(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23035,        763]*)
(*NotebookOutlinePosition[     55421,       1848]*)
(*  CellTagsIndexPosition[     55050,       1831]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Appendix: Finite-Differenced Derivatives", "Title",
  CellTags->"i:1"],

Cell[TextData[{
  "\tSay we know the value of some smooth function ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " only at a sequence of evenly spaced grid points ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "=", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2, 3,  ... \)]],
  ". How do we determine an approximate numerical value for the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th derivative of this function, ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^\((n)\)\)(x)\)]],
  ",  evaluated at one of the grid points ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ x\_i\)]],
  "? What will be the error in this derivative compared to the true value? "
}], "Text"],

Cell[TextData[{
  "\tWe will refer to this finite-differenced form of the derivative as ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_FD\%\((n)\)\)(x)\)]],
  ", in order to distinguish it from the exact derivative ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^\((n)\)\)(x)\)]],
  " of the function. We will write the finite differenced derivative, \
evaluated at the grid position ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  ", as a linear combination of the values ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_j)\)]],
  "at ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " consecutive grid points, starting at ",
  Cell[BoxData[
      \(TraditionalForm\`j = l\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(y\_FD\%\((n)\)\)(x\_i)\), " ", "=", " ", 
          RowBox[{
            RowBox[{\(\[Sum]\+\(j = l\)\%\(l + M - 1\)\), 
              FractionBox[
                RowBox[{\(a\_j\), " ", 
                  RowBox[{"y", "(", 
                    RowBox[{\(x\_i\), "+", " ", 
                      RowBox[{"j", " ", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]]}]}], ")"}]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "n"]]}], "+", " ", 
            RowBox[{"O", "(", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "p"], ")"}]}]}], 
        TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(A.1)"],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  "'s are constants that remain to be determined, the order of the error ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " also must be determined, and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " is arbitrary.  Typically for best accuracy ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "are chosen so that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + l\) \[LessEqual] \ x\_i \[LessEqual] \ 
        x\_\(i + l + M - 1\)\)]],
  ", but this is not required by the mathematics. We have anticipated that \
each term in the sum will be of order ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "n"]}], TraditionalForm]]],
  " and have divided this term out, so that the ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j' s\)]],
  " are of order unity."
}], "Text"],

Cell[TextData[{
  "\tIn order to find the ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j' s\)]],
  ", we will Taylor-expand ",
  Cell[BoxData[
      FormBox[
        RowBox[{"y", "(", 
          RowBox[{\(x\_i\), "+", " ", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], ")"}], TraditionalForm]]],
  " up to order ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"y", "(", 
            RowBox[{\(x\_i\), "+", " ", 
              RowBox[{"j", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]}], ")"}], "=", 
          RowBox[{
            RowBox[{\(\[Sum]\+\(k = 0\)\%\(M - 1\)\), 
              RowBox[{\(1\/\(k!\)\), 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"j", " ", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}], ")"}], "k"], 
                " ", \(\(y\^\((k)\)\)(x\_i)\)}]}], "+", " ", 
            RowBox[{"O", "(", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "M"], ")"}]}]}], 
        TraditionalForm]]],
  ". "
}], "NumberedEquation",
  CellTags->"(A.2)"],

Cell[TextData[{
  "Substituting this expression into Eq. ",
  ButtonBox["(A.1)",
    ButtonData:>"(A.1)",
    ButtonStyle->"Hyperlink"],
  " yields "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(y\_FD\%\((n)\)\)(x\_i)\), " ", "=", " ", 
        RowBox[{
          RowBox[{\(\[Sum]\+\(k = 0\)\%\(M - 1\)\), 
            RowBox[{\(1\/\(k!\)\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], \(k - n\)], \(\(y\^\((k)\)\)(
                x\_i)\), \(\[Sum]\+\(j = l\)\%\(l + M - 1\)a\_j\ j\^k\)}]}], 
          "+", " ", 
          RowBox[{"O", "(", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], \(M - n\)], ")"}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(A.3)"],

Cell[TextData[{
  "In order for this expression to be valid for any choice of the function ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ", we require that only terms on the right-hand side that are proportional \
to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(y\^\((n)\)\)(x\_i)\)\(\ \)\)\)]],
  " survive the summations. Since, for general ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ",  the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^\((k)\)\)(x\_i)\)]],
  " are independent variables, we therefore require that "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+\(j = l\)\%\(l + M - 1\)a\_j\ j\^k = \(0\ \
for\ \ k = 0\), 1, 2,  ... , M - 1, \ 
    k \[NotEqual] \ n, \)]]], "NumberedEquation",
  CellTags->"(A.4)"],

Cell[TextData[{
  "and for ",
  Cell[BoxData[
      \(TraditionalForm\`k = n\)]],
  ", "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(1\/\(n!\)\) \(\[Sum]\+\(j = l\)\%\(l + M - 1\)a\_j\ \
j\^n\) = 1\)]]], "NumberedEquation",
  CellTags->"(A.5)"],

Cell[TextData[{
  "When these equations are used in Eq. ",
  ButtonBox["(A.3)",
    ButtonData:>"(A.3)",
    ButtonStyle->"Hyperlink"],
  ", that equation becomes "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(y\_FD\%\((n)\)\)(x\_i)\), " ", "=", 
          RowBox[{\(\(y\^\((n)\)\)(x\_i)\), " ", "+", " ", 
            RowBox[{"O", "(", " ", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], \(M - n\)], ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(A.6)"],

Cell[TextData[{
  "\t  Equations ",
  ButtonBox["(A.4)",
    ButtonData:>"(A.4)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(A.5)",
    ButtonData:>"(A.5)",
    ButtonStyle->"Hyperlink"],
  " provide us with ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " linear equations in the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " unknowns ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j, \ j = l,  .. , l + M - 1\)]],
  ".  Their solution provides us with a finite-differenced form for the \
derivative, Eq. ",
  ButtonBox["(A.1)",
    ButtonData:>"(A.1)",
    ButtonStyle->"Hyperlink"],
  ". Furthermore, the order of the error in the finite differenced derivative \
scales as",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[""], "p"}], "=", \(M - n\)}], TraditionalForm]]],
  ".  Therefore, to reduce the error to at most ",
  Cell[BoxData[
      FormBox[
        RowBox[{"O", "(", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], ")"}], TraditionalForm]]],
  ", an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th derivative requires at least ",
  Cell[BoxData[
      \(TraditionalForm\`M = n + 1\)]],
  " points to be used in Eq. ",
  ButtonBox["(A.1)",
    ButtonData:>"(A.1)",
    ButtonStyle->"Hyperlink"],
  ". Furthermore, the larger the value of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", the more accurate the approximation. "
}], "Text"],

Cell[TextData[{
  "\tFor example, consider the first derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_i)\)]],
  ". In order to find an ",
  Cell[BoxData[
      FormBox[
        RowBox[{"O", "(", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], ")"}], TraditionalForm]]],
  " form for this derivative, we require two points, ",
  Cell[BoxData[
      \(TraditionalForm\`M = 2\)]],
  ". If we choose these points as ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_i)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_\(i + 1\))\)]],
  ", then Eq. ",
  ButtonBox["(A.4)",
    ButtonData:>"(A.4)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(j = 0\)\%1 a\_j\ j\^0 = \(\(a\_0 + \ 
            a\_1\)\(=\)\(0\)\(\ \)\)\)]],
  ","
}], "unnum"],

Cell[TextData[{
  "and Eq. ",
  ButtonBox["(A.5)",
    ButtonData:>"(A.5)",
    ButtonStyle->"Hyperlink"],
  " is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[\(\(1\/\(1!\)\) \(\[Sum]\+\(j = 0\)\%1 a\_j\ j\^1\) = \ \(\(a\
\_1\)\(=\)\(1\)\(\ \)\)\),
          "TraditionalForm"], "."}], TraditionalForm]]]], "unnum"],

Cell[TextData[{
  "Therefore, we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_\(\(1\)\(\ \)\) = \ \(\(-\ a\_0\) = 
          1\)\)\(,\)\)\)]],
  " and Eq. ",
  ButtonBox["(A.1)",
    ButtonData:>"(A.1)",
    ButtonStyle->"Hyperlink"],
  " becomes the standard form for a forward-differenced first derivative,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(y\_FD\%\((n)\)\)(x\_i)\), " ", "=", 
          RowBox[{
            FractionBox[\(y(x\_\(i + 1\)) - y(x\_i)\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]], "+", " ", 
            RowBox[{"O", "(", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], ")"}]}]}], TraditionalForm]]],
  ". "
}], "unnum"],

Cell[TextData[{
  "\tHowever, for derivatives where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is even, such as ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[DoublePrime]\)]],
  ", we can do a bit better if we use a ",
  StyleBox["centered-difference",
    FontSlant->"Italic"],
  " form of the derivative. In such a form, ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " is chosen so that the number of grid points in Eq. ",
  ButtonBox["(A.1)",
    ButtonData:>"(A.1)",
    ButtonStyle->"Hyperlink"],
  "  below ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " equals the number of points above ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  ", that is,  ",
  Cell[BoxData[
      \(TraditionalForm\`l = \(-\((M - 1)\)\)/2\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " odd.  "
}], "Text"],

Cell[TextData[{
  "\tThe error estimate in Eq. ",
  ButtonBox["(A.3)",
    ButtonData:>"(A.3)",
    ButtonStyle->"Hyperlink"],
  " assumes that the ",
  Cell[BoxData[
      FormBox[
        RowBox[{"O", "(", 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], \(M - n\)], ")"}], 
        TraditionalForm]]],
  "term in the power series expansion has a nonvanishing coefficient. \
However, if we choose a centered-difference form for the derivative, one can \
show that this term actually vanishes thanks to the symmetry of the sum, and \
the error is actually ",
  Cell[BoxData[
      FormBox[
        RowBox[{"O", "(", 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], \(M - n + 1\)], ")"}], 
        TraditionalForm]]],
  ". Thus, for a centered-difference form of the second derivative, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 3\)]],
  " terms involving ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_\(i - 1\))\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(x\_i)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_\(i + 1\))\)]],
  " results in an error not of order ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", but rather of order ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "2"], TraditionalForm]]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(y\_FD\%\[DoublePrime]\)(x\_i)\), "=", 
          RowBox[{
            
            FractionBox[\(y(x\_\(i + 1\)) - 2 \( y(x\_i)\) + 
                y(x\_\(i - 1\))\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], "+", " ", 
            RowBox[{
              RowBox[{"O", "(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"], ")"}], Cell[""]}]}]}], 
        TraditionalForm]]],
  "."
}], "unnum"],

Cell[TextData[{
  "\tCentered-difference forms for odd derivatives also exist, for which one \
again takes ",
  Cell[BoxData[
      \(TraditionalForm\`l = \(-\((M - 1)\)\)/2\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " odd. For these derivatives, one can show that ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0 = 0\)]],
  " using symmetry, and as a result these centered-difference odd derivatives \
are independent of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_i)\)]],
  ". For instance, one finds that the centered-difference form of ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[Prime]\)]],
  " taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 3\)]],
  " terms is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(y\_FD\%\[Prime]\)(x\_i)\), "=", 
        RowBox[{
          
          FractionBox[\(y(x\_\(i + 1\)) + 0 \( y(x\_i)\) - y(x\_\(i - 1\))\), 
            
            RowBox[{"2", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]], "+", " ", 
          RowBox[{
            RowBox[{"O", "(", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], ")"}], 
            RowBox[{Cell[""], "."}]}]}]}], TraditionalForm]]]], "unnum"],

Cell[TextData[{
  "\tOf course, it is possible to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to solve Eqs. ",
  ButtonBox["(A.4)",
    ButtonData:>"(A.4)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(A.5)",
    ButtonData:>"(A.5)",
    ButtonStyle->"Hyperlink"],
  " for derivatives of any order, keeping any number of grid points. Below, \
we provide a module that does so. It evaluates ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`\(y\_FD\%\((n)\)\)(0)\)]]]], 
        TraditionalForm]]],
  " keeping grid points from ",
  Cell[BoxData[
      \(TraditionalForm\`j = l\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`j = l + M - 1\)]],
  ": "
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(FD[n_, M_, l_]\  := \ 
      Module[{p, eqns1, eqns2, eqn3, coeff, 
          a}, \[IndentingNewLine]p[j_, k_]\  = \ 
          j\^\(\(k\)\(\ \ \)\); \[IndentingNewLine]p[0, 0]\  = \ 1; 
        eqns1\  = \ 
          Table[Sum[a[j]\ \ p[j, k], {j, l, l + M - 1}] \[Equal] 0, {k, 0, 
              n - 1}]; \ \[IndentingNewLine]eqns2\  = \ 
          Table[Sum[a[j]\ \ p[j, k], {j, l, l + M - 1}] \[Equal] 0, {k, 
              n + 1, M - 
                1}]; \[IndentingNewLine]eqn3\  = \ {Sum[
                  a[j]\ \ p[j, n], {j, l, l + M - 1}]/\(n!\) \[Equal] 1}; 
        coeff\  = \ 
          Solve[Join[eqns1, eqns2, eqn3], 
            Table[a[j], {j, l, l + M - 1}]]; \[IndentingNewLine]Together[
          Expand[\ Sum[
                  a[j]\ y[j\ \[CapitalDelta]x], {j, l, 
                    l + M - 1}]/\[CapitalDelta]x^n] /. 
            coeff[\([1]\)]]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell A.1"],

Cell[TextData[{
  "For instance, a second-order-accurate backward-difference version of the \
first derivative, ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`\(y\_FD\%\[Prime]\)(0)\)]]]], 
        TraditionalForm]]],
  ", is given by"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FD[1, 3, \(-2\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell A.2"],

Cell[BoxData[
    \(\(3\ y[0] + y[\(-2\)\ \[CapitalDelta]x] - 4\ y[\(-\[CapitalDelta]x\)]\)\
\/\(2\ \[CapitalDelta]x\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This can be checked by Taylor expanding the result in powers of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[%, {\[CapitalDelta]x, 0, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell A.3"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "0", "]"}], "+", 
        InterpretationBox[\(O[\[CapitalDelta]x]\^2\),
          SeriesData[ \[CapitalDelta]x, 0, {}, 0, 2, 1]]}],
      SeriesData[ \[CapitalDelta]x, 0, {
        Derivative[ 1][ y][ 0]}, 0, 2, 1]]], "Output"]
}, Open  ]],

Cell["\<\
As a second example, the second-order-accurate centered-difference \
form of the fourth derivative is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FD[4, 5, \(-2\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell A.4"],

Cell[BoxData[
    \(\(6\ y[0] + y[\(-2\)\ \[CapitalDelta]x] - 4\ y[\(-\[CapitalDelta]x\)] - \
4\ y[\[CapitalDelta]x] + y[2\ \[CapitalDelta]x]\)\/\[CapitalDelta]x\^4\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "Again, the form and the error can be checked by Taylor-expanding the \
result in powers of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[%, {\[CapitalDelta]x, 0, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell A.5"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["y", 
            TagBox[\((4)\),
              Derivative],
            MultilineFunction->None], "[", "0", "]"}], "+", 
        InterpretationBox[\(O[\[CapitalDelta]x]\^2\),
          SeriesData[ \[CapitalDelta]x, 0, {}, 0, 2, 1]]}],
      SeriesData[ \[CapitalDelta]x, 0, {
        Derivative[ 4][ y][ 0]}, 0, 2, 1]]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Appendix"}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> ("NextIndexingNumber" -> 2), \
"IndexEntries" -> {{"i:1", "Derivatives", "finite-differenced forms", ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(A.", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["unnum"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"unnum",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["unnum", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:1"->{
    Cell[1727, 52, 76, 1, 69, "Title",
      CellTags->"i:1"]},
  "(A.1)"->{
    Cell[3432, 106, 1111, 30, 45, "NumberedEquation",
      CellTags->"(A.1)"]},
  "(A.2)"->{
    Cell[6178, 194, 1118, 31, 40, "NumberedEquation",
      CellTags->"(A.2)"]},
  "(A.3)"->{
    Cell[7463, 235, 812, 20, 43, "NumberedEquation",
      CellTags->"(A.3)"]},
  "(A.4)"->{
    Cell[8853, 274, 212, 4, 43, "NumberedEquation",
      CellTags->"(A.4)"]},
  "(A.5)"->{
    Cell[9171, 287, 164, 3, 38, "NumberedEquation",
      CellTags->"(A.5)"]},
  "(A.6)"->{
    Cell[9517, 300, 485, 14, 35, "NumberedEquation",
      CellTags->"(A.6)"]},
  "Cell A.1"->{
    Cell[19287, 635, 1030, 22, 251, "Input",
      CellTags->"Cell A.1"]},
  "Cell A.2"->{
    Cell[20637, 671, 95, 3, 67, "Input",
      CellTags->"Cell A.2"]},
  "Cell A.3"->{
    Cell[21182, 694, 114, 3, 67, "Input",
      CellTags->"Cell A.3"]},
  "Cell A.4"->{
    Cell[21845, 718, 95, 3, 67, "Input",
      CellTags->"Cell A.4"]},
  "Cell A.5"->{
    Cell[22465, 743, 114, 3, 67, "Input",
      CellTags->"Cell A.5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:1", 53962, 1791},
  {"(A.1)", 54039, 1794},
  {"(A.2)", 54133, 1797},
  {"(A.3)", 54227, 1800},
  {"(A.4)", 54320, 1803},
  {"(A.5)", 54412, 1806},
  {"(A.6)", 54504, 1809},
  {"Cell A.1", 54600, 1812},
  {"Cell A.2", 54691, 1815},
  {"Cell A.3", 54778, 1818},
  {"Cell A.4", 54866, 1821},
  {"Cell A.5", 54953, 1824}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 76, 1, 69, "Title",
  CellTags->"i:1"],
Cell[1806, 55, 909, 26, 64, "Text"],
Cell[2718, 83, 711, 21, 71, "Text"],
Cell[3432, 106, 1111, 30, 45, "NumberedEquation",
  CellTags->"(A.1)"],
Cell[4546, 138, 1105, 34, 80, "Text"],
Cell[5654, 174, 521, 18, 28, "Text"],
Cell[6178, 194, 1118, 31, 40, "NumberedEquation",
  CellTags->"(A.2)"],
Cell[7299, 227, 161, 6, 27, "Text"],
Cell[7463, 235, 812, 20, 43, "NumberedEquation",
  CellTags->"(A.3)"],
Cell[8278, 257, 572, 15, 64, "Text"],
Cell[8853, 274, 212, 4, 43, "NumberedEquation",
  CellTags->"(A.4)"],
Cell[9068, 280, 100, 5, 27, "Text"],
Cell[9171, 287, 164, 3, 38, "NumberedEquation",
  CellTags->"(A.5)"],
Cell[9338, 292, 176, 6, 27, "Text"],
Cell[9517, 300, 485, 14, 35, "NumberedEquation",
  CellTags->"(A.6)"],
Cell[10005, 316, 1502, 51, 98, "Text"],
Cell[11510, 369, 756, 26, 44, "Text"],
Cell[12269, 397, 165, 5, 43, "unnum"],
Cell[12437, 404, 127, 6, 27, "Text"],
Cell[12567, 412, 228, 5, 43, "unnum"],
Cell[12798, 419, 334, 10, 27, "Text"],
Cell[13135, 431, 562, 16, 41, "unnum"],
Cell[13700, 449, 851, 30, 62, "Text"],
Cell[14554, 481, 1779, 56, 106, "Text"],
Cell[16336, 539, 760, 22, 41, "unnum"],
Cell[17099, 563, 721, 22, 62, "Text"],
Cell[17823, 587, 716, 19, 41, "unnum"],
Cell[18542, 608, 742, 25, 67, "Text"],
Cell[19287, 635, 1030, 22, 251, "Input",
  CellTags->"Cell A.1"],
Cell[20320, 659, 292, 8, 28, "Text"],

Cell[CellGroupData[{
Cell[20637, 671, 95, 3, 67, "Input",
  CellTags->"Cell A.2"],
Cell[20735, 676, 132, 2, 64, "Output"]
}, Open  ]],
Cell[20882, 681, 275, 9, 27, "Text"],

Cell[CellGroupData[{
Cell[21182, 694, 114, 3, 67, "Input",
  CellTags->"Cell A.3"],
Cell[21299, 699, 381, 9, 50, "Output"]
}, Open  ]],
Cell[21695, 711, 125, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[21845, 718, 95, 3, 67, "Input",
  CellTags->"Cell A.4"],
Cell[21943, 723, 180, 3, 64, "Output"]
}, Open  ]],
Cell[22138, 729, 302, 10, 27, "Text"],

Cell[CellGroupData[{
Cell[22465, 743, 114, 3, 67, "Input",
  CellTags->"Cell A.5"],
Cell[22582, 748, 425, 11, 50, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

