(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   7687563,     239792]*)
(*NotebookOutlinePosition[   7791045,     243004]*)
(*  CellTagsIndexPosition[   7776830,     242548]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1. Ordinary Differential Equations in the Physical Sciences", "Title",
  CellTags->{"chapter 2", "i:5", "c:1"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["1.1 Introduction", "Subtitle",
  CellTags->{"Sec. 1.1", "c:2"}],

Cell[" ", "Text"],

Cell[CellGroupData[{

Cell["1.1.1 Definitions", "Subsubtitle",
  CellTags->"c:3"],

Cell[CellGroupData[{

Cell["\<\
Differential Equations, Unknown Functions, and Initial Conditions\
\
\>", "Section",
  CellTags->{"i:1", "c:4"}],

Cell[TextData[{
  "\tThree centuries ago, the great British mathematician, scientist, and \
curmudgeon  ",
  ButtonBox["Sir Isaac Newton",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Newton.\
html"], None},
    ButtonStyle->"Hyperlink"],
  "  and the German mathematician ",
  ButtonBox["Gottfried von Liebniz",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Leibniz.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " independently introduced the world to calculus, and in so doing ushered \
in the modern scientific era. It has since been established in countless \
experiments that natural phenomena of all kinds can be described, often in \
exquisite detail, by the solutions to ",
  StyleBox["differential equations",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:2"],

Cell[TextData[{
  " \t",
  StyleBox["Differential equations involve derivatives of an ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["unknown function",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" or functions, whose form we try to determine through solution of \
the equations. For example, consider the motion (in one dimension) of a point \
particle of mass ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["m",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" under the action of a prescribed time-dependent force ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["F",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["). The particle's velocity ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["v",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[") satisfies Newton's second law ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text",
  CellTags->"i:4"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`m\ \[DifferentialD]v/\[DifferentialD]t\  = \ \(\(F(
          t)\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(1.1.1)"],

Cell[TextData[{
  StyleBox["This is a differential equation for the unknown function ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`v(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\tEquation ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["(1.1.1",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[") is probably the simplest differential equation that one can \
write down. It can be solved by ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  "applying",
  StyleBox[" the ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["fundamental theorem of calculus",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[":  for any function ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  StyleBox[" whose derivative exists and is integrable on the interval ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  StyleBox[",",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\(\[DifferentialD]f\/\
\[DifferentialD]t\) \[DifferentialD]t = f(b) - f(a)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(1.1.2)"],

Cell[TextData[{
  StyleBox[" Integrating both sides of Eq. ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["(1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" from an initial time",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t = 0\)\)\)]],
  StyleBox[" to time ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  StyleBox[" and using Eq. ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["(1.1.2)",
    ButtonData:>"(1.1.2)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" yields",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Integral]\_0\%t\), 
            RowBox[{
              FractionBox[
                RowBox[{
                  StyleBox["\[DifferentialD]",
                    FontSlant->"Plain"], " ", 
                  "v"}], \(\[DifferentialD]t\)], \(\[DifferentialD]t\)}]}], 
          "=", \(v(t) - 
              v(0) = \(1\/m\) \(\[Integral]\_0\%t\( F(
                    t)\) \[DifferentialD]t\)\)}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(1.1.3)"],

Cell[TextData[{
  StyleBox["Therefore, the solution of ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" for the velocity at time ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t ",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["is given by the integral over time of the force, a known \
function, and an ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["initial condition",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[", the velocity at time ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["=0. This initial condition can be thought of mathematically as a \
constant of integration that appears when the integral is applied to ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[".  Physically,  the requirement that we need to know the initial \
velocity in order to find the velocity at later times is intuitively obvious. \
 However, it also implies that the differential ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["equation (1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" by itself is not enough to completely determine a solution for ",
    
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["v",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["); the initial velocity must also be provided. This is a general \
feature of differential equations: ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text",
  CellTags->"i:3"],

Cell[TextData[StyleBox["Extra conditions beyond the equation itself must be \
supplied in order to completely determine a solution of a differential \
equation.",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["\tIf the initial condition is",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox[" not ",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" known, so that ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["v",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(0) is an undetermined constant in ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.3)",
    ButtonData:>"(1.1.3)",
    ButtonStyle->"Hyperlink"],
  StyleBox[", then we call ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.3)",
    ButtonData:>"(1.1.3)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" a ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["general",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["solution",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" to the differential equation, because different choices of the \
undetermined constant allow the solution to satisfy different initial \
conditions. ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text",
  CellTags->"i:13"],

Cell[TextData[{
  StyleBox["\tAs a second example of a differential equation, let's now \
assume that the force in ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" depends on the position ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["x",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[") of the particle according to ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Hooke's law",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Hooke.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  StyleBox[":",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text",
  CellTags->"i:9"],

Cell[TextData[{
  StyleBox["F",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[") = - ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["k",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["x",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["),",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "NumberedEquation",
  CellTags->"(1.1.4)"],

Cell[TextData[{
  StyleBox["where ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["k",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" is a constant (the spring constant). Then, using the definition \
of velocity as the rate of change of position,",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text"],

Cell[TextData[{
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"v", "=", 
          RowBox[{\(\[DifferentialD]x\), "/", 
            RowBox[{
              StyleBox["\[DifferentialD]",
                FontSlant->"Plain"], 
              StyleBox["t",
                FontSlant->"Italic"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->{"(1.1.5)", "i:70"}],

Cell[TextData[{
  ButtonBox["Eq. (1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" becomes a differential equation for the unknown function ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["x",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["):",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], 
          "=", \(\(-\(\(\(k\)\(\ \)\)\/m\)\) \(x(t)\)\)}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(1.1.6)"],

Cell[TextData[{
  StyleBox["\tThis familiar differential equation, the ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["harmonic oscillator",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" equation, has a general solution in terms of the trigonometric \
functions ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`sin\ x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ x\)]],
  ", and ",
  StyleBox["two",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" undetermined constants ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  StyleBox[" and ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  StyleBox[":",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text",
  CellTags->"i:10"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(
          t) = \(C\_1\) \(cos(\[Omega]\_o\ t)\)\  + \(C\_2\) \
\(sin(\[Omega]\_o\ t)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(1.1.7)"],

Cell[TextData[{
  StyleBox["where  ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = \@\(k/m\)\)]],
  StyleBox[" is the natural frequency of the oscillation.  The two constants \
can be determined by two initial conditions, on the initial position and \
velocity: ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text"],

Cell[TextData[{
  StyleBox["x",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(0) = ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  StyleBox[" , ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["v",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(0)=",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  StyleBox[".",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "NumberedEquation",
  CellTags->"(1.1.8)"],

Cell[TextData[{
  StyleBox["Since ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.7)",
    ButtonData:>"(1.1.7)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" implies that ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["x",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(0) = ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  StyleBox[" and  ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[Prime]\)(
          0) = \(v(0) = \(\[Omega]\_o\) C\_2\)\)]],
  StyleBox[", the solution can be written directly in terms of the initial \
conditions as  ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(
          t) = \(x\_o\) \(cos(\[Omega]\_o\ t)\)\  + \(\(\(\ \)\(v\_o\)\)\/\
\[Omega]\_o\) \(sin(\[Omega]\_o\ t)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(1.1.9)"],

Cell[TextData[{
  StyleBox["We can easily verify that this solution satisfies the \
differential equation by substituting it into  ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.6)",
    ButtonData:>"(1.1.6)",
    ButtonStyle->"Hyperlink"],
  StyleBox[":",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(x[t_]\  = \ 
        x0\ Cos[\[Omega]\_o\ t]\  + \ 
          v0/\[Omega]\_o\ Sin[\[Omega]\_o\ \ t];\)\[IndentingNewLine]
    Simplify[\ \(x''\)[
          t]\  \[Equal] \ \(-\[Omega]\_o^2\)\ x[t]]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.1"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["We can also verify that the solution matches the \
initial conditions:",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.2"],

Cell[BoxData[
    \(x0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x'\)[0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.3"],

Cell[BoxData[
    \(v0\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Order of a Differential Equation", "Section",
  CellTags->"c:5"],

Cell[TextData[{
  StyleBox["\tThe ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["order",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" of a differential equation is the order of the highest \
derivative of the unknown function that appears in the equation. Since only a \
first derivative of ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["v",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[")  appears in ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[", the equation is a  ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["first-order",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" differential equation for ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["v",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["(",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["). On the other hand, Equation ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["(1.1.6)",
    ButtonData:>"(1.1.6)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" is a ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["second-order",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox[" differential equation.",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text",
  CellTags->"i:11"],

Cell[TextData[{
  StyleBox["\tNote that the general solution ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["(1.1.3)",
    ButtonData:>"(1.1.3)",
    ButtonStyle->"Hyperlink"],
  StyleBox[" of the first-order equation ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["(1.1.1",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[") involved one undetermined constant,but for the second",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  "-order",
  StyleBox[" equation, ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  StyleBox["two ",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  StyleBox["undetermined constants were required in  ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  ButtonBox["Eq. (1.1.7)",
    ButtonData:>"(1.1.7)",
    ButtonStyle->"Hyperlink"],
  StyleBox[". It's easy to see why this must be so - an ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  StyleBox["th-order differential equation involves the ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "th derivative of the unknown function",
  StyleBox[". To determine this function one needs to integrate the equation \
",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  StyleBox[" times, giving ",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  StyleBox[" constants of integration.",
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
}], "Text"],

Cell["\<\
The number of undetermined constants that enter the general \
solution of an ordinary differential equation equals the order of the \
equation.\
\>", "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Partial Differential Equations", "Section",
  CellTags->{"i:7", "c:6"}],

Cell[TextData[{
  "This statement applies only to ",
  StyleBox["ordinary ",
    FontSlant->"Italic"],
  "differential equations (ODEs), which are differential equations for which \
derivatives of the unknown function are taken with respect to only a single \
variable.  The two examples that we have seen so far have been ODEs, since \
only derivatives with respect to time appeared. However, this book will also \
consider ",
  StyleBox["partial",
    FontSlant->"Italic"],
  " differential equations (PDEs), which involve derivatives of the unknown \
function with respect to ",
  StyleBox["several ",
    FontSlant->"Italic"],
  "variables.  One example of a PDE is ",
  ButtonBox["Poisson's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Poisson.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " equation, relating the electrostatic potential ",
  StyleBox["\[Phi]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ",",
  StyleBox["y",
    FontSlant->"Italic"],
  ",",
  StyleBox["z",
    FontSlant->"Italic"],
  ") to the charge density ",
  StyleBox["\[Rho]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ",",
  StyleBox["y",
    FontSlant->"Italic"],
  ",",
  StyleBox["z",
    FontSlant->"Italic"],
  ") of a distribution of charges:"
}], "Text",
  CellTags->"i:6"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y, 
          z)\) = \(-\(\(\(\[Rho](x, y, 
                z)\)\/\[Epsilon]\_o\)\(.\)\)\)\)]]], "NumberedEquation",
  CellTags->"(1.1.10)"],

Cell[TextData[{
  "Here ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_o\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "is a constant (the dielectric permittivity of free space, given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\[Epsilon]\_o\),
              "TraditionalForm"], "=", 
            RowBox[{\(\(8.85 ... \)\ \[Cross]10\^\(-12\)\), 
              RowBox[{
                StyleBox["F",
                  FontSlant->"Plain"], "/", 
                StyleBox["m",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  "), and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " is the ",
  StyleBox["Laplacian operator",
    FontSlant->"Italic"],
  ", "
}], "Text",
  CellTags->"i:8"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Del]\^2\), 
          RowBox[{"=", 
            RowBox[{
              FractionBox[\(\[PartialD]\^2\), \(\[PartialD]x\^2\),
                MultilineFunction->None], "+", 
              FractionBox[\(\[PartialD]\^2\), \(\[PartialD]y\^2\),
                MultilineFunction->None], "+", 
              FractionBox[\(\[PartialD]\^2\), \(\[PartialD]z\^2\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(1.1.11)"],

Cell[TextData[{
  "We will find that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " appears frequently in the equations of mathematical physics. "
}], "Text"],

Cell[TextData[{
  "\tLike ODEs, PDEs must be supplemented with extra conditions in order to \
obtain a specific solution. However, the form of these conditions becomes \
more complex than for ODEs. In the case of Poisson's equation, ",
  StyleBox[" boundary conditions ",
    FontSlant->"Italic"],
  "must be specified over one or more surfaces that bound the volume within \
which the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, z)\)]],
  " is determined. "
}], "Text",
  CellTags->"i:123"],

Cell[TextData[{
  "\t A discussion of solutions to Poisson\[CloseCurlyQuote]s equation and \
other PDE\[CloseCurlyQuote]s of mathematical physics can be found in Chapter \
",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  " and later chapters. For now we will confine ourselves to ODEs. Many of \
the techniques used to solve ODEs can also be applied to PDEs. "
}], "Text"],

Cell["\<\
An ODE involves derivatives of the unknown function with respect to \
only a single variable. A PDE involves derivatives of the unknown function \
with respect to more than one variable.\
\>", "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initial-Value and Boundary-Value Problems", "Section",
  CellTags->"c:7"],

Cell[TextData[{
  "\tEven if we limit discussion to ODEs, there is still an important \
distinction to be made, between ",
  StyleBox["initial-value problems",
    FontSlant->"Italic"],
  " and ",
  StyleBox["boundary-value problems",
    FontSlant->"Italic"],
  ". In initial-value problems, the unknown function is required in some time \
domain ",
  StyleBox["t",
    FontSlant->"Italic"],
  " >0 and all conditions to specify  the solution are given at ",
  StyleBox["one",
    FontSlant->"Italic"],
  " end of this domain, at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " =0. Equations ",
  ButtonBox["(1.1.3)",
    ButtonData:>"(1.1.3)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(1.1.9)",
    ButtonData:>"(1.1.9)",
    ButtonStyle->"Hyperlink"],
  " are solutions of initial-value problems."
}], "Text",
  CellTags->"i:12"],

Cell[TextData[{
  "\t However, in boundary-value problems, conditions that specify the \
solution are given at different times or places. Examples of boundary-value \
problems in ODEs may be found in ",
  ButtonBox["Sec. 1.5",
    ButtonData:>"Sec. 1.5",
    ButtonStyle->"Hyperlink"],
  ". (Problems involving PDE\[CloseCurlyQuote]s are often boundary- value \
problems; Poisson\[CloseCurlyQuote]s equation ",
  ButtonBox["(1.1.10)",
    ButtonData:>"(1.1.10)",
    ButtonStyle->"Hyperlink"],
  " is an example. In Chapter ",
  ButtonBox["3",
    ButtonData:>"Chapter3.nb",
    ButtonStyle->"Hyperlink"],
  " we will find that some PDE\[CloseCurlyQuote]s involving both time and \
space derivatives are solved as both boundary- ",
  StyleBox["and",
    FontSlant->"Italic"],
  " initial-value problems.)"
}], "Text"],

Cell["\<\
\tFor now, we will stick to a discussion of ODE initial-value \
problems. \
\>", "Text"],

Cell[TextData[{
  "In initial-value problems, all conditions to specify a solution are given \
at one point in time or space, and are termed ",
  StyleBox["initial conditions",
    FontSlant->"Italic"],
  ". In boundary-value problems, the conditions are given at several points \
in time or space, and are termed ",
  StyleBox["boundary conditions",
    FontSlant->"Italic"],
  ". For ODEs, the boundary conditions are usually given at two points, \
between which the solution to the ODE must be determined."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:121"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercises for Sec. 1.1",
  FontFamily->"Helvetica"]], "Subsubtitle",
  CellTags->{"Ex. 1.1", "c:8"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Is ",
  ButtonBox["Eq. (1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  " still a differential equation if the velocity  ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") is given and the force ",
  StyleBox["F",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") is the unknown function?"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Determine by substitution whether the following functions satisfy the \
given differential equation, and if so, state whether the functions are a \
general solution to the equation:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", \(x(t)\)}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x(
          t) = \(C\_1\) \(sinh(
              t)\)\  + \ \(C\_2\) \[ExponentialE]\^\(-t\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None], ")"}], "2"], "=", \(x(t)\)}], 
        TraditionalForm]]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`x(t) = 1\/4\ \((a\^2 + t\^2)\) - \(a\ t\)\/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\^4 x\), \(\[DifferentialD]t\^4\),
              MultilineFunction->None], "-", 
            RowBox[{"3", " ", 
              
              FractionBox[\(\[DifferentialD]\^3 x\), \(\[DifferentialD]t\^3\),
                
                MultilineFunction->None]}], "-", 
            RowBox[{"7", " ", 
              
              FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
                
                MultilineFunction->None]}], "+", 
            RowBox[{"15", " ", 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], "+", \(18\ x\)}], 
          "=", \(12\ t\^2\)}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`x(t) = 
        a\ \[ExponentialE]\^\(3\ t\)\ t + 
          b\ \[ExponentialE]\^\(\(-2\)\ t\) + \(2\ t\^2\)\/3 - \(10\ t\)\/9 + 
          13\/9\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Prove by substitution that the following functions are general solutions \
to the given differential equations, and find values for the undetermined \
constants in order to match the boundary or initial conditions. Plot the \
solutions:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
              MultilineFunction->None], "=", \(5\ \(x(t)\) - 3\)}], ",", 
          " ", \(x(0) = 1; \ x(t) = C\ \[ExponentialE]\^\(5\ t\) + 3/5\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              
              FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
                
                MultilineFunction->None], "+", 
              RowBox[{"4", 
                FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                  MultilineFunction->None]}], "+", \(4\ \(x(t)\)\)}], "=", 
            "0"}], ",", " ", \(x(0) = 0\), 
          ",", \(\(x\^\[Prime]\)(1) = \(-3\)\)}], TraditionalForm]]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`x(t) = 
        C\_1\ \[ExponentialE]\^\(\(\ \)\(\(-2\)\ t\)\)\  + \(\(C\_2\) \(t\)\(\
\ \)\(\[ExponentialE]\^\(\(-2\) t\)\)\(\ \)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              
              FractionBox[\(\[DifferentialD]\^3 x\), \(\[DifferentialD]t\^3\),
                
                MultilineFunction->None], "+", 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], "=", "t"}], ",", 
          " ", \(x(0) = 0\), ",", " ", \(\(x\^\[Prime]\)(0) = 1\), 
          ",", \(\(x\^\[DoublePrime]\)(\[Pi]) = 0; \ 
          x(t) = \(\(t\^2/
                2\)\(\ \)\(+\)\(\ \)\(C\_1\ Sin\ t\)\(\ \)\(+\)\(\ \)\(C\_2\ \
Cos\ t\)\(\ \)\(+\)\(\ \)\(C\_3\)\(\ \)\)\)}], TraditionalForm]]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2 Graphical Solution of Initial-Value Problems", "Subtitle",
  CellTags->{"Sec. 1.2", "i:14", "c:9"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["\<\
1.2.1 Direction Fields; Existence and Uniqueness of Solutions\
\>", \
"Subsubtitle",
  CellTags->"c:10"],

Cell[TextData[{
  "In an ",
  "initial-value",
  " problem, how do we know when the initial conditions specify a ",
  StyleBox["unique",
    FontSlant->"Italic"],
  " solution to an ODE? And how do we know that the solution will even exist? \
These fundamental questions are addressed by the following theorem:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    StyleBox[GridBox[{
          {
            RowBox[{
            "                                                                 \
", 
              StyleBox[\(Theorem\ 1  .1\),
                FontWeight->"Bold"]}]},
          {
            RowBox[{\(Consider\ a\ general\ initial\), "-", 
              RowBox[{
              "value", " ", "problem", " ", "involving", " ", "an", " ", 
                StyleBox["Nth",
                  FontSlant->"Italic"]}], 
              StyleBox["-",
                
                FontSlant->
                  "Italic"], \(\(order\)\(\ \)\(ODE\)\(\ \)\(of\)\(\ \
\)\(the\)\(\ \)\(form\)\(\ \)\)}]},
          {
            RowBox[{"     ", Cell[TextData[Cell[BoxData[
                  FormBox[
                    StyleBox[
                      RowBox[{
                        
                        FractionBox[\(\[DifferentialD]\^N 
                            x\), \(\[DifferentialD]t\^N\),
                          MultilineFunction->None], "=", 
                        RowBox[{"f", "(", 
                          RowBox[{"t", ",", "x", ",", 
                            
                            FractionBox[\(\[DifferentialD]x\), \(\
\[DifferentialD]t\),
                              MultilineFunction->None], ",", 
                            
                            FractionBox[\(\[DifferentialD]\^2 
                                x\), \(\[DifferentialD]t\^2\),
                              MultilineFunction->None], ",", "...", ",", 
                            
                            FractionBox[\(\[DifferentialD]\^\(N - 1\)x\), \(\
\[DifferentialD]t\^\(N - 1\)\),
                              MultilineFunction->None]}], ")"}], "   "}],
                      FontFamily->"Times"], TraditionalForm]],
                TextAlignment->Center]]]}]},
          {
            RowBox[{
              RowBox[{"for", " ", "some", " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"function", 
                      StyleBox["f",
                        FontSlant->"Italic"]}]], ".", " ", "The"}], " ", 
                "ODE", " ", "is", " ", "supplemented", " ", "by", " ", 
                StyleBox["N",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], "initial", " ", "conditions", " ", 
                "on", " ", 
                StyleBox["x",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], "and", " ", "its"}], "  ", 
              "\[IndentingNewLine]", 
              RowBox[{"derivatives", " ", "of", " ", "order", 
                FormBox[
                  StyleBox[\(N - 1\),
                    FontFamily->"Times"],
                  "TraditionalForm"], "and", " ", \(\(lower\)\(:\)\)}]}]},
          {
            RowBox[{"     ", 
              RowBox[{Cell[TextData[{
                  Cell[BoxData[
                      FormBox[
                        StyleBox[\(x(0) = x\_o\),
                          FontFamily->"Times"], TraditionalForm]]],
                  StyleBox[",   ",
                    FontFamily->"Times"],
                  Cell[BoxData[
                      FormBox[
                        RowBox[{
                          StyleBox[
                            
                            FractionBox[\(\[DifferentialD]x\), \(\
\[DifferentialD]t\),
                              MultilineFunction->None],
                            FontFamily->"Times",
                            FontSize->14], 
                          StyleBox["=",
                            FontFamily->"Times"], 
                          StyleBox[\(v\_o\),
                            FontFamily->"Times"]}], TraditionalForm]]],
                  StyleBox[", ",
                    FontFamily->"Times"],
                  Cell[BoxData[
                      FormBox[
                        RowBox[{"   ", 
                          RowBox[{
                            StyleBox[
                              FractionBox[\(\[DifferentialD]\^2 
                                  x\), \(\[DifferentialD]t\^2\),
                                MultilineFunction->None],
                              FontFamily->"Times",
                              FontSize->14], 
                            StyleBox["=",
                              FontFamily->"Times"], 
                            StyleBox[\(a\_o\),
                              FontFamily->"Times"]}]}], TraditionalForm]]],
                  StyleBox[",...,   ",
                    FontFamily->"Times"],
                  Cell[BoxData[
                      FormBox[
                        StyleBox[
                          RowBox[{
                            
                            FractionBox[\(\[DifferentialD]\^\(N - 1\)x\), \(\
\[DifferentialD]t\^\(N - 1\)\),
                              MultilineFunction->None], "=", \(u\_o\)}],
                          FontFamily->"Times"], TraditionalForm]]]
                }]], "."}]}]},
          {
            RowBox[{
              RowBox[{"Then", ",", 
                RowBox[{"if", " ", "the", " ", "derivative", " ", "of", " ", 
                  StyleBox["f",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], "in", " ", "each", " ", "of", " ", 
                  "its", " ", "arguments", " ", "is", " ", "continuous", " ", 
                  "over", " ", "some", " ", "domain"}]}], 
              "\[IndentingNewLine]", \(encompassing\ this\ initial\ \
condition, the\ solution\ to\ this\ problem\ exists\ and\ is\ unique\), 
              "\[IndentingNewLine]", \(for\ some\ length\ of\ time\ around\ \
the\ initial\ \(\(time\)\(.\)\)\)}]}
          },
        ColumnAlignments->{Left}],
      FontFamily->"Times"]]]], "NE2",
  TextAlignment->Left,
  CellTags->{"(1.2.1)", "i:16"}],

Cell[TextData[{
  "\tNow, we are not going to give the proof to this theorem. (See, for \
instance, ",
  ButtonBox["Boyce and Diprima",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " for an accessible discussion of the proof.) But trying to understand it \
qualitatively is useful. To do so, let\[CloseCurlyQuote]s consider a simple \
example of ",
  ButtonBox["Eq. (1.2.1)",
    ButtonData:>"(1.2.1)",
    ButtonStyle->"Hyperlink"],
  ": the  first-order ODE"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]v\), \(\[DifferentialD]t\),
            MultilineFunction->None], "=", \(f(t, v)\)}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(1.2.2)"],

Cell["\<\
This equation can be thought of as Newton\[CloseCurlyQuote]s second \
law for motion in one dimension due to a force that depends on both velocity \
and time. \
\>", "Text"],

Cell[TextData[{
  "\tLet\[CloseCurlyQuote]s consider a graphical depiction of ",
  ButtonBox["Eq. (1.2.2)",
    ButtonData:>"(1.2.2)",
    ButtonStyle->"Hyperlink"],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((t, v)\)\)]],
  " plane. At every point ",
  Cell[BoxData[
      \(TraditionalForm\`\((t, v)\)\)]],
  ", the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t, v)\)]],
  " specifies the slope ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]v/\[DifferentialD]t\)]],
  " of the solution ",
  Cell[BoxData[
      \(TraditionalForm\`v(t)\)]],
  ". An example of one such solution is given in ",
  ButtonBox["Fig. 1.1",
    ButtonData:>"Fig. 1.1",
    ButtonStyle->"Hyperlink"],
  ". At each point along the curve, the slope ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]v/\[DifferentialD]t\)]],
  " is determined through ",
  ButtonBox["Eq. (1.2.2)",
    ButtonData:>"(1.2.2)",
    ButtonStyle->"Hyperlink"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`f(t, v)\)]],
  ".  This slope is, geometrically speaking, an infinitesimal vector that is \
tangent to the curve at each of its points. A schematic representation of \
three of these infinitesimal vectors is shown in the figure. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000820001NB000`400?l00000o`00003ooooooooo
ooooo`Cooooo003ooooooooooooo1?ooool00?ooooooooooool4ooooo`00ooooooooooooo`Cooooo
003ooooooooooooo1?ooool00?ooooooooooool4ooooo`00ooooooooooooo`Cooooo003ooooooooo
oooo1?ooool00?ooooooooooool4ooooo`00ooooooooooooo`Cooooo000<ooooool0ooooV@3oool5
000004`0oooo3Oooool000coooooo`3ooonH0?ooo`030820P0000000000000H00000B@3oool=oooo
o`003?oooooo0?oooiP0oooo00<0P820000000000000200000000`20P800oooo0?ooo`140?ooo`go
oooo000<ooooool0ooooV03oool00`20P80000000000000;000004@0oooo3Oooool000coooooo`3o
oonH0?oooa000000@P3oool=ooooo`003?oooooo0?oooiP0oooo4`0000030820P3`0oooo3Oooool0
00coooooo`3ooonH0?oooaL00000>`3oool=ooooo`003?oooooo0?oooiP0oooo6P00000h0?ooo`go
oooo000<ooooool0ooooU`3ooolM000003H0oooo3Oooool000coooooo`3ooonG0?ooob000000<`3o
ool=ooooo`003?oooooo0?oooiL0oooo8P00000a0?ooo`gooooo000<ooooool0ooooU`3ooolU0000
02h0oooo3Oooool000coooooo`3ooonG0?ooobP00000:`3oool=ooooo`003?ooool?0?ooool00000
/P00000Y0?ooo`gooooo000<ooooo`l0ooooo`00002d000002L0oooo3Oooool000cooooo3@3ooooo
00000;D00000:03oool=ooooo`003?ooool=0?ooo`<0000000<0@4100820P020P800o`20P8240820
P2D000000`20P80[0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?oooh@0
oooo8P0000000`20P800oooo0?ooo`0^0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo
0?ooo`3o0?oooh@0oooo8000000c0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?oo
o`3o0?oooh@0oooo7@00000f0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o
0?oooh@0oooo6P00000i0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?oo
ohD0oooo5`00000k0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooohD0
oooo5@00000m0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooohD0oooo
4P0000100?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooohD0oooo3`00
00130?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooohD0oooo00<0P820
0000000000002@0000160?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?oo
ohD0oooo00<0P8200000000000001`0000180?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800
oooo0?ooo`3o0?ooohH0oooo0`0000030820P4/0oooo3Oooool000cooooo3@3oool3000000030820
P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3o
oooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool0
00cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0
000000<0P8200?ooo`3oool0o`3ooonK0?ooo`040820P00000000000000003P0oooo3Oooool000co
oooo3@3oool3000000030820P03oool0oooo0?l0ooooV`3oool00`20P800000000000003000003H0
oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooV`3oool01020P8000000
0000000000020?ooo`030000003oool0oooo03<0oooo3Oooool000cooooo3@3oool3000000030820
P03oool0oooo0?l0ooooV`3oool01020P80000000000000000030?ooo`030000003oool0oooo0380
oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooV`3oool01020P8000000
0000000000030?ooo`800000<`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooonK0?ooo`030820P0000000000000800000=`3oool=ooooo`003?ooool=0?ooo`<0000000<0
P8200?ooo`3oool0o`3ooonL0?ooo`@00000=`3oool=ooooo`003?ooool=0?ooo`<0000000<0P820
0?ooo`3oool0o`3ooonL0?ooo`D00000=P3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?oo
o`3oool0o`3ooonM0?ooo`@00000=P3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3o
ool0o`3ooonM0?ooo`@00000=P3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooonM0?ooo`D00000=@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3o
oonM0?ooo`D00000=@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonN
0?ooo`@00000=@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonN0?oo
o`@00000=@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonN0?ooo`D0
0000=03oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonO0?ooo`@00000
=03oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonO0?ooo`@0000000<0
P8200?ooo`3oool0<@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonP
0?ooo`@00000<`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonP0?oo
o`@00000<`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonL0?ooo`/0
0000<03oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonO0?ooo`H00000
<P3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonQ0?ooo`@00000<P3o
ool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonR0?ooo`<00000<P3oool=
ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonS0?ooo`<00000<@3oool=oooo
o`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonT0?ooo`800000<@3oool=ooooo`00
3?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo02l0oooo
3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooY@3oool00`000000P8200?oo
o`0_0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool0
00cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0
000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo
0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3o
ool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<oooo
o`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool300000003
0820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Ooo
ool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?oo
o`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800
oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0oooo
e`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<
ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool30000
00030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3o
ool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo
3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=
0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20
P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0
ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo
000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3
000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?oo
o`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0
oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?oo
ool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`000000
0`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo
0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`go
oooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3o
ool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P820
0?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?oo
omL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`00
3?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`00
00000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0
oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?oo
o`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo
3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0
P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o
0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=oooo
o`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo
0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03o
ool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG
0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000co
oooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<00000
00<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?oo
o`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=
ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0
oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820
P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3o
oooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool0
00cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0
000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo
0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3o
ool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<oooo
o`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool300000003
0820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Ooo
ool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooe`3oool=ooooo`003?ooool=0?oo
o`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800
oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0oooo
e`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooG0?ooo`gooooo000<
ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooomL0oooo3Oooool000cooooo3@3oool30000
00030820P03oool0oooo08d0oooo200000070820P?l0oooo>`3oool=ooooo`003?ooool=0?ooo`<0
000000<0P8200?ooo`3oool0S@3ooolF00000?l0oooo=03oool=ooooo`003?ooool=0?ooo`<00000
00<0P8200?ooo`3oool0S@3ooolM00000<@0oooo100000040?ooo`800000GP3oool=ooooo`003?oo
ool=0?ooo`<0000000<0P8200?ooo`3oool0S03ooolU00000;/0oooo200000020?ooo`<0000000<0
P8200?ooo`3oool00`3oool4000005<0oooo3Oooool000cooooo3@3oool3000000030820P03oool0
oooo08`0oooo;000002c0?ooo`X0000000<0oooo0000000000000`0000040?ooo`D0000000<0P820
0?ooo`3oool0C`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0S03ooold0000
0:X0oooo1P0000040?ooo`P000000`3oool4000000030?ooo`20P800oooo0500oooo3Oooool000co
oooo3@3oool3000000030820P03oool0oooo08`0oooo>`00002S0?ooo`@0000000<0P8200?ooo`3o
ool0103oool4000000030820P03oool0oooo00<0oooo100000020?ooo`030000003oool0oooo04h0
oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo09<0oooo>`00002K0?ooo`D00000
203oool3000000030820P03oool0oooo00<0oooo100000020?ooo`800000C`3oool=ooooo`003?oo
ool=0?ooo`<0000000<0P8200?ooo`3oool0VP3oooll000009<0oooo1@0000080?ooo`<0000000<0
P8200?ooo`3oool00`3oool500000580oooo3Oooool000cooooo3@3oool3000000030820P03oool0
oooo05@0oooo0P00001:0?ooo`030820P0000000000003T00000S03oool5000000T0oooo0`000000
0`20P800oooo0?ooo`040?ooo`@00000DP3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?oo
o`3oool0D`3oool3000002`0ooooH@0000250?ooo`D000002@3oool3000000030820P03oool0oooo
00@0oooo1000001B0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`1@0?ooo`03
0820P0000000000000@000007@3oool00`30`<00P8200820P0020820P78000001`20P81f0?ooo`@0
00002P3oool3000000030820P03oool0oooo00@0oooo00D0P82000000000000000000820P01A0?oo
o`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`1>0?ooo`X000005`3ooon3000007H0
oooo1000000:0?ooo`<0000000<0P8200?ooo`3oool01@3oool3000000030820P03oool0oooo04l0
oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo04d0oooo2`00000A0?ooo`030820
P0000000000008H00000MP3oool4000000X0oooo0`0000000`20P800oooo0?ooo`050?ooo`@00000
D@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0B`3oool>000000`0oooo5@00
000g0?oood400000MP3oool4000000X0oooo0`0000000`20P800oooo0?ooo`050?ooo`@00000D@3o
ool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0B@3oool00`20P80000000000000;
000000/0oooo4P0000000`20P800oooo0?ooo`110?ooocX00000MP3oool4000000X0oooo0`000000
0`20P800oooo0?ooo`060?ooo`<00000D@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?oo
o`3oool0B@3oool=000000T0oooo4000001@0?oooc<00000M`3oool3000000X0oooo0`0000000`20
P800oooo0?ooo`060?ooo`<00000D@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3o
ool0A`3oool=000000030820P03oool0oooo00@0oooo3P0000000`20P800oooo0?ooo`1J0?ooob/0
0000N03oool3000000X0oooo0`0000000`20P800oooo0?ooo`060?ooo`@00000D03oool=ooooo`00
3?ooool=0?ooo`<0000000<0P8200?ooo`3oool0AP3oool>000000D0oooo3@00001U0?ooo`030820
P0000000000001<000000P3oool>000007P0oooo100000090?ooo`<0000000<0P8200?ooo`3oool0
1`3oool300000500oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo04@0oooo3P00
00050?ooo``00000KP3ooolC000000L0oooo1P00001i0?ooo`<00000203oool4000000030820P03o
ool0oooo00L0oooo0`00001@0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`12
0?ooo`l00000103oool:000000030820P03oool0oooo07@0oooo00<0P8200000000000003`000022
0?ooo`@000001`3oool4000000030820P03oool0oooo00L0oooo1000001?0?ooo`gooooo000<oooo
o`d0oooo0`0000000`20P800oooo0?ooo`110?ooo`h00000103oool900000800oooo4000001o0?oo
o`<0000000<0P8200?ooo`3oool00`3oool5000000030820P03oool0oooo00P0oooo0`00001?0?oo
o`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`0n0?ooo`030<30`0000000000000/0
00000P20P8000`3oool0P8200820P00700000080P820QP3oool30820P0`000001020P81i0?ooo`03
0820P0000000000000@0P8200P0000001@20P8000000000000000000P82000H0oooo1020P8030000
00@0P820B`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0?@3oool=000000<0
oooo2@00002A0?oooa000000M`3oool00`20P800000000000002000000<0oooo0`0000000`20P800
oooo0?ooo`070?ooo`D00000CP3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0
?03oool=000000030820P03oool0000000P0000000<0P8200?ooo`3oool0U03oool>000007d0oooo
0`0000000`20P800oooo0?ooo`080?ooo`040820P00000000000000004h0oooo3Oooool000cooooo
3@3oool3000000030820P03oool0oooo03X0oooo3P0000000`3oool0P82000000008000009/0oooo
3`00001i0?ooo`<0000000<0P8200?ooo`3oool02@3oool3000004h0oooo3Oooool000cooooo3@3o
ool3000000030820P03oool0oooo03P0oooo3`0000000`3oool000000000000700000:40oooo3P00
001f0?ooo`<0000000<0P8200?ooo`3oool02P3oool3000004d0oooo3Oooool000cooooo3@3oool3
000000030820P03oool0oooo03L0oooo3P0000000`3oool000000000000600000:P0oooo3@00001c
0?ooo`<0000000<0P8200?ooo`3oool02`3oool2000004d0oooo3Oooool000cooooo3@3oool30000
00030820P03oool0oooo03D0oooo5`00002/0?ooo`h00000L03oool3000000030820P03oool0oooo
00`0oooo00<000000?ooo`3oool0B`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3o
ool0=03ooolF00000;80oooo3P00001/0?ooo`<0000000<0P8200?ooo`3oool0303oool2000004`0
oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo03<0oooo5@00002g0?ooo`h00000
J@3oool3000000030820P03oool0oooo05X0oooo3Oooool000cooooo3@3oool3000000030820P03o
ool0oooo0380oooo5000002l0?ooo`030820P0000000000000/00000IP3oool3000000030820P03o
ool0oooo05X0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0300oooo5@000030
0?ooo`l00000G`3oool6000000030820P03oool0oooo05X0oooo3Oooool000cooooo3@3oool30000
00030820P03oool0oooo02d0oooo00<0P8200000000000004@0000020820P<H0oooo0`20P80;0000
00<0P820FP3oool20820P0<0000000<0P8200?ooo`3oool0FP3oool=ooooo`003?ooool=0?ooo`<0
000000<0P8200?ooo`3oool0:`3ooolE00000<l0oooo3P00001K0?ooo`0300000020P800oooo05/0
oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo02X0oooo500000000`20P800oooo
0?ooo`3A0?ooo`l00000]@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0:03o
ool00`20P80000000000000B00000=T0oooo3@00002c0?ooo`gooooo000<ooooo`d0oooo0`000000
0`20P800oooo0?ooo`0W0?oooa@00000g@3oool>00000;00oooo3Oooool000cooooo3@3oool30000
00030820P03oool0oooo02H0oooo5000003R0?ooo``00000[P3oool=ooooo`003?ooool=0?ooo`<0
000000<0P8200?ooo`3oool0903ooolD00000>L0oooo3000002[0?ooo`gooooo000<ooooo`d0oooo
0`0000000`20P800oooo0?ooo`0S0?oooa@00000j`3oool;000000030820P03oool0oooo01@0oooo
E`00000k0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`0Q0?oooa@00000k`3o
ool<000001<0oooo00<0P820000000000000E@00000k0?ooo`gooooo000<ooooo`d0oooo0`000000
0`20P800oooo0?ooo`0P0?oooa<0000000<0P8200?ooo`3oool0l03oool<00000140ooooF000000k
0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`0N0?oooaD00000mP3oool<0000
00h0ooooF000000k0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`0L0?ooo`03
0820P000000000000140000000<0P8200?ooo`3oool0n@3oool20820P0X0000000<0P8200?ooo`3o
ool01`3oool<000000030820P03oool0oooo04T0oooo0`00000i0?ooo`gooooo000<ooooo`d0oooo
0`0000000`20P800oooo0?ooo`0J0?oooa@00000o`3oool30?ooo`/000001P3oool@000004T0oooo
0`00000i0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`0I0?oooa@00000o`3o
ool70?ooo`/000001@3oool@000004L0oooo0`00000i0?ooo`gooooo000<ooooo`d0oooo0`000000
0`20P800oooo0?ooo`0G0?oooaD00000o`3oool;0?ooo`X00000103ooolA000004D0oooo0`00000i
0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`0F0?oooaD00000o`3oool>0?oo
o`030820P0000000000000L00000103ooolA000004<0oooo0`00000i0?ooo`gooooo000<ooooo`d0
oooo0`0000000`20P800oooo0?ooo`0D0?oooaD00000o`3ooolB0?ooo`T0000000<0P8200?ooo`3o
ool00P3ooolA00000440oooo0`00000i0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo
0?ooo`0C0?oooaD0000000<0P8200?ooo`3oool0o`3ooolC0?ooo`P000001@3oool@00000400oooo
0`00000B0?ooo`@00000103oool2000001d0oooo3Oooool000cooooo3@3oool3000000030820P03o
ool0oooo0180oooo5P00003o0?oooaP0oooo200000050?ooo`l00000?`3oool300000100oooo2000
00020?ooo`<0000000<0P8200?ooo`3oool0203oool00`20P800oooo0?ooo`0>0?ooo`gooooo000<
ooooo`d0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`h0000000<0oooo0000000000001@00003o
0?oooad0oooo200000040?ooo`l00000?@3oool3000000l0oooo2P0000000`3oool0000000000003
000000T0oooo00<000000?ooo`3oool03P3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?oo
o`3oool03`3oool>000000030820P0000000000000D00000o`3ooolO0?ooo`030820P00000000000
00H000000`3oool@000003/0oooo0`00000>0?ooo`H00000103oool8000000P0oooo0P00000?0?oo
o`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`0=0?ooo`l0000000<0oooo00000000
00001@00003o0?ooob<0oooo200000030?oooa000000>@3oool3000000h0oooo100000000`20P800
oooo0?ooo`040?ooo`@0000000<0P8200?ooo`3oool0203oool3000000h0oooo3Oooool000cooooo
3@3oool3000000030820P03oool0oooo00X0oooo00<0P820000000000000300000000`20P800oooo
0820P005000000030820P03oool0oooo0?l0oooo9@3oool30820P0@000000P20P8020?ooo`80P820
3P0000000`20P800oooo0?ooo`0d0?ooo`<000003@3oool5000000P0oooo0`0000000`20P800oooo
0?ooo`080?ooo`<000000P20P80<0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?oo
o`080?ooo`030820P0000000000000`000000`3oool600000?l0oooo;P3oool7000000<0oooo3`00
000d0?ooo`<00000303oool5000000T0oooo0`0000000`20P800oooo0?ooo`080?ooo`<000000P3o
ool00`000000oooo0?ooo`090?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`08
0?ooo`h000000`3oool500000?l0oooo<@3oool00`20P80000000000000500000080oooo4000000b
0?ooo`<00000303oool5000000T0oooo0`0000000`20P800oooo0?ooo`080?ooo`<000000`3oool0
0`000000oooo0?ooo`080?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`060?oo
o`h000000`3oool6000000030820P03oool0oooo0?l0oooo<@3oool8000000030?ooo`20P8000000
00l00000<03oool3000000`0oooo1000000:0?ooo`<0000000<0P8200?ooo`3oool0203oool30000
00<0oooo0P0000090?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`050?ooo`h0
000000<0P8200?ooo`3oool01`00003o0?ooocL0oooo1P0000000`20P800oooo0000000@000002h0
oooo0`00000<0?ooo`@000002P3oool3000000030820P03oool0oooo00L0oooo100000040?ooo`80
0000203oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool00`3oool?000000<0oooo
1P00003o0?oooc/0oooo1P0000020?oooa400000;03oool3000000`0oooo1000000:0?ooo`<00000
00<0P8200?ooo`3oool01`3oool4000000D0oooo00<000000?ooo`3oool01P3oool=ooooo`003?oo
ool=0?ooo`<0000000<0P8200?ooo`3oool0103oool<000000@0oooo1P00003o0?oooch0oooo1P00
00020?oooa000000:`3oool3000000`0oooo1000000:0?ooo`<0000000<0P8200?ooo`3oool01`3o
ool4000000H0oooo00<000000?ooo`3oool01@3oool=ooooo`003?ooool=0?ooo`<0000000<0P820
0?ooo`3oool0103oool;000000@0oooo00<0P8200000000000000P00003o0?oood80oooo1`000000
0`3oool000000000000>000002T0oooo0`00000<0?ooo`@000002P3oool3000000030820P03oool0
oooo00L0oooo0`0000070?ooo`8000001P3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?oo
o`3oool01@3oool8000000D0oooo1@00003o0?oood@0oooo200000000`3oool000000000000>0000
02L0oooo0`00000<0?ooo`@000002P3oool3000000030820P03oool0oooo00L0oooo0`0000080?oo
o`0300000020P800oooo00@0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo00H0
oooo1P0000050?ooo`D00000o`3ooom70?ooo`L0000000<0P8200000000000003`00000U0?ooo`<0
00003@3oool3000000X0oooo0`0000000`20P800oooo0?ooo`070?ooo`<000002@3oool00`20P800
oooo0?ooo`030?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`070?ooo`<00000
1P3oool500000?l0ooooB`3oool6000000030?ooo`000000000000l000008`3oool3000000d0oooo
0`00000:0?ooo`<0000000<0P8200?ooo`3oool01`3oool3000000T0oooo00<000000?ooo`3oool0
0`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool01`3oool20820P0@0oooo0P20
P804000000030820P03oool0oooo0?l0ooooC03oool20820P0@0000000<0P82000000020P8003`00
00000`20P800oooo0?ooo`0N0?ooo`<000003@3oool01020P80000000000000000080?ooo`050820
P0000000000000000020P800203oool01020P80000000000000000090?ooo`0300000020P800oooo
00<0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo00`0oooo1P00003o0?oooe80
oooo00<0P8200000000000001@0000000`3oool000000000000>000001h0oooo0`00000>0?ooo`@0
00001`3oool4000000030820P03oool0oooo00H0oooo100000090?ooo`800000103oool=ooooo`00
3?ooool=0?ooo`<0000000<0P8200?ooo`3oool02`3oool600000?l0ooooD`3oool:000000030?oo
o`000000000000h00000703oool3000000l0oooo0`0000000`20P800oooo0?ooo`030?ooo`D00000
00<0P8200?ooo`3oool01P3oool3000000T0oooo0`0000040?ooo`gooooo000<ooooo`d0oooo0`00
00000`20P800oooo0?ooo`0:0?ooo`H00000o`3ooomC0?ooo`@000000P3oool6000000030820P000
0000000000l000006P3oool300000100oooo0`0000040?ooo`H0000000<0P8200?ooo`3oool01@3o
ool4000000P0oooo100000040?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`09
0?ooo`H00000o`3ooomC0?ooo`D00000103oool6000000030?ooo`000000000000l00000603oool3
00000140oooo200000001@3oool00000000000000000P82000@0oooo1`0000080?ooo`@00000103o
ool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0203oool600000?l0ooooD`3oool6
000000H0oooo1P0000000`3oool000000000000?000001H0oooo0`00000B0?ooo`030820P0000000
0000008000000`3oool3000000030820P03oool0oooo00H0oooo0P0000000`20P800oooo0?ooo`07
0?ooo`8000001@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool01`3oool60000
0?l0ooooD`3oool7000000P0oooo1P0000000`3oool000000000000>000001D0oooo0`00000J0?oo
o`<0000000<0P8200?ooo`3oool06@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3o
ool01P3oool500000?l0ooooE03oool8000000P0oooo00<0P8200000000000001@0000000`3oool0
00000000000=000001@0oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool06@3oool=ooooo`00
3?ooool=0?ooo`<0000000<0P8200?ooo`3oool01@3oool500000?l0ooooE03oool9000000X0oooo
200000000`3oool000000000000=00000180oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool0
6@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0103oool500000?l0ooooE03o
ool:000000`0oooo1`0000000`20P80000000000000>00000100oooo0`00000J0?ooo`<0000000<0
P8200?ooo`3oool06@3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool00`3oool5
000000030820P03oool0oooo0?l0ooooD03oool;000000l0oooo1`0000000`3oool000000000000>
000000h0oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool06@3oool=ooooo`003?ooool=0?oo
o`<0000000D0P8200?ooo`3oool0oooo0820P005000000030820P03oool0oooo0?l0ooooD03oool0
0`10@40000000000000900000140oooo0P20P804000000@0P8203P0000000`20P800`<300?ooo`09
0?ooo`<000006P3oool3000000030820P03oool0oooo01T0oooo3Oooool000cooooo3@3oool30000
00030820P03oool0oooo00H00000o`3ooomC0?ooo`d00000503oool00`20P8000000000000040000
0080oooo3`0000090?ooo`<000006P3oool3000000030820P03oool0oooo01T0oooo3Oooool000co
oooo3@3oool3000000030820P03oool0000000D00000o`3ooomC0?ooo`h000005@3oool700000080
oooo400000070?ooo`<000005`3oool6000000030820P03oool0oooo01T0oooo3Oooool000cooooo
3@3oool3000000030820P0000000000000@00000o`3ooomC0?ooo`l000005`3oool7000000030?oo
o`20P800000000l000001@3oool3000001P0oooo1@0000000`20P800oooo0?ooo`0I0?ooo`gooooo
000<ooooo`d0oooo2@00003o0?oooe<0oooo4000000I0?ooo`H0000000<0P8200?ooo`0000004000
00030?ooo`<000006P3oool3000000030820P03oool0oooo01T0oooo3Oooool000cooooo3@3oool8
00000?l0ooooD`3ooolA000001X0oooo1`0000020?oooa40000000@0oooo0000000000000000703o
ool00`000000P8200?ooo`0J0?ooo`gooooo000<ooooo`d0oooo1`00003o0?oooe<0oooo4@00000M
0?ooo`H000000`3ooolC000003T0oooo3Oooool000cooooo3@3oool600000?l0ooooD`3ooolB0000
01l0oooo1P0000030?oooa400000>@3oool=ooooo`003?ooool=0?ooo`D00000o`3ooomC0?oooa<0
0000803oool00`20P800000000000004000000<0oooo3`00000i0?ooo`gooooo000<ooooo``0oooo
1@00003o0?oooe<0oooo5000000Q0?ooo`L000000`3oool00`20P80000000000000;000003T0oooo
3Oooool000cooooo2`3oool5000000030820P03oool0oooo0?l0ooooD03ooolE000002<0oooo1`00
00030?ooo``00000>@3oool=ooooo`003?ooool<0?ooo`050820P0000000000000000020P800o`3o
oomA0?ooo`030410@0000000000001<000009@3oool00`20P800000000000003000000040410@03o
ool0oooo0?ooo`80P8201@0000030820P3T0oooo3Oooool000cooooo3@3oool3000000030820P03o
ool0oooo0?l0ooooCP3ooolG000002P0oooo1P0000050?ooo`<00000?03oool=ooooo`003?ooool=
0?ooo`<0000000<0P8200?ooo`3oool0o`3ooom<0?oooaP0000000<0P8200?ooo`3oool0:03oool6
00000480oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooB`3ooolI0000
00030820P03oool0oooo02T0oooo1P0000110?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800
oooo0?ooo`3o0?ooodX0oooo6P0000000`20P800oooo0?ooo`0Z0?ooo`L00000?`3oool=ooooo`00
3?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooom:0?oooaX0000000<0P8200?ooo`3oool0
:`3oool8000003d0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?l0ooooB@3o
oolK000000030820P03oool0oooo02d0oooo1`0000000`20P800oooo0?ooo`0i0?ooo`gooooo000<
ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooodP0oooo700000000`20P800oooo0?ooo`0^
0?ooo`L00000>`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3ooom90?oo
oa/0000000<0P8200?ooo`3oool0<03oool7000003T0oooo3Oooool000cooooo3@3oool300000003
0820P03oool0oooo0?l0ooooBP3ooolJ000000030820P03oool0oooo0340oooo2000000g0?ooo`go
oooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o0?ooo`<0oooo00<0`<300820P020P800
1P20P80n0?ooo`030820P0000000000001L00000=P3oool00`20P80000000000000400000080P820
=03oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0o`3oool20?ooo`/00000?`3o
oolH000003P0oooo1P00000e0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3o
0?ooo`h00000?P3ooolH000003T0oooo1@00000e0?ooo`gooooo000<ooooo`d0oooo0`0000000`20
P800oooo0?ooo`3m0?oooa400000?03ooolI000003/0oooo0P00000f0?ooo`gooooo000<ooooo`d0
oooo0`0000000`20P800oooo0?ooo`3k0?ooo`P000001`3oool5000003/0oooo100000000`20P800
00000000000B000007<0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?X0oooo
200000000`20P800oooo0?ooo`060?ooo`@00000>P3oool5000000030820P03oool0oooo01800000
L`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0n03oool9000000/0oooo0`00
000i0?ooo`H00000103ooolA000007<0oooo3Oooool000cooooo3@3oool3000000030820P03oool0
oooo0?L0oooo1`00000>0?ooo`<00000>@3oool5000000L0oooo3`00001c0?ooo`gooooo000<oooo
o`d0oooo0`0000000`20P800oooo0?ooo`3f0?ooo`H00000403oool4000003L0oooo1@00000;0?oo
o`/00000M03oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0m03oool700000140
oooo00@0P8200000000000000000=P3oool6000000d0oooo2@00001d0?ooo`gooooo000<ooooo`d0
oooo0`0000000`20P800oooo0?ooo`3c0?ooo`L000004P3oool01020P800000000000000000f0?oo
o`D000004@3oool6000007@0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0?00
oooo0P20P805000000030410@03oool0oooo0180oooo00@0P8200000000000000000=03oool00`20
P800000000000002000000030820P03oool0oooo01D0oooo00<0P8200?ooo`3oool0LP3oool=oooo
o`003?ooool=0?ooo`<0000000<0P8200?ooo`3oool0l03oool7000001D0oooo00@0P82000000000
00000000<`3oool00`20P800000000000003000008d0oooo3Oooool000cooooo3@3oool300000003
0820P03oool0oooo0>l0oooo1P00000G0?ooo`040820P00000000000000003<0oooo1@00002>0?oo
o`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?ooo`3^0?ooo`H00000603oool01020P800
000000000000000b0?ooo`D00000S`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3o
ool0k@3oool6000001T0oooo00@0P8200000000000000000<@3oool500000900oooo3Oooool000co
oooo3@3oool3000000030820P03oool0oooo0>`0oooo00<0P8200000000000000`00000J0?ooo`<0
0000<P3oool400000940oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0>`0oooo
1@00000K0?ooo`<00000<@3oool400000980oooo3Oooool000cooooo3@3oool3000000030820P03o
ool0oooo0>/0oooo1@00000L0?ooo`<00000<03oool4000000030820P03oool0oooo0900oooo3Ooo
ool000cooooo3@3oool3000000030820P03oool0oooo0>X0oooo1000000N0?ooo`<00000;`3oool5
000000030820P03oool0oooo0900oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo
0>T0oooo1000000O0?ooo`<00000;P3oool6000009<0oooo3Oooool000cooooo3@3oool300000003
0820P03oool0oooo0>P0oooo1@00000O0?ooo`<00000;@3oool6000009@0oooo3Oooool000cooooo
3@3oool3000000030820P03oool0oooo0>L0oooo00<0P8200000000000000P0000000`30`<00oooo
0?ooo`0M0?ooo`<00000:`3oool00`20P800000000000003000000030820P03oool0oooo09<0oooo
3Oooool000cooooo3@3oool3000000030820P03oool0oooo0>H0oooo1@00000Q0?ooo`<00000:P3o
ool6000009L0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0>D0oooo1P00000P
0?ooo`<00000:P3oool00`20P800000000000003000009P0oooo3Oooool000cooooo3@3oool30000
00030820P03oool0oooo0>@0oooo1P00000Q0?ooo`<00000:P3oool00`20P8000000000000020000
09T0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0>@0oooo1@00000R0?ooo`<0
0000:P3oool4000009X0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0><0oooo
1@00000S0?ooo`<00000:@3oool4000009/0oooo3Oooool000cooooo3@3oool3000000030820P03o
ool0oooo0>80oooo1@00000T0?ooo`<00000:03oool5000009/0oooo3Oooool000cooooo3@3oool3
000000030820P03oool0oooo0>40oooo00<0P8200000000000000P00000U0?ooo`<000009`3oool5
000009`0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0>40oooo00<0P8200000
000000000P00000T0?ooo`@000009P3oool5000009d0oooo3Oooool000cooooo3@3oool300000003
0820P03oool0oooo0>40oooo1000000U0?ooo`@000009@3oool5000000030820P03oool0oooo09/0
oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0>00oooo1000000V0?ooo`@00000
903oool6000009h0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0=h0oooo00<0
P8200000000000000P00000W0?ooo`<0000000<0P8200?ooo`3oool0803oool00`20P80000000000
0003000000030820P03oool0oooo09d0oooo3Oooool000cooooo3@3oool3000000030820P03oool0
oooo0=d0oooo1@00000W0?ooo`@000008P3oool500000:80oooo3Oooool000cooooo3@3oool30000
00030820P03oool0oooo0=d0oooo100000000`20P800oooo0?ooo`0U0?ooo`@000008@3oool50000
0:<0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0=`0oooo1@00000X0?ooo`@0
0000803oool00`20P80000000000000200000:@0oooo3Oooool000cooooo3@3oool3000000030820
P03oool0oooo0=/0oooo1P00000X0?ooo`@000007`3oool500000:D0oooo3Oooool000cooooo3@3o
ool3000000030820P03oool0oooo0=X0oooo1P00000Y0?ooo`@000007P3oool500000:H0oooo3Ooo
ool000cooooo3@3oool3000000030820P03oool0oooo0=X0oooo1@00000Z0?ooo`@000007@3oool5
00000:L0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0=T0oooo1P00000Z0?oo
o`@00000703oool500000:P0oooo3Oooool000cooooo3@3oool3000000030820P03oool0oooo0=P0
oooo1P00000[0?ooo`@000006`3oool5000000030820P03oool0oooo0:H0oooo3Oooool000cooooo
3@3oool3000000030820P03oool0oooo0=L0oooo1P00000/0?ooo`@000006P3oool600000:T0oooo
3Oooool000cooooo3@3oool3000000030820P03oool0oooo0=L0oooo1P00000/0?ooo`<0000000<0
P8200?ooo`3oool05P3oool700000:X0oooo3Oooool000cooooo2@3oool40820P0<0000000<0@410
0820P020P800eP3oool00`20P800000000000002000000030820P03oool0oooo02/0oooo00@0P820
00000000000000005@3oool00`30`<00P82000000005000000030820P03oool0oooo0:T0oooo3Ooo
ool000cooooo1@3oool00`20P80000000000000@00000=40oooo1000000`0?ooo`<000005@3oool0
0`20P80000000000000300000:h0oooo3Oooool000cooooo0`3ooolH000000030820P03oool0oooo
0<X0oooo1@00000`0?ooo`@000004`3oool600000:l0oooo3Oooool000cooooo7P00003:0?ooo`@0
0000<P3oool400000140oooo1@00002a0?ooo`gooooo000<oooooah00000b@3oool4000003<0oooo
1000000>0?ooo`L00000/P3oool=ooooo`003?ooool00`3oool000000000000J00000<T0oooo1000
000d0?ooo`D000002`3oool7000000030820P03oool0oooo0;40oooo3Oooool000cooooo00<0oooo
0000000000006P0000380?ooo`@0000000<0P8200?ooo`3oool0<`3oool6000000L0oooo2@00002d
0?ooo`gooooo000<ooooo`030?ooo`000000000001X00000b03oool4000003H0oooo00<0P8200000
00000000100000030?ooo`X00000]P3oool=ooooo`003?ooool20?oooaX00000b03oool5000003L0
oooo4P00002g0?ooo`gooooo000<ooooo`80oooo6P0000370?ooo`D00000>03oool@00000;T0oooo
3Oooool000cooooo0P3ooolI000000030820P03oool0oooo0<@0oooo1@00000l0?ooo`/00000^`3o
ool=ooooo`003?ooool30?oooaP0000000<0P8200?ooo`3oool0`P3oool00`20P800000000000003
000000030820P03oool0oooo03/0oooo1P20P82o0?ooo`gooooo000<ooooo`<0oooo600000340?oo
o`L00000o`3oool40?ooo`gooooo000<ooooo`@0oooo5`0000330?ooo`030820P0000000000000<0
0000o`3oool60?ooo`gooooo000<ooooo`@0oooo5`0000340?ooo`@00000o`3oool70?ooo`gooooo
000<ooooo`D0oooo5@0000360?ooo`800000o`3oool80?ooo`gooooo000<ooooo`D0oooo5@00003o
0?ooom00oooo3Oooool000cooooo1@3ooolE00000?l0ooood03oool=ooooo`003?ooool50?ooo`03
0820P0000000000001400000o`3ooooA0?ooo`gooooo000<ooooo`D0oooo00<0P820000000000000
4@00003o0?ooom40oooo3Oooool000cooooo1@3oool00`20P80000000000000@00000?l0oooodP3o
ool=ooooo`003?ooool60?oooa800000o`3ooooB0?ooo`gooooo000<ooooo`H0oooo4@0000000`20
P800oooo0?ooo`3o0?ooom00oooo3Oooool000cooooo1`3oool@00000?l0ooood`3oool=ooooo`00
3?ooool70?oooa0000003`3oool00`20P800oooo0?ooo`3o0?oool40oooo3Oooool000cooooo1`3o
ool?00000100oooo00<000000?ooo`3oool0o`3oooo10?ooo`gooooo000<ooooo`P0oooo3P00000@
0?ooo`800000o`3oooo20?ooo`gooooo000<ooooo`P0oooo3@00000A0?ooo`<00000o`3oooo10?oo
o`gooooo000<ooooo`P0oooo3@00000A0?ooo`@00000o`3oooo00?ooo`gooooo000<ooooo`T0oooo
3000000A0?ooo`<0000000<0oooo0000003oool0o`3ooonn0?ooo`gooooo000<ooooo`T0oooo2`00
000B0?ooo`<000000P3oool00`000000oooo0?ooo`3o0?oook`0oooo3Oooool000cooooo2@3oool;
00000180oooo0`0000030?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`2m0?ooo`gooooo000<ooooo`X0oooo2@00000C0?ooo`<000000`3oool20000
0<T0oooo0P00000a0?ooo`030000003oool0oooo0;`0oooo3Oooool000cooooo2P3oool900000180
oooo100000040?ooo`030820P0000000oooo0:h0oooo00<0@4100?ooo`3oool0503oool00`20P800
00000820P00b0?ooo`040<30`0000000P8200820P;/0oooo3Oooool000cooooo2`3oool7000001<0
oooo100000060?ooo`030000003oool0oooo0:`0oooo00<0P8200000003oool04`3oool00`20P800
00000?ooo`0A0?ooo`030000003oool0oooo0240oooo0`00002j0?ooo`gooooo000<ooooo`/0oooo
1`00000C0?ooo`<000001`3oool00`000000P8200?ooo`2/0?ooo`030820P0000000000001<0oooo
00<000000?ooo`3oool04P3oool00`000000P8200?ooo`0Q0?ooo`<00000^@3oool=ooooo`003?oo
ool<0?ooo`D00000503oool3000000P0oooo00<000000?ooo`3oool0[03oool200000180oooo0P00
000E0?ooo`030000003oool0oooo0240oooo0P00002i0?ooo`gooooo000<ooooo``0oooo1@00000D
0?ooo`<00000203oool00`20P800oooo0?ooo`2/0?ooo`<00000403oool2000000030820P03oool0
oooo01<0oooo00<0P8200000003oool08@3oool300000;P0oooo3Oooool000cooooo303oool50000
01@0oooo0`0000080?ooo`030820P0000000oooo0:`0oooo0`00000?0?ooo`<000005P3oool00`20
P80000000?ooo`0R0?ooo`<00000]`3oool=ooooo`003?ooool=0?ooo`<0000000<0P8200?ooo`3o
ool04P3oool3000000P0oooo00<0P8200000003oool0[@3oool3000000h0oooo0`00000F0?ooo`03
0820P000000000000280oooo0`00002g0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo
0?ooo`0A0?ooo`@00000203oool00`20P80000000000000n0?ooo`@00000103oool2000001T0oooo
0P00000B0?ooo`030820P0000000000000800000103oool2000002d0oooo0`00000=0?ooo`@00000
5P3oool300000280oooo1000002f0?ooo`gooooo000<ooooo`d0oooo0`0000000`20P800oooo0?oo
o`0A0?ooo`@00000203oool00`20P80000000000000l0?ooo`P000000P3oool3000000030820P03o
ool0oooo00P0oooo00<0P8200?ooo`3oool02P3oool300000100oooo200000020?ooo`<000001P3o
ool400000280oooo1000000<0?ooo`<000002P3oool3000000T0oooo1000000<0?ooo`030000003o
ool0oooo01@0oooo0`00002f0?ooo`gooooo000<ooooo`h0oooo0P0000000`20P800oooo0?ooo`0A
0?ooo`<000002@3oool3000003/0oooo2P0000000`3oool0000000000003000000T0oooo00<00000
0?ooo`3oool02`3oool2000000l0oooo2P0000000`3oool0000000000003000000@0oooo1@00000Q
0?ooo`@000002`3oool4000000X0oooo1@0000070?ooo`@00000303oool2000001D0oooo1000002e
0?ooo`gooooo000<ooooo`h0oooo0P0000000`30`<00oooo0?ooo`0=0?ooo`<0P820100000080?oo
o`@00000>P3oool5000000030820P03oool0oooo0080oooo00<0P8200000000000000P0000000`10
@400P8200820P0080?ooo`80000000<0P8200?ooo`3oool02@3oool2000000030820P03oool0oooo
00/0oooo100000020820P0@0oooo00<0P8200000000000000P0000030820P0<0oooo100000000`3o
ool0P8200820P00P0?ooo`@000002@3oool00`20P800000000000002000000X0oooo0`0000020?oo
o`80P8201@3oool01020P800000000000020P80<0?ooo`<0000000<0P8200?ooo`3oool04@3oool4
000000030820P03oool0oooo0;80oooo3Oooool000cooooo3`3oool00`000000oooo0?ooo`0B0?oo
o`80000000<0P8200?ooo`3oool01`3oool2000003X0oooo1@0000080?ooo`<0000000<0P8200?oo
o`3oool0203oool4000000/0oooo0P00000<0?ooo`@0000000<0P8200?ooo`3oool01P3oool30000
00H0oooo100000020?ooo`8000007`3oool4000000T0oooo1@00000:0?ooo`<000000`3oool20000
01@0oooo1@00000B0?ooo`D00000]03oool=ooooo`003?oooom/0?ooo`D00000203oool300000003
0820P03oool0oooo00P0oooo0`0000000`3oool000000?ooo`090?ooo`800000303oool400000003
0820P03oool0oooo00H0oooo0`0000060?ooo`@0000000<0P8200?ooo`3oool08@3oool4000000P0
oooo1000000;0?ooo`@00000603oool4000000030?ooo`000000oooo0140oooo1000002d0?ooo`go
oooo000<ooooof/0oooo1@0000090?ooo`<0000000<0P8200?ooo`3oool0203oool300000080oooo
00<000000?ooo`3oool01`3oool3000000X0oooo1@0000090?ooo`<000001`3oool3000000030820
P03oool0oooo0240oooo100000080?ooo`@00000303oool3000001P0oooo100000020?ooo`030820
P03oool0oooo00l0oooo1000002d0?ooo`gooooo000<ooooof/0oooo1@0000090?ooo`<0000000<0
P8200?ooo`3oool0203oool3000000<0oooo00<000000?ooo`3oool01`3oool2000000X0oooo1@00
00090?ooo`<000001`3oool3000000030820P03oool0oooo0240oooo100000070?ooo`D00000303o
ool3000001P0oooo100000020?ooo`030820P03oool0oooo00l0oooo100000000`20P800oooo0?oo
o`2a0?ooo`gooooo000<ooooof/0oooo1000000:0?ooo`<0000000<0P8200?ooo`3oool0203oool3
000000<0oooo0P0000080?ooo`8000002P3oool4000000X0oooo0`0000070?ooo`@00000903oool4
000000H0oooo1@00000<0?ooo`@000005`3oool400000080oooo00<0P8200000003oool03`3oool4
000000030820P03oool0oooo0;40oooo3Oooool000coooooJ`3oool4000000X0oooo0`0000000`20
P800oooo0?ooo`070?ooo`@00000103oool2000000L0oooo0`0000090?ooo`@000002P3oool30000
00P0oooo0`00000T0?ooo`@000001P3oool5000000d0oooo0`00000F0?ooo`D000000`3oool20000
00l0oooo100000000`20P800oooo0?ooo`2a0?ooo`gooooo000<ooooof/0oooo1000000:0?ooo`<0
000000<0P8200?ooo`3oool01`3oool4000000D0oooo00<000000?ooo`3oool01P3oool2000000T0
oooo1000000:0?ooo`<00000203oool3000002@0oooo100000060?ooo`D000003@3oool3000001H0
oooo1@0000040?ooo`030000003oool0oooo00d0oooo100000000`20P800oooo0?ooo`2a0?ooo`go
oooo000<ooooof/0oooo1000000:0?ooo`<0000000<0P8200?ooo`3oool01`3oool4000000H0oooo
00<000000?ooo`3oool01@3oool2000000T0oooo1000000:0?ooo`<00000203oool4000002<0oooo
1@0000050?ooo`D000003@3oool4000001D0oooo1@0000050?ooo`030000003oool0oooo00`0oooo
100000000`20P800oooo0?ooo`2a0?ooo`gooooo000<ooooof/0oooo1000000:0?ooo`<0000000<0
P8200?ooo`3oool01`3oool3000000L0oooo0P0000060?ooo`<00000203oool4000000X0oooo0`00
00080?ooo`@000001P3ooolH000000H0oooo100000050?ooo`D000003@3oool4000001D0oooo1000
00060?ooo`8000003@3oool4000000030820P03oool0oooo0;40oooo3Oooool000coooooJ`3oool4
000000X0oooo0`0000000`20P800oooo0?ooo`070?ooo`<00000203oool00`000000P8200?ooo`05
0?ooo`800000203oool4000000X0oooo0`0000090?ooo`<000001P3ooolH000000H0oooo10000005
0?ooo`D000003@3oool01020P800000000000000000E0?ooo`@000001`3oool2000000`0oooo1000
00000`20P800oooo0?ooo`2a0?ooo`gooooo000<ooooof`0oooo0`00000:0?ooo`<0000000<0P820
0?ooo`3oool01`3oool3000000T0oooo00<0@4100?ooo`3oool0103oool2000000030820P03oool0
oooo00H0oooo0`00000:0?ooo`<000002@3oool3000000030820P03oool0oooo0240oooo00<0P820
0000000000000P0000040?ooo`D000003@3oool01@20P8000000000000000000P82001@0oooo1000
00080?ooo`0300000020P800oooo00X0oooo100000000`20P800oooo0?ooo`2a0?ooo`gooooo000<
ooooof`0oooo100000090?ooo`<0000000<0P8200?ooo`3oool01`3oool3000000T0oooo00<00000
0?ooo`3oool01@3oool2000000P0oooo100000090?ooo`<000002P3oool3000002@0oooo10000004
0?ooo`D000003P3oool4000001@0oooo100000080?ooo`8000002`3oool4000000030820P03oool0
oooo0;40oooo3Oooool000coooooK@3oool3000000P0oooo100000000`20P800oooo0?ooo`060?oo
o`@000002@3oool2000000H0oooo0P0000090?ooo`<00000203oool4000000X0oooo0`00000T0?oo
o`@000001@3oool4000000h0oooo1000000C0?ooo`D00000203oool3000000X0oooo1000002d0?oo
o`gooooo000<ooooofd0oooo100000070?ooo`@0000000<0P8200?ooo`3oool01P3oool4000000T0
oooo0P0000060?ooo`<00000203oool3000000030820P03oool0oooo00D0oooo1000000:0?ooo`@0
0000903oool3000000030820P03oool0oooo0080oooo1000000>0?ooo`D000004P3oool5000000P0
oooo0`00000:0?ooo`@00000]03oool=ooooo`003?oooom^0?ooo`@000001@3oool5000000030820
P03oool0oooo00H0oooo0`0000090?ooo`<000001`3oool2000000T0oooo0`0000060?ooo`D00000
2P3oool01020P800000000000000000T0?ooo`<0000000<0P8200?ooo`3oool00P3oool5000000h0
oooo1000000B0?ooo`@00000203oool4000000T0oooo1@00002d0?ooo`gooooo000<ooooofl0oooo
0`0000001020P800oooo0?ooo`3oool6000000030820P03oool0oooo00D0oooo100000080?ooo`@0
00001`3oool2000000X0oooo0`0000040?ooo`H000002P3oool01020P80000000000000000040?oo
oaP000000`3oool<000000030?ooo`000000000000<000003P3oool400000140oooo1@0000070?oo
o`D000002@3oool500000;@0oooo3Oooool000coooooL03oool8000000050?ooo`00000000000000
0020P800103oool7000000P0oooo100000070?ooo`80000000<0P8200?ooo`3oool0203oool80000
00040?ooo`0000000000000000L0oooo8`0000030?ooo``000000P3oool4000000/0oooo2`00000;
0?ooo`L000001`3oool5000000T0oooo1000002e0?ooo`gooooo000<ooooog80oooo100000030?oo
o`<0000000<0P8200?ooo`3oool01P3oool2000000030820P03oool0oooo00L0oooo0P0000090?oo
o`0300000020P800oooo00X0oooo1@0000030?ooo`<000002P3oool500000280oooo1@0000050?oo
o`@000003@3oool600000140oooo0`0000090?ooo`<000002P3oool400000;D0oooo3Oooool000co
ooooN@3oool3000000030820P03oool0oooo01d0oooo00<000000820P03oool04P3oool3000000/0
oooo1000000T0?ooo`<000001P3oool3000000l0oooo1000000Z0?ooo`<00000]P3oool=ooooo`00
3?oooomi0?ooo`<0000000<0P8200?ooo`3oool07@3oool2000001<0oooo0`00000<0?ooo`<00000
903oool3000000H0oooo1000000?0?ooo`<00000:@3oool400000;H0oooo3Oooool000coooooN@3o
ool3000000030820P03oool0oooo01h0oooo00<000000?ooo`3oool04@3oool3000000d0oooo0`00
000T0?ooo`<000001P3oool300000100oooo0`00000X0?ooo`<00000]`3oool=ooooo`003?oooomi
0?ooo`<0000000<0P8200?ooo`3oool07P3oool00`000000P8200?ooo`0A0?ooo`<000003P3oool0
0`20P80000000?ooo`0S0?ooo`030820P0000000000000H0oooo00@0P820000000000000`<30403o
ool00`20P80000000?ooo`0V0?ooo`040820P000000000000820P;L0oooo3Oooool000coooooN@3o
ool3000000030820P03oool0oooo01h0oooo00<0P8200000003oool04@3oool3000000l0oooo0P00
000T0?ooo`<000001`3oool00`000000P8200?ooo`0@0?ooo`8000009@3oool300000;T0oooo3Ooo
ool000coooooN@3oool3000000030820P03oool0oooo01h0oooo00<0P8200000003oool04@3oool3
000003D0oooo00<0P8200000000000001`3oool2000003P0oooo0P00002j0?ooo`gooooo000<oooo
ogT0oooo0`0000000`20P800oooo0?ooo`0N0?ooo`030820P000000000000140oooo0`00000e0?oo
o`040820P00000000000000000<0oooo0`0000000`3oool000000000000f0?ooo`<00000^P3oool=
ooooo`003?oooomf0?ooo`H0000000<0P8200?ooo`3oool07`3oool2000000h0oooo1P00000f0?oo
o`<000000`3oool4000000030820P0000000000003@0oooo0P00002l0?ooo`gooooo000<ooooogL0
oooo1@0000000`20P800oooo0?ooo`0O0?ooo`8000003`3oool5000003L0oooo0`0000030?ooo`<0
00000P3oool200000380oooo00<0P8200000003oool0_03oool=ooooo`003?oooomi0?ooo`<00000
00<0P8200?ooo`3oool07`3oool300000100oooo0`00000h0?ooo`<000000P3oool2000000@0oooo
0P00000a0?ooo`030000003oool0oooo0;`0oooo3Oooool000coooooN`3oool00`000000P8200?oo
o`0Q0?ooo`8000004P3oool00`000000oooo0?ooo`0h0?ooo`@000001`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0;d0oooo3Oooool000coooooo`3ooooZ0?ooo`gooooo000<oooo
ool0oooojP3oool=ooooo`003?oooooo0?ooonX0oooo3Oooool000coooooo`3ooooZ0?ooo`gooooo
000<ooooool0oooojP3oool=ooooo`003?oooooo0?ooonX0oooo3Oooool000coooooo`3ooooZ0?oo
o`gooooo000<ooooool0oooojP3oool=ooooo`003?oooooo0?ooonX0oooo3Oooool00?oooooooooo
ool4ooooo`00ooooooooooooo`Cooooo003ooooooooooooo1?ooool00?ooooooooooool4ooooo`00
ooooooooooooo`Cooooo003ooooooooooooo1?ooool00?ooooooooooool4ooooo`00oooooooooooo
o`Cooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{171.5, 125.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 1.1 A solution to ",
  StyleBox["dv",
    FontSlant->"Italic"],
  "/",
  StyleBox["dt",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["t,v",
    FontSlant->"Italic"],
  ")"
}], "Caption",
  TextAlignment->Left,
  TextJustification->0,
  CellTags->"Fig. 1.1"],

Cell["\tThe components of these vectors are", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[DifferentialD]t, \[DifferentialD]v)\) = \(\
\[DifferentialD]t\ \((1, \[DifferentialD]v\/\[DifferentialD]t)\) = \
\[DifferentialD]t\ \((1, f(t, v))\)\)\)]],
  ".\t"
}], "NE2",
  CellTags->"(1.2.3)"],

Cell[TextData[{
  "The vectors ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\ \((1, f(t, v))\)\)]],
  " form a type of ",
  StyleBox["vector field",
    FontSlant->"Italic"],
  " (a set of vectors, each member of which is associated with a separate \
point in some spatial domain) called a ",
  StyleBox["direction field. ",
    FontSlant->"Italic"],
  "This field specifies the ",
  StyleBox["direction",
    FontSlant->"Italic"],
  " of the solutions at all points in the (",
  StyleBox["t,v",
    FontSlant->"Italic"],
  ") plane: every solution to ",
  ButtonBox["Eq. (1.2.2)",
    ButtonData:>"(1.2.2)",
    ButtonStyle->"Hyperlink"],
  " for every initial condition must be a curve that runs tangent to the \
direction field. Individual vectors in the direction field are called ",
  StyleBox["tangent vectors",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"i:15"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.47596 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.226648 0.715085 0.226648 [
[.25046 .70259 -3 -9 ]
[.25046 .70259 3 0 ]
[.47711 .70259 -3 -9 ]
[.47711 .70259 3 0 ]
[.70375 .70259 -3 -9 ]
[.70375 .70259 3 0 ]
[.9304 .70259 -3 -9 ]
[.9304 .70259 3 0 ]
[1.025 .71509 0 -6 ]
[1.025 .71509 10 6 ]
[.01131 .03514 -12 -4.5 ]
[.01131 .03514 0 4.5 ]
[.01131 .26179 -12 -4.5 ]
[.01131 .26179 0 4.5 ]
[.01131 .48844 -12 -4.5 ]
[.01131 .48844 0 4.5 ]
[.01131 .94173 -6 -4.5 ]
[.01131 .94173 0 4.5 ]
[.01131 1.16838 -6 -4.5 ]
[.01131 1.16838 0 4.5 ]
[.01131 1.39503 -6 -4.5 ]
[.01131 1.39503 0 4.5 ]
[.02381 1.50096 -5 0 ]
[.02381 1.50096 5 12 ]
[ 0 0 0 0 ]
[ 1 1.47596 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25046 .71509 m
.25046 .72134 L
s
[(1)] .25046 .70259 0 1 Mshowa
.47711 .71509 m
.47711 .72134 L
s
[(2)] .47711 .70259 0 1 Mshowa
.70375 .71509 m
.70375 .72134 L
s
[(3)] .70375 .70259 0 1 Mshowa
.9304 .71509 m
.9304 .72134 L
s
[(4)] .9304 .70259 0 1 Mshowa
.125 Mabswid
.06914 .71509 m
.06914 .71884 L
s
.11447 .71509 m
.11447 .71884 L
s
.1598 .71509 m
.1598 .71884 L
s
.20513 .71509 m
.20513 .71884 L
s
.29579 .71509 m
.29579 .71884 L
s
.34112 .71509 m
.34112 .71884 L
s
.38645 .71509 m
.38645 .71884 L
s
.43178 .71509 m
.43178 .71884 L
s
.52243 .71509 m
.52243 .71884 L
s
.56776 .71509 m
.56776 .71884 L
s
.61309 .71509 m
.61309 .71884 L
s
.65842 .71509 m
.65842 .71884 L
s
.74908 .71509 m
.74908 .71884 L
s
.79441 .71509 m
.79441 .71884 L
s
.83974 .71509 m
.83974 .71884 L
s
.88507 .71509 m
.88507 .71884 L
s
.97573 .71509 m
.97573 .71884 L
s
.25 Mabswid
0 .71509 m
1 .71509 L
s
gsave
1.025 .71509 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .03514 m
.03006 .03514 L
s
[(-3)] .01131 .03514 1 0 Mshowa
.02381 .26179 m
.03006 .26179 L
s
[(-2)] .01131 .26179 1 0 Mshowa
.02381 .48844 m
.03006 .48844 L
s
[(-1)] .01131 .48844 1 0 Mshowa
.02381 .94173 m
.03006 .94173 L
s
[(1)] .01131 .94173 1 0 Mshowa
.02381 1.16838 m
.03006 1.16838 L
s
[(2)] .01131 1.16838 1 0 Mshowa
.02381 1.39503 m
.03006 1.39503 L
s
[(3)] .01131 1.39503 1 0 Mshowa
.125 Mabswid
.02381 .08047 m
.02756 .08047 L
s
.02381 .1258 m
.02756 .1258 L
s
.02381 .17113 m
.02756 .17113 L
s
.02381 .21646 m
.02756 .21646 L
s
.02381 .30712 m
.02756 .30712 L
s
.02381 .35245 m
.02756 .35245 L
s
.02381 .39778 m
.02756 .39778 L
s
.02381 .44311 m
.02756 .44311 L
s
.02381 .53377 m
.02756 .53377 L
s
.02381 .5791 m
.02756 .5791 L
s
.02381 .62443 m
.02756 .62443 L
s
.02381 .66976 m
.02756 .66976 L
s
.02381 .76041 m
.02756 .76041 L
s
.02381 .80574 m
.02756 .80574 L
s
.02381 .85107 m
.02756 .85107 L
s
.02381 .8964 m
.02756 .8964 L
s
.02381 .98706 m
.02756 .98706 L
s
.02381 1.03239 m
.02756 1.03239 L
s
.02381 1.07772 m
.02756 1.07772 L
s
.02381 1.12305 m
.02756 1.12305 L
s
.02381 1.21371 m
.02756 1.21371 L
s
.02381 1.25904 m
.02756 1.25904 L
s
.02381 1.30437 m
.02756 1.30437 L
s
.02381 1.3497 m
.02756 1.3497 L
s
.02381 1.44036 m
.02756 1.44036 L
s
.25 Mabswid
.02381 0 m
.02381 1.47596 L
s
gsave
.02381 1.50096 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.02381 .03514 m
.04429 .09658 L
s
% Start of user PostScript
0 -3. 0.0903508 -2.72895 MAarrowhead1
% End of user PostScript
.02381 .13228 m
.04728 .19263 L
s
% Start of user PostScript
0 -2.57143 0.103556 -2.30514 MAarrowhead1
% End of user PostScript
.02381 .22941 m
.05119 .28809 L
s
% Start of user PostScript
0 -2.14286 0.120824 -1.88395 MAarrowhead1
% End of user PostScript
.02381 .32655 m
.05644 .38248 L
s
% Start of user PostScript
0 -1.71429 0.143963 -1.46749 MAarrowhead1
% End of user PostScript
.02381 .42368 m
.06357 .4748 L
s
% Start of user PostScript
0 -1.28571 0.175412 -1.06019 MAarrowhead1
% End of user PostScript
.02381 .52082 m
.07298 .56296 L
s
% Start of user PostScript
0 -0.857143 0.21693 -0.671202 MAarrowhead1
% End of user PostScript
.02381 .61795 m
.08333 .64346 L
s
% Start of user PostScript
0 -0.428571 0.262613 -0.316023 MAarrowhead1
% End of user PostScript
.02381 .71509 m
.08857 .71509 L
s
% Start of user PostScript
0 0 0.285714 0 MAarrowhead1
% End of user PostScript
.02381 .81222 m
.08333 .78671 L
s
% Start of user PostScript
0 0.428571 0.262613 0.316023 MAarrowhead1
% End of user PostScript
.02381 .90935 m
.07298 .86721 L
s
% Start of user PostScript
0 0.857143 0.21693 0.671202 MAarrowhead1
% End of user PostScript
.02381 1.00649 m
.06357 .95537 L
s
% Start of user PostScript
0 1.28571 0.175412 1.06019 MAarrowhead1
% End of user PostScript
.02381 1.10362 m
.05644 1.04769 L
s
% Start of user PostScript
0 1.71429 0.143963 1.46749 MAarrowhead1
% End of user PostScript
.02381 1.20076 m
.05119 1.14208 L
s
% Start of user PostScript
0 2.14286 0.120824 1.88395 MAarrowhead1
% End of user PostScript
.02381 1.29789 m
.04728 1.23754 L
s
% Start of user PostScript
0 2.57143 0.103556 2.30514 MAarrowhead1
% End of user PostScript
.02381 1.39503 m
.04429 1.3336 L
s
% Start of user PostScript
0 3. 0.0903508 2.72895 MAarrowhead1
% End of user PostScript
.08857 .03514 m
.10742 .09709 L
s
% Start of user PostScript
0.285714 -3. 0.368903 -2.72666 MAarrowhead1
% End of user PostScript
.08857 .13228 m
.10996 .1934 L
s
% Start of user PostScript
0.285714 -2.57143 0.3801 -2.30175 MAarrowhead1
% End of user PostScript
.08857 .22941 m
.11322 .28929 L
s
% Start of user PostScript
0.285714 -2.14286 0.3945 -1.87866 MAarrowhead1
% End of user PostScript
.08857 .32655 m
.11753 .38447 L
s
% Start of user PostScript
0.285714 -1.71429 0.41349 -1.45874 MAarrowhead1
% End of user PostScript
.08857 .42368 m
.12333 .47831 L
s
% Start of user PostScript
0.285714 -1.28571 0.439107 -1.04467 MAarrowhead1
% End of user PostScript
.08857 .52082 m
.13121 .56955 L
s
% Start of user PostScript
0.285714 -0.857143 0.473858 -0.642121 MAarrowhead1
% End of user PostScript
.08857 .61795 m
.14126 .65559 L
s
% Start of user PostScript
0.285714 -0.428571 0.51821 -0.262503 MAarrowhead1
% End of user PostScript
.08857 .71509 m
.15083 .73288 L
s
% Start of user PostScript
0.285714 0 0.560435 0.0784918 MAarrowhead1
% End of user PostScript
.08857 .81222 m
.15267 .80306 L
s
% Start of user PostScript
0.285714 0.428571 0.568557 0.388165 MAarrowhead1
% End of user PostScript
.08857 .90935 m
.14479 .87723 L
s
% Start of user PostScript
0.285714 0.857143 0.533784 0.715389 MAarrowhead1
% End of user PostScript
.08857 1.00649 m
.13436 .9607 L
s
% Start of user PostScript
0.285714 1.28571 0.487745 1.08368 MAarrowhead1
% End of user PostScript
.08857 1.10362 m
.1257 1.05057 L
s
% Start of user PostScript
0.285714 1.71429 0.449561 1.48022 MAarrowhead1
% End of user PostScript
.08857 1.20076 m
.11927 1.14374 L
s
% Start of user PostScript
0.285714 2.14286 0.421171 1.89129 MAarrowhead1
% End of user PostScript
.08857 1.29789 m
.11452 1.23857 L
s
% Start of user PostScript
0.285714 2.57143 0.400234 2.30967 MAarrowhead1
% End of user PostScript
.08857 1.39503 m
.11095 1.33426 L
s
% Start of user PostScript
0.285714 3. 0.384487 2.7319 MAarrowhead1
% End of user PostScript
.15332 .03514 m
.17078 .0975 L
s
% Start of user PostScript
0.571429 -3. 0.648466 -2.72487 MAarrowhead1
% End of user PostScript
.15332 .13228 m
.17296 .19398 L
s
% Start of user PostScript
0.571429 -2.57143 0.658058 -2.29916 MAarrowhead1
% End of user PostScript
.15332 .22941 m
.17571 .29018 L
s
% Start of user PostScript
0.571429 -2.14286 0.670202 -1.87476 MAarrowhead1
% End of user PostScript
.15332 .32655 m
.17928 .38587 L
s
% Start of user PostScript
0.571429 -1.71429 0.685948 -1.45253 MAarrowhead1
% End of user PostScript
.15332 .42368 m
.18402 .4807 L
s
% Start of user PostScript
0.571429 -1.28571 0.706886 -1.03415 MAarrowhead1
% End of user PostScript
.15332 .52082 m
.19046 .57387 L
s
% Start of user PostScript
0.571429 -0.857143 0.735275 -0.623077 MAarrowhead1
% End of user PostScript
.15332 .61795 m
.19911 .66374 L
s
% Start of user PostScript
0.571429 -0.428571 0.773459 -0.226541 MAarrowhead1
% End of user PostScript
.15332 .71509 m
.20955 .74721 L
s
% Start of user PostScript
0.571429 0 0.819498 0.141754 MAarrowhead1
% End of user PostScript
.15332 .81222 m
.21743 .82138 L
s
% Start of user PostScript
0.571429 0.428571 0.854271 0.468978 MAarrowhead1
% End of user PostScript
.15332 .90935 m
.21559 .89156 L
s
% Start of user PostScript
0.571429 0.857143 0.84615 0.778651 MAarrowhead1
% End of user PostScript
.15332 1.00649 m
.20602 .96885 L
s
% Start of user PostScript
0.571429 1.28571 0.803924 1.11965 MAarrowhead1
% End of user PostScript
.15332 1.10362 m
.19597 1.05489 L
s
% Start of user PostScript
0.571429 1.71429 0.759573 1.49926 MAarrowhead1
% End of user PostScript
.15332 1.20076 m
.18809 1.14613 L
s
% Start of user PostScript
0.571429 2.14286 0.724822 1.90181 MAarrowhead1
% End of user PostScript
.15332 1.29789 m
.18228 1.23997 L
s
% Start of user PostScript
0.571429 2.57143 0.699204 2.31588 MAarrowhead1
% End of user PostScript
.15332 1.39503 m
.17798 1.33515 L
s
% Start of user PostScript
0.571429 3. 0.680214 2.73581 MAarrowhead1
% End of user PostScript
.21808 .03514 m
.23433 .09783 L
s
% Start of user PostScript
0.857143 -3. 0.928846 -2.72343 MAarrowhead1
% End of user PostScript
.21808 .13228 m
.23621 .19444 L
s
% Start of user PostScript
0.857143 -2.57143 0.937143 -2.29714 MAarrowhead1
% End of user PostScript
.21808 .22941 m
.23856 .29084 L
s
% Start of user PostScript
0.857143 -2.14286 0.947494 -1.8718 MAarrowhead1
% End of user PostScript
.21808 .32655 m
.24155 .3869 L
s
% Start of user PostScript
0.857143 -1.71429 0.960699 -1.448 MAarrowhead1
% End of user PostScript
.21808 .42368 m
.24546 .48236 L
s
% Start of user PostScript
0.857143 -1.28571 0.977967 -1.0268 MAarrowhead1
% End of user PostScript
.21808 .52082 m
.25071 .57675 L
s
% Start of user PostScript
0.857143 -0.857143 1.00111 -0.610349 MAarrowhead1
% End of user PostScript
.21808 .61795 m
.25784 .66907 L
s
% Start of user PostScript
0.857143 -0.428571 1.03255 -0.203042 MAarrowhead1
% End of user PostScript
.21808 .71509 m
.26725 .75723 L
s
% Start of user PostScript
0.857143 0 1.07407 0.18594 MAarrowhead1
% End of user PostScript
.21808 .81222 m
.2776 .83773 L
s
% Start of user PostScript
0.857143 0.428571 1.11976 0.54112 MAarrowhead1
% End of user PostScript
.21808 .90935 m
.28284 .90935 L
s
% Start of user PostScript
0.857143 0.857143 1.14286 0.857143 MAarrowhead1
% End of user PostScript
.21808 1.00649 m
.2776 .98098 L
s
% Start of user PostScript
0.857143 1.28571 1.11976 1.17317 MAarrowhead1
% End of user PostScript
.21808 1.10362 m
.26725 1.06148 L
s
% Start of user PostScript
0.857143 1.71429 1.07407 1.52835 MAarrowhead1
% End of user PostScript
.21808 1.20076 m
.25784 1.14964 L
s
% Start of user PostScript
0.857143 2.14286 1.03255 1.91733 MAarrowhead1
% End of user PostScript
.21808 1.29789 m
.25071 1.24196 L
s
% Start of user PostScript
0.857143 2.57143 1.00111 2.32463 MAarrowhead1
% End of user PostScript
.21808 1.39503 m
.24546 1.33635 L
s
% Start of user PostScript
0.857143 3. 0.977967 2.74109 MAarrowhead1
% End of user PostScript
.28284 .03514 m
.29803 .09809 L
s
% Start of user PostScript
1.14286 -3. 1.2099 -2.72226 MAarrowhead1
% End of user PostScript
.28284 .13228 m
.29967 .19481 L
s
% Start of user PostScript
1.14286 -2.57143 1.21714 -2.29554 MAarrowhead1
% End of user PostScript
.28284 .22941 m
.30169 .29136 L
s
% Start of user PostScript
1.14286 -2.14286 1.22605 -1.86952 MAarrowhead1
% End of user PostScript
.28284 .32655 m
.30423 .38767 L
s
% Start of user PostScript
1.14286 -1.71429 1.23724 -1.44461 MAarrowhead1
% End of user PostScript
.28284 .42368 m
.30749 .48356 L
s
% Start of user PostScript
1.14286 -1.28571 1.25164 -1.02152 MAarrowhead1
% End of user PostScript
.28284 .52082 m
.3118 .57874 L
s
% Start of user PostScript
1.14286 -0.857143 1.27063 -0.601592 MAarrowhead1
% End of user PostScript
.28284 .61795 m
.3176 .67258 L
s
% Start of user PostScript
1.14286 -0.428571 1.29625 -0.187525 MAarrowhead1
% End of user PostScript
.28284 .71509 m
.32548 .76382 L
s
% Start of user PostScript
1.14286 0 1.331 0.215022 MAarrowhead1
% End of user PostScript
.28284 .81222 m
.33553 .84986 L
s
% Start of user PostScript
1.14286 0.428571 1.37535 0.594639 MAarrowhead1
% End of user PostScript
.28284 .90935 m
.3451 .92714 L
s
% Start of user PostScript
1.14286 0.857143 1.41758 0.935635 MAarrowhead1
% End of user PostScript
.28284 1.00649 m
.34694 .99733 L
s
% Start of user PostScript
1.14286 1.28571 1.4257 1.24531 MAarrowhead1
% End of user PostScript
.28284 1.10362 m
.33906 1.0715 L
s
% Start of user PostScript
1.14286 1.71429 1.39093 1.57253 MAarrowhead1
% End of user PostScript
.28284 1.20076 m
.32863 1.15497 L
s
% Start of user PostScript
1.14286 2.14286 1.34489 1.94083 MAarrowhead1
% End of user PostScript
.28284 1.29789 m
.31997 1.24484 L
s
% Start of user PostScript
1.14286 2.57143 1.3067 2.33736 MAarrowhead1
% End of user PostScript
.28284 1.39503 m
.31354 1.33801 L
s
% Start of user PostScript
1.14286 3. 1.27831 2.74844 MAarrowhead1
% End of user PostScript
.34759 .03514 m
.36186 .09831 L
s
% Start of user PostScript
1.42857 -3. 1.4915 -2.7213 MAarrowhead1
% End of user PostScript
.34759 .13228 m
.3633 .1951 L
s
% Start of user PostScript
1.42857 -2.57143 1.49787 -2.29424 MAarrowhead1
% End of user PostScript
.34759 .22941 m
.36505 .29177 L
s
% Start of user PostScript
1.42857 -2.14286 1.50561 -1.86772 MAarrowhead1
% End of user PostScript
.34759 .32655 m
.36723 .38825 L
s
% Start of user PostScript
1.42857 -1.71429 1.5152 -1.44202 MAarrowhead1
% End of user PostScript
.34759 .42368 m
.36998 .48444 L
s
% Start of user PostScript
1.42857 -1.28571 1.52734 -1.01762 MAarrowhead1
% End of user PostScript
.34759 .52082 m
.37355 .58014 L
s
% Start of user PostScript
1.42857 -0.857143 1.54309 -0.595384 MAarrowhead1
% End of user PostScript
.34759 .61795 m
.37829 .67497 L
s
% Start of user PostScript
1.42857 -0.428571 1.56403 -0.177008 MAarrowhead1
% End of user PostScript
.34759 .71509 m
.38473 .76814 L
s
% Start of user PostScript
1.42857 0 1.59242 0.234066 MAarrowhead1
% End of user PostScript
.34759 .81222 m
.39338 .85801 L
s
% Start of user PostScript
1.42857 0.428571 1.6306 0.630602 MAarrowhead1
% End of user PostScript
.34759 .90935 m
.40382 .94148 L
s
% Start of user PostScript
1.42857 0.857143 1.67664 0.998897 MAarrowhead1
% End of user PostScript
.34759 1.00649 m
.4117 1.01565 L
s
% Start of user PostScript
1.42857 1.28571 1.71141 1.32612 MAarrowhead1
% End of user PostScript
.34759 1.10362 m
.40986 1.08583 L
s
% Start of user PostScript
1.42857 1.71429 1.70329 1.63579 MAarrowhead1
% End of user PostScript
.34759 1.20076 m
.40029 1.16312 L
s
% Start of user PostScript
1.42857 2.14286 1.66107 1.97679 MAarrowhead1
% End of user PostScript
.34759 1.29789 m
.39023 1.24916 L
s
% Start of user PostScript
1.42857 2.57143 1.61672 2.35641 MAarrowhead1
% End of user PostScript
.34759 1.39503 m
.38236 1.3404 L
s
% Start of user PostScript
1.42857 3. 1.58196 2.75895 MAarrowhead1
% End of user PostScript
.41235 .03514 m
.42579 .09849 L
s
% Start of user PostScript
1.71429 -3. 1.77357 -2.7205 MAarrowhead1
% End of user PostScript
.41235 .13228 m
.42706 .19534 L
s
% Start of user PostScript
1.71429 -2.57143 1.77921 -2.29319 MAarrowhead1
% End of user PostScript
.41235 .22941 m
.4286 .2921 L
s
% Start of user PostScript
1.71429 -2.14286 1.78599 -1.86629 MAarrowhead1
% End of user PostScript
.41235 .32655 m
.43048 .38871 L
s
% Start of user PostScript
1.71429 -1.71429 1.79429 -1.44 MAarrowhead1
% End of user PostScript
.41235 .42368 m
.43283 .48511 L
s
% Start of user PostScript
1.71429 -1.28571 1.80464 -1.01466 MAarrowhead1
% End of user PostScript
.41235 .52082 m
.43582 .58117 L
s
% Start of user PostScript
1.71429 -0.857143 1.81784 -0.590856 MAarrowhead1
% End of user PostScript
.41235 .61795 m
.43973 .67663 L
s
% Start of user PostScript
1.71429 -0.428571 1.83511 -0.169662 MAarrowhead1
% End of user PostScript
.41235 .71509 m
.44498 .77102 L
s
% Start of user PostScript
1.71429 0 1.85825 0.246794 MAarrowhead1
% End of user PostScript
.41235 .81222 m
.45211 .86334 L
s
% Start of user PostScript
1.71429 0.428571 1.8897 0.654101 MAarrowhead1
% End of user PostScript
.41235 .90935 m
.46152 .9515 L
s
% Start of user PostScript
1.71429 0.857143 1.93122 1.04308 MAarrowhead1
% End of user PostScript
.41235 1.00649 m
.47187 1.032 L
s
% Start of user PostScript
1.71429 1.28571 1.9769 1.39826 MAarrowhead1
% End of user PostScript
.41235 1.10362 m
.47711 1.10362 L
s
% Start of user PostScript
1.71429 1.71429 2. 1.71429 MAarrowhead1
% End of user PostScript
.41235 1.20076 m
.47187 1.17525 L
s
% Start of user PostScript
1.71429 2.14286 1.9769 2.03031 MAarrowhead1
% End of user PostScript
.41235 1.29789 m
.46152 1.25575 L
s
% Start of user PostScript
1.71429 2.57143 1.93122 2.38549 MAarrowhead1
% End of user PostScript
.41235 1.39503 m
.45211 1.34391 L
s
% Start of user PostScript
1.71429 3. 1.8897 2.77447 MAarrowhead1
% End of user PostScript
.47711 .03514 m
.4898 .09864 L
s
% Start of user PostScript
2. -3. 2.05603 -2.71983 MAarrowhead1
% End of user PostScript
.47711 .13228 m
.49094 .19554 L
s
% Start of user PostScript
2. -2.57143 2.06106 -2.29231 MAarrowhead1
% End of user PostScript
.47711 .22941 m
.4923 .29236 L
s
% Start of user PostScript
2. -2.14286 2.06704 -1.86512 MAarrowhead1
% End of user PostScript
.47711 .32655 m
.49394 .38908 L
s
% Start of user PostScript
2. -1.71429 2.07428 -1.4384 MAarrowhead1
% End of user PostScript
.47711 .42368 m
.49596 .48563 L
s
% Start of user PostScript
2. -1.28571 2.08319 -1.01238 MAarrowhead1
% End of user PostScript
.47711 .52082 m
.4985 .58194 L
s
% Start of user PostScript
2. -0.857143 2.09439 -0.587469 MAarrowhead1
% End of user PostScript
.47711 .61795 m
.50176 .67783 L
s
% Start of user PostScript
2. -0.428571 2.10879 -0.164378 MAarrowhead1
% End of user PostScript
.47711 .71509 m
.50607 .77301 L
s
% Start of user PostScript
2. 0 2.12778 0.255551 MAarrowhead1
% End of user PostScript
.47711 .81222 m
.51187 .86685 L
s
% Start of user PostScript
2. 0.428571 2.15339 0.669618 MAarrowhead1
% End of user PostScript
.47711 .90935 m
.51975 .95809 L
s
% Start of user PostScript
2. 0.857143 2.18814 1.07216 MAarrowhead1
% End of user PostScript
.47711 1.00649 m
.5298 1.04413 L
s
% Start of user PostScript
2. 1.28571 2.2325 1.45178 MAarrowhead1
% End of user PostScript
.47711 1.10362 m
.53937 1.12141 L
s
% Start of user PostScript
2. 1.71429 2.27472 1.79278 MAarrowhead1
% End of user PostScript
.47711 1.20076 m
.54121 1.1916 L
s
% Start of user PostScript
2. 2.14286 2.28284 2.10245 MAarrowhead1
% End of user PostScript
.47711 1.29789 m
.53333 1.26577 L
s
% Start of user PostScript
2. 2.57143 2.24807 2.42967 MAarrowhead1
% End of user PostScript
.47711 1.39503 m
.52289 1.34924 L
s
% Start of user PostScript
2. 3. 2.20203 2.79797 MAarrowhead1
% End of user PostScript
.54186 .03514 m
.5539 .09877 L
s
% Start of user PostScript
2.28571 -3. 2.33883 -2.71927 MAarrowhead1
% End of user PostScript
.54186 .13228 m
.55492 .1957 L
s
% Start of user PostScript
2.28571 -2.57143 2.34333 -2.29158 MAarrowhead1
% End of user PostScript
.54186 .22941 m
.55612 .29258 L
s
% Start of user PostScript
2.28571 -2.14286 2.34865 -1.86416 MAarrowhead1
% End of user PostScript
.54186 .32655 m
.55757 .38937 L
s
% Start of user PostScript
2.28571 -1.71429 2.35501 -1.4371 MAarrowhead1
% End of user PostScript
.54186 .42368 m
.55932 .48604 L
s
% Start of user PostScript
2.28571 -1.28571 2.36275 -1.01058 MAarrowhead1
% End of user PostScript
.54186 .52082 m
.5615 .58252 L
s
% Start of user PostScript
2.28571 -0.857143 2.37234 -0.584878 MAarrowhead1
% End of user PostScript
.54186 .61795 m
.56425 .67871 L
s
% Start of user PostScript
2.28571 -0.428571 2.38449 -0.160473 MAarrowhead1
% End of user PostScript
.54186 .71509 m
.56782 .77441 L
s
% Start of user PostScript
2.28571 0 2.40023 0.261759 MAarrowhead1
% End of user PostScript
.54186 .81222 m
.57256 .86924 L
s
% Start of user PostScript
2.28571 0.428571 2.42117 0.680135 MAarrowhead1
% End of user PostScript
.54186 .90935 m
.579 .96241 L
s
% Start of user PostScript
2.28571 0.857143 2.44956 1.09121 MAarrowhead1
% End of user PostScript
.54186 1.00649 m
.58765 1.05228 L
s
% Start of user PostScript
2.28571 1.28571 2.48774 1.48774 MAarrowhead1
% End of user PostScript
.54186 1.10362 m
.59809 1.13575 L
s
% Start of user PostScript
2.28571 1.71429 2.53378 1.85604 MAarrowhead1
% End of user PostScript
.54186 1.20076 m
.60597 1.20992 L
s
% Start of user PostScript
2.28571 2.14286 2.56856 2.18326 MAarrowhead1
% End of user PostScript
.54186 1.29789 m
.60413 1.2801 L
s
% Start of user PostScript
2.28571 2.57143 2.56044 2.49294 MAarrowhead1
% End of user PostScript
.54186 1.39503 m
.59456 1.35739 L
s
% Start of user PostScript
2.28571 3. 2.51821 2.83393 MAarrowhead1
% End of user PostScript
.60662 .03514 m
.61806 .09888 L
s
% Start of user PostScript
2.57143 -3. 2.6219 -2.71878 MAarrowhead1
% End of user PostScript
.60662 .13228 m
.61898 .19584 L
s
% Start of user PostScript
2.57143 -2.57143 2.62596 -2.29097 MAarrowhead1
% End of user PostScript
.60662 .22941 m
.62006 .29276 L
s
% Start of user PostScript
2.57143 -2.14286 2.63072 -1.86336 MAarrowhead1
% End of user PostScript
.60662 .32655 m
.62133 .38961 L
s
% Start of user PostScript
2.57143 -1.71429 2.63635 -1.43605 MAarrowhead1
% End of user PostScript
.60662 .42368 m
.62287 .48637 L
s
% Start of user PostScript
2.57143 -1.28571 2.64313 -1.00914 MAarrowhead1
% End of user PostScript
.60662 .52082 m
.62475 .58298 L
s
% Start of user PostScript
2.57143 -0.857143 2.65143 -0.582857 MAarrowhead1
% End of user PostScript
.60662 .61795 m
.6271 .67938 L
s
% Start of user PostScript
2.57143 -0.428571 2.66178 -0.157519 MAarrowhead1
% End of user PostScript
.60662 .71509 m
.63009 .77544 L
s
% Start of user PostScript
2.57143 0 2.67498 0.266287 MAarrowhead1
% End of user PostScript
.60662 .81222 m
.634 .8709 L
s
% Start of user PostScript
2.57143 0.428571 2.69225 0.687481 MAarrowhead1
% End of user PostScript
.60662 .90935 m
.63925 .96529 L
s
% Start of user PostScript
2.57143 0.857143 2.71539 1.10394 MAarrowhead1
% End of user PostScript
.60662 1.00649 m
.64637 1.05761 L
s
% Start of user PostScript
2.57143 1.28571 2.74684 1.51124 MAarrowhead1
% End of user PostScript
.60662 1.10362 m
.65578 1.14577 L
s
% Start of user PostScript
2.57143 1.71429 2.78836 1.90023 MAarrowhead1
% End of user PostScript
.60662 1.20076 m
.66614 1.22627 L
s
% Start of user PostScript
2.57143 2.14286 2.83404 2.25541 MAarrowhead1
% End of user PostScript
.60662 1.29789 m
.67137 1.29789 L
s
% Start of user PostScript
2.57143 2.57143 2.85714 2.57143 MAarrowhead1
% End of user PostScript
.60662 1.39503 m
.66614 1.36952 L
s
% Start of user PostScript
2.57143 3. 2.83404 2.88745 MAarrowhead1
% End of user PostScript
.67137 .03514 m
.68227 .09897 L
s
% Start of user PostScript
2.85714 -3. 2.90523 -2.71836 MAarrowhead1
% End of user PostScript
.67137 .13228 m
.68311 .19596 L
s
% Start of user PostScript
2.85714 -2.57143 2.9089 -2.29044 MAarrowhead1
% End of user PostScript
.67137 .22941 m
.68407 .29291 L
s
% Start of user PostScript
2.85714 -2.14286 2.91318 -1.86269 MAarrowhead1
% End of user PostScript
.67137 .32655 m
.68521 .38981 L
s
% Start of user PostScript
2.85714 -1.71429 2.9182 -1.43517 MAarrowhead1
% End of user PostScript
.67137 .42368 m
.68657 .48663 L
s
% Start of user PostScript
2.85714 -1.28571 2.92418 -1.00798 MAarrowhead1
% End of user PostScript
.67137 .52082 m
.68821 .58335 L
s
% Start of user PostScript
2.85714 -0.857143 2.93142 -0.581253 MAarrowhead1
% End of user PostScript
.67137 .61795 m
.69023 .6799 L
s
% Start of user PostScript
2.85714 -0.428571 2.94033 -0.155236 MAarrowhead1
% End of user PostScript
.67137 .71509 m
.69277 .77621 L
s
% Start of user PostScript
2.85714 0 2.95153 0.269674 MAarrowhead1
% End of user PostScript
.67137 .81222 m
.69603 .8721 L
s
% Start of user PostScript
2.85714 0.428571 2.96593 0.692765 MAarrowhead1
% End of user PostScript
.67137 .90935 m
.70033 .96727 L
s
% Start of user PostScript
2.85714 0.857143 2.98492 1.11269 MAarrowhead1
% End of user PostScript
.67137 1.00649 m
.70614 1.06112 L
s
% Start of user PostScript
2.85714 1.28571 3.01054 1.52676 MAarrowhead1
% End of user PostScript
.67137 1.10362 m
.71402 1.15236 L
s
% Start of user PostScript
2.85714 1.71429 3.04529 1.92931 MAarrowhead1
% End of user PostScript
.67137 1.20076 m
.72407 1.2384 L
s
% Start of user PostScript
2.85714 2.14286 3.08964 2.30893 MAarrowhead1
% End of user PostScript
.67137 1.29789 m
.73364 1.31568 L
s
% Start of user PostScript
2.85714 2.57143 3.13186 2.64992 MAarrowhead1
% End of user PostScript
.67137 1.39503 m
.73548 1.38587 L
s
% Start of user PostScript
2.85714 3. 3.13999 2.95959 MAarrowhead1
% End of user PostScript
.73613 .03514 m
.74654 .09906 L
s
% Start of user PostScript
3.14286 -3. 3.18876 -2.718 MAarrowhead1
% End of user PostScript
.73613 .13228 m
.74729 .19606 L
s
% Start of user PostScript
3.14286 -2.57143 3.19211 -2.28999 MAarrowhead1
% End of user PostScript
.73613 .22941 m
.74817 .29304 L
s
% Start of user PostScript
3.14286 -2.14286 3.19597 -1.86212 MAarrowhead1
% End of user PostScript
.73613 .32655 m
.74919 .38997 L
s
% Start of user PostScript
3.14286 -1.71429 3.20047 -1.43444 MAarrowhead1
% End of user PostScript
.73613 .42368 m
.75039 .48685 L
s
% Start of user PostScript
3.14286 -1.28571 3.20579 -1.00702 MAarrowhead1
% End of user PostScript
.73613 .52082 m
.75184 .58364 L
s
% Start of user PostScript
3.14286 -0.857143 3.21215 -0.579959 MAarrowhead1
% End of user PostScript
.73613 .61795 m
.75359 .68031 L
s
% Start of user PostScript
3.14286 -0.428571 3.21989 -0.153439 MAarrowhead1
% End of user PostScript
.73613 .71509 m
.75577 .77679 L
s
% Start of user PostScript
3.14286 0 3.22949 0.272265 MAarrowhead1
% End of user PostScript
.73613 .81222 m
.75852 .87298 L
s
% Start of user PostScript
3.14286 0.428571 3.24163 0.696669 MAarrowhead1
% End of user PostScript
.73613 .90935 m
.76209 .96868 L
s
% Start of user PostScript
3.14286 0.857143 3.25738 1.1189 MAarrowhead1
% End of user PostScript
.73613 1.00649 m
.76683 1.06351 L
s
% Start of user PostScript
3.14286 1.28571 3.27831 1.53728 MAarrowhead1
% End of user PostScript
.73613 1.10362 m
.77327 1.15667 L
s
% Start of user PostScript
3.14286 1.71429 3.3067 1.94835 MAarrowhead1
% End of user PostScript
.73613 1.20076 m
.78192 1.24655 L
s
% Start of user PostScript
3.14286 2.14286 3.34489 2.34489 MAarrowhead1
% End of user PostScript
.73613 1.29789 m
.79236 1.33002 L
s
% Start of user PostScript
3.14286 2.57143 3.39093 2.71318 MAarrowhead1
% End of user PostScript
.73613 1.39503 m
.80024 1.40419 L
s
% Start of user PostScript
3.14286 3. 3.4257 3.04041 MAarrowhead1
% End of user PostScript
.80089 .03514 m
.81084 .09913 L
s
% Start of user PostScript
3.42857 -3. 3.47249 -2.71768 MAarrowhead1
% End of user PostScript
.80089 .13228 m
.81153 .19615 L
s
% Start of user PostScript
3.42857 -2.57143 3.47554 -2.2896 MAarrowhead1
% End of user PostScript
.80089 .22941 m
.81233 .29315 L
s
% Start of user PostScript
3.42857 -2.14286 3.47905 -1.86164 MAarrowhead1
% End of user PostScript
.80089 .32655 m
.81325 .39011 L
s
% Start of user PostScript
3.42857 -1.71429 3.48311 -1.43382 MAarrowhead1
% End of user PostScript
.80089 .42368 m
.81432 .48703 L
s
% Start of user PostScript
3.42857 -1.28571 3.48786 -1.00622 MAarrowhead1
% End of user PostScript
.80089 .52082 m
.8156 .58388 L
s
% Start of user PostScript
3.42857 -0.857143 3.49349 -0.578903 MAarrowhead1
% End of user PostScript
.80089 .61795 m
.81714 .68063 L
s
% Start of user PostScript
3.42857 -0.428571 3.50027 -0.152001 MAarrowhead1
% End of user PostScript
.80089 .71509 m
.81902 .77725 L
s
% Start of user PostScript
3.42857 0 3.50857 0.274286 MAarrowhead1
% End of user PostScript
.80089 .81222 m
.82137 .87365 L
s
% Start of user PostScript
3.42857 0.428571 3.51892 0.699624 MAarrowhead1
% End of user PostScript
.80089 .90935 m
.82436 .96971 L
s
% Start of user PostScript
3.42857 0.857143 3.53213 1.12343 MAarrowhead1
% End of user PostScript
.80089 1.00649 m
.82827 1.06517 L
s
% Start of user PostScript
3.42857 1.28571 3.5494 1.54462 MAarrowhead1
% End of user PostScript
.80089 1.10362 m
.83352 1.15956 L
s
% Start of user PostScript
3.42857 1.71429 3.57253 1.96108 MAarrowhead1
% End of user PostScript
.80089 1.20076 m
.84064 1.25187 L
s
% Start of user PostScript
3.42857 2.14286 3.60398 2.36839 MAarrowhead1
% End of user PostScript
.80089 1.29789 m
.85005 1.34004 L
s
% Start of user PostScript
3.42857 2.57143 3.6455 2.75737 MAarrowhead1
% End of user PostScript
.80089 1.39503 m
.86041 1.42054 L
s
% Start of user PostScript
3.42857 3. 3.69118 3.11255 MAarrowhead1
% End of user PostScript
.86564 .03514 m
.87518 .09919 L
s
% Start of user PostScript
3.71429 -3. 3.75637 -2.7174 MAarrowhead1
% End of user PostScript
.86564 .13228 m
.87582 .19623 L
s
% Start of user PostScript
3.71429 -2.57143 3.75918 -2.28926 MAarrowhead1
% End of user PostScript
.86564 .22941 m
.87654 .29324 L
s
% Start of user PostScript
3.71429 -2.14286 3.76237 -1.86122 MAarrowhead1
% End of user PostScript
.86564 .32655 m
.87738 .39023 L
s
% Start of user PostScript
3.71429 -1.71429 3.76605 -1.4333 MAarrowhead1
% End of user PostScript
.86564 .42368 m
.87834 .48718 L
s
% Start of user PostScript
3.71429 -1.28571 3.77032 -1.00555 MAarrowhead1
% End of user PostScript
.86564 .52082 m
.87948 .58408 L
s
% Start of user PostScript
3.71429 -0.857143 3.77534 -0.578029 MAarrowhead1
% End of user PostScript
.86564 .61795 m
.88084 .6809 L
s
% Start of user PostScript
3.71429 -0.428571 3.78133 -0.150834 MAarrowhead1
% End of user PostScript
.86564 .71509 m
.88248 .77762 L
s
% Start of user PostScript
3.71429 0 3.78856 0.27589 MAarrowhead1
% End of user PostScript
.86564 .81222 m
.8845 .87417 L
s
% Start of user PostScript
3.71429 0.428571 3.79747 0.701907 MAarrowhead1
% End of user PostScript
.86564 .90935 m
.88704 .97048 L
s
% Start of user PostScript
3.71429 0.857143 3.80867 1.12682 MAarrowhead1
% End of user PostScript
.86564 1.00649 m
.8903 1.06637 L
s
% Start of user PostScript
3.71429 1.28571 3.82307 1.54991 MAarrowhead1
% End of user PostScript
.86564 1.10362 m
.8946 1.16154 L
s
% Start of user PostScript
3.71429 1.71429 3.84206 1.96984 MAarrowhead1
% End of user PostScript
.86564 1.20076 m
.90041 1.25539 L
s
% Start of user PostScript
3.71429 2.14286 3.86768 2.3839 MAarrowhead1
% End of user PostScript
.86564 1.29789 m
.90829 1.34663 L
s
% Start of user PostScript
3.71429 2.57143 3.90243 2.78645 MAarrowhead1
% End of user PostScript
.86564 1.39503 m
.91834 1.43267 L
s
% Start of user PostScript
3.71429 3. 3.94678 3.16607 MAarrowhead1
% End of user PostScript
.9304 .03514 m
.93956 .09925 L
s
% Start of user PostScript
4. -3. 4.04041 -2.71716 MAarrowhead1
% End of user PostScript
.9304 .13228 m
.94014 .1963 L
s
% Start of user PostScript
4. -2.57143 4.04298 -2.28897 MAarrowhead1
% End of user PostScript
.9304 .22941 m
.94081 .29333 L
s
% Start of user PostScript
4. -2.14286 4.04591 -1.86086 MAarrowhead1
% End of user PostScript
.9304 .32655 m
.94156 .39033 L
s
% Start of user PostScript
4. -1.71429 4.04925 -1.43285 MAarrowhead1
% End of user PostScript
.9304 .42368 m
.94244 .48731 L
s
% Start of user PostScript
4. -1.28571 4.05311 -1.00498 MAarrowhead1
% End of user PostScript
.9304 .52082 m
.94346 .58424 L
s
% Start of user PostScript
4. -0.857143 4.05762 -0.577298 MAarrowhead1
% End of user PostScript
.9304 .61795 m
.94466 .68112 L
s
% Start of user PostScript
4. -0.428571 4.06293 -0.149874 MAarrowhead1
% End of user PostScript
.9304 .71509 m
.94611 .77791 L
s
% Start of user PostScript
4. 0 4.0693 0.277184 MAarrowhead1
% End of user PostScript
.9304 .81222 m
.94786 .87458 L
s
% Start of user PostScript
4. 0.428571 4.07704 0.703704 MAarrowhead1
% End of user PostScript
.9304 .90935 m
.95004 .97106 L
s
% Start of user PostScript
4. 0.857143 4.08663 1.12941 MAarrowhead1
% End of user PostScript
.9304 1.00649 m
.95279 1.06725 L
s
% Start of user PostScript
4. 1.28571 4.09877 1.55381 MAarrowhead1
% End of user PostScript
.9304 1.10362 m
.95636 1.16295 L
s
% Start of user PostScript
4. 1.71429 4.11452 1.97604 MAarrowhead1
% End of user PostScript
.9304 1.20076 m
.9611 1.25778 L
s
% Start of user PostScript
4. 2.14286 4.13546 2.39442 MAarrowhead1
% End of user PostScript
.9304 1.29789 m
.96754 1.35094 L
s
% Start of user PostScript
4. 2.57143 4.16385 2.80549 MAarrowhead1
% End of user PostScript
.9304 1.39503 m
.97619 1.44082 L
s
% Start of user PostScript
4. 3. 4.20203 3.20203 MAarrowhead1
% End of user PostScript
.015 w
.02381 1.39503 m
.06059 1.29601 L
.1007 1.2111 L
.13837 1.14989 L
.17459 1.10533 L
.19478 1.08579 L
.21315 1.07097 L
.23245 1.05817 L
.25027 1.04869 L
.2685 1.04112 L
.27871 1.03777 L
.28828 1.03516 L
.29759 1.03311 L
.30611 1.03164 L
.31557 1.03043 L
.32078 1.02996 L
.32334 1.02977 L
.32574 1.02962 L
.32804 1.02951 L
.33053 1.02941 L
.33163 1.02938 L
.33279 1.02935 L
.33387 1.02932 L
.33487 1.02931 L
.33602 1.02929 L
.33726 1.02929 L
.33841 1.02929 L
.3395 1.02929 L
.34012 1.0293 L
.34077 1.0293 L
.34194 1.02932 L
.3432 1.02934 L
.34459 1.02938 L
.34686 1.02946 L
.34894 1.02955 L
.35362 1.02981 L
.35775 1.03012 L
.3621 1.03052 L
.37118 1.0316 L
.38089 1.0331 L
.39837 1.03666 L
.41869 1.04208 L
.43788 1.04838 L
.47449 1.06324 L
.51344 1.08259 L
.55095 1.10416 L
.58702 1.12719 L
.62542 1.15382 L
.66238 1.18118 L
.70167 1.21185 L
Mistroke
.73952 1.24269 L
.77592 1.27338 L
.81466 1.30696 L
.85196 1.34006 L
.8916 1.37593 L
.92979 1.41106 L
.9304 1.41163 L
Mfstroke
.02381 .94173 m
.04171 .92521 L
.06059 .91061 L
.08135 .89764 L
.1007 .88821 L
.1182 .88172 L
.13692 .87674 L
.14665 .87491 L
.15177 .87414 L
.1572 .87347 L
.16195 .873 L
.16446 .8728 L
.16717 .87261 L
.16965 .87247 L
.17192 .87237 L
.17421 .87229 L
.17534 .87225 L
.17638 .87223 L
.17756 .87221 L
.17818 .8722 L
.17884 .8722 L
.17995 .87219 L
.18116 .87219 L
.18224 .87219 L
.18341 .8722 L
.1845 .87221 L
.1855 .87223 L
.18789 .87229 L
.18925 .87234 L
.1905 .87239 L
.19523 .87263 L
.19926 .87291 L
.20372 .8733 L
.21273 .87432 L
.22234 .87575 L
.23115 .87736 L
.251 .88199 L
.28872 .8942 L
.325 .90965 L
.36361 .92946 L
.40078 .95132 L
.44028 .97708 L
.47834 1.00398 L
.51496 1.0315 L
.55391 1.06225 L
.59142 1.09309 L
.62748 1.12371 L
.66588 1.15718 L
.70284 1.19013 L
.74213 1.22581 L
Mistroke
.77998 1.26073 L
.81639 1.29474 L
.85513 1.33133 L
.89243 1.36687 L
.9304 1.40333 L
Mfstroke
.02381 .71509 m
.02493 .71509 L
.02595 .7151 L
.02712 .71511 L
.02823 .71513 L
.03021 .71517 L
.03235 .71524 L
.03472 .71534 L
.03722 .71547 L
.04171 .71577 L
.05069 .71662 L
.06059 .71791 L
.07056 .71959 L
.0813 .7218 L
.1007 .72677 L
.13994 .74034 L
.17774 .75729 L
.21409 .77661 L
.25279 .79994 L
.29003 .82468 L
.32962 .85304 L
.36776 .88208 L
.40445 .91135 L
.44349 .94369 L
.48108 .97584 L
.51722 1.00755 L
.5557 1.04202 L
.59274 1.07578 L
.63211 1.11222 L
.67004 1.14776 L
.70653 1.1823 L
.74535 1.21937 L
.78273 1.25532 L
.81866 1.29009 L
.85693 1.3273 L
.89376 1.36327 L
.9304 1.39918 L
s
.02381 .03514 m
.06059 .13982 L
.1007 .24244 L
.13837 .32955 L
.17459 .40617 L
.21315 .48119 L
.25027 .548 L
.28972 .61412 L
.32773 .67378 L
.3643 .72802 L
.4032 .78284 L
.44066 .83324 L
.47668 .87984 L
.51503 .92776 L
.55194 .97247 L
.59118 1.01872 L
.62898 1.06222 L
.66534 1.10323 L
.70403 1.14611 L
.74127 1.18678 L
.78086 1.22943 L
.819 1.27005 L
.85569 1.30878 L
.89473 1.34964 L
.9304 1.38673 L
s
0 0 m
1 0 L
1 1.47596 L
0 1.47596 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{283.625, 333.812},
  ImageMargins->{{0, 0}, {0, 0.625}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005R0001XB000`400?l00000o`00003o;Oooool0
0ol0003oooooooooo`3ooooooc?ooooo000]ooooo`03o`000?oooooooooo0?oooooo<oooool002go
oooo00?o0000ooooooooool0oooooolcooooo`00;Oooool00ol0003oooooooooo`3ooooooc?ooooo
000]ooooo`03o`000?oooooooooo0?oooooo<oooool002gooooo00?o0000ooooooooool0oooooolc
ooooo`00;Oooool00ol0003oooooooooo`3ooooooc?ooooo000Sooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`3ooooooc?ooooo000Sooooo`05oa0@4?nj^[[oooooogMg
Molb<S801Oooool00ol0003oooooooooo`3ooooooc?ooooo000Kooooo`Ko00001_ooool01?l0003o
ooooooooooooool4o`000?oooooo=?ooool002Kooooo00?oZJVYoa0@4?ooool00_ooool5o`0000oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`009Oooool00ol@413o0000
okZj^P03ooooo`Go00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo
000Vooooo`03okZj^_lQ8B7ooooo00;ooooo1Ol0000?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0?oooool002?ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`Go00004?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo000Sooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01?ooool5o`0000oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0oooooo`00;?ooool5o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0n
ooooo`00;?ooool5o`00013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0noooo
o`00;Oooool5o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0nooooo`00
;Oooool5o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0nooooo`00;Ooo
ool5o`00013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0nooooo`00;Oooool6
o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0nooooo`00;Oooool6o`00
00oooooo0_l0000?ooooo`;o00003oooool3o`0000oooooo0_l0000>ooooo`?o00003_ooool3o`00
00oooooo0_l0000?ooooo`;o00003oooool3o`0000kooooo0ol0000?ooooo`;o00003oooool2o`00
00oooooo0_l0000?ooooo`?o0000?_ooool002gooooo1_l0000>ooooo`?o00003_ooool3o`0000ko
oooo1?l0000=ooooo`Co00003Oooool4o`0000gooooo1?l0000>ooooo`?o00003_ooool3o`0000ko
oooo1?l0000=ooooo`Co00003Oooool4o`0000kooooo0ol0000>ooooo`?o00003_ooool4o`0003ko
oooo000]ooooo`03o`000?oooooo000000Co00003Oooool3o`0000kooooo0ol0000>ooooo`Co0000
3Oooool4o`0000gooooo1?l0000=ooooo`Co00003_ooool3o`0000kooooo0ol0000>ooooo`Co0000
3Oooool4o`0000gooooo1?l0000>ooooo`?o00003_ooool3o`0000kooooo1?l0000nooooo`00;Ooo
ool00ol0003oooooo`000004o`0000kooooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo0ol0
000>ooooo`?o00003_ooool3o`0000oooooo0_l0000?ooooo`;o00003oooool3o`0000kooooo0ol0
000>ooooo`?o00003oooool2o`0000oooooo0_l0000?ooooo`?o0000?_ooool002gooooo00?o0000
ooooool000001Ol0000>ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2
o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00004?ooool2
o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0003oooooo000]ooooo`03o`000?oooooooooo
00Go00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`;o00003oooool2o`0000oooooo0_l0000?oooo
o`;o00003oooool2o`0000oooooo0_l0000@ooooo`;o00003oooool2o`0000oooooo0_l0000?oooo
o`;o0000?oooool002gooooo00?o0000ooooooooool01Ol0001Cooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03go
oooo000]ooooo`04o`000?ooooooooooooooo`Go0000ooooool]ooooo`00;Oooool01?l0003ooooo
ooooooooool5o`000?oooooo;Oooool002gooooo00Co0000oooooooooooooooo1Ol0003oooooobgo
oooo000]ooooo`03o`000?oooooooooo00;ooooo1Ol0003oooooobcooooo000]ooooo`03o`000?oo
oooooooo00;ooooo1Ol0003oooooobcooooo000]ooooo`03o`000?oooooooooo00;ooooo1Ol0003o
ooooobcooooo000]ooooo`;o00001?ooool5o`000?oooooo:oooool002gooooo00?o0000oooooooo
ool00oooool5o`000?oooooo:oooool002gooooo00?o0000ooooooooool00oooool5o`0000Oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`00;Oooool00ol0003ooooooooo
o`04ooooo`Go00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo000]
ooooo`;o00001Oooool5o`0000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0o
ooooo`00;Oooool2o`0000Gooooo1_l00006ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0?oooool002gooooo00?o0000ooooool000001Oooool5o`0000Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0oooooo`00;Oooool00ol0003oooooo`000005ooooo`Go0000
1_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo000]ooooo`03o`000?oo
oooo000000Kooooo1Ol00006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_oo
ool002gooooo00Co0000oooooooooooo00001Oooool5o`0000Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0nooooo`00;Oooool01?l0003oooooooooool00005ooooo`Ko00001Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo000]ooooo`05o`000?oooooo
ooooooooool000001Oooool5o`0000Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0nooooo`00;Oooool2o`0000;ooooo0ol00003ooooo`Go00001_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03kooooo000]ooooo`03o`000?oooooooooo00Co00001?ooool5o`00
00Cooooo1?l0000=ooooo`Co00003Oooool4o`0000oooooo0_l0000?ooooo`;o00003oooool2o`00
00oooooo0_l0000?ooooo`?o00003_ooool3o`0000kooooo0ol0000?ooooo`;o00003oooool2o`00
00oooooo0ol0000>ooooo`?o0000?_ooool002gooooo00?o0000ooooooooool01?l00004ooooo`Go
00001?ooool4o`0000gooooo1?l0000=ooooo`Co00003Oooool4o`0000gooooo1?l0000>ooooo`?o
00003_ooool3o`0000kooooo1?l0000=ooooo`Co00003Oooool4o`0000kooooo0ol0000>ooooo`?o
00003_ooool4o`0000gooooo1?l0000nooooo`00;Oooool01?l0003oooooooooooooool3o`0000Co
oooo1_l00004ooooo`?o00003_ooool3o`0000kooooo0ol0000=ooooo`Co00003Oooool4o`0000ko
oooo0ol0000>ooooo`?o00003_ooool4o`0000gooooo1?l0000=ooooo`Co00003_ooool3o`0000ko
oooo0ol0000>ooooo`Co00003Oooool4o`0003kooooo000]ooooo`03o`000?oooooooooo00;ooooo
0ol00004ooooo`Go00001Oooool2o`0000oooooo0_l0000?ooooo`;o00003_ooool3o`0000kooooo
0ol0000?ooooo`;o00003oooool2o`0000oooooo0ol0000>ooooo`?o00003_ooool3o`0000oooooo
0_l0000?ooooo`;o00003oooool3o`0000kooooo0ol0000nooooo`00;Oooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool6o`0000Cooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0
000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`00013ooooo0_l0
000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o0000?oooool002gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`Go00001Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool2o`0000oooooo0_l0000?
ooooo`;o00004?ooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000o
ooooo`00;Oooool00ol0003oooooooooo`0:ooooo`Go0000Joooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03gooooo000]ooooo`03o`000?oooooooooo00_ooooo1Ol0003oooooob?o
oooo000]ooooo`03o`000?oooooooooo00_ooooo1Ol0003oooooob?ooooo000]ooooo`03o`000?oo
oooooooo00_ooooo1_l0003oooooob;ooooo000]ooooo`03o`000?oooooooooo00cooooo1Ol0003o
ooooob;ooooo000]ooooo`;o00003Oooool5o`000?oooooo8_ooool002gooooo00?o0000oooooooo
ool03Oooool5o`000?oooooo8Oooool002gooooo00?o0000ooooooooool03Oooool5o`000?oooooo
8Oooool002gooooo00?o0000ooooooooool03Oooool6o`000?oooooo8?ooool002gooooo00?o0000
ooooooooool03_ooool5o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?oooool002gooooo00?o0000oooo
ooooool03_ooool5o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?oooool002gooooo0_l0000@ooooo`Go
00003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0oooooo`00;Oooool2o`00013ooooo1Ol0000=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03oooooo000]ooooo`03o`000?oooooo000000oooooo1_l0000<ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03oooooo000]ooooo`03o`000?oooooo0000013ooooo1Ol0000=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03kooooo000Sooooo`Go00001Oooool01?l0003oooooooooool0000?ooooo`Ko00003?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0nooooo`008oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00Co0000
oooooooooooo00004?ooool5o`0000cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool001_ooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol000000ooooooo0000ooooo`0>ooooo`Go00003Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0nooooo`009Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool5o`0000cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0?_ooool002Ko
oooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`02ooooo`?o00003Oooool5o`0000go
oooo0_l0000?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0nooooo`009oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Co
00003Oooool6o`0000_ooooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo0ol0000?ooooo`;o
00004?ooool2o`0000oooooo0_l0000>ooooo`?o00003_ooool3o`0000oooooo0_l0000?ooooo`;o
00003oooool3o`0000kooooo0ol0000nooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@00Go
oooo00?o0000ooooooooool00_ooool3o`0000gooooo1_l0000;ooooo`?o00003_ooool3o`0000ko
oooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo1?l0000=ooooo`Co00003Oooool4o`0000go
oooo1?l0000>ooooo`?o00003_ooool3o`0000kooooo1?l0000=ooooo`Co0000?_ooool002?ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo00?ooooo0ol0000=ooooo`Ko
00002oooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000kooooo0ol0000>ooooo`Co
00003Oooool4o`0000gooooo1?l0000=ooooo`Co00003_ooool3o`0000kooooo0ol0000>ooooo`Co
00003Oooool4o`0003kooooo000]ooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`Go0000
3?ooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000kooooo0ol0000>ooooo`?o0000
3_ooool3o`0000kooooo0ol0000>ooooo`?o00003oooool2o`0000oooooo0_l0000?ooooo`?o0000
3_ooool3o`0003kooooo000]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?oo
ool5o`0000cooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00003ooo
ool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00003ooo
ool2o`0000oooooo0_l0000oooooo`00;Oooool00ol0003oooooooooo`0Eooooo`Go00003?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2
o`0000oooooo0_l0000oooooo`00;Oooool00ol0003oooooooooo`0Eooooo`Go0000Poooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0?Oooool002go
oooo00?o0000ooooooooool05Oooool6o`000?oooooo6?ooool002gooooo00?o0000ooooooooool0
5_ooool5o`000?oooooo6?ooool002gooooo0_l0000Gooooo`Ko0000oooooolGooooo`00;Oooool0
0ol0003oooooooooo`0Gooooo`Go0000oooooolGooooo`00;Oooool00ol0003oooooooooo`0Goooo
o`Go0000oooooolGooooo`00;Oooool00ol0003oooooooooo`0Hooooo`Go0000oooooolFooooo`00
;Oooool00ol0003oooooooooo`0Hooooo`Go0000oooooolFooooo`00;Oooool00ol0003ooooooooo
o`0Hooooo`Ko0000oooooolEooooo`00;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo1Ol00002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo000]ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01oooool6o`000003ooooool0003ooooo00oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo000]ooooo`;o
00004Oooool00ol0003oooooooooo`07ooooo`Go00000_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`00
;Oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo00Oooooo1_l000000ooooooo0000
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0oooooo`00;Oooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00Oooooo1Ol0
0002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03kooooo000]ooooo`04o`000?ooooooooooo`00013ooooo00?o
0000ooooooooool01oooool6o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo000]ooooo`;o00000_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo1Ol00002ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03kooooo000]ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`07
ooooo`Ko000000?oooooo`000?ooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0?_ooool002gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo1Ol00002ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03kooooo000]ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o00003Oooool00ol0
003oooooooooo`07ooooo`Ko000000?oooooo`000?ooool03oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool002gooooo00?o0000oooooooo
ool00oooool3o`0000gooooo0ol00008ooooo`Go000000Coooooo`000?l0003o00003_ooool3o`00
00kooooo0ol0000>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo000]ooooo`03o`000?oooooooooo00;o
oooo1?l0000=ooooo`?o00002?ooool5o`000004ooooool0003o0000o`0000gooooo1?l0000=oooo
o`Co00003Oooool4o`0000gooooo1?l0000=ooooo`Co00003oooool2o`0000oooooo0_l0000?oooo
o`;o00003oooool2o`0000oooooo0ol0000>ooooo`?o00003oooool2o`0003kooooo000]ooooo`03
o`000?oooooooooo00Cooooo0ol0000<ooooo`?o00002Oooool8o`0000gooooo1?l0000=ooooo`Co
00003Oooool4o`0000gooooo1?l0000=ooooo`Co00003Oooool4o`0000kooooo0ol0000>ooooo`?o
00003_ooool3o`0000kooooo1?l0000=ooooo`Co00003Oooool4o`0003kooooo000]ooooo`03o`00
0?oooooooooo00Gooooo0_l0000=ooooo`?o00002?ooool5o`000004ooooool0003o0000o`0000go
oooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo0ol0000>ooooo`?o00003Oooool4o`0000ko
oooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo1?l0000=ooooo`Co00003Oooool4o`0003ko
oooo000]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool2o`0000Sooooo
1_l000000ooooooo0000o`00000>ooooo`?o00003_ooool2o`0000oooooo0_l0000?ooooo`;o0000
3oooool2o`0000kooooo0ol0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`?o0000
3_ooool3o`0000kooooo0ol0000nooooo`00;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Oooooo1Ol00002ooooo`03o`000?oooooooooo00gooooo0_l0000>ooooo`;o00003ooo
ool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00003ooo
ool2o`0000oooooo0_l0000@ooooo`;o00003oooool2o`0003kooooo000]ooooo`03o`000?oooooo
oooo023ooooo1_l0000Booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`;o00004?ooool2o`0000oooooo0_l0000nooooo`00;Oooool00ol0
003oooooooooo`0Qooooo`Go0000Z_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0??ooool002gooooo00?o0000ooooooooool08Oooool6o`000?oo
oooo3?ooool002gooooo0_l0000Sooooo`Go0000ooooool<ooooo`00;Oooool00ol0003ooooooooo
o`0Rooooo`Ko0000ooooool;ooooo`00;Oooool00ol0003oooooooooo`0Sooooo`Go0000ooooool;
ooooo`00;Oooool00ol0003oooooooooo`0Sooooo`Ko0000ooooool:ooooo`00;Oooool00ol0003o
ooooooooo`0Tooooo`Go0000ooooool:ooooo`00;Oooool00ol0003oooooooooo`0Tooooo`Ko0000
ooooool9ooooo`00;Oooool00ol0003oooooooooo`0Uooooo`Go0000ooooool9ooooo`00;Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool6
o`0000Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03oooooo000]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`Go00001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0?oooool002gooooo0_l0000Aooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool6o`0000Kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03oooooo000]ooooo`03o`000?oooooo0000017ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`Go00001_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0?oooool002gooooo00Co
0000oooooooooooo00004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
1_l00006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0nooooo`00;Oooool2o`0000;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo1Ol00006ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0nooooo`00;Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`Ko00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0?_ooool002gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool5o`0000Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo000]ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo1_l00006ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0nooooo`00;Oooool00ol0003oooooooooo`04ooooo`?o
00003Oooool3o`0000kooooo0ol00002ooooo`Go00001oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool002gooooo00?o0000ooooooooool0
1?ooool4o`0000cooooo0ol0000>ooooo`?o00000_ooool6o`0000Kooooo0ol0000>ooooo`;o0000
3oooool2o`0000oooooo0_l0000?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
?Oooool002gooooo00?o0000ooooooooool01_ooool2o`0000gooooo0ol0000<ooooo`Co00000ooo
ool5o`0000Gooooo1?l0000=ooooo`?o00003_ooool3o`0000kooooo0ol0000>ooooo`?o00003_oo
ool3o`0000kooooo0ol0000>ooooo`Co00003oooool2o`0000oooooo0_l0000?ooooo`;o00003ooo
ool2o`0003kooooo000]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2
o`0000gooooo0ol00003ooooo`Ko00001Oooool3o`0000gooooo0ol0000>ooooo`?o00003_ooool3
o`0000kooooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo1?l0000=ooooo`Co00003Oooool4
o`0000gooooo1?l0000>ooooo`?o0000?_ooool002gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0ol00003ooooo`Go00001_ooool3o`00
00gooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`00
00oooooo0ol0000=ooooo`Co00003Oooool4o`0000gooooo1?l0000>ooooo`?o0000?_ooool002Co
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool03?ooool2o`0000?ooooo1_l00006ooooo`;o00003_ooool2o`0000oooooo0_l0000?ooooo`;o
00003oooool2o`0000oooooo0_l0000>ooooo`;o00004?ooool2o`0000kooooo0ol0000>ooooo`?o
00003_ooool3o`0000oooooo0_l0000nooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool00_ooool5o`0000Oooooo00?o0000ooooooooool0
3?ooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000>ooooo`;o0000
4?ooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000nooooo`006ooo
ool6o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`Ko00005_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0=ooooo`;o0000?_ooool002Kooooo00?o0000ooooooooool01?ooool3
o`0002kooooo1Ol00030ooooo`03o`000?oooooooooo03cooooo000Vooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0;_ooool6o`000?kooooo000Vooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0;oooool6o`000?gooooo000Vooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;oooool6o`000?gooooo000Tooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool0<?ooool6o`000?cooooo000]ooooo`03o`000?oooooooooo037ooooo1Ol0003l
ooooo`00;Oooool00ol0003oooooooooo`0aooooo`Ko0000noooool002gooooo00?o0000oooooooo
ool0<_ooool5o`000?_ooooo000]ooooo`;o00004?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo1ol0000;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
?oooool002gooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooool000001?l0000;ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0?oooool002gooooo00Co0000oooooooooooo00003oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo1ol0000;ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0?oooool002gooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool7o`0000[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0oooooo`00;Oooool2o`0000?ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo1ol0000;ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0?_ooool002gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool7o`00
00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0nooooo`00;Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooo000000Co00002_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03kooooo000]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo1ol0000:ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0?_ooool002gooooo00?o0000ooooooooool01_oo
ool2o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`Ko00002_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo000]ooooo`03o`000?oooooo
oooo00Kooooo0ol0000=ooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`Oo00002_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo000]ooooo`03o`000?oooooooooo
00Sooooo0_l0000;ooooo`?o00003_ooool3o`0000kooooo1_l0000:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0?Oooool002gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0;ooooo`;o00003Oooool3o`0000gooooo2?l0000:ooooo`;o00003oooool2o`0000ko
oooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03gooooo000]ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool2o`0000gooooo0ol0000=ooooo`So00002?ooool3o`0000gooooo
1?l0000=ooooo`Co00003Oooool4o`0000gooooo1?l0000=ooooo`Co00003Oooool4o`0000gooooo
1?l0000=ooooo`Co00003_ooool3o`0000kooooo0ol0000nooooo`00;Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Oo00002?ooool3o`0000kooooo0ol0
000=ooooo`Co00003Oooool4o`0000gooooo1?l0000=ooooo`Co00003Oooool4o`0000gooooo1?l0
000=ooooo`Co00003_ooool3o`0000kooooo0ol0000nooooo`00;Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool7o`0000Sooooo0ol0000>
ooooo`?o00003Oooool3o`0000kooooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo0ol0000>
ooooo`?o00003_ooool3o`0000oooooo0_l0000?ooooo`;o0000?_ooool002gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0=ooooo`Ko00002Oooool2o`0000oooooo0_l0000>oooo
o`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?oooo
o`;o00003oooool2o`0000oooooo0_l0000nooooo`00;Oooool2o`0003cooooo1_l00009ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool2o`0000oooooo0_l0000?ooooo`;o
00003oooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o
0000?_ooool002gooooo00?o0000ooooooooool0??ooool6o`0002Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03cooooo000]ooooo`03o`000?oo
oooooooo03cooooo1_l0003`ooooo`00;Oooool00ol0003oooooooooo`0mooooo`Ko0000koooool0
02gooooo00?o0000ooooooooool0?_ooool5o`000>oooooo000]ooooo`03o`000?oooooooooo03ko
oooo1_l0003^ooooo`00;Oooool00ol0003oooooooooo`0oooooo`Ko0000kOooool002gooooo00?o
0000ooooooooool0?oooool6o`000>gooooo000]ooooo`03o`000?oooooooooo043ooooo1_l0003/
ooooo`00;Oooool00ol0003oooooooooo`11ooooo`Go0000k?ooool002gooooo0_l0000@ooooo`;o
00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo1_l0000=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03oooooo000]ooooo`04o`000?oooooo0000o`00013ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo1_l0000<ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03oooooo000]ooooo`;o00000_ooool3o`0000kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo1_l0000=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03oooooo000]ooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`Ko00003?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0nooooo`00;Oooool00ol0003oooooooooo`06ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`Ko00003?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0nooooo`00;Oooool00ol0003oooooooooo`08oooo
o`Co00002_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool6o`0000cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool002gooooo00?o0000oooooooo
ool02?ooool5o`0000[ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo1_l0000<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo000]ooooo`03o`00
0?oooooooooo00cooooo0_l0000:ooooo`;o00003?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo1_l0000;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo000]ooooo`03o`000?oo
oooooooo01Sooooo0ol0000<ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03?oo
ool7o`0000_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0?Oooool002gooooo00?o0000ooooooooool06?ooool4
o`0000cooooo0_l0000>ooooo`03o`000?oooooo000000cooooo1_l0000;ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03gooooo000]ooooo`03o`000?oooooooooo01[ooooo0ol0000:ooooo`Co00003Oooool3o`00
00gooooo1_l0000;ooooo`?o00003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0?Oooool002gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`09ooooo`?o00003?ooool4o`0000cooooo1ol0000:ooooo`?o00003_ooool2o`0000oo
oooo0_l0000?ooooo`;o00003oooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0mooooo`00;Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo
0_l0000=ooooo`Ko00002Oooool4o`0000gooooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo
0ol0000>ooooo`?o00003_ooool3o`0000kooooo0ol0000>ooooo`?o00003_ooool4o`0003gooooo
000]ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`Ko00002Oooool3o`0000kooooo0ol0000=ooooo`?o00003_ooool3o`0000kooooo0ol0
000>ooooo`?o00003_ooool3o`0000kooooo0ol0000>ooooo`?o00003_ooool4o`0003gooooo000]
ooooo`;o0000>Oooool5o`0000kooooo1_l00009ooooo`?o00003_ooool2o`0000Oooooo1Ol00002
ooooo`?o00003_ooool2o`0000oooooo0_l0000?ooooo`;o000000GoV9RHoa0@4?l0003o<S8bolc<
c00:ooooo`;o00003oooool2o`0000oooooo0_l0000<ooooo`;o000000Co410@o`000?l0003o0000
?Oooool002gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0>ooooo`Ko00002_oo
ool2o`0000oooooo00?o0000ooooooooool01Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l000001?nj^[[oooooogMgMolb<S8:ooooo`;o
00003oooool2o`0000oooooo0_l0000=ooooo`03o`000?oooooooooo00;o0000?Oooool002gooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`Ko00002_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003ooooo
ooooo`0=ooooo`;o00003oooool2o`0000oooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo
0_l0000?ooooo`;o00003oooool2o`0000[ooooo1Ol000000ooooooo0000o`00000mooooo`00;Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo1_l0000Sooooo`03oiRHV?lQ
8B7ok^k^01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`05o`000?oo
ooooooooojVYZOl@41002oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02?ooool01?m4A4CogMgMooooool00003ooooo`03o`000?oooooooooo03_o
oooo000]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04?ooool6o`0002Cooooo
00?oMgMgofIVI_ooool0>?ooool00ol@413o0000okZj^P0hooooo`04omgMgOmEEEGoooooo`00047o
oooo000]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04Oooool6o`0002Cooooo
00?o0000ooooooooool0>?ooool00onj^[[o8B4Qooooo`0hooooo`03ogMgMoo<c<co0000047ooooo
000]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04_ooool5o`00023ooooo00Go
0000okZj^_ooooooV9RHoa0@400gooooo`05oa0@4?nHV9SooooookZj^_l00000>Oooool00oo^k^ko
A4A4o`000011ooooo`00;Oooool00ol0003oooooooooo`0hooooo`03oeEEEOmVIVKo000001Cooooo
1_l0000Oooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0=oooool01OnYZJWo410@o`000?l@413oZJVY
03[ooooo00?oMgMgo`000?ooool0@?ooool002gooooo00?o0000ooooooooool0D?ooool6o`000=co
oooo000]ooooo`03o`000?oooooooooo053ooooo1_l0003Looooo`00;Oooool00ol0003ooooooooo
o`1Aooooo`Ko0000]_ooool01OnHV9So0000o`000?m4A4Co^[Zj023ooooo000[ooooo`Oo00001ooo
ool4o`0004Gooooo1Ol0002fooooo`05oa0@4?nj^[[ok^k^ogMgMol@41008?ooool002Ooooooool0
000=o`0000[ooooo00?o0000ooooooooool08_ooool002_ooooo5Ol00002ooooo`?o000000?ooooo
o`000?ooool02_ooool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002oooool7o`0000Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooo`00000;ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;o
oooo000[oooooaSo00000_ooool3o`0000;ooooo0_l00008ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
1_l0000=ooooo`03o`000?oooooooooo00kooooo0_l0000@ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Rooooo`00;Oooool00ol0003oooooo`00
000Fo`0000;ooooo1_l00007ooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo1_l0000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Gooooo`03oa0@4?l0003o000000?o00008Oooool002gooooo00?o0000
ooooooooool02?oooolAo`000003ooooool0003o000000?o00002?ooool2o`0000gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`Go00003Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0R
ooooo`00;Oooool00ol0003oooooooooo`0=oooooa?o00002Oooool00ol0003oooooo`00000;oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool6o`0000gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool08_ooool002gooooo00?o0000ooooooooool04?ooool?o`0000_ooooo0ol0000;ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo000]ooooo`03o`00
0?oooooooooo01?ooooo3_l00009ooooo`Co00002oooool00ol0003oooooo`00000=ooooo`03o`00
0?oooooooooo00[ooooo1ol0000<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0mooooo`00;Oooool00ol0003oooooooooo`0Fooooo`ko00001_oo
ool5o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo1_l0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0mooooo`00;Oooool0
0ol0003oooooooooo`0Iooooo`go00002?ooool2o`0000Wooooo1?l0000=ooooo`;o00003?ooool6
o`0000cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03gooooo000]ooooo`03o`000?oooooooooo01cooooo3?l0000Cooooo`?o00002oooool3o`00
00gooooo1_l0000<ooooo`;o00003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03gooooo000]ooooo`03o`000?oooooooooo01kooooo3?l0000Cooooo`03o`000?oooooooooo00_o
oooo0_l0000<ooooo`Oo00002_ooool3o`0000oooooo0_l0000?ooooo`;o00003_ooool3o`0000ko
oooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0?Oooool002gooooo00?o0000ooooooooool08Oooool;o`0001;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`Ko00002oooool3o`0000gooooo
0ol0000=ooooo`Co00003Oooool4o`0000gooooo1?l0000=ooooo`Co00003Oooool4o`0000gooooo
1?l0000=ooooo`Co0000?Oooool002gooooo0_l0000Tooooo`_o00008?ooool00ol0003ooooooooo
o`0:ooooo`Ko00002oooool2o`0000gooooo0ol0000>ooooo`?o00003Oooool4o`0000gooooo1?l0
000=ooooo`Co00003Oooool4o`0000gooooo1?l0000=ooooo`Co0000?Oooool002gooooo00?o0000
ooooooooool09Oooool:o`0002gooooo1_l0000;ooooo`03o`000?oooooooooo00cooooo0ol0000>
ooooo`?o00003Oooool3o`0000kooooo0ol0000>ooooo`?o00003_ooool3o`0000kooooo0ol0000>
ooooo`?o0000?Oooool002gooooo00?o0000ooooooooool09oooool:o`0002_ooooo1_l0000<oooo
o`03o`000?oooooooooo00cooooo0_l0000?ooooo`;o00003_ooool2o`0000oooooo0_l0000?oooo
o`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o0000?Oooool002gooooo00?o0000oooooooo
ool0:Oooool:o`0002[ooooo1_l0000Kooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03?ooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000?ooooo`;o
0000?Oooool002gooooo00?o0000ooooooooool0:oooool:o`0002Wooooo1_l0000kooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0kooooo`00;Ooo
ool00ol0003oooooooooo`0/ooooo`_o00009oooool7o`000<gooooo000]ooooo`03o`000?oooooo
oooo02kooooo2_l0000Wooooo`Ko0000cOooool002gooooo00?o0000ooooooooool02?ooool6o`00
02;ooooo2_l0000Vooooo`Ko0000c?ooool002gooooo00?o0000ooooooooool02?ooool4o`0002Ko
oooo2_l0000Uooooo`Ko0000boooool002gooooo00?o0000ooooooooool01_ooool5o`0002Wooooo
2_l0000Sooooo`Oo0000b_ooool002gooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o
0000ooooooooool03_ooool4o`0001Oooooo2_l0000Sooooo`Ko0000b_ooool002gooooo00Co0000
oooooooooooooooo0ol0000Fooooo`Oo00005_ooool:o`0002;ooooo1_l00039ooooo`00;Oooool4
o`0001;ooooo3?l0000Jooooo`Wo00008_ooool6o`000<Sooooo000]ooooo`03o`000?oooooooooo
00oooooo1?l00008ooooo`03o`000?oooooooooo00;ooooo1?l0000=ooooo`;o00002?ooool:o`00
00oooooo00?o0000ooooooooool03Oooool7o`0000cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0oooooo`00;Oooool00ol0003oooooooooo`0Tooooo`Ko00000_ooool2o`0000Go
oooo0_l00007ooooo`[o00003_ooool00ol0003oooooooooo`0>ooooo`Oo00002oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03oooooo000]ooooo`03o`000?oooooooooo02[ooooo
1ol00004ooooo`?o00001_ooool:o`0000gooooo00?o0000ooooooooool03_ooool6o`0000cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`00;Oooool00ol0003ooooooooo
o`0/ooooo`Ko00001_ooool2o`0000Gooooo2_l0000=ooooo`03o`000?oooooooooo00kooooo1_l0
000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool002gooooo00?o0000
ooooooooool0>_ooool2o`000004ooooool0003o0000ooooo`[o00003Oooool00ol0003ooooooooo
o`0>ooooo`Ko00002oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo000]
ooooo`03o`000?oooooooooo03cooooo1?l00002ooooo`[o00003?ooool00ol0003oooooooooo`0=
ooooo`Oo00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo000]oooo
o`03o`000?oooooooooo03cooooo1Ol00002ooooo`_o00002oooool00ol0003oooooooooo`0=oooo
o`Ko00002oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo000]ooooo`03
o`000?oooooooooo043ooooo0_l00003ooooo`[o00002oooool00ol0003oooooooooo`0=ooooo`Ko
00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo000]ooooo`03o`00
0?oooooooooo04Kooooo2_l0000;ooooo`03o`000?oooooo000000gooooo1_l0000;ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0?Oooool002gooooo00?o0000ooooooooool0B?oo
ool9o`0000_ooooo0_l0000=ooooo`Oo00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03gooooo000]ooooo`03o`000?oooooooooo04Wooooo2Ol00009ooooo`Co00003Oooool6
o`0000_ooooo0_l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0?Oooool002gooooo0_l0001;ooooo`Wo00002_ooool3o`00
00_ooooo2?l00009ooooo`?o00003_ooool3o`0000kooooo0_l0000?ooooo`;o00003oooool2o`00
00oooooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`0mooooo`00;Oooool00ol0003o
ooooooooo`1<ooooo`So00002oooool00ol0003oooooooooo`0;ooooo`Oo00002Oooool3o`0000co
oooo1?l0000=ooooo`?o00003_ooool3o`0000kooooo0ol0000>ooooo`?o00003_ooool3o`0000ko
oooo0ol0000mooooo`00;Oooool00ol0003oooooooooo`1=ooooo`So00002oooool00ol0003ooooo
ooooo`0;ooooo`Oo00002Oooool2o`0000gooooo0ol0000=ooooo`?o00003_ooool3o`0000kooooo
0ol0000>ooooo`?o00003_ooool3o`0000kooooo0ol0000mooooo`00;Oooool00ol0003ooooooooo
o`1?ooooo`So00006?ooool6o`0000[ooooo00?o0000ooooooooool03?ooool3o`0000gooooo0ol0
000>ooooo`?o00003_ooool2o`0000oooooo0_l0000?ooooo`;o00003oooool2o`0003gooooo000]
ooooo`03o`000?oooooooooo00Wooooo0_l0000Gooooo`[o00009?ooool8o`0001Sooooo1_l0000:
ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`;o00003oooool2o`0000oooooo0_l0000?
ooooo`;o00003_ooool2o`0000oooooo0_l0000mooooo`00;Oooool00ol0003oooooooooo`08oooo
o`?o00004?oooolKo`0001_ooooo2?l0000Hooooo`Ko00006Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool2o`0000oooooo0_l0000>oooo
o`;o00003oooool2o`0003gooooo000]ooooo`03o`000?oooooooooo00Oooooo0ol0000>ooooob;o
00006?ooool8o`0001Oooooo1ol0001:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03_ooooo000]ooooo`03o`00
0?oooooooooo00Kooooo0ol0000;ooooob[o00005_ooool8o`0001Kooooo1_l0002jooooo`00;Ooo
ool00ol0003oooooooooo`05ooooo`Co00002?oooolEo`0000?ooooo6?l0000Dooooo`So00005_oo
ool6o`000;Wooooo000]ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooo
oooo00Gooooo3ol0000Eoooooa7o00004_ooool8o`0001Kooooo1_l0002hooooo`00;Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo4?l0000Koooooa3o00004?ooool8o`00
01Gooooo1ol0002gooooo`00;Oooool01Ol0003ooooooooooooooooo000000Sooooo3Ol00003oooo
o`03o`000?oooooooooo00kooooo1ol00009ooooo`oo00003oooool8o`0001Cooooo1ol0002foooo
o`00;Oooool2o`000003ooooool0003ooooo00Oooooo3Ol0000Eooooo`Go00003_ooool>o`0000ko
oooo2?l0000Dooooo`Oo0000]Oooool002gooooo00?o0000ooooool000001oooool=o`0001;ooooo
1Ol000000ooooooo0000ooooo`0Cooooo`ko00003?ooool8o`0001Cooooo1ol0002dooooo`00;Ooo
ool2o`0000Oooooo2Ol000000ooooooo0000o`00000@ooooo`Co00005oooool4o`0000?ooooo3Ol0
000;ooooo`So00005?ooool6o`000;Cooooo000]ooooo`03o`000?oooooooooo00Cooooo2Ol00002
ooooo`03o`000?oooooooooo00kooooo0_l0000?oooooaGo000000?oooooo`000?l000002_l00000
0ooooooo0000o`000008ooooo`Wo00004?ooool00ol0003oooooo`000005o`0000Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0?oooool002gooooo00?o0000ooooooooool00oooool9o`00037ooooo1Ol00004oooo
o`ko00000_ooool2o`0000Oooooo2Ol0000?ooooo`03o`000?oooooooooo00Ko00002?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0oooooo`00;Oooool00ol0003oooooooooo`02ooooo`So0000<oooool2o`0000[o
oooo3Ol00002ooooo`03o`000?oooooooooo00Gooooo2Ol0000?ooooo`03o`000?oooooo000000Ko
00002?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0oooooo`00;Oooool01?l0003oooooooooooooool8o`0004?o
oooo3?l000000ooooooo0000o`000006ooooo`Wo00003oooool00ol0003oooooo`000006o`0000So
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0?_ooool002gooooo00?o0000ooooool000001ol00017ooooo`_o0000
0_ooool2o`0000Kooooo2?l0000?ooooo`03o`000?oooooo000000Ko00001oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0nooooo`00;Oooool9o`0004Sooooo3Ol00002ooooo`03o`000?oooooo000000Cooooo2?l0
000?ooooo`03o`000?oooooo000000Go00002?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0nooooo`009?ooool4
o`000003oa0@4?oooooooooo00;ooooo2?l0001>ooooo`[o000000Coooooo`000?l0003o00001?oo
ool8o`0000oooooo00?o0000ooooool000001Ol00008ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo000V
ooooo`03o`000?oooooooooo00?ooooo2?l0001Aooooo`go00001?ooool8o`000003ooooool0003o
oooo00cooooo00?o0000ooooool000001Ol00007ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo000Voooo
o`03o`000?oooooooooo00;ooooo1ol0001Dooooo`go00001Oooool8o`0000gooooo00?o0000oooo
ool000001_l00007ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03gooooo000Vooooo`03o`000?oooooooooo00;o
oooo1_l0001Gooooo`[o000000?oooooo`000?ooool01?ooool8o`0000gooooo2Ol00007ooooo`03
o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03cooooo000Vooooo`03o`000?oooooooooo00;ooooo1Ol0001Jooooo`Wo0000
1oooool8o`0000_ooooo2ol00006ooooo`?o00003_ooool2o`0000kooooo00?o0000ooooool00000
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0looooo`009_ooool00ol0003oooooooooo`02ooooo`Co0000G?oo
ool:o`0000Kooooo2?l0000<ooooo`Wo00001_ooool4o`0000cooooo0ol0000>ooooo`?o00003ooo
ool2o`0000kooooo0ol0000>ooooo`?o00003_ooool3o`0003cooooo000Vooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0GOooool:o`0000Gooooo2?l0000=ooooo`03o`000?oooooo
000000Go00001_ooool3o`0000gooooo0ol0000=ooooo`?o00003Oooool4o`0000gooooo1?l0000=
ooooo`Co00003Oooool4o`0003cooooo000Tooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooo
ooooool01oooool2o`0005Kooooo2_l00005ooooo`So00003?ooool00ol0003oooooo`000005o`00
00Kooooo0_l0000>ooooo`;o00003Oooool3o`0000kooooo0ol0000=ooooo`Co00003Oooool4o`00
00gooooo1?l0000looooo`00;Oooool00ol0003oooooooooo`06ooooo`?o00004Oooool2o`0004Co
oooo2_l00005ooooo`So00003Oooool7o`0000Kooooo0_l0000>ooooo`03o`000?oooooooooo00co
oooo0ol0000>ooooo`?o00003Oooool3o`0000kooooo0ol0000>ooooo`?o0000??ooool002gooooo
00?o0000ooooooooool01Oooool3o`00013ooooo1?l00016ooooo`[o00001?ooool8o`0000gooooo
1ol00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000oooooo
0_l0000>ooooo`;o00003oooool2o`0000oooooo0_l0000looooo`00;Oooool00ol0003ooooooooo
o`04ooooo`Co00003oooool4o`0001;ooooo0_l0000eooooo`[o00000oooool8o`0000gooooo1ol0
000Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`;o00003oooool2o`0003cooooo000]ooooo`03o`000?oooooooooo00Gooooo0ol0000>
ooooo`Co00004?ooool4o`0003Sooooo2_l00003ooooo`Oo00003Oooool6o`0005Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0jooooo`00;Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo0000013ooooo0ol0000?ooooo`Co0000>_ooool:o`0000?ooooo1ol0000=oooo
o`Ko0000Y?ooool002gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooo0000013ooooo0ol0000Cooooo`?o00009oooool9o`0000?ooooo1ol0000=ooooo`Ko
0000Xoooool002gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooool000004Oooool5o`0002[ooooo2?l00003ooooo`Oo0000
3?ooool7o`000:;ooooo000]ooooo`;o00000oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00oooooo0_l0000Cooooo`Go0000;Oooool8o`0000;ooooo1ol0000<ooooo`Ko0000X_oo
ool002gooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04Oooool2o`0000;ooooo0_l0000_ooooo`So00000_ooool7o`0000cooooo1_l0
002Qooooo`00;Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00kooooo0_l0
000Booooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`Co00007Oooool8o`0000;ooooo1ol0
000<ooooo`Ko0000X?ooool002gooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo0ol0000Gooooo`Oo00006oooool8o`0000;ooooo1ol0000;
ooooo`Oo0000Woooool002gooooo0_l0000Aooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool2o`0001?ooooo3?l0000Oooooo`So000000?oooooo`000?l000001Ol0000;oooo
o`Oo0000W_ooool002gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool4o`0000Sooooo00?o0000oooooooo
ool00_ooool4o`0000gooooo0_l0000<ooooo`So000000?oooooo`000?l000001_l00004ooooo`03
o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0oooooo`00;Oooool00ol0003oooooooooo`1Hooooo`Ko0000
0_ooool2o`0000Gooooo0_l0000;oooooa7o00000oooool00ol0003oooooooooo`04ooooo`Ko0000
1?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
?oooool002gooooo00?o0000ooooooooool0G_ooool7o`0000Cooooo0ol00009oooooa7o00000ooo
ool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0?_ooool002gooooo00?o0000ooooooooool0H?ooool6
o`0000Kooooo0_l00009oooooa3o00000oooool00ol0003oooooooooo`03ooooo`Oo00001?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool0
02gooooo00?o0000ooooooooool0K_ooool2o`000003ooooool0003o000000Gooooo4Ol00002oooo
o`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0nooooo`00;Oooool00ol0003oooooooooo`1<ooooo`_o
00006Oooool4o`0000Kooooo4?l00002ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0mooooo`00
;Oooool00ol0003oooooooooo`14oooooago00003oooool5o`0000Kooooo4?l00002ooooo`03o`00
0?oooooooooo00?ooooo1_l00004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0mooooo`00;Oooool2o`0004;ooooo9?l0000?ooooo`;o00001_oo
ool@o`0000;ooooo00?o0000ooooooooool00_ooool7o`0000Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03gooooo000]ooooo`03o`000?oooooo
oooo03kooooo:_l0000Fooooo`oo00000_ooool00ol0003oooooo`000002ooooo`Oo00001?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0??ooool0
02gooooo00?o0000ooooooooool0??oooolCo`0000Gooooo5_l0000Eooooo`oo00000_ooool2o`00
00?ooooo1ol00004ooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03cooooo000]ooooo`03o`000?oooooooooo03Wooooo3_l0000Gooooo`oo00005?oooolBo`0000?o
oooo1ol00003ooooo`?o00003Oooool3o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0looooo`00;Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02kooooo3Ol0000Nooooo`ko00004_ooool>o`000004oooo
ool0003o0000o`0000?ooooo1ol000000ooooooo0000o`000003o`0000cooooo0ol0000=ooooo`Co
00003_ooool2o`0000oooooo0_l0000?ooooo`;o0000??ooool002gooooo00?o0000ooooooooool0
1Oooool2o`00017ooooo0_l0000Jooooo`go00009?ooool>o`00013ooooo3_l00002ooooo`03o`00
0?oooooooooo00;ooooo1ol00002ooooo`?o00003Oooool3o`0000cooooo1?l0000=ooooo`?o0000
3_ooool3o`0000kooooo0ol0000looooo`00;Oooool00ol0003oooooooooo`04ooooo`?o00004?oo
ool3o`00013ooooo0_l00006ooooo`go0000:?ooool?o`0000kooooo3_l00002ooooo`03o`000?oo
oooooooo00;ooooo1ol00003ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`?o00003Ooo
ool3o`0000kooooo0ol0000>ooooo`?o0000??ooool002gooooo00?o0000ooooooooool00oooool4
o`0000oooooo0ol0000@ooooo`?o00001Oooool;o`0002kooooo3ol0000=ooooo`go00001oooool7
o`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`?o00003Oooool3
o`0000kooooo0ol0000>ooooo`;o0000??ooool002gooooo00?o0000ooooooooool00_ooool4o`00
00oooooo1?l0000?ooooo`?o00001Oooool:o`0000?ooooo0_l0000^ooooo`ko00003?ooool=o`00
00Oooooo1_l0000Cooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`;o00003oooool2o`00
00oooooo0_l0000kooooo`00;Oooool00ol0003oooooooooo`03ooooo`?o00003_ooool5o`0000ko
oooo1?l00004ooooo`So00001?ooool4o`00037ooooo3?l0000<ooooo`go00001oooool6o`0002;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo0_l0000kooooo`00;Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000013ooooo
0_l0000@ooooo`?o00000_ooool8o`0000Gooooo1?l0000eooooo`_o00002oooool=o`0000Oooooo
1_l0001Cooooo`03o`000?oooooooooo03Wooooo000]ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000;ooooo2?l0
0005ooooo`Co00004_ooool4o`0002?ooooo2_l0000;ooooo`go00001Oooool7o`0008kooooo000]
ooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool8o`0000Kooooo1?l0000?ooooo`Ko00009_ooool9o`0000_ooooo3Ol00005
ooooo`Oo0000SOooool002gooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool8o`0000Gooooo0_l00002ooooo`03o`000?oooooo
oooo00kooooo1Ol0000Xooooo`[o00002_ooool=o`0000Gooooo1ol0002<ooooo`00;Oooool01?l0
003oooooooooool0000Booooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo1ol0
0006ooooo`03o`000?oooooooooo01;ooooo1Ol0000[ooooo`[o00002Oooool=o`0000Gooooo1ol0
002;ooooo`00;Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo1ol00006ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooooooo
ooooo`00000@ooooo`Oo00005oooool:o`0000Wooooo3?l00005ooooo`Oo0000R_ooool002gooooo
00?o0000ooooool000004Oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`Oo
00001_ooool00ol0003oooooooooo`0Aooooo`;o00005Oooool5o`0001[ooooo2ol00008ooooo`co
00001Oooool7o`0008Wooooo000]ooooo`;o00004_ooool00ol0003oooooooooo`0>ooooo`04o`00
0?ooooooooooooooo`Oo00001_ooool00ol0003oooooooooo`0@ooooo`;o00004_ooool5o`000003
ooooool0003ooooo01kooooo2ol00007ooooo`co00001Oooool7o`0008Sooooo000]ooooo`;o0000
4Oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooooooo`Oo00001_ooool00ol0003o
ooooooooo`0?ooooo`;o00004?ooool4o`0001Oooooo1?l0000=ooooo`_o00001_ooool<o`0000Go
oooo1ol00027ooooo`00;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo
00Co0000oooooooooooooooo1ol00006ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool2o`0000oooooo5Ol0000:ooooo`[o00001oooool;o`0000Gooooo1_l0000Aooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03oooooo000]ooooo`03o`000?oooooooooo02Cooooo1_l00017ooooo`Go0000
1?ooool3o`0000Wooooo2_l00006ooooo`_o00001Oooool6o`00013ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
?oooool002gooooo00?o0000ooooooooool08oooool6o`0004Sooooo0_l0000:ooooo`?o00000_oo
ool2o`0000Cooooo2Ol00006ooooo`co00001?ooool6o`00013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_oo
ool002gooooo00?o0000ooooooooool08_ooool6o`0005Sooooo1_l00004ooooo`So00001_ooool<
o`0000?ooooo1ol0000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo000]ooooo`03o`000?oooooooooo
027ooooo1ol0001Jooooo`Go00001?ooool9o`0000Gooooo3?l00003ooooo`Oo00004?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0mooooo`00;Oooool2o`00027ooooo1ol0001Kooooo`Ko00001Oooool8o`0000Go
oooo3?l00003ooooo`Oo00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0mooooo`00;Oooool00ol0003ooooo
ooooo`0Oooooo`Oo0000J?ooool9o`0000Cooooo3?l00003ooooo`Ko00004?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0mooooo`00;Oooool00ol0003oooooooooo`0Oooooo`Ko0000J_ooool9o`0000Cooooo3?l0
0003ooooo`Ko00004?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`00;Oooool00ol0003oooooooooo`0N
ooooo`Ko0000KOooool9o`0000?ooooo3?l00003ooooo`Ko000000?oooooo`000?ooool03?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0looooo`00;Oooool00ol0003oooooooooo`0Mooooo`Ko0000Koooool9o`00
00Cooooo2ol00002ooooo`So00003_ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0kooooo`00;Oooool00ol0003o
ooooooooo`0Looooo`Oo0000LOooool8o`0000Cooooo2ol00002ooooo`So00003_ooool2o`0000ko
oooo0_l0000>ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0>oooool002gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`Oo
0000Loooool9o`0000?ooooo3?l000000ooooooo0000o`000006o`0000cooooo1?l0000<ooooo`?o
00003_ooool3o`0000oooooo0_l0000kooooo`00;Oooool00ol0003oooooooooo`04ooooo`;o0000
4?ooool2o`0000;ooooo1ol00007ooooo`;o0000KOooool8o`0000?ooooo3?l000000ooooooo0000
o`000005o`0000kooooo0_l0000=ooooo`?o00003Oooool3o`0000gooooo1?l0000kooooo`00;Ooo
ool00ol0003oooooooooo`03ooooo`?o00003oooool2o`0000?ooooo1_l00007ooooo`?o00004Ooo
ool2o`0005_ooooo2Ol00002ooooo`co000000?oooooo`000?l000001Ol0000>ooooo`03o`000?oo
oooooooo00cooooo0_l0000=ooooo`?o00003_ooool3o`0003_ooooo000]ooooo`03o`000?oooooo
oooo00;ooooo0ol0000?ooooo`?o00000_ooool6o`0000Oooooo0ol0000Aooooo`?o00004Oooool2
o`0004Wooooo2Ol00002ooooo`co000000?oooooo`000?l000001?l0000?ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool3o`0000kooooo0ol0000jooooo`008oooool5o`00
00Gooooo00Co0000oooooooooooooooo1?l0000>ooooo`Co000000?oooooo`000?l000001?l00007
ooooo`Co00004?ooool3o`00013ooooo1?l0001;ooooo`Wo000000?oooooo`000?l000004Ol0000N
ooooo`03o`000?oooooooooo00cooooo0_l0000?ooooo`;o0000>_ooool002?ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oooooo
oooo00Ko00002?ooool3o`0000oooooo1?l0000?ooooo`Co00004_ooool2o`0003Wooooo2Ol00000
0ooooooo0000o`00000Ao`0002gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0h
ooooo`009?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`06o`0000Wooooo0_l0000Aooooo`?o00003_ooool4o`00
013ooooo1?l0000looooo`So000000?oooooo`000?l000004Ol0001hooooo`009Oooool00onHV9So
8B4Qonk^kP05ooooo`?o00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Go
00002Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo0000013ooooo0ol0000?ooooo`Co
0000?_ooool9o`000003ooooool0003o0000013o0000Moooool002Kooooo00?oMgMgofIVI_ooool0
1?ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool01_l00009ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00000@ooooo`?o
00004oooool3o`0002_ooooo2?l000000ooooooo0000o`00000@o`0007Kooooo000Wooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`06o`0000Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooool000004Oooool5o`0002gooooo6ol0001eooooo`008oooool01Ol0003o^[Zj
oooooonHV9So410@00Gooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`06o`00
00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00oooooo0_l0000Cooooo`Go0000;ooooolKo`0007Cooooo000Sooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01Oooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00Ko00002Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Aooooo`;o00000_ooool2o`0003;ooooo2?l000000ooooooo0000o`00000?o`00
07?ooooo000]ooooo`03o`000?oooooo0000017ooooo00?o0000ooooool000001Ol00009ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`;o
00004_ooool2o`0000Cooooo00?o0000ooooooooool03_ooool4o`00023ooooo6_l0001booooo`00
;Oooool2o`00017ooooo00?o0000ooooooooool01_l00009ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
0ol0000Gooooo`Oo00007ooooolIo`00077ooooo000]ooooo`;o00004Oooool00ol0003oooooo`00
0005o`0000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool2o`0001?ooooo3?l0000RoooooaWo0000L?oo
ool002gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05o`0000Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`Co00002?ooool00ol0003oooooooooo`02
ooooo`Co00003Oooool2o`0000oooooo6Ol0000:ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0oooooo`00;Oooool00ol0003oooooooooo`0Aoooo
o`Ko0000MOooool6o`0000;ooooo0_l00005ooooo`;o00003ooooolHo`0000Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo000]ooooo`03
o`000?oooooooooo013ooooo1_l0001looooo`Oo00001?ooool3o`0000gooooo6?l00009ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0nooooo`00
;Oooool00ol0003oooooooooo`0@ooooo`Ko0000OOooool7o`0000Kooooo0_l0000=oooooaOo0000
2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
?_ooool002gooooo0_l0000@ooooo`Ko0000SOooool2o`000003ooooool0003o000000Wooooo5ol0
0009ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0mooooo`00;Oooool00ol0003oooooooooo`0?ooooo`Go0000T?ooool4o`0000Wooooo5ol00009
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0m
ooooo`00;Oooool00ol0003oooooooooo`0>ooooo`Ko0000T?ooool5o`0000[ooooo5_l00008oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0loooo
o`00;Oooool00ol0003oooooooooo`0>ooooo`Go0000UOooool2o`0000[ooooo5_l00008ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0looooo`00
;Oooool00ol0003oooooooooo`0=ooooo`Ko0000X?oooolGo`0000Wooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03_ooooo000]ooooo`03o`000?oo
oooooooo00gooooo1Ol0002ToooooaGo00002Oooool2o`0000kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0jooooo`00;Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo1_l00004ooooo`03o`000?oooooooooo09oooooo5?l00008ooooo`;o00003_ooool3
o`0000kooooo0ol0000jooooo`00;Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo1Ol00005ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1loooooaCo00001_ooool4o`0000gooooo0ol0000=ooooo`Co0000>_ooool002go
oooo00?o0000ooooooooool00oooool2o`0000Kooooo1_l00004ooooo`;o00004?ooool2o`00013o
oooo0_l0000Aooooo`;o0000K?oooolDo`0000Oooooo0ol0000=ooooo`?o00003Oooool3o`0003[o
oooo000]ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`Go00001?ooool3o`0000oooooo
0_l0000@ooooo`;o00004Oooool3o`00013ooooo0_l0001KoooooaCo00002?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool3o`0003Wooooo000]ooooo`04o`000?ooooooooooooooo`?o0000
1_ooool6o`0000?ooooo0ol0000?ooooo`?o00003oooool3o`00013ooooo0ol0000@ooooo`?o0000
G?oooolDo`0000Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`;o0000
>Oooool002gooooo00?o0000ooooooooool01?l00006ooooo`Go00000oooool4o`0000kooooo1?l0
000>ooooo`Co00003oooool4o`0000oooooo0ol0000Booooo`;o0000B_oooolDo`0001Oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0gooooo`00;Oooool2o`0000?ooooo0_l00006
ooooo`Go00001Oooool2o`00013ooooo00?o0000ooooooooool03_ooool2o`0000oooooo1Ol0000>
ooooo`Co00003oooool5o`0004_ooooo5?l0001Pooooo`00;Oooool01Ol0003ooooooooooooooooo
000000Oooooo1Ol00005ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool2
o`00017ooooo0_l0000@ooooo`?o00003_ooool5o`0004gooooo5?l0001Oooooo`00;Oooool01Ol0
003ooooooooooooooooo000000Oooooo1Ol00005ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool000004?ooool3o`0001;ooooo1?l0000ioooooaCo0000G_ooool002gooooo00Co0000oooo
oooooooo00001oooool6o`0000Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooo0000013ooooo1Ol0000loooooaCo0000GOooool002gooooo00Co0000oooo
oooooooo00001oooool5o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`;o00005?ooool3o`0003kooooo5?l0001Looooo`00;Oooool00ol0003oooooo`000007oooo
o`Ko00001?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04_ooool2o`000003ooooool0003ooooo01;ooooo0ol0000ZoooooaCo0000Foooool002go
oooo00?o0000ooooool000001oooool5o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool4o`0002go
oooo5?l0001Jooooo`00;Oooool00ol0003oooooo`000006ooooo`Ko00001Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool2o`0001;ooooo
1_l0000`oooooa?o0000FOooool002gooooo0_l00007ooooo`Go00001Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool2o`00017ooooo0ol0
0004ooooo`03o`000?oooooooooo033ooooo4ol0001Hooooo`00;Oooool2o`0000Kooooo1_l00005
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`;o00004?ooool3o`0001Sooooo1?l0000Ooooooa?o0000Eoooool002gooooo00?o0000oooo
ooooool01Oooool5o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool2o`0000oooooo5?l0000?oooo
o`;o00002ooooolCo`0000;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0ooooo
o`00;Oooool00ol0003oooooooooo`04ooooo`Ko0000Voooool4o`0000Cooooo0ol0000>ooooo`;o
00002ooooolBo`000003ooooool0003ooooo013ooooo00?o0000ooooooooool0?oooool002gooooo
0_l00005ooooo`Go0000W?ooool00ol0003oooooooooo`08ooooo`Co00000_ooool2o`0000Sooooo
00?o0000ooooooooool02OoooolBo`000003ooooool0003ooooo013ooooo00?o0000ooooooooool0
?_ooool002gooooo00?o0000ooooooooool01?ooool5o`000:_ooooo1_l00007ooooo`;o00002_oo
oolAo`0000;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0mooooo`00;Oooool0
0ol0003oooooooooo`03ooooo`Go0000[_ooool5o`0000Sooooo0_l00009oooooa7o00000_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo000]ooooo`03o`000?oooooooooo
00?ooooo1Ol0002^ooooo`Ko00002Oooool00ol0003oooooo`000007oooooa7o00000_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03cooooo000]ooooo`03o`000?oooooooooo00;o
oooo1_l0002nooooo`?o00002?ooool@o`0000;ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0kooooo`00;Oooool00ol0003oooooooooo`02ooooo`Go0000__ooool5o`0000Sooooo
4?l00002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>_ooool002gooooo00?o
0000ooooooooool00_ooool5o`000<7ooooo0ol00008oooooa3o00000_ooool00ol0003oooooo`00
000=ooooo`03o`000?oooooooooo03[ooooo000]ooooo`04o`000?ooooooooooooooo`Go0000aOoo
ool00ol0003oooooooooo`06oooooa3o00000_ooool2o`0000kooooo0ol0000iooooo`00;Oooool0
1?l0003oooooooooooooool5o`0000oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo09[ooooo4ol0000=ooooo`?o0000>Oooool002gooooo00Co0000
oooooooooooooooo1Ol0000?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Wooooo3ol000001?oooooo0000o`00
0?l0000;ooooo`Go0000>?ooool002gooooo00?o0000ooooooooool01Ol0000?ooooo`;o00004?oo
ool2o`00013ooooo0_l0000@ooooo`;o00004?ooool2o`0007[ooooo3ol00002ooooo`03o`000?oo
oooooooo00_ooooo0ol0000hooooo`00;Oooool00ol0003oooooooooo`05o`0000kooooo0_l0000@
ooooo`?o00003oooool3o`0000oooooo0_l0000@ooooo`?o00004Oooool2o`0006Sooooo3ol00002
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool002gooooo2?l0000=oooo
o`?o00003oooool3o`0000oooooo0ol0000?ooooo`?o00003oooool3o`00013ooooo1?l0000Aoooo
o`;o0000E_ooool?o`00017ooooo00?o0000ooooooooool0=Oooool002gooooo00?o0000ooooool0
00001?l0000?ooooo`;o00003_ooool4o`0000kooooo1?l0000>ooooo`Co00003_ooool4o`0000oo
oooo1?l0000@ooooo`Co0000Eoooool?o`0004Sooooo000]ooooo`03o`000?oooooo000000Co0000
3oooool00ol0003oooooooooo`0?ooooo`;o00003oooool00ol0003oooooo`00000@ooooo`03o`00
0?oooooooooo00kooooo0ol0000>ooooo`Go00003oooool4o`0001;ooooo0_l00015ooooo`oo0000
Aoooool002gooooo1_l0000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo0_l0000Aooooo`?o00003_oo
ool4o`00013ooooo1?l00017ooooo`oo0000A_ooool002gooooo1_l0000?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00000@ooooo`?o00003oooool4
o`0004Wooooo3ol00015ooooo`00;Oooool6o`0000oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool000004?ooool3o`00
01?ooooo0ol0000eooooo`oo0000A?ooool002gooooo1Ol0000?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooool000004Oooool5o`0003Oooooo3ol00013ooooo`00;Oooool5o`0000oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool2o`0001?ooooo1Ol0000iooooo`oo0000@_ooool002cooooo1Ol0
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool2o`0000;ooooo0_l0
000kooooo`oo0000@Oooool002cooooo1Ol0000?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo0_l0000B
ooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`Co0000:Oooool?o`00043ooooo000Soooo
o`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool5o`0000oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`?o00005oooool7o`0002Sooooo3Ol00010ooooo`008oooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo1Ol0000@ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool2o`0001?ooooo3?l0000[ooooo`co0000@?ooool002Oooooo00Co0000oooo
oooooooooooo1Ol0000?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`Go00001oooool2o`0000Cooooo1?l0000=ooooo`;o00003oooool2
o`0000Oooooo2ol00010ooooo`009_ooool00onYZJWo410@ooooo`02ooooo`Go0000`?ooool6o`00
00;ooooo0_l00005ooooo`;o00003oooool00ol0003oooooooooo`05ooooo`[o0000@?ooool002Go
oooo00?o410@o`000?nj^[X00oooool4o`000<Oooooo1ol00004ooooo`?o00003Oooool2o`0000Oo
oooo2Ol0000oooooo`009_ooool00onj^[[o8B4Qooooo`04ooooo`03o`000?oooooooooo0<Oooooo
1ol00006ooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`Oo000000?oooooo`000?ooool0
?Oooool002?ooooo00Go410@oiRHV?oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0=Kooooo
0_l000000ooooooo0000o`000009ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`03o`00
0?oooooooooo03_ooooo000Sooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00ol0003ooooo
ooooo`3Hooooo`Co00002Oooool2o`0000Kooooo1Ol00003ooooo`03o`000?oooooooooo03[ooooo
000]ooooo`03o`000?oooooooooo0=Oooooo1_l0000:ooooo`03o`000?oooooo000000Cooooo1?l0
0004ooooo`03o`000?oooooooooo03Wooooo000]ooooo`03o`000?oooooooooo0=_ooooo0ol0000:
ooooo`;o00001?ooool4o`0000Gooooo00?o0000ooooooooool0>?ooool002gooooo00?o0000oooo
ooooool0ioooool4o`0000gooooo0_l0000hooooo`00;Oooool00ol0003oooooooooo`3Yooooo`?o
00003?ooool2o`0003Sooooo000]ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool0
2?ooool4o`0003Oooooo000]ooooo`03o`000?oooooooooo0?Wooooo0ol0000fooooo`00;Oooool2
o`000?gooooo00?o0000ooooooooool0<oooool002gooooo00?o0000ooooooooool0oooooolcoooo
o`00;Oooool00ol0003oooooooooo`3ooooooc?ooooo000]ooooo`03o`000?oooooooooo0?oooooo
<oooool002gooooo00?o0000ooooooooool0oooooolcooooo`00;Oooool00ol0003oooooooooo`3o
oooooc?ooooo000]ooooo`03o`000?oooooooooo0?oooooo<oooool002gooooo00?o0000oooooooo
ool0oooooolcooooo`00;Oooool00ol0003oooooooooo`3ooooooc?ooooo000]ooooo`03o`000?oo
oooooooo0?oooooo<oooool002gooooo00?o0000ooooooooool0oooooolcooooo`00oooooomSoooo
o`00oooooomSooooo`00oooooomSooooo`00oooooomSooooo`00oooooomSooooo`00oooooomSoooo
o`00oooooomSooooo`00oooooomSooooo`00oooooomSooooo`00oooooomSooooo`00;Oooool00olQ
8B7o<S8booooo`3ooooooc?ooooo000/ooooo`04oiRHV?lb<S;o410@okZj^_oooooo<oooool002co
oooo00Co410@okZj^_nHV9So<S8boooooolcooooo`00:oooool01_nHV9So<S8boooooooooooo410@
okZj^_oooooo<_ooool002[ooooo00?ok^k^o`000?oMgMd00_ooool00onHV9So<S8booooo`3ooooo
oc7ooooo000Zooooo`03oa0@4?l0003o000000;ooooo0ol0003ooooooc7ooooo003oooooof?ooooo
003oooooof?ooooo003oooooof?ooooo003oooooof?ooooo003oooooof?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 353.5}, {416.25, 0}} -> {-0.756713, -3.15508, \
0.0206308, 0.0206308}}],

Cell[TextData[{
  "Fig. 1.2 Direction field for  ",
  StyleBox["dv",
    FontSlant->"Italic"],
  "/",
  StyleBox["dt ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["t-v",
    FontSlant->"Italic"],
  ", along with four solutions."
}], "Caption",
  CellTags->"Fig. 1.2"],

Cell[TextData[{
  "\tBy drawing these tangent vectors at a grid of points in the (",
  StyleBox["t,v",
    FontSlant->"Italic"],
  ") plane (not infinitesimal vectors, of course; we will take ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  " to be finite so that we can see the vectors), we get an overall \
qualitative picture of solutions to the ODE. An example is shown in ",
  ButtonBox["Fig. 1.2",
    ButtonData:>"Fig. 1.2",
    ButtonStyle->"Hyperlink"],
  ". This direction field is drawn for the particular case of an acceleration \
given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t, v)\  = \ t\  - \ v\)]],
  StyleBox[".",
    FontSlant->"Italic"]
}], "NE2",
  CellTags->"(1.2.4)"],

Cell[TextData[{
  "Along with the direction field, four solutions to ",
  ButtonBox["Eq. (1.2.2)",
    ButtonData:>"(1.2.2)",
    ButtonStyle->"Hyperlink"],
  "  with different initial ",
  StyleBox["v'",
    FontSlant->"Italic"],
  "s are shown. One can see that the direction field is tangent to each \
solution. "
}], "Text"],

Cell[TextData[{
  "\t",
  ButtonBox["Figure 1.2",
    ButtonData:>"Fig. 1.2",
    ButtonStyle->"Hyperlink"],
  " was created using a graphics function, available in  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]s graphical add-on packages, that is made for plotting \
two-dimensional vector fields:  ",
  StyleBox["PlotVectorField",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The syntax for this function is given below:"
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\
PlotVectorField[{vx[x,y],vy[x,y]},{x,xmin,xmax},{y,ymin,ymax},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  "."
}], "Text",
  CellTags->"i:18"],

Cell[TextData[{
  "The vector field in ",
  ButtonBox["Fig. 1.2",
    ButtonData:>"Fig. 1.2",
    ButtonStyle->"Hyperlink"],
  " was drawn with the following ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " commands"
}], "Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.4"],

Cell[BoxData[{
    \(\(f[t_, v_]\  = \ \(-v\)\  + \ t;\)\), "\n", 
    \(PlotVectorField[{1, f[t, v]}, {t, 0, 4}, {v, \(-3\), 3}, \ 
      Axes \[Rule] True, ScaleFunction \[Rule] \((1 &)\), 
      AxesLabel \[Rule] {"\<t\>", "\<v\>"}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.5"],

Cell[TextData[{
  "The option ",
  StyleBox["ScaleFunction->(1&)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " makes all the vectors the same length. The plot shows that you don't \
really need the four superimposed solutions in order to see the qualitative \
behavior of solutions for different initial conditions - you can trace them \
by eye just by following the arrows. "
}], "Text"],

Cell[TextData[{
  "\tHowever, for completeness we give the general solution of ",
  ButtonBox["Eqs. (1.2.2)",
    ButtonData:>"(1.2.2)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(1.2.4)",
    ButtonData:>"(1.2.4)",
    ButtonStyle->"Hyperlink"],
  " below:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v(t) = C\ \[ExponentialE]\^\(-t\) + t - 1\)]],
  " ,"
}], "NE2",
  CellTags->"(1.2.5)"],

Cell[TextData[{
  "which can be verified by substitution. In ",
  ButtonBox["Fig. 1.2",
    ButtonData:>"Fig. 1.2",
    ButtonStyle->"Hyperlink"],
  ", the solutions traced out by the solid lines are for ",
  Cell[BoxData[
      \(TraditionalForm\`C = \ {4, 2, 1, \(-2\)}\)]],
  ". (These solutions were plotted with the ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function and then superimposed on the vector field using the ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command.) One can see that for ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "< ",
  StyleBox["\[Infinity]",
    FontFamily->"Symbol"],
  ", the different solutions ",
  "never cross",
  ".  Thus, specifying an initial condition leads to a ",
  StyleBox["unique ",
    FontSlant->"Italic"],
  " solution of the differential equation.  There are no places in the \
direction field where one sees convergence of two different solutions, except \
perhaps as ",
  StyleBox["t",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rule]\)\(\ \)\)\)]],
  StyleBox["\[Infinity]",
    FontFamily->"Symbol"],
  " . This is guaranteed by the differentiability of the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " in each of its arguments."
}], "Text"],

Cell[TextData[{
  "\tA simple example of what can happen when the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is nondifferentiable at some point or points is given below. Consider the \
case "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t, v) = v/t\)]],
  "."
}], "NE2",
  CellTags->"(1.2.6)"],

Cell[TextData[{
  "This function is not differentiable at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0. The general solution to Eqs. ",
  ButtonBox["(1.2.2)",
    ButtonData:>"(1.2.2)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(1.2.6)",
    ButtonData:>"(1.2.6)",
    ButtonStyle->"Hyperlink"],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v(t) = C\ t\)]],
  ","
}], "NE2",
  CellTags->"(1.2.7)"],

Cell[TextData[{
  " as can be seen by direct substitution. This implies that ",
  "all",
  " solutions  to the ODE emanate from the point ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(0)=0. Therefore, the solution with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`v(0) = 0\)]],
  " is ",
  StyleBox["not unique",
    FontSlant->"Italic"],
  ".   This can easily be seen in a plot of the direction field, ",
  ButtonBox["Fig. 1.3",
    ButtonData:>"Fig. 1.3",
    ButtonStyle->"Hyperlink"],
  ". Furthermore, Eq. ",
  ButtonBox["(1.2.7)",
    ButtonData:>"(1.2.7)",
    ButtonStyle->"Hyperlink"],
  " shows that solutions with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(v(
          0)\)\(\ \)\(\[NotEqual]\)\(\ \)\(0\)\(\ \)\)\)]],
  " ",
  "do not exist",
  ". When ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is differentiable, this kind of singular behavior in the direction field \
cannot occur, and as a result the solution for a given initial condition \
exists and is unique."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.909091 0 0.909091 [
[.18182 -0.0125 -9 -9 ]
[.18182 -0.0125 9 0 ]
[.36364 -0.0125 -9 -9 ]
[.36364 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.72727 -0.0125 -9 -9 ]
[.72727 -0.0125 9 0 ]
[.90909 -0.0125 -3 -9 ]
[.90909 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .18182 -18 -4.5 ]
[-0.0125 .18182 0 4.5 ]
[-0.0125 .36364 -18 -4.5 ]
[-0.0125 .36364 0 4.5 ]
[-0.0125 .54545 -18 -4.5 ]
[-0.0125 .54545 0 4.5 ]
[-0.0125 .72727 -18 -4.5 ]
[-0.0125 .72727 0 4.5 ]
[-0.0125 .90909 -6 -4.5 ]
[-0.0125 .90909 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18182 0 m
.18182 .00625 L
s
[(0.2)] .18182 -0.0125 0 1 Mshowa
.36364 0 m
.36364 .00625 L
s
[(0.4)] .36364 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.6)] .54545 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(0.8)] .72727 -0.0125 0 1 Mshowa
.90909 0 m
.90909 .00625 L
s
[(1)] .90909 -0.0125 0 1 Mshowa
.125 Mabswid
.04545 0 m
.04545 .00375 L
s
.09091 0 m
.09091 .00375 L
s
.13636 0 m
.13636 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.31818 0 m
.31818 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.77273 0 m
.77273 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .18182 m
.00625 .18182 L
s
[(0.2)] -0.0125 .18182 1 0 Mshowa
0 .36364 m
.00625 .36364 L
s
[(0.4)] -0.0125 .36364 1 0 Mshowa
0 .54545 m
.00625 .54545 L
s
[(0.6)] -0.0125 .54545 1 0 Mshowa
0 .72727 m
.00625 .72727 L
s
[(0.8)] -0.0125 .72727 1 0 Mshowa
0 .90909 m
.00625 .90909 L
s
[(1)] -0.0125 .90909 1 0 Mshowa
.125 Mabswid
0 .04545 m
.00375 .04545 L
s
0 .09091 m
.00375 .09091 L
s
0 .13636 m
.00375 .13636 L
s
0 .22727 m
.00375 .22727 L
s
0 .27273 m
.00375 .27273 L
s
0 .31818 m
.00375 .31818 L
s
0 .40909 m
.00375 .40909 L
s
0 .45455 m
.00375 .45455 L
s
0 .5 m
.00375 .5 L
s
0 .59091 m
.00375 .59091 L
s
0 .63636 m
.00375 .63636 L
s
0 .68182 m
.00375 .68182 L
s
0 .77273 m
.00375 .77273 L
s
0 .81818 m
.00375 .81818 L
s
0 .86364 m
.00375 .86364 L
s
0 .95455 m
.00375 .95455 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
9e-05 0 m
.06502 0 L
s
% Start of user PostScript
0.0001 0 0.0715214 0 MAarrowhead1
% End of user PostScript
9e-05 .06494 m
.00018 .12986 L
s
% Start of user PostScript
0.0001 0.0714286 0.00019999 0.14285 MAarrowhead1
% End of user PostScript
9e-05 .12987 m
.00014 .1948 L
s
% Start of user PostScript
0.0001 0.142857 0.000149995 0.214279 MAarrowhead1
% End of user PostScript
9e-05 .19481 m
.00012 .25973 L
s
% Start of user PostScript
0.0001 0.214286 0.00013333 0.285707 MAarrowhead1
% End of user PostScript
9e-05 .25974 m
.00011 .32467 L
s
% Start of user PostScript
0.0001 0.285714 0.000124997 0.357136 MAarrowhead1
% End of user PostScript
9e-05 .32468 m
.00011 .3896 L
s
% Start of user PostScript
0.0001 0.357143 0.000119998 0.428564 MAarrowhead1
% End of user PostScript
9e-05 .38961 m
.00011 .45454 L
s
% Start of user PostScript
0.0001 0.428571 0.000116665 0.499993 MAarrowhead1
% End of user PostScript
9e-05 .45455 m
.0001 .51947 L
s
% Start of user PostScript
0.0001 0.5 0.000114284 0.571421 MAarrowhead1
% End of user PostScript
9e-05 .51948 m
.0001 .58441 L
s
% Start of user PostScript
0.0001 0.571429 0.000112499 0.64285 MAarrowhead1
% End of user PostScript
9e-05 .58442 m
.0001 .64934 L
s
% Start of user PostScript
0.0001 0.642857 0.00011111 0.714279 MAarrowhead1
% End of user PostScript
9e-05 .64935 m
.0001 .71428 L
s
% Start of user PostScript
0.0001 0.714286 0.000109999 0.785707 MAarrowhead1
% End of user PostScript
9e-05 .71429 m
.0001 .77921 L
s
% Start of user PostScript
0.0001 0.785714 0.00010909 0.857136 MAarrowhead1
% End of user PostScript
9e-05 .77922 m
.0001 .84415 L
s
% Start of user PostScript
0.0001 0.857143 0.000108332 0.928564 MAarrowhead1
% End of user PostScript
9e-05 .84416 m
.0001 .90908 L
s
% Start of user PostScript
0.0001 0.928571 0.000107692 0.999993 MAarrowhead1
% End of user PostScript
9e-05 .90909 m
.0001 .97402 L
s
% Start of user PostScript
0.0001 1. 0.000107142 1.07142 MAarrowhead1
% End of user PostScript
.06502 0 m
.12995 0 L
s
% Start of user PostScript
0.0715214 0 0.142943 0 MAarrowhead1
% End of user PostScript
.06502 .06494 m
.11096 .11082 L
s
% Start of user PostScript
0.0715214 0.0714286 0.122057 0.121898 MAarrowhead1
% End of user PostScript
.06502 .12987 m
.09409 .18793 L
s
% Start of user PostScript
0.0715214 0.142857 0.103495 0.206722 MAarrowhead1
% End of user PostScript
.06502 .19481 m
.08558 .25639 L
s
% Start of user PostScript
0.0715214 0.214286 0.0941333 0.282033 MAarrowhead1
% End of user PostScript
.06502 .25974 m
.08079 .32273 L
s
% Start of user PostScript
0.0715214 0.285714 0.0888649 0.354998 MAarrowhead1
% End of user PostScript
.06502 .32468 m
.07777 .38834 L
s
% Start of user PostScript
0.0715214 0.357143 0.0855458 0.427174 MAarrowhead1
% End of user PostScript
.06502 .38961 m
.07571 .45365 L
s
% Start of user PostScript
0.0715214 0.428571 0.0832779 0.499019 MAarrowhead1
% End of user PostScript
.06502 .45455 m
.07421 .51882 L
s
% Start of user PostScript
0.0715214 0.5 0.0816348 0.570702 MAarrowhead1
% End of user PostScript
.06502 .51948 m
.07308 .58391 L
s
% Start of user PostScript
0.0715214 0.571429 0.0803915 0.642297 MAarrowhead1
% End of user PostScript
.06502 .58442 m
.0722 .64895 L
s
% Start of user PostScript
0.0715214 0.642857 0.0794187 0.713841 MAarrowhead1
% End of user PostScript
.06502 .64935 m
.07149 .71396 L
s
% Start of user PostScript
0.0715214 0.714286 0.0786373 0.785352 MAarrowhead1
% End of user PostScript
.06502 .71429 m
.07091 .77895 L
s
% Start of user PostScript
0.0715214 0.785714 0.077996 0.856842 MAarrowhead1
% End of user PostScript
.06502 .77922 m
.07042 .84392 L
s
% Start of user PostScript
0.0715214 0.857143 0.0774603 0.928317 MAarrowhead1
% End of user PostScript
.06502 .84416 m
.07001 .90889 L
s
% Start of user PostScript
0.0715214 0.928571 0.0770063 0.999782 MAarrowhead1
% End of user PostScript
.06502 .90909 m
.06965 .97385 L
s
% Start of user PostScript
0.0715214 1. 0.0766166 1.07124 MAarrowhead1
% End of user PostScript
.12995 0 m
.19488 0 L
s
% Start of user PostScript
0.142943 0 0.214364 0 MAarrowhead1
% End of user PostScript
.12995 .06494 m
.18803 .09396 L
s
% Start of user PostScript
0.142943 0.0714286 0.206832 0.103354 MAarrowhead1
% End of user PostScript
.12995 .12987 m
.17587 .17577 L
s
% Start of user PostScript
0.142943 0.142857 0.193461 0.193345 MAarrowhead1
% End of user PostScript
.12995 .19481 m
.16598 .24882 L
s
% Start of user PostScript
0.142943 0.214286 0.182577 0.273701 MAarrowhead1
% End of user PostScript
.12995 .25974 m
.159 .31781 L
s
% Start of user PostScript
0.142943 0.285714 0.174899 0.349588 MAarrowhead1
% End of user PostScript
.12995 .32468 m
.15407 .38495 L
s
% Start of user PostScript
0.142943 0.357143 0.169482 0.42345 MAarrowhead1
% End of user PostScript
.12995 .38961 m
.15049 .4512 L
s
% Start of user PostScript
0.142943 0.428571 0.16554 0.496324 MAarrowhead1
% End of user PostScript
.12995 .45455 m
.1478 .51697 L
s
% Start of user PostScript
0.142943 0.5 0.162575 0.56867 MAarrowhead1
% End of user PostScript
.12995 .51948 m
.1457 .58247 L
s
% Start of user PostScript
0.142943 0.571429 0.160275 0.640715 MAarrowhead1
% End of user PostScript
.12995 .58442 m
.14404 .6478 L
s
% Start of user PostScript
0.142943 0.642857 0.158445 0.712576 MAarrowhead1
% End of user PostScript
.12995 .64935 m
.14269 .71302 L
s
% Start of user PostScript
0.142943 0.714286 0.156958 0.784319 MAarrowhead1
% End of user PostScript
.12995 .71429 m
.14157 .77817 L
s
% Start of user PostScript
0.142943 0.785714 0.155727 0.855982 MAarrowhead1
% End of user PostScript
.12995 .77922 m
.14063 .84326 L
s
% Start of user PostScript
0.142943 0.857143 0.154691 0.927591 MAarrowhead1
% End of user PostScript
.12995 .84416 m
.13983 .90833 L
s
% Start of user PostScript
0.142943 0.928571 0.153809 0.999161 MAarrowhead1
% End of user PostScript
.12995 .90909 m
.13914 .97337 L
s
% Start of user PostScript
0.142943 1. 0.153049 1.0707 MAarrowhead1
% End of user PostScript
.19488 0 m
.25981 0 L
s
% Start of user PostScript
0.214364 0 0.285786 0 MAarrowhead1
% End of user PostScript
.19488 .06494 m
.25648 .08546 L
s
% Start of user PostScript
0.214364 0.0714286 0.282123 0.0940066 MAarrowhead1
% End of user PostScript
.19488 .12987 m
.24891 .16588 L
s
% Start of user PostScript
0.214364 0.142857 0.273797 0.182465 MAarrowhead1
% End of user PostScript
.19488 .19481 m
.2408 .24071 L
s
% Start of user PostScript
0.214364 0.214286 0.264876 0.264779 MAarrowhead1
% End of user PostScript
.19488 .25974 m
.23384 .31168 L
s
% Start of user PostScript
0.214364 0.285714 0.257227 0.342844 MAarrowhead1
% End of user PostScript
.19488 .32468 m
.22829 .38035 L
s
% Start of user PostScript
0.214364 0.357143 0.25112 0.41838 MAarrowhead1
% End of user PostScript
.19488 .38961 m
.22392 .44768 L
s
% Start of user PostScript
0.214364 0.428571 0.246314 0.492448 MAarrowhead1
% End of user PostScript
.19488 .45455 m
.22046 .51422 L
s
% Start of user PostScript
0.214364 0.5 0.242507 0.565643 MAarrowhead1
% End of user PostScript
.19488 .51948 m
.21768 .58027 L
s
% Start of user PostScript
0.214364 0.571429 0.23945 0.6383 MAarrowhead1
% End of user PostScript
.19488 .58442 m
.21542 .64601 L
s
% Start of user PostScript
0.214364 0.642857 0.236957 0.710611 MAarrowhead1
% End of user PostScript
.19488 .64935 m
.21354 .71154 L
s
% Start of user PostScript
0.214364 0.714286 0.234894 0.782693 MAarrowhead1
% End of user PostScript
.19488 .71429 m
.21197 .77692 L
s
% Start of user PostScript
0.214364 0.785714 0.233163 0.854617 MAarrowhead1
% End of user PostScript
.19488 .77922 m
.21063 .84221 L
s
% Start of user PostScript
0.214364 0.857143 0.231693 0.92643 MAarrowhead1
% End of user PostScript
.19488 .84416 m
.20948 .90742 L
s
% Start of user PostScript
0.214364 0.928571 0.23043 0.998163 MAarrowhead1
% End of user PostScript
.19488 .90909 m
.20849 .97258 L
s
% Start of user PostScript
0.214364 1. 0.229334 1.06983 MAarrowhead1
% End of user PostScript
.25981 0 m
.32473 0 L
s
% Start of user PostScript
0.285786 0 0.357207 0 MAarrowhead1
% End of user PostScript
.25981 .06494 m
.3228 .08068 L
s
% Start of user PostScript
0.285786 0.0714286 0.355076 0.0887467 MAarrowhead1
% End of user PostScript
.25981 .12987 m
.31788 .1589 L
s
% Start of user PostScript
0.285786 0.142857 0.34967 0.174791 MAarrowhead1
% End of user PostScript
.25981 .19481 m
.31175 .23376 L
s
% Start of user PostScript
0.285786 0.214286 0.342928 0.257132 MAarrowhead1
% End of user PostScript
.25981 .25974 m
.30572 .30565 L
s
% Start of user PostScript
0.285786 0.285714 0.336295 0.336211 MAarrowhead1
% End of user PostScript
.25981 .32468 m
.30037 .37537 L
s
% Start of user PostScript
0.285786 0.357143 0.330409 0.412908 MAarrowhead1
% End of user PostScript
.25981 .38961 m
.29583 .44363 L
s
% Start of user PostScript
0.285786 0.428571 0.32541 0.487993 MAarrowhead1
% End of user PostScript
.25981 .45455 m
.29202 .51092 L
s
% Start of user PostScript
0.285786 0.5 0.321227 0.562007 MAarrowhead1
% End of user PostScript
.25981 .51948 m
.28885 .57755 L
s
% Start of user PostScript
0.285786 0.571429 0.317733 0.635307 MAarrowhead1
% End of user PostScript
.25981 .58442 m
.28618 .64375 L
s
% Start of user PostScript
0.285786 0.642857 0.314799 0.70812 MAarrowhead1
% End of user PostScript
.25981 .64935 m
.28392 .70963 L
s
% Start of user PostScript
0.285786 0.714286 0.312317 0.780597 MAarrowhead1
% End of user PostScript
.25981 .71429 m
.282 .7753 L
s
% Start of user PostScript
0.285786 0.785714 0.310199 0.852834 MAarrowhead1
% End of user PostScript
.25981 .77922 m
.28034 .84082 L
s
% Start of user PostScript
0.285786 0.857143 0.308376 0.924897 MAarrowhead1
% End of user PostScript
.25981 .84416 m
.2789 .90621 L
s
% Start of user PostScript
0.285786 0.928571 0.306795 0.996833 MAarrowhead1
% End of user PostScript
.25981 .90909 m
.27765 .97152 L
s
% Start of user PostScript
0.285786 1. 0.305411 1.06867 MAarrowhead1
% End of user PostScript
.32473 0 m
.38966 0 L
s
% Start of user PostScript
0.357207 0 0.428629 0 MAarrowhead1
% End of user PostScript
.32473 .06494 m
.3884 .07767 L
s
% Start of user PostScript
0.357207 0.0714286 0.427242 0.085433 MAarrowhead1
% End of user PostScript
.32473 .12987 m
.38502 .15398 L
s
% Start of user PostScript
0.357207 0.142857 0.423522 0.169378 MAarrowhead1
% End of user PostScript
.32473 .19481 m
.38041 .22821 L
s
% Start of user PostScript
0.357207 0.214286 0.418453 0.251027 MAarrowhead1
% End of user PostScript
.32473 .25974 m
.37544 .3003 L
s
% Start of user PostScript
0.357207 0.285714 0.412982 0.330326 MAarrowhead1
% End of user PostScript
.32473 .32468 m
.37065 .37058 L
s
% Start of user PostScript
0.357207 0.357143 0.407714 0.407641 MAarrowhead1
% End of user PostScript
.32473 .38961 m
.3663 .43949 L
s
% Start of user PostScript
0.357207 0.428571 0.402935 0.483435 MAarrowhead1
% End of user PostScript
.32473 .45455 m
.36248 .50738 L
s
% Start of user PostScript
0.357207 0.5 0.398725 0.558114 MAarrowhead1
% End of user PostScript
.32473 .51948 m
.35915 .57454 L
s
% Start of user PostScript
0.357207 0.571429 0.395065 0.631991 MAarrowhead1
% End of user PostScript
.32473 .58442 m
.35627 .64117 L
s
% Start of user PostScript
0.357207 0.642857 0.391897 0.705288 MAarrowhead1
% End of user PostScript
.32473 .64935 m
.35377 .70742 L
s
% Start of user PostScript
0.357207 0.714286 0.389152 0.778165 MAarrowhead1
% End of user PostScript
.32473 .71429 m
.35161 .77339 L
s
% Start of user PostScript
0.357207 0.785714 0.386766 0.850732 MAarrowhead1
% End of user PostScript
.32473 .77922 m
.34971 .83915 L
s
% Start of user PostScript
0.357207 0.857143 0.384681 0.923069 MAarrowhead1
% End of user PostScript
.32473 .84416 m
.34805 .90476 L
s
% Start of user PostScript
0.357207 0.928571 0.38285 0.995231 MAarrowhead1
% End of user PostScript
.32473 .90909 m
.34658 .97024 L
s
% Start of user PostScript
0.357207 1. 0.381233 1.06726 MAarrowhead1
% End of user PostScript
.38966 0 m
.45459 0 L
s
% Start of user PostScript
0.428629 0 0.50005 0 MAarrowhead1
% End of user PostScript
.38966 .06494 m
.45371 .07561 L
s
% Start of user PostScript
0.428629 0.0714286 0.499078 0.0831687 MAarrowhead1
% End of user PostScript
.38966 .12987 m
.45126 .1504 L
s
% Start of user PostScript
0.428629 0.142857 0.496386 0.16544 MAarrowhead1
% End of user PostScript
.38966 .19481 m
.44774 .22384 L
s
% Start of user PostScript
0.428629 0.214286 0.492512 0.246223 MAarrowhead1
% End of user PostScript
.38966 .25974 m
.44369 .29575 L
s
% Start of user PostScript
0.428629 0.285714 0.488057 0.325328 MAarrowhead1
% End of user PostScript
.38966 .32468 m
.43954 .36624 L
s
% Start of user PostScript
0.428629 0.357143 0.483499 0.402862 MAarrowhead1
% End of user PostScript
.38966 .38961 m
.43558 .43552 L
s
% Start of user PostScript
0.428629 0.428571 0.479135 0.479071 MAarrowhead1
% End of user PostScript
.38966 .45455 m
.43192 .50384 L
s
% Start of user PostScript
0.428629 0.5 0.475113 0.554224 MAarrowhead1
% End of user PostScript
.38966 .51948 m
.42862 .57142 L
s
% Start of user PostScript
0.428629 0.571429 0.471485 0.628563 MAarrowhead1
% End of user PostScript
.38966 .58442 m
.42568 .63844 L
s
% Start of user PostScript
0.428629 0.642857 0.46825 0.702281 MAarrowhead1
% End of user PostScript
.38966 .64935 m
.42307 .70502 L
s
% Start of user PostScript
0.428629 0.714286 0.465378 0.775527 MAarrowhead1
% End of user PostScript
.38966 .71429 m
.42076 .77128 L
s
% Start of user PostScript
0.428629 0.785714 0.462832 0.848413 MAarrowhead1
% End of user PostScript
.38966 .77922 m
.4187 .83729 L
s
% Start of user PostScript
0.428629 0.857143 0.460573 0.921022 MAarrowhead1
% End of user PostScript
.38966 .84416 m
.41687 .90311 L
s
% Start of user PostScript
0.428629 0.928571 0.458562 0.993418 MAarrowhead1
% End of user PostScript
.38966 .90909 m
.41524 .96877 L
s
% Start of user PostScript
0.428629 1. 0.456766 1.06565 MAarrowhead1
% End of user PostScript
.45459 0 m
.51952 0 L
s
% Start of user PostScript
0.50005 0 0.571471 0 MAarrowhead1
% End of user PostScript
.45459 .06494 m
.51887 .07412 L
s
% Start of user PostScript
0.50005 0.0714286 0.570754 0.0815281 MAarrowhead1
% End of user PostScript
.45459 .12987 m
.51702 .14771 L
s
% Start of user PostScript
0.50005 0.142857 0.568724 0.162476 MAarrowhead1
% End of user PostScript
.45459 .19481 m
.51427 .22038 L
s
% Start of user PostScript
0.50005 0.214286 0.565698 0.242418 MAarrowhead1
% End of user PostScript
.45459 .25974 m
.51097 .29195 L
s
% Start of user PostScript
0.50005 0.285714 0.562063 0.321147 MAarrowhead1
% End of user PostScript
.45459 .32468 m
.50743 .36241 L
s
% Start of user PostScript
0.50005 0.357143 0.55817 0.398653 MAarrowhead1
% End of user PostScript
.45459 .38961 m
.50389 .43186 L
s
% Start of user PostScript
0.50005 0.428571 0.554279 0.475049 MAarrowhead1
% End of user PostScript
.45459 .45455 m
.5005 .50045 L
s
% Start of user PostScript
0.50005 0.5 0.550555 0.5505 MAarrowhead1
% End of user PostScript
.45459 .51948 m
.49735 .56834 L
s
% Start of user PostScript
0.50005 0.571429 0.547084 0.625176 MAarrowhead1
% End of user PostScript
.45459 .58442 m
.49446 .63567 L
s
% Start of user PostScript
0.50005 0.642857 0.543901 0.699232 MAarrowhead1
% End of user PostScript
.45459 .64935 m
.49183 .70254 L
s
% Start of user PostScript
0.50005 0.714286 0.54101 0.772795 MAarrowhead1
% End of user PostScript
.45459 .71429 m
.48945 .76906 L
s
% Start of user PostScript
0.50005 0.785714 0.538397 0.845968 MAarrowhead1
% End of user PostScript
.45459 .77922 m
.48731 .8353 L
s
% Start of user PostScript
0.50005 0.857143 0.53604 0.918834 MAarrowhead1
% End of user PostScript
.45459 .84416 m
.48538 .90132 L
s
% Start of user PostScript
0.50005 0.928571 0.533914 0.991455 MAarrowhead1
% End of user PostScript
.45459 .90909 m
.48363 .96716 L
s
% Start of user PostScript
0.50005 1. 0.531993 1.06388 MAarrowhead1
% End of user PostScript
.51952 0 m
.58445 0 L
s
% Start of user PostScript
0.571471 0 0.642893 0 MAarrowhead1
% End of user PostScript
.51952 .06494 m
.58395 .07299 L
s
% Start of user PostScript
0.571471 0.0714286 0.642341 0.0802867 MAarrowhead1
% End of user PostScript
.51952 .12987 m
.58251 .14562 L
s
% Start of user PostScript
0.571471 0.142857 0.640761 0.160178 MAarrowhead1
% End of user PostScript
.51952 .19481 m
.58031 .2176 L
s
% Start of user PostScript
0.571471 0.214286 0.638346 0.239362 MAarrowhead1
% End of user PostScript
.51952 .25974 m
.57759 .28878 L
s
% Start of user PostScript
0.571471 0.285714 0.635354 0.317653 MAarrowhead1
% End of user PostScript
.51952 .32468 m
.57458 .35909 L
s
% Start of user PostScript
0.571471 0.357143 0.632038 0.394994 MAarrowhead1
% End of user PostScript
.51952 .38961 m
.57146 .42857 L
s
% Start of user PostScript
0.571471 0.428571 0.62861 0.471422 MAarrowhead1
% End of user PostScript
.51952 .45455 m
.56838 .4973 L
s
% Start of user PostScript
0.571471 0.5 0.625223 0.547029 MAarrowhead1
% End of user PostScript
.51952 .51948 m
.56543 .56539 L
s
% Start of user PostScript
0.571471 0.571429 0.621976 0.621929 MAarrowhead1
% End of user PostScript
.51952 .58442 m
.56266 .63294 L
s
% Start of user PostScript
0.571471 0.642857 0.618923 0.696236 MAarrowhead1
% End of user PostScript
.51952 .64935 m
.56008 .70005 L
s
% Start of user PostScript
0.571471 0.714286 0.61609 0.770055 MAarrowhead1
% End of user PostScript
.51952 .71429 m
.55771 .76679 L
s
% Start of user PostScript
0.571471 0.785714 0.613482 0.843474 MAarrowhead1
% End of user PostScript
.51952 .77922 m
.55554 .83324 L
s
% Start of user PostScript
0.571471 0.857143 0.611091 0.916568 MAarrowhead1
% End of user PostScript
.51952 .84416 m
.55355 .89945 L
s
% Start of user PostScript
0.571471 0.928571 0.608905 0.989397 MAarrowhead1
% End of user PostScript
.51952 .90909 m
.55173 .96546 L
s
% Start of user PostScript
0.571471 1. 0.606908 1.06201 MAarrowhead1
% End of user PostScript
.58445 0 m
.64938 0 L
s
% Start of user PostScript
0.642893 0 0.714314 0 MAarrowhead1
% End of user PostScript
.58445 .06494 m
.64898 .0721 L
s
% Start of user PostScript
0.642893 0.0714286 0.713878 0.0793153 MAarrowhead1
% End of user PostScript
.58445 .12987 m
.64783 .14395 L
s
% Start of user PostScript
0.642893 0.142857 0.712614 0.15835 MAarrowhead1
% End of user PostScript
.58445 .19481 m
.64605 .21534 L
s
% Start of user PostScript
0.642893 0.214286 0.71065 0.23687 MAarrowhead1
% End of user PostScript
.58445 .25974 m
.64378 .28611 L
s
% Start of user PostScript
0.642893 0.285714 0.708159 0.31472 MAarrowhead1
% End of user PostScript
.58445 .32468 m
.64121 .35621 L
s
% Start of user PostScript
0.642893 0.357143 0.705327 0.391827 MAarrowhead1
% End of user PostScript
.58445 .38961 m
.63847 .42562 L
s
% Start of user PostScript
0.642893 0.428571 0.70232 0.468187 MAarrowhead1
% End of user PostScript
.58445 .45455 m
.6357 .49441 L
s
% Start of user PostScript
0.642893 0.5 0.699271 0.543847 MAarrowhead1
% End of user PostScript
.58445 .51948 m
.63298 .56262 L
s
% Start of user PostScript
0.642893 0.571429 0.696275 0.618877 MAarrowhead1
% End of user PostScript
.58445 .58442 m
.63036 .63033 L
s
% Start of user PostScript
0.642893 0.642857 0.693397 0.693358 MAarrowhead1
% End of user PostScript
.58445 .64935 m
.62788 .69761 L
s
% Start of user PostScript
0.642893 0.714286 0.690673 0.767372 MAarrowhead1
% End of user PostScript
.58445 .71429 m
.62556 .76454 L
s
% Start of user PostScript
0.642893 0.785714 0.688121 0.84099 MAarrowhead1
% End of user PostScript
.58445 .77922 m
.62341 .83116 L
s
% Start of user PostScript
0.642893 0.857143 0.685747 0.914279 MAarrowhead1
% End of user PostScript
.58445 .84416 m
.62141 .89754 L
s
% Start of user PostScript
0.642893 0.928571 0.683548 0.987293 MAarrowhead1
% End of user PostScript
.58445 .90909 m
.61956 .96371 L
s
% Start of user PostScript
0.642893 1. 0.681516 1.06008 MAarrowhead1
% End of user PostScript
.64938 0 m
.71431 0 L
s
% Start of user PostScript
0.714314 0 0.785736 0 MAarrowhead1
% End of user PostScript
.64938 .06494 m
.71398 .0714 L
s
% Start of user PostScript
0.714314 0.0714286 0.785381 0.078535 MAarrowhead1
% End of user PostScript
.64938 .12987 m
.71304 .1426 L
s
% Start of user PostScript
0.714314 0.142857 0.784349 0.156863 MAarrowhead1
% End of user PostScript
.64938 .19481 m
.71157 .21346 L
s
% Start of user PostScript
0.714314 0.214286 0.782724 0.234808 MAarrowhead1
% End of user PostScript
.64938 .25974 m
.70966 .28385 L
s
% Start of user PostScript
0.714314 0.285714 0.780628 0.312239 MAarrowhead1
% End of user PostScript
.64938 .32468 m
.70745 .35371 L
s
% Start of user PostScript
0.714314 0.357143 0.778196 0.389082 MAarrowhead1
% End of user PostScript
.64938 .38961 m
.70505 .42301 L
s
% Start of user PostScript
0.714314 0.428571 0.775558 0.465316 MAarrowhead1
% End of user PostScript
.64938 .45455 m
.70257 .49178 L
s
% Start of user PostScript
0.714314 0.5 0.772826 0.540956 MAarrowhead1
% End of user PostScript
.64938 .51948 m
.70008 .56004 L
s
% Start of user PostScript
0.714314 0.571429 0.770086 0.616044 MAarrowhead1
% End of user PostScript
.64938 .58442 m
.69764 .62785 L
s
% Start of user PostScript
0.714314 0.642857 0.767402 0.690635 MAarrowhead1
% End of user PostScript
.64938 .64935 m
.69529 .69526 L
s
% Start of user PostScript
0.714314 0.714286 0.764818 0.764787 MAarrowhead1
% End of user PostScript
.64938 .71429 m
.69305 .76233 L
s
% Start of user PostScript
0.714314 0.785714 0.762359 0.838561 MAarrowhead1
% End of user PostScript
.64938 .77922 m
.69094 .8291 L
s
% Start of user PostScript
0.714314 0.857143 0.760038 0.912009 MAarrowhead1
% End of user PostScript
.64938 .84416 m
.68897 .89562 L
s
% Start of user PostScript
0.714314 0.928571 0.757862 0.985181 MAarrowhead1
% End of user PostScript
.64938 .90909 m
.68712 .96192 L
s
% Start of user PostScript
0.714314 1. 0.755828 1.05812 MAarrowhead1
% End of user PostScript
.71431 0 m
.77923 0 L
s
% Start of user PostScript
0.785736 0 0.857157 0 MAarrowhead1
% End of user PostScript
.71431 .06494 m
.77897 .07081 L
s
% Start of user PostScript
0.785736 0.0714286 0.856864 0.0778946 MAarrowhead1
% End of user PostScript
.71431 .12987 m
.77819 .14148 L
s
% Start of user PostScript
0.785736 0.142857 0.856005 0.155633 MAarrowhead1
% End of user PostScript
.71431 .19481 m
.77695 .21189 L
s
% Start of user PostScript
0.785736 0.214286 0.854641 0.233077 MAarrowhead1
% End of user PostScript
.71431 .25974 m
.77532 .28193 L
s
% Start of user PostScript
0.785736 0.285714 0.852857 0.310121 MAarrowhead1
% End of user PostScript
.71431 .32468 m
.77341 .35154 L
s
% Start of user PostScript
0.785736 0.357143 0.850756 0.386697 MAarrowhead1
% End of user PostScript
.71431 .38961 m
.77131 .4207 L
s
% Start of user PostScript
0.785736 0.428571 0.848437 0.462771 MAarrowhead1
% End of user PostScript
.71431 .45455 m
.76908 .4894 L
s
% Start of user PostScript
0.785736 0.5 0.845992 0.538344 MAarrowhead1
% End of user PostScript
.71431 .51948 m
.76682 .55767 L
s
% Start of user PostScript
0.785736 0.571429 0.843497 0.613436 MAarrowhead1
% End of user PostScript
.71431 .58442 m
.76456 .62553 L
s
% Start of user PostScript
0.785736 0.642857 0.841013 0.688083 MAarrowhead1
% End of user PostScript
.71431 .64935 m
.76235 .69303 L
s
% Start of user PostScript
0.785736 0.714286 0.838584 0.762328 MAarrowhead1
% End of user PostScript
.71431 .71429 m
.76022 .7602 L
s
% Start of user PostScript
0.785736 0.785714 0.836239 0.836216 MAarrowhead1
% End of user PostScript
.71431 .77922 m
.75818 .82708 L
s
% Start of user PostScript
0.785736 0.857143 0.833998 0.909791 MAarrowhead1
% End of user PostScript
.71431 .84416 m
.75625 .89372 L
s
% Start of user PostScript
0.785736 0.928571 0.831871 0.983093 MAarrowhead1
% End of user PostScript
.71431 .90909 m
.75442 .96014 L
s
% Start of user PostScript
0.785736 1. 0.829862 1.05616 MAarrowhead1
% End of user PostScript
.77923 0 m
.84416 0 L
s
% Start of user PostScript
0.857157 0 0.928579 0 MAarrowhead1
% End of user PostScript
.77923 .06494 m
.84394 .07033 L
s
% Start of user PostScript
0.857157 0.0714286 0.928332 0.0773597 MAarrowhead1
% End of user PostScript
.77923 .12987 m
.84328 .14054 L
s
% Start of user PostScript
0.857157 0.142857 0.927607 0.154599 MAarrowhead1
% End of user PostScript
.77923 .19481 m
.84222 .21055 L
s
% Start of user PostScript
0.857157 0.214286 0.926446 0.231608 MAarrowhead1
% End of user PostScript
.77923 .25974 m
.84083 .28027 L
s
% Start of user PostScript
0.857157 0.285714 0.924914 0.308299 MAarrowhead1
% End of user PostScript
.77923 .32468 m
.83917 .34965 L
s
% Start of user PostScript
0.857157 0.357143 0.923085 0.384612 MAarrowhead1
% End of user PostScript
.77923 .38961 m
.83731 .41865 L
s
% Start of user PostScript
0.857157 0.428571 0.921039 0.460512 MAarrowhead1
% End of user PostScript
.77923 .45455 m
.83532 .48726 L
s
% Start of user PostScript
0.857157 0.5 0.91885 0.535987 MAarrowhead1
% End of user PostScript
.77923 .51948 m
.83326 .5555 L
s
% Start of user PostScript
0.857157 0.571429 0.916584 0.611046 MAarrowhead1
% End of user PostScript
.77923 .58442 m
.83118 .62337 L
s
% Start of user PostScript
0.857157 0.642857 0.914295 0.68571 MAarrowhead1
% End of user PostScript
.77923 .64935 m
.82911 .69092 L
s
% Start of user PostScript
0.857157 0.714286 0.912025 0.760008 MAarrowhead1
% End of user PostScript
.77923 .71429 m
.8271 .75816 L
s
% Start of user PostScript
0.857157 0.785714 0.909806 0.833975 MAarrowhead1
% End of user PostScript
.77923 .77922 m
.82515 .82513 L
s
% Start of user PostScript
0.857157 0.857143 0.90766 0.907645 MAarrowhead1
% End of user PostScript
.77923 .84416 m
.82327 .89187 L
s
% Start of user PostScript
0.857157 0.928571 0.905601 0.981052 MAarrowhead1
% End of user PostScript
.77923 .90909 m
.82149 .95839 L
s
% Start of user PostScript
0.857157 1. 0.903638 1.05423 MAarrowhead1
% End of user PostScript
.84416 0 m
.90909 0 L
s
% Start of user PostScript
0.928579 0 1. 0 MAarrowhead1
% End of user PostScript
.84416 .06494 m
.9089 .06991 L
s
% Start of user PostScript
0.928579 0.0714286 0.99979 0.0769063 MAarrowhead1
% End of user PostScript
.84416 .12987 m
.90834 .13974 L
s
% Start of user PostScript
0.928579 0.142857 0.99917 0.153717 MAarrowhead1
% End of user PostScript
.84416 .19481 m
.90743 .2094 L
s
% Start of user PostScript
0.928579 0.214286 0.998171 0.230345 MAarrowhead1
% End of user PostScript
.84416 .25974 m
.90622 .27883 L
s
% Start of user PostScript
0.928579 0.285714 0.996842 0.306718 MAarrowhead1
% End of user PostScript
.84416 .32468 m
.90476 .34798 L
s
% Start of user PostScript
0.928579 0.357143 0.99524 0.382781 MAarrowhead1
% End of user PostScript
.84416 .38961 m
.90311 .41682 L
s
% Start of user PostScript
0.928579 0.428571 0.993426 0.458501 MAarrowhead1
% End of user PostScript
.84416 .45455 m
.90133 .48533 L
s
% Start of user PostScript
0.928579 0.5 0.991463 0.533861 MAarrowhead1
% End of user PostScript
.84416 .51948 m
.89946 .55351 L
s
% Start of user PostScript
0.928579 0.571429 0.989405 0.60886 MAarrowhead1
% End of user PostScript
.84416 .58442 m
.89755 .62137 L
s
% Start of user PostScript
0.928579 0.642857 0.987301 0.683511 MAarrowhead1
% End of user PostScript
.84416 .64935 m
.89563 .68894 L
s
% Start of user PostScript
0.928579 0.714286 0.985189 0.757832 MAarrowhead1
% End of user PostScript
.84416 .71429 m
.89373 .75623 L
s
% Start of user PostScript
0.928579 0.785714 0.983101 0.831848 MAarrowhead1
% End of user PostScript
.84416 .77922 m
.89187 .82326 L
s
% Start of user PostScript
0.928579 0.857143 0.981059 0.905586 MAarrowhead1
% End of user PostScript
.84416 .84416 m
.89007 .89007 L
s
% Start of user PostScript
0.928579 0.928571 0.979081 0.979074 MAarrowhead1
% End of user PostScript
.84416 .90909 m
.88834 .95667 L
s
% Start of user PostScript
0.928579 1. 0.977178 1.05234 MAarrowhead1
% End of user PostScript
.90909 0 m
.97402 0 L
s
% Start of user PostScript
1. 0 1.07142 0 MAarrowhead1
% End of user PostScript
.90909 .06494 m
.97385 .06956 L
s
% Start of user PostScript
1. 0.0714286 1.07124 0.0765171 MAarrowhead1
% End of user PostScript
.90909 .12987 m
.97337 .13905 L
s
% Start of user PostScript
1. 0.142857 1.0707 0.152958 MAarrowhead1
% End of user PostScript
.90909 .19481 m
.97258 .20841 L
s
% Start of user PostScript
1. 0.214286 1.06984 0.229251 MAarrowhead1
% End of user PostScript
.90909 .25974 m
.97152 .27758 L
s
% Start of user PostScript
1. 0.285714 1.06867 0.305335 MAarrowhead1
% End of user PostScript
.90909 .32468 m
.97024 .34651 L
s
% Start of user PostScript
1. 0.357143 1.06726 0.381164 MAarrowhead1
% End of user PostScript
.90909 .38961 m
.96877 .41519 L
s
% Start of user PostScript
1. 0.428571 1.06565 0.456706 MAarrowhead1
% End of user PostScript
.90909 .45455 m
.96716 .48358 L
s
% Start of user PostScript
1. 0.5 1.06388 0.531941 MAarrowhead1
% End of user PostScript
.90909 .51948 m
.96546 .55169 L
s
% Start of user PostScript
1. 0.571429 1.06201 0.606864 MAarrowhead1
% End of user PostScript
.90909 .58442 m
.96371 .61953 L
s
% Start of user PostScript
1. 0.642857 1.06008 0.681479 MAarrowhead1
% End of user PostScript
.90909 .64935 m
.96193 .68709 L
s
% Start of user PostScript
1. 0.714286 1.05812 0.755799 MAarrowhead1
% End of user PostScript
.90909 .71429 m
.96015 .7544 L
s
% Start of user PostScript
1. 0.785714 1.05616 0.82984 MAarrowhead1
% End of user PostScript
.90909 .77922 m
.95839 .82148 L
s
% Start of user PostScript
1. 0.857143 1.05423 0.903623 MAarrowhead1
% End of user PostScript
.90909 .84416 m
.95667 .88834 L
s
% Start of user PostScript
1. 0.928571 1.05234 0.97717 MAarrowhead1
% End of user PostScript
.90909 .90909 m
.955 .955 L
s
% Start of user PostScript
1. 1. 1.0505 1.0505 MAarrowhead1
% End of user PostScript
.012 w
0 0 m
.04057 .01014 L
.08481 .0212 L
.12636 .03159 L
.16632 .04158 L
.20885 .05221 L
.2498 .06245 L
.29331 .07333 L
.33524 .08381 L
.37557 .09389 L
.41848 .10462 L
.4598 .11495 L
.49953 .12488 L
.54183 .13546 L
.58254 .14564 L
.62583 .15646 L
.66752 .16688 L
.70762 .17691 L
.7503 .18758 L
.79139 .19785 L
.83505 .20876 L
.87712 .21928 L
.9176 .2294 L
.96065 .24016 L
1 .25 L
s
0 0 m
.04057 .16227 L
.08481 .33924 L
.12636 .50544 L
.16632 .66527 L
.20885 .83541 L
.2498 .99918 L
s
.2498 .99918 m
.25 1 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00B?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;Oooool4o`000003oa0@4?oooooooooo02gooooo0018ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00S
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool08ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40;oooool00ol0003oooooooooo`0_ooooo`00B?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Tooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Co
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000;oooool0
0ol0003oooooooooo`0_ooooo`00B?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h08oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Toooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b02oooooo00?o
0000ooooooooool0;oooool004Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Go
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00_ooooo`03o`00
0?oooooooooo02oooooo0018ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Qooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Uooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Vooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@02oooooo00?o0000ooooooooool0;ooo
ool004Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
8oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000_ooooo`03o`000?oooooooooo02oooooo0018
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;Oooool00omEEEGoIVIVo`00000aooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomPooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool0
02Sooooo0ol0000Aooooo`?o00004_ooool3o`00017ooooo0ol0000Aooooo`?o00004Oooool3o`00
01;ooooo0ol0000Aooooo`?o00004Oooool3o`00017ooooo0ol0000Booooo`?o00004Oooool3o`00
017ooooo0ol0000Booooo`?o00004Oooool3o`0001Sooooo00Go410@okZj^_o^k^koMgMgoa0@4004
ooooo`006Oooool5o`0000[ooooo1_l0000>ooooo`Ko00003oooool6o`0000kooooo1_l0000>oooo
o`Ko00003_ooool6o`0000oooooo1_l0000>ooooo`Ko00003_ooool6o`0000kooooo1_l0000?oooo
o`Ko00003_ooool6o`0000kooooo1_l0000?ooooo`Ko00003_ooool6o`0001Gooooo00?o0000oooo
ooooool01_ooool001Woooooool0000ko`0000cooooo00?o0000ooooooooool01_ooool001Wooooo
3_l000000ooooooo0000o`000003o`0000Wooooo00?o0000ooooooooool00oooool5o`0000?ooooo
00?o0000ooooooooool02_ooool5o`0000_ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03
o`000?oooooooooo00Oooooo1Ol0000=ooooo`03o`000?oooooo000000Co00002?ooool00ol0003o
ooooooooo`05ooooo`Go000000?oooooo`000?ooool03?ooool5o`0000Wooooo00?o0000oooooooo
ool00oooool5o`0000?ooooo00?o0000ooooooooool02Oooool5o`0000cooooo00Co0000oooooooo
oooooooo1Ol00005ooooo`03o`000?oooooooooo00Oooooo1Ol0000=ooooo`03o`000?oooooo0000
00Co00002?ooool00ol0003oooooooooo`05ooooo`Go000000?oooooo`000?ooool03?ooool5o`00
01Kooooo00?o0000ooooooooool01_ooool001Wooooo4_l0000Aooooo`;o00004oooool3o`00017o
oooo0_l0000Booooo`;o00004?ooool01?l0003oooooo`000?l0000Cooooo`;o00004_ooool2o`00
00cooooo00?o0000ooooooooool00oooool2o`0001;ooooo0_l0000Cooooo`;o00002?ooool00ol0
003oooooooooo`07ooooo`;o00004_ooool2o`0001?ooooo0_l00004ooooo`03o`000?oooooooooo
00_ooooo0_l0000Gooooo`03oa0@4?l0003o000000?o00001Oooool001Wooooo1?l00004ooooo`go
0000oooooolbooooo`03o`000?oooooooooo00Kooooo000Jooooo`?o00002?ooool<o`000?oooooo
;oooool00ol0003oooooooooo`06ooooo`006_ooool3o`0000cooooo2ol0003oooooocGooooo000J
ooooo`Co00003_ooool<o`000?oooooo<Oooool001[ooooo1?l0000Aooooo`ko0000ooooool/oooo
o`006_ooool4o`0001Cooooo3ol0003oooooobSooooo000Jooooo`Co00006?ooool?o`000?oooooo
9?ooool001[ooooo1Ol0000Looooo`oo0000oooooolOooooo`006_ooool5o`00023ooooo3ol0003o
oooooa_ooooo000Jooooo`03o`000?oooooo000000;o00009?ooool?o`000?oooooo5oooool001[o
oooo00?o0000ooooool000000_l0000Yooooo`oo0000oooooolBooooo`006_ooool6o`0002cooooo
3ol0003oooooo`kooooo000Jooooo`03o`000?oooooo000000?o0000<?ooool?o`000?oooooo2_oo
ool001[ooooo00?o0000ooooooooool00ol0000eooooo`go0000ooooool7ooooo`006_ooool00ol0
003oooooooooo`03o`0003Wooooo3?l0003oooooo`Cooooo000Jooooo`03o`000?oooooooooo00Co
0000??ooool;o`000?oooooo0Oooool001[ooooo00?o0000ooooooooool01?l0000oooooo`co0000
o?ooool001[ooooo00Co0000oooooooooooooooo0ol0000=ooooo`03o`000?oooooooooo017ooooo
0_l0000Cooooo`;o00002_ooool>o`0000kooooo1?l0000Aooooo`Co00004?ooool4o`00013ooooo
1?l0000@ooooo`Go00002_ooool2o`0000Cooooo1_l00008ooooo`?o00000oooool6o`0000Sooooo
0ol00003ooooo`Ko00002?ooool3o`0000Cooooo1_l00008ooooo`?o00000oooool6o`0000Sooooo
0ol0000Qooooo`006_ooool01?l0003oooooooooooooool3o`0000kooooo00?o0000ooooooooool0
4_ooool2o`0001?ooooo0ol0000:oooooa3o00003Oooool5o`00013ooooo1Ol00005ooooo`;o0000
2?ooool7o`0000?ooooo0ol00007ooooo`Oo00000oooool3o`0000Sooooo1ol00003ooooo`Co0000
2?ooool>o`0000Kooooo3_l00006ooooo`ko00001oooool>o`0000Kooooo3_l0000Nooooo`006_oo
ool01?l0003oooooooooooooool4o`0000kooooo00?o0000ooooooooool04oooool2o`0001Cooooo
0ol0000;oooooa7o00003Oooool8o`0000gooooo2Ol0000=ooooo`Wo00002oooool9o`0000cooooo
2Ol0000=ooooo`So00003Oooool7o`0000gooooo1ol0000=ooooo`So00003Oooool7o`0001gooooo
000Jooooo`04o`000?ooooooooooooooo`Co00003oooool00ol0003oooooooooo`0Dooooo`;o0000
5Oooool3o`0000?ooooo0_l00008oooooa3o00003_ooool6o`0000kooooo1ol0000>ooooo`Oo0000
3Oooool7o`0000gooooo2?l0000<ooooo`Co00004Oooool3o`00017ooooo0ol0000Aooooo`Co0000
4Oooool3o`00027ooooo000Jooooo`03o`000?oooooooooo00;ooooo0ol0000@ooooo`03o`000?oo
oooooooo01Gooooo0ol0000Eooooo`;o000000Coooooo`000?l0003o00003?ooool?o`0000[ooooo
1ol0000=ooooo`So00003Oooool3o`00017ooooo0ol0002Kooooo`006_ooool00ol0003ooooooooo
o`02ooooo`Co00004?ooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l000004_oo
ool5o`0000oooooo3ol00006ooooo`?o0000f?ooool001[ooooo00?o0000ooooooooool00_ooool4
o`00017ooooo00?o0000ooooooooool06?ooool4o`00017ooooo1_l0000Cooooo`ko0000gOooool0
01[ooooo00?o0000ooooooooool00oooool3o`0001;ooooo00?o0000ooooooooool05oooool5o`00
01Cooooo0ol0000Fooooo`ko0000fOooool001[ooooo0_l00004ooooo`?o00004oooool00ol0003o
ooooooooo`0Eooooo`Oo0000<?ooool>o`000=Gooooo000Jooooo`03o`000?oooooooooo00?ooooo
1?l0000Cooooo`03o`000?oooooo000001Wooooo0ol0000cooooo`go0000d_ooool001[ooooo00?o
0000ooooooooool00oooool4o`0001Cooooo0_l0001Cooooo`go0000c_ooool001[ooooo00?o0000
ooooooooool01?ooool3o`0001?ooooo1?l0001Fooooo`co0000boooool001[ooooo00?o0000oooo
ooooool01?ooool3o`0001Gooooo0ol0001Hooooo`go0000aoooool001[ooooo00?o0000oooooooo
ool01?ooool4o`0001Gooooo0_l0001Looooo`go0000`oooool001Sooooo1?l00005ooooo`Co0000
5oooool00ol0003oooooooooo`1Looooo`ko0000_oooool001Sooooo1?l00006ooooo`?o00006?oo
ool00ol0003oooooooooo`1Oooooo`ko0000^oooool001Sooooo1?l00006ooooo`?o0000O_ooool?
o`000;Kooooo000Iooooo`?o00001_ooool4o`00087ooooo3ol0002booooo`006Oooool2o`0000Oo
oooo1?l00025ooooo`oo0000[_ooool001Wooooo0_l00008ooooo`?o0000R_ooool?o`000:Wooooo
000Jooooo`03o`000?oooooooooo00Kooooo0ol0002>ooooo`oo0000YOooool001[ooooo00?o0000
ooooooooool01_ooool4o`0000Oooooo00?o0000ooooooooool04Oooool2o`0001?ooooo0_l0000B
ooooo`;o00004_ooool2o`0001?ooooo0ol0000Aooooo`?o00003Oooool?o`0000Wooooo1?l0000A
ooooo`Co00004?ooool4o`00013ooooo1?l0000:ooooo`;o00001Oooool4o`0000[ooooo0_l00004
ooooo`Ko00002?ooool3o`00027ooooo000Jooooo`03o`000?oooooooooo00Kooooo1?l00007oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aoooo
o`;o00004_ooool3o`0001?ooooo0ol0000Aooooo`Co00003_ooool=o`0000[ooooo1Ol00005oooo
o`;o00002Oooool5o`0000Gooooo0_l00008ooooo`Oo00000oooool3o`0000Oooooo1ol00003oooo
o`Co00001oooool7o`0000?ooooo1?l00008ooooo`ko00007_ooool001[ooooo0_l00008ooooo`?o
00002?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo0_l0000Cooooo`;o
00004oooool3o`0001?ooooo0ol0000Booooo`Co00000oooool2o`0000Wooooo3?l0000<ooooo`Wo
00003?ooool9o`0000gooooo2Ol0000;ooooo`Wo00003?ooool9o`0000gooooo2?l0000Mooooo`00
6_ooool00ol0003oooooooooo`07ooooo`?o00002?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool2o`0001Cooooo0ol00003ooooo`;o0000
3_ooool3o`000003ooooool0003o0000013ooooo1ol0000;ooooo`_o00003_ooool6o`0000kooooo
1ol0000=ooooo`So00003Oooool7o`0000gooooo2?l0000<ooooo`Co00008Oooool001[ooooo00?o
0000ooooooooool01oooool4o`0000Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Cooooo`;o00005?ooool2o`0000?ooooo00?o0000ooooooooool03oooool2o`000004ooooool0
003o0000o`00013ooooo1Ol0000@ooooo`Ko00003Oooool<o`0000[ooooo1ol0000=ooooo`So0000
3?ooool4o`0005kooooo000Jooooo`03o`000?oooooooooo00Oooooo1?l00008ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05?ooool2o`0001Cooooo0_l000000ooooooo0000o`00
000Booooo`Go00003oooool7o`0000kooooo1ol0000=oooooa3o0000Soooool001[ooooo00?o0000
ooooooooool02?ooool3o`0000Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooo000001?ooooo1?l0000Aooooo`Ko00003_ooool8o`0002Kooooo3ol0002;
ooooo`006_ooool00ol0003oooooooooo`08ooooo`?o00002Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01Gooooo0ol0000Booooo`Go00005?ooool3o`0003oooooo3ol00027oooo
o`006_ooool00ol0003oooooooooo`08ooooo`Co00002Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooo000001Cooooo1?l0000Dooooo`?o0000F_ooool?o`0008;ooooo000Jooooo`03o`00
0?oooooooooo00Sooooo1?l00009ooooo`03o`000?oooooooooo01Oooooo0_l0000Dooooo`Go0000
5_ooool00ol0003oooooooooo`1Kooooo`oo0000O_ooool001[ooooo00?o0000ooooooooool02Ooo
ool3o`0000[ooooo00?o0000ooooooooool05_ooool3o`0001Kooooo0ol0001gooooo`oo0000N_oo
ool001[ooooo00?o0000ooooooooool02Oooool3o`0000[ooooo00Co0000ooooool0003o00005?oo
ool5o`0001Sooooo00?o0000ooooooooool0NOooool?o`0007Gooooo000Jooooo`03o`000?oooooo
oooo00Wooooo1?l0000:ooooo`?o00005_ooool3o`0009Sooooo3ol0001aooooo`0000Co<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo00Wooooo1?l00009
ooooo`Co00006?ooool2o`0009_ooooo3ol0001]ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A004ooooo`Co00002oooool3o`0000Wooooo1?l0
000Jooooo`03o`000?oooooooooo09gooooo3Ol0001Zooooo`000oooool00ol@413oooooooooo`0:
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo1?l0000;ooooo`?o00002_ooool4o`000;gooooo3?l0001W
ooooo`000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Gooooo1?l0000:oooo
o`Co00002_ooool3o`000<7ooooo2ol0001Tooooo`000oooool00ol0003oooooooooo`0<ooooo`03
ogMgMomVIVKooooo00Cooooo0ol0000;ooooo`Co00002oooool2o`000<Cooooo3?l0001Pooooo`00
0oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l0000=ooooo`?o0000
3?ooool00ol0003oooooooooo`35ooooo`ko0000Foooool00004oiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00_ooooo0ol0003Gooooo`oo
0000Eoooool00004oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo00_ooooo0ol00003ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`;o00004_ooool2o`0001?ooooo0_l0000Boooo
o`;o00004_ooool2o`0001;ooooo0ol0000Booooo`?o00004Oooool3o`0000[ooooo3ol0000=oooo
o`?o00004Oooool4o`0002kooooo000Jooooo`03o`000?oooooooooo00_ooooo1?l00002ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo0_l0000Cooooo`;o00004_ooool3o`00017ooooo0ol0000Booooo`?o
00004_ooool3o`00017ooooo1?l0000;ooooo`oo00002oooool5o`00013ooooo1Ol00005ooooo`;o
00008_ooool001[ooooo00?o0000ooooooooool02oooool4o`0000?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool2o`0001?ooooo0_l0000Cooooo`;o00004_ooool3o`0001;ooooo0ol0000Booooo`?o0000
1Oooool2o`0000_ooooo1?l00003ooooo`;o00001_ooool@o`0000_ooooo1Ol000000ooooooo0000
o`00000=ooooo`Wo00008?ooool001[ooooo00?o0000ooooooooool03?ooool3o`0000?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo0_l0
000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Cooooo`;o00004oooool3o`0000?ooooo0_l0
000=ooooo`Co000000?oooooo`000?l000003_ooool3o`0000;ooooo0ol0000>ooooo`Oo00002?oo
ool@o`0000cooooo1_l0000>ooooo`Oo00007_ooool001[ooooo00?o0000ooooooooool03?ooool3
o`0000?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool2o`0001Cooooo0_l0000Cooooo`?o000000?ooooo
o`000?l000004?ooool2o`000004ooooool0003o0000o`00013ooooo1Ol0000?ooooo`Ko00003ooo
ool7o`0000_ooooo3_l00009ooooo`Oo00003Oooool8o`0001gooooo000Jooooo`03o`000?oooooo
oooo00cooooo1?l00003ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000004Oooool4o`00017ooooo1Ol0000?ooooo`Oo00003_ooool6o`0000kooooo2?l0000<
ooooo`oo00001_ooool3o`0003Kooooo000Jooooo`03o`000?oooooooooo00cooooo1?l00003oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`;o00005Oooool4o`0001;ooooo1?l0000@ooooo`Ko00003oooool6o`0000kooooo2?l0000Aoooo
o`?o0000:?ooool;o`0003cooooo000Jooooo`03o`000?oooooooooo00gooooo0ol00003ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooo000001Cooooo0ol0000Aooooo`Go00003oooool7o`0001;ooooo0ol0001Dooooo`co
0000>?ooool001[ooooo00?o0000ooooooooool03Oooool3o`0000Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo0_l0000Cooooo`Go0000
3oooool7o`0001?ooooo0ol0001[ooooo`go0000=?ooool001[ooooo00?o0000ooooooooool03Ooo
ool4o`0000?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooo000001?ooooo0ol0000Eooooo`?o00004oooool3o`0008?ooooo3_l0000`ooooo`006_ooool2
o`0000kooooo1?l00004ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool2
o`0001;ooooo1Ol0000Gooooo`03o`000?oooooooooo09[ooooo3_l0000/ooooo`006_ooool00ol0
003oooooooooo`0>ooooo`?o00001?ooool00ol0003oooooooooo`0Dooooo`04o`000?oooooo0000
o`0001?ooooo1?l0000Dooooo`?o0000]oooool?o`0002Oooooo000Jooooo`03o`000?oooooooooo
00kooooo0ol00004ooooo`03o`000?oooooooooo01Cooooo1?l0000Eooooo`?o00005_ooool00ol0
003oooooooooo`2hoooooa3o00008_ooool001[ooooo00?o0000ooooooooool03_ooool4o`0000Co
oooo0_l0000Eooooo`Co00005_ooool00ol0003oooooooooo`3Coooooa3o00007_ooool001Sooooo
1?l0000?ooooo`Co00000_ooool4o`0001Kooooo0ol0000Gooooo`03o`000?oooooooooo0=Oooooo
3ol0000Jooooo`006?ooool4o`00013ooooo0ol00002ooooo`Co00005oooool2o`000?Kooooo3_l0
000Fooooo`006Oooool3o`00013ooooo0ol00003ooooo`?o00006?ooool2o`000?Wooooo3?l0000D
ooooo`006Oooool3o`00013ooooo1?l00003ooooo`?o00006?ooool00ol0003oooooooooo`3koooo
o`So00005?ooool001Wooooo0_l0000Aooooo`Co00001?ooool2o`000?oooooo6oooool4o`0001Co
oooo000Jooooo`03o`000?oooooooooo013ooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo
<Oooool001[ooooo00?o0000ooooooooool04?ooool3o`0001;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo0_l0000Cooooo`;o00004_oo
ool2o`0001;ooooo0_l0000Booooo`;o00004oooool2o`0001;ooooo0_l0000Booooo`;o00004ooo
ool3o`00017ooooo0ol0000_ooooo`006_ooool00ol0003oooooooooo`0@ooooo`?o00004_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo0_l0000Booooo`;o00004_ooool3
o`0001;ooooo0ol0000Aooooo`?o00004Oooool3o`0001?ooooo0ol0000Aooooo`?o0000;?ooool0
01[ooooo00?o0000ooooooooool04?ooool4o`0001;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool2o`00
01?ooooo00?o0000ooooooooool04Oooool2o`0001?ooooo0_l0000Cooooo`;o00004_ooool3o`00
017ooooo0ol0000Cooooo`?o00004Oooool3o`0002Wooooo000Jooooo`03o`000?oooooooooo013o
oooo1?l0000Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool2o`0001?o
oooo0_l0000Cooooo`;o00004oooool2o`0001?ooooo0ol0000Aooooo`?o00000oooool2o`0000ko
oooo0ol000000ooooooo0000o`00000>ooooo`?o00000_ooool2o`0002;ooooo000Jooooo`;o0000
4_ooool3o`0001?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo0_l0000Dooooo`;o00004oooool2o`0001?ooooo0_l0000Cooooo`?o0000
0_ooool2o`0000kooooo0ol000000ooooooo0000o`00000@ooooo`;o000000?oooooo`000?l00000
3oooool2o`000004ooooool0003o0000o`00013ooooo1Ol0000?ooooo`Ko00008?ooool001[ooooo
00?o0000ooooooooool04Oooool3o`0001Cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo0_l000000ooooooo0000o`00000Aooooo`Go0000
4?ooool4o`00017ooooo1Ol0000?ooooo`Go00003oooool7o`0000kooooo1_l0000Oooooo`006_oo
ool00ol0003oooooooooo`0Aooooo`Co00004oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo0_l000000ooooooo0000ooooo`0Aooooo`Co00004Oooool5o`0000oooooo1_l0
000?ooooo`Ko00003_ooool6o`0000kooooo2?l0000=ooooo`Oo00007_ooool001[ooooo00?o0000
ooooooooool04Oooool4o`0001Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool3o`0001?ooooo0ol0000A
ooooo`Go00004?ooool6o`0000kooooo1ol0000Booooo`?o00004Oooool3o`0004Oooooo000Joooo
o`03o`000?oooooooooo01;ooooo0ol0000Dooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000001?ooooo0ol0000Boooo
o`Co00004?ooool6o`0001?ooooo0ol0000Booooo`?o0000Koooool001[ooooo00?o0000oooooooo
ool04_ooool3o`0001Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooo000001?ooooo0_l0000Booooo`Go00004?ooool6o`0001?ooooo0ol0002Iooooo`00
6_ooool00ol0003oooooooooo`0Booooo`Co00005?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooo000001Cooooo0_l0000Booooo`Co00005?ooool3o`0001?ooooo0ol0002^ooooo`006_oo
ool00ol0003oooooooooo`0Booooo`Co00005Oooool00ol0003oooooooooo`0Dooooo`;o00004ooo
ool4o`0001?ooooo0ol0000Fooooo`03o`000?oooooooooo0<7ooooo000Jooooo`03o`000?oooooo
oooo01?ooooo0ol0000Eooooo`?o00004oooool4o`0001Cooooo0ol0000Dooooo`;o0000fOooool0
01[ooooo00?o0000ooooooooool04oooool4o`0001?ooooo1?l0000Eooooo`;o00005_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0=Kooooo000Hooooo`Co00005?ooool4o`0001Co
oooo1?l0000Eooooo`;o00005_ooool00ol0003oooooooooo`3/ooooo`006?ooool4o`0001Cooooo
1?l0000Eooooo`?o00005_ooool00ol0003oooooooooo`3oooooo`Cooooo000Iooooo`?o00005Ooo
ool3o`0001Kooooo0_l0000Gooooo`03o`000?oooooooooo0?oooooo0oooool001Wooooo0ol0000E
ooooo`?o00005oooool2o`000?oooooo7?ooool001Wooooo0ol0000Eooooo`?o00006?ooool00ol0
003oooooooooo`3ooooooa[ooooo000Jooooo`03o`000?oooooooooo01Cooooo1?l0003oooooocCo
oooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?l0000=ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo0_l0000Booooo`;o00004_ooool2o`0001;ooooo0_l0000Cooooo`;o0000
4_ooool2o`0001;ooooo0_l0000Cooooo`;o00004_ooool2o`00033ooooo000Jooooo`03o`000?oo
oooooooo017ooooo00Co0000oooooooooooooooo0ol0000=ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
0_l0000Cooooo`;o00004_ooool2o`0001;ooooo0ol0000Booooo`;o00004_ooool3o`0002gooooo
000Jooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooooooo0ol0000>ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`;o0000
4oooool2o`0001?ooooo0_l0000Booooo`;o00004oooool2o`0001;ooooo0ol0000Booooo`?o0000
:_ooool001[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04o`0000gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`;o00004oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo0_l0000Booooo`;o00004oooool2o`0001?ooooo0_l0
000Cooooo`?o00009oooool001[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04
o`0000gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo0_l0000Cooooo`;o00005?ooool2o`0001;ooooo0_l0000Cooooo`?o00000_ooool2
o`0000kooooo0_l00002ooooo`;o00004?ooool2o`000003ooooool0003o000002;ooooo000Joooo
o`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo0ol0000>ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`;o00004oooool2
o`0001Cooooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l000004Oooool5
o`0000oooooo1Ol0000Aooooo`Go00008?ooool001[ooooo00?o0000ooooooooool04_ooool01?l0
003oooooooooooooool3o`0000kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0000D
ooooo`03o`000?oooooooooo01;ooooo1?l0000Booooo`Co00004?ooool4o`00017ooooo1Ol0000?
ooooo`Go00004?ooool6o`0001oooooo000Jooooo`03o`000?oooooooooo01;ooooo00Co0000oooo
oooooooooooo1?l0000>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooo`00000Booooo`?o00004oooool3o`00017ooooo1Ol0000?ooooo`Go00004?ooool6
o`0000kooooo1_l0000>ooooo`So00007_ooool001[ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`04o`0000kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool2o`0001?ooooo0_l0000Coooo
o`?o00004Oooool5o`00013ooooo1_l0000>ooooo`Ko00004oooool3o`00017ooooo0ol0000coooo
o`006_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`?o00003oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0
003oooooo`00000Dooooo`03o`000?oooooooooo017ooooo0ol0000Aooooo`Go00004?ooool6o`00
01?ooooo0ol0000Aooooo`?o0000G?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`04o`000?oooooooooo
ooooo`?o00003oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooool000004oooool2o`0001?ooooo0ol0000Aooooo`Go00004oooool3o`0001?ooooo0ol00025
ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`Co00003_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Cooooo0_l0000Booooo`Co00004Oooool5o`0001?ooooo0ol0
000Eooooo`03o`000?oooooooooo09Sooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooooooo1?l0000?ooooo`03o`000?oo
oooooooo01?ooooo0ol0000Cooooo`Co00004oooool3o`0001?ooooo0ol0000Eooooo`03o`000?oo
oooooooo0:gooooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`0001Cooooo00Co0000oooooooooooooooo0ol0000?ooooo`?o00004oooool3o`0001Gooooo
0_l0000Dooooo`;o00005_ooool00ol0003oooooooooo`32ooooo`000oooool00ol0003ooooooooo
o`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo0_l0000Cooooo`Co00000_ooool3o`0000kooooo
1?l0000Cooooo`Co00005Oooool2o`0001Gooooo00?o0000ooooooooool0f?ooool000?ooooo00?o
410@ooooooooool02_ooool00omgMgOoc<c<o`000005ooooo`Co00004oooool4o`0000;ooooo1?l0
000=ooooo`Co00005?ooool3o`0001Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`3Gooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000005ooooo`Co00005?oo
ool3o`0000;ooooo1?l0000>ooooo`?o00005Oooool2o`0001Oooooo00?o0000ooooooooool0kOoo
ool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01Oooool3o`0001Cooooo0ol0
0003ooooo`?o00003oooool3o`0001Gooooo0_l0003oooooo`Oooooo000Iooooo`;o00005_ooool2
o`0000?ooooo0ol0000@ooooo`;o00005_ooool00ol0003oooooooooo`3oooooo`Gooooo000Ioooo
o`;o00005_ooool2o`0000?ooooo1?l0000@ooooo`03o`000?oooooooooo0?oooooo7?ooool001[o
oooo00?o0000ooooooooool05Oooool01?l0003oooooooooooooool4o`000?oooooo;oooool001[o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`?o00002?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo0_l0000Booooo`;o00004_ooool2o`0001?o
oooo0_l0000Booooo`;o00004_ooool2o`0001?ooooo0_l0000Booooo`;o0000<?ooool001[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`?o00002?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo0_l0000Booooo`;o00004_ooool2o`0001?ooooo
0_l0000Booooo`;o0000;_ooool001[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`06ooooo`Co00002?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`;o00005?ooool00ol0003ooooooooo
o`0Aooooo`;o00004_ooool2o`0001?ooooo0ol0000Aooooo`?o0000:oooool001[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`05ooooo`Co00002?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool2o`0001?ooooo00?o0000
ooooooooool04_ooool2o`0001?ooooo0_l0000Booooo`;o00005?ooool2o`0001;ooooo0_l0000Y
ooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo0ol00008oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo0_l0000Dooooo`;o00004oooool2o`0001;ooooo0_l0000Doooo
o`;o00000_ooool2o`0000kooooo0_l00002ooooo`;o00008oooool001[ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`06ooooo`?o00002Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`;o
00005?ooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`000?l000003oooool2o`000003
ooooool0003o0000017ooooo1Ol0000?ooooo`Go00008_ooool001[ooooo0_l0000Cooooo`03o`00
0?oooooooooo00Kooooo1?l00008ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool2o`0001?ooooo0_l0000Dooooo`04o`000?ooooooooooo`00017ooooo0_l000000ooooooo
0000ooooo`0Aooooo`Co00004?ooool4o`00017ooooo1Ol0000?ooooo`Go00008Oooool001[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`Co00002?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
o`00000Booooo`?o00004oooool3o`00017ooooo1Ol0000?ooooo`Go00004?ooool6o`0000kooooo
1_l0000Pooooo`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo0ol0
0009ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool3o`0001;ooooo0_l0
000Cooooo`?o00004Oooool5o`00013ooooo1_l0000Aooooo`?o00004oooool3o`00017ooooo0ol0
000Oooooo`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo0ol00009
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Cooooo0ol0000Booooo`?o00004Oooool4o`00017ooooo1Ol0000C
ooooo`?o00004oooool3o`0001?ooooo00?o0000ooooooooool0A_ooool001[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`06ooooo`Co00002Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooo`00000Coooo
o`?o00004Oooool5o`0001;ooooo0ol0000Cooooo`?o00005Oooool00ol0003oooooooooo`1_oooo
o`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo1?l00009ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool3o`0001?ooooo0_l0000Booooo`Go
00004_ooool4o`0001?ooooo0_l0000Eooooo`03o`000?oooooooooo08Cooooo000Jooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01oooool3o`0000Wooooo00?o0000ooooooooool0
5?ooool2o`0001;ooooo1?l0000Booooo`Co00004oooool4o`0001?ooooo0_l0000Eooooo`03o`00
0?oooooooooo09Wooooo000Jooooo`03o`000?oooooooooo01Cooooo0_l00007ooooo`?o00002_oo
ool2o`0001?ooooo0ol0000Cooooo`Co00004oooool3o`0001Cooooo0_l0000Eooooo`03o`000?oo
oooooooo0:kooooo000Hooooo`Co00004oooool4o`0000Oooooo1?l00007ooooo`Co00004oooool4
o`0001?ooooo0ol0000Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0`oooool0
01Sooooo1?l0000Cooooo`Co00001oooool4o`0000Oooooo1?l0000Dooooo`?o00005?ooool2o`00
01Kooooo00?o0000ooooooooool0fOooool001Wooooo0ol0000Dooooo`?o00002?ooool3o`0000So
oooo0ol0000Eooooo`;o00005Oooool2o`000?7ooooo000Iooooo`?o00005?ooool3o`0000Sooooo
0ol00009ooooo`?o00005Oooool2o`0001Gooooo00?o0000ooooooooool0koooool001Wooooo0_l0
000Fooooo`;o00002?ooool4o`0000Wooooo0_l0000Fooooo`03o`000?oooooooooo0?oooooo1_oo
ool001[ooooo00?o0000ooooooooool05?ooool2o`0000Sooooo1?l0000:ooooo`03o`000?oooooo
oooo0?oooooo7Oooool001[ooooo0_l0000Booooo`05o`000?ooooooooooooooool000002Oooool3
o`0000?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo0_l0000Booooo`;o00004oooool2o`0001;ooooo0_l0000Booooo`;o00004oooool2
o`0001;ooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00_ooooo0ol00003ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo0_l0000Cooooo`;o00004_ooool2o`00
02kooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool4o`0000;o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017o
oooo0_l0000Cooooo`;o00004oooool00ol0003oooooooooo`0Aooooo`;o0000;?ooool001[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`Co00000oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`;o00004oooool2o`0001?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`;o00004oooool2o`0002[ooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02oooool3o`0000?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo0_l0000Cooooo`;o00004oooool2o`0001?ooooo0_l0
000Xooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo0ol00003
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`;o00004oooool2o`0001?ooooo00Go0000ooooooooooooooooo`00000@ooooo`;o000000?o
ooooo`000?l000008oooool001[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;
ooooo`Co00000oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool2o`0001?ooooo0_l0000Cooooo`;o00005?ooool01?l0003oooooooooool0
000Aooooo`Co00004?ooool2o`000003ooooool0003ooooo017ooooo1?l0000Rooooo`006_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo1?l00003ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooool000004_ooool00ol0003oooooo`00000Booooo`?o00004oooool3
o`00017ooooo0ol0000Aooooo`Go00008Oooool001[ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0<ooooo`?o00000oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04oooool00ol0003oooooo`00000Booooo`;o00004oooool2o`00
01?ooooo0ol0000Aooooo`Go00003oooool5o`00013ooooo1_l0000Pooooo`006_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00cooooo0ol00004ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000Cooooo`;o00004_ooool3o`00017o
oooo1?l0000Aooooo`Go00004oooool3o`00017ooooo0ol0000Cooooo`?o00007oooool001[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`Co00000oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooo000001?ooooo0_l0000Booooo`Co00004?ooool5o`0001;ooooo
0ol0000Cooooo`?o00005Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo
000Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool4o`0000?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000001?ooooo0ol0
000Cooooo`;o00004_ooool4o`0001?ooooo0ol0000Booooo`?o00004oooool2o`0001Gooooo00?o
0000ooooooooool0Foooool001[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<
ooooo`?o00001?ooool00ol0003oooooooooo`0Cooooo`?o00004_ooool3o`0001;ooooo1?l0000B
ooooo`Co00004oooool3o`0001Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo073ooooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03?ooool3o`0000Cooooo0ol0000Cooooo`?o00004_ooool3o`0001Cooooo0ol0000Coooo
o`?o00005?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09[ooooo000Hooooo`Co
00004oooool4o`0000cooooo1?l00002ooooo`Co00004_ooool4o`0001;ooooo1?l0000Dooooo`;o
00005Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0:oooooo000Hooooo`Co0000
4oooool4o`0000cooooo1?l00002ooooo`Co00004_ooool4o`0001?ooooo0ol0000Eooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0a?ooool001Wooooo0ol0000Dooooo`?o00003Ooo
ool3o`0000?ooooo0ol0000Cooooo`Co00004oooool2o`0001Kooooo00?o0000ooooooooool0f_oo
ool001Wooooo0ol0000Dooooo`?o00003Oooool3o`0000Cooooo0_l0000Dooooo`?o00005?ooool2
o`000?;ooooo000Iooooo`;o00005Oooool2o`0000kooooo1?l00003ooooo`;o00005Oooool2o`00
01Gooooo00?o0000ooooooooool0l?ooool001[ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0<ooooo`Co00001?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oo
oooo1oooool001[ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000?ooooo`?o
00004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool2o`0001?ooooo0_l0000Booooo`;o00004_ooool2o`0001?ooooo0_l0000Booooo`;o
0000<?ooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`?o0000
4oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo0_l0000^ooooo`006_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo1?l0000Cooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`;o00004ooo
ool2o`0001?ooooo00?o0000ooooooooool0:oooool001[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0@ooooo`Co00004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool2
o`0002_ooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool3o`00
01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04_ooool2o`0001?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`;o00004oooool2o`0002Wooooo000Jooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04?ooool3o`0001Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo0_l0000Dooooo`;o00004oooool00ol0003o
ooooooooo`0Vooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool4o`00
01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`;o00004oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooo0000017ooooo0_l000000ooooooo0000ooooo`0Soooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool4o`0001?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo0_l0000D
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooool000004Oooool2o`000003ooooool0003o
oooo017ooooo0ol0000Booooo`?o00008oooool000?ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol0000Booooo`03o`000?oooooooooo017ooooo0ol0000D
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooo000001;ooooo00?o0000ooooool000004_ooool2o`0001?ooooo0_l0000B
ooooo`Co00004Oooool4o`0002;ooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool4
o`0001?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`04o`000?oooooo
ooooo`0001?ooooo0_l0000Cooooo`;o00004_ooool3o`00017ooooo1?l0000Aooooo`Go00003ooo
ool6o`00027ooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool4o`0001Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooo`00000Booooo`?o00004oooool3o`00017ooooo1?l0
000@ooooo`Go00004_ooool3o`0001?ooooo0ol0000Booooo`?o00008?ooool000?ooooo00?o410@
ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04Oooool3o`0001Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`?o00004oooool2o`0001?ooooo0_l0000Booooo`Co00004Oooool5o`0001;ooooo0ol0000B
ooooo`?o00004oooool2o`0001Gooooo00?o0000ooooooooool0<_ooool00004oiRHV?ooooooV9RH
ogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo017ooooo0ol0000Dooooo`03o`000?oooooooooo01?ooooo0ol0000Booooo`?o00004_ooool3
o`0001;ooooo1?l0000Cooooo`;o00004oooool3o`0001Cooooo0_l0000Dooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Aoooool00004oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo1?l0
000Dooooo`;o00004oooool3o`00017ooooo1Ol0000Cooooo`;o00004oooool2o`0001Cooooo0_l0
000Dooooo`;o00005Oooool00ol0003oooooooooo`1`ooooo`006?ooool4o`0001;ooooo1?l0000B
ooooo`Co00004_ooool4o`0001;ooooo1?l0000Cooooo`?o00005?ooool2o`0001?ooooo0_l0000D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0QOooool001Sooooo1?l0000Boooo
o`Co00004_ooool4o`0001;ooooo1?l0000Cooooo`?o00005?ooool2o`0001Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09_ooooo000Hooooo`Co
00004oooool3o`0001?ooooo0ol0000Cooooo`?o00005?ooool3o`0001Cooooo0_l0000Eooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0/?ooool001Wooooo0ol0000Cooooo`?o0000
4oooool4o`0001?ooooo0ol0000Dooooo`;o00005Oooool00ol0003oooooooooo`3Kooooo`006Ooo
ool2o`0001Gooooo0_l0000Cooooo`Co00005?ooool2o`0001Gooooo00?o0000ooooooooool0lOoo
ool001Wooooo0_l0000Eooooo`;o00005?ooool3o`0001Gooooo00?o0000ooooooooool0ooooool8
ooooo`006_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo0ol0003ooooo
ob3ooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool01?l0003o
ooooooooooooool4o`0000gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo0_l0000Cooooo`;o00004_ooool2o`0001;ooooo0_l0000Coooo
o`;o00004_ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool01?l0003oooooooooooooool4o`0000gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`;o0000;_ooool001[ooooo0_l0000Booooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00_ooool3o`0000gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool2o`0001?o
oooo00?o0000ooooooooool0:oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`04o`000?ooooooooooooooo`?o00003_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo0_l0000Booooo`;o00005?ooool00ol0003oooooooooo`0Aooooo`;o
0000:oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`04o`00
0?ooooooooooooooo`Co00003Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`0002Wo
oooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool01?l0003ooooo
ooooooooool4o`0000gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02Kooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`02ooooo`?o00003_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`;o0000
4oooool2o`0001;ooooo0_l0000Dooooo`04o`000?ooooooooooo`00017ooooo1?l0000Tooooo`00
6_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo
oooo0ol0000>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooo`00000Aooooo`03o`000?oooooo000001;ooooo0ol0000Cooooo`?o00008oooool001[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`Co
00003Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooo`00000Cooooo`;o00004oooool2o`0001;ooooo0_l0000Cooooo`?o
00004Oooool5o`0002;ooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool01?l0003oooooooooooooool4o`0000kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`04o`000?oooooo0000o`0001;ooooo0_l0000Cooooo`;o00004oooool3o`00
017ooooo0ol0000Aooooo`Go00004oooool3o`00027ooooo000Jooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04oooool01?l0003oooooooooooooool3o`0000kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo0ol0000Aoooo
o`04o`000?oooooo0000o`0001;ooooo0ol0000Booooo`?o00004Oooool4o`00017ooooo1Ol0000B
ooooo`;o00004oooool3o`0001Gooooo00?o0000ooooooooool07_ooool001[ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`?o00003_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooool000004oooool3
o`0001;ooooo0ol0000Aooooo`Go00004?ooool5o`0001;ooooo0ol0000Cooooo`?o00004oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03?ooooo000Jooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04oooool01?l0003oooooooooooooool4o`0000kooooo0ol0000B
ooooo`?o00004oooool2o`0001;ooooo1Ol0000@ooooo`Go00004_ooool3o`0001;ooooo0ol0000D
ooooo`;o00005Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo000Joooo
o`03o`000?oooooooooo01;ooooo0ol0000Cooooo`?o000000?oooooo`000?l000000_l0000=oooo
o`Co00004Oooool4o`0001;ooooo1?l0000Cooooo`?o00004_ooool3o`0001?ooooo0ol0000Coooo
o`;o00005Oooool00ol0003oooooooooo`1aooooo`006?ooool4o`0001;ooooo1?l0000Booooo`Co
00000_ooool3o`0000gooooo1?l0000Aooooo`Co00004oooool3o`0001Cooooo0_l0000Cooooo`;o
00005Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08Kooooo000Hooooo`Co0000
4_ooool4o`0001;ooooo1?l00002ooooo`Co00003Oooool3o`0001;ooooo0ol0000Dooooo`;o0000
5Oooool2o`0001?ooooo0_l0000Eooooo`03o`000?oooooooooo09_ooooo000Iooooo`?o00004ooo
ool3o`0001?ooooo0ol00002ooooo`Co00003Oooool3o`0001?ooooo0ol0000Dooooo`;o00005Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;7ooooo000Iooooo`?o00004oooool2
o`0001Gooooo0_l00003ooooo`?o00003_ooool2o`0001Cooooo0_l0000Eooooo`03o`000?oooooo
oooo0=cooooo000Iooooo`;o00005?ooool2o`0001Gooooo0_l00003ooooo`?o00003_ooool2o`00
01Gooooo00?o0000ooooooooool0l_ooool001[ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Dooooo`04o`000?ooooooooooooooo`Co00003_ooool00ol0003oooooooooo`3ooooo
o`Wooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooool000004Oooool00ol0003o
ooooooooo`06ooooo`Co00002?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017o
oooo0_l0000Booooo`;o00004oooool2o`0001;ooooo0_l0000`ooooo`006_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool3o`0000Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02gooooo
000Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`07ooooo`?o00002?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0;?ooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo0_l0000B
ooooo`;o0000;?ooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`;o00005?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02Wooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`07ooooo`?o00002?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0:?ooool001[ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo0ol00009ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool2o`0001?ooooo00?o0000ooooooooool0
4_ooool2o`0001;ooooo0_l0000Xooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01oooool4o`0000Sooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooo`00000Aooooo`03o`000?oooooo000002Gooooo000Jooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`Co00002?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo0_l0000Booooo`03o`000?oooooo
000001?ooooo0_l0000Booooo`;o00009Oooool001[ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo0ol00009ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`04o`000?oooooooooo
o`0001;ooooo0ol0000Booooo`;o00004oooool2o`0001?ooooo0ol0000@ooooo`Co00009?ooool0
01[ooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool3o`00
00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00000Booooo`03o`000?oooooo0000
01;ooooo0ol0000Booooo`?o00004Oooool4o`00017ooooo1?l0000Aooooo`Go00004Oooool3o`00
02?ooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`07ooooo`Co00002?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04oooool3o`0001;ooooo0ol0000Cooooo`;o00004_ooool4o`00013o
oooo1Ol0000Booooo`?o00004_ooool3o`0001?ooooo0ol0000Booooo`;o00008_ooool001[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo
1?l00009ooooo`03o`000?oooooooooo01;ooooo0ol0000Booooo`?o00004_ooool3o`0001;ooooo
1?l0000Aooooo`Co00004oooool2o`0001;ooooo1?l0000Cooooo`;o00004oooool2o`0001Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Oooooo`006_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo0ol00007ooooo`?o00002Oooool2o`0001;ooooo1?l0
000Aooooo`Co00004Oooool5o`0001;ooooo0ol0000Cooooo`;o00005?ooool2o`0001?ooooo0_l0
000Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B?ooool001Sooooo1?l0000B
ooooo`Co00004_ooool4o`0000Oooooo0ol00007ooooo`Co00004_ooool4o`00017ooooo1?l0000C
ooooo`?o00004oooool2o`0001Cooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0L_ooool001Sooooo1?l0000Booooo`Co00004_ooool4o`0000Oooooo1?l00006oooo
o`Co00004oooool3o`0001;ooooo0ol0000Dooooo`;o00005?ooool2o`0001Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`27ooooo`006Oooool3o`0001?ooooo0ol0000Cooooo`?o
00001oooool4o`0000Oooooo0ol0000Dooooo`?o00004_ooool3o`0001Cooooo0_l0000Dooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0W?ooool001Wooooo0ol0000Cooooo`?o0000
4oooool2o`0000Wooooo0ol00008ooooo`?o00004oooool3o`0001?ooooo0_l0000Eooooo`03o`00
0?oooooooooo0<Oooooo000Iooooo`;o00005?ooool2o`0001Cooooo0_l00009ooooo`?o00002Ooo
ool2o`0001Cooooo0_l0000Dooooo`03o`000?oooooooooo0=gooooo000Jooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`Co00002Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?;ooooo000Jooooo`03o`000?oooooooooo
017ooooo00?o0000ooooool000004Oooool01Ol0003ooooooooooooooooo000000Wooooo1?l00003
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`;o00004oooool2o`0001;ooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool3o`0000?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02gooooo00001?lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo0ol00003
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0/
ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0;ooooo`Co00000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0:oooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0000Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02ooo
ool4o`0000?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`;o0000:ooo
ool000?ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo0ol0
0003ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Xooooo`000oooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?oo
ool3o`0000?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool2o`0001?ooooo00?o0000ooooooooool09ooo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo1?l0
0003ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Vooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo
1?l00003ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`04o`000?ooooooooooo`0001;ooooo0_l0000Booooo`03o`000?oooooo000002Go
oooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool3o`00
00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000Booooo`03o`000?oooooo
000001;ooooo00?o0000ooooool000004_ooool2o`0001?ooooo0_l0000Uooooo`006_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool3o`00
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooool000004_ooool00ol0003oooooo`00000Cooooo`;o00004oooool3o`00
013ooooo1?l0000Aooooo`Co00009?ooool001[ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00cooooo1?l00003ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?o
oooo0ol0000Booooo`?o00004_ooool2o`0001?ooooo0ol0000Aooooo`Co00004Oooool4o`0001;o
oooo0ol0000Booooo`?o00008oooool001[ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00cooooo1?l00003ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool01?l0003oooooo`000?l0000Booooo`?o00004_ooool3o`00017o
oooo1?l0000Aooooo`Co00004Oooool4o`0001?ooooo0ol0000Booooo`?o00004oooool2o`0001?o
oooo0_l0000Rooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03?ooool3o`0000?ooooo0ol0000Cooooo`;o00004oooool3o`00017ooooo
1?l0000Aooooo`Go00004_ooool3o`0001;ooooo0_l0000Cooooo`?o00005?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Oooooo`006?ooool4o`0001;ooooo1?l0000Aooooo`Co00003Oooool3o`0000;ooooo1?l0
000Aooooo`Co00004_ooool4o`00017ooooo1?l0000Cooooo`?o00004oooool2o`0001?ooooo0_l0
000Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`19ooooo`006?ooool4o`0001;ooooo1?l0000Aooooo`Co00003Oooool3o`0000;ooooo1?l0000A
ooooo`Co00004_ooool4o`0001;ooooo0ol0000Dooooo`;o00005?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Loooool001Wooooo0ol0000Coooo
o`?o00004_ooool3o`0000gooooo1?l00002ooooo`?o00004_ooool3o`0001?ooooo1?l0000Boooo
o`?o00005?ooool2o`0001Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`28oooo
o`006Oooool3o`0001?ooooo0ol0000Booooo`?o00003Oooool4o`0000;ooooo0ol0000Cooooo`?o
00004oooool3o`0001?ooooo0_l0000Eooooo`03o`000?oooooooooo0;;ooooo000Iooooo`?o0000
4oooool2o`0001Cooooo0_l0000>ooooo`?o00000oooool2o`0001Cooooo0_l0000Dooooo`;o0000
5?ooool00ol0003oooooooooo`38ooooo`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo0_l0000>ooooo`?o00000oooool2o`0001Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`3Mooooo`006_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
0000017ooooo00Go0000ooooooooooooooooo`00000>ooooo`Co00000oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool4o`0001;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`006_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool3o`0001;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0/ooooo`006_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool3o`0001?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0[ooooo`006_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04?ooool4o`0001;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Zooooo`006_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04?ooool4o`0001;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Yooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool3o`0001?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Xooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool3o`0001?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Wooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04?ooool4o`0001;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooo`00000Vooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04?ooool4o`0001?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooo000001;ooooo00?o0000ooooool000004_ooool2o`0002Kooooo
000Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`?o00004oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool3o`0001;ooooo0ol0000Booooo`;o00004oooool2o`0001;ooooo0ol0
000Uooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool3o`0001?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00000B
ooooo`03o`000?oooooo000001;ooooo0ol0000Booooo`?o00004Oooool4o`00017ooooo1?l0000@
ooooo`Go00009?ooool001[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo1?l0000Booooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool3o`0001;ooooo0ol0000Booooo`?o00004oooool2o`00017ooooo1Ol0000@oooo
o`Go00004_ooool3o`0001;ooooo0ol0000Aooooo`?o00009?ooool001[ooooo0_l0000Cooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool4o`0001?ooooo0ol0000Booooo`?o
00004_ooool3o`0001;ooooo0ol0000Booooo`Co00004Oooool4o`0001;ooooo0ol0000Booooo`Co
00004_ooool2o`0001Cooooo00?o0000ooooooooool04Oooool2o`0002?ooooo000Hooooo`Co0000
4oooool3o`00017ooooo1?l0000Booooo`Co00004Oooool4o`00017ooooo1?l0000Aooooo`Co0000
4_ooool4o`0001;ooooo0ol0000Cooooo`;o00004oooool3o`0001?ooooo0_l0000Dooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Pooooo`006?oo
ool4o`0001;ooooo1?l0000Aooooo`Co00004_ooool4o`00017ooooo1?l0000Aooooo`Co00004_oo
ool4o`0001;ooooo0ol0000Cooooo`;o00005?ooool2o`0001Cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Wooooo000Hooooo`Co00004_ooool4
o`0001;ooooo0ol0000Booooo`Co00004_ooool3o`0001;ooooo0ol0000Cooooo`?o00004oooool2
o`0001Cooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Loooool0
01Wooooo0ol0000Cooooo`?o00004_ooool3o`0001;ooooo1?l0000Booooo`?o00004oooool3o`00
01?ooooo0_l0000Dooooo`;o00005?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
08Sooooo000Iooooo`;o00005?ooool2o`0001Cooooo0_l0000Cooooo`?o00004oooool2o`0001Co
oooo0_l0000Dooooo`;o00005?ooool00ol0003oooooooooo`2cooooo`006Oooool2o`0001Cooooo
0_l0000Dooooo`;o00004oooool3o`0001?ooooo0_l0000Eooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0b?ooool001[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo017ooooo1?l0000Cooooo`03o`000?oooooooooo0?Cooooo000J
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Co00003Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`;o0000<?ooool0
01[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01;ooooo00Co0000oooooooooooooooo0ol0000=ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0;Oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo0ol0000=ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0;?ooool001[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?l0000=oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool001[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01?l0000=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:_ooool001[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00Co0000oooooooooooooooo0ol0000=ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0:Oooool001[ooooo0_l0000Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4_ooool01?l0003oooooooooooooool3o`0000kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool2o`0002Wo
oooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`04o`000?ooooooooooooooo`Co00003Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02Kooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Co00003Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool01?l0003ooooo
ooooool0000Booooo`;o00009_ooool001[ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo0ol0000>ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool0000B
ooooo`?o00004_ooool2o`0002Kooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`?o00003_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00Co0000ooooool0003o00004Ooo
ool00ol0003oooooo`00000Booooo`?o00004_ooool3o`0001;ooooo1?l0000@ooooo`Co00009Ooo
ool001[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00Co0000oooooooooooooooo1?l0000=ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`?o00004_ooool3o`0001;ooooo0ol0
000Booooo`;o00004_ooool4o`00017ooooo1?l0000@ooooo`Go00004_ooool3o`0002Cooooo000J
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`04o`000?ooooooooooooooo`Co00003_ooool00ol0003oooooooooo`0Booooo`?o00004_oo
ool3o`0001;ooooo0ol0000Aooooo`Co00004Oooool5o`00013ooooo1?l0000Cooooo`;o00004ooo
ool2o`0001;ooooo1?l0000Cooooo`;o00008oooool001[ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Cooooo`;o00004oooool2o`0000;ooooo0ol0000>ooooo`?o00004Oooool4
o`00017ooooo1?l0000Aooooo`Co00004_ooool4o`0001;ooooo0ol0000Booooo`;o00005?ooool2
o`0001?ooooo0_l0000Cooooo`;o00005Oooool00ol0003oooooooooo`0Pooooo`006?ooool4o`00
01;ooooo1?l0000Aooooo`Co00004Oooool4o`0000;ooooo0ol0000=ooooo`Co00004Oooool4o`00
017ooooo1?l0000Booooo`?o00004oooool3o`0001?ooooo0_l0000Cooooo`;o00005?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=Oooool001So
oooo1?l0000Booooo`Co00004Oooool4o`00017ooooo1?l00002ooooo`Co00003?ooool4o`0001;o
oooo0ol0000Booooo`?o00004oooool3o`0001?ooooo0_l0000Dooooo`;o00004oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B_ooool001Wooooo
0ol0000Cooooo`?o00004_ooool3o`0001;ooooo0ol00002ooooo`Co00003Oooool3o`0001?ooooo
0ol0000Booooo`?o00004oooool2o`0001Cooooo0_l0000Dooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0M?ooool0013ooooo1?l000000ol@413oooooooooo`02ooooo`?o00004ooo
ool3o`0001;ooooo0ol0000Cooooo`;o00000oooool3o`0000kooooo0_l0000Cooooo`?o00004ooo
ool2o`0001Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Nooooo`004_ooool0
0ol0003oooooooooo`04ooooo`;o00005?ooool2o`0001Cooooo0_l0000Cooooo`;o00000oooool3
o`0000kooooo0_l0000Dooooo`;o00005?ooool00ol0003oooooooooo`39ooooo`004_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool2o`00
01Cooooo00Co0000oooooooooooooooo1?l0000>ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0g_ooool001;ooooo00?o0000ooooooooool01Oooool3o`00017ooooo00?o0000oooo
ool000004Oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool01Oooool4
o`0000Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0_ooooo`004_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0;_ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`06ooooo`Co00001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02go
oooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool4o`0000Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0/ooooo`004?ooool00omEEEGoIVIVo`00
0007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool3o`0000Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Zooooo`006_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06oooo
o`Co00002?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo000Jooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0:?ooool001[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01_ooool3o`0000Sooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Wooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`?o00002Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool01?l0003oooooooooool0000Booooo`03o`000?oooooo000002Kooooo000Jooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo1?l00008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000001;ooooo0ol0000Aooooo`04o`000?oo
oooo0000o`00017ooooo0ol0000Cooooo`;o00009_ooool001[ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_oo
ool4o`0000Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00000Booooo`03o`000?oo
oooo000001;ooooo0ol0000Booooo`?o00004_ooool3o`00017ooooo1?l0000Aooooo`Co00009Ooo
ool001[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01oooool3o`0000Wooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Cooooo`?o00004_ooool3o`00017ooooo0ol0000Booooo`?o00004_ooool4
o`00013ooooo1Ol0000@ooooo`Go00004_ooool2o`0001?ooooo0ol0000Tooooo`006_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool2o`00
00Oooooo0ol00009ooooo`;o00004oooool3o`00017ooooo1?l0000Aooooo`Co00004Oooool3o`00
01;ooooo1?l0000Booooo`?o00004_ooool3o`0001;ooooo0ol0000Cooooo`;o00005?ooool00ol0
003oooooooooo`0Rooooo`006?ooool4o`0001;ooooo1?l0000Aooooo`Co00004Oooool4o`0000Oo
oooo1?l00006ooooo`Co00004_ooool4o`00017ooooo1?l0000Aooooo`Co00004Oooool4o`0001;o
oooo0ol0000Cooooo`;o00004oooool3o`0001?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo027ooooo000Hooooo`Co00004_ooool4o`00017ooooo
1?l0000Aooooo`Co00001oooool4o`0000Kooooo1?l0000Booooo`Co00004_ooool3o`0001;ooooo
0ol0000Booooo`?o00004oooool2o`0001Cooooo0_l0000Dooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0fooooo`006Oooool3o`0001?ooooo0ol0
000Booooo`?o00004_ooool3o`0000Sooooo0ol00007ooooo`?o00004oooool3o`0001?ooooo0ol0
000Booooo`?o00004_ooool2o`0001Cooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0Goooool001Wooooo0ol0000Cooooo`?o00004_ooool3o`0001;ooooo0ol00008
ooooo`?o00002?ooool3o`0001?ooooo0_l0000Cooooo`?o00004oooool2o`0001?ooooo0_l0000D
ooooo`03o`000?oooooooooo08[ooooo000Iooooo`;o00005?ooool2o`0001?ooooo0_l0000Doooo
o`;o00002?ooool4o`0000Sooooo0_l0000Cooooo`;o00005?ooool2o`0001Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`2Oooooo`006_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool2o`0000Sooooo1?l00009ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`39ooooo`00
6_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`07ooooo`?o0000ooooool1ooooo`006_ooool00ol0003ooooooooo
o`18ooooo`?o0000ooooool1ooooo`006_ooool00ol0003oooooooooo`18ooooo`Co0000ooooool0
01[ooooo00?o0000ooooooooool0B?ooool4o`000?oooooo000Jooooo`03o`000?oooooooooo04Wo
oooo0ol0003oooooo`006_ooool00ol0003oooooooooo`19ooooo`?o0000ooooool001[ooooo00?o
0000ooooooooool0BOooool4o`000?kooooo000Jooooo`03o`000?oooooooooo04Wooooo1?l0003n
ooooo`006_ooool00ol0003oooooooooo`1:ooooo`?o0000o_ooool006Oooooo0ol0003nooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`006Oooool00olQ8B7o<S8booooo`3oooooodgooooo000Hooooo`04oiRHV?lb<S;o
410@okZj^_ooooooCOooool001Sooooo00Co410@okZj^_nHV9So<S8boooooom=ooooo`005oooool0
1_nHV9So<S8boooooooooooo410@okZj^_ooooooC?ooool001Kooooo00?ok^k^o`000?oMgMd00_oo
ool00onHV9So<S8booooo`3ooooood_ooooo000Fooooo`03oa0@4?l0003o000000;ooooo0ol0003o
oooood_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.09301, -0.0687934, \
0.00440301, 0.00440301}}],

Cell[TextData[{
  "Fig. 1.3: Direction field for ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]v/\[DifferentialD]t = v/t\)]],
  ", along with two solutions, both with initial condition ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(0)=0."
}], "Caption",
  CellTags->"Fig. 1.3"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
1.2.2 Direction Fields for Second-Order ODEs: Phase-Space Portraits\
\
\>", "Subsubtitle",
  CellTags->"c:11"],

Cell[CellGroupData[{

Cell["Phase-Space", "Section",
  CellTags->{"i:20", "c:12"}],

Cell[TextData[{
  "\tWe have seen that the direction field provides a global picture of all \
solutions to a first-order ODE. The direction field is also a useful \
visualization tool for higher-order ODEs , although the field becomes \
difficult to view in three or more dimensions. A nontrivial case that ",
  StyleBox["can",
    FontSlant->"Italic"],
  " be easily visualized is the direction field for second-order ODEs of the \
form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{"f", "(", 
            RowBox[{"x", ",", 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], ")"}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(1.2.8)"],

Cell[TextData[{
  ButtonBox["Equation (1.2.8)",
    ButtonData:>"(1.2.8)",
    ButtonStyle->"Hyperlink"],
  " is a special case of ",
  ButtonBox["Eq. ( 1.2.1 )",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  " for which the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is ",
  StyleBox["time-independent",
    FontSlant->"Italic"],
  ", and the ODE is",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["second",
    FontSlant->"Italic"],
  StyleBox["-order. ",
    FontSlant->"Italic"],
  "Equations like this often appear in mechanics problems. One simple example \
is the harmonic oscillator with a frictional damping force added, so that the \
acceleration depends linearly on both oscillator position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "and velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v = \[DifferentialD]x/\[DifferentialD]t\)]],
  ":"
}], "Text",
  CellTags->"i:25"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, v) = \(-\[Omega]\_o\%2\)\ x - \[Gamma]\ v\)]],
  ","
}], "NE2",
  CellTags->"(1.2.9)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " is the oscillator frequency and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is a frictional damping rate. "
}], "Text",
  CellTags->"i:109"],

Cell[TextData[{
  "\tThe direction field consists of a set of vectors tangent to the solution \
curves of this ODE in  ",
  Cell[BoxData[
      \(TraditionalForm\`\((t, x, v)\)\)]],
  " space.  Consider a given solution curve, as shown schematically in ",
  ButtonBox["Fig. 1.4",
    ButtonData:>"Fig. 1.4",
    ButtonStyle->"Hyperlink"],
  ". In  a time interval ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  " the solution changes by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]v\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " directions respectively. The tangent to this curve is the vector"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\((\[DifferentialD]t, \[DifferentialD]x, \
\[DifferentialD]v)\) = \(\[DifferentialD]t\ \((1, \[DifferentialD]x\/\
\[DifferentialD]t, \[DifferentialD]v\/\[DifferentialD]t)\) = \
\[DifferentialD]t\ \((1, v, f(x, v))\)\)\)]]], "NE2",
  CellTags->"(1.2.10)"],

Cell[TextData[{
  "Note that this tangent vector is independent of time. The direction field \
is the same in every time slice, so the trajectory of the particle can be \
understood by projecting solutions onto the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane as shown in ",
  ButtonBox["Fig. 1.4",
    ButtonData:>"Fig. 1.4",
    ButtonStyle->"Hyperlink"],
  ". The ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane is often referred to as ",
  StyleBox["phase-space",
    FontSlant->"Italic"],
  ", and the plot of a solution curve in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane is called a ",
  StyleBox["phase-space",
    FontSlant->"Italic"],
  StyleBox[" portrait",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tOften, momentum ",
  Cell[BoxData[
      \(TraditionalForm\`p = m\ v\)]],
  " is used as a phase-space coordinate rather than ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ", so that the ",
  "phase-space",
  " portrait is in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " plane rather than the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane. This sometimes simplifies things (especially for motion in \
magnetic fields, where the relation between ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " is more complicated than just ",
  Cell[BoxData[
      \(TraditionalForm\`p = m\ v\)]],
  "), but for now we will stick with plots in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0002fR000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo001:0?oo
o`030?knoP3oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo001>0?ooo`030?knoP3oool0oooo0?l0
ooooo`3ooooo0?oooa80oooo001>0?ooo`030?knoP3oool0oooo0?l0ooooo`3ooooo0?oooa80oooo
000j0?oooa0000002@3oool=0000000300410@000000000000@00000o`3ooooo0?oooo/0oooo000m
0?ooo`@000000P010@44000000l0oooo0P0000000`010@4000000000000900000080o_kno`3ooooo
0?oooo`0oooo000n0?ooo`L000004`3oool:00000?l0ooooo`3ooooo0?ooo`40oooo000o0?ooo`03
000000010@40000000<000003@3oool00`3no_h0oooo0?knoP030?ooo`T00000o`3ooooo0?ooool0
oooo0P3oool003l0oooo00<0o_kn0000000000000`00000?0?ooo`030?knoP3oool0000000T00000
o`3ooooo0?ooool0oooo0`3oool00440oooo1@00000?0?ooo`/00000o`3ooooo0?ooool0oooo0`3o
ool00440oooo1@00000?0?ooo`/00000o`3ooooo0?ooool0oooo0`3oool004<0oooo1000000>0?oo
o`X00000o`3ooooo0?ooool0oooo103oool004@0oooo00<0000000410@0000003@3oool600000003
00410@0000000@410?l0ooooo`3ooooo0?ooo`H0oooo00140?ooo`@000002`3oool6000000040041
0@000000000000000?l0ooooo`3ooooo0?ooo`H0oooo00150?ooo`D000002@3oool5000000040041
0@000000000000000?l0ooooo`3ooooo0?ooo`L0oooo00160?ooo`D000001`3oool900000?l0oooo
o`3ooooo0?ooo`P0oooo00170?ooo`@000001P3oool:00000?l0ooooo`3ooooo0?ooo`P0oooo0017
0?ooo`@000001P3oool:00000?l0ooooo`3ooooo0?ooo`P0oooo00170?ooo`@0000000<00@410?oo
o`3oool00`3oool900000?l0ooooo`3ooooo0?ooo`T0oooo00180?ooo`80000000<00@4100000000
00000P3oool:00000080oooo00<0o_kn0?ooo`3oool0o`3ooooo0?ooool0oooo1@3oool004X0oooo
3`0000000`3no_h0oooo0?ooo`3o0?ooool0ooooo`3oool70?ooo`00A`3oool0103no_h0oooo0?oo
o`3oool;000000800@41o`3ooooo0?ooool0oooo2`3oool004/0oooo2`00003o0?ooool0ooooo`3o
ool=0?ooo`00B`3oool00`3no_h000000000000800000?l0ooooo`3ooooo0?ooo`d0oooo001;0?oo
o`030?knoP000000000000P00000o`3ooooo0?ooool0oooo3@3oool004/0oooo1P00000010010@40
000000000000003o0?ooool0ooooo`3oool>0?ooo`00B`3oool900000?l0ooooo`3ooooo0?ooo`l0
oooo001:0?ooo`X00000o`3ooooo0?ooool0oooo3`3oool004X0oooo1000000010010@4000000000
00010@4200000?l0ooooo`3ooooo0?ooo`l0oooo000E0?ooo`030?knoP3oool0oooo0300oooo3@00
003o0?ooool0ooooo`3oool>0?ooo`006@3oool00`3no_h0oooo0?ooo`0W0?ooo`040?knoP3oool0
oooo0?ooo`l000000`3oool00`3no_h0oooo0?knoP3o0?ooool0ooooo`3oool70?ooo`006@3oool0
0`3no_h0oooo0?ooo`0W0?ooo`040?knoP3oool0oooo0?ooo`l000000`3oool00`3no_h0oooo0?kn
oP3o0?ooool0ooooo`3oool70?ooo`00A`3oool8000000800@410P3oool00`0000000@410000003o
0?ooool0ooooo`3oool=0?ooo`00AP3oool;00000080oooo1@00003o0?ooool0ooooo`3oool;0?oo
o`00A@3oool3000000800@411@0000050?ooo`D00000o`3ooooo0?ooool0oooo2P3oool001D0oooo
00<0o_kn0?ooo`3oool0;@3oool70000000300410@000000oooo00H0oooo1@00003o0?ooool0oooo
o`3oool90?ooo`005@3oool00`000000oooo0?ooo`0/0?ooo`X00000203oool4000000<0oooo0P3n
o_ko0?ooool0ooooo`3oool40?ooo`005@3oool2000000@0oooo00<0o_kn0?ooo`3oool09@3oool:
000000T0oooo1@00003o0?ooool0ooooo`3oool80?ooo`005@3oool2000000@0oooo00<0o_kn0?oo
o`3oool09@3oool:000000T0oooo1@00003o0?ooool0ooooo`3oool80?ooo`005@3oool5000000X0
oooo00<0o_kn0?ooo`3oool0703oool9000000`0oooo0P0000000`010@4000000?ooo`3o0?ooool0
ooooo`3oool60?ooo`005P3oool00`010@40000000000002000002H0oooo2`0000000`3no_h0oooo
0?ooo`0:0?ooo`@000000`3oool00`3no_h0oooo0?ooo`3o0?ooool0ooooo`3oool001H0oooo1`00
00050?ooo`030?knoP3oool0oooo01/0oooo2`000000103oool0o_kn0?ooo`3no_h70?ooo`80o_kn
00<0oooo000000000000100000000`3no_h0oooo0?ooo`3o0?ooool0ooooo`3oool10?ooo`005P3o
ool:000000<0oooo00<0o_kn0?ooo`3oool06@3oool40000000300410@000000000000D000003P3o
ool7000000030?ooo`3no_h0oooo0?l0ooooo`3ooooo0?ooo`005P3oool;000001d0oooo3P00000<
0?ooo`X00000o`3ooooo0?ooool0oooo0@3oool001L0oooo3000000G0?ooo`H0000000<00@410000
000000002`0000070?ooo`l00000o`3ooooo0?ooooh0oooo000G0?ooo``000005`3oool600000003
00410@000000000000/000001`3oool?00000?l0ooooo`3oooon0?ooo`005`3oool>000002d0oooo
00<0o_kn0?ooo`3oool0o`3ooooo0?ooool0oooo3P3oool001@0oooo00<0o_kn0?ooo`3oool03000
000010010@40000000000000000C0?ooo`80o_kn903oool00`3no_h0oooo0?ooo`040?ooo`030?kn
oP3oool0oooo0?l0ooooo`3ooooh0?ooo`006@3oool@00000080oooo00<0o_kn0?ooo`3oool0o`3o
oooo0?ooool0oooo=@3oool001T0oooo4@00003o0?ooool0ooooo`3oooli0?ooo`006@3oool20000
000300410@000000000000h00000o`3ooooo0?ooool0oooo=`3oool001X0oooo5@0000000`3oool0
o_kn0?ooo`3o0?ooool0ooooo`3ooola0?ooo`006P3ooolE000000030?ooo`3no_h0oooo0?l0oooo
o`3ooooo0?oooc40oooo000J0?oooaH00000203oool00`3no_h0oooo0?ooo`3o0?ooool0ooooo`3o
oolX0?ooo`006`3ooolG00000?l0ooooo`3ooooo0?oooc40oooo000K0?oooaP00000o`3ooooo0?oo
ool0oooo<03oool001/0oooo300000000`010@4000000000000<00000?l0ooooo`3ooooo0?ooobd0
oooo000F0?ooo`040?knoP3oool0oooo0?knoP80oooo7000000;0?ooo`030?knoP3oool0o_kn0?l0
oooo^03oool20?knoPH0oooo0P3no_kP0?ooo`030?knoP3oool0oooo07H0oooo000L0?oooad00000
o`3oooo@0?ooo`030?knoP3oool0oooo0=L0oooo00<0o_kn0?ooo`3oool0N`3oool001`0oooo7@00
003o0?ooom00oooo00<0o_kn0?ooo`3oool0e`3oool00`3no_h0oooo0?ooo`1k0?ooo`00703ooolP
000000030?knoP3oool0oooo0?l0ooooa`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0
oooo0880oooo000I0?ooo`040?knoP3oool0oooo0?ooob00000000@00@410?ooo`3oool0o_kn0P3o
ool00`3no_h0oooo0?ooo`3o0?oookd0oooo0`00001W0?ooo`80o_knKP3oool3000000H0oooo00<0
o_kn0?ooo`3oool00P3oool20?knoW@0oooo000M0?ooob8000002@3oool20?kno_l0oooo/@3oool0
0`3no_h0oooo0?ooo`040?ooo`<00000J`3oool00`3no_h0oooo0?ooo`1/0?ooo`800000P03oool0
01h0oooo100000000`010@4000000000000L00000?l0oooo_`3oool300000=d0oooo0`00001n0?oo
o`007P3ooolU00000?l0oooo_03oool3000006T0oooo00<000000?ooo`3oool0K@3oool00`3no_h0
oooo0?ooo`040?ooo`800000O@3oool00200oooo9@00003o0?oookT0oooo00<0000000410@000000
1P3oool00`3no_h0oooo0?ooo`1Q0?ooo`D00000L@3oool00`3no_h0oooo00000002000000@0oooo
00<0o_kn0?ooo`3oool0M03oool00200oooo9@00003o0?oookT0oooo00<0000000410@0000001P3o
ool00`3no_h0oooo0?ooo`1Q0?ooo`D00000L@3oool00`3no_h0oooo00000002000000@0oooo00<0
o_kn0?ooo`3oool0M03oool001h0oooo0P3no_h200410B<00000o`3ooonf0?ooo`030?knoP000000
000000800000K03oool00`3no_h000000000000300000740oooo100000030?ooo`030?knoP3oool0
oooo07@0oooo000P0?ooob@00000o`3ooong0?ooo`@00000L@3oool3000000030?ooo`3no_h0o_kn
06h0oooo100000000`3oool0o_kn0?ooo`1f0?ooo`008@3ooolS000000<0oooo00<0o_kn0?ooo`3o
ool0o`3ooon`0?ooo`@00000L`3oool300000780oooo0`00001h0?ooo`00803oool01@3no_h00000
0000000000000@4101h00000o`3ooonf0?ooo`D00000M03oool400000740oooo0`0000000`3oool0
o_kn0?knoP1d0?ooo`008P3ooolL0000000300410@00000000000?l0oooo]`3oool4000006h0oooo
00<0o_kn0?ooo`3oool01P3oool400000700oooo1000001f0?ooo`008P3oool00`010@4000000000
000K00000?l0oooo^03oool400000700oooo00<0o_kn0?ooo`3oool01@3oool400000700oooo0`00
001f0?ooo`008P3oool00`010@4000000000000K00000?l0oooo^03oool400000700oooo00<0o_kn
0?ooo`3oool01@3oool400000700oooo0`00001f0?ooo`008P3ooolM00000?l0oooo]03oool01P3n
o_h0oooo0?ooo`3oool0000000410@800000N@3oool400000700oooo1@00001d0?ooo`008`3ooolK
00000?l0oooo]`3oool6000000@0oooo00<0o_kn0?ooo`3oool0M03oool200000700oooo1P00001c
0?ooo`008`3ooolJ00000?l0oooo^03oool30000000300410@000000oooo02L0oooo00<0o_kn0?oo
o`3oool0<03oool00`3no_h0oooo0?ooo`0N0?ooo`<000003P3oool01@3no_h0oooo0?ooo`3oool0
o_kn00@0oooo0`3no_hG0?ooo`030?knoP3oool0oooo03`0oooo1@00001c0?ooo`008`3ooolJ0000
0?l0oooo]`3oool6000003l0oooo00<0o_kn0?ooo`3oool00`3oool00`3no_h0oooo0?ooo`0A0?oo
o`030?knoP3oool0oooo0080oooo0P3no_hL0?ooo`<00000803oool00`3no_h0oooo0?ooo`1=0?oo
o`H00000LP3oool002@0oooo4`0000000`010@4000000000000200000?l0oooo^03oool600000240
oooo1`0000080?ooo`03000000010@4000000280oooo00<0o_kn0?ooo`3oool06`3oool5000000@0
oooo0`00000>0?ooo`040?knoP3oool0o_kn0?knoP<0oooo1`0000000`3no_h0oooo0?ooo`030?oo
o`030?knoP3oool0000000<000008P3oool3000000D0oooo00<0o_kn0?ooo`3oool0703oool50000
0780oooo000T0?oooaP000000P3no_ko0?oookD0oooo1@0000000`010@40oooo0?ooo`0L0?ooo`/0
000000@00@410000003oool0o_kn103oool7000000<0oooo0P3no_h30?ooo`l000002@3oool60000
000300410@000000000000<0000000<00@41000000000000100000000`010@40oooo0?ooo`050?oo
o`d000004P3oool<000000H0oooo1`0000050?ooo`030?knoP3oool0oooo01D0oooo1@00000T0?oo
o`H00000L@3oool002@0oooo600000020?kno_l0oooo]@3oool50000000300410@3oool0oooo01`0
oooo2`00000010010@4000000?ooo`3no_h40?ooo`L000000`3oool20?knoP<0oooo3`0000090?oo
o`H0000000<00@410000000000000`0000000`010@400000000000040000000300410@3oool0oooo
00D0oooo3@00000B0?ooo``000001P3oool7000000D0oooo00<0o_kn0?ooo`3oool05@3oool50000
02@0oooo1P00001a0?ooo`00903ooolI000000<0oooo00<0o_kn0?ooo`3oool0o`3ooon`0?ooo`H0
00007@3oool50000000300410@000000000000P00000103oool9000000P0oooo1P0000000`010@40
000000000002000000@0oooo0P3no_h90?ooo`h00000203oool>000000030?knoP3oool0oooo00d0
oooo2`0000000`010@40000000000003000000<0oooo2P00000J0?ooo`H000008`3oool600000740
oooo000T0?oooaX00000o`3ooonc0?ooo`030?knoP000000000000D00000703ooolC00000080oooo
3@0000050?ooo`L000004`3oool50000000300410@000000000000<000002P3oool>000000030?kn
oP3oool0oooo00`0oooo4`0000020?ooo`X0000000<00@410000000000005P3oool7000000P0oooo
0P3no_hI0?ooo`L00000L03oool001h0oooo0P3no_h50?oooa0000000`3oool60000000300410@3o
ool0oooo0?l0oooo/@3oool7000001/0oooo00<00@410000000000004P0000000`3oool000000000
000800000080oooo0P0000060?ooo`D000003@3oool00`3no_h0oooo0?ooo`030?ooo`T00000303o
ool=000000l0oooo4000000200410@<0000000<0oooo0000000000002@0000000`3oool000000000
000E0?ooo`0300410@000000000000D00000703oool20?knoPD0oooo1P00001`0?ooo`009@3oool<
0000000300410@000000oooo00D0oooo1`00003o0?oook80oooo1P00000K0?ooo``000001P3oool0
1@010@400000000000000000oooo00T000002@3oool20?knoP030?ooo`000000000000800000403o
ool00`3no_h0oooo00000002000000800@411000000=0?ooo`d0000000<0oooo0?knoP3oool02`3o
ool90000000400410@000000000000410@H0oooo0`0000000`3oool0000000000008000001T0oooo
200000040?ooo`030?knoP3oool0oooo0080o_kn6P3oool50000000300410@3oool0oooo06h0oooo
000W0?ooo`X000002@3oool30000000400410@000000000000000?l0oooo/03oool7000001L0oooo
00<0o_kn0?ooo`0000002`0000090?ooo``000003P3oool5000000l0oooo2P0000000`3oool0o_kn
0?knoP0;0?ooo`@000000P010@45000000h0oooo2`00000:0?ooo`@000000P010@45000001X0oooo
00@00@41000000010@400@410P0000000`010@400000000000050?ooo`030?knoP3oool0oooo01/0
oooo1@0000000`010@4000000?ooo`1^0?ooo`009`3oool8000000d0oooo1@0000020?kno_l0oooo
[P3oool7000001P0oooo3000000=0?ooo`T00000303oool01@3no_h0oooo0?ooo`0000000@4100<0
00000P3oool0103no_h0oooo0?knoP3no_h30?ooo`050?knoP3oool0oooo0?ooo`3no_h02@00000?
0?ooo`P000000P010@480?ooo`030?knoP3oool0oooo00<0oooo2`00000=0?ooo`T000006P3oool;
000000<0oooo00<0o_kn0?ooo`3oool06`3oool50000000300410@000000oooo06h0oooo000W0?oo
o`P000003@3oool500000080o_kno`3ooon^0?ooo`L00000603oool<000000d0oooo2@00000<0?oo
o`050?knoP3oool0oooo000000010@400`0000020?ooo`040?knoP3oool0o_kn0?knoP<0oooo00D0
o_kn0?ooo`3oool0oooo0?knoP09000000l0oooo2000000200410@P0oooo00<0o_kn0?ooo`3oool0
0`3oool;000000d0oooo2@00000J0?ooo`/000000`3oool00`3no_h0oooo0?ooo`0K0?ooo`D00000
00<00@410000003oool0KP3oool002P0oooo0`00000A0?ooo`L000001`3oool00`3no_h0oooo0?oo
o`3o0?oooj@0oooo1`00000H0?ooo`/000003`3oool800000100oooo1000000=0?ooo`T000000`3o
ool20?knoPh0oooo1@00000@0?ooo`X000003`3oool8000001@0oooo00<0o_kn0?ooo`3oool00P3o
ool<000001h0oooo00<0o_kn0?ooo`3oool01`00001_0?ooo`00?@3oool700000?l0oooo[03oool8
000001L0oooo100000000`010@40000000000004000000P0oooo00<0o_kn0?ooo`3oool01@3oool8
00000100oooo1@00000:0?ooo`/000008@3oool00`3no_h0oooo0?ooo`020?ooo`D0000000<00@41
0000000000000`00000?0?ooo`030?knoP010@40000000H000006@3oool90000000400410@000000
0000000001d0oooo00<0o_kn0?ooo`3oool02@00001]0?ooo`009`3oool00`3no_h0oooo0?ooo`0?
0?ooo`030?knoP3oool0oooo0080oooo1`00003o0?ooojL0oooo00@0o_kn0?ooo`3oool0oooo2000
000G0?ooo`T000000P3oool00`3no_h0oooo0?ooo`0;0?ooo`030?knoP3oool0000000L000004@3o
ool5000000T0oooo2P0000000`3oool0o_kn0?ooo`0Q0?ooo`030?knoP3oool0oooo00X000000P3o
ool00`3no_h0oooo0?ooo`0<0?ooo`P00000603oool9000000030?ooo`00000000000080000000<0
oooo0?knoP3oool07@3oool9000000030?knoP3oool0oooo06X0oooo000Y0?ooo`030?knoP3oool0
oooo0100oooo00<0o_kn0?ooo`3oool01`0000000`3no_h0oooo0?ooo`3o0?oooj<0oooo00@0o_kn
0?ooo`3oool0oooo0`0000000`010@40000000000002000001L0oooo2@00000B0?ooo`P000004`3o
ool4000000L0oooo1P00000010010@40000000000000000X0?ooo`<0000000@00@41000000000000
0@410`00000A0?ooo`03000000010@400@4100D00000603oool9000000060?ooo`0000000@410041
0@0000000@418@3oool7000000030?knoP3oool0oooo06X0oooo00100?ooo`03000000010@400@41
00@00000o`3ooonY0?ooo`L00000603oool50000000300410@000000000001<0oooo2000000D0?oo
o`<00000103oool00`3no_h0oooo0000000:000002P0oooo2@00000B0?ooo`P00000603oool90000
00030?ooo`000000000000<0000000<0oooo0?knoP3oool07P3oool7000006d0oooo000o0?ooo`03
0?knoP3oool0000000D00000o`3ooonY0?ooo`L000005`3oool9000000h0oooo00D0o_kn0?ooo`3o
ool0o_kn0?ooo`08000001@0oooo100000050?ooo`T00000:@3oool00`0000000@4100410@070000
0180oooo2000000B0?ooo`030?knoP3oool0oooo0080oooo2@0000030?ooo`@000008@3oool70000
06d0oooo000o0?ooo`030?knoP3oool0000000D00000o`3ooonY0?ooo`L000005`3oool9000000h0
oooo00D0o_kn0?ooo`3oool0o_kn0?ooo`08000001@0oooo100000050?ooo`T00000:@3oool00`00
00000@4100410@0700000180oooo2000000B0?ooo`030?knoP3oool0oooo0080oooo2@0000030?oo
o`@000008@3oool7000006d0oooo00110?ooo`L00000G@3oool00`3no_h0oooo0?ooo`3o0?ooodH0
oooo2@00000G0?ooo`T000004`3oool8000001<0oooo00<0o_kn0?ooo`000000100000020?ooo`T0
0000:P3oool:00000180oooo2000000G0?ooo`T000000`3oool500000200oooo2000001/0?ooo`00
@`3oool7000006<0oooo00@0o_kn0?ooo`0000000000o`3ooolm0?ooo`T000005`3oool8000001@0
oooo2000000F0?ooo`l00000:P3oool8000001@0oooo2000000B0?ooo`030?knoP3oool0oooo00H0
000000@00@4100000000000000001P3oool3000000030?knoP3oool0oooo01d0oooo2000001/0?oo
o`00A03oool7000005P0oooo0`0000070?ooo`H00000o`3ooolk0?ooo`T000005`3oool8000001@0
oooo2000000G0?ooo`d00000:`3oool8000001@0oooo2000000E0?ooo`80000000<00@4100000000
00001@0000000`3oool0o_kn0?ooo`030?ooo`@000007`3oool8000006`0oooo00150?ooo`L00000
E03oool00`3no_h0oooo00000004000000030?ooo`3no_h0oooo00@0oooo00<0000000410@000000
0`00003o0?ooocX0oooo2@00000G0?ooo`P00000503oool8000001L0oooo3000000/0?ooo`P00000
503oool8000001@0oooo2P0000080?ooo`<000007`3oool8000006`0oooo00160?ooo`L00000E03o
ool7000000L0oooo1P00003o0?ooocT0oooo2@00000G0?ooo`P00000503oool8000001P0oooo2`00
000/0?ooo`P00000503oool8000001@0oooo2P0000080?ooo`<000007`3oool8000006`0oooo0017
0?ooo`@0000000<00@410000003oool0E03oool7000000H0oooo1P00003o0?ooocT0oooo2@00000G
0?ooo`P00000503oool8000001<0oooo00@0o_kn0?ooo`3oool0oooo2`00000]0?ooo`P00000503o
ool8000001@0oooo2P0000050?ooo`80o_kn00<0oooo0000000000000P00000N0?ooo`P00000K03o
ool004L0oooo100000000`010@4000000?ooo`1D0?ooo`L000001P3oool600000?l0oooo>@3oool9
000001L0oooo2000000D0?ooo`P000004`3oool0103no_h0oooo0?ooo`3oool;000002d0oooo2000
000D0?ooo`P00000503oool:000000D0oooo0P3no_h00`3oool0000000000002000001h0oooo2000
001/0?ooo`00A@3oool00`3no_h0oooo000000050000000300410@3oool0oooo05<0oooo1`000006
0?ooo`0600410@0000000000000000010@4000000P3oool20?kno_l0oooo=03oool9000001L0oooo
2000000D0?ooo`P000005`3oool8000000800@410P3oool00`3no_h0oooo0?ooo`0Y0?ooo`L00000
00<00@410?ooo`3oool00`3oool00`3no_h0oooo0?ooo`0<0?ooo`P000004`3oool9000000/0oooo
0`00000N0?ooo`P00000K03oool004P0oooo1`0000020?knoU@0oooo1`0000050?ooo`H00000o`3o
oolg0?ooo`T000005`3oool8000001@0oooo2000000F0?ooo`L0000000@00@410000000000000000
;P3oool8000000D0oooo00<0o_kn0?ooo`3oool0303oool8000001<0oooo2@0000060?ooo`030?kn
oP3oool0oooo0080oooo1@00000L0?ooo`P00000K03oool004@0oooo00<0o_kn0?ooo`3oool00`3o
ool7000000T0oooo00<0o_kn0?ooo`3oool0@`3oool00`3no_h0oooo0?ooo`040?ooo`D000001`3o
ool40000000300410@3oool0oooo0?l0oooo7P3oool00`3no_h0oooo0?ooo`0C0?ooo`T00000603o
ool7000001<0oooo00<0o_kn0000000000001P00000F0?ooo`/00000;`3oool700000100oooo00@0
o_kn0?ooo`3oool0oooo2000000B0?ooo`P0000000<00@410?ooo`3oool02`3oool4000001`0oooo
2000001/0?ooo`00B`3oool7000000<0oooo00<0o_kn0?ooo`3oool0C`3oool6000000L0oooo1P00
003o0?ooob<0oooo00<0o_kn0?ooo`3no_h0103oool2000000P0oooo2@00000H0?ooo`L00000503o
ool60000000300410@000000oooo01@0oooo00<0000000410@010@401@0000000`010@4000000000
0002000002h0oooo1P0000000`010@40oooo0?ooo`0B0?ooo`P000004P3oool9000000d0oooo1@00
000K0?ooo`P00000K03oool004`0oooo1`00001E0?ooo`D000001`3oool400000?l0oooo9`3oool0
103no_h0oooo0?ooo`3oool4000000L0oooo2@00000H0?ooo`L00000103oool00`3no_h0oooo0?oo
o`0=0?ooo`L0000000<00@410?ooo`3oool04P3oool?000000H0oooo00<0o_kn0?ooo`3oool0903o
ool40000000300410@000000000001@0oooo1000000010010@40000000000000000A0?ooo`T00000
3P3oool00`0000000@4100000002000001/0oooo200000000`3no_h0oooo0?ooo`1Y0?ooo`00C@3o
ool6000000D0oooo00<0o_kn0?ooo`3oool00P3oool20?knoTT0oooo1P0000050?ooo`040?knoP3o
ool0000000000?l0oooo7P3oool00`3no_h0oooo0?ooo`030?ooo`030?knoP3oool0oooo0080oooo
2@0000050?ooo`T00000603oool50000000300410@000000oooo01<0oooo2000000D0?ooo`T00000
0P3oool4000002d0oooo1`00000D0?ooo`P000004@3oool9000000l0oooo0`0000000`010@40oooo
0?ooo`020?ooo`80o_kn00<0oooo0?knoP3oool04P3oool40000000400410@0000000000000006`0
oooo001=0?ooo`H000001@3oool00`3no_h0oooo0?ooo`020?ooo`80o_knB@3oool6000000D0oooo
00@0o_kn0?ooo`0000000000o`3ooolN0?ooo`030?knoP3oool0oooo00<0oooo00<0o_kn0?ooo`3o
ool00P3oool9000000D0oooo2@00000H0?ooo`D0000000<00@410000003oool04`3oool8000001@0
oooo2@0000020?ooo`@00000;@3oool7000001@0oooo2000000A0?ooo`T000003`3oool300000003
00410@3oool0oooo0080oooo0P3no_h00`3oool0o_kn0?ooo`0B0?ooo`@0000000@00@4100000000
00000000K03oool004<0oooo00<0o_kn0?ooo`3oool00P3oool20?knoP<0oooo00<0000000410@00
00001000001E0?ooo`D00000o`3ooola0?ooo`P000001`3oool9000001T0oooo1`00000C0?ooo`P0
00004`3oool80000000400410@000000oooo0?ooo`D000009`3oool00`3no_h0oooo0?ooo`040?oo
o`80000000<00@410000000000000P0000000`3oool0o_kn0?ooo`0?0?ooo`@0000000@00@410000
0000000000004@3oool9000000l0oooo1@00000J0?ooo`D000000P010@400`000000oooo0?ooo`1Z
0?ooo`00CP3oool7000005@0oooo1P00000;0?ooo`80o_kno`3ooolR0?ooo`L0000000<00@410?oo
o`3oool0203oool7000001T0oooo1@0000000`010@4000000?ooo`0B0?ooo`P000003@3oool0103n
o_h0oooo0?ooo`3oool;000000D0oooo100000080?ooo`80o_kn8`3oool30000000600410@000000
0@4100410@3oool0o_kn403oool800000100oooo0P0000000`010@40000000000002000000030041
0@000000oooo00T0oooo0P3no_h50?ooo`@000006P3oool40000000500410@00000000000?ooo`3n
o_h0J`3oool004/0oooo00@0o_kn0?ooo`3oool0oooo0P0000000`010@40000000000002000005@0
oooo1P0000040?ooo`030?knoP3oool0oooo0?l0oooo9P3oool7000000`0oooo1`00000I0?ooo`03
0?knoP000000000000@000004`3oool800000140oooo2P0000070?ooo`@00000;@3oool600000180
oooo2000000@0?ooo`T000004@3oool20000000300410@000000000001T0oooo1`00001]0?ooo`00
AP3oool00`3no_h0oooo0?ooo`050?ooo`030?knoP3oool0oooo00L00000103oool00`3no_h0oooo
0?ooo`1;0?ooo`H00000o`3ooolV0?ooo`030?knoP3oool0oooo00<0oooo0`00000010010@400000
00000000000=0?ooo`L000006P3oool7000000@0oooo00<0o_kn0?ooo`3oool02P3oool400000080
0@410`00000@0?ooo`/000001P3oool00`3no_h0oooo00000002000000@0oooo00<0o_kn0?ooo`3o
ool00P3no_hT0?ooo`L00000403oool9000000h0oooo2P00000B0?ooo`D000005`3oool9000006d0
oooo001B0?ooo`L00000D@3oool20?knoPD00000o`3ooolP0?ooo`<0o_kn00<0oooo0?knoP3oool0
0P3oool9000000D0oooo0P3no_h20?ooo`030?knoP3oool0oooo0080oooo2000000K0?ooo`@00000
00<00@410?ooo`3oool03`3oool9000000l0oooo100000001@010@4000000000000000000@410080
00002@3oool5000002`0oooo1P00000@0?ooo`T000003P3oool20000000300410@000000000000D0
0000503oool00`0000000@410000000G0?ooo`T00000K@3oool004`0oooo00<0o_kn0?ooo`3oool0
103oool00`010@40000000000003000005<0oooo1@0000020?kno_l0oooo9@3oool7000000030041
0@3oool0oooo00h0oooo0P0000000`010@40000000000003000000030?knoP3oool0oooo0180oooo
00<0o_kn0?ooo`3oool0103oool00`010@40000000000003000000<0oooo00<0o_kn0?ooo`3oool0
203oool:000000H0oooo00<0o_kn0?ooo`3no_h00`3oool00`3no_h0oooo0?ooo`09000000`0oooo
1@0000060?ooo`030?knoP3oool0o_kn02<0oooo1P00000>0?ooo`X000003P3oool4000000030041
0@0000000000008000000P3oool00`3no_h0oooo0?knoP0@0?ooo`@000005P3oool9000006d0oooo
001<0?ooo`030?knoP3oool0oooo00@0oooo00<00@410000000000000`00001C0?ooo`D000000P3n
o_ko0?ooobD0oooo1`0000000`010@40oooo0?ooo`0>0?ooo`80000000<00@410000000000000`00
00000`3no_h0oooo0?ooo`0B0?ooo`030?knoP3oool0oooo00@0oooo00<00@410000000000000`00
00030?ooo`030?knoP3oool0oooo00P0oooo2P0000060?ooo`030?knoP3oool0o_kn00<0oooo00<0
o_kn0?ooo`3oool02@00000<0?ooo`D000001P3oool00`3no_h0oooo0?knoP0S0?ooo`H000003P3o
ool:000000h0oooo100000000`010@4000000000000200000080oooo00<0o_kn0?ooo`3no_h0403o
ool4000001H0oooo2@00001]0?ooo`00C03oool00`3no_h0oooo0?ooo`040?ooo`L00000D`3oool4
00000?l0oooo9P3oool8000000P0oooo0P3no_h80?ooo`<0000000@00@4100000000000000005@3o
ool00`3no_h0oooo0?ooo`040?ooo`L000000P3oool20?knoPL0oooo300000020?ooo`80o_kn2P3o
ool60000000400410@0000000000000000d0oooo1000000010010@40oooo0?ooo`3no_h70?ooo`80
o_kn7`3oool7000000`0oooo2`00000=0?ooo`X00000203oool00`3no_h0oooo0?ooo`080?ooo`80
o_kn00@0oooo00000000000000000`3oool00`3no_h0oooo0?ooo`0;0?ooo`030?knoP3oool0oooo
0080oooo1`00001_0?ooo`00DP3oool00`3no_h0oooo000000050000000300410@3oool0oooo0500
oooo1P00003o0?ooob<0oooo1`00000D0?ooo`L000006`3oool00`3no_h0oooo00000006000000T0
oooo3@00000=0?ooo`X000003P3oool00`010@40000000000003000002/0oooo1`00000:0?ooo``0
0000303oool;000001H0oooo100000020?knoP030?ooo`3no_h0oooo0100oooo1`00001_0?ooo`00
E@3oool7000000030?knoP3oool0oooo04h0oooo1P00003o0?ooob80oooo1P0000000`010@40oooo
0?ooo`0C0?ooo`L000007P3oool60000000300410@000000oooo00D0oooo200000000`010@400000
00000003000000`0oooo00<00@410000000000002000000>0?ooo`L00000:`3oool6000000030041
0@000000000000D0oooo1`00000200410@D00000303oool;000001H0oooo1000000E0?ooo`L00000
K`3oool00580oooo00@0o_kn0?ooo`3oool0oooo1`00001A0?ooo`D00000o`3ooolK0?ooo`030?kn
oP3oool0o_kn00<0oooo1@00000200410A40oooo00<0o_kn0?ooo`3oool00`3oool6000001/0oooo
00@0o_kn0?ooo`3oool0oooo4P0000000`3oool0000000000006000000P0oooo00<0o_kn0?ooo`00
00001P00000300410@<0000000<00@410?ooo`3oool02P3oool;000000030?knoP3oool0oooo02L0
oooo4@0000000`3oool00000000000020000000400410@0000000000000000X0oooo3P0000000`3o
ool0o_kn0?ooo`0A0?ooo`<0000000D00@41000000010@400@410000000;0?ooo`80o_kn1@3oool6
00000700oooo001H0?ooo`L00000C`3oool500000?l0oooo7P3oool00`0000000@4100410@050000
01T0oooo00<0000000410@0000000`00000R0?ooo``00000103oool8000000L0oooo500000070?oo
o`l000009P3oool20?knoP80oooo3@0000000`3oool0o_kn0?ooo`08000000L0oooo5000000=0?oo
o`/0000000<00@410000000000003`3oool700000700oooo001E0?ooo`040?knoP3oool0oooo0?oo
o`H00000C`3oool600000?l0oooo703oool8000001X0oooo1`00000T0?ooo`L000001P3oool20000
000400410@000000000000410@800000403oool00`3no_h0oooo0?ooo`0>0?ooo`030?knoP3oool0
oooo03X0oooo1`0000060?ooo`P00000:@3oool30?knoQT0oooo1`0000030?ooo`030?knoP3oool0
oooo06X0oooo001E0?ooo`040?knoP3oool0oooo0?ooo`H00000C`3oool600000?l0oooo703oool8
000001X0oooo1`00000T0?ooo`L000001P3oool20000000400410@000000000000410@800000403o
ool00`3no_h0oooo0?ooo`0>0?ooo`030?knoP3oool0oooo03X0oooo1`0000060?ooo`P00000:@3o
ool30?knoQT0oooo1`0000030?ooo`030?knoP3oool0oooo06X0oooo001F0?ooo`80o_kn00<0oooo
0000000000001@00001<0?ooo`030?knoP3oool0o_kn00D00000o`3oool?0?ooo`030?knoP3oool0
oooo00T0oooo00<00@410000000000001@00000L0?ooo`H00000<@3oool8000006/0oooo20000015
0?ooo`H00000L@3oool005X0oooo1`00001>0?ooo`H000000P3oool00`3no_h0oooo0?ooo`0<0?oo
o`80o_knn@3oool00`3no_h0oooo0?ooo`050?ooo`040?knoP3oool0oooo0?ooo`L000007P3oool6
00000340oooo2000001[0?ooo`P00000A@3oool30000000300410@00000000000740oooo001K0?oo
o`0300410@000000000000@00000CP3oool5000001<0oooo0P0000000`3oool0o_kn0?ooo`3f0?oo
o`80o_kn1`3oool7000000030?knoP3oool0oooo01d0oooo00<00@410000000000000`00000`0?oo
o`P00000J`3oool8000004@0oooo1P00001b0?ooo`00G03oool7000000<0oooo00<0o_kn0?ooo`3o
ool0A`3oool5000000030?knoP3oool0oooo00h0oooo1@00003j0?ooo`040?knoP3oool0oooo0?oo
o`<0000000<00@410000000000000P0000090?ooo`030?knoP3oool0oooo01H0oooo1P00000`0?oo
o`P00000J`3oool8000004@0oooo100000000`010@4000000?ooo`1a0?ooo`00F@3oool0103no_h0
oooo0?ooo`3oool7000004`0oooo1P00000?0?ooo`L00000o03oool8000000@0oooo00<0o_kn0?oo
o`3oool06P3oool00`3no_h0oooo0?ooo`05000000@0oooo00<0o_kn0?ooo`3oool0:@3oool80000
06/0oooo200000120?ooo`030?knoP3oool0000000@00000L`3oool005P0oooo00<0o_kn0?ooo`3o
ool0103oool5000004d0oooo1@00000@0?ooo`H00000n`3oool00`010@40000000000005000002<0
oooo00<0o_kn0?ooo`0000001@00000_0?ooo`P00000J`3oool8000004<0oooo0`00000200410@03
0000003oool0oooo0740oooo001H0?ooo`030?knoP3oool0oooo00@0oooo1@00001=0?ooo`D00000
403oool600000?/0oooo00<00@410000000000001@00000S0?ooo`030?knoP3oool0000000D00000
;`3oool8000006/0oooo200000130?ooo`<000000P010@400`000000oooo0?ooo`1a0?ooo`00E@3o
ool00`3no_h0oooo0?ooo`050?ooo`80o_kn1`0000170?ooo`040?knoP3oool0oooo0?ooo`H00000
4@3oool00`010@4000000000000200000?T0oooo1`00000Y0?ooo`@00000;`3oool8000006/0oooo
200000130?ooo`D00000M03oool005H0oooo0P3no_h80?ooo`L00000C03oool4000000@0oooo00<0
o_kn0?ooo`3oool02`3oool600000?<0oooo00<0o_kn0?ooo`3oool01`0000030?ooo`030?knoP3o
ool0oooo0080oooo00<0o_kn0?ooo`3no_h06@3oool00`3no_h0oooo0?ooo`040?ooo`<000000`3o
ool00`3no_h0oooo0?knoP0Y0?ooo`P00000J`3oool800000480oooo0P0000000`010@4000000?oo
o`1e0?ooo`00H@3oool20000000300410@0000000000008000001`3oool00`3no_h0oooo0?ooo`11
0?ooo`0400410@000000000000000180oooo1`00003b0?ooo`P000009`3oool00`3no_h0oooo0?oo
o`030?ooo`@00000;P3oool8000006T0oooo00<0o_kn0?ooo`0000001`0000120?ooo`80000000@0
0@410000003no_h0o_knM03oool00680oooo1`0000070?ooo`030?knoP3oool0oooo0400oooo1@00
000B0?ooo`P00000k`3oool00`0000000@4100000005000002l0oooo1@0000020?ooo`030?knoP3o
ool0oooo02L0oooo2000001[0?ooo`03000000010@400@4100D00000@@3oool4000000030?knoP3o
ool0oooo07@0oooo001O0?ooo`040?knoP3oool0oooo0?ooo`L00000BP3oool30000000300410@3o
ool0oooo0140oooo2000003X0?ooo`<0o_kn0P3oool70000000300410@3oool0oooo02l0oooo1000
00000`3oool0o_kn0?ooo`0Y0?ooo`80000000<00@410000000000000`00001[0?ooo`P00000@@3o
ool3000007P0oooo001Q0?ooo`030?knoP3oool0000000H00000BP3oool4000001<0oooo00<0o_kn
000000000000100000020?ooo`80o_knj@3oool7000003@0oooo100000030?ooo`030?knoP3oool0
oooo01d0oooo00<0o_kn0?ooo`3oool01@3oool20000000300410@000000000000<00000J`3oool8
000003l0oooo1000001i0?ooo`00H@3oool00`3no_h0oooo00000006000004X0oooo1000000C0?oo
o`030?knoP000000000000@000000P3oool20?kno^T0oooo1`00000d0?ooo`@000000`3oool00`3n
o_h0oooo0?ooo`0M0?ooo`030?knoP3oool0oooo00D0oooo0P0000000`010@400000000000030000
06/0oooo2000000o0?ooo`@00000N@3oool006@0oooo1`0000180?ooo`030?knoP000000000000@0
000000<0oooo0?knoP3oool04P3oool200000>d0oooo1`00000[0?ooo`030?knoP3oool0oooo00<0
oooo00<0o_kn0?ooo`3oool00P3oool4000002X0oooo2000001[0?ooo`P00000?P3oool4000007X0
oooo001V0?ooo`L00000B03oool5000000030?ooo`3no_h0oooo0?h0oooo00<0000000410@010@40
1@00000j0?ooo`800000:@3oool9000006X0oooo2@00000m0?ooo`8000000P010@5k0?ooo`00I`3o
ool7000004L0oooo1@00000>0?ooo`030?knoP3oool0oooo0>l0oooo100000001@010@4000000000
00000000o_kn03D0oooo00<0o_kn0?ooo`3oool00`3oool2000002<0oooo0P0000020?ooo`X00000
I@3oool3000000030?ooo`000000000000P00000?03oool00`010@400000000000060?ooo`030?kn
oP3oool0oooo07@0oooo001X0?ooo`L00000AP3oool6000001/0oooo00<0o_kn0?ooo`3oool0h03o
ool70000000300410@3oool0oooo0300oooo00<0o_kn0?ooo`3oool02@3oool2000002<0oooo3@00
001W0?ooo`D000000P010@45000003/0oooo0`0000030?ooo`030?knoP3oool0oooo07P0oooo001Y
0?ooo`L00000AP3oool2000000800@4100<000000?ooo`3oool0h03oool2000001T0oooo1`000012
0?ooo`<00000903oool9000006L0oooo00<0o_kn0?ooo`3oool01P0000000`010@40000000000002
0?ooo`80o_kn=P3oool200000800oooo001Y0?ooo`L00000AP3oool500000>80oooo1@0000090?oo
o`030?knoP3oool0oooo00T0oooo1`0000140?ooo`<000009@3oool2000000800@410`00001/0?oo
o`D0000000<00@410000003oool0=03oool00`3no_h0oooo0?ooo`0300000840oooo001Y0?ooo`L0
0000AP3oool500000>80oooo1@0000090?ooo`030?knoP3oool0oooo00T0oooo1`0000140?ooo`<0
00009@3oool2000000800@410`00001/0?ooo`D0000000<00@410000003oool0=03oool00`3no_h0
oooo0?ooo`0300000840oooo001Z0?ooo`L000001`3oool00`3no_h0oooo0?ooo`0k0?ooo`H00000
h03oool00`0000000@410000000500000140oooo1@00000010010@4000000?knoP3no_i70?ooo`04
0000003oool0oooo0?knoQl0oooo00<0o_kn0?ooo`3oool00`3oool300000700oooo0`00000g0?oo
o`030000003oool0oooo0880oooo001[0?ooo`L00000A@3oool500000>00oooo2@00000>0?ooo`P0
0000o`3ooonV0?ooo`00K@3oool30000000400410@0000000000000004<0oooo00<00@4100000000
00000P0000030?ooo`80o_knfP3oool<00000080o_kn2@3oool8000000030?knoP3oool0oooo06l0
oooo0P3no_ic0?ooo`030?knoP3oool0oooo0;`0oooo001^0?ooo`03000000010@40000000@00000
00<0o_kn0?ooo`3oool0?`3oool40000000300410@000000oooo0=d0oooo3P0000080?ooo`@00000
0P010@42000004T0oooo0P3no_h20?ooo`030?knoP3oool0oooo09P0oooo00<0o_kn0?ooo`3oool0
>P3oool00`3no_h0oooo0?ooo`1o0?ooo`00K`3oool700000480oooo0P010@4300000=`0oooo0P01
0@470000000300410@000000000000D000001P3oool700000740oooo00<0o_kn0?ooo`3oool0K`3o
ool00`3no_h0oooo0?ooo`330?ooo`00K`3oool700000480oooo1@0000020?ooo`80o_kn00<0oooo
0?knoP3oool0d`3oool00`3no_h0000000000006000000800@412@0000030?ooo`L00000L`3oool0
0`3no_h0oooo0?ooo`3o0?ooocH0oooo001_0?ooo`L00000@P3oool500000080oooo0P3no_h00`3o
ool0o_kn0?ooo`3C0?ooo`030?knoP000000000000H000000P010@49000000<0oooo1`00001c0?oo
o`030?knoP3oool0oooo0?l0oooo=P3oool00700oooo1`0000110?ooo`H00000eP3oool0103no_h0
oooo0?ooo`3ooolC000000030?ooo`000000000000H00000o`3ooon]0?ooo`00L@3oool700000480
oooo1000003F0?ooo`030?knoP3oool0oooo01T0000000<00@41000000000000o`3ooon^0?ooo`00
LP3oool30000000400410@000000000000000440oooo1000000V0?ooo`050000003oool0oooo0?oo
o`3no_h0103oool00`3no_h0oooo0?ooo`2W0?ooo`0300410@000000000001P00000o`3ooon_0?oo
o`00M03oool7000003l0oooo100000030?ooo`030?knoP3oool0oooo01h0oooo1@0000060?ooo`03
0?knoP3oool0oooo0:H0oooo00<0000000410@0000000P0000000`010@4000000000000B00000?l0
oooo/@3oool007D0oooo1`00000n0?ooo`D000008P3oool7000000<0oooo00<0o_kn0?ooo`3oool0
Y`3ooolK00000080oooo00<0o_kn0?ooo`3oool0o`3ooon/0?ooo`00M@3oool7000003l0oooo1000
000S0?ooo`T00000ZP3ooolI000000800@4100<000000?ooo`3oool0o`3ooon^0?ooo`00M@3oool7
000003l0oooo1000000S0?ooo`T00000ZP3ooolI000000800@4100<000000?ooo`3oool0o`3ooon^
0?ooo`00MP3oool60000000300410@3oool0oooo03`0oooo1000000V0?ooo`L00000Z03ooolN0000
0?l0oooo[`3oool007L0oooo1`0000000`3no_h0oooo0?ooo`0j0?ooo`H000008`3oool00`3no_h0
oooo0000000700000:H0oooo7P00003o0?ooojl0oooo001b0?ooo`80o_kn103oool7000000X0oooo
00<0o_kn0?ooo`3oool0<03oool5000002H0oooo2000002J0?ooo`030?knoP3oool0oooo00H0oooo
8@00003o0?ooojh0oooo001i0?ooo`L00000103oool00`3no_h0oooo0?ooo`0e0?ooo`D000009`3o
ool700000:<0oooo8@0000000`3no_h0oooo0?ooo`3o0?oooj/0oooo001k0?ooo`D000000P010@4j
0?ooo`0300410@000000000000<00000:@3oool00`010@400000000000050?ooo`030?knoP3oool0
oooo09/0oooo7@00000200410@@00000o`3ooon]0?ooo`00N`3oool30000000400410@0000000000
000000@0oooo00<0o_kn0?ooo`3oool00`3oool00`3no_h0oooo0?ooo`0]0?ooo`H00000:P3oool2
00000:80oooo9000003o0?ooojd0oooo001k0?ooo`<0000000@00@410000000000000000103oool0
0`3no_h0oooo0?ooo`030?ooo`030?knoP3oool0oooo02d0oooo1P00000Z0?ooo`800000XP3ooolT
00000?l0oooo[@3oool00740oooo00<0o_kn0?ooo`3oool00`3oool00`3no_h0oooo0?ooo`020?oo
o`L00000>@3oool00`3no_h0000000000003000002X0oooo00<0o_kn0?ooo`3oool0X@3oool00`00
00000@410000000M0000000300410@000000000000800000o`3ooon/0?ooo`00O@3oool7000003T0
oooo1P0000000`3no_h0oooo0?ooo`390?ooobH00000o`3ooon/0?ooo`00N@3oool30?knoP80oooo
1`00000g0?ooo`030?knoP000000000000@0000000<0oooo0?knoP3oool09P3oool00`3no_h0oooo
0?ooo`2P0?ooobH00000o`3ooon/0?ooo`00M@3oool00`3no_h0oooo0?ooo`070?ooo`@0000000<0
0@410000000000001@3oool00`3no_h0oooo0?ooo`0`0?ooo`03000000010@400@410080000000<0
o_kn0?ooo`3oool0:@3oool00`3no_h0oooo0?ooo`2L0?ooobL00000o`3ooon/0?ooo`00N`3oool0
0`3no_h0oooo0?ooo`020?ooo`L00000=`3oool600000<T0oooo900000000`010@40000000000003
00000?l0ooooZP3oool00800oooo1`00000h0?ooo`D00000@03oool00`3no_h0oooo0?ooo`220?oo
o`040?knoP3oool0oooo0?ooob00000000<00@410000000000000P0000000`010@40000000000002
00000?l0ooooZP3oool00800oooo1`00000h0?ooo`D00000@03oool00`3no_h0oooo0?ooo`220?oo
o`040?knoP3oool0oooo0?ooob00000000<00@410000000000000P0000000`010@40000000000002
00000?l0ooooZP3oool00880oooo1`00000c0?ooo`030?knoP3oool0oooo00D000001@3oool00`3n
o_h0oooo0?ooo`0g0?ooo`030?knoP3oool0oooo00<0oooo00<0o_kn0?ooo`3oool0O`3ooolV0000
0?l0oooo/03oool007l0oooo00@0o_kn0?ooo`3oool0oooo1`0000000`3oool0o_kn0?ooo`0`0?oo
o`030?knoP3oool0000000D00000A03oool00`3no_h0oooo0?ooo`1m0?ooo`030?knoP3oool00000
01T000000P010@4700000?l0oooo/`3oool008@0oooo1`00000f0?ooo`@00000@P3oool00`3no_h0
oooo0?ooo`200?ooob800000o`3ooone0?ooo`00Q@3oool40000000300410@000000000003D0oooo
100000080?ooo`80o_kn=03oool2000008D0oooo8000003o0?oookL0oooo00250?ooo`P00000=03o
ool5000003`0oooo1P0000210?oooah00000o`3ooonj0?ooo`00QP3oool7000003D0oooo10000004
0?ooo`030?knoP3oool0oooo0080o_kn<P3oool9000007h0oooo700000070?ooo`030?knoP3oool0
oooo0?l0oooo/`3oool008H0oooo1`00000e0?ooo`@00000103oool00`3no_h0oooo0?ooo`020?kn
oS80oooo2@00001n0?oooa`000001`3oool00`3no_h0oooo0?ooo`3o0?oook<0oooo00270?ooo`L0
0000;P3oool00`3no_h0oooo0?ooo`030?ooo`@00000?@3oool8000007d0oooo6000003o0?oool40
oooo00290?ooo`80000000<00@410000000000000P00000b0?ooo`H00000?03oool:000000030?kn
oP3oool0oooo06l0oooo00<0o_kn0?ooo`3oool0103oool20000000300410@000000000001800000
o`3oooo30?ooo`00RP3oool700000380oooo0P0000000`010@4000000000000o0?ooo`0300410@00
0000000000H00000L`3oool01P3no_h0oooo0?ooo`3oool0000000410A<00000o`3oooo50?ooo`00
R@3oool0103no_h0oooo000000010@4500000080oooo00<0o_kn0?ooo`3oool0;03oool500000400
oooo0`0000000`010@4000000000000200000780oooo00@0o_kn0?ooo`3oool0oooo4P00003o0?oo
olT0oooo002;0?ooo`P00000<03oool00`0000000@4100000003000003h0oooo00<0o_kn0?ooo`3o
ool01@00001g0?ooo`h00000o`3oooo=0?ooo`00S03oool700000340oooo1@0000120?ooo`@00000
M@3oool;00000?l0oooodP3oool008`0oooo1`00000a0?ooo`D00000@P3oool4000007D0oooo2`00
003o0?ooom80oooo00270?ooo`80o_kn103oool700000300oooo1@00002j0?ooo`X000001@3oool2
0?kno_l0ooooc@3oool008`0oooo00<0o_kn0?ooo`0000001P00000X0?ooo`030?knoP3oool0oooo
00@0oooo1P00002i0?ooo`L000004P3oool00`3no_h0oooo0?ooo`3o0?oool80oooo002@0?ooo`L0
00001`3oool00`3no_h0oooo0?ooo`0T0?ooo`D00000G@3oool00`3no_h0oooo0?ooo`040?ooo`03
0?knoP3oool0oooo00<0oooo00<0o_kn0?ooo`3oool02`3oool00`3no_h0oooo0?ooo`030?ooo`03
0?knoP3oool0o_kn03L0oooo100000000`010@4000000?ooo`3o0?ooomP0oooo002@0?ooo`030?kn
oP000000000000D000001`3oool00`3no_h0oooo0?ooo`0S0?ooo`D00000o`3ooooo0?oooiP0oooo
002A0?ooo`P00000;03oool600000?l0ooooo`3ooonG0?ooo`00TP3oool7000002d0oooo1@00001m
0?ooo`030?knoP3oool0oooo03/0oooo00<0o_kn0?ooo`3oool0o`3ooooH0?ooo`00TP3oool70000
02d0oooo1@00001m0?ooo`030?knoP3oool0oooo03/0oooo00<0o_kn0?ooo`3oool0o`3ooooH0?oo
o`00T`3oool7000002`0oooo1@00001K0?ooo`<000000P3oool00`3no_h0oooo0?ooo`0P0?ooo`03
0?knoP3oool0oooo0300oooo00<0o_kn0?ooo`3oool0o`3ooooM0?ooo`00U03oool00`010@400000
00000004000002/0oooo1P00001I0?ooo`P000003@3oool6000000D0oooo0P3no_ko0?ooool0oooo
6`3oool009D0oooo1`00000/0?ooo`@00000F03oool<000000X0oooo1P000000103no_h0oooo0?oo
o`010@4300000?l0ooooo`3ooolK0?ooo`00T@3oool00`3no_h0oooo0?ooo`030?ooo`L00000:P3o
ool01@0000000@41000000000000o_kn05T0oooo3@0000070?ooo`H000000P3oool3000000800@41
0`00003o0?ooool0oooo603oool009L0oooo2000000Y0?ooo`D00000F`3oool;000000L0oooo1P00
00000`3oool0o_kn0000000<000000@0oooo0P3no_h00`3oool0o_kn0?ooo`0;0?ooo`030?knoP3o
ool0oooo0?l0oooon`3oool009P0oooo1`00000Z0?ooo`@00000GP3oool8000000L0oooo1P000002
0?oooa0000003P3oool00`3no_h0oooo0?ooo`3o0?ooooh0oooo002H0?ooo`L00000:P3oool40000
05h0oooo200000070?ooo`H000000P3oool@000000h0oooo00<0o_kn0?ooo`3oool0o`3oooon0?oo
o`00V@3oool7000000L0oooo00<0o_kn0?ooo`3oool07`3oool6000005l0oooo100000020?ooo`03
0?knoP3oool0oooo00<0oooo1000000200410@030?ooo`000000000001<0000000<0o_kn0?ooo`3o
ool02`3oool00`3no_h0oooo0?ooo`3o0?ooooX0oooo002J0?ooo`03000000010@40000000@00000
:@3oool5000005`0oooo00<0o_kn0?ooo`3oool0303oool6000000030?ooo`000000000000L00000
00<00@410000000000003000003o0?ooool0oooo2@3oool009/0oooo1`00000X0?ooo`D000000`3o
ool00`3no_h0oooo0?ooo`1C0?ooo`030?knoP3oool0oooo00l0oooo1P000000103oool000000000
0000000300410@T0000000<00@410000000000002P0000040?ooo`80o_kn1`3oool00`3no_h0oooo
0?ooo`3o0?oooo@0oooo002H0?ooo`040?knoP3oool0oooo0?ooo`L000000P3no_hU0?ooo`H00000
F03oool00`3no_h0oooo0?ooo`040?ooo`030?knoP3oool0oooo00P0oooo9`00003o0?ooool0oooo
0@3oool009P0oooo00@0o_kn0?ooo`3oool0oooo2@00000V0?ooo`D00000JP3oool[00000?l0oooo
o03oool009L0oooo00<0o_kn0?ooo`3oool0103oool7000002H0oooo1@0000020?ooo`040?knoP3o
ool0o_kn0?knoUh0oooo00<0o_kn0?ooo`3oool00`3oool;000000800@411`0000000`010@400000
00410@0?0000000400410@000000000000410@@00000o`3ooooi0?ooo`00U`3oool00`3no_h0oooo
0?ooo`040?ooo`L000009P3oool500000080oooo00@0o_kn0?ooo`3no_h0o_knGP3oool00`3no_h0
oooo0?ooo`030?ooo`/000000P010@470000000300410@0000000@4100l0000000@00@4100000000
00000@411000003o0?ooooT0oooo002O0?ooo`L000008`3oool00`3no_h0oooo00000005000006T0
oooo5@0000000`010@4000000000000J000001H0oooo00<0o_kn0?ooo`3oool0o`3ooooL0?ooo`00
X03oool7000002D0oooo1@00001]0?ooo`H0000000<00@41000000000000:000000C0?ooo`030?kn
oP3oool0oooo0?l0oooog03oool00:40oooo1`00000T0?ooo`H00000L03oool90000000300410@00
0000000000<0000000<00@41000000000000800000040?ooo`030?knoP3oool0oooo0?l0ooooiP3o
ool00:80oooo1`00000T0?ooo`D00000L`3ooolc000000030?ooo`3no_h0o_kn0?l0ooooiP3oool0
0:80oooo2000000O0?ooo`040?knoP3oool0oooo0?ooo`D00000N03oool70000000300410@000000
000002L00000o`3ooooV0?ooo`00X`3oool7000002<0oooo1P00001`0?ooo`030?knoP3oool0oooo
00P0oooo<@0000000`3no_h0oooo0?ooo`3o0?oooml0oooo002S0?ooo`L000008`3oool600000700
oooo00<0o_kn0?ooo`3oool0203ooola000000030?knoP3oool0oooo0?l0oooog`3oool00:D0oooo
00<0000000410@0000000P00000200410B<0oooo1000001g0?ooo`030?knoP3oool0oooo00@0oooo
7@0000000`010@4000000000000A00000?l0oooog`3oool00:H0oooo1`0000000`3no_h0oooo0?oo
o`0O0?ooo`04000000010@400000000006d0oooo00<0o_kn0?ooo`3oool04P3ooolb00000?l0oooo
fP3oool00:L0oooo1`0000000`3oool0o_kn0?ooo`060?ooo`030?knoP3oool0oooo01D0oooo0`00
000010010@4000000?knoP3no_j20?oooaD0000000<00@410000000000006P00003o0?ooomL0oooo
002X0?ooo`L00000103oool00`3no_h0oooo0?ooo`0J0?ooo`@00000R@3oool20000000300410@00
0000000002`00000o`3ooooC0?ooo`00X`3oool20?knoP<0oooo2000000P0?ooo`H00000Q03oool2
0?knoP@0oooo;P00003o0?ooom<0oooo002Y0?ooo`L000001@3oool00`3no_h0oooo0?ooo`030?oo
o`030?knoP3oool0oooo01<0oooo1@00001m0?ooo`80o_kn3`3ooolY00000?l0ooooe03oool00:T0
oooo1`0000050?ooo`030?knoP3oool0oooo00<0oooo00<0o_kn0?ooo`3oool04`3oool5000007d0
oooo0P3no_h?0?ooobT00000o`3ooooD0?ooo`00ZP3oool20000000300410@000000000000800000
0P3no_hN0?ooo`H00000PP3oool00`3no_h0oooo0?ooo`030?ooo`030?knoP3oool0oooo00D0oooo
9P00003o0?ooom@0oooo002/0?ooo`L000007`3oool5000009@0oooo8P00003o0?ooom@0oooo002Y
0?ooo`040?knoP3oool0oooo0?ooo`L000007P3oool600000880oooo0P3no_h80?ooo`030?knoP3o
ool0oooo00P0oooo7000003o0?ooomH0oooo002]0?ooo`P000001@3oool00`3no_h0oooo0?ooo`0F
0?ooo`03000000010@400@4100800000O`3oool00`3no_h0oooo0?knoP020?knoQH0oooo6@00003o
0?ooomH0oooo002^0?ooo`P000007@3oool5000009d0oooo2000000200410@`00000103oool00`3n
o_h0oooo0?ooo`020?knoP030?ooo`3no_h0oooo0?l0oooobP3oool00:l0oooo1`00000N0?ooo`D0
0000W`3oool00`0000000@410000000?00000?l0ooooe`3oool00:l0oooo1`00000N0?ooo`D00000
W`3oool00`0000000@410000000?00000?l0ooooe`3oool00;00oooo1`00000K0?ooo`030?knoP3o
ool0000000@00000J@3oool00`3no_h0oooo0?ooo`0e0?ooo`030?knoP3oool0oooo00d00000o`3o
oooG0?ooo`00[P3oool00`3no_h0oooo0?ooo`07000000<0oooo00<0o_kn0?ooo`3oool0603oool4
00000:P0oooo0P00000200410@@00000203oool20?kno_l0ooooc@3oool00;<0oooo100000000`01
0@4000000000000L0?ooo`@00000YP3oool0103no_h0oooo0?ooo`3no_h20?ooo`<000003`3oool0
0`3no_h0oooo0?ooo`3o0?ooolH0oooo002c0?ooo`<0000000<00@410000000000000P00000L0?oo
o`@000000P3oool00`3no_h0oooo0?ooo`1W0?ooo`030?knoP3oool0oooo03d0oooo00<0o_kn0?oo
o`3oool00`3oool00`3no_h0oooo0?ooo`3o0?ooom40oooo002d0?ooo`P000006`3oool4000005`0
oooo0P3no_h00`3oool0000000000004000003P0oooo00<0o_kn0?ooo`3oool0o`3ooooV0?ooo`00
]@3oool20000000300410@000000000000800000703oool5000005d0oooo1P0000030?ooo`050?kn
oP3oool0oooo0?ooo`3no_h0>03oool00`3no_h0oooo0?knoP0?0?ooo`<00000o`3oooo<0?ooo`00
]@3oool20000000300410@000000000000800000703oool5000005d0oooo1P0000030?ooo`050?kn
oP3oool0oooo0?ooo`3no_h0>03oool00`3no_h0oooo0?knoP0?0?ooo`<00000o`3oooo<0?ooo`00
]P3oool7000001/0oooo0P0000000`010@4000000000001M0?ooo`H00000D@3oool600000?l0oooo
bP3oool00;L0oooo1`00000J0?ooo`H00000G03oool600000540oooo00<0000000410@010@401@00
003o0?ooolP0oooo002f0?ooo`030?knoP3oool0000000H000006P3oool5000005`0oooo1P00001@
0?ooo`D0000000<00@410000000000000`00003o0?ooolH0oooo002h0?ooo`T000000P3oool00`3n
o_h0oooo0?ooo`0C0?ooo`H00000F`3oool6000005@0oooo0`0000000`010@400000000000030000
0?l0ooooa03oool00;X0oooo2000000H0?ooo`D00000F`3oool6000005D0oooo1P0000000`010@40
00000000003o0?oool<0oooo002k0?ooo`L00000603oool6000005X0oooo1P00001G0?ooo`P00000
o`3oooo20?ooo`00^`3oool7000001P0oooo1P00001J0?ooo`H00000E`3oool800000?l0oooo`P3o
ool00;`0oooo1`00000H0?ooo`D00000FP3oool6000005T0oooo1P0000040?ooo`030?knoP3oool0
oooo0?l0oooo^`3oool00;X0oooo00<0o_kn0?ooo`3oool01`00000F0?ooo`040?knoP0000000000
00410@<00000F@3oool6000005/0oooo0`00003o0?oool<0oooo002n0?ooo`L000001`3oool00`3n
o_h0oooo0?ooo`0:0?ooo`040?knoP3oool0oooo0?ooo`@00000F@3oool6000000<0oooo00D0o_kn
0?ooo`3oool0oooo0?knoP160?ooo`030?knoP3oool0oooo0:00oooo00<0o_kn0?ooo`3oool02@3o
ool00`3no_h0oooo0?ooo`3o0?ooob40oooo002n0?ooo`D000000P010@400`000000oooo0?ooo`05
0?ooo`80o_kn3P3oool5000005D0oooo0P3no_h00`3oool0000000000004000004H0oooo1000002R
0?ooo`80o_kn203oool00`3no_h0oooo0?ooo`040?ooo`030?knoP3oool0oooo0?l0oooo8@3oool0
0;l0oooo2@00000F0?ooo`80000000<00@410000003oool0I03oool00`3no_h0oooo0?ooo`0l0?oo
o`@00000X@3oool6000000L0oooo00<0o_kn0?ooo`3oool0o`3ooolV0?ooo`00`@3oool7000001H0
oooo1P00002O0?ooo`030?knoP3oool0oooo0080000000<00@410000003oool0W`3oool900000?l0
oooo;P3oool00<40oooo1`00000F0?ooo`H00000W`3oool00`3no_h0oooo0?ooo`02000000030041
0@000000oooo09l0oooo2@00003o0?ooobh0oooo00320?ooo`L000005P3oool500000:80oooo1000
002P0?ooo`8000000P010@4800000?l0oooo:`3oool00<<0oooo1`00000A0?ooo`80o_kn0P3oool6
000000030?ooo`3no_h0oooo05X0oooo00<0o_kn0?ooo`3oool0@@3oool20000000300410@000000
oooo00H0oooo00<0o_kn0?ooo`3oool0UP3oool60000000300410@000000000000D00000o`3ooolY
0?ooo`00a03oool700000100oooo0P3no_h30?ooo`D00000V`3oool00`3no_h0oooo0?ooo`030?oo
o`@000001P3oool00`3no_h0oooo0?ooo`2F0?ooo`<000000P010@4?00000?l0oooo903oool00<@0
oooo2000000?0?ooo`80o_kn0`3oool600000:00oooo0`0000000`010@40oooo0?ooo`2M0?ooo`03
00410@000000000001D00000o`3ooolP0?ooo`00a@3oool8000000D0oooo00<0o_kn0?ooo`3oool0
303oool6000009l0oooo1000002O0?ooo`80000000@00@410000000000000@415P00003o0?oooa`0
oooo00360?ooo`L000001P3oool00`3no_h0oooo0?ooo`0;0?ooo`H00000W`3oool4000009l0oooo
7P00003o0?oooaX0oooo00360?ooo`L000001P3oool00`3no_h0oooo0?ooo`0;0?ooo`H00000W`3o
ool4000009l0oooo7P00003o0?oooaX0oooo00380?ooo`L00000203oool00`3no_h0oooo0?ooo`08
0?ooo`H00000WP3oool20000000300410@000000oooo0080oooo00<0o_kn0?ooo`3oool0V@3ooolR
000000/0oooo00<0o_kn0?ooo`3oool0o`3oool80?ooo`00b03oool00`3no_h00000000000090000
00h0oooo1P00002N0?ooo`80000000<00@410000003oool00P3oool00`3no_h0oooo0?ooo`0R0?oo
o`800000M03oool30000000300410@000000000001h0000000<00@410?ooo`3oool0o`3ooolB0?oo
o`00b03oool00`3no_h0oooo00000009000000<0oooo00<0o_kn0?ooo`3oool02P3oool5000009d0
oooo1000000W0?ooo`@00000L`3ooolM0000000300410@000000000000P000001P3oool00`3no_h0
oooo0?ooo`3o0?ooo`P0oooo00380?ooo`030?knoP3oool0000000T00000403oool500000<L0oooo
1`00001a0?ooob@0000000<00@41000000000000100000020?ooo`030?knoP3oool0oooo0?l0oooo
2@3oool00</0oooo100000000`3oool000000000000200000140oooo1P00002L0?ooo`030?knoP3o
ool0oooo02@0oooo0P3no_h00`3oool00@410000000500000700oooo9`0000000`010@4000000000
000400000?l0oooo2`3oool00=00oooo1000000A0?ooo`L00000V03oool20?knoR`0oooo1P00001`
0?oooc800000o`3oool70?ooo`00d03oool400000140oooo1`00002H0?ooo`80o_kn;03oool60000
0700oooo<P00003o0?ooo`L0oooo003?0?ooon80000000<00@41000000010@40K@0000000`010@40
000000410@0a0000000300410@00000000000080000000@00@41000000010@40oooo0P3no_ko0?oo
o`40oooo003?0?ooogH000000P010@7o000000L0000000<00@410000000000002P0000000`010@40
00000000000300000?l0oooo0@3oool00<l0oooo4P00000010010@400000000000010@4400000080
0@41E`0000000`010@4000000000003o000001T00000o`3oool40?ooo`00c`3ooolG000000030041
0@00000000000<l0000000<00@41000000000000W`0000000`3oool0o_kn0?ooo`3o0?ooo`@0oooo
003@0?ooo`@000004P3oool00`3no_h0oooo0000000500000<T0oooo1000001/0?ooobl0000000<0
oooo0?knoP3no_h0103oool00`3no_h0oooo0?ooo`3o0?ooo`40oooo003@0?ooo`@000005@3oool6
00000<T0oooo0P00001^0?ooob`00000o`3oool=0?ooo`00d03oool4000001D0oooo1P0000390?oo
o`800000KP3oool/00000?l0oooo3@3oool00=00oooo1000000E0?ooo`D0000000<00@410?ooo`3o
ool0o`3ooolh0?ooobP000002`3oool00`3no_h0oooo0?ooo`3o0?ooo`<0oooo003@0?ooo`@00000
5`3oool5000004X0oooo1P00001^0?ooo`80o_knKP3oool20?knoPP0oooo9@0000030?ooo`80o_kn
o`3oool?0?ooo`00d03oool4000001L0oooo00<0000000410@000000100000180?ooo`H00000L`3o
ool00`3no_h0oooo0?ooo`1b0?ooo`X0000000<00@410000000000005000003o0?oooaP0oooo003@
0?ooo`@00000603oool6000004P0oooo1P00001e0?ooo`80o_knLP3ooolK0000000300410@000000
oooo0?l0oooo6P3oool00=00oooo1000000J0?ooo`D00000A`3oool600000>T0oooo00<000000041
0@000000300000000`010@4000000000000700000080o_kno`3ooolM0?ooo`00d03oool4000001X0
oooo1P0000160?ooo`H00000M03oool500000700oooo1`0000000`010@4000000000000<00000?l0
oooo8P3oool00=00oooo1000000J0?ooo`H00000AP3oool6000007@0oooo1@00001`0?ooo`L00000
00<00@410000000000003000003o0?ooob80oooo003@0?ooo`@000006`3oool5000004H0oooo1P00
001d0?ooo`<0000000D00@410000003oool0oooo0?knoP1]0?ooo`0300410@0000000@4100l00000
0P3oool20?kno_l0oooo8P3oool00=00oooo1000000K0?ooo`H00000A@3oool6000007@0oooo0`00
00001@010@4000000?ooo`3oool0o_kn06h0oooo3`0000020?ooo`80o_kno`3ooolT0?ooo`00d03o
ool4000001`0oooo1@0000000`010@40oooo0?ooo`120?ooo`H00000M03oool500000740oooo3000
003o0?ooob/0oooo003@0?ooo`@000007P3oool5000004<0oooo1P00001d0?ooo`D00000L@3oool8
00000?l0oooo;`3oool00=00oooo1000000N0?ooo`D00000@`3oool6000007@0oooo100000000`01
0@40oooo0?ooo`1_0?ooo`D000007@3oool00`3no_h0oooo0?ooo`3o0?oooa80oooo003@0?ooo`@0
00007`3oool600000440oooo1P00001^0?ooo`80o_kn103oool5000000H0oooo00<0o_kn0?ooo`3o
ool0J03oool00`010@40oooo0?ooo`0K0?ooo`030?knoP3oool0oooo0?l0oooo5P3oool00=00oooo
1000000O0?ooo`H00000@@3oool6000006h0oooo0P3no_h40?ooo`D000001P3oool00`3no_h0oooo
0?ooo`1X0?ooo`0300410@3oool0oooo01/0oooo00<0o_kn0?ooo`3oool0o`3ooolF0?ooo`00d03o
ool4000001X0oooo00<0o_kn0?ooo`3oool00P3oool700000400oooo1P0000160?ooo`0400000001
0@400000000002X0oooo0`0000000`010@4000000?ooo`060?ooo`030?knoP3oool0oooo0880oooo
00<0o_kn0?ooo`3oool0o`3ooolI0?ooo`00d03oool400000200oooo0P00000010010@4000000000
000000100?ooo`H00000AP3oool4000002X0oooo1@00002>0?ooo`030?knoP3oool0oooo0?l0oooo
5`3oool00=00oooo1000000P0?ooo`L00000Q@3oool00`3no_h0oooo0?ooo`030?ooo`@00000:03o
ool00`3no_h0oooo000000020000000300410@000000oooo0?l0ooooY`3oool00=00oooo1000000Q
0?ooo`L00000>`3oool20?knoTd0oooo1000000Z0?ooo`D00000o`3ooonX0?ooo`00d03oool40000
0280oooo1P00002:0?ooo`@00000:P3oool5000008h0oooo1000003o0?oooaH0oooo003@0?ooo`@0
00008P3oool7000008T0oooo1000000b0?ooo`80o_knJ`3oool00`3no_h0oooo0?ooo`0J0?ooo`D0
0000o`3ooolF0?ooo`00d03oool400000280oooo1`0000290?ooo`@00000<P3oool20?knoV/0oooo
00<0o_kn0?ooo`3oool06P3oool500000?l0oooo5P3oool00=00oooo1000000S0?ooo`@0000000<0
0@41000000000000R03oool30000000300410@3oool0oooo0;X0oooo1P00003o0?oooaD0oooo003@
0?ooo`@000008`3oool900000080oooo00<0o_kn0?ooo`3oool0N`3oool00`3no_h0oooo0?ooo`03
0?ooo`@000001P3oool00`3no_h0oooo0?ooo`2b0?ooo`L00000o`3ooolE0?ooo`00d03oool40000
02D0oooo1`0000260?ooo`80000000<00@410000003oool01P3oool00`3no_h0oooo0?ooo`2[0?oo
o`030?knoP3oool0oooo00<0oooo2000003o0?oooa@0oooo003@0?ooo`@000009`3oool600000003
0?ooo`3no_h0oooo0880oooo1000002k0?ooo`P00000o`3ooolD0?ooo`00d03oool4000002P0oooo
00<0000000410@0000000`0000210?ooo`030?knoP3oool0oooo0080000000<00@410000003oool0
^@3oool70000000300410@000000oooo0?l0oooo4`3oool00=00oooo1000000X0?ooo`L00000P`3o
ool400000;00oooo00<0o_kn0?ooo`3oool01`3oool:000000@0oooo00<0o_kn0?ooo`3oool0o`3o
ool<0?ooo`00d03oool4000002P0oooo1`0000230?ooo`@00000/03oool00`3no_h0oooo0?ooo`07
0?ooo`X00000103oool00`3no_h0oooo0?ooo`3o0?ooo``0oooo003@0?ooo`@00000:@3oool60000
08<0oooo1000002h0?ooo`80000000<00@410000000000001`00003o0?oooa<0oooo003@0?ooo`@0
00008P3oool00`3no_h0oooo0?ooo`050?ooo`H00000RP3oool00`3no_h0oooo0?ooo`2Y0?ooo`05
0?knoP3oool0oooo0?ooo`3no_h00`3oool90000000400410@000000000000000?l0oooo4P3oool0
0=00oooo1000000/0?ooo`D00000o`3ooolg0?ooo`80o_kn103oool:000000040?ooo`0000000000
00000?l0oooo4P3oool00=00oooo1000000Z0?ooo`80o_kn00<0oooo0000000000001000003o0?oo
oc/0oooo2P0000001@3oool00000000000010@4000000?l0oooo4@3oool00=00oooo1000000]0?oo
o`80000000@00@410000000000000000203oool00`3no_h0oooo0?ooo`3o0?oooc00oooo2P000000
0`3oool000000000000200000?l0oooo4@3oool00=00oooo1000000^0?ooo`H00000o`3oooli0?oo
o`T00000103oool300000?l0oooo4@3oool00=00oooo1000000^0?ooo`H00000o`3oooli0?ooo`T0
0000103oool300000?l0oooo4@3oool00=00oooo1000000_0?ooo`H00000o`3ooolh0?ooo`@00000
00<00@410000000000000P0000040?ooo`0300410@000000000000800000o`3oool?0?ooo`00d03o
ool400000300oooo1P00003o0?ooocD0oooo00<0o_kn0000000000001`0000060?ooo`@00000o`3o
ool?0?ooo`00d03oool400000340oooo1@00003o0?oooc80oooo0P3no_h20?ooo`T00000103oool0
0`3no_h0oooo0000000400000?l0oooo3P3oool00=00oooo1000000a0?ooo`@0000000<00@410000
003oool0o`3ooolb0?ooo`030?knoP000000000000L00000203oool400000?l0oooo3P3oool00=00
oooo1000000c0?ooo`D00000=`3oool00`3no_h0oooo0?ooo`3h0?ooo`T000001`3oool00`3no_h0
00000000000200000?l0oooo3P3oool00=00oooo1000000d0?ooo`H00000;03oool600000?X0oooo
00@0o_kn0?ooo`3oool0oooo1P0000000`010@400000000000080?ooo`D000000P3no_ko0?ooo`/0
oooo003@0?ooo`@00000=03oool6000002`0oooo1P00003j0?ooo`040?knoP3oool0oooo0?ooo`H0
000000<00@41000000000000203oool500000080o_kno`3oool;0?ooo`00d03oool4000003<0oooo
00<0o_kn0000000000001@00000[0?ooo`H00000o@3oool9000000X0oooo1000003o0?ooo`d0oooo
003@0?ooo`@00000=@3oool7000002X0oooo1P00003j0?ooo`030?knoP3oool0oooo00L0000000<0
0@410000003oool02@3oool500000?l0oooo303oool00=00oooo1000000f0?ooo`L000000P3oool2
0?knoRD0oooo1P00001d0?ooo`D00000PP3oool:000000d0oooo0`00003o0?ooo``0oooo003@0?oo
o`@00000=`3oool7000002P0oooo1P0000070?ooo`030?knoP3oool0oooo06X0oooo1@0000220?oo
o`X000003@3oool400000?l0oooo2`3oool00=00oooo1000000d0?ooo`040?knoP3oool0oooo0?kn
oPL000009`3oool6000000D0oooo0P3no_i]0?ooo`D00000P@3oool:000000h0oooo1000003o0?oo
o`/0oooo003@0?ooo`@00000>P3oool5000000D0oooo00<0o_kn0?ooo`3oool07`3oool400000080
0@41M03oool500000840oooo2P00000?0?ooo`<00000o`3oool;0?ooo`00d03oool4000003X0oooo
1@0000050?ooo`030?knoP3oool0oooo01l0oooo1000000200410G@0oooo1@0000210?ooo`X00000
3`3oool300000?l0oooo2`3oool00=00oooo1000000k0?ooo`H000000`3oool00`3no_h0oooo0?oo
o`0O0?ooo`H00000A03oool20?knoRh0oooo1@0000210?ooo`03000000010@400@4100L000003`3o
ool400000?l0oooo2P3oool00=00oooo1000000l0?ooo`H00000903oool6000004L0oooo00<0o_kn
0?ooo`3oool0:P3oool500000800oooo2@00000B0?ooo`<00000o`3oool:0?ooo`00d03oool40000
03`0oooo1`00000S0?ooo`H000000P3oool00`3no_h0oooo0?ooo`1_0?ooo`D00000P03oool90000
00/0oooo00<0o_kn0?ooo`3oool0103oool500000?l0oooo203oool00=00oooo1000000m0?ooo`L0
00008P3oool600000080oooo00<0o_kn0?ooo`3oool0@@3oool4000002X0oooo1@00001o0?ooo`T0
00004`3oool5000000030?knoP3oool0oooo0?l0oooo1@3oool00=00oooo1000000n0?ooo`030041
0@000000000000@000008@3oool6000004H0oooo0P0000000`010@4000000?ooo`020?ooo`030?kn
oP3oool0oooo02@0oooo1@00001o0?ooo`T00000503oool400000?l0oooo203oool00=00oooo1000
000o0?ooo`800@411@00001/0?ooo`80000000<00@410000003oool00P3oool00`3no_h0oooo0?oo
o`0T0?ooo`D00000O`3oool8000001D0oooo1@0000000`3oool0o_kn0?ooo`3o0?ooo`@0oooo003@
0?ooo`@00000@@3oool5000000800@41JP3oool4000002X0oooo1@00001n0?ooo`T000003@3oool0
0`3no_h0oooo0?ooo`060?ooo`@00000o`3oool70?ooo`00d03oool400000440oooo1@0000020041
0FX0oooo1000000Z0?ooo`D00000OP3oool9000000d0oooo00<0o_kn0?ooo`3oool01P3oool40000
0?l0oooo1`3oool00=00oooo100000120?ooo`L00000J@3oool4000002X0oooo1@00001h0?ooo`03
0?knoP3oool0oooo0080oooo2P00000=0?ooo`030?knoP3oool0oooo00H0oooo1@00003o0?ooo`H0
oooo003@0?ooo`@00000?@3oool00`3no_h0oooo0?ooo`030?ooo`L000002P3oool00`3no_h0oooo
0?ooo`1K0?ooo`@00000[03oool:000001@0oooo00<0o_kn0?ooo`0000001000003o0?ooo`H0oooo
003@0?ooo`@00000A03oool8000006H0oooo1000002Y0?ooo`h00000503oool800000?l0oooo103o
ool00=00oooo100000160?ooo`800@410`0000000`010@4000000?ooo`1T0?ooo`@00000Y`3ooolD
000000d0oooo3P00003o0?ooo`40oooo003@0?ooo`@00000B03oool7000006<0oooo1000003o0?oo
omL0oooo003@0?ooo`@00000?03oool00`3no_h0oooo0?ooo`030?ooo`030?knoP3oool0oooo00@0
oooo1`0000030?ooo`030?knoP3oool0oooo05`0oooo1000002g0?ooo`030?knoP3oool0oooo0?l0
oooo7@3oool00=00oooo1000000l0?ooo`030?knoP3oool0oooo00<0oooo00<0o_kn0?ooo`3oool0
103oool7000000<0oooo00<0o_kn0?ooo`3oool0G03oool400000;L0oooo00<0o_kn0?ooo`3oool0
o`3ooolM0?ooo`00d03oool4000004/0oooo100000000`010@4000000000001P0?ooo`@00000o`3o
oooG0?ooo`00d03oool4000004@0oooo00<0o_kn0?ooo`3oool00`3oool00`3no_h0oooo00000006
00000180oooo0P00001;0?ooo`@00000[03oool00`3no_h0oooo0?ooo`0Q0?ooo`030?knoP3oool0
oooo0?l0oooo103oool00=00oooo1000000o0?ooo`80o_kn1`3oool00`3no_h0oooo0?ooo`020?oo
o`L000003`3oool5000004X0oooo1000002[0?ooo`050?knoP3oool0oooo0?ooo`3no_h01@3oool0
0`3no_h0oooo0?ooo`0D0?ooo`030?knoP3oool0oooo0080oooo00<0o_kn0?ooo`3oool0o`3oool3
0?ooo`00d03oool4000004l0oooo0P00000010010@40000000000000000:0?ooo`040?knoP3oool0
oooo0?ooo`D0000000<00@410000003oool0o`3ooooo0?ooob<0oooo003@0?ooo`@00000D03oool8
000000X0oooo2P00003o0?ooool0oooo8P3oool00=00oooo1000001A0?ooo`P00000203oool<0000
0?l0ooooo`3ooolQ0?ooo`00d03oool400000540oooo200000080?ooo``00000o`3ooooo0?ooob40
oooo003@0?ooo`@00000DP3oool8000000H0oooo3P00003o0?ooool0oooo803oool00=00oooo1000
001D0?ooo`0300410@000000000000@00000103oool4000000800@41100000000`010@4000000000
000400000?l0ooooo`3ooolN0?ooo`00d03oool4000005D0oooo2@0000000`3oool00@410000000@
00000?l0ooooo`3ooolM0?ooo`00d03oool4000005L0oooo1`00000010010@400000000000010@4A
00000?l0ooooo`3ooolK0?ooo`00d03oool4000005P0oooo3P0000000`010@4000000000000;0000
0?l0ooooo`3ooolJ0?ooo`00d03oool4000005T0oooo3@0000000`010@4000000000000=000000`0
oooo00<0o_kn0?ooo`3oool0o`3ooooo0?ooo`T0oooo003@0?ooo`@00000F@3oool=000000030041
0@000000000000d00000303oool00`3no_h0oooo0?ooo`3o0?ooool0oooo2@3oool00=00oooo1000
001K0?ooo`H0000000<00@41000000000000400000000`010@400000000000060?ooo`030?knoP3o
ool0oooo0?l0ooooo`3oool>0?ooo`00d03oool4000005`0oooo100000000`010@4000000000000E
000006/0oooo00<0o_kn0?ooo`3oool0o`3ooonW0?ooo`00d03oool4000005h0oooo00<00@410000
000000000P00000200410@@0000000<00@410000000000003P0000050?ooo`80o_kn103oool00`3n
o_h0oooo0?ooo`1K0?ooo`030?knoP3oool0oooo0?l0ooooY`3oool00=00oooo1000001O0?ooo`03
00410@000000000001X00000J`3oool00`3no_h0oooo0?ooo`3o0?oooj<0oooo003@0?ooo`@00000
G03oool20?knoP<0oooo7000001S0?ooo`D00000o`3ooonX0?ooo`00d03oool400000680oooo6@00
00000`010@4000000000001R0?ooo`03000000010@400@4100800000o`3ooonX0?ooo`00d03oool4
00000680oooo6@0000000`010@4000000000001R0?ooo`03000000010@400@4100800000o`3ooonX
0?ooo`00d03oool4000006<0oooo1@0000000`010@400000000000090000000300410@0000000000
00P000001@3oool00`3no_h0oooo0?ooo`1F0?ooo`80o_kn00H0oooo000000000000000000410@00
00020?ooo`040?knoP3oool0oooo0?kno_l0ooooXP3oool00=00oooo1000001U0?oooad00000GP3o
ool500000?l0ooooZ03oool00=00oooo1000001W0?ooo`X000000`010@4?000005d0oooo1@00003o
0?ooojP0oooo003@0?ooo`@00000H@3oool00`3no_h0oooo0?ooo`040?oooa`00000<03oool00`3n
o_h0oooo0?ooo`0Y0?ooo`D00000o`3ooonX0?ooo`00d03oool4000006T0oooo6@0000000`010@40
00000000000_0?ooo`030?knoP3oool0oooo02T0oooo1@00003o0?ooojP0oooo003@0?ooo`@00000
K03ooolL00000080oooo00<0o_kn0?ooo`3oool0;03oool00`3no_h0oooo0?ooo`0T0?ooo`D00000
o`3ooonX0?ooo`00d03oool4000006`0oooo700000020?ooo`030?knoP3oool0oooo02`0oooo00<0
o_kn0?ooo`3oool0903oool500000?l0ooooZ03oool00=00oooo1000001]0?ooo`H0000000<00@41
0000000000004`00000Y0?ooo`@00000:P3oool500000?l0ooooZ03oool00=00oooo1000001Q0?oo
o`80o_kn2`3ooolL000002P0oooo00@0000000410@0000000000:P3oool500000?l0ooooZ03oool0
0=00oooo1000001`0?oooa/000008`3oool20?knoP80oooo0P0000000`010@4000000?ooo`020?oo
o`030?knoP3oool0o_kn02@0oooo1@00003o0?ooojP0oooo003@0?ooo`@00000K03oool00`3no_h0
oooo0?ooo`020?ooo`X0000000<00@410000000000002P0000000`010@40000000000002000000T0
oooo00<0o_kn0?ooo`3oool06@3oool4000002X0oooo1@0000030?ooo`80o_kn0P3oool00`3no_h0
oooo0?ooo`3o0?oooih0oooo003@0?ooo`@00000L`3oool90000000300410@000000000001000000
203oool00`3no_h0oooo0?ooo`0H0?ooo`@00000:P3oool500000?l0ooooZ03oool00=00oooo1000
001e0?oooa/0000000<0oooo0?knoP3oool07`3oool4000003H0oooo00<0o_kn0?ooo`3oool0o`3o
oonN0?ooo`00d03oool4000007D0oooo6`0000000`3oool0o_kn0?ooo`0O0?ooo`@00000=P3oool0
0`3no_h0oooo0?ooo`3o0?oooih0oooo003@0?ooo`@00000MP3ooolK000000030?ooo`3no_h0oooo
01h0oooo1000003o0?ooomL0oooo003@0?ooo`@00000JP3oool20?knoP@0oooo00<0o_kn0?ooo`3o
ool0103oool?000000800@41100000000`010@4000000000000300000200oooo1000003o0?ooomL0
oooo003@0?ooo`@00000N03ooolL000001h0oooo1000000W0?ooo`030?knoP3oool0oooo00L0oooo
00<0o_kn0?ooo`3oool0o`3ooonS0?ooo`00d03oool4000007<0oooo00<0o_kn0?ooo`3oool01@3o
oolD0000000300410@000000000000@000000P3oool00`3no_h0oooo0?ooo`0G0?ooo`@00000o`3o
oooG0?ooo`00d03oool4000006h0oooo00<0o_kn0?ooo`3oool02`3oool>0000000300410@000000
000000X000006`3oool400000?l0ooooe`3oool00=00oooo1000001m0?oooa/000006P3oool40000
0?l0ooooe`3oool00=00oooo1000001m0?oooa/000006P3oool400000?l0ooooe`3oool00=00oooo
1000001n0?ooo`@0000000<00@410000000000005@00003o0?oooo<0oooo003@0?ooo`@00000P@3o
ool30000000300410@000000000001@000000P3no_ko0?oooo00oooo003@0?ooo`@00000PP3ooolK
000001L0oooo00<0o_kn0?ooo`3oool0o`3ooooF0?ooo`00d03oool4000008<0oooo00<00@410000
000000006000003o0?ooonl0oooo003@0?ooo`@00000P@3oool00`3no_h0oooo0?ooo`0L000001@0
oooo00<0o_kn0?ooo`3oool0o`3ooooF0?ooo`00d03oool4000008H0oooo6`00003o0?ooon`0oooo
003@0?ooo`@00000QP3ooolK00000?l0ooook03oool00=00oooo100000280?oooa<000000P010@45
000004H0oooo2P00003o0?oooi/0oooo003@0?ooo`@00000QP3oool20?knoP040?ooo`0000000000
00410AP00000303oool20?knoPP0oooo00<0o_kn0?ooo`3oool08P3ooolC00000?l0ooooV`3oool0
0=00oooo1000002:0?ooo`<000000P010@4G000000H0oooo00<0o_kn0?ooo`3oool07@3oool30?kn
oPL0oooo7000003o0?oooi/0oooo003@0?ooo`@00000S03oool60000000300410@00000000000180
0000103oool00`3no_h0oooo0?ooo`080?ooo`030?knoP3oool0oooo00L0oooo00<0o_kn0?ooo`3n
o_h0203ooolW00000?l0ooooV`3oool00=00oooo1000002;0?ooo`030?knoP3oool0000000@00000
00<00@410000000000004`0000000`3no_h0oooo0?ooo`030?ooo`030?knoP3oool0oooo00<0oooo
00<0o_kn0?ooo`3oool00`3oool00`3no_h0oooo0?ooo`050?oooa00000000<00@41000000000000
7@00003o0?oooi/0oooo003@0?ooo`@00000R03oool00`3no_h0oooo0?ooo`040?ooo`0300000001
0@40000001L000000P3no_h>0?ooo`L0000000<00@410000000000001@00000200410BP00000o`3o
oonK0?ooo`00d03oool4000008P0oooo00<0o_kn0?ooo`3oool0103oool00`0000000@410000000G
00000080o_kn3P3oool70000000300410@000000000000D000000P010@4X00000?l0ooooV`3oool0
0=00oooo1000002@0?oooaL0000000<00@410000000000000P00000>0?ooo`l0000000<00@410000
000000009P00003o0?oooi/0oooo003@0?ooo`@00000T@3ooolL000000l0oooo0P00000200410C80
0000o`3ooonK0?ooo`00d03oool4000009<0oooo6`0000050?ooo`030?knoP3oool0oooo00P0oooo
0P010@4b00000?l0ooooV`3oool00=00oooo1000002D0?ooo`D0000000<00@410000000000004000
00000`010@4000000000000B0?oooc4000001`3oool00`3no_h0oooo0?knoP3o0?oooi40oooo003@
0?ooo`@00000UP3oool9000000800@414@00000@0?ooo`<000000P010@4[000001T0oooo0P3no_ko
0?oooh00oooo003@0?ooo`@00000U`3ooolL00000140oooo;P00000P0?ooo`80o_kno`3ooomi0?oo
o`00d03oool4000009L0oooo7000000A0?ooobh00000803oool20?kno_l0ooooN@3oool00=00oooo
1000002D0?ooo`80o_kn0P3oool80000000300410@0000000000014000004@3oool3000000030041
0@000000000002X000003`3oool20?kno_l0ooooQ`3oool00=00oooo1000002I0?ooo`@0000000<0
0@410000000000003P0000000`010@4000000000000200000180oooo0P3no_h00`3oool000000000
00060000000300410@000000000002`00000203oool0103no_h0oooo0?ooo`3no_h70?ooo`80o_kn
o`3ooomi0?ooo`00d03oool4000009/0oooo5`00000H0?oooch00000o`3ooon50?ooo`00d03oool4
000009d0oooo5@00000E0?ooo`040?knoP3oool0oooo0?ooodH00000o`3oooml0?ooo`00d03oool4
000009h0oooo4P00000N0?ooob@000000`3oool00`0000000@4100410@0H0000000300410@000000
000000<00000o`3ooomg0?ooo`00d03oool4000009l0oooo4000000Q0?ooob8000000P3oool00`3n
o_h0oooo0?ooo`080?ooo`D000000P010@440000000300410@000000000000l000003@3oool00`3n
o_h0oooo0?ooo`3o0?ooof40oooo003@0?ooo`@00000W`3oool@00000240oooo8P0000020?ooo`03
0?knoP3oool0oooo00P0oooo1@00000200410@@0000000<00@410000000000003`00000=0?ooo`03
0?knoP3oool0oooo0?l0ooooH@3oool00=00oooo1000002P0?ooo`0300410@000000000000/00000
00@0oooo0?knoP3no_h0o_kn803ooolO000001L0oooo6000003o0?ooofd0oooo003@0?ooo`@00000
X@3oool<000002H0oooo2P0000000`010@4000000000000A00000200oooo5000003o0?ooofP0oooo
003@0?ooo`@00000XP3oool;000002T0oooo1`0000000`010@4000000000000A000002D0oooo5@00
00000`3oool0o_kn0?ooo`050?ooo`030?knoP3oool0oooo0?l0ooooE`3oool00=00oooo1000002T
0?ooo`80000000<00@410000000000000`0000060?ooo`030?knoP3oool0oooo02<0oooo0P000002
00410A<000008@3oool00`3no_h0oooo0?ooo`090?ooo`X0000000<00@410000000000001`00003o
0?oooed0oooo003@0?ooo`@00000Y@3oool7000002h0oooo5@00000a0?oooa<00000o`3ooomJ0?oo
o`00d03oool400000:H0oooo1`00000Y0?ooo`030?knoP3oool0o_kn00<0oooo4P0000060?ooo`03
0?knoP3oool0oooo02h0oooo4`00003o0?oooeD0oooo003@0?ooo`@00000YP3oool7000002T0oooo
00<0o_kn0?ooo`3no_h00`3ooolB000000H0oooo00<0o_kn0?ooo`3oool0;P3ooolC00000?l0oooo
E@3oool00=00oooo1000002W0?ooo`H000009@3oool00`3no_h0oooo0?ooo`090?oooa000000103o
ool00`3no_h0oooo0?ooo`0R0?ooo`80o_kn4@3ooolB00000?l0ooooD@3oool00=00oooo1000002X
0?ooo`H00000<P3oool<0000000300410@3oool0oooo03l0oooo400000000`010@40000000410@0E
0?ooo`030?knoP3oool0oooo0?l0oooo=03oool00=00oooo1000002R0?ooo`80o_kn1@3oool20041
0@@00000<P3oool<000004D0oooo4`00000A0?ooo`030?knoP3oool0oooo0?l0oooo=03oool00=00
oooo1000002R0?ooo`80o_kn1@3oool30000000400410@0000000000000003@0oooo00<00@410000
000000001@00001;0?ooo`80000000<00@410000000000003@0000080?ooo`80o_kno`3ooolj0?oo
o`00d03oool400000:P0oooo00<0o_kn0?ooo`3oool0100000000`010@40oooo0?ooo`020?ooo`03
0?knoP3oool0oooo02h0oooo1P00001@0?ooo`03000000010@400@410080000000<00@4100000000
00002P00003o0?oood00oooo003@0?ooo`@00000[03oool600000380oooo00<0o_kn0?ooo`3oool0
100000150?ooo`030?knoP3oool0oooo00P0oooo00@0o_kn0?ooo`3oool0oooo4@00003o0?ooocd0
oooo003@0?ooo`@00000[03oool600000380oooo00<0o_kn0?ooo`3oool0100000150?ooo`030?kn
oP3oool0oooo00P0oooo00@0o_kn0?ooo`3oool0oooo4@00003o0?ooocd0oooo003@0?ooo`@00000
Z03oool00`3no_h0oooo0?ooo`020?ooo`H00000<P3oool00`3no_h0oooo0?ooo`1I0?ooo`030?kn
oP3oool0000000l00000203oool00`3no_h0oooo0?ooo`3o0?ooobl0oooo003@0?ooo`@00000[@3o
ool7000009<0oooo00<0000000410@0000001P0000000`010@4000000000000300000?l0oooo=`3o
ool00=00oooo1000002^0?ooo`H00000<P3oool00`3no_h0oooo0?ooo`1Q0?ooo``00000o`3ooolg
0?ooo`00d03oool400000:l0oooo1P00002I0?ooo``00000o`3ooolc0?ooo`00d03oool400000;00
oooo1P0000030?knoYP0oooo0P0000000`010@40000000000008000000H0oooo00<0o_kn0?ooo`3n
o_h01P3oool00`3no_h0oooo0?ooo`3o0?oooad0oooo003@0?ooo`@00000/03oool6000009l0oooo
3@00003o0?ooob/0oooo003@0?ooo`@00000/03oool6000009l0oooo3@00003o0?ooob/0oooo003@
0?ooo`@00000/`3oool4000009d0oooo00@0o_kn0?ooo`3oool0oooo0P010@4;000000T0oooo0P3n
o_ko0?oooad0oooo003@0?ooo`@00000/`3oool00`0000000@410000000300000:80oooo0`000003
00410@H00000o`3ooolV0?ooo`00d03oool400000:l0oooo00<0o_kn0?ooo`3oool00P3oool50000
0:D0oooo3@0000000`3no_h0oooo0?ooo`3o0?oooal0oooo003@0?ooo`@00000]03oool600000:40
oooo00<0o_kn0?ooo`3oool00`3oool<00000?l0oooo803oool00=00oooo1000002e0?ooo`D00000
ZP3oool<00000?l0oooo7@3oool00=00oooo1000002e0?ooo`H000009@3oool500000840oooo3@00
003o0?oooaX0oooo003@0?ooo`@00000]@3oool6000002D0oooo1@0000210?ooo`d00000o`3ooolJ
0?ooo`00d03oool400000;H0oooo1P00000T0?ooo`D00000Q03oool<00000=`0oooo00<0o_kn0?oo
o`3oool0>03oool00=00oooo1000002f0?ooo`H0000000<0o_kn0?ooo`3oool08@3oool5000003<0
oooo00<0o_kn0?ooo`3oool0C`3oool00`3no_h0oooo0000000800000?l0oooo603oool00=00oooo
1000002g0?ooo`H000008`3oool5000003L0oooo00<0o_kn0?ooo`3oool0C`3oool6000000<0oooo
00<0o_kn0?ooo`3oool0eP3oool00`3no_h0oooo0?ooo`0i0?ooo`00d03oool400000;L0oooo1P00
000S0?ooo`D00000>03oool00`000000oooo0?ooo`1<0?ooo`030?knoP3oool0oooo0080oooo0`00
003O0?ooo`030000003oool0oooo03H0oooo003@0?ooo`@00000^@3oool500000280oooo1@00000f
0?ooo`800000FP3oool00`3no_h0oooo0?ooo`3G0?ooo`030?knoP3oool0oooo00<00000=@3oool0
0=00oooo1000002j0?ooo`@000008P3oool5000003@0oooo0`000000103oool0o_kn0?knoP3oool2
0?kno_l0oooo=03oool3000003@0oooo003@0?ooo`@00000^P3oool400000280oooo1@00000d0?oo
o`<0000000@0oooo0?knoP3no_h0oooo0P3no_ko0?oooc@0oooo0`00000d0?ooo`00d03oool40000
0;X0oooo1P00000P0?ooo`D00000<P3oool4000005X0oooo0P3no_kP0?ooo`<00000<P3oool00=00
oooo1000002k0?ooo`D00000803oool500000340oooo0`00001=0?ooo`050?knoP3oool0oooo0?oo
o`3no_h00`3oool2000000h0oooo00<0o_kn0?ooo`3oool0H@3oool00`000000oooo0?ooo`1d0?oo
o`800000<@3oool00=00oooo1000002k0?ooo`80000000@00@4100000000000000007`3oool50000
0300oooo0`00001F0?ooo`@0000000<00@410?ooo`3oool0103oool00`3no_h0oooo0?ooo`1V0?oo
o`D00000L`3oool200000300oooo003@0?ooo`@00000_03oool6000001h0oooo1@00000_0?ooo`<0
0000C`3oool00`3no_h0oooo0?ooo`080?ooo`<0000000<00@410?ooo`3oool0K@3oool01@010@40
00000000000000000@410740oooo1000000^0?ooo`00d03oool400000;`0oooo00<0000000410@00
00000`00000N0?ooo`D00000;@3oool4000005d0oooo100000001@3oool0o_kn0?ooo`3oool0o_kn
00D0oooo00<0o_kn0?ooo`3oool0H`3oool300000700oooo00<0o_kn0000000000000P00000]0?oo
o`00d03oool400000;d0oooo1P00001;0?ooo`030?knoP3oool0oooo00@000001P3oool00`3no_h0
oooo0?ooo`1D0?ooo`030?knoP3oool0000000<00000L03oool300000740oooo1000000/0?ooo`00
d03oool400000;d0oooo1P00001;0?ooo`030?knoP3oool0oooo00@000001P3oool00`3no_h0oooo
0?ooo`1D0?ooo`030?knoP3oool0000000<00000L03oool300000740oooo1000000/0?ooo`00d03o
ool400000;d0oooo1P00001=0?ooo`D00000EP3oool00`3no_h0oooo0?ooo`070?ooo`@00000L03o
ool300000780oooo0`00000[0?ooo`00d03oool400000;h0oooo1@00001<0?ooo`D00000G`3oool0
103no_h0oooo0?knoP3no_h300000700oooo1000001`0?ooo`@00000:P3oool00=00oooo1000002n
0?ooo`H00000A@3oool00`3no_h0oooo0?ooo`030?ooo`D00000I03oool3000000D0oooo00<0o_kn
0?ooo`3oool0J03oool400000700oooo0`00000Z0?ooo`00d03oool400000<00oooo1000001:0?oo
o`@000005`3oool00`3no_h0oooo0?ooo`070?ooo`80o_kn2`3oool00`3no_h0oooo0?ooo`0e0?oo
o`<000008`3oool00`3no_h0oooo0?ooo`1:0?ooo`@00000;03oool00`3no_h0oooo0?ooo`110?oo
o`@00000:@3oool00=00oooo100000300?ooo`D00000B03oool5000001/0oooo00<0o_kn0?ooo`3o
ool09P3oool00`3no_h0oooo0?ooo`0P0?ooo`8000006@3oool00`3no_h0oooo0?ooo`070?ooo`03
0?knoP3oool0oooo00X0oooo00@0o_kn0?ooo`3no_h0o_kn2@3oool00`3no_h0oooo0?ooo`0a0?oo
o`<000008`3oool00`3no_h0oooo0?ooo`0P0?ooo`030?knoP3oool0oooo02L0oooo1P00000W0?oo
o`00d03oool400000<40oooo100000180?ooo`@00000>@3oool20?knoQl0oooo00<0o_kn0?ooo`3o
ool02`3oool300000240oooo00<0o_kn0?ooo`3oool0803oool00`3no_h0oooo0?ooo`0Y0?ooo`@0
0000303oool01@3no_h0oooo0?ooo`3oool0o_kn0080oooo00<0o_kn0?ooo`3oool0E@3oool00`3n
o_h0oooo0?ooo`020?ooo`D000009`3oool00=00oooo100000310?ooo`@00000B03oool4000003T0
oooo0P3no_hO0?ooo`030?knoP3oool0oooo00/0oooo0`00000Q0?ooo`030?knoP3oool0oooo0200
oooo00<0o_kn0?ooo`3oool0:@3oool4000000`0oooo00D0o_kn0?ooo`3oool0oooo0?knoP020?oo
o`030?knoP3oool0oooo05D0oooo00<0o_kn0?ooo`3oool00P3oool5000002L0oooo003@0?ooo`@0
0000`@3oool4000004H0oooo1P00000D0?ooo`030?knoP3oool0oooo00<0oooo00<0o_kn0?ooo`3o
ool0A`3oool20?knoP80oooo0`00000E0?ooo`80o_kn5P3oool20?knoS`0oooo00<0o_kn0?ooo`3o
ool00P3oool4000004T0oooo0P3no_hU0?ooo`H000009P3oool00=00oooo100000310?ooo`030041
0@000000000000<00000A03oool600000240oooo1`0000080?ooo`@000001@3oool20?knoPh0oooo
00@0o_kn0000000000000@411000000?0?ooo`@00000103oool3000001@0oooo1P0000000`010@40
oooo0?ooo`060?ooo`800@410P0000110?ooo`D000000`3oool4000001<0oooo00<0o_kn0?ooo`00
00001P0000080?ooo`@00000803oool4000002D0oooo1@00000V0?ooo`00d03oool400000<80oooo
1@0000130?ooo`H000007P3oool=000000H0oooo1`00000B0?ooo`T0000000@0oooo0?knoP3oool0
o_kn2@3oool:0000000300410@000000oooo0100oooo3@0000050?ooo`L000002P3oool600000003
00410@000000000000H000002@3ooolD000000L0oooo3@00000A0?ooo`d000001P3oool700000080
oooo0P3no_hH0?ooo`D000009@3oool6000002D0oooo003@0?ooo`@00000`03oool00`3no_h0oooo
0000000500000480oooo1P00000M0?oooa4000000`3oool00`010@40000000000006000000h0oooo
1`00000200410@@000002@3oool>00000100oooo400000030?ooo`X000002@3oool;000000l0oooo
3P0000080?ooo`h0000000<0o_kn0?ooo`3oool03@3ooolA000000<0oooo1P0000000`010@400000
0000000J0?ooo`H00000903oool6000002D0oooo003@0?ooo`@00000``3oool00`010@4000000000
000200000440oooo1`00000F0?ooo`030?knoP3oool0oooo00<0oooo3`00000010010@4000000000
000000020?ooo`d000002@3oool?000000050?knoP3oool0oooo0?ooo`3no_h00`3oool300000003
00410@000000000000P000003P3ooolB0000000300410@3oool0oooo00<0000000<00@4100000000
00001`0000070?ooo`D0000000<00@410000003oool0403oool00`3no_h0oooo00000009000000T0
oooo00<0o_kn0?ooo`0000003@0000000`3oool0o_kn0?ooo`0<0?ooo`l0000000@00@4100000000
000000000P3oool=000001D0oooo1`00000T0?ooo`L00000903oool00=00oooo100000330?ooo`H0
00000`3oool20?knoS/0oooo1`00000K0?oooaD0000000<0oooo0000000000002@0000000`3oool0
0000000000080?ooo`l0000000D0o_kn0?ooo`3oool0oooo0?knoP030?ooo`T000000P010@420000
00h0oooo3P0000000`010@40000000000004000000030?ooo`000000000000P0000000@00@410?oo
o`00000000001`3oool6000001<0oooo2@00000:0?ooo`030?knoP3oool0000000`000003`3ooolA
000000800@410P0000000`3oool0000000000009000000030?ooo`000000000001@0oooo00<00000
00410@0000001@0000060?ooo`80o_kn703oool6000002@0oooo003@0?ooo`@00000``3oool60000
00<0oooo0P3no_hk0?ooo`L000006`3ooolE000000030?ooo`000000000000T0000000<0oooo0000
00000000203oool?000000050?knoP3oool0oooo0?ooo`3no_h00`3oool9000000800@410P00000>
0?ooo`h0000000<00@41000000000000100000000`3oool00000000000080000000400410@3oool0
0000000000L0oooo1P00000C0?ooo`T000002P3oool00`3no_h0oooo0000000<000000l0oooo4@00
000200410@80000000<0oooo0000000000002@0000000`3oool000000000000D0?ooo`0300000001
0@40000000D000001P3oool20?knoQ`0oooo1P00000T0?ooo`00d03oool400000<@0oooo1@000006
0?ooo`030?knoP3oool0oooo02l0oooo00<0o_kn0?ooo`3oool01@3oool6000001/0oooo2P000000
0`010@400000000000050?ooo`@0000000<0oooo0000000000001`0000050?ooo`030?knoP3oool0
oooo00@0oooo0P00000200410@L000000`3oool3000000L0oooo3@00000=0?ooo`T000000P010@42
000000H0oooo0`0000000`3oool0000000000008000000X0oooo00<0o_kn0?ooo`3oool010000007
0?ooo`030?knoP3oool0oooo00P0oooo1P0000000`010@40000000410@0=0?ooo`d000003@3oool0
0`3no_h00000000000050000000300410@000000000000<000001@3oool4000000030?ooo`000000
000000@0000000<00@410000000000000P3oool00`3no_h0oooo0?ooo`0D0?ooo`0300410@000000
000000D00000903oool6000002@0oooo003@0?ooo`@00000a03oool6000003h0oooo1`00000J0?oo
o`/00000203oool20?knoP/000003@3oool7000000800@411P3oool00`010@4000000?ooo`080?oo
o`X000003@3oool00`010@40000000000009000000030?knoP3oool0oooo00H0oooo200000001001
0@40000000410@010@440?ooo`030?knoP3oool0oooo00P0oooo1000000@0?ooo`D000000P010@43
000000h0oooo200000000`010@400000000000050?ooo`80o_kn1`3oool;000000X0oooo2@000000
0`010@4000000?ooo`0B0?ooo`030?knoP3oool0oooo00<0oooo0P0000000`010@40000000000004
000000030?ooo`3no_h0oooo0240oooo1`00000S0?ooo`00d03oool400000<<0oooo00<0o_kn0?oo
o`0000001000000n0?ooo`L00000603oool<000000d0oooo2@0000070?ooo`040?knoP3oool0oooo
0?knoP80oooo200000000`3oool0o_kn0?knoP050?ooo`<000001`3oool80000000300410@3oool0
oooo00/0oooo2`0000070?ooo`80o_kn103oool:000000D0oooo0P3no_h90?ooo`D000002@3oool0
0`3no_h0oooo0?ooo`020?ooo`@0000000<00@410000000000000P00000?0?ooo`T00000103oool0
0`3no_h0oooo0?ooo`070?ooo``0000000<0oooo0?knoP3oool00`3oool20?knoPD0oooo2@00000I
0?ooo`<0000000@00@410000000000000@410`00000S0?ooo`L0000000<0o_kn0?ooo`3oool0803o
ool00=00oooo100000350?ooo`H00000?@3oool7000001P0oooo2`00000?0?ooo`P000003@3oool8
000001@0oooo0`00000200410@030000003oool0oooo00`0oooo2P00000>0?ooo`030?knoP000000
000000L000002P3oool01@3no_h0oooo0?ooo`3oool0o_kn0080oooo1000000<0?ooo`X000004P3o
ool6000000@0oooo00<0o_kn0?ooo`3oool0203oool;000000l0oooo2000000H0?ooo`/0000000<0
oooo0?knoP3no_h0803oool7000002<0oooo003@0?ooo`@00000a03oool00`3no_h0oooo0?ooo`04
000003`0oooo2000000G0?ooo`D0000000<00@410000000000000`00000@0?ooo`P000003@3oool8
000000d0oooo00<0o_kn0?ooo`3oool05`3oool20000000300410@000000000000<0000000<00@41
0000003oool01@3oool00`3no_h0oooo0?ooo`060?ooo`030?knoP000000000000L00000303oool2
0?knoP<0oooo1@00000:0?ooo`/000003`3oool00`3no_h0oooo0?ooo`090?ooo`030?knoP3oool0
oooo00P0oooo2P0000000`010@40oooo0?ooo`0>0?ooo`P00000103oool00`3no_h0oooo0?ooo`07
0?ooo`030?knoP3oool0oooo00L0oooo3000000R0?ooo`D0000000<00@410000000000008P3oool0
0=00oooo100000370?ooo`@00000?03oool8000001L0oooo0`0000001@010@400000000000000000
0@41008000000`3oool00`3no_h0oooo0?ooo`060?ooo`80o_kn0`3oool8000000/0oooo00<0o_kn
0?ooo`0000001`00000>0?ooo`030?knoP3oool0oooo01H0oooo2@0000000`3no_h0oooo0?ooo`0>
0?ooo`T0000000<0oooo0?knoP3oool03`3oool5000000T0oooo100000000`010@40000000000003
000002L0oooo2P0000000`3no_h0oooo0?ooo`0>0?ooo`P000005P3oool:000000040?ooo`000000
000000000280oooo2000000R0?ooo`00d03oool400000<L0oooo1000000l0?ooo`P000005`3oool3
0000000500410@0000000000000000010@400P0000030?ooo`030?knoP3oool0oooo00H0oooo0P3n
o_h30?ooo`P000002`3oool00`3no_h0oooo00000007000000h0oooo00<0o_kn0?ooo`3oool05P3o
ool9000000030?knoP3oool0oooo00h0oooo2@0000000`3oool0o_kn0?ooo`0?0?ooo`D000002@3o
ool40000000300410@000000000000<000009`3oool:000000030?knoP3oool0oooo00h0oooo2000
000F0?ooo`X0000000@0oooo00000000000000008P3oool800000280oooo003@0?ooo`@00000_P3o
ool30?knoPH0oooo1@0000030?ooo`030?knoP3oool0oooo03D0oooo200000000`3no_h0oooo0?oo
o`0D0?ooo`<0000000<00@410000000000001000000A0?ooo`P000001P3oool01@3no_h0oooo0?oo
o`3oool0o_kn0080oooo2000000C0?ooo`030?knoP3oool0o_kn0140oooo2@00000?0?ooo`030?kn
oP3oool0000000P000004`3oool5000000L0oooo2@0000030?ooo`030?knoP3oool0oooo0180oooo
00<0o_kn0?ooo`3oool03P3oool:00000100oooo00<0o_kn0000000000001P00000>0?ooo`050?kn
oP3oool0oooo0?ooo`3no_h00`3oool:000000030?ooo`000000000000<000008@3oool700000280
oooo003@0?ooo`@00000b03oool20000000300410@000000oooo01/0oooo0P3no_hM0?ooo`L00000
603oool8000001<0oooo2000000=0?ooo`P000009`3oool800000080oooo00@0o_kn0?ooo`3no_h0
o_kn303oool9000001D0oooo0`0000060?ooo`X000000P3no_hW0?ooo`P000004`3oool8000001H0
oooo2P0000000`3oool000000000000300000240oooo1`00000R0?ooo`00d03oool400000<P0oooo
1P00000B0?ooo`D000008P3oool7000001L0oooo2@00000C0?ooo`P000003@3oool8000002D0oooo
2P00000B0?ooo`T000005@3oool4000000D0oooo1P0000000`010@40000000410@0Y0?ooo`T00000
4`3oool8000001D0oooo2P0000030?ooo`0400410@000000000000000240oooo1`00000R0?ooo`00
d03oool400000<T0oooo1@00000B0?ooo`D000008@3oool8000001L0oooo2@00000C0?ooo`P00000
3@3oool8000002D0oooo2P00000B0?ooo`T000005P3oool4000000<0oooo2@00000Z0?ooo`T00000
4`3oool8000001D0oooo2P0000030?ooo`D00000803oool900000200oooo003@0?ooo`@00000b@3o
ool6000000l0oooo00<0o_kn0?ooo`0000000P0000000`010@4000000?ooo`0P0?ooo`P000005`3o
ool8000001@0oooo2000000=0?ooo`P00000903oool00`3no_h0000000000007000000<0oooo00<0
o_kn0?ooo`3oool03@3oool9000001<0oooo0P3no_h20?ooo`l00000:P3oool8000000@0oooo00<0
o_kn0?ooo`3oool03@3oool8000001@0oooo2@0000060?ooo`@00000803oool900000200oooo003@
0?ooo`@00000bP3oool500000140oooo1@00000Q0?ooo`P000005`3oool8000001@0oooo2000000=
0?ooo`P000009@3oool9000001<0oooo2@00000H0?ooo`d00000:`3oool40000000400410@000000
0000000001@0oooo2000000D0?ooo`T000001P3oool5000001l0oooo2@00000P0?ooo`00d03oool4
00000<X0oooo1@00000A0?ooo`D000008@3oool8000001L0oooo2000000D0?ooo`P000003@3oool8
000002D0oooo2@00000C0?ooo`T00000603oool=000002/0oooo1000000010010@40000000000000
000D0?ooo`P00000503oool9000000H0oooo1@00000O0?ooo`T00000803oool00=00oooo1000003:
0?ooo`H00000403oool30000000300410@000000oooo00H0oooo00<0o_kn0?ooo`3oool05`3oool0
0`0000000@4100000005000001L0oooo2000000D0?ooo`P000003@3oool8000002D0oooo2@00000C
0?ooo`T00000603oool00`010@40000000000009000002`0oooo1000000010010@40000000000000
000D0?ooo`P000004`3oool9000000P0oooo1000000O0?ooo`@0000000<00@410000000000000P00
000P0?ooo`00d03oool400000</0oooo1@00000:0?ooo`80o_kn103oool5000000H0oooo00<0o_kn
0?ooo`3oool0603oool8000001L0oooo2000000D0?ooo`P000003@3oool8000002D0oooo2@00000C
0?ooo`T000006@3oool8000000<00@41;03oool8000001@0oooo2000000C0?ooo`T00000203oool3
0000000300410@3oool0oooo01d0oooo2@00000P0?ooo`00d03oool400000<X0oooo00@0o_kn0000
00010@400@410`00000?0?ooo`@0000000<00@410?ooo`3oool07`3oool8000001L0oooo00<00@41
0000000000001@00000D0?ooo`P000003@3oool8000002D0oooo0P010@430000000400410@000000
0000000001<0oooo2@00000G0?ooo`030?knoP0000000@4100T00000;@3oool00`010@4000000000
0005000001@0oooo2000000C0?ooo`0300410@000000000000H0000000<0o_kn0?ooo`3oool01@3o
ool5000001h0oooo2@00000P0?ooo`00d03oool400000</0oooo00<0o_kn0000000000000`00000?
0?ooo`D000008@3oool00`010@40000000000005000001L0oooo2000000D0?ooo`P000003@3oool8
000002D0oooo2@00000C0?ooo`T00000603oool900000080o_kn;@3oool8000001@0oooo2000000B
0?ooo`T000002`3oool3000001h0oooo100000000`010@4000000000000200410B00oooo003@0?oo
o`@00000c03oool6000000h0oooo1@00000Q0?ooo`P000005`3oool8000001@0oooo2000000=0?oo
o`P000009@3oool60000000300410@000000000001<0oooo2@00000B0?ooo`030?knoP3oool0oooo
0080oooo1P00000010010@40000000000000000_0?ooo`P00000503oool8000000h0oooo00@0o_kn
0?ooo`3oool0oooo1P0000000`010@4000000000000;0?ooo`@000007@3oool40000000300410@00
0000000000800000803oool00=00oooo1000003>0?ooo`@000003P3oool500000240oooo2000000H
0?ooo`L00000503oool8000000d0oooo2000000W0?ooo`L000000`3oool00`3no_h0oooo0?ooo`0=
0?ooo`T000005`3oool:00000300oooo1`00000D0?ooo`P000004@3oool9000000d0oooo0`00000L
0?ooo`030?knoP000000000000L00000803oool00=00oooo1000003>0?ooo`@000003P3oool50000
0240oooo2000000H0?ooo`L00000503oool8000000d0oooo2000000W0?ooo`L000000`3oool00`3n
o_h0oooo0?ooo`0=0?ooo`T000005`3oool:00000300oooo1`00000D0?ooo`P000004@3oool90000
00d0oooo0`00000L0?ooo`030?knoP000000000000L00000803oool00=00oooo1000003>0?ooo`80
00000P010@450?ooo`030?knoP3oool0o_kn0080o_kn103oool500000240oooo2000000H0?ooo`03
000000010@400@4100@00000503oool8000000d0oooo2000000W0?ooo`L000004`3oool9000001H0
oooo3@0000000`3no_h0oooo0?ooo`0[0?ooo`L00000503oool800000140oooo2@00000=0?ooo`80
000000<00@410000003oool06`3oool900000200oooo003@0?ooo`@00000cP3oool5000000d0oooo
1@00000Q0?ooo`P00000603oool7000001@0oooo2000000=0?ooo`P000009`3oool7000001<0oooo
2@00000E0?ooo`<0000000<00@410000000000002@00000]0?ooo`L00000503oool8000000h0oooo
00<0o_kn0000000000000`0000000`010@40000000410@0200410@@0oooo0P3no_h0103oool0o_kn
0?ooo`3no_h40?ooo`@00000703oool900000200oooo003@0?ooo`@00000c`3oool0100000000@41
00000000000=0?ooo`03000000010@400@41008000008@3oool8000001P0oooo1`00000D0?ooo`P0
00003@3oool8000002L0oooo1`0000080?ooo`030?knoP3oool0oooo00P0oooo2@00000E0?ooo`T0
00000P3oool010010@40000000000000000]0?ooo`L00000503oool8000000l0oooo2P00000?0?oo
o`<00000703oool900000200oooo003@0?ooo`@00000cP3oool0103no_h00000000000010@430000
0340oooo2000000I0?ooo`L000004`3oool8000000d0oooo2000000X0?ooo`L000004P3oool90000
01<0oooo2`0000020?ooo`D000009P3oool20?knoPD0oooo1`00000C0?ooo`P000003`3oool:0000
00l0oooo1@00000J0?ooo`80000000<00@410000000000001000000P0?ooo`00d03oool400000=00
oooo1@00000b0?ooo`L000006@3oool7000001<0oooo2000000=0?ooo`P00000:03oool7000000<0
oooo00D0o_kn0?ooo`3oool0oooo0?knoP0:0?ooo`T000004P3oool;000000@0oooo1@00000/0?oo
o`L000004`3oool8000000h0oooo2P00000A0?ooo`8000000P010@4J0?ooo`L000008P3oool00=00
oooo100000380?ooo`040?knoP3oool0oooo0?knoP@0oooo1@0000000`3no_h0oooo0?ooo`0_0?oo
o`L000005`3oool01P3no_h0oooo0?ooo`3oool0000000410@80000000<00@410?ooo`3oool04@3o
ool8000000d0oooo2000000U0?ooo`80o_kn0P3oool600000180oooo2@00000:0?ooo`030?knoP3o
ool0oooo00D0oooo2P0000070?ooo`@00000;@3oool5000000H0oooo00<0o_kn0?ooo`3oool02P3o
ool8000000d0oooo00<0o_kn000000000000200000090?ooo`030?knoP3oool0oooo0080o_kn0`3o
ool5000001T0oooo1`00000R0?ooo`00d03oool400000<P0oooo00@0o_kn0?ooo`3oool0o_kn103o
ool5000000030?knoP3oool0oooo02l0oooo1`00000G0?ooo`060?knoP3oool0oooo0?ooo`000000
0@410P0000000`010@40oooo0?ooo`0A0?ooo`P000003@3oool8000002D0oooo0P3no_h20?ooo`H0
00004P3oool9000000X0oooo00<0o_kn0?ooo`3oool01@3oool:000000L0oooo1000000]0?ooo`D0
00001P3oool00`3no_h0oooo0?ooo`0:0?ooo`P000003@3oool00`3no_h0000000000008000000T0
oooo00<0o_kn0?ooo`3oool00P3no_h30?ooo`D000006@3oool700000280oooo003@0?ooo`@00000
d03oool6000002X0oooo00<0o_kn0?ooo`3oool0103oool4000000800@4100<000000?ooo`3oool0
6@3oool700000100oooo2@00000;0?ooo`030?knoP3oool0000000L00000:03oool0103no_h00000
000000010@44000000030?knoP3oool0oooo00d0oooo2P0000090?ooo`030?knoP3oool0oooo00D0
oooo2`0000080?ooo`<0000000<0o_kn0?ooo`3oool0:P3oool700000100oooo2@00000=0?ooo`80
00000P010@45000001<0oooo00D0000000410@010@400@410000000H0?ooo`P000000P3no_hP0?oo
o`00d03oool400000<P0oooo00<0o_kn0?ooo`3oool01P3oool5000002X0oooo00<0o_kn0?ooo`3o
ool0103oool60000000300410@000000oooo01X0oooo1P00000:0?ooo`030?knoP3oool0oooo00<0
oooo2@00000=0?ooo`P00000303oool00`3no_h0oooo0?ooo`0K0?ooo`H00000203oool00`3no_h0
oooo0?ooo`050?ooo`X00000403oool80000000300410@000000oooo00@0oooo00<0o_kn0?ooo`3o
ool00P3oool4000002d0oooo1P00000@0?ooo`03000000010@40000000H00000203oool20?knoP<0
oooo2@00000;0?ooo`030?knoP3oool0oooo00H0oooo1000000H0?ooo`P000008P3oool00=00oooo
1000003A0?ooo`H000000P3oool00`3no_h0oooo0?ooo`0[0?ooo`P00000703oool6000000/0oooo
0P3no_h00`3oool0000000000008000000`0oooo00<0o_kn0000000000001P00000[0?ooo`H00000
303oool00`3no_h0oooo0000000:00000100oooo2@00000<0?ooo`D0000000<0oooo0?knoP3oool0
:@3oool6000000h0oooo2P0000080?ooo`80o_kn0`3oool8000001D0oooo1@00000G0?ooo`P00000
8P3oool00=00oooo1000003B0?ooo`D00000;@3oool20?knoP80oooo1`00000F0?ooo`030?knoP3o
ool0oooo00<0oooo1`0000020?ooo`030?knoP3oool0oooo00L0oooo00<0000000410@0000002000
000=0?ooo`P00000:`3oool7000000`0oooo3000000?0?ooo`@000000P010@44000000d0oooo1@00
000[0?ooo`L00000303oool5000000800@411000000<0?ooo`T000005P3oool4000001L0oooo1`00
000S0?ooo`00d03oool400000<`0oooo0P3no_h40?ooo`D00000;@3oool20?knoP80oooo00<00000
00410@0000001000000M0?ooo`L000002@3oool200410@/000003@3oool800000100oooo0P3no_hJ
0?ooo`L000000P3oool0103no_h0oooo0?ooo`3no_h40?ooo`d000003P3oool:000000h0oooo1P00
000[0?ooo`03000000010@40000000@000002@3oool=000000H0oooo0P3no_h30?ooo`<0000000<0
0@410000000000001000000A0?ooo`030?knoP3oool0oooo0080oooo1@00000F0?ooo`@0000000<0
0@410000000000008`3oool00=00oooo1000003B0?ooo`H00000:@3oool00`3no_h0oooo0?ooo`04
0?ooo`L000005P3oool00`3no_h0oooo0?ooo`050?ooo`P00000103oool00`3no_h0oooo0000000=
000000@0oooo00<0o_kn0?ooo`0000003P0000000`010@40000000000006000002D0oooo20000006
0?ooo`h00000303oool<000000h0oooo1`00000[0?ooo`P000001P3oool>000000/0oooo0`000000
0`010@400000000000020000000300410@000000oooo01D0oooo0P010@43000000030?knoP3oool0
oooo01<0oooo1`00000S0?ooo`00d03oool400000=80oooo1P00000Y0?ooo`030?knoP3oool0oooo
00@0oooo1`00000F0?ooo`030?knoP3oool0oooo00D0oooo200000040?ooo`030?knoP3oool00000
00d00000103oool00`3no_h0oooo0000000>0000000300410@000000000000H000009@3oool80000
00H0oooo3P00000<0?ooo``000003P3oool7000002/0oooo200000060?ooo`h000002`3oool30000
000300410@00000000000080000000<00@410000003oool05@3oool200410@<0000000<0o_kn0?oo
o`3oool04`3oool7000002<0oooo003@0?ooo`@00000d`3oool500000340oooo0P00000200410@80
00007`3ooolB000000030?ooo`000000000000H000001P3oool70000000300410@000000000000h0
0000103oool00`3no_h0oooo0?ooo`020?knoQd0oooo3`0000000`010@4000000?ooo`09000000/0
oooo1`0000000`010@40000000000004000000`0oooo2P00000Z0?oooa80000000<0oooo00000000
00001P0000080?ooo`h00000503oool8000001@0oooo1P00000T0?ooo`00d03oool400000=<0oooo
1P00000`0?ooo`H000008P3oool=00000080oooo00<0o_kn0000000000001P0000080?ooo`@00000
00<00@41000000000000100000000`010@400000000000020000000300410@000000000000<00000
:03oool=000000<0oooo2@0000080?oooa@000001`3oool?000002X0oooo3@0000030?ooo`P00000
1P3ooolD000000d0oooo3P00000@0?ooo`L000000P3oool20?knoR00oooo003@0?ooo`@00000e@3o
ool400000300oooo1`00000T0?ooo`L000001P3oool8000000/0oooo2P00000e0?ooo`0300000001
0@40000000@000001@3oool9000005l0oooo1`0000060?ooo`P00000@03oool20?knoP<0oooo1`00
000T0?ooo`00d03oool400000=D0oooo1000000a0?ooo`H00000<@3oool8000000`0oooo2@000011
0?ooo`T00000K03oool8000004D0oooo1P00000U0?ooo`00d03oool400000=D0oooo1@00000`0?oo
o`H00000<@3oool8000000@0oooo00<0o_kn0?ooo`3oool01P3oool70000000300410@3oool0oooo
03l0oooo2@00000N0?ooo`030?knoP3oool0oooo00d0oooo00<0o_kn0?ooo`3oool0>`3oool80000
01d0oooo0P3no_h:0?ooo`030?knoP3oool0oooo01T0oooo1P00000U0?ooo`00d03oool400000=H0
oooo100000040?ooo`030?knoP3oool0oooo02X0oooo1P00000`0?ooo`P000002P3oool0103no_h0
oooo0?ooo`3oool7000003T0oooo00<0o_kn0?ooo`3oool01@3oool9000002@0oooo00<0o_kn0?oo
o`3oool0A@3oool8000000D0oooo00<0o_kn0?ooo`3oool0403oool00`3no_h0oooo0?ooo`0Y0?oo
o`H000000`3oool00`3no_h0oooo0?ooo`0P0?ooo`00d03oool400000=H0oooo100000040?ooo`03
0?knoP3oool0oooo02X0oooo1P00000`0?ooo`P000002P3oool0103no_h0oooo0?ooo`3oool70000
03T0oooo00<0o_kn0?ooo`3oool01@3oool9000002@0oooo00<0o_kn0?ooo`3oool0A@3oool80000
00D0oooo00<0o_kn0?ooo`3oool0403oool00`3no_h0oooo0?ooo`0Y0?ooo`H000000`3oool00`3n
o_h0oooo0?ooo`0P0?ooo`00d03oool400000=H0oooo00<00@410000000000000`00000_0?ooo`H0
0000<03oool8000000l0oooo1P0000110?ooo`T00000;P3oool00`3no_h0oooo0?ooo`0k0?ooo`P0
0000:@3oool00`3no_h0oooo0?ooo`0H0?ooo`H000009P3oool00=00oooo1000003G0?ooo`D00000
<@3oool4000001l0oooo00<0o_kn0?ooo`3oool02`3oool00`3no_h0oooo0?ooo`08000000l0oooo
1P0000060?ooo`030?knoP3oool0oooo03P0oooo2@00001/0?ooo`P00000303oool00`3no_h0oooo
0?ooo`0e0?ooo`D000000`3oool00`3no_h0oooo0?ooo`0Q0?ooo`00d03oool400000=L0oooo1@00
00020?ooo`030?knoP3oool0o_kn02`0oooo1@00000_0?ooo`P000001`3oool0103no_h0oooo0?oo
o`3no_h60?ooo`@00000?P3oool00`3no_h0oooo0?ooo`0900000240oooo0P3no_h00`3oool0o_kn
0?ooo`130?ooo`030?knoP3oool0oooo00P000002`3oool00`3no_h0oooo0?ooo`0:0?ooo`030?kn
oP3oool0o_kn02P0oooo1P00000W0?ooo`00d03oool400000=L0oooo1P00000a0?ooo`0400000001
0@400000000000T0oooo00<0o_kn0?ooo`3oool08`3oool8000000/0oooo00<0o_kn0?ooo`3oool0
103oool300000400oooo00<0o_kn0000000000001`00001V0?ooo`030?knoP3oool0oooo00<0oooo
200000130?ooo`@00000:@3oool00=00oooo1000003B0?ooo`030?knoP3oool0oooo00<0oooo1@00
000b0?ooo`<00000;`3oool800000180oooo0`0000110?ooo`H0000000<00@41000000000000IP3o
ool00`3no_h0oooo0?ooo`030?ooo`0300410@000000000000D00000@P3oool4000002X0oooo003@
0?ooo`@00000f03oool6000000030?knoP3oool0oooo02h0oooo1@0000050?ooo`80o_kn9P3oool8
000001<0oooo0P0000030?ooo`030?knoP3oool0oooo03/0oooo1`00000200410F`0oooo2000000m
0?ooo`030?knoP3oool0oooo0080oooo1000000Z0?ooo`00d03oool400000=P0oooo1P0000000`3n
o_h0oooo0?ooo`0^0?ooo`D000001@3oool20?knoRH0oooo2000000C0?ooo`8000000`3oool00`3n
o_h0oooo0?ooo`0k0?ooo`L000000P010@5/0?ooo`P00000?@3oool00`3no_h0oooo0?ooo`020?oo
o`@00000:P3oool00=00oooo1000003I0?ooo`D000000P3oool5000002/0oooo0P00000200410@04
0000003oool0oooo0?knoRT0oooo2000000C0?ooo`8000000`3oool00`3no_h0oooo0?ooo`0k0?oo
o`T00000K03oool8000003h0oooo00<0o_kn0?ooo`0000001000000[0?ooo`00d03oool400000=T0
oooo1P0000000`3oool000000000000300000080oooo00<0o_kn0?ooo`3oool09`3oool4000002`0
oooo2000000D0?ooo`030000003oool0oooo03l0oooo2@00001/0?ooo`P00000?P3oool01P3no_h0
oooo0000000000000@41000002`0oooo003@0?ooo`@00000fP3oool5000000030?ooo`0000000000
00<000000P3oool00`3no_h0oooo0?ooo`0O0?ooo`030?knoP3oool0oooo00H0oooo1000000[0?oo
o`P00000EP3oool9000006`0oooo2000000o0?ooo`@00000;@3oool00=00oooo1000003J0?ooo`D0
000000<0oooo0000000000000`00000_0?ooo`<0000000<0oooo0?knoP3oool09`3oool8000005H0
oooo2@00001/0?ooo`P00000?P3oool4000002h0oooo003@0?ooo`@00000f03oool00`3no_h0oooo
0000000:00000300oooo0P00000Y0?ooo`T00000E@3oool50000000300410@000000000000800000
J`3oool9000003d0oooo0`00000`0?ooo`00d03oool400000=`0oooo200000000`010@40oooo0?oo
o`0_0?ooo`8000008`3oool3000000030?ooo`000000000000P00000D@3oool2000000030?ooo`00
0000000000T00000IP3oool3000000030?ooo`000000000000@0000000@00@410000000000000000
?03oool3000000D0oooo00<0o_kn0?ooo`3oool0:@3oool00=00oooo1000003L0?ooo`P0000000<0
0@410?ooo`3oool0;`3oool2000002<0oooo0`0000000`3oool000000000000800000540oooo0P00
00000`3oool0000000000009000006H0oooo0`0000000`3oool00000000000040000000400410@00
00000000000003`0oooo0`0000050?ooo`030?knoP3oool0oooo02T0oooo003@0?ooo`@00000g03o
ool9000000H0oooo00<0o_kn0?ooo`3oool0:@3oool2000000T0oooo00<0o_kn0?ooo`3oool05`3o
ool=00000580oooo3@00001W0?ooo`d00000=P3oool00`3no_h0oooo0?ooo`020?ooo`<00000<P3o
ool00=00oooo1000003M0?ooo`<0000000<00@410000000000000P0000070?ooo`030?knoP3oool0
oooo02X0oooo0`00000T0?ooo`L0000000<00@410000003oool0E03oool:000006/0oooo2@00000i
0?ooo`<00000=03oool00=00oooo1000003P0?ooo`D00000=P3oool2000001h0oooo00<0o_kn0?oo
o`3oool0103oool7000005P0oooo0P0000000`010@40000000000002000006d0oooo1`000000103o
ool0o_kn0?knoP3no_hd0?ooo`<00000=@3oool00=00oooo1000003M0?ooo`030?knoP3oool0oooo
00D00000=`3oool00`3no_h000000?ooo`0W0?ooo`<00000E@3oool01P3no_h0oooo0?ooo`3oool0
o_kn0?ooo`@00000L@3oool3000000030?ooo`3no_h0o_kn03@0oooo00<000000?ooo`3oool01@3o
ool00`3no_h0oooo0?ooo`030?ooo`030?knoP3oool0oooo02P0oooo003@0?ooo`@00000h03oool5
000005H0oooo00<0o_kn0?ooo`3oool0I`3oool00`3no_h0oooo0?ooo`3T0?ooo`00d03oool40000
0>00oooo1@00001T0?ooo`030?knoP3oool0oooo0<80oooo00@0o_kn0?ooo`3oool0o_knA`3oool0
0`3no_h0oooo0?ooo`0`0?ooo`00d03oool400000>00oooo1@00001T0?ooo`030?knoP3oool0oooo
0<80oooo00@0o_kn0?ooo`3oool0o_knA`3oool00`3no_h0oooo0?ooo`0`0?ooo`00d03oool40000
0>P0oooo0P3no_hd0?ooo`030?knoP3oool0oooo07T0oooo00D0o_kn0?ooo`3oool0oooo0?knoP02
0?ooo`030?knoP3oool0oooo0:`0oooo00<0o_kn0?ooo`3oool02`3oool00`3no_h0oooo0?ooo`0[
0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00
d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool4
00000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0
ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3o
oon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?oo
o`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03o
ool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool40000
0?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0oooo
o`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>
0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00
d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool4
00000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0
ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3o
oon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?oo
o`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03o
ool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool40000
0?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0oooo
o`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>
0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00
d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00d03oool4
00000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0ooooo`3ooon>0?ooo`00a03oool00`3no_h0
oooo0?ooo`090?ooo`04000000010@40000000000?l0ooooo`3ooon>0?ooo`00a03oool00`3no_h0
oooo0?ooo`090?ooo`04000000010@40000000000?l0ooooo`3ooon>0?ooo`00d03oool400000?l0
ooooo`3ooon>0?ooo`00d03oool4000000d0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?ooogh0oooo
00390?ooo`030?knoP3oool0oooo00@0oooo1000003o0?ooool0ooooSP3oool00<H0oooo0P3no_h7
0?ooo`050?knoP0000000@41000000010@404`3oool00`3no_h0oooo0?ooo`3o0?ooool0ooooN03o
ool00<H0oooo6@00003o0?ooool0ooooP`3oool00<<0oooo4@00000200410@@0000000<00@410000
000000001@00003o0?ooool0ooooP03oool00<<0oooo4@00000200410@@0000000<00@4100000000
00001@00003o0?ooool0ooooP03oool00<40oooo9@00003o0?ooool0ooooO03oool00;l0oooo9`00
003o0?ooool0ooooO03oool00;h0oooo00<0o_kn0?ooo`3oool09000003o0?ooool0ooooO@3oool0
0;l0oooo0P3no_hT00000?l0ooooo`3ooomm0?ooo`00_`3oool20?knoR@00000o`3ooooo0?ooogd0
oooo00320?ooob800000o`3ooooo0?ooogh0oooo00320?ooob800000o`3ooooo0?ooogh0oooo0032
0?oooal0000000<00@41000000000000o`3ooooo0?ooogh0oooo00320?ooob800000o`3ooooo0?oo
ogh0oooo00320?ooo`030?knoP000000000001d00000o`3ooooo0?oooh00oooo00330?ooo`030041
0@000000000001`00000103oool00`3no_h0oooo0?ooo`020?knoPL0oooo1`0000000`3no_h0oooo
0?ooo`3o0?ooool0ooooIP3oool00<<0oooo7`00000>0?ooo`X00000o`3ooooo0?ooofP0oooo0034
0?oooad00000203oool20?knoP@0oooo00<00@410000000000002P00003o0?ooool0ooooIP3oool0
0<@0oooo7@0000080?ooo`80o_kn103oool00`010@4000000000000:00000?l0ooooo`3ooomV0?oo
o`00a03ooolM000000d0oooo3`00003o0?ooool0ooooI@3oool00<@0oooo7@00000=0?ooo`l00000
o`3ooooo0?ooofD0oooo00350?oooaH000000P010@43000000D0oooo00<0o_kn0?ooo`3oool01@3o
ool20000000300410@000000000000D00000103oool3000000@0oooo00<0o_kn0?ooo`3oool0o`3o
oooo0?oooed0oooo00350?oooa/000003@3oool9000000@0oooo00@0o_kn0?ooo`0000000000o`3o
oooo0?ooof@0oooo00350?oooaX000003P3oool8000000030?knoP3oool0oooo00D0oooo0`00003o
0?ooool0ooooHP3oool00<H0oooo1P0000000`010@4000000000000>000000800@4100<0o_kn0?oo
o`3oool02`3oool800000?l0ooooo`3ooom]0?ooo`00aP3oool60000000300410@000000000000h0
00000P010@400`3no_h0oooo0?ooo`0;0?ooo`P00000o`3ooooo0?ooofd0oooo00360?oooaT00000
3P3oool800000?l0ooooo`3ooom]0?ooo`00aP3ooolH000000l0oooo2000003o0?ooool0ooooK@3o
ool00<D0oooo00<0o_kn0?ooo`3oool04@0000000`010@40000000000002000000030?knoP3oool0
oooo00`0oooo2000003o0?ooool0ooooK@3oool00<P0oooo5@00000@0?ooo`P00000o`3ooooo0?oo
ofd0oooo00380?oooa<000000P010@4@0?ooo`P00000o`3ooooo0?ooofd0oooo00390?oooa@00000
403oool800000?l0ooooo`3ooom]0?ooo`00b@3ooolD00000100oooo2000003o0?ooool0ooooK@3o
ool00<T0oooo1000000200410@`000004P3oool800000?l0ooooo`3ooom]0?ooo`00bP3oool20000
000300410@000000000000`000004P3oool800000?l0ooooo`3ooom]0?ooo`00bP3oool@000001<0
oooo2000003o0?ooool0ooooK@3oool00<X0oooo4000000C0?ooo`P00000o`3ooooo0?ooofd0oooo
003;0?ooo`l000004`3oool800000?l0ooooo`3ooom]0?ooo`00b`3oool?000001<0oooo2000003o
0?ooool0ooooK@3oool00</0oooo3`00000C0?ooo`P00000o`3ooooo0?ooofd0oooo003;0?ooo`h0
0000503oool800000?l0ooooo`3ooom]0?ooo`00c03oool=000001@0oooo2000003o0?ooool0oooo
K@3oool00<`0oooo3@00000D0?ooo`P00000o`3ooooo0?ooofd0oooo00380?ooo`040?knoP3oool0
oooo0?ooo`/0000000<00@410000003oool04`3oool800000?l0ooooo`3ooom]0?ooo`00c@3oool;
000001D0oooo2000003o0?ooool0ooooK@3oool00<d0oooo2`00000E0?ooo`P00000o`3ooooo0?oo
ofd0oooo003=0?ooo`/000005@3oool800000?l0ooooo`3ooom]0?ooo`00c@3oool:000000030041
0@3oool0oooo01<0oooo2000003o0?ooool0ooooK@3oool00<l0oooo2000000F0?ooo`P00000o`3o
oooo0?ooofd0oooo003:0?ooo`030?knoP3oool0oooo0080oooo2000000F0?ooo`P00000o`3ooooo
0?ooofd0oooo003?0?ooo`L000005`3oool800000?l0ooooo`3ooom]0?ooo`00d03oool300000003
00410@000000000001L0oooo2000003o0?ooool0ooooK@3oool00=00oooo1000000I0?ooo`800000
00<00@410000000000000`00003o0?ooool0ooooK@3oool00=00oooo1000000I0?ooo`80000000<0
0@410000000000000`00003o0?ooool0ooooK@3oool00=00oooo00@00@4100000000000000006@3o
ool70000000300410@3oool0oooo0080o_kn103oool00`3no_h0oooo0?ooo`3o0?ooool0ooooHP3o
ool00=40oooo0`00000B0?ooo`X000000P010@45000000800@4100<0000000410@0000000P000003
0?ooo`030?knoP3oool0oooo0?l0ooooo`3ooomN0?ooo`00d@3oool2000001<0oooo00<00@410000
000000002P0000000`010@40000000000008000000<0oooo00@0o_kn0?ooo`3oool0oooo0P3no_ko
0?ooool0ooooF`3oool00=40oooo0P00000A0?ooo`040?knoP3oool0oooo0?ooo`H0000000<00@41
000000000000200000000`010@4000000000000200000?l0ooooo`3ooomT0?ooo`00dP3oool00`00
0000oooo0?ooo`0F0?ooo`X00000303oool00`3no_h0oooo0?ooo`3o0?ooool0ooooGP3oool00>`0
oooo2@00003o0?ooool0ooooK@3oool00>`0oooo2@00003o0?ooool0ooooK@3oool00>d0oooo1@00
00000`010@4000000000003o0?ooool0ooooK@3oool00>h0oooo100000000`010@4000000000003o
0?ooool0ooooK@3oool00>l0oooo0`0000000`010@4000000000003o0?ooool0ooooK@3oool00>h0
oooo00<0o_kn0000000000001000003o0?ooool0ooooK@3oool00>/0oooo00D0o_kn0?ooo`3oool0
o_kn0?ooo`0500000?l0ooooo`3ooom]0?ooo`00lP3oool300000?l0ooooo`3ooom]0?ooo`00lP3o
ool300000?l0ooooo`3ooom]0?ooo`00lP3oool300000?l0ooooo`3ooom]0?ooo`00l`3oool20000
0?l0ooooo`3ooom]0?ooo`00l`3oool200000?l0ooooo`3ooom]0?ooo`00m03oool00`000000oooo
0?ooo`3o0?ooool0ooooJ`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{103.188, 87.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 1.4 A solution curve to ",
  ButtonBox["Eq. (1.2.8)",
    ButtonData:>"(1.2.8)",
    ButtonStyle->"Hyperlink"],
  ", a tangent vector, and the projection onto the (",
  StyleBox["x,v",
    FontSlant->"Italic"],
  ") plane."
}], "Caption",
  CellTags->"Fig. 1.4"],

Cell[TextData[{
  "\t The projection of the direction field onto phase-space,  created as \
usual with the ",
  StyleBox["PlotVectorField",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, provides us with a global picture of the solution for all \
initial conditions (",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  "). This projection is shown in Cell ",
  ButtonBox["1.6",
    ButtonData:>"Cell 1.6",
    ButtonStyle->"Hyperlink"],
  " for the case of a damped oscillator with acceleration given by ",
  ButtonBox["Eq. (1.2.9)",
    ButtonData:>"(1.2.9)",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Omega]\_o\),
            "TraditionalForm"], " ", "=", " ", \(\[Gamma]\ \  = \ 1\)}], 
        TraditionalForm]]],
  ".  One can see from this plot that all solutions spiral into the origin, \
which is expected, since the oscillator loses energy through frictional \
damping and eventually comes to rest."
}], "Text"],

Cell[TextData[{
  "\t   Vectors in the direction field point toward the origin, in a manner \
reminscent of the singularity in Fig. ",
  ButtonBox["1.3",
    ButtonData:>"Fig. 1.3",
    ButtonStyle->"Hyperlink"],
  ", even though ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, v)\)]],
  " is differentiable However, particles actually require an infinite amount \
of time to reach the origin, and if placed at the origin will not move from \
it (the origin is an ",
  StyleBox["attracting",
    FontSlant->"Italic"],
  " ",
  StyleBox["fixed point",
    FontSlant->"Italic"],
  "), so this field does not violate Theorem 1.1, and all initial conditions \
result in unique trajectories."
}], "Text",
  CellTags->"i:114"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(f[x_, v_]\  = \ \(-x\)\  - \ v;\)\), "\n", 
    \(\(PlotVectorField[{v, f[x, v]}, {x, \(-1\), 1}, {v, \(-1\), 1}, 
        Axes \[Rule] True, ScaleFunction \[Rule] \((1 &)\), 
        AxesLabel \[Rule] {"\<x\>", "\<v\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93995 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.447595 0.469974 0.447595 [
[.05241 .45747 -6 -9 ]
[.05241 .45747 6 0 ]
[.2762 .45747 -12 -9 ]
[.2762 .45747 12 0 ]
[.7238 .45747 -9 -9 ]
[.7238 .45747 9 0 ]
[.94759 .45747 -3 -9 ]
[.94759 .45747 3 0 ]
[1.025 .46997 0 -6 ]
[1.025 .46997 10 6 ]
[.4875 .02238 -12 -4.5 ]
[.4875 .02238 0 4.5 ]
[.4875 .24618 -24 -4.5 ]
[.4875 .24618 0 4.5 ]
[.4875 .69377 -18 -4.5 ]
[.4875 .69377 0 4.5 ]
[.4875 .91757 -6 -4.5 ]
[.4875 .91757 0 4.5 ]
[.5 .96495 -5 0 ]
[.5 .96495 5 12 ]
[ 0 0 0 0 ]
[ 1 .93995 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05241 .46997 m
.05241 .47622 L
s
[(-1)] .05241 .45747 0 1 Mshowa
.2762 .46997 m
.2762 .47622 L
s
[(-0.5)] .2762 .45747 0 1 Mshowa
.7238 .46997 m
.7238 .47622 L
s
[(0.5)] .7238 .45747 0 1 Mshowa
.94759 .46997 m
.94759 .47622 L
s
[(1)] .94759 .45747 0 1 Mshowa
.125 Mabswid
.09716 .46997 m
.09716 .47372 L
s
.14192 .46997 m
.14192 .47372 L
s
.18668 .46997 m
.18668 .47372 L
s
.23144 .46997 m
.23144 .47372 L
s
.32096 .46997 m
.32096 .47372 L
s
.36572 .46997 m
.36572 .47372 L
s
.41048 .46997 m
.41048 .47372 L
s
.45524 .46997 m
.45524 .47372 L
s
.54476 .46997 m
.54476 .47372 L
s
.58952 .46997 m
.58952 .47372 L
s
.63428 .46997 m
.63428 .47372 L
s
.67904 .46997 m
.67904 .47372 L
s
.76856 .46997 m
.76856 .47372 L
s
.81332 .46997 m
.81332 .47372 L
s
.85808 .46997 m
.85808 .47372 L
s
.90284 .46997 m
.90284 .47372 L
s
.00765 .46997 m
.00765 .47372 L
s
.99235 .46997 m
.99235 .47372 L
s
.25 Mabswid
0 .46997 m
1 .46997 L
s
gsave
1.025 .46997 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02238 m
.50625 .02238 L
s
[(-1)] .4875 .02238 1 0 Mshowa
.5 .24618 m
.50625 .24618 L
s
[(-0.5)] .4875 .24618 1 0 Mshowa
.5 .69377 m
.50625 .69377 L
s
[(0.5)] .4875 .69377 1 0 Mshowa
.5 .91757 m
.50625 .91757 L
s
[(1)] .4875 .91757 1 0 Mshowa
.125 Mabswid
.5 .06714 m
.50375 .06714 L
s
.5 .1119 m
.50375 .1119 L
s
.5 .15666 m
.50375 .15666 L
s
.5 .20142 m
.50375 .20142 L
s
.5 .29094 m
.50375 .29094 L
s
.5 .3357 m
.50375 .3357 L
s
.5 .38046 m
.50375 .38046 L
s
.5 .42521 m
.50375 .42521 L
s
.5 .51473 m
.50375 .51473 L
s
.5 .55949 m
.50375 .55949 L
s
.5 .60425 m
.50375 .60425 L
s
.5 .64901 m
.50375 .64901 L
s
.5 .73853 m
.50375 .73853 L
s
.5 .78329 m
.50375 .78329 L
s
.5 .82805 m
.50375 .82805 L
s
.5 .87281 m
.50375 .87281 L
s
.25 Mabswid
.5 0 m
.5 .93995 L
s
gsave
.5 .96495 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.05241 .02238 m
.02381 .07957 L
s
% Start of user PostScript
-1. -1. -1.06389 -0.872225 MAarrowhead1
% End of user PostScript
.05241 .08632 m
.02561 .14438 L
s
% Start of user PostScript
-1. -0.857143 -1.05987 -0.727434 MAarrowhead1
% End of user PostScript
.05241 .15026 m
.02781 .20929 L
s
% Start of user PostScript
-1. -0.714286 -1.05495 -0.582418 MAarrowhead1
% End of user PostScript
.05241 .21421 m
.03055 .2743 L
s
% Start of user PostScript
-1. -0.571429 -1.04882 -0.437172 MAarrowhead1
% End of user PostScript
.05241 .27815 m
.03403 .33939 L
s
% Start of user PostScript
-1. -0.428571 -1.04105 -0.291739 MAarrowhead1
% End of user PostScript
.05241 .34209 m
.03853 .40451 L
s
% Start of user PostScript
-1. -0.285714 -1.03099 -0.146259 MAarrowhead1
% End of user PostScript
.05241 .40603 m
.04447 .46948 L
s
% Start of user PostScript
-1. -0.142857 -1.01772 -0.00110316 MAarrowhead1
% End of user PostScript
.05241 .46997 m
.05241 .53392 L
s
% Start of user PostScript
-1. 0 -1. 0.142857 MAarrowhead1
% End of user PostScript
.05241 .53392 m
.06292 .59699 L
s
% Start of user PostScript
-1. 0.142857 -0.976514 0.283771 MAarrowhead1
% End of user PostScript
.05241 .59786 m
.07615 .65723 L
s
% Start of user PostScript
-1. 0.285714 -0.946944 0.418354 MAarrowhead1
% End of user PostScript
.05241 .6618 m
.09077 .71295 L
s
% Start of user PostScript
-1. 0.428571 -0.914286 0.542857 MAarrowhead1
% End of user PostScript
.05241 .72574 m
.10356 .76411 L
s
% Start of user PostScript
-1. 0.571429 -0.885714 0.657143 MAarrowhead1
% End of user PostScript
.05241 .78968 m
.11177 .81343 L
s
% Start of user PostScript
-1. 0.714286 -0.86736 0.767342 MAarrowhead1
% End of user PostScript
.05241 .85363 m
.11548 .86414 L
s
% Start of user PostScript
-1. 0.857143 -0.859087 0.880628 MAarrowhead1
% End of user PostScript
.05241 .91757 m
.11635 .91757 L
s
% Start of user PostScript
-1. 1. -0.857143 1. MAarrowhead1
% End of user PostScript
.11635 .02238 m
.08603 .07868 L
s
% Start of user PostScript
-0.857143 -1. -0.924871 -0.874218 MAarrowhead1
% End of user PostScript
.11635 .08632 m
.08775 .14351 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.921031 -0.729368 MAarrowhead1
% End of user PostScript
.11635 .15026 m
.08989 .20847 L
s
% Start of user PostScript
-0.857143 -0.714286 -0.916258 -0.584233 MAarrowhead1
% End of user PostScript
.11635 .21421 m
.0926 .27357 L
s
% Start of user PostScript
-0.857143 -0.571429 -0.910199 -0.438789 MAarrowhead1
% End of user PostScript
.11635 .27815 m
.09613 .33881 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.902318 -0.293045 MAarrowhead1
% End of user PostScript
.11635 .34209 m
.10084 .40412 L
s
% Start of user PostScript
-0.857143 -0.285714 -0.891791 -0.147122 MAarrowhead1
% End of user PostScript
.11635 .40603 m
.1073 .46933 L
s
% Start of user PostScript
-0.857143 -0.142857 -0.877346 -0.00143579 MAarrowhead1
% End of user PostScript
.11635 .46997 m
.11635 .53392 L
s
% Start of user PostScript
-0.857143 0 -0.857143 0.142857 MAarrowhead1
% End of user PostScript
.11635 .53392 m
.12889 .59662 L
s
% Start of user PostScript
-0.857143 0.142857 -0.829126 0.28294 MAarrowhead1
% End of user PostScript
.11635 .59786 m
.14494 .65505 L
s
% Start of user PostScript
-0.857143 0.285714 -0.793255 0.41349 MAarrowhead1
% End of user PostScript
.11635 .6618 m
.16156 .70701 L
s
% Start of user PostScript
-0.857143 0.428571 -0.756128 0.529587 MAarrowhead1
% End of user PostScript
.11635 .72574 m
.17354 .75434 L
s
% Start of user PostScript
-0.857143 0.571429 -0.729368 0.635316 MAarrowhead1
% End of user PostScript
.11635 .78968 m
.17905 .80223 L
s
% Start of user PostScript
-0.857143 0.714286 -0.71706 0.742302 MAarrowhead1
% End of user PostScript
.11635 .85363 m
.18029 .85363 L
s
% Start of user PostScript
-0.857143 0.857143 -0.714286 0.857143 MAarrowhead1
% End of user PostScript
.11635 .91757 m
.17965 .90853 L
s
% Start of user PostScript
-0.857143 1. -0.715722 0.979797 MAarrowhead1
% End of user PostScript
.18029 .02238 m
.14807 .07761 L
s
% Start of user PostScript
-0.714286 -1. -0.786267 -0.876603 MAarrowhead1
% End of user PostScript
.18029 .08632 m
.14967 .14246 L
s
% Start of user PostScript
-0.714286 -0.857143 -0.782693 -0.731729 MAarrowhead1
% End of user PostScript
.18029 .15026 m
.15169 .20746 L
s
% Start of user PostScript
-0.714286 -0.714286 -0.778173 -0.58651 MAarrowhead1
% End of user PostScript
.18029 .21421 m
.15432 .27264 L
s
% Start of user PostScript
-0.714286 -0.571429 -0.772305 -0.440884 MAarrowhead1
% End of user PostScript
.18029 .27815 m
.15784 .33802 L
s
% Start of user PostScript
-0.714286 -0.428571 -0.764446 -0.29481 MAarrowhead1
% End of user PostScript
.18029 .34209 m
.16272 .40357 L
s
% Start of user PostScript
-0.714286 -0.285714 -0.753532 -0.148354 MAarrowhead1
% End of user PostScript
.18029 .40603 m
.16978 .4691 L
s
% Start of user PostScript
-0.714286 -0.142857 -0.737771 -0.00194373 MAarrowhead1
% End of user PostScript
.18029 .46997 m
.18029 .53392 L
s
% Start of user PostScript
-0.714286 0 -0.714286 0.142857 MAarrowhead1
% End of user PostScript
.18029 .53392 m
.1958 .59595 L
s
% Start of user PostScript
-0.714286 0.142857 -0.679638 0.281449 MAarrowhead1
% End of user PostScript
.18029 .59786 m
.21576 .65106 L
s
% Start of user PostScript
-0.714286 0.285714 -0.635043 0.404579 MAarrowhead1
% End of user PostScript
.18029 .6618 m
.23349 .69727 L
s
% Start of user PostScript
-0.714286 0.428571 -0.595421 0.507814 MAarrowhead1
% End of user PostScript
.18029 .72574 m
.24232 .74125 L
s
% Start of user PostScript
-0.714286 0.571429 -0.575694 0.606077 MAarrowhead1
% End of user PostScript
.18029 .78968 m
.24423 .78968 L
s
% Start of user PostScript
-0.714286 0.714286 -0.571429 0.714286 MAarrowhead1
% End of user PostScript
.18029 .85363 m
.24336 .84312 L
s
% Start of user PostScript
-0.714286 0.857143 -0.573372 0.833657 MAarrowhead1
% End of user PostScript
.18029 .91757 m
.24177 .9 L
s
% Start of user PostScript
-0.714286 1. -0.576925 0.960754 MAarrowhead1
% End of user PostScript
.24423 .02238 m
.2099 .07633 L
s
% Start of user PostScript
-0.571429 -1. -0.648125 -0.879477 MAarrowhead1
% End of user PostScript
.24423 .08632 m
.21133 .14115 L
s
% Start of user PostScript
-0.571429 -0.857143 -0.644928 -0.734644 MAarrowhead1
% End of user PostScript
.24423 .15026 m
.21318 .20616 L
s
% Start of user PostScript
-0.571429 -0.714286 -0.640806 -0.589406 MAarrowhead1
% End of user PostScript
.24423 .21421 m
.21564 .2714 L
s
% Start of user PostScript
-0.571429 -0.571429 -0.635316 -0.443653 MAarrowhead1
% End of user PostScript
.24423 .27815 m
.21904 .33692 L
s
% Start of user PostScript
-0.571429 -0.428571 -0.627703 -0.297265 MAarrowhead1
% End of user PostScript
.24423 .34209 m
.22401 .40275 L
s
% Start of user PostScript
-0.571429 -0.285714 -0.616604 -0.150188 MAarrowhead1
% End of user PostScript
.24423 .40603 m
.23169 .46873 L
s
% Start of user PostScript
-0.571429 -0.142857 -0.599445 -0.00277419 MAarrowhead1
% End of user PostScript
.24423 .46997 m
.24423 .53392 L
s
% Start of user PostScript
-0.571429 0 -0.571429 0.142857 MAarrowhead1
% End of user PostScript
.24423 .53392 m
.26445 .59458 L
s
% Start of user PostScript
-0.571429 0.142857 -0.526253 0.278383 MAarrowhead1
% End of user PostScript
.24423 .59786 m
.28945 .64307 L
s
% Start of user PostScript
-0.571429 0.285714 -0.470413 0.38673 MAarrowhead1
% End of user PostScript
.24423 .6618 m
.30489 .68202 L
s
% Start of user PostScript
-0.571429 0.428571 -0.435902 0.473747 MAarrowhead1
% End of user PostScript
.24423 .72574 m
.30817 .72574 L
s
% Start of user PostScript
-0.571429 0.571429 -0.428571 0.571429 MAarrowhead1
% End of user PostScript
.24423 .78968 m
.30693 .77714 L
s
% Start of user PostScript
-0.571429 0.714286 -0.431346 0.686269 MAarrowhead1
% End of user PostScript
.24423 .85363 m
.30489 .83341 L
s
% Start of user PostScript
-0.571429 0.857143 -0.435902 0.811967 MAarrowhead1
% End of user PostScript
.24423 .91757 m
.303 .89238 L
s
% Start of user PostScript
-0.571429 1. -0.440122 0.943726 MAarrowhead1
% End of user PostScript
.30817 .02238 m
.27151 .07476 L
s
% Start of user PostScript
-0.428571 -1. -0.510495 -0.882967 MAarrowhead1
% End of user PostScript
.30817 .08632 m
.27271 .13952 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.507814 -0.738279 MAarrowhead1
% End of user PostScript
.30817 .15026 m
.27428 .20449 L
s
% Start of user PostScript
-0.428571 -0.714286 -0.504286 -0.593143 MAarrowhead1
% End of user PostScript
.30817 .21421 m
.27645 .26972 L
s
% Start of user PostScript
-0.428571 -0.571429 -0.499448 -0.447394 MAarrowhead1
% End of user PostScript
.30817 .27815 m
.27958 .33534 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.492459 -0.300796 MAarrowhead1
% End of user PostScript
.30817 .34209 m
.28443 .40146 L
s
% Start of user PostScript
-0.428571 -0.285714 -0.481627 -0.153075 MAarrowhead1
% End of user PostScript
.30817 .40603 m
.29267 .46807 L
s
% Start of user PostScript
-0.428571 -0.142857 -0.463219 -0.00426536 MAarrowhead1
% End of user PostScript
.30817 .46997 m
.30817 .53392 L
s
% Start of user PostScript
-0.428571 0 -0.428571 0.142857 MAarrowhead1
% End of user PostScript
.30817 .53392 m
.33677 .59111 L
s
% Start of user PostScript
-0.428571 0.142857 -0.364684 0.270632 MAarrowhead1
% End of user PostScript
.30817 .59786 m
.36537 .62645 L
s
% Start of user PostScript
-0.428571 0.285714 -0.300796 0.349602 MAarrowhead1
% End of user PostScript
.30817 .6618 m
.37212 .6618 L
s
% Start of user PostScript
-0.428571 0.428571 -0.285714 0.428571 MAarrowhead1
% End of user PostScript
.30817 .72574 m
.37021 .71023 L
s
% Start of user PostScript
-0.428571 0.571429 -0.28998 0.536781 MAarrowhead1
% End of user PostScript
.30817 .78968 m
.36754 .76594 L
s
% Start of user PostScript
-0.428571 0.714286 -0.295932 0.66123 MAarrowhead1
% End of user PostScript
.30817 .85363 m
.36537 .82503 L
s
% Start of user PostScript
-0.428571 0.857143 -0.300796 0.793255 MAarrowhead1
% End of user PostScript
.30817 .91757 m
.36369 .88584 L
s
% Start of user PostScript
-0.428571 1. -0.304537 0.929123 MAarrowhead1
% End of user PostScript
.37212 .02238 m
.33286 .07285 L
s
% Start of user PostScript
-0.285714 -1. -0.37342 -0.887235 MAarrowhead1
% End of user PostScript
.37212 .08632 m
.33375 .13748 L
s
% Start of user PostScript
-0.285714 -0.857143 -0.371429 -0.742857 MAarrowhead1
% End of user PostScript
.37212 .15026 m
.33495 .2023 L
s
% Start of user PostScript
-0.285714 -0.714286 -0.368748 -0.598038 MAarrowhead1
% End of user PostScript
.37212 .21421 m
.33665 .26741 L
s
% Start of user PostScript
-0.285714 -0.571429 -0.364957 -0.452564 MAarrowhead1
% End of user PostScript
.37212 .27815 m
.33922 .33298 L
s
% Start of user PostScript
-0.285714 -0.428571 -0.359214 -0.306072 MAarrowhead1
% End of user PostScript
.37212 .34209 m
.34352 .39928 L
s
% Start of user PostScript
-0.285714 -0.285714 -0.349602 -0.157939 MAarrowhead1
% End of user PostScript
.37212 .40603 m
.3519 .46669 L
s
% Start of user PostScript
-0.285714 -0.142857 -0.33089 -0.00733096 MAarrowhead1
% End of user PostScript
.37212 .46997 m
.37212 .53392 L
s
% Start of user PostScript
-0.285714 0 -0.285714 0.142857 MAarrowhead1
% End of user PostScript
.37212 .53392 m
.41733 .57913 L
s
% Start of user PostScript
-0.285714 0.142857 -0.184699 0.243872 MAarrowhead1
% End of user PostScript
.37212 .59786 m
.43606 .59786 L
s
% Start of user PostScript
-0.285714 0.285714 -0.142857 0.285714 MAarrowhead1
% End of user PostScript
.37212 .6618 m
.43278 .64158 L
s
% Start of user PostScript
-0.285714 0.428571 -0.150188 0.383396 MAarrowhead1
% End of user PostScript
.37212 .72574 m
.42931 .69715 L
s
% Start of user PostScript
-0.285714 0.571429 -0.157939 0.507541 MAarrowhead1
% End of user PostScript
.37212 .78968 m
.42695 .75679 L
s
% Start of user PostScript
-0.285714 0.714286 -0.163215 0.640786 MAarrowhead1
% End of user PostScript
.37212 .85363 m
.42532 .81816 L
s
% Start of user PostScript
-0.285714 0.857143 -0.16685 0.7779 MAarrowhead1
% End of user PostScript
.37212 .91757 m
.42415 .8804 L
s
% Start of user PostScript
-0.285714 1. -0.169467 0.916966 MAarrowhead1
% End of user PostScript
.43606 .02238 m
.39395 .0705 L
s
% Start of user PostScript
-0.142857 -1. -0.236929 -0.892489 MAarrowhead1
% End of user PostScript
.43606 .08632 m
.39444 .13487 L
s
% Start of user PostScript
-0.142857 -0.857143 -0.235827 -0.748678 MAarrowhead1
% End of user PostScript
.43606 .15026 m
.39512 .19939 L
s
% Start of user PostScript
-0.142857 -0.714286 -0.234312 -0.60454 MAarrowhead1
% End of user PostScript
.43606 .21421 m
.39611 .26414 L
s
% Start of user PostScript
-0.142857 -0.571429 -0.232099 -0.459876 MAarrowhead1
% End of user PostScript
.43606 .27815 m
.39769 .3293 L
s
% Start of user PostScript
-0.142857 -0.428571 -0.228571 -0.314286 MAarrowhead1
% End of user PostScript
.43606 .34209 m
.40059 .39529 L
s
% Start of user PostScript
-0.142857 -0.285714 -0.2221 -0.16685 MAarrowhead1
% End of user PostScript
.43606 .40603 m
.40746 .46322 L
s
% Start of user PostScript
-0.142857 -0.142857 -0.206745 -0.0150818 MAarrowhead1
% End of user PostScript
.43606 .46997 m
.43606 .53392 L
s
% Start of user PostScript
-0.142857 0 -0.142857 0.142857 MAarrowhead1
% End of user PostScript
.43606 .53392 m
.5 .53392 L
s
% Start of user PostScript
-0.142857 0.142857 0 0.142857 MAarrowhead1
% End of user PostScript
.43606 .59786 m
.49325 .56926 L
s
% Start of user PostScript
-0.142857 0.285714 -0.0150818 0.221827 MAarrowhead1
% End of user PostScript
.43606 .6618 m
.48926 .62633 L
s
% Start of user PostScript
-0.142857 0.428571 -0.0239928 0.349329 MAarrowhead1
% End of user PostScript
.43606 .72574 m
.48721 .68738 L
s
% Start of user PostScript
-0.142857 0.571429 -0.0285714 0.485714 MAarrowhead1
% End of user PostScript
.43606 .78968 m
.48599 .74974 L
s
% Start of user PostScript
-0.142857 0.714286 -0.0313045 0.625044 MAarrowhead1
% End of user PostScript
.43606 .85363 m
.48518 .81269 L
s
% Start of user PostScript
-0.142857 0.857143 -0.0331112 0.765688 MAarrowhead1
% End of user PostScript
.43606 .91757 m
.48461 .87596 L
s
% Start of user PostScript
-0.142857 1. -0.0343919 0.90703 MAarrowhead1
% End of user PostScript
.5 .02238 m
.45479 .06759 L
s
% Start of user PostScript
0 -1. -0.101015 -0.898985 MAarrowhead1
% End of user PostScript
.5 .08632 m
.45479 .13154 L
s
% Start of user PostScript
0 -0.857143 -0.101015 -0.756128 MAarrowhead1
% End of user PostScript
.5 .15026 m
.45479 .19548 L
s
% Start of user PostScript
0 -0.714286 -0.101015 -0.61327 MAarrowhead1
% End of user PostScript
.5 .21421 m
.45479 .25942 L
s
% Start of user PostScript
0 -0.571429 -0.101015 -0.470413 MAarrowhead1
% End of user PostScript
.5 .27815 m
.45479 .32336 L
s
% Start of user PostScript
0 -0.428571 -0.101015 -0.327556 MAarrowhead1
% End of user PostScript
.5 .34209 m
.45479 .3873 L
s
% Start of user PostScript
0 -0.285714 -0.101015 -0.184699 MAarrowhead1
% End of user PostScript
.5 .40603 m
.45479 .45125 L
s
% Start of user PostScript
0 -0.142857 -0.101015 -0.0418419 MAarrowhead1
% End of user PostScript
.5 .46997 m
.5 .46997 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .53392 m
.54521 .4887 L
s
% Start of user PostScript
0 0.142857 0.101015 0.0418419 MAarrowhead1
% End of user PostScript
.5 .59786 m
.54521 .55264 L
s
% Start of user PostScript
0 0.285714 0.101015 0.184699 MAarrowhead1
% End of user PostScript
.5 .6618 m
.54521 .61659 L
s
% Start of user PostScript
0 0.428571 0.101015 0.327556 MAarrowhead1
% End of user PostScript
.5 .72574 m
.54521 .68053 L
s
% Start of user PostScript
0 0.571429 0.101015 0.470413 MAarrowhead1
% End of user PostScript
.5 .78968 m
.54521 .74447 L
s
% Start of user PostScript
0 0.714286 0.101015 0.61327 MAarrowhead1
% End of user PostScript
.5 .85363 m
.54521 .80841 L
s
% Start of user PostScript
0 0.857143 0.101015 0.756128 MAarrowhead1
% End of user PostScript
.5 .91757 m
.54521 .87236 L
s
% Start of user PostScript
0 1. 0.101015 0.898985 MAarrowhead1
% End of user PostScript
.56394 .02238 m
.51539 .06399 L
s
% Start of user PostScript
0.142857 -1. 0.0343919 -0.90703 MAarrowhead1
% End of user PostScript
.56394 .08632 m
.51482 .12726 L
s
% Start of user PostScript
0.142857 -0.857143 0.0331112 -0.765688 MAarrowhead1
% End of user PostScript
.56394 .15026 m
.51401 .19021 L
s
% Start of user PostScript
0.142857 -0.714286 0.0313045 -0.625044 MAarrowhead1
% End of user PostScript
.56394 .21421 m
.51279 .25257 L
s
% Start of user PostScript
0.142857 -0.571429 0.0285714 -0.485714 MAarrowhead1
% End of user PostScript
.56394 .27815 m
.51074 .31362 L
s
% Start of user PostScript
0.142857 -0.428571 0.0239928 -0.349329 MAarrowhead1
% End of user PostScript
.56394 .34209 m
.50675 .37069 L
s
% Start of user PostScript
0.142857 -0.285714 0.0150818 -0.221827 MAarrowhead1
% End of user PostScript
.56394 .40603 m
.5 .40603 L
s
% Start of user PostScript
0.142857 -0.142857 0 -0.142857 MAarrowhead1
% End of user PostScript
.56394 .46997 m
.56394 .40603 L
s
% Start of user PostScript
0.142857 0 0.142857 -0.142857 MAarrowhead1
% End of user PostScript
.56394 .53392 m
.59254 .47672 L
s
% Start of user PostScript
0.142857 0.142857 0.206745 0.0150818 MAarrowhead1
% End of user PostScript
.56394 .59786 m
.59941 .54466 L
s
% Start of user PostScript
0.142857 0.285714 0.2221 0.16685 MAarrowhead1
% End of user PostScript
.56394 .6618 m
.60231 .61065 L
s
% Start of user PostScript
0.142857 0.428571 0.228571 0.314286 MAarrowhead1
% End of user PostScript
.56394 .72574 m
.60389 .67581 L
s
% Start of user PostScript
0.142857 0.571429 0.232099 0.459876 MAarrowhead1
% End of user PostScript
.56394 .78968 m
.60488 .74056 L
s
% Start of user PostScript
0.142857 0.714286 0.234312 0.60454 MAarrowhead1
% End of user PostScript
.56394 .85363 m
.60556 .80508 L
s
% Start of user PostScript
0.142857 0.857143 0.235827 0.748678 MAarrowhead1
% End of user PostScript
.56394 .91757 m
.60605 .86945 L
s
% Start of user PostScript
0.142857 1. 0.236929 0.892489 MAarrowhead1
% End of user PostScript
.62788 .02238 m
.57585 .05955 L
s
% Start of user PostScript
0.285714 -1. 0.169467 -0.916966 MAarrowhead1
% End of user PostScript
.62788 .08632 m
.57468 .12179 L
s
% Start of user PostScript
0.285714 -0.857143 0.16685 -0.7779 MAarrowhead1
% End of user PostScript
.62788 .15026 m
.57305 .18316 L
s
% Start of user PostScript
0.285714 -0.714286 0.163215 -0.640786 MAarrowhead1
% End of user PostScript
.62788 .21421 m
.57069 .2428 L
s
% Start of user PostScript
0.285714 -0.571429 0.157939 -0.507541 MAarrowhead1
% End of user PostScript
.62788 .27815 m
.56722 .29837 L
s
% Start of user PostScript
0.285714 -0.428571 0.150188 -0.383396 MAarrowhead1
% End of user PostScript
.62788 .34209 m
.56394 .34209 L
s
% Start of user PostScript
0.285714 -0.285714 0.142857 -0.285714 MAarrowhead1
% End of user PostScript
.62788 .40603 m
.58267 .36082 L
s
% Start of user PostScript
0.285714 -0.142857 0.184699 -0.243872 MAarrowhead1
% End of user PostScript
.62788 .46997 m
.62788 .40603 L
s
% Start of user PostScript
0.285714 0 0.285714 -0.142857 MAarrowhead1
% End of user PostScript
.62788 .53392 m
.6481 .47326 L
s
% Start of user PostScript
0.285714 0.142857 0.33089 0.00733096 MAarrowhead1
% End of user PostScript
.62788 .59786 m
.65648 .54067 L
s
% Start of user PostScript
0.285714 0.285714 0.349602 0.157939 MAarrowhead1
% End of user PostScript
.62788 .6618 m
.66078 .60697 L
s
% Start of user PostScript
0.285714 0.428571 0.359214 0.306072 MAarrowhead1
% End of user PostScript
.62788 .72574 m
.66335 .67254 L
s
% Start of user PostScript
0.285714 0.571429 0.364957 0.452564 MAarrowhead1
% End of user PostScript
.62788 .78968 m
.66505 .73765 L
s
% Start of user PostScript
0.285714 0.714286 0.368748 0.598038 MAarrowhead1
% End of user PostScript
.62788 .85363 m
.66625 .80247 L
s
% Start of user PostScript
0.285714 0.857143 0.371429 0.742857 MAarrowhead1
% End of user PostScript
.62788 .91757 m
.66714 .8671 L
s
% Start of user PostScript
0.285714 1. 0.37342 0.887235 MAarrowhead1
% End of user PostScript
.69183 .02238 m
.63631 .0541 L
s
% Start of user PostScript
0.428571 -1. 0.304537 -0.929123 MAarrowhead1
% End of user PostScript
.69183 .08632 m
.63463 .11492 L
s
% Start of user PostScript
0.428571 -0.857143 0.300796 -0.793255 MAarrowhead1
% End of user PostScript
.69183 .15026 m
.63246 .17401 L
s
% Start of user PostScript
0.428571 -0.714286 0.295932 -0.66123 MAarrowhead1
% End of user PostScript
.69183 .21421 m
.62979 .22971 L
s
% Start of user PostScript
0.428571 -0.571429 0.28998 -0.536781 MAarrowhead1
% End of user PostScript
.69183 .27815 m
.62788 .27815 L
s
% Start of user PostScript
0.428571 -0.428571 0.285714 -0.428571 MAarrowhead1
% End of user PostScript
.69183 .34209 m
.63463 .31349 L
s
% Start of user PostScript
0.428571 -0.285714 0.300796 -0.349602 MAarrowhead1
% End of user PostScript
.69183 .40603 m
.66323 .34884 L
s
% Start of user PostScript
0.428571 -0.142857 0.364684 -0.270632 MAarrowhead1
% End of user PostScript
.69183 .46997 m
.69183 .40603 L
s
% Start of user PostScript
0.428571 0 0.428571 -0.142857 MAarrowhead1
% End of user PostScript
.69183 .53392 m
.70733 .47188 L
s
% Start of user PostScript
0.428571 0.142857 0.463219 0.00426536 MAarrowhead1
% End of user PostScript
.69183 .59786 m
.71557 .53849 L
s
% Start of user PostScript
0.428571 0.285714 0.481627 0.153075 MAarrowhead1
% End of user PostScript
.69183 .6618 m
.72042 .60461 L
s
% Start of user PostScript
0.428571 0.428571 0.492459 0.300796 MAarrowhead1
% End of user PostScript
.69183 .72574 m
.72355 .67023 L
s
% Start of user PostScript
0.428571 0.571429 0.499448 0.447394 MAarrowhead1
% End of user PostScript
.69183 .78968 m
.72572 .73546 L
s
% Start of user PostScript
0.428571 0.714286 0.504286 0.593143 MAarrowhead1
% End of user PostScript
.69183 .85363 m
.72729 .80042 L
s
% Start of user PostScript
0.428571 0.857143 0.507814 0.738279 MAarrowhead1
% End of user PostScript
.69183 .91757 m
.72849 .86519 L
s
% Start of user PostScript
0.428571 1. 0.510495 0.882967 MAarrowhead1
% End of user PostScript
.75577 .02238 m
.697 .04757 L
s
% Start of user PostScript
0.571429 -1. 0.440122 -0.943726 MAarrowhead1
% End of user PostScript
.75577 .08632 m
.69511 .10654 L
s
% Start of user PostScript
0.571429 -0.857143 0.435902 -0.811967 MAarrowhead1
% End of user PostScript
.75577 .15026 m
.69307 .1628 L
s
% Start of user PostScript
0.571429 -0.714286 0.431346 -0.686269 MAarrowhead1
% End of user PostScript
.75577 .21421 m
.69183 .21421 L
s
% Start of user PostScript
0.571429 -0.571429 0.428571 -0.571429 MAarrowhead1
% End of user PostScript
.75577 .27815 m
.69511 .25793 L
s
% Start of user PostScript
0.571429 -0.428571 0.435902 -0.473747 MAarrowhead1
% End of user PostScript
.75577 .34209 m
.71055 .29688 L
s
% Start of user PostScript
0.571429 -0.285714 0.470413 -0.38673 MAarrowhead1
% End of user PostScript
.75577 .40603 m
.73555 .34537 L
s
% Start of user PostScript
0.571429 -0.142857 0.526253 -0.278383 MAarrowhead1
% End of user PostScript
.75577 .46997 m
.75577 .40603 L
s
% Start of user PostScript
0.571429 0 0.571429 -0.142857 MAarrowhead1
% End of user PostScript
.75577 .53392 m
.76831 .47122 L
s
% Start of user PostScript
0.571429 0.142857 0.599445 0.00277419 MAarrowhead1
% End of user PostScript
.75577 .59786 m
.77599 .5372 L
s
% Start of user PostScript
0.571429 0.285714 0.616604 0.150188 MAarrowhead1
% End of user PostScript
.75577 .6618 m
.78096 .60303 L
s
% Start of user PostScript
0.571429 0.428571 0.627703 0.297265 MAarrowhead1
% End of user PostScript
.75577 .72574 m
.78436 .66855 L
s
% Start of user PostScript
0.571429 0.571429 0.635316 0.443653 MAarrowhead1
% End of user PostScript
.75577 .78968 m
.78682 .73379 L
s
% Start of user PostScript
0.571429 0.714286 0.640806 0.589406 MAarrowhead1
% End of user PostScript
.75577 .85363 m
.78867 .7988 L
s
% Start of user PostScript
0.571429 0.857143 0.644928 0.734644 MAarrowhead1
% End of user PostScript
.75577 .91757 m
.7901 .86362 L
s
% Start of user PostScript
0.571429 1. 0.648125 0.879477 MAarrowhead1
% End of user PostScript
.81971 .02238 m
.75823 .03995 L
s
% Start of user PostScript
0.714286 -1. 0.576925 -0.960754 MAarrowhead1
% End of user PostScript
.81971 .08632 m
.75664 .09683 L
s
% Start of user PostScript
0.714286 -0.857143 0.573372 -0.833657 MAarrowhead1
% End of user PostScript
.81971 .15026 m
.75577 .15026 L
s
% Start of user PostScript
0.714286 -0.714286 0.571429 -0.714286 MAarrowhead1
% End of user PostScript
.81971 .21421 m
.75768 .1987 L
s
% Start of user PostScript
0.714286 -0.571429 0.575694 -0.606077 MAarrowhead1
% End of user PostScript
.81971 .27815 m
.76651 .24268 L
s
% Start of user PostScript
0.714286 -0.428571 0.595421 -0.507814 MAarrowhead1
% End of user PostScript
.81971 .34209 m
.78424 .28889 L
s
% Start of user PostScript
0.714286 -0.285714 0.635043 -0.404579 MAarrowhead1
% End of user PostScript
.81971 .40603 m
.8042 .344 L
s
% Start of user PostScript
0.714286 -0.142857 0.679638 -0.281449 MAarrowhead1
% End of user PostScript
.81971 .46997 m
.81971 .40603 L
s
% Start of user PostScript
0.714286 0 0.714286 -0.142857 MAarrowhead1
% End of user PostScript
.81971 .53392 m
.83022 .47084 L
s
% Start of user PostScript
0.714286 0.142857 0.737771 0.00194373 MAarrowhead1
% End of user PostScript
.81971 .59786 m
.83728 .53638 L
s
% Start of user PostScript
0.714286 0.285714 0.753532 0.148354 MAarrowhead1
% End of user PostScript
.81971 .6618 m
.84216 .60193 L
s
% Start of user PostScript
0.714286 0.428571 0.764446 0.29481 MAarrowhead1
% End of user PostScript
.81971 .72574 m
.84568 .66731 L
s
% Start of user PostScript
0.714286 0.571429 0.772305 0.440884 MAarrowhead1
% End of user PostScript
.81971 .78968 m
.84831 .73249 L
s
% Start of user PostScript
0.714286 0.714286 0.778173 0.58651 MAarrowhead1
% End of user PostScript
.81971 .85363 m
.85033 .79749 L
s
% Start of user PostScript
0.714286 0.857143 0.782693 0.731729 MAarrowhead1
% End of user PostScript
.81971 .91757 m
.85193 .86234 L
s
% Start of user PostScript
0.714286 1. 0.786267 0.876603 MAarrowhead1
% End of user PostScript
.88365 .02238 m
.82035 .03142 L
s
% Start of user PostScript
0.857143 -1. 0.715722 -0.979797 MAarrowhead1
% End of user PostScript
.88365 .08632 m
.81971 .08632 L
s
% Start of user PostScript
0.857143 -0.857143 0.714286 -0.857143 MAarrowhead1
% End of user PostScript
.88365 .15026 m
.82095 .13772 L
s
% Start of user PostScript
0.857143 -0.714286 0.71706 -0.742302 MAarrowhead1
% End of user PostScript
.88365 .21421 m
.82646 .18561 L
s
% Start of user PostScript
0.857143 -0.571429 0.729368 -0.635316 MAarrowhead1
% End of user PostScript
.88365 .27815 m
.83844 .23293 L
s
% Start of user PostScript
0.857143 -0.428571 0.756128 -0.529587 MAarrowhead1
% End of user PostScript
.88365 .34209 m
.85506 .2849 L
s
% Start of user PostScript
0.857143 -0.285714 0.793255 -0.41349 MAarrowhead1
% End of user PostScript
.88365 .40603 m
.87111 .34333 L
s
% Start of user PostScript
0.857143 -0.142857 0.829126 -0.28294 MAarrowhead1
% End of user PostScript
.88365 .46997 m
.88365 .40603 L
s
% Start of user PostScript
0.857143 0 0.857143 -0.142857 MAarrowhead1
% End of user PostScript
.88365 .53392 m
.8927 .47062 L
s
% Start of user PostScript
0.857143 0.142857 0.877346 0.00143579 MAarrowhead1
% End of user PostScript
.88365 .59786 m
.89916 .53583 L
s
% Start of user PostScript
0.857143 0.285714 0.891791 0.147122 MAarrowhead1
% End of user PostScript
.88365 .6618 m
.90387 .60114 L
s
% Start of user PostScript
0.857143 0.428571 0.902318 0.293045 MAarrowhead1
% End of user PostScript
.88365 .72574 m
.9074 .66637 L
s
% Start of user PostScript
0.857143 0.571429 0.910199 0.438789 MAarrowhead1
% End of user PostScript
.88365 .78968 m
.91011 .73147 L
s
% Start of user PostScript
0.857143 0.714286 0.916258 0.584233 MAarrowhead1
% End of user PostScript
.88365 .85363 m
.91225 .79644 L
s
% Start of user PostScript
0.857143 0.857143 0.921031 0.729368 MAarrowhead1
% End of user PostScript
.88365 .91757 m
.91397 .86127 L
s
% Start of user PostScript
0.857143 1. 0.924871 0.874218 MAarrowhead1
% End of user PostScript
.94759 .02238 m
.88365 .02238 L
s
% Start of user PostScript
1. -1. 0.857143 -1. MAarrowhead1
% End of user PostScript
.94759 .08632 m
.88452 .07581 L
s
% Start of user PostScript
1. -0.857143 0.859087 -0.880628 MAarrowhead1
% End of user PostScript
.94759 .15026 m
.88823 .12652 L
s
% Start of user PostScript
1. -0.714286 0.86736 -0.767342 MAarrowhead1
% End of user PostScript
.94759 .21421 m
.89644 .17584 L
s
% Start of user PostScript
1. -0.571429 0.885714 -0.657143 MAarrowhead1
% End of user PostScript
.94759 .27815 m
.90923 .22699 L
s
% Start of user PostScript
1. -0.428571 0.914286 -0.542857 MAarrowhead1
% End of user PostScript
.94759 .34209 m
.92385 .28272 L
s
% Start of user PostScript
1. -0.285714 0.946944 -0.418354 MAarrowhead1
% End of user PostScript
.94759 .40603 m
.93708 .34296 L
s
% Start of user PostScript
1. -0.142857 0.976514 -0.283771 MAarrowhead1
% End of user PostScript
.94759 .46997 m
.94759 .40603 L
s
% Start of user PostScript
1. 0 1. -0.142857 MAarrowhead1
% End of user PostScript
.94759 .53392 m
.95553 .47047 L
s
% Start of user PostScript
1. 0.142857 1.01772 0.00110316 MAarrowhead1
% End of user PostScript
.94759 .59786 m
.96147 .53544 L
s
% Start of user PostScript
1. 0.285714 1.03099 0.146259 MAarrowhead1
% End of user PostScript
.94759 .6618 m
.96597 .60056 L
s
% Start of user PostScript
1. 0.428571 1.04105 0.291739 MAarrowhead1
% End of user PostScript
.94759 .72574 m
.96945 .66565 L
s
% Start of user PostScript
1. 0.571429 1.04882 0.437172 MAarrowhead1
% End of user PostScript
.94759 .78968 m
.97219 .73066 L
s
% Start of user PostScript
1. 0.714286 1.05495 0.582418 MAarrowhead1
% End of user PostScript
.94759 .85363 m
.97439 .79557 L
s
% Start of user PostScript
1. 0.857143 1.05987 0.727434 MAarrowhead1
% End of user PostScript
.94759 .91757 m
.97619 .86038 L
s
% Start of user PostScript
1. 1. 1.06389 0.872225 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 .93995 L
0 .93995 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 270.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001DQ000`40O003h00OZGoo00<007ooOol0
_7oo002YOol00`00Oomoo`2lOol00:Uoo`03001oogoo0;aoo`00ZGoo00<007ooOol0_7oo002YOol0
0`00Oomoo`2lOol009ioo`D000Ioo`03001oogoo0;aoo`00X7oo00<007ooOol01Woo00<007ooOol0
PWoo0P00>7oo002EOol60005Ool00`00Oomoo`06Ool00`00Oomoo`1oOol5000hOol001=oo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo00Yoo`03001oogoo00Eoo`@0015oo`8001=oo`8001Aoo`8001=oo`80019o
o`<000Eoo`8000]ooaT002Uoo`004goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol017oo
00<007oo00004Woo00<007ooOol04Woo00<007ooOol04Woo0P004Woo0`004Goo0`001Woo100017oo
1`001goo0`00>7oo000BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0;Ool00`00Oomoo`03Ool01000Oomo
o`004Goo00<007ooOol04Goo0P004goo0P004Woo0P002Woo0P001Goo0`001goo2P00BGoo000BOol0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`02Ool01@00Oomoogoo000047oo00<007ooOol0
4Goo00<007ooOol04Goo0P004Goo0`002goo0`0000=oo`0000000P002Goo1`00CGoo000AOol00`00
Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00
Oomoo`0BOol00`00Oomoo`0;Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0A
Ool00`00Oomoo`0@Ool2000=Ool20002Ool2000<Ool6001QOol0015oo`03001oogoo015oo`03001o
ogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo015oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo011oo`80019oo`03001oogoo00ao
o`D000eoo`L0065oo`0047oo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007oo
Ool04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol017oo00<007oo
Ool02goo00<007ooOol047oo00<007ooOol03Goo0P0000=oo`0000003Goo1P003Goo1000IGoo000@
Ool00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`09Ool2000?Ool01000
Ool000003goo10003Woo1`00MWoo000?Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Ool0000AOol2000@Ool6000<Ool4001jOol000moo`03001oogoo015o
o`03001oogoo01=oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019o
o`03001oogoo00ioo`03001oo`0000Uoo`03001oogoo00Ioo`80015oo`<000moo`@008eoo`003Woo
00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol03Woo
0P000Woo00<007ooOol03Woo0P0000=oo`00Ool047oo0P002Woo00<007ooOol01Goo10003goo1@00
3Goo0P00T7oo000>Ool00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0?Ool200000goo001o
o`0@Ool00`00Ool0000AOol4000AOol3000AOol40009Ool00`00Oomoo`04Ool3000@Ool4002QOol0
00]oo`800003Ool007oo011oo`<0019oo`<0019oo`<0019oo`80019oo`@0011oo`D000moo`<000]o
o`03001oogoo00Aoo`80011oo`800:Aoo`002goo0`004Woo10004Goo10004Goo100047oo100047oo
10004Goo0`004Goo0P0037oo00<007ooOol00goo00<007ooOol0]Woo000;Ool4000@Ool4000AOol4
000AOol4000AOol2000BOol3000AOol3000AOol00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomo
o`2gOol000]oo`@0011oo`<0019oo`<0019oo`<0015oo`8001=oo`80019oo`03001oogoo011oo`03
001oogoo00eoo`800;eoo`002Woo10004Goo0P004goo0P004goo0P004Woo00<007ooOol04Goo0P00
4Woo00<007ooOol08Goo00<007ooOol0_7oo000:Ool3000AOol2000COol2000COol2000BOol00`00
Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`21Ool4000gOol000Yoo`80019oo`03001oogoo019o
o`03001oogoo019oo`03001oogoo05ioo`03001oogoo07eoo`P003Moo`002Woo00<007ooOol0W7oo
00<007ooOol0K7oo0`004Goo2@00<goo002YOol00`00Oomoo`1YOol6000DOol00`00Oomoo`03Ool7
000/Ool001=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo019oo`03001oogoo019oo`03001oogoo019oo`8001=oo`8001=oo`8001Aoo`8001=oo`80
015ooaX0019oo`<002Uoo`004goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<0
07ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007oo00004Woo00<0
07ooOol04Woo00<007ooOol04Woo0P004Woo0`001goo0P001Goo1@001Woo1@00CGoo000BOol00`00
Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00
Oomoo`0BOol00`00Oomoo`0AOol01000Oomoo`004Goo00<007ooOol04Goo0P004goo0P004Goo0`00
1goo2P003Woo0P00CGoo000BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00
Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol01@00Oomoogoo000047oo
00<007ooOol04Goo00<007ooOol04Goo0P002goo0P000goo0`0027oo1`00HWoo000AOol00`00Oomo
o`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomo
o`0BOol00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomo
o`0@Ool2000<Ool6000:Ool8001ROol0015oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo
015oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo
00=oo`03001oogoo00aoo`03001oogoo011oo`8000ioo`05001oogooOol0000<Ool6001fOol0011o
o`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019o
o`03001oogoo015oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo011o
o`03001oogoo00eoo`800003Ool0000000aoo`L007Ioo`0047oo00<007ooOol04Woo00<007ooOol0
4goo00<007ooOol04Goo00<007ooOol04goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol0
4Goo00<007ooOol01Goo00<007ooOol02Goo0P003goo00@007oo000000moo`@000eoo`@007Yoo`00
3goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Goo00<007ooOol04goo00<007ooOol0
4Goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol01Woo00<007oo0000
4Goo0P0047oo1@00Rgoo000?Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Ool00009Ool20007
Ool2000AOol3000?Ool4002=Ool000ioo`03001oogoo019oo`03001oogoo01=oo`03001oogoo015o
o`03001oogoo01=oo`03001oogoo015oo`03001oogoo00ioo`800003Ool007oo011oo`8000Yoo`03
001oogoo00Eoo`<0011oo`D000eoo`80091oo`003Woo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol04Woo00<007ooOol03goo0P0000=oo`00Ool047oo00<007oo00004Goo0`004Goo0`002Woo
00<007ooOol017oo1@003Woo1000XGoo000>Ool00`00Oomoo`0?Ool200000goo001oo`0@Ool20000
0goo001oo`0@Ool3000BOol3000BOol2000AOol5000?Ool50009Ool00`00Oomoo`04Ool3000?Ool2
002TOol000]oo`<0019oo`<0019oo`<0019oo`<0019oo`@0011oo`@0011oo`<0015oo`<000]oo`03
001oogoo00=oo`8007Uoo`D003Uoo`002goo10004Goo10004Goo100047oo1@0047oo10004Goo0P00
4Goo0`004Goo0P003Goo00<007ooOol00Woo00<007ooOol0Ngoo1P00=Woo000;Ool4000AOol4000A
Ool4000@Ool3000BOol3000AOol2000BOol00`00Oomoo`0@Ool00`00Oomoo`0=Ool00`00Oomoo`21
Ool5000fOol000]oo`<0015oo`@0015oo`@0015oo`8001=oo`80019oo`03001oogoo011oo`03001o
ogoo025oo`03001oogoo089oo`H003Aoo`002Woo0`004Woo0`004Woo0`004Goo0P004goo0P004Woo
00<007ooOol0=Goo00<007ooOol0J7oo20004goo0P000goo0P00<Woo000:Ool2000COol2000COol2
000BOol00`00Oomoo`0BOol00`00Oomoo`19Ool00`00Oomoo`1ZOol7000COol00`00Oomoo`03Ool3
000_Ool000Yoo`03001oogoo019oo`03001oogoo019oo`03001oogoo079oo`03001oogoo06aoo`<0
009oo`D001Moo`8002eoo`00ZGoo00<007ooOol0EWoo100057oo00<007ooOol01Goo1@0057oo0`00
:Woo000COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00
Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol2000COol2000COol2000DOol2000BOolH000C
Ool3000DOol00`00Oomoo`0WOol001=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oo`00019o
o`03001oogoo019oo`03001oogoo015oo`<0011oo`@000Eoo`D0069oo`004Woo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04Goo00@007ooOol0015oo`03001oogoo015oo`80019oo`8000Uoo`8000=oo`D000ao
o`80069oo`004Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00@007ooOomoo`8000moo`03001oogoo
011oo`80015oo`<000Uoo`L007Eoo`004Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol04goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol047oo00<007ooOol02Woo0P000goo0P002Woo1`00Mgoo000A
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool2000AOol2000<
Ool6000;Ool8001gOol0015oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo011oo`03001oogoo00Aoo`03001o
ogoo00Yoo`03001oogoo00moo`8000eoo`D008aoo`0047oo00<007ooOol04Woo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol047oo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol03Goo0`003Woo1`00Rgoo000@Ool00`00Oomo
o`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`0AOol00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01000Oomoo`003goo10003Goo
1000Sgoo000@Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol0
0`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`05Ool3
000?Ool6001TOol2000iOol000moo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00ioo`8000Yoo`03001oogoo
00Aoo`@000ioo`@006Moo`@003Moo`003goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol0
4Woo00<007ooOol04Woo00<007ooOol03goo0`004Woo00<007oo00004Goo0P002Woo00<007ooOol0
0goo1P0037oo0P00Jgoo1@00=Goo000>Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0@
Ool00`00Ool0000AOol3000BOol3000BOol2000AOol40009Ool00`00Oomoo`03Ool4001SOol3000F
Ool5000dOol000aoo`<0019oo`<0019oo`<0019oo`80019oo`<0015oo`D0011oo`@000moo`<000]o
o`03001oogoo009oo`8006Moo`D001Aoo`@003Aoo`0037oo0`004Woo10004Goo10004Goo0`0047oo
1@0047oo0`004Woo0P0047oo0P003Goo00D007ooOomoo`0006Yoo`D001Aoo`04001oogoo000cOol0
00aoo`@0015oo`@0011oo`@0015oo`@0011oo`<0015oo`<0019oo`80011oo`03001oogoo00eoo`03
001oogoo06eoo`D001Moo`80035oo`0037oo10004Goo0`004Goo0`004Woo0`004Goo0P004Woo0P00
4goo00<007ooOol07goo00<007ooOol0KWoo0P000Woo0P005goo00<007ooOol0;Woo000;Ool4000A
Ool3000BOol2000COol2000AOol2000COol00`00Oomoo`0AOol00`00Oomoo`0POol2001DOol8000D
Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`0]Ool000]oo`<0019oo`<0015oo`8001=o
o`80019oo`03001oogoo015oo`03001oogoo03Eoo`03001oogoo05Eoo`H001Yoo`8001Ioo`03001o
ogoo02aoo`002goo0P004goo0P004Woo00<007ooOol04Woo00<007ooOol0GGoo00<007ooOol0Egoo
1`006Goo0P005Goo0P00;7oo000;Ool00`00Oomoo`0BOol00`00Oomoo`26Ool00`00Oomoo`12Ool2
000EOol00`00Oomoo`02Ool4000GOol2000EOol00`00Oomoo`0YOol00:Uoo`03001oogoo03moo`D0
01ioo`@001Eoo`8001Aoo`03001oogoo02Qoo`004goo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo0P00
4goo0P004goo0P004goo60004goo0P005Goo00<007ooOol04Woo00<007ooOol09goo000COol00`00
Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Ool0000BOol00`00Oomoo`0AOol2000AOol40006Ool3001h
Ool0019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo019oo`03001oogoo015oo`04001oogoo000AOol00`00Oomoo`0@Ool20009
Ool20003Ool50025Ool0019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`05001oogooOol0000?Ool2
000AOol20009Ool7002:Ool0019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo009oo`03
001oogoo00aoo`03001oogoo00ioo`<000Uoo`L005Eoo`8003Eoo`004Goo00<007ooOol04Woo00<0
07ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<0
07ooOol04Goo00<007ooOol00goo00<007ooOol02goo00<007ooOol02Woo0P0000=oo`0000002goo
2000EGoo0`00=7oo000AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomo
o`09Ool2000<Ool4001COol2000FOol4000bOol0015oo`03001oogoo015oo`03001oogoo01=oo`03
001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo011oo`03
001oogoo00Eoo`03001oogoo00Eoo`04001oogoo000=Ool5001COol3000EOol5000aOol0011oo`03
001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo015oo`@000Ioo`8000Eoo`@000Moo`03001oogoo00Eoo`03001oo`0000eoo`L005=oo`<0
01Eoo`D0031oo`0047oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol04Goo00<007ooOol04Goo0P000goo00<007ooOol00goo0P0017oo00<007oo0000
0Woo00<007ooOol017oo00<007ooOol017oo0`003Goo1000?Woo0P005goo100057oo0`00<Woo000@
Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0:Ool700000goo001oo`02Ool00`00Oomoo`09Ool20003Ool00`00Oomoo`04Ool3
0003Ool5001>Ool4000FOol4000DOol2000bOol000moo`03001oogoo019oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo019oo`03001oogoo00ioo`800003Ool007oo011oo`80009oo`05001o
ogooOol0000:Ool40002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool3001AOol5000DOol4000FOol0
0`00Oomoo`0_Ool000moo`03001oogoo015oo`03001oogoo01=oo`03001oogoo00moo`800003Ool0
07oo011oo`<0015oo`<0015oo`@00003Ool007oo009oo`03001oogoo00Moo`L000Moo`03001oogoo
009oo`8005Aoo`D001Aoo`04001oogoo000FOol00`00Oomoo`0^Ool000aoo`@0015oo`<0019oo`<0
019oo`<0019oo`@0011oo`@0011oo`8000=oo`05001oogooOol00009Ool200000goo001oo`09Ool0
1@00Oomoogoo0000Egoo100067oo00<007ooOol057oo00<007ooOol0;Goo000<Ool5000@Ool4000A
Ool4000AOol4000@Ool4000@Ool4000@Ool20004Ool01@00Oomoogoo000027oo00D007ooOomoo`00
00Yoo`03001oogoo03ioo`D001Moo`03001oogoo008001Moo`03001oogoo01=oo`03001oogoo02eo
o`0037oo1@0047oo10004Goo10004Goo100047oo0`004Goo0`004Goo00<007ooOol017oo0`0027oo
00<007ooOol00Woo10001goo00<007ooOol0@7oo1P006Goo00<007ooOol05Goo00<007ooOol04goo
00<007ooOol0;7oo000<Ool4000AOol3000BOol3000AOol4000AOol2000BOol2000AOol00`00Oomo
o`0POol00`00Oomoo`11Ool5000JOol2000FOol00`00Oomoo`0COol00`00Oomoo`0[Ool000aoo`<0
015oo`<0019oo`<0019oo`<0015oo`80019oo`8003Eoo`03001oogoo04=oo`800004Ool00000000I
Ool00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0ZOol000aoo`<0015oo`<0019oo`8001=o
o`80019oo`03001oogoo015oo`03001oogoo03Aoo`03001oogoo04Aoo`03001oogoo009oo`<001Mo
o`03001oogoo01Aoo`03001oogoo019oo`03001oogoo02Yoo`0037oo0P004Woo0P004goo00<007oo
Ool04Woo00<007ooOol0G7oo00<007ooOol0;7oo0`007Goo0`005Goo0P005Goo00<007ooOol04Woo
00<007ooOol0:Goo000<Ool00`00Oomoo`0AOol00`00Oomoo`26Ool00`00Oomoo`0YOol6000POol3
000DOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0XOol001=oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo019oo`8001=oo`8001=ooaP001Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo
019oo`03001oogoo02Moo`004goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<0
07ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007oo00004Woo00<0
07ooOol047oo0`0017oo1@00SGoo000COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol01000Oomoo`00
47oo0P0047oo0`002Woo0P00A7oo00<007ooOol057oo00<007ooOol0;goo000BOol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0B
Ool00`00Oomoo`0AOol01@00Oomoogoo00003goo00<007ooOol027oo0P000goo0`00Dgoo00<007oo
Ool057oo00<007ooOol0;goo000BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`02Ool2
000<Ool2000:Ool6000oOol2000EOol2000EOol2000`Ool0019oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo015oo`03001oogoo019oo`03001oogoo
011oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Qoo`H0045oo`<001Eoo`8001Aoo`<0
02moo`004Goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol04Woo00<007ooOol04Goo00<007ooOol047oo00<007ooOol017oo00<007ooOol027oo0P00
2Woo1`00:7oo0P0067oo0`0057oo0`0057oo0`00;Woo000AOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0@
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Ool0000;Ool4000/Ool3000GOol4000COol4000C
Ool4000]Ool0015oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019o
o`03001oogoo015oo`03001oogoo015oo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Ao
o`<003eoo`@001Eoo`D001=oo`@0019oo`8002moo`004Goo00<007ooOol04Goo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol047oo00<007ooOol03Woo
00<007oo00002Goo00<007ooOol00goo1000?Goo1@005Goo0P005Goo0P005Woo00<007ooOol0;7oo
000@Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`0AOol00`00Oomoo`0AOol00`00Oomoo`0>Ool2000:Ool00`00Oomoo`02Ool6000mOol5000DOol0
0`00Ool0000FOol00`00Oomoo`0COol00`00Oomoo`0/Ool0011oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00ioo`<0011oo`<0
00Yoo`04001oogooOol40010Ool4000GOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0[
Ool0011oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo00moo`<0015oo`<000moo`D000Uoo`03001oogoo008002Qoo`@001Qoo`04001oogoo000GOol0
0`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0[Ool000moo`03001oogoo019oo`03001oogoo
011oo`<0019oo`<0015oo`<0019oo`<0011oo`D000ioo`<000]oo`03001oogoo02aoo`D001Uoo`03
001oogoo01Eoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo02]oo`003Goo0`004Woo0`00
4Woo10004Goo100047oo100047oo1@003goo0`003goo0P003Goo00<007ooOol0;Goo10006Woo00<0
07ooOol057oo00<007ooOol057oo00<007ooOol04goo00<007ooOol0:Woo000=Ool4000AOol4000A
Ool4000AOol4000@Ool4000@Ool3000@Ool3000?Ool00`00Oomoo`0=Ool00`00Oomoo`0^Ool4000J
Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0BOol00`00Oomoo`0ZOol000eoo`@0015o
o`@0015oo`<0019oo`<0015oo`<0015oo`80015oo`03001oogoo01moo`03001oogoo02moo`03001o
ogoo00<001Qoo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo02Uoo`00
3Goo0`004Woo0`004Goo0`004Woo0`004Goo0`004Goo0P004Goo00<007ooOol087oo00<007ooOol0
=Goo0P005goo00<007ooOol04goo00<007ooOol057oo00<007ooOol04Woo00<007ooOol0:Goo000=
Ool3000BOol2000BOol3000BOol3000AOol2000BOol00`00Oomoo`0cOol00`00Oomoo`0gOol2000F
Ool00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0XOol000eoo`8001=o
o`80019oo`8001=oo`80019oo`03001oogoo04Moo`8003Yoo`8001Eoo`03001oogoo019oo`03001o
ogoo01Aoo`03001oogoo019oo`03001oogoo02Qoo`003Goo0P004goo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol0Fgoo00<007ooOol05Woo10008Goo0P0057oo00<007ooOol04Woo00<007oo
Ool04goo00<007ooOol04Woo00<007ooOol0:7oo000=Ool00`00Oomoo`03Ool00`00Oomoo`0BOol0
0`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0COol00`00Oomoo`0AOolG000EOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`0BOol00`00Oomoo`0WOol001=oo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`80
015oo`8000Aoo`D004Qoo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo02Yoo`004goo00<0
07ooOol04Woo00<007ooOol04goo00<007ooOol04Goo00<007ooOol04goo00<007ooOol04Woo00<0
07ooOol04Woo00<007ooOol04Woo00<007oo00003goo0P002Goo0P00<Goo00<007ooOol057oo00<0
07ooOol057oo00<007ooOol04goo00<007ooOol0:Woo000BOol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0B
Ool01000Oomoo`003Goo0P009Woo00<007ooOol05Goo00<007ooOol057oo0P005Goo0P0057oo0P00
:goo000BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol01@00Oomoogoo00002goo0P00:7oo0P005Woo
0P005Goo0P005Goo0P0057oo0P00:goo000BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomo
o`0AOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomo
o`02Ool00`00Oomoo`08Ool00`00Oomoo`0YOol2000EOol3000DOol3000COol3000COol3000[Ool0
019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo
015oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00=oo`03001oogoo00=oo`800003Ool0
000002aoo`<001Eoo`<001=oo`<001=oo`@0019oo`@002Yoo`004Goo00<007ooOol04Woo00<007oo
Ool04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool047oo00<007ooOol017oo00<007ooOol00Woo10004Woo0P006Woo100057oo10004Woo10004Woo
10004Woo1000:Woo000AOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomo
o`0COol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`05Ool01000Oomo
ogoo1@004Woo10006Goo10004goo0P0057oo0`004goo0`004goo0`00:goo000AOol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0@
Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`07000BOol5000GOol2000FOol00`00Oomo
o`0DOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0YOol0015oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03
001oogoo00eoo`03001oo`0000Uoo`03001oo`0000<001Moo`D001Moo`03001oogoo01Eoo`03001o
ogoo01=oo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo02Uoo`0047oo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Goo00<007ooOol04goo00<007ooOol04Goo00<007ooOol047oo
00<007ooOol03Woo0P002Woo00<007ooOol06Woo1@0067oo00<007ooOol057oo00<007ooOol04goo
00<007ooOol057oo00<007ooOol04Woo00<007ooOol0:Goo000@Ool00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0?Ool2000@Ool4
0009Ool00`00Oomoo`0KOol3000IOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol0
0`00Oomoo`0COol00`00Oomoo`0XOol0011oo`03001oogoo019oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo00moo`800003Ool007oo011oo`<0015oo`8000moo`<000]oo`8001eoo`03001o
o`0001Uoo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo01=oo`03001o
ogoo02Qoo`003Woo0`004Woo0`004Woo0`004Woo0`004Goo10004Goo10003goo10003Woo0P0037oo
00<007ooOol07goo00<007ooOol05goo00<007ooOol04goo00<007ooOol04goo00<007ooOol04goo
00<007ooOol04goo00<007ooOol0:7oo000>Ool5000@Ool4000AOol4000AOol4000@Ool5000@Ool4
000?Ool2000?Ool00`00Oomoo`0<Ool00`00Oomoo`0POol00`00Oomoo`0FOol00`00Oomoo`0COol0
0`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0BOol00`00Oomoo`0XOol000ioo`D0011oo`@0
015oo`@0015oo`@0011oo`D000moo`@000moo`8000moo`03001oogoo00eoo`03001oogoo025oo`03
001oogoo01Ioo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01Aoo`03001oogoo019oo`03
001oogoo02Qoo`003Woo10004Goo0`004Woo0`004Woo0`004Goo100047oo0`0047oo00<007ooOol0
7Woo00<007ooOol08Woo00<007ooOol05Goo00<007ooOol04goo00<007ooOol04goo00<007ooOol0
4goo00<007ooOol04Woo00<007ooOol0:7oo000>Ool3000BOol3000BOol3000AOol3000BOol3000A
Ool2000@Ool00`00Oomoo`0OOol00`00Oomoo`0SOol00`00Oomoo`0EOol00`00Oomoo`0BOol00`00
Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0XOol000ioo`<0019oo`8001=o
o`80019oo`<0019oo`80015oo`8003=oo`03001oogoo02Aoo`03001oogoo01Aoo`03001oogoo01=o
o`03001oogoo019oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo02Moo`003Woo0P004goo
0P004goo0P004Woo0P004goo00<007ooOol047oo00<007ooOol0<Woo00<007ooOol00Woo0P008Goo
00<007ooOol057oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol057oo00<007ooOol04Woo
00<007ooOol09goo000>Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`1JOol00`00Ool00004000ROol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00
Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0WOol001=oo`03001oogoo019oo`03001oogoo01=o
o`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019o
oaL001Aoo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo02Moo`004goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007oo00000goo
0`003Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007oo
Ool04goo00<007ooOol04Woo00<007ooOol09goo000COol00`00Oomoo`0BOol00`00Oomoo`0COol0
0`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol0
1000Oomoo`004goo0`004goo0P004goo0P004goo0`004goo0P004goo0P004goo0`00:7oo000COol0
0`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0@Ool01@00Oomoogoo00004goo0`004goo0P004goo0P004goo0`00
4goo0P004goo0P004goo0`00:7oo000BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`02
Ool00`00Oomoo`0AOol3000BOol3000COol3000BOol3000BOol3000COol3000BOol3000XOol0019o
o`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo015o
o`03001oogoo019oo`03001oogoo00moo`03001oogoo00=oo`03001oogoo011oo`D0015oo`@0015o
o`@0015oo`D0015oo`@0015oo`@0015oo`D002Moo`004Woo00<007ooOol04Woo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol03goo
00<007ooOol017oo0P004Goo1@004Goo10004Goo10004Goo1@004Goo10004Goo10004Goo1@009goo
000BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`0BOol00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomo
o`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomo
o`0BOol00`00Oomoo`0WOol0019oo`03001oogoo00D000eoo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo00=oo`<000Ioo`8000Aoo`D000moo`03001oogoo015oo`03001oogoo00ioo`03001o
ogoo00Ioo`03001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`<000Ioo`8000Eoo`@00003
Ool007oo01=oo`03001oogoo01=oo`03001oogoo011oo`D002Moo`004Woo00<007ooOol00Woo00<0
07ooOol03Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol00goo00D007ooOomoo`0000Eo
o`8000Aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo015oo`03001oogoo00]oo`03001o
o`0000Uoo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`80009oo`03001oogoo00=o
o`8000Uoo`8001Aoo`03001oogoo01=oo`03001oogoo019oo`03001oogoo02Moo`0037oo1`0017oo
00<007ooOol03Goo00<007ooOol04Woo00<007ooOol047oo1P000Woo00D007ooOomoo`0000Yoo`03
001oogoo00=oo`03001oogoo00aoo`03001oogoo011oo`03001oogoo00aoo`8000Yoo`03001oogoo
019oo`03001oogoo019oo`03001oogoo019oo`80009oo`03001oogoo00ioo`8001Aoo`03001oogoo
01=oo`03001oogoo019oo`03001oogoo02Moo`004Goo00<007ooOol00goo00<007ooOol037oo00<0
07ooOol04goo00<007ooOol04Woo00<007ooOol00goo00D007ooOomoo`0000Yoo`03001oogoo00=o
o`03001oogoo00]oo`03001oogoo015oo`03001oogoo00]oo`@000Uoo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo019oo`80009oo`03001oogoo00ioo`8001Aoo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo02Moo`004Goo00<007ooOol00goo00<007ooOol037oo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol00goo00D007ooOomoo`0000Yoo`03001oo`0000<000ioo`03001o
ogoo00ioo`800003Ool007oo00]oo`<000]oo`03001oogoo019oo`03001oogoo019oo`03001oogoo
019oo`80009oo`03001oogoo00Yoo`@00003Ool007oo01=oo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo02Moo`004Goo00<007ooOol00goo00<007ooOol037oo00<007ooOol04goo00<007oo
Ool04Woo00<007ooOol00goo00D007ooOomoo`0000Uoo`04001oogoo000?Ool3000@Ool3000=Ool2
000<Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol20002Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0WOol0
011oo`<000Aoo`03001oogoo00]oo`<0019oo`<0019oo`<000Eoo`05001oogooOol00007Ool6000?
Ool4000?Ool4000;Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool20002Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00
Oomoo`0BOol00`00Oomoo`0WOol0011oo`@00004Ool00000000=Ool4000AOol4000AOol40005Ool3
0008Ool9000<Ool4000?Ool4000:Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0COol3000=Ool400000goo001oo`0COol00`00Oomoo`0COol00`00Oomoo`0@Ool3000Y
Ool0011oo`@0015oo`@0015oo`@0015oo`@0011oo`@0015oo`<000moo`@001]oo`03001oogoo019o
o`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo01=o
o`03001oogoo019oo`03001oogoo02Moo`0047oo0`004Woo0`004Woo0`004Woo0`004Goo100047oo
0`0047oo0`0077oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol09goo000@Ool3000BOol3
000BOol3000BOol3000AOol3000AOol3000@Ool2000MOol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol0
0`00Oomoo`0JOol20002Ool20007Ool0011oo`8001=oo`8001=oo`8001=oo`80019oo`80019oo`80
015oo`03001oogoo01aoo`03001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo
019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01]oo`04001oogoo
0008Ool0011oo`8001=oo`8001=oo`8001=oo`80019oo`80019oo`03001oogoo02moo`03001oogoo
019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo
01=oo`03001oogoo019oo`03001oogoo01aoo`8000Uoo`000Wooo`00D00037oo0P002Goo0004Ool0
0`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool0
0`00Ool0000>Ool01@00Oomoogoo00002Woo00<007ooOol027oo00D007ooOomoo`0000ioo`03001o
o`0000aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00aoo`03001o
ogoo00]oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo00Uoo`04001oogoo000>Ool01000Oomoo`002goo00<007ooOol037oo00@007ooOol000Qoo`00
4goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol06goo00<007ooOol0
47oo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol04Goo0P004goo0P00
4Goo00@007oo000001Uoo`80009oo`8000Moo`004goo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol06goo00<007ooOol03goo0P004Woo0P004Woo0P004goo0P004goo0P004goo0P009Woo000C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0JOol2000@Ool3000BOol2000BOol2000B
Ool3000BOol3000BOol4000UOol001=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01Uo
o`<0011oo`80019oo`<0015oo`@0015oo`<0019oo`<0019oo`@002Eoo`004goo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol02goo0P0037oo0P0047oo0`004Woo0`004Goo10004Goo0`004Woo
0`004Woo10009Goo000COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomo
o`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0:Ool3000;Ool3
000?Ool4000AOol4000@Ool5000@Ool4000AOol4000AOol5000UOol001=oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo00Qoo`@000]oo`@0015oo`80019oo`03001oo`00019oo`<0019oo`03
001oogoo019oo`03001oogoo019oo`03001oogoo02Eoo`004goo00<007ooOol04Woo00<007ooOol0
4goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0
4goo00<007ooOol01goo10003Goo00<007oo000047oo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol09Goo000COol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`06Ool5000=Ool00`00Oomoo`0@Ool00`00Oomoo`0BOol00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0UOol001=o
o`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo019oo`03001oogoo01=oo`03001oogoo00Moo`<000eoo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo02Eoo`004goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol01goo0P003Woo00<007oo
Ool047oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007oo
Ool04Woo00<007ooOol09Woo000COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol0
0`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`06Ool0
0`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0VOol001=oo`03001oogoo019oo`03001oogoo
01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo
01=oo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo015oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo02Ioo`004Goo1@00
4Goo10004Goo10004Goo1@004Goo10004Goo10004Woo10004goo0P001Goo00<007ooOol03Woo00<0
07ooOol04Goo00<007ooOol04goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol04Woo00<007ooOol09Woo000AOol5000AOol4000AOol4000AOol5000AOol4000AOol4000B
Ool4000COol00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`0AOol00`00Oomoo`0COol00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0VOol0015o
o`D0015oo`@0015oo`@0015oo`D0015oo`@0015oo`@0019oo`@001=oo`03001oogoo009oo`03001o
ogoo00moo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo01=oo`03001oogoo019oo`03001oogoo02Ioo`004Woo0`004Woo0`004goo0`004Woo0`004goo
0`004Woo0`004Woo0`0057oo00D007ooOomoo`00019oo`03001oogoo015oo`03001oogoo01=oo`03
001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo02Ioo`00
4Woo0`004goo0P004goo0P004goo0`004goo0P004goo0P0057oo0P0057oo00@007ooOol001=oo`03
001oogoo015oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo02Moo`004Woo0`004goo0P004goo0P004goo0`004goo0P004goo0P00
57oo0P003Goo0`0017oo00<007oo00004goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0
4Goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol09goo000COol00`00
Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00
Oomoo`0BOol00`00Oomoo`0<Ool600000goo0000000DOol00`00Oomoo`0AOol00`00Oomoo`0COol0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0WOol0
01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo
019oo`03001oogoo019ooaL001Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03
001oogoo009oo`03001oogoo029oo`004goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0
4Woo00<007ooOol04goo00<007ooOol04goo00<007ooOol087oo10000goo00<007ooOol0AGoo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol08Woo000C
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0C
Ool00`00Oomoo`0VOol00`00Oomoo`0aOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0@
Ool2000COol2000COol2000TOol001=oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo02Eoo`03001oogoo01ioo`03001oogoo00mo
o`80019oo`80019oo`80019oo`8001=oo`8001=oo`8002Aoo`0057oo00<007ooOol04Woo00<007oo
Ool04goo00<007ooOol04Woo00<007ooOol057oo00<007ooOol057oo00<007ooOol097oo00<007oo
Ool07Goo0P0047oo0`004Goo0`004Goo0`004Goo0`004Woo0`004Woo0`0097oo000DOol00`00Oomo
o`0BOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomo
o`0SOol00`00Oomoo`0LOol2000@Ool3000BOol2000AOol3000BOol3000BOol3000BOol3000TOol0
01Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo
01Eoo`03001oogoo029oo`03001oogoo00]oo`8000ioo`<000moo`@0015oo`<0011oo`@0015oo`@0
015oo`@0015oo`@002Aoo`0057oo00<007ooOol04goo00<007ooOol04goo00<007ooOol04Woo00<0
07ooOol057oo00<007ooOol05Woo00<007ooOol08Goo00<007ooOol02Goo10003Goo0`003goo1@00
47oo10004Woo0P004Woo00<007oo00004Woo00<007oo00004Woo00<007oo000097oo000DOol00`00
Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0FOol00`00
Oomoo`0POol20008Ool5000=Ool4000AOol2000BOol00`00Ool0000BOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0TOol001Eoo`03001oogoo019oo`03001oogoo01=o
o`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo01Moo`03001oo`0001moo`03001oogoo00Io
o`D000moo`<0015oo`80019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo02Aoo`005Goo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04goo
00<007ooOol05Goo00<007ooOol05goo0P007goo00<007ooOol01Woo1@003goo0P004Goo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04goo00<007ooOol04Woo00<007oo
Ool097oo000EOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0DOol0
0`00Oomoo`0FOol4000JOol20002Ool00`00Oomoo`07Ool3000?Ool00`00Oomoo`0AOol00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`0UOol001Eoo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo01Aoo`04
001oo`00000GOol3000FOol40003Ool00`00Oomoo`06Ool00`00Ool0000?Ool00`00Oomoo`0AOol0
0`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0UOol001Eoo`03001oogoo01=oo`03001oogoo01=oo`<001=oo`<001Aoo`@001Qoo`80
01Aoo`D000Aoo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo011oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo015oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo02Eoo`00
57oo10004Woo10004Woo10004Woo100057oo10006Woo00<007ooOol047oo1@001Goo00<007ooOol0
17oo00<007ooOol047oo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol09Goo000DOol4000BOol4000BOol4000B
Ool4000EOol3000KOol00`00Oomoo`0=Ool20002Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`0@
Ool00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0UOol001Eoo`<001=oo`<001=oo`<001=oo`<001Ioo`<002Uo
o`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo015oo`03001oogoo015o
o`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019o
o`03001oogoo02Ioo`005Goo0`004goo0`004goo0`0057oo0`005Goo0`009goo0P003Goo00D007oo
Oomoo`0001=oo`03001oogoo015oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo015oo`03
001oogoo01=oo`03001oogoo019oo`03001oogoo02Ioo`005Woo0P0057oo0P0057oo0P0057oo0`00
5Woo0P009Goo0P003goo00@007ooOol001=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo02Ioo`005Woo0P00
57oo0P0057oo0P005Goo0P005goo00<007ooOol067oo0`001Woo0P004Goo00<007oo000057oo00<0
07ooOol04Goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<0
07ooOol04Woo00<007ooOol09Woo000FOol2000EOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00
Oomoo`0`Ool600000goo0000000COol2000DOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomo
o`0BOol00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0WOol001=oo`05
001oogooOol0000@Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol2000COolF000E
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0WOol001=oo`03001oogoo019oo`03001o
ogoo01=oo`03001oogoo01=oo`03001oogoo01Aoo`80021oo`D001Moo`03001oogoo06moo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo025oo`0057oo00<007ooOol04Woo00<007ooOol04goo
00<007ooOol04goo00<007ooOol05Goo0P007Woo0P006Woo0P00Agoo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol08Goo000DOol00`00Oomoo`0BOol0
0`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0FOol2000hOol00`00Oomoo`0bOol00`00Oomo
o`0AOol00`00Oomoo`0AOol00`00Oomoo`0AOol2000BOol2000COol2000SOol001Aoo`03001oogoo
01=oo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo01Moo`<003Eoo`03001oogoo01ioo`80
015oo`80019oo`80019oo`80019oo`<0019oo`8001=oo`8002=oo`005Goo00<007ooOol04Woo00<0
07ooOol057oo00<007ooOol057oo00<007ooOol06Goo1000<Goo00<007ooOol07Goo0`0047oo0`00
4Goo0`004Goo0`004Woo0P004Woo0`004Woo0`008goo000EOol00`00Oomoo`0COol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0JOol3000`Ool00`00Oomoo`0;Ool2000?Ool3000@Ool3000A
Ool3000AOol3000BOol3000BOol3000BOol3000SOol001Ioo`03001oogoo019oo`03001oogoo01Ao
o`03001oogoo01Eoo`03001oogoo01Qoo`H002ioo`03001oogoo00Yoo`<000ioo`@000moo`@0011o
o`@0011oo`@0015oo`@0015oo`@0015oo`@002=oo`005Woo00<007ooOol04goo00<007ooOol057oo
00<007ooOol05Goo00<007ooOol05goo1`00;Goo00<007ooOol027oo10003Woo10003goo1@004Goo
0`004Woo0P004Woo00<007oo00004Woo00<007oo00004Woo00<007oo00008goo000FOol00`00Oomo
o`0COol00`00Oomoo`0EOol00`00Oomoo`0EOol01000Ool000006Woo0`009goo0P000goo00<007oo
Ool01goo10003Woo1@004Goo0P004Woo00<007oo00004Goo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol08goo000GOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomo
o`0FOol30011Ool50003Ool00`00Oomoo`06Ool5000@Ool3000@Ool00`00Ool0000AOol00`00Oomo
o`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0TOol001Moo`03
001oogoo01Aoo`03001oogoo01Aoo`03001oo`0001Aoo`D003ioo`H000Aoo`03001oogoo00Moo`<0
011oo`03001oo`00011oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo019oo`03001oogoo02Aoo`0067oo00<007ooOol04goo0`005Goo0P005Woo0`00
?Goo1P001Goo00<007ooOol01Woo00<007oo000047oo00<007ooOol04Goo00<007ooOol04Goo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol097oo000H
Ool3000COol3000DOol4000FOol3000lOol50006Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0COol00`00
Oomoo`0BOol00`00Oomoo`0TOol001Moo`@0019oo`@001Eoo`<001Qoo`03001oogoo02]oo`@000Yo
o`03001oo`00008000Moo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo
02Eoo`005goo10004goo10005Goo0`0067oo00<007ooOol09Woo1P002Woo0P000goo00<007ooOol0
1Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol09Goo000HOol3000D
Ool3000FOol20011Ool5000:Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00
Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00
Oomoo`0BOol00`00Oomoo`0UOol001Uoo`<001Aoo`8001Moo`03001oogoo03aoo`<00003Ool00000
00Yoo`8000moo`80009oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo02Ioo`006Goo0`00
5Goo0P005goo00<007ooOol0>7oo0`0017oo00<007ooOol027oo00<007ooOol03goo00@007ooOol0
01Aoo`03001oogoo015oo`03001oogoo01=oo`03001oogoo015oo`03001oogoo019oo`03001oogoo
01=oo`03001oogoo019oo`03001oogoo02Ioo`006Woo0P005Woo00<007ooOol0CGoo0`0047oo0P00
4Woo00<007oo000057oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol09Woo000KOol00`00Oomoo`1IOol50003
Ool3000BOol00`00Oomoo`0BOol2000DOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0WOol001=oo`03001o
ogoo019oo`8001Aoo`8001=oo`8001AooaH001Aoo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo02Moo`004goo00<007ooOol057oo00<007ooOol04goo00<007ooOol04Woo
0`007goo1@00;Goo00<007ooOol0_7oo000DOol00`00Oomoo`0DOol00`00Oomoo`0COol2000EOol3
000LOol2000`Ool00`00Oomoo`1LOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol0
0`00Oomoo`0POol001Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`<000Aoo`80
04Eoo`03001oogoo04Moo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo
015oo`03001oogoo021oo`005Woo00<007ooOol057oo00<007ooOol057oo0P0067oo0`0000Aoo`00
000004Aoo`03001oogoo039oo`80019oo`8001=oo`80019oo`8001=oo`80019oo`80029oo`005Woo
00<007ooOol05Goo00<007ooOol05Goo00<007ooOol067oo1@00@goo00<007ooOol07Woo0P004Goo
0`004Goo0`004Woo0P004Woo0`004Woo0`004Goo0`008Woo000GOol00`00Oomoo`0EOol00`00Oomo
o`0EOol2000HOol60012Ool00`00Oomoo`0;Ool2000@Ool3000@Ool3000AOol3000BOol3000BOol2
000BOol3000BOol3000ROol001Qoo`03001oogoo01Eoo`03001oogoo01Ioo`03001oo`0001Uoo`<0
045oo`03001oogoo00Yoo`<000moo`<0011oo`@0011oo`@0015oo`@0015oo`<0015oo`@0015oo`@0
029oo`006Goo00<007ooOol05Goo00<007ooOol05Woo0`00@Goo0`001Woo0P001Goo10001goo00<0
07ooOol027oo10003goo10003goo1@003goo1@0047oo10004Goo10004goo0P004Woo00<007oo0000
8Woo000JOol00`00Oomoo`0EOol00`00Ool0000EOol4000oOol01@00Oomoogoo00001Goo0P002Goo
0`0017oo00<007ooOol01goo10003goo10004Woo0P004Woo0P004goo0P004Woo00<007oo00004Woo
00<007oo00004Woo00<007ooOol08Woo000JOol00`00Oomoo`0FOol2000DOol6000nOol01@00Oomo
ogoo00003Woo1@0017oo00<007ooOol01Woo1@0047oo0`004Goo00<007oo00004Woo0P004Woo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol08goo000KOol00`00Ool0000E
Ool3000FOol4000mOol01@00Oomoogoo000037oo1P001Goo0`001goo0`004Goo0P004Woo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04goo00<007ooOol04Goo00<007oo
Ool08goo000LOol2000DOol5000HOol2000lOol00`00Ool00002000<Ool50006Ool00`00Oomoo`07
Ool2000AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00
Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0SOol001]oo`@001Eoo`<005Eoo`H000aoo`@000Mo
o`03001oogoo00Ioo`03001oogoo011oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019o
o`03001oogoo015oo`03001oogoo01=oo`03001oogoo015oo`03001oogoo02Aoo`007Goo0P005goo
0P00DWoo1P0000=oo`00Ool02Woo0P0000=oo`00Ool01goo00<007ooOol01Goo00<007ooOol047oo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol097oo000NOol2000HOol00`00Oomoo`1?Ool7000:Ool200000goo
000000020007Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0TOol0
01moo`03001oogoo05Aoo`P000Yoo`800004Ool00000000<Ool00`00Oomoo`0<Ool00`00Oomoo`03
Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0UOol0021oo`03001oogoo05=oo`H000]o
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo009oo`03001oogoo015o
o`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo015oo`03001oogoo01=o
o`03001oogoo019oo`03001oogoo02Eoo`00MGoo1P002Woo0P004Goo00<007ooOol03Woo00D007oo
Oomoo`0001=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo019oo`03001oogoo02Eoo`00LGoo10000Woo0P002Woo0P004Goo0P00
4Goo00@007ooOol001Aoo`03001oogoo015oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo
019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo02Ioo`00HWoo0`002Goo0`001Woo00<0
07ooOol01goo0P004Woo00<007ooOol04Goo00<007oo000057oo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol0
9Woo001ROol60003Ool3000AOol2000COol00`00Oomoo`0BOol2000DOol00`00Oomoo`0BOol00`00
Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00
Oomoo`0VOol001=oo`8001=oo`8001Aoo`<0019ooaP001=oo`03001oogoo019oo`03001oogoo01=o
o`03001oogoo019oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo019oo`03001oogoo02Moo`005Goo00<007ooOol04Woo0P005Goo
10007Goo1000@goo00<007ooOol0VWoo00<007ooOol07goo000FOol2000DOol3000FOol50002Ool2
001KOol00`00Oomoo`1LOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0OOol001Qoo`03001oogoo01Aoo`8001Uoo`L005Qoo`03001oogoo04Qoo`03001oogoo015oo`03
001oogoo015oo`8001=oo`80019oo`80025oo`006Goo00<007ooOol05Goo0P006Goo1`00EWoo0P00
=7oo0P004Woo0P004Woo0P004Woo0`004Woo0P004Woo0`008Goo000JOol2000GOol200000goo0000
000DOol8001EOol00`00Oomoo`0OOol2000AOol3000AOol2000BOol3000AOol3000BOol3000BOol2
000ROol001aoo`03001oogoo01Ioo`@0071oo`03001oogoo00]oo`80015oo`<000moo`@0015oo`<0
015oo`<0015oo`@0015oo`@0015oo`<0029oo`007Goo0P0000=oo`00Ool04goo1P00KWoo00<007oo
Ool02Goo10003goo10003goo1@0047oo100047oo100047oo1@0047oo10004Goo10008Woo000OOol2
000DOol7001WOol20004Ool00`00Oomoo`07Ool5000?Ool5000>Ool5000@Ool4000BOol3000BOol2
000COol2000BOol00`00Ool0000ROol001moo`<001Qoo`<006=oo`D000Aoo`03001oogoo00Ioo`D0
00moo`D0015oo`<0019oo`80019oo`03001oo`00019oo`8001=oo`03001oogoo015oo`03001oogoo
029oo`007Woo1@00K7oo0P003Goo1P001Goo00<007ooOol01Woo1@004Goo0`004Goo0P004Woo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol08Woo000Q
Ool3001XOol4000>Ool50006Ool00`00Oomoo`07Ool3000AOol00`00Ool0000AOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0S
Ool002Aoo`03001oogoo06=oo`D000moo`@000Moo`03001oogoo00Ioo`03001oo`00015oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019oo`03001o
ogoo019oo`03001oogoo02=oo`00NGoo10003Goo10003goo00@007ooOol000Qoo`03001oogoo00Eo
o`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo015oo`03001oogoo02Aoo`00MGoo1P003Woo00@007oo000000io
o`8000aoo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo015oo`03001oogoo02Aoo`00MGoo
1@003Goo0P000Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol00goo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol097oo001QOol5000>Ool5000<Ool2000BOol00`00Oomoo`0=Ool0
0`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0UOol0065oo`P000Qoo`<0
00=oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00ioo`05001oogooOol0000DOol00`00
Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00
Oomoo`0BOol00`00Oomoo`0UOol0061oo`L000Qoo`80015oo`80019oo`80015oo`04001oogoo000D
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0AOol00`00Oomoo`0VOol004aoo`<000aoo`D0009oo`<000Qoo`80015oo`8001=o
o`03001oogoo015oo`<001Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo02Ioo`00C7oo1P0017oo1@001goo
00<007ooOol01Goo0`004Woo00<007ooOol04Woo00<007ooOol04Woo0P0057oo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo
00<007ooOol09Woo000COol2000COol4000BOolH000COol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0WOol001Eoo`<001Aoo`D0
00Ioo`8001=oo`D005Qoo`03001oogoo0;aoo`0067oo0P005goo1@0000=oo`0000000P004Goo0P00
Fgoo00<007ooOol0QWoo00<007ooOol04Woo00<007ooOol07Woo000JOol3000IOol7001/Ool00`00
Oomoo`1MOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0NOol001eo
o`80009oo`8001=oo`P006]oo`03001oogoo03Aoo`03001oogoo011oo`8001=oo`8001=oo`80019o
o`8001=oo`80021oo`007goo1@004Woo1000Kgoo00<007ooOol07goo0P004Woo0P004Goo0`004Woo
0`004Woo0P004Woo0`004Woo0`0087oo000POol60023Ool00`00Oomoo`0;Ool2000AOol3000AOol2
000AOol3000BOol3000BOol3000AOol3000BOol3000QOol0021oo`L0089oo`03001oogoo00Yoo`<0
00moo`@0015oo`<0011oo`@0015oo`@0015oo`@0011oo`@0015oo`@0025oo`009Goo0`00Ngoo0P00
17oo00<007ooOol027oo10003goo1@0047oo0`0047oo1@0047oo1@0047oo10004Woo0`004Woo0`00
8Goo002?Ool2000?Ool50004Ool00`00Oomoo`07Ool4000?Ool5000@Ool4000BOol2000COol2000C
Ool2000BOol00`00Ool0000BOol00`00Ool0000QOol008aoo`D000eoo`H000Eoo`03001oogoo00Io
o`D0015oo`<0015oo`<0015oo`03001oo`00019oo`03001oo`00019oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo029oo`00RWoo1P003Goo1P001Woo00<007ooOol01goo0`004Goo00<007oo
00004Goo00<007oo00004Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007oo
Ool04Woo00<007ooOol08Woo001iOol4000<Ool6000?Ool40007Ool00`00Oomoo`06Ool00`00Ool0
000AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`0SOol007Eoo`H000ioo`D000moo`04001oogoo0008Ool2
0006Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0SOol007Eoo`D000ioo`03001oo`00
008000ioo`8000aoo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019o
o`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo02=o
o`00HGoo1`003Goo0`003Woo0P000goo00<007ooOol037oo00<007ooOol037oo00<007ooOol00goo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol04Woo00<007ooOol097oo001QOol5000<Ool300000goo001oo`0=
Ool00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0A
Ool00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0B
Ool00`00Oomoo`0TOol004aoo`D000ioo`D000aoo`80015oo`8001=oo`03001oogoo00ioo`05001o
ogooOol0000DOol00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0UOol004aoo`P000Moo`@000=oo`03001oogoo
00Uoo`80019oo`03001oogoo015oo`80015oo`04001oogoo000DOol00`00Oomoo`0BOol00`00Oomo
o`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomo
o`0UOol004Uoo`T000Ioo`<0015oo`80019oo`8001=oo`03001oogoo015oo`03001oo`0001Aoo`03
001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo02Ioo`00=goo1@001Woo1`0017oo0`001Goo0`004Woo0P004goo00<0
07ooOol04Woo00<007ooOol04Woo0P0057oo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0
4Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol09Woo000COol4000A
OolJ000;Ool00`00Oomoo`03Ool2000DOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0WOol001Moo`D000Ioo`8001=oo`D006eo
o`03001oogoo0;aoo`0077oo1@0000=oo`0000000P004Goo0P00L7oo00<007ooOol0_7oo000QOol7
0021Ool00`00Oomoo`1bOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0MOol0025oo`P0
081oo`03001oogoo04Uoo`03001oogoo011oo`8001=oo`8001=oo`8001=oo`8001moo`00ZGoo00<0
07ooOol0<goo0P004goo0P004Goo0`004Woo0`004Woo0`004Woo0P0087oo002YOol00`00Oomoo`0O
Ool2000AOol3000BOol2000AOol3000BOol3000BOol3000BOol3000POol00:Uoo`8000aoo`80015o
o`<0011oo`<0019oo`<0011oo`@0015oo`@0015oo`@0015oo`@0021oo`00XWoo0P001Goo00<007oo
Ool02Goo10003goo100047oo10004Goo0`0047oo1@0047oo1@0047oo1@0047oo10008Goo002>Ool2
000@Ool40005Ool00`00Oomoo`07Ool5000?Ool5000?Ool5000@Ool4000BOol2000COol2000COol2
000COol2000QOol008aoo`@000ioo`D000Ioo`03001oogoo00Ioo`D000moo`D0019oo`80019oo`<0
019oo`80019oo`03001oo`0001=oo`8001=oo`03001oogoo021oo`00NGoo0`003Woo1@003Woo1@00
1goo00<007ooOol01Woo1@004Goo0`004Goo00<007oo00004Woo0P004Woo00<007ooOol04Woo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol08Goo001fOol5000>Ool5000@Ool30008Ool00`00
Oomoo`07Ool3000AOol00`00Ool0000AOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0B
Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0QOol006Aoo`@000aoo`H000moo`D000mo
o`03001oo`0000Uoo`03001oogoo00Ioo`03001oo`00015oo`03001oogoo015oo`03001oogoo019o
o`03001oogoo019oo`03001oogoo015oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo029o
o`00H7oo1P003Woo1@003goo00<007oo00000P003goo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol04goo00<007ooOol04Goo00<007ooOol04Woo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol08goo001POol5000?Ool4000>Ool20003Ool00`00
Oomoo`0<Ool2000=Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0B
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0S
Ool004]oo`P000aoo`@000moo`80009oo`03001oogoo00aoo`03001oogoo015oo`03001oogoo00eo
o`03001oogoo00=oo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo019o
o`03001oogoo019oo`03001oogoo019oo`03001oogoo019oo`03001oogoo02Aoo`00Bgoo1P0037oo
0P000Woo00<007ooOol037oo0P004Woo00<007ooOol04Goo00<007ooOol03Woo00<007ooOol00Woo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04goo00<007ooOol04Goo00<007ooOol04Woo
00<007ooOol04goo00<007ooOol04Woo00<007ooOol097oo000gOol5000>Ool5000<Ool2000BOol0
0`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0?Ool01@00Oomoogoo000057oo00<007ooOol0
4Goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol09Goo000gOol80007Ool40002Ool00`00Oomoo`0:Ool2000BOol2000BOol2000C
Ool00`00Oomoo`05Ool50006Ool01000Oomoo`0057oo00<007ooOol04Woo00<007ooOol04Woo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol09Goo000R
Ool3000>Ool90007Ool3000@Ool3000BOol2000COol00`00Oomoo`0BOol00`00Oomoo`08Ool00`00
Oomoo`06Ool00`00Ool0000DOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00
Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0VOol0029oo`H000Aoo`L000Ao
o`8000Moo`<0015oo`8001Aoo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Uoo`03001o
ogoo00Ioo`8001Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo019oo`03001oogoo02Ioo`004goo6@004Woo0P004goo00<007oo
Ool04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol01Woo0`004Woo
00<007ooOol04Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04goo
00<007ooOol04Woo00<007ooOol09goo000ROol3001kOol00`00Oomoo`06Ool00`00Oomoo`2lOol0
0:1oo`03001oogoo00Ioo`03001oogoo0;aoo`00X7oo00<007ooOol01Woo00<007ooOol0_7oo002N
Ool30008Ool00`00Oomoo`2lOol00:Uoo`03001oogoo0;aoo`00ZGoo00<007ooOol0_7oo002YOol0
0`00Oomoo`2lOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00:Qoo`800;ioo`00
Z7oo0P00_Woo002WOol01000Oomoo`00_Goo002WOol01000Oomoo`00_Goo002VOol00`00Oomoo`02
Ool00`00Oomoo`2jOol00:Eoo`<0009oo`<00;]oo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {337.312, 0}} -> {-1, -1, 0, 0}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Conservation of Phase-Space Area", "Section",
  CellTags->"c:13"],

Cell[TextData[{
  "\tThe solutions of the damped oscillator ODE do not conserve phase-space \
area. By this we mean the following: consider an area of phase-space, say a \
square, whose boundary is mapped out by a collection of initial conditions. \
As these points evolve in time according to the ODE, the square changes \
shape. The area of the square shrinks as all points are attracted toward the \
origin. (See ",
  ButtonBox["Fig. 1.5",
    ButtonData:>"Fig. 1.5",
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:B0003Gb000`400?l00000o`00003oo`3ooooo
0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo
003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0
ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool0
0?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3o
oonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00
o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oo
oi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o
0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0oooo
U03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0
ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD
0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3o
oooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0
oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?oo
ool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03o
ool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0oooo
o`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?oo
o`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo
0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo
003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0
ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool0
0?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3o
oonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00
o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oo
oi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o
0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0oooo
U03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0
ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD
0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3o
oooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0
oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?oo
ool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03o
ool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0oooo
o`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?oo
o`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo
0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo
003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0
ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool0
0?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3o
oonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00
o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oo
oi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o
0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0oooo
U03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0
ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD
0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3o
oooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0
oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?oo
ool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03o
ool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0oooo
o`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?oo
o`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo
0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo
003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0
ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool0
0?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3o
oonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00
D03oool00`000000P8200?ooo`3o0?ooool0oooo@@3oool00500oooo00<000000820P03oool0o`3o
oooo0?oood40oooo001>0?ooo`80P82000<000000410@030`<00o`3ooooo0?oood40oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo
001>0?ooo`@0000000<0@4100820P03oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0@410
0820P03oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000@0P8200?ooo`3o
ool0o_kno`3ooooo0?oooch0oooo001>0?ooo`H00000o`3ooooo0?oood00oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?oo
o`@0000000@0P8200?ooo`3oool0o_kno`3ooooo0?oooch0oooo001>0?ooo`@0000000<0P8200?oo
o`3oool0o`3ooooo0?ooocl0oooo000Q0?ooo`040<30`020P800P8200820P0P0oooo00@0`<300000
00010@40`<301P3oool40820P0030<30`03oool0oooo0100oooo100000000`20P800oooo0?ooo`3o
0?ooool0oooo?`3oool001l0oooo00<0`<300000000000000P20P802000000030<30`03oool0oooo
00@0oooo00@0P820000000000000P820103oool00`30`<00000000000005000000030820P030`<00
oooo00h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool001h0oooo00<0`<300000
0020P800103oool00`30`<0000000<30`0060?ooo`80P8201@3oool01020P80000000410@020P803
0?ooo`040<30`020P80000000<30`0h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3o
ool001h0oooo0P0000060?ooo`03000000010@40oooo01D0oooo00<0Ogmo0000003oool03@3oool4
000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`007@3oool00`20P80000000820P0060?oo
o`030820P0010@40P82001H0oooo00<0@4100451@@3oool0303oool4000000030820P03oool0oooo
0?l0ooooo`3ooolo0?ooo`007@3oool00`0000000@410<30`0070?ooo`8000005P3oool00`30`<00
00000<30`00<0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo000@0?ooo`P0P820
00D0`<300?ooo`3oool0oooo0<30`002000000P0oooo0P0000000`20P800oooo0?ooo`0D0?ooo`03
00000010@400oooo00/0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool00100oooo
0P0000000`010@40000000000003000000070820P03oool0oooo0?ooo`20P80000000410@0080?oo
o`030410@0000000000001H0oooo0P00000<0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo000@0?ooo`0300410@000000000000D0000000L0P8200?ooo`3oool0oooo0820P0000000
P82000P0oooo00<0P8200000000000005P3oool2000000`0oooo100000000`20P800oooo0?ooo`3o
0?ooool0oooo?`3oool00100oooo2020P8001030`<00oooo0?ooo`3oool2000000030820P03oool0
oooo00H0oooo00@0P820000000000000P820503oool00`20P80000000000000<0?ooo`@0000000<0
P8200?ooo`3oool0o`3ooooo0?ooocl0oooo000L0?ooo`80000000<0P8200?ooo`3oool01P3oool0
1020P800000000000020P80D0?ooo`03000000010@40@41000`0oooo100000000`20P800oooo0?oo
o`3o0?ooool0oooo?`3oool001`0oooo0P0000000`20P800oooo0?ooo`060?ooo`040820P0000000
00000820P1<0oooo00@0@410000000000000P820303oool4000000030820P03oool0oooo0?l0oooo
o`3ooolo0?ooo`00703oool2000000030820P03oool0oooo00H0oooo00@0P820000000000000P820
4@3oool01@20P8000000000000010@40000000d0oooo2000003o0?ooool0oooo?P3oool001`0oooo
0P0000000`20P800oooo0?ooo`060?ooo`040820P000000000000820P100oooo1@0000000`20P800
oooo0?ooo`0;0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo000L0?ooo`800000
00<0P8200?ooo`3oool01P3oool01020P800000000000020P80;0?ooo`030;no_`20P800P82000<0
000000@00@41000000000000@4103P3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?oo
o`00703oool00`10@40000000410@0080?ooo`040820P000000000000<30`0/0oooo00<0`<300041
0@000000100000000`20P800`<300?ooo`0>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo000L0?ooo`030820P0000000000000P0oooo00<0P8200000000000003@3oool300000003
0410@020P800oooo0140oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool001`0oooo
00<0`<30000000010@40203oool2000000030820P03oool0oooo00/0oooo00<0P8200000003oool0
503oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`007@3oool00`010@4000000?oo
o`070?ooo`03000000010@40oooo00h0oooo00<00@410820P03oool04`3oool4000000030820P03o
ool0oooo0?l0ooooo`3ooolo0?ooo`007@3oool00`20P80000000820P0060?ooo`030<30`0000000
@D5100l0oooo00<0P8200410@03oool04`3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo
0?ooo`007P3oool00`000000@4100?ooo`050?ooo`030410@0000000`<300100oooo00<0@4100820
P020P8001@20P8000`30`<00oooo0?ooo`0:0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo000N0?ooo`030<30`0000000000000@0oooo00<0`<3000000030`<004@3oool00`30`<00
0@4100000005000000030410@03oool0oooo00X0oooo100000000`20P800oooo0?ooo`3o0?oooeD0
oooo1020P8000`30`<00oooo0?ooo`3R0?ooo`007`3oool00`30`<000000000000030820P0030000
0030`<00oooo0180oooo00<0@4100000000000001@0000000`20P800oooo0?ooo`090?ooo`@00000
00<0P8200?ooo`3oool0o`3ooomE0?ooo`@0000000<0P8200?ooo`3oool0hP3oool00240oooo00@0
P8200000000000000000:@3oool4000000030820P03oool0oooo0?l0ooooE@3oool4000000030820
P03oool0oooo0>80oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooomE0?ooo`@0000000<0
P8200?ooo`3oool0hP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooeD0oooo10000000
0`20P800oooo0?ooo`3R0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooJ@3oool40000
0=40oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooomY0?ooo`80000000<00@410000003o
ool0d03oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooofT0oooo0P0000000`010@400000
0?ooo`3@0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooJ@3oool400000=40oooo001>
0?ooo`@0000000<0@4100820P03oool0o`3ooomY0?ooo`@0P820d@3oool004h0oooo100000000`10
@400P8200?ooo`3o0?ooogd0oooo1020P82m0?ooo`00CP3oool4000000030820P03oool0oooo0?l0
ooooO@3oool20000000300410@000000oooo0;`0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0
o`3ooomm0?ooo`@00000_@3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooogd0oooo00@0
000000410@010@400000_@3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooogd0oooo1000
002m0?ooo`00CP3oool4000000030820P03oool0oooo0>h0oooo0P20P8000`30`<00oooo0?ooo`2M
0?ooo`@00000Z@3oool004h0oooo100000000`20P800oooo0?ooo`3]0?ooo`050820P00000000000
00000020P800603oool00`20P800000000000006000007d0oooo0P0000000`010@4000000?ooo`2X
0?ooo`00CP3oool4000000030820P03oool0oooo0>`0oooo00<0`<300000000000000P0000000`01
0@40`<300?ooo`0I0?ooo`040410@000000000000820P7l0oooo1000002Y0?ooo`00CP3oool40000
00030820P03oool0oooo0>`0oooo00@0P820000000000000@4100P3oool00`20P800oooo0?ooo`0H
0?ooo`030820P000000000000800oooo00@0000000410@0000000000Z@3oool004h0oooo10000000
0`20P800oooo0?ooo`3/0?ooo`040820P000000000000820P1d0oooo00<0P820000000000000T`3o
ool01@20P80000000000000000000@4109D0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0k03o
ool01020P800000000000020P80M0?ooo`030820P0000000000002`0oooo1020P8000`30`<00oooo
0?ooo`1P0?ooo`030820P0000000000000800000U@3oool004h0oooo100000000`20P800oooo0?oo
o`3/0?ooo`040820P000000000000820P1d0oooo00<0P820000000000000;03oool01P0000000@41
000000000000P8200?knoV40oooo00<0P82000410@0000000P00002E0?ooo`00CP3oool400000003
0820P03oool0oooo0>`0oooo00@0P820000000000000P8207@3oool00`20P80000000000000/0?oo
o`05000000010@40000000410@20P800HP3oool00`20P800000000410@02000009D0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0k03oool01020P800000000000020P80M0?ooo`030820P0000000
000002`0oooo00D0000000410@00000000000820P01R0?ooo`030<30`020P800P8200080P820U@3o
ool004h0oooo100000000`20P800oooo0?ooo`3/0?ooo`040820P000000000000820P1d0oooo00<0
P820000000000000;03oool01@0000000@41000000000000P8200?`0oooo001>0?ooo`@0000000<0
P8200?ooo`3oool0k03oool01020P800000000000020P8040?oooa40P82000<0`<300?ooo`3oool0
1@3oool00`20P80000000000002W0?ooo`050820P0000000000000000020P800P@3oool004h0oooo
100000000`20P800oooo0?ooo`3/0?ooo`040820P000000000000820P0@0oooo00<0000000410@00
00003P0000000`20P800oooo0?ooo`050?ooo`030820P0000000000002l0oooo00<0o_kn0?ooo`3o
ool0M@3oool01@20P8000000000000000000P8200840oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0k03oool01020P800000000000020P80M0?ooo`030820P000000000000:L0oooo00D0P8200000
0000000000000820P0210?ooo`00CP3oool600000>d0oooo00@0P82000410@010@40P8207@3oool0
0`20P80000000000002W0?ooo`050820P0000000000000000020P800P@3oool004h0oooo10000000
0`20P800oooo0?ooo`3/0?ooo`040820P000000000000820P1d0oooo00<0P820000000000000o`3o
ool^0?ooo`00CP3oool4000000030820P03oool0oooo0>X0oooo0P20P8001010@400000000000010
@4020820P0030<30`03oool0P8200100P82000<0`<300?ooo`3oool01@3oool00`20P80000000000
003o0?ooobh0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0jP3oool01020P800000000000001
0@44000000030820P03oool000000100000000<0P8200?ooo`3oool01@3oool00`20P80000000000
003o0?ooobh0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0j`3oool01@30`<00000000000000
0000P82001d0oooo00<0P820000000000000o`3oool^0?ooo`00CP3oool4000000030820P03oool0
oooo0>`0oooo00@0`<30000000000000P8207@3oool00`20P80000000000003o0?ooobh0oooo001>
0?ooo`@0000000<0P8200?ooo`3oool0k@3oool00`20P80000000820P00M0?ooo`030820P0000000
00000?l0oooo;P3oool004h0oooo100000000`20P800oooo0?ooo`3^0?ooo`0300000020P800oooo
01`0oooo00<0P820000000000000o`3oool^0?ooo`00CP3oool4000000030820P03oool0oooo0>l0
oooo00<0P8200?ooo`3oool0603oool00`000000oooo0?ooo`0300000?l0oooo;P3oool004h0oooo
100000000`20P800oooo0?ooo`3o0?ooo`/0oooo00@0`<300820P00000000@410P00003o0?ooobh0
oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3oool>0?ooo`030820P000000000000?l0oooo
;P3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooa00oooo00<0P8200?ooo`3oool0o`3o
ool/0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo8`3oool00`20P800000000000002
00000?l0oooo5`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooob<0oooo00<0P8200000
000000000P00003o0?oooaL0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolS0?ooo`03
0820P0000000000000800000o`3ooolG0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo
8`3oool00`20P80000000000000200000?l0oooo5`3oool004h0oooo100000000`20P800oooo0?oo
o`3o0?ooob<0oooo00<0`<300820P020P8000P20P81h0?ooo`050<30`020P800P8200820P030`<00
V@3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooj00oooo00D0P8200000000000000000
0820P02I0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooX03oool01@20P80000000000
00000000P82009T0oooo001>0?ooo`@0000000<0@4100820P03oool0o`3ooonP0?ooo`050820P000
0000000000000020P800V@3oool004h0oooo1P00003o0?oooj40oooo00D0P8200000000000000000
0820P02I0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo
0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00
CP3oool4000000030820P03oool0oooo0?l0ooooW@3oool20820P0030<30`03oool0oooo09`0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonM0?ooo`040<30`0010@4000000;no_id0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonN0?ooo`<00000W@3oool004h0oooo10000000
0`20P800oooo0?ooo`3o0?oooih0oooo00D0P82000000000000000000;no_`2K0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0ooooW`3oool01@0000000@41000000000000P82009X0oooo001>
0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonO0?ooo`030410@0000000000000<0000000<0`<30
0?ooo`3oool0UP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooil0oooo00<0P8200000
00000000100000000`30`<00oooo0?ooo`2E0?ooo`00CP3oool4000000030820P03oool0oooo0?l0
oooo2`3oool00`20P800000000000002000008h0oooo00<0o_kn0?ooo`000000100000000`010@40
00000820P02F0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo2`3oool00`20P8000000
0000000200000900oooo200000000`20P800oooo0?ooo`2C0?ooo`00CP3oool4000000030820P03o
ool0oooo0?l0oooo2`3oool00`20P80000000000000200000900oooo00<0@4100000000000001P00
00000`10@400`<300?ooo`2B0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo2`3oool0
0`20P80000000000000200000900oooo00<0P820000000010@40200000000`30`<00oooo0?ooo`2@
0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo2`3oool00`30`<00P8200820P0020820
P7P0oooo00D0`<300820P020P800P8200<30`00D0?ooo`/0000000<0P8200?ooo`3oool0S`3oool0
04h0oooo100000000`20P800oooo0?ooo`3o0?ooohP0oooo00D0P82000000000000000000820P00D
0?ooo`@0000000<00@410000000000001P00002@0?ooo`00CP3oool600000?l0ooooR@3oool01@20
P8000000000000000000P82001@0oooo00D0P820000000010@40000000410@060000000300410@00
0000@41008l0oooo001>0?ooo`@0000000<0@4100820P03oool0o`3ooon80?ooo`050820P0000000
0@4100410@20P8005@3oool>000000030<30`03oool0oooo08/0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooon80?ooo`050<30`020P800P8200820P030`<005@3oool00`10@40000000000
000<000000030<30`03oool0oooo08X0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonR
0?ooo`030820P0000000000000h0000000<0`<300?ooo`3oool0R03oool004h0oooo100000000`1o
Ogl0oooo0?ooo`3o0?oooj80oooo00<0P8200000000000002P0000001@010@400000000000000000
0@4108X0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonS0?oooa40000000<0@4100<30
`03oool0Q`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooj<0oooo4`0000000`1oOgl0
oooo0?ooo`250?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooY03oool00`010@400000
0000000@000000030410@030`<00oooo08@0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oonT0?oooaD00000Q@3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooj@0oooo00<0@410
0000000000004P0000000`10@400oooo0?ooo`220?ooo`00CP3oool4000000030820P03oool0oooo
0?l0ooooY03oool00`20P800000000000007000000030410@03oool0oooo00@0oooo00L0`<300820
P020P800@410000000010@40P8200880oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonT
0?ooo`030<30`0000000000000D0000000@0@410000000000000`<302P3oool00`30`<00P8200410
@0210?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooY@3oool50000000300410@10@400
oooo00<000003@3oool00`30`<00oooo0?ooo`1n0?ooo`00CP3oool4000000030820P03oool0oooo
0?l0ooooY@3oool00`20P800000000000003000000030820P03oool0oooo0080000000<0P8200?oo
o`3oool0R`3oool004h0oooo100000000`20P800oooo0?ooo`3a0?ooo`@0P82000<0`<300?ooo`3o
ool0[03oool01`30`<0000000000000000000@4100000030`<000P3oool00`10@40000000410@02=
0?ooo`00CP3oool4000000030820P03oool0oooo0?40oooo100000000`20P800oooo0?ooo`2]0?oo
o`D000000`3oool01030`<00000000000030`<2<0?ooo`00CP3oool4000000030820P03oool0oooo
0?40oooo100000000`20P800oooo0?ooo`2]0?ooo`050820P0000000000000000010@400103oool0
0`10@40000000410@02<0?ooo`00CP3oool4000000030820P03oool0oooo0?40oooo100000000`20
P800oooo0?ooo`2]0?ooo`050<30`0000000000000000020P800103oool01030`<00000000000020
P82;0?ooo`00CP3oool800000?l0ooooKP3oool4000003@0oooo0P0000000`010@40P8200?ooo`04
0?ooo`<00000R`3oool004h0oooo2000003o0?ooofh0oooo1000000d0?ooo`040820P00000000000
0820P0D0oooo00@0P820000000000000P820RP3oool004h0oooo100000000`20P800oooo0?ooo`3o
0?ooofl0oooo1000000d0?ooo`040<30`00000000@410<30`0H0oooo00<0000000410@000000RP3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?ooofl0oooo0P0000000`010@4000000?ooo`0d
0?ooo`030820P0000000oooo00H0oooo00@0P820000000010@40P820R@3oool004h0oooo10000000
0`20P800oooo0?ooo`3o0?ooofl0oooo0`20P8000`1oOgl0oooo0?ooo`0d0?ooo`030000003oool0
oooo00H0oooo0`0000290?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooZ@3oool00`20
P800oooo0?ooo`070?ooo`80000000<0P8200?ooo`3oool0QP3oool004h0oooo100000000`20P800
oooo0?ooo`3o0?ooojT0oooo00<0P8200?ooo`3oool01`3oool00`10@40000000451@@280?ooo`00
CP3oool4000000030820P03oool0oooo0?l0ooooZ@3oool00`30`<00oooo0?ooo`070?ooo`040<30
`0010@4000000820P8L0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooond0?ooo`030451
@@000000000008L0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooond0?ooo`040<30`000
000000000820P8H0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooone0?ooo`<00000QP3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?oookD0oooo00@0P820000000010@40`<30Q@3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?oookH0oooo0P0000000`10@400oooo0?ooo`23
0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo]`3oool2000008D0oooo001>0?ooo`@0
000000<0P8200?ooo`3oool0o`3ooong0?ooo`030410@0000000P82008@0oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooong0?ooo`030820P0000000P82008@0oooo001>0?ooo`@0000000<0
P8200?ooo`3oool0f@3oool30000000300410@20P800oooo0=L0oooo00<0_kno000000000000Q03o
ool004h0oooo100000000`20P800oooo0?ooo`3I0?ooo`<0000000<00@410820P03oool0f03oool2
000000030<30`03oool0oooo0840oooo001>0?ooo`@0000000<0@4100820P03oool0f@3oool20041
0@03000000010@40P8200=T0oooo00<0P82000410@20P800P`3oool004h0oooo1P00003J0?ooo`<0
000000<00@410820P03oool0f03oool00`20P80000000410@0230?ooo`00CP3oool4000000030820
P03oool0oooo0?l0ooooE`3oool4000005h0oooo0P0000230?ooo`00CP3oool4000000030820P03o
ool0oooo0>d0oooo1020P81S0?ooo`060?knoP3oool00000000000010@400000GP3oool200000003
0820P03oool0oooo0800oooo001>0?ooo`@0000000<0P8200?ooo`3oool0k@3oool3000000030041
0@3oool0oooo06<0oooo1000001N0?ooo`030820P000000000000880oooo001>0?ooo`@0000000<0
P8200?ooo`3oool0k@3oool20000000300410@000000oooo06@0oooo00@0000000410@0000000000
GP3oool01030`<00000000000020P8210?ooo`00CP3oool4000000030820P03oool0oooo0>d0oooo
100000380?ooo`80000000<0@4100?ooo`3oool0O`3oool004h0oooo100000000`20P800oooo0?oo
o`3]0?ooo`<0000000<00@410?ooo`3oool0aP3oool00`20P8000000000000210?ooo`00CP3oool4
000000030820P03oool0oooo0?l0oooo0@3oool00`20P80000000000000200000;@0oooo00<0P820
000000000000P@3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooo`40oooo00<0P8200041
0@0000000P00002d0?ooo`040<30`000000000000820P800oooo001>0?ooo`@0000000<0P8200?oo
o`3oool0o`3oool10?ooo`050820P00000000000000000010@40]@3oool2000000030820P03oool0
oooo07h0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3oool10?ooo`030820P00000000000
00800000]@3oool300000800oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3oool10?ooo`03
0<30`020P800P8200080P8203`3oool01@30`<00P8200820P020P800`<300:80oooo00<000000041
0@3oool0O`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooaD0oooo00D0P82000000000
00000@410820P02R0?ooo`80000000<0`<300?ooo`3oool0O@3oool004h0oooo100000000`20P800
oooo0?ooo`3o0?oooaD0oooo00D0P82000000000000000000820P02R0?ooo`030820P0000000P820
07l0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolE0?ooo`050820P000000000000000
0020P800XP3oool00`20P80000000410@01o0?ooo`00CP3oool4000000030820P03oool0oooo0?l0
oooo_@3oool2000007l0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonm0?ooo`800000
O`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooobT0oooo100000000`20P800oooo0?oo
o`2=0?ooo`800@4100<0`<300?ooo`3oool0O03oool004h0oooo1P00003o0?ooobX0oooo10000000
0`20P800oooo0?ooo`2=0?ooo`030820P0010@40P82007h0oooo001>0?ooo`@0000000<0@4100820
P03oool0o`3ooolY0?ooo`@0000000<0P8200?ooo`3oool0S@3oool00`20P8000@410820P01n0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0oooo:@3oool4000000030820P03oool0oooo08d0
oooo00<0P82000000020P800OP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooocd0oooo
0`0000000`010@40P8200?ooo`1j0?ooo`030<30`0000000@41007h0oooo001>0?ooo`@0000000<0
P8200?ooo`3oool0o`3ooolm0?ooo`@0000000<0P8200?ooo`3oool0NP3oool2000007h0oooo001>
0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolm0?ooo`80000000<00@4100000020P800O03oool2
000007h0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolm0?ooo`05000000010@400000
00000020P800O03oool2000007h0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonn0?oo
o`030820P0000000000007d0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonn0?ooo`03
0820P0000000000007d0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonn0?ooo`030820
P0000000000007d0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonn0?ooo`030820P000
00000@4107d0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonA0?ooo`@0P820:@3oool0
0`20P80000000000001m0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooT@3oool01000
00000@4100000000000Z0?ooo`80000000<0P8200?ooo`3oool0NP3oool004h0oooo100000000`20
P800oooo0?ooo`3o0?oooi40oooo1000000Z0?ooo`80000000<0P8200?ooo`3oool0NP3oool004h0
oooo100000000`20P800oooo0?ooo`3o0?oooi40oooo0P0000000`010@4000000?ooo`0Y0?ooo`80
000000<0P8200?ooo`3oool0NP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooi40oooo
1020P80Z0?ooo`80000000<0P8200?ooo`3oool0NP3oool004h0oooo100000000`20P800oooo0?oo
o`200?ooo`040<30`020P800P8200820P0T0oooo00<0P82000000010@4003@3oool00`30`<00P820
0820P03o0?oooal0oooo0P0000000`20P800oooo0?ooo`1j0?ooo`00CP3oool4000000030820P03o
ool0oooo07l0oooo00<0P8200000000000000`0000080?ooo`<000003@3oool00`20P80000000000
00260?ooo`030820P0000000oooo00T0oooo00<0o_kn0?ooo`3oool0R@3oool2000000030820P03o
ool0oooo07X0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0OP3oool00`20P80000000820P002
0?ooo`030820P010@400@41000L0oooo00<0P82000000010@4003@3oool00`20P80000000000001h
0?ooo`060820P0000000000000410@10@400`<30203oool00`010@400000000000080?ooo`80P820
100000020820P8D0oooo00<0P820000000000000O03oool004h0oooo100000000`20P800oooo0?oo
o`1m0?ooo`030410@0000000P82000D0oooo00<000000410@03oool05@3oool00`20P80000000000
001g0?ooo`80@41000H0`<300?ooo`3oool0P82000000030`<070?ooo`030410@0000000P82000L0
oooo00@0@410000000000000`<300P3oool01030`<00P82000000010@4240?ooo`030820P0000000
000007`0oooo001>0?ooo`D0000000<00@410?ooo`3oool0N`3oool00`20P8000000000000060?oo
o`030820P0000000P82001D0oooo00<0P820000000000000MP3oool00`10@40000000?ooo`040?oo
o`030820P0000000P82000l0oooo00<0@41000000010@4001P3oool00`20P80000000410@0230?oo
o`030820P0000000000007`0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0O03oool00`010@40
00000820P0070?ooo`03000000010@40oooo01@0oooo00<0P820000000000000M@3oool200000003
0820P03oool0oooo00@0oooo00<0000000410@20P8003@3oool01030`<00000000000030`<070?oo
o`80000000<0`<300?ooo`3oool0P03oool00`20P800000000410@1l0?ooo`00CP3oool400000003
0820P03oool0oooo07`0oooo0P0000080?ooo`8000005@3oool00`20P80000000000001d0?ooo`04
0820P0010@4000000820P0H0oooo00<0P820000000000000303oool0103no_h0P820000000000006
0?ooo`050?knoP3oool0000000000020P800PP3oool00`20P80000000000001l0?ooo`00CP3oool4
000000030820P03oool0oooo07/0oooo00<0P820000000000000203oool00`0000000@410000000;
0?ooo`03000000010@40000000`00000L@3oool00`20P8000000000000070?ooo`030820P0000000
0@4100d0oooo00<0P8200000000000001`3oool01030`<00000000000020P81_0?ooo`030<30`020
P800P82000H0P8201P3oool01@20P8000@410410@03oool0P820008000003@20P81_0?ooo`00CP3o
ool4000000030820P03oool0oooo07/0oooo00<0P82000000020P800203oool00`20P80000000000
000;0?ooo`l00000L@3oool3000000L0oooo00@0P820000000000000P820303oool00`30`<000000
000000070?ooo`040410@000000000000820P780oooo00@0@410000000000000P820203oool30000
00050?ooo`20P800000000000010@4000P010@4;000006h0oooo001>0?ooo`@0000000<0P8200?oo
o`3oool0N`3oool2000000030820P03oool0oooo00H0oooo00@0P820000000000000P8202P3oool0
0`20P800@4100?ooo`060?ooo`030820P0000000000007@0oooo0P0000000`20P800oooo0?ooo`06
0?ooo`80000000<0P8200?ooo`3oool02`3oool00`10@40000000820P0040?ooo`030<30`0000000
000000800000<`3oool40820P3`0oooo00<0P8200000000000002P3oool01020P800`<300?ooo`20
P802000000030?ooo`30`<000@4100/0000000<0`<300?ooo`3oool0J`3oool004h0oooo10000000
0`20P800oooo0?ooo`1k0?ooo`80000000<0P8200?ooo`3oool01P3oool01020P800000000000020
P80;0?ooo`0300000020P800oooo00D0oooo00<0P820000000000000L`3oool01020P80000000000
0020P8080?ooo`<000003@3oool00`20P80000000820P0040?ooo`0500410@000000000000000020
P800<`3oool4000003`0oooo00<0P8200000000000003@3oool00`20P8000000000000020?ooo`03
0820P0010@40oooo00L0oooo00<0P82000000020P800K@3oool004h0oooo100000000`20P800oooo
0?ooo`1k0?ooo`80000000<0P8200?ooo`3oool01P3oool01020P800000000000020P80;0?ooo`03
0820P011@D40oooo00D0oooo00<0P820000000000000L`3oool01020P800000000000020P8080?oo
o`<000003P3oool00`10@40000000820P0020?ooo`030410@0000000000000800000=03oool40000
03`0oooo00<0P8200000000000003P3oool2000000050820P03oool0oooo0820P010@400203oool0
0`20P800@4100?ooo`1/0?ooo`00CP3oool4000000030820P03oool0oooo07/0oooo0P0000000`20
P800oooo0?ooo`060?ooo`040820P000000000000820P0`0oooo00<0@D510820P03oool0103oool0
0`20P80000000000001c0?ooo`040820P000000000000820P0P0oooo0`00000?0?ooo`040<30`000
0000@4100410@0<0000000<0@4100<30`03oool0<`3oool20000000300410@000000oooo03/0oooo
00<0P8200000000000003P3oool2000000060820P03oool0oooo0?ooo`30`<00@410MP3oool004h0
oooo100000000`20P800oooo0?ooo`1k0?ooo`80000000<0P8200?ooo`3oool01P3oool01020P800
000000000020P80<0?ooo`030<30`0000000P82000@0oooo00<0P820000000000000L`3oool01020
P800000000000020P8080?ooo`<00000403oool01P20P800000000410@0000000@410820P3H0oooo
1000000l0?ooo`030820P0000000000000h0oooo0P0000000`20P800oooo0?ooo`020?ooo`030<30
`010@400oooo07@0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0N`3oool2000000030820P03o
ool0oooo00H0oooo00@0P820000000000000P8203P3oool00`000000`<300?ooo`020?ooo`030820
P0000000000007<0oooo00@0P820000000000000P820203oool20000000300410@3oool0oooo00d0
oooo00H0@4100000000000000@4100000010@41g0?ooo`030820P0000000000000h0oooo00<00@41
00000020P8001@3oool00`30`<00@4100?ooo`1c0?ooo`00CP3oool4000000030820P03oool0oooo
07/0oooo0P0000000`20P800oooo0?ooo`060?ooo`040820P000000000000820P0h0oooo0P20P803
0?ooo`030820P0000000000007<0oooo00@0P820000000000000P820203oool3000000h0oooo00<0
P8200000000000000P0000000`3oool000000000001V0?ooo`@00000303oool00`20P80000000000
000>0?ooo`80000000<0P8200?ooo`3oool0103oool00`20P80000000?ooo`1b0?ooo`00CP3oool4
000000030820P03oool0oooo07/0oooo00<0P820000000010@40203oool00`20P80000000000000@
0?ooo`0500000030`<00oooo0?ooo`20P8000P00001c0?ooo`040820P000000000000820P0P0oooo
0`00000>0?ooo`@0000000<0`<300?ooo`30`<000P0000000`30`<00oooo0?ooo`1R0?ooo`@00000
303oool00`20P80000000000000>0?ooo`80000000<0P8200?ooo`3oool0103oool00`30`<000000
0410@01b0?ooo`00CP3oool4000000030820P03oool0oooo07/0oooo00<0P820000000000000203o
ool00`11@D400@410000000@0?ooo`050<30`010@400oooo0?ooo`20P8000P00001d0?ooo`<00000
203oool2000000030820P03oool0oooo00/0oooo00D0P82000410@00000000000<30`0030?ooo`04
0820P000000000000<30`6<0oooo1000000<0?ooo`030820P0000000000000h0oooo0P20P8000`30
`<00oooo0?ooo`060?ooo`80@410L@3oool004h0oooo100000000`20P800oooo0?ooo`1l0?ooo`80
0000203oool00`0000000@410?ooo`0A0?ooo`80P82000@0oooo0820P00000000000M03oool30000
00L0oooo00@0`<30000000000000P8203@3oool00`0000000@41000000060?ooo`030410@0000000
@D5106<0oooo1000000<0?ooo`030820P0000000000001T0oooo00<0`<3000000030`<00L03oool0
04h0oooo100000000`20P800oooo0?ooo`1l0?ooo`030820P0000000000000H0oooo00<0`<300000
0010@4004`3oool00`10@400P8200820P002000007@0oooo00<0P8200000000000001`3oool00`20
P800000000410@0>0?ooo`03000000010@40P82000H0oooo00<0P820000000000000H`3oool40820
P0`0oooo00<0P8200000000000006P3oool00`10@40000000?ooo`1_0?ooo`00CP3oool400000003
0820P03oool0oooo07d0oooo0P0000060?ooo`030820P0010@40P82001<0oooo00<0P82000000020
P8000P00001e0?ooo`80000000<0P8200?ooo`3oool0103oool00`20P80000000000000>0?ooo`80
000000<0P8200?ooo`3oool0103oool00`20P80000000000001c0?ooo`030820P0000000000001X0
oooo00<0P82000000020P800K`3oool004h0oooo100000000`20P800oooo0?ooo`1m0?ooo`030410
@0000000@41000D0oooo00<000000410@03oool0503oool01020P800000000000000001e0?ooo`03
0820P0000000P82000H0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`030410@0000000P82000H0
oooo00<0P820000000000000L`3oool00`20P80000000000000K0?ooo`0300000010@400oooo06h0
oooo001>0?ooo`@0000000<0@4100820P03oool0OP3oool00`20P80000000820P0030?ooo`80@410
5`3oool00`10@40000000000001f0?ooo`030410@0000000`<3000@0oooo00<0P82000000020P800
3`3oool00`30`<000@41000000060?ooo`03000000010@40P82007<0oooo00<0P820000000000000
6`3oool00`010@4000000820P01^0?ooo`00CP3oool4000000030410@020P800oooo07l0oooo00<0
`<300410@00000000P0000000`20P800oooo0?ooo`0G0?ooo`800000M`3oool20410@0060<30`03o
ool0oooo0<30`0010@40`<304@3oool01030`<00000000000020P8020?ooo`040<30`00000000000
0410@180oooo1020P8000`30`<00oooo0?ooo`1K0?ooo`030820P0000000000001/0oooo0`00001^
0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo6@3oool01P20P8000000000000000000
@4100<30`1<0oooo00<0`<300820P010@4000`0000000`20P800`<300?ooo`0B0?ooo`@0000000<0
P8200?ooo`3oool0F`3oool00`20P8000@4100410@0@0?ooo`030820P030`<00oooo00L0oooo00@0
`<300000000000000000KP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooodd0oooo1000
00000`20P800oooo0?ooo`1K0?ooo`030820P000000000000100oooo0P20P8080?ooo`040820P000
00000000000006h0oooo000g0?ooo`040<30`020P800P8200820P1<0oooo100000000`20P800oooo
0?ooo`3o0?ooodd0oooo100000000`20P800oooo0?ooo`1K0?ooo`030820P000000000000140oooo
00<000000<30`03oool01@3oool01@30`<000000000000000000P82006h0oooo000f0?ooo`070410
@0000000P8200820P010@40000000<30`00A0?ooo`@0000000<0P8200?ooo`3oool0o`3ooom=0?oo
o`@0000000<0P8200?ooo`3oool0F03oool01020P800oooo0?ooo`11@D4200000140oooo00@0P820
00000020P800`<300P3oool01P30`<00P8200000000000000@410410@6l0oooo000e0?ooo`80@410
103oool00`30`<000@410820P00@0?ooo`@0000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030<30
`020P800000000<000004P3oool01010@4000000000000010@46000000030<30`03oool0oooo06d0
oooo000d0?ooo`030410@0010@40`<3000D0oooo00<0@41000000010@4003`3oool4000000030820
P03oool0oooo0?l0oooo[`3oool00`20P80000000000000C0?ooo`030820P0000000000000<00000
00<00@410410@030`<00L03oool003@0oooo0P0000060?ooo`030820P0000000000000l0oooo1000
00000`20P800oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool04`3oool01@20P80000000000
00000000Ogmo0780oooo000c0?ooo`80000000<0@4100?ooo`3oool01@3oool00`0000000@410820
P00>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo000b0?ooo`040<30`0000000
00000820P0L0oooo00<0000000410@10@4003P3oool4000000030820P03oool0oooo0?l0ooooo`3o
oolo0?ooo`00<P3oool01020P800000000000030`<070?ooo`030820P0000000000000h0oooo1000
00000`20P800oooo0?ooo`3o0?ooojd0oooo1020P82=0?ooo`00<P3oool00`10@400000000000009
0?ooo`80000000<0`<300?ooo`3oool02`3oool4000000030820P03oool0oooo0?l0oooo[@3oool2
00410@800000S@3oool00380oooo0`0000090?ooo`80000000<0P8200?ooo`3oool02`3oool40000
00030820P03oool0oooo0?l0oooo[@3oool4000008d0oooo000b0?ooo`<000002@3oool200000003
0820P03oool0oooo00/0oooo100000000`20P800oooo0?ooo`3o0?ooojd0oooo00@0000000410@00
00000000S@3oool00380oooo0`0000090?ooo`80000000<0P8200?ooo`3oool02`3oool400000003
0820P03oool0oooo0?l0oooo[@3oool4000008d0oooo000b0?ooo`<000002@3oool2000000030820
P03oool0oooo00/0oooo100000000`20P800oooo0?ooo`3o0?ooob`0oooo00D00@41000000000000
00000820P03o0?ooo`h0oooo000b0?ooo`<000002@3oool2000000030820P03oool0oooo00/0oooo
100000000`11@D40P8200820P03o0820P2`0P820100000000`10@400P8200820P03k0820P100oooo
000b0?ooo`<000002@3oool2000000030820P03oool0oooo00/0oooo1P0000000`010@4000000000
003o00000?l00000;@00000@0?ooo`00<P3oool01010@400000000000030`<080?ooo`80000000<0
`<300?ooo`3oool02`3oool6000000800@41o`00000S0000000300410@000000000000D0000000<0
0@41000000000000o`00000@0?ooo`00<P3oool01020P800000000000020P8080?ooo`8000003P3o
oolj0000000300410@000000000005/0000000@00@410000000000000@418@0000000`010@400000
000000170000000300410@00000000000140000000<00@41000000000000A`0000000`010@400000
0000000?0000000300410@0000000@4105X0000000<00@41000000000000G@00000@0?ooo`00<P3o
ool01030`<00000000000020P8070?ooo`80000000<0@4100?ooo`3oool0303oool5000000030041
0@0000000@4104<000000P010@420000000300410@000000000004P0000000<00@41000000000000
<P00000200410A80000000<00@41000000000000A00000000`010@40000000410@03000000030041
0@0000000@4105X000000P010@4=000000800@419@0000000`010@40000000410@0T000000800@41
3@00000200410A80000000<00@410000000000009000000@0?ooo`00<`3oool2000000030820P03o
ool0oooo00D0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`@0000000<0P8200?ooo`3oool03P3o
ool00`20P80000000820P00@0?ooo`800000403oool00`1oOgl000000?ooo`0@0?ooo`0300000020
P800oooo00l0oooo00<0P8200000003oool04@3oool20820P140oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`80P8204@3oool00`010@40oooo0?ooo`0@0?ooo`030820P000
0000oooo0100oooo00<000000820P03oool03`3oool200000100oooo00<0Ogmo0000003oool0403o
ool00`000000Ogmo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo0P20P80A0?ooo`030000003o
ool0oooo00l0oooo00<000000820P03oool03`3oool00`20P80000000?ooo`0A0?ooo`800000403o
ool00`20P80000000?ooo`0@0?ooo`0300000020P800oooo00l0oooo00<0P82000410@3oool03`3o
ool00`1oOgl000000820P00B0?ooo`0300000020P800oooo00l0oooo0P00000@0?ooo`030820P000
0000oooo0100oooo00<000000820P03oool08@3oool003@0oooo0P0000060?ooo`040<30`0000000
0@410<30`0h0oooo100000000`20P800oooo0?ooo`160?ooo`0300000020P800oooo04P0oooo00<0
00000?ooo`3oool0B03oool00`010@40P8200?ooo`180?ooo`030000003oool0oooo04H0oooo00<0
P8200000003oool0B03oool00`20P8000@410?ooo`180?ooo`030820P0010@40oooo03@0oooo000d
0?ooo`030820P0000000`<3000D0oooo00<0@D5100000010@4003`3oool4000000030820P03oool0
oooo04H0oooo00<0P8200<30`03oool0B03oool00`20P800oooo0?ooo`180?ooo`030820P030`<00
oooo04P0oooo00<0P8200?ooo`3oool0AP3oool00`30`<00P8200?ooo`180?ooo`030<30`020P800
oooo04P0oooo00<0`<300820P03oool0=03oool003D0oooo00<0@4100000003oool00`3oool00`30
`<0000000820P00@0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo000f0?ooo`03
0410@0000000P8200080P82000<000000<30`03oool0403oool4000000030820P03oool0oooo0?l0
ooooo`3ooolo0?ooo`00=`3oool01020P800000000000000000C0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3oool:0?ooo`050820P0000000000000000020P800o`3oool`0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0oooo2P3oool01@20P8000000000000000000P8200:`0oooo1020
P8000`30`<00oooo0?ooo`1l0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo2P3oool0
1@20P8000@41000000000000P8200:`0oooo100000000`20P800oooo0?ooo`1l0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0oooo2P3oool01@20P8000000000000000000P8200:`0oooo1000
00000`20P800oooo0?ooo`1l0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo2P3oool0
1@30`<00P8200820P020P800`<300:`0oooo0`0000000`010@40P8200?ooo`1;0?ooo`040820P000
000000000820P0D0oooo00<0`<3000000011@D409P3oool004h0oooo100000000`20P800oooo0?oo
o`3o0?oook/0oooo1020P8000`30`<00oooo0?ooo`1:0?ooo`050820P0000000000000000020P800
103oool01@10@40000000410@0000000`<3002@0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0
o`3ooooo0?ooo`d0oooo00H0P82000000020P800oooo0410@030`<030?ooo`05000000010@40oooo
0?ooo`10@400903oool004h0oooo1P00003o0?ooool0oooo4`3oool010000000oooo0?ooo`20P802
00000080oooo0P20P80S0?ooo`00CP3oool4000000030410@020P800oooo0?l0ooooo`3ooolB0?oo
o`060410@030`<00oooo0820P0000000@4109`3oool004h0oooo100000000`20P800oooo0?ooo`3o
0?ooool0oooo4`3oool01@010@40oooo0820P0000000P82002L0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooooo0?oooa<0oooo00D0`<3000410@0000000@410<30`00W0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0ooooo`3ooolD0?ooo`030820P00000000@4102P0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooooo0?oooa@0oooo0`00000X0?ooo`00CP3oool400000003
0820P03oool0oooo0?l0ooooo`3ooolD0?ooo`80000000<0P8200?ooo`3oool09P3oool004h0oooo
100000000`20P800oooo0?ooo`3W0?ooo`050820P0000000000000000020P800o`3ooolV0?ooo`04
0<30`00000000@41000002P0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0i`3oool01@20P800
0000000000000000P8200?l0oooo9P3oool01@20P80000000000003oool0@41002L0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0i`3oool01@20P8000000000000000000P8200?l0oooo9P3oool0
2@10@40000000410@03oool0P8200410@03oool0`<300820P00S0?ooo`00CP3oool4000000030820
P03oool0oooo0>L0oooo00D0P82000000000000000000820P03o0?ooobD0oooo00@0P82000000000
0000P8200P3oool4000000030820P03no_h0oooo0200oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0i`3oool01@30`<00P8200820P020P800`<300?l0oooo8`3oool00`20P800000000410@020000
00040<30`03oool0oooo0<30`080000000<00@410820P03oool08@3oool004h0oooo100000000`20
P800oooo0?ooo`3o0?ooool0oooo4`3oool00`20P800oooo0?ooo`040?ooo`030<30`020P800oooo
0280oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3oooo90?ooo`@0000000<0P8200?ooo`3oool0KP3oool004h0oooo1000
00000`20P800oooo0?ooo`3o0?ooolT0oooo100000000`20P800oooo0?ooo`1^0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0oooob@3oool4000000030820P03oool0oooo06h0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3oooo90?ooo`@0000000<0P8200?ooo`3oool0KP3oool004h0
oooo100000000`10@400P8200?ooo`3o0?ooolT0oooo1020P8000`30`<00oooo0?ooo`1^0?ooo`00
CP3oool4000000030410@020P800oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03o
ool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo
0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool400000003
0820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo
o`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?D0oooo00<0`<300820P020P8000P20
P83o0?oood@0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0m@3oool01@20P800000000000000
00000@410?l0ooooA03oool004h0oooo100000000`20P800oooo0?ooo`3e0?ooo`050820P0000000
000000410@000000o`3ooom40?ooo`00CP3oool4000000030820P03oool0oooo0?D0oooo00<0P820
00410@0000000P00003o0?oood@0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0m@3oool01@20
P80000000000000000000@410?l0ooooA03oool004h0oooo100000000`20P800oooo0?ooo`3o0?oo
ool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo
100000000`20P800oooo0?ooo`3o0?ooomH0oooo1020P8000`2o_kl0oooo0?ooo`1Q0?ooo`00CP3o
ool4000000030820P03oool0oooo0?l0ooooeP3oool4000000030820P03oool0oooo0640oooo001>
0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooF0?ooo`@0000000<0P8200?ooo`3oool0H@3oool0
04h0oooo100000000`20P800oooo0?ooo`3o0?ooomH0oooo100000000`20P800oooo0?ooo`1Q0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0ooooeP3oool4000000030820P03oool0oooo0640
oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`H00000o`3o
oooo0?oood00oooo001>0?ooo`H00000o`3ooooo0?oood00oooo001>0?ooo`@0000000<0P8200?oo
o`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0
oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0
P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo
0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3oool40?ooo`050<30`020P800P820
07moO`20P800o`3ooolf0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo103oool00`20
P80000000000000200000?l0oooo=P3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooo`@0
oooo00<0P8200000000000000P00002/0?ooo`050820P0000000000000000020P800Q03oool004h0
oooo100000000`20P800oooo0?ooo`3o0?ooo`@0oooo00<0P82000410@0000000P00002/0?ooo`05
0820P0000000000000000020P800Q03oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooo`@0
oooo00<0P8200000000000000P00002[0?ooo`060?knoP20P800000000410@000000P820Q03oool0
04h0oooo100000000`20P800oooo0?ooo`3o0?oookD0oooo00D0P82000410@00000000000820P024
0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool400000003
0820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo
o`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030410@020P800oooo
0?l0ooooo`3ooolo0?ooo`00CP3oool600000?l0ooooo`3ooom00?ooo`00CP3oool4000000030820
P03oool0oooo0?l0ooooU03oool00`3no_h0oooo0?ooo`2W0?ooo`00CP3oool4000000030820P03o
ool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo
0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooT`3oool01@20P8000000000000000000
P8200:H0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonC0?ooo`050820P00000000@41
00410@20P800YP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oooi<0oooo00D0P8200000
0000000000000820P02V0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooT`3oool01@20
P8000000000000010@40P8200:H0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolC0?oo
o`@0P820O03oool01@30`<00P8200820P020P800`<300:H0oooo001>0?ooo`@0000000<0P8200?oo
o`3oool0o`3ooolC0?ooo`04000000010@400@4100000?l0oooo:03oool004h0oooo100000000`20
P800oooo0?ooo`3o0?oooa<0oooo1000003o0?ooobP0oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooolC0?ooo`@00000o`3ooolX0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo
4`3oool40820P?l0oooo:03oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20
P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0
oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo2000
003o0?ooog80oooo0P0000000`010@4000000?ooo`360?ooo`00CP3oool4000000040410@020P800
P8200820P?l0ooooLP3oool4000001h0oooo00@0_kno000000000000P8206`3oool01030`<00P820
0820P020P8090?ooo`030<30`0000000@41000L0oooo1020P81_0?ooo`00CP3oool4000000030820
P03oool0oooo0?l0ooooL`3oool0100000000@4100000000000M0?ooo`030820P0010@40000000<0
000000<0`<300?ooo`3oool05P3oool01`10@40000000820P020P800@41000000030`<001`3oool0
0`20P8000000000000050?ooo`030410@0000000000000D0000000<0P8200?ooo`3oool0JP3oool0
04h0oooo100000000`20P800oooo0?ooo`3o0?ooog<0oooo1000000M0?ooo`<0000000@0P8200?oo
o`3oool0P8205`3oool2000000@0oooo00<0P8200000003oool01`3oool00`000000P8200?ooo`04
0?ooo`0400410@00000000000820P0<0oooo00<0P82000000020P800J`3oool004h0oooo10000000
0`20P800oooo0?ooo`3o0?ooog<0oooo1020P80M0?ooo`<000000`3oool00`30`<00oooo0?ooo`0D
0?ooo`030410@0000000P82000D0oooo00<000000451@@3oool03@3oool20820P0030<30`03oool0
oooo00<0oooo00<0`<3000000030`<00JP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oo
oi@0oooo0`00000I0?ooo`030820P0000000000000H0oooo00<0P82000410@0000005P3oool00`30
`<0000000820P01Y0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooU03oool3000001T0
oooo00<0000000410@20P8001`3oool00`010@4000000820P00F0?ooo`030410@0000000`<3006P0
oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonD0?ooo`<00000603oool00`30`<000000
000000080?ooo`80000000<0@4100?ooo`3oool0503oool00`20P80000000410@01X0?ooo`00CP3o
ool4000000030820P03oool0oooo0?l0ooooU03oool3000001P0oooo00<0P820000000000000203o
ool3000001H0oooo00<0P820000000000000J03oool004h0oooo100000000`20P800oooo0?ooo`3o
0?ooob40oooo00@0000000410@010@400000K`3oool3000001P0oooo00<0P82000000020P800203o
ool00`20P80000000000000F0?ooo`030820P0000000000006P0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooolQ0?ooo`04000000010@400000000006l0oooo0`00000H0?ooo`80000000<0
P8200?ooo`3oool01P3oool01020P800000000000020P80E0?ooo`<00000J03oool004h0oooo1000
00000`20P800oooo0?ooo`3o0?ooob40oooo0`0000000`010@40oooo0?ooo`1]0?ooo`<00000103o
ool00`20P80000000000000?00000080oooo0P0000000`20P800oooo0?ooo`060?ooo`040820P000
000000000820P1@0oooo00@0P820000000000000@410J03oool004h0oooo100000000`20P800oooo
0?ooo`3o0?ooob40oooo1020P81_0?ooo`<00000603oool2000000030820P03oool0oooo00H0oooo
00@0P820000000000000P8204`3oool01@2o_kl00000000000000000P82006P0oooo001>0?ooo`@0
000000<0P8200?ooo`3oool0o`3ooonD0?ooo`<00000603oool2000000030820P03oool0oooo00H0
oooo00@0P820000000000000P8204`3oool010010@40000000000000001Y0?ooo`00CP3oool40000
00030820P03oool0oooo0?l0ooooD@3oool01030`<00P8200820P020P80o0?ooo`<00000603oool2
000000030820P03oool0oooo00H0oooo00@0P820000000000000P820403oool00`30`<00P8200000
0003000000030820P03oool0oooo06L0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooomA
0?ooo`040820P0000000000000410Cl0oooo0`00000H0?ooo`80000000<0P8200?ooo`3oool01P3o
ool01020P8000@4100000020P80<0?ooo`80P82000<0@410000000000000100000000`30`<00oooo
0?ooo`1X0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooD@3oool01020P80000000000
0000000l0?ooo`050<30`00000000@41000000010@40100000020820P0h0000000<00@4100000000
00000P3oool00`10@40000000410@0080?ooo`040820P000000000000<30`0`0oooo00<0P8200000
00000000100000000`20P800oooo0?ooo`1Z0?ooo`00CP3oool4000000030820P03oool0oooo0?l0
ooooD@3oool01020P800000000000000000n0?ooo`040410@0000000000000410AP0oooo00<0P820
000000000000203oool00`20P80000000000000>0?ooo`03000000010@4000000080P820KP3oool0
04h0oooo1P00003o0?oooiD0oooo0`00000H0?ooo`030820P0000000000000P0oooo0`00000>0?oo
o`80P820L@3oool004h0oooo1P00003o0?oooiH0oooo00<0@4100000003oool0603oool00`000000
0@410?ooo`070?ooo`80000000<0P8200?ooo`3oool0303oool00`30`<00@4100?ooo`1`0?ooo`00
CP3oool4000000030820P03oool0oooo0?l0ooooU@3oool00`30`<0000000?ooo`0H0?ooo`030820
P0010@400@4100H0oooo00@0`<30000000000000`<303`3oool00`10@400`<300?ooo`1_0?ooo`00
CP3oool4000000030820P03oool0oooo0?l0ooooUP3oool00`10@400oooo0?ooo`0H0?ooo`800000
00<0`<300?ooo`3oool00`3oool00`10@40000000820P00@0?ooo`030<30`011@D40P82000H0P820
00<0`<300?ooo`3oool0IP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oook40oooo00<0
P8200000000000001@3oool00`000000P8200?ooo`0A0?ooo`P0000000<0P8200?ooo`3oool0IP3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?oook80oooo00<0P82000000020P8000`3oool0
0`10@400@D510?ooo`0B0?ooo`030820P0010@40000000H00000J03oool004h0oooo100000000`20
P800oooo0?ooo`3o0?oook<0oooo00<0_kno0410@00000000P0000000`20P800oooo0?ooo`0C0?oo
o`P0P82000<0`<300?ooo`3oool0I@3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0
oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo1000
00000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o
0?ooobl0oooo00@0`<300820P020P800P820o`3oool<0?ooo`00CP3oool4000000030820P03oool0
oooo0?l0oooo;`3oool01020P800000000410@00003o0?ooo``0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3oool_0?ooo`040820P00000000@4100000?l0oooo303oool004h0oooo10000000
0`20P800oooo0?ooo`3o0?ooobl0oooo00@0P8200000000000000000o`3oool<0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0oooo;`3oool01020P800000000000000003o0?ooo``0oooo001>
0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonk0?ooo`0307moO`3oool0oooo0800oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooonj0?ooo`030820P0010@40oooo0840oooo001>0?ooo`@0
000000<0P8200?ooo`3oool0o`3ooonj0?ooo`030410@0000000P8200840oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooonj0?ooo`80000000<0P8200?ooo`3oool0O`3oool004h0oooo1000
00000`20P800oooo0?ooo`3o0?oookT0oooo00@0P8200000000000000000P@3oool004h0oooo1000
00000`10@400P8200?ooo`3o0?oookT0oooo00@0@4100000000000000@41P@3oool004h0oooo1000
00000`10@400P8200?ooo`3o0?oookT0oooo100000000`20P800oooo0?ooo`1n0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0oooo^03oool01P30`<000000000000010@4000000410@800oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonh0?ooo`030820P0000000000000<00000P03o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?oookP0oooo1P0000200?ooo`00CP3oool40000
00030820P03oool0oooo0?l0oooo^03oool6000000030820P03oool0oooo07d0oooo001>0?ooo`@0
000000<0P8200?ooo`3oool0o`3ooong0?ooo`030820P0000000000000@0000000<0@4100?ooo`3o
ool0O@3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oookL0oooo00<0@410000000000000
1@00001o0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo]`3oool8000000030820P03o
ool0oooo07`0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonf0?ooo`03000000010@40
000000H0000000<0P8200?ooo`3oool0O03oool004h0oooo100000000`20P800oooo0?ooo`3o0?oo
okH0oooo2@0000000`10@400oooo0?ooo`1l0?ooo`00CP3oool4000000030820P03oool0oooo0?l0
oooo]@3oool00`20P800000000000008000007h0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0
o`3ooone0?ooo`030410@0000000000000T00000O@3oool004h0oooo100000000`20P800oooo0?oo
o`3o0?oookD0oooo00<00@410000000000002@0000000`30`<00oooo0?ooo`1j0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0oooo]03oool00`20P80000000000000:000000030820P03oool0
oooo07X0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooond0?ooo`030820P00000000000
00X0000000<0P8200?ooo`3oool0NP3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oook@0
oooo00<00@410000000000002P0000000`010@40oooo0?ooo`1j0?ooo`00CP3oool4000000030820
P03oool0oooo0?l0oooo/`3oool00`30`<0000000000000<000000030<30`03oool0oooo07T0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonc0?ooo`030820P0000000000000`0000000<0
Ogmo0?ooo`3oool0N@3oool004h0oooo1P00003o0?oook@0oooo00<0@41000000000000030000000
0`11@D40oooo0?ooo`1i0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo/`3oool@0000
07/0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonb0?ooo`P0000000<00@4100000000
0000100000000`010@4000000<30`01j0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo
/@3oool00`30`<000@41000000030000000300410@0000000000008000000P010@400`0000000@41
00000002000000030820P03oool0oooo07P0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oona0?ooo`030820P0000000000000P0000000<00@410000000000001@00001j0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0oooo/@3oool00`10@40000000000000400000080P8200P000000
1@3oool0`<300000000000000@4100<00000NP3oool004h0oooo100000000`20P800oooo0?ooo`3o
0?oook40oooo1@0000001020P800`<300?ooo`20P80200000080oooo00<0`<300000000000000P00
00000`010@40P8200?ooo`1h0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo/03oool0
0`30`<00000000000002000000050820P03oool0oooo0?ooo`20P8000P0000030?ooo`030<30`000
000000000080000000<0P8200?ooo`3oool0M`3oool004h0oooo100000000`20P800oooo0?ooo`3o
0?oook00oooo00D0P82000000000000000000410@0040?ooo`030820P0000000000000D0oooo00@0
`<3000410@0000000000N@3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oook00oooo00@0
Ogmo0000000000000@411@3oool00`20P8000000000000060?ooo`030820P0000000000007T0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooon`0?ooo`040451@@010@4000000<30`0D0oooo
00<0P8200000000000001`3oool00`10@4000@4100410@1h0?ooo`00CP3oool4000000030820P03o
ool0oooo0?l0oooo/03oool00`000000@4100?ooo`060?ooo`030410@0000000P82000L0oooo00@0
`<3000410@000000`<30M`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oook00oooo00<0
@4100?ooo`3oool01P3oool00`0000000@410?ooo`080?ooo`030<30`0000000P82007L0oooo001>
0?ooo`@0000000<0P8200?ooo`3oool0o`3ooon_0?ooo`030820P030`<00oooo00L0oooo0P00000;
0?ooo`030410@03oool0oooo07D0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonh0?oo
o`030820P0000000000000/0oooo00<0P8200?ooo`3oool0M@3oool004h0oooo100000000`20P800
oooo0?ooo`3o0?ooojl0oooo00<0`<300?ooo`3oool01P3oool00`20P80000000820P00<0?ooo`03
0<30`03oool0oooo07@0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonh0?ooo`030820
P0000000P82008<0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonh0?ooo`030410@000
0000P82008<0oooo001>0?ooo`D0000000<00@410?ooo`3oool0o`3ooong0?ooo`800000Q03oool0
04h0oooo100000000`20P800oooo0?ooo`3o0?oookP0oooo0P0000240?ooo`00CP3oool400000003
0820P03oool0oooo0?l0oooo^03oool00`0000000@410?ooo`230?ooo`00CP3oool4000000030820
P03oool0oooo0?l0oooo]`3oool00`20P8000@410410@0240?ooo`00CP3oool4000000030820P03o
ool0oooo0?l0oooo]`3oool00`20P8000@410820P0240?ooo`00CP3oool4000000030820P03oool0
oooo0?l0oooo]`3oool00`10@40000000820P0240?ooo`00>03oool00`3no_h0oooo0?ooo`0C0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooong0?ooo`0300410@000000oooo08@0oooo000M0?ooo`<0
P8202@3oool00`1oOgl000000410@0060?ooo`030<30`020P800P8200080P8205`3oool400000003
0820P03oool0oooo0?l0oooo]`3oool00`010@4000000?ooo`240?ooo`006`3oool01`20P8000000
0410@020P800@41000000010@4001`3oool00`0000000@41000000050?ooo`030410@0010@400000
00D0000000<0P8200?ooo`3oool04P3oool4000000030820P03oool0oooo0?l0oooo]P3oool20000
00030410@03oool0oooo08<0oooo000J0?ooo`030410@0000000`<3000@0oooo0P10@4070?ooo`03
0820P030`<00oooo00@0oooo0P0000000`20P800`<300?ooo`020?ooo`030820P010@400@41001<0
oooo100000000`20P800oooo0?ooo`3o0?oookH0oooo0P0000000`20P800oooo0?ooo`230?ooo`00
6@3oool00`10@40000000820P0050?ooo`030<30`0000000@41001H0oooo0P10@40B0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooone0?ooo`040<30`000000000000820P8D0oooo000I0?ooo`800000
1`3oool2000001L0oooo00<000000820P03oool0403oool4000000030820P03oool0oooo0?l0oooo
]@3oool00`20P8000000000000260?ooo`00603oool00`20P80000000410@0070?ooo`030820P000
0000000001H0oooo0P10@40A0?ooo`@0000000<0P8200?ooo`3oool0o`3ooone0?ooo`030820P000
0000000008H0oooo000H0?ooo`030410@0000000P82000L0oooo00@0P820000000000000`<305@3o
ool00`20P80000000820P00@0?ooo`@0000000<0P8200?ooo`3oool0o`3ooone0?ooo`80000000<0
@4100?ooo`3oool0Q03oool001P0oooo0P0000000`30`<00oooo0?ooo`050?ooo`040<30`0000000
00000820P1D0oooo00<0P820000000010@40403oool4000000030820P03oool0oooo0?l0oooo]@3o
ool2000000030820P03oool0oooo08@0oooo000H0?ooo`8000002@3oool2000000030820P03oool0
oooo01<0oooo00<0P820000000000000403oool4000000030820P03oool0oooo0=d0oooo00<0o_kn
0?ooo`3oool0d`3oool01020P800000000000020P8260?ooo`005`3oool00`20P800000000000009
0?ooo`<000005@3oool300000100oooo100000000`20P800oooo0?ooo`3o0?oooe00oooo00<0o_kn
0?ooo`3oool0H@3oool00`20P8000000000000270?ooo`005`3oool00`20P8000000000000090?oo
o`<00000503oool01020P800000000000020P80@0?ooo`@0000000<0P8200?ooo`3oool0]03oool0
1@0000000@41000000000000P8200240oooo00D0P82000000000000000000820P00P0?ooo`050820
P00000000@4100000020P8008@3oool00`20P80000000000000200000200oooo100000000`20P800
oooo0?ooo`0N0?ooo`@0000000<0P8200?ooo`3oool0?@3oool00`10@4000000000000270?ooo`00
5`3oool00`20P8000000000000090?ooo`<000004`3oool01030`<00000000000000000A0?ooo`@0
000000@0@4100820P020P800P820/`3oool4000000030820P03oool0oooo01l0oooo00D0P8200041
0@00000000000820P00P0?ooo`050820P0000000000000000020P8008@3oool00`20P80000000000
000200000200oooo00D0000000410@00000000000820P00P0?ooo`@0000000<0P8200?ooo`3oool0
?03oool00`2o_kl00000000000280?ooo`005`3oool00`20P8000000000000090?ooo`80000000<0
0@410?ooo`3oool03`3oool00`30`<00P82000000002000000030820P03oool0oooo00l0oooo1000
00001010@400P8200820P020P82c0?ooo`05000000010@400@4100000020P8008@3oool01@20P800
0000000000010@40P8200200oooo00D0P82000410@010@4000000820P00Q0?ooo`030820P0000000
000000800000803oool30000000300410@20P800oooo01l0oooo100000000`20P800oooo0?ooo`0l
0?ooo`030820P0000000@D5108P0oooo000G0?ooo`030820P0000000000000T0oooo0`00000@0?oo
o`030820P0000000000000<000004P3oool4000000030820P03oool0oooo0;@0oooo100000000`20
P800oooo0?ooo`0O0?ooo`050820P0000000000000000020P800803oool01@20P800000000000000
0000P8200240oooo00<0P8200000000000000P00000P0?ooo`@0000000<0P8200?ooo`3oool07P3o
ool4000000030820P03oool0oooo03`0oooo0P0000000`20P800oooo0?ooo`260?ooo`005`3oool0
0`20P8000@41000000090?ooo`<00000303oool20820P0030410@000000000000080000000<00@41
00000030`<004P3oool4000000030820P03oool0oooo0;@0oooo1020P8000`30`<00oooo0?ooo`0O
0?ooo`050<30`020P800P8200820P030`<00803oool01@30`<00P8200820P020P800`<300240oooo
00<0`<300820P020P8000P20P80P0?ooo`@0P82000<0`<300?ooo`3oool07P3oool40820P0030<30
`03oool0oooo03/0oooo00<0P82000410@000000R@3oool001L0oooo00@0`<30000000000000`<30
203oool2000000030410@03oool0oooo00X0oooo00<0@410000000010@400P0000000`010@400000
0820P00D0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonb0?ooo`80000000<0@4100?ooo`3oool0
Q`3oool001P0oooo0P0000000`20P800oooo0?ooo`060?ooo`80000000<0P8200?ooo`3oool02P3o
ool01P20P8000000000000000000P8200<30`1H0oooo100000000`20P800oooo0?ooo`3o0?oook40
oooo00@0P820000000000000`<30R@3oool001P0oooo00<0@41000000020P8001`3oool01020P800
000000000030`<0=0?ooo`0300000020P800oooo01P0oooo100000000`20P800oooo0?ooo`3o0?oo
ok40oooo0P0000000`010@40oooo0?ooo`280?ooo`00603oool00`20P80000000820P0070?ooo`03
0820P0000000000000l0oooo00<000000?ooo`3oool05`3oool4000000030820P03oool0oooo0?l0
oooo/@3oool2000000030820P03oool0oooo08P0oooo000I0?ooo`8000001`3oool00`10@4000000
0820P00?0?ooo`030410@030`<00oooo01L0oooo100000000`20P800oooo0?ooo`3o0?oook00oooo
00@0P820000000000000P820RP3oool001T0oooo00<0P82000000020P8001@3oool00`30`<000@41
0410@00@0?ooo`030<30`010@400P82000H0P8204@3oool4000000030820P03oool0oooo0?l0oooo
/03oool3000008/0oooo000J0?ooo`030410@0000000P82000@0oooo0P10@40B0?ooo`030410@001
0@40000000D0000000<0P8200?ooo`3oool03P3oool4000000030820P03oool0oooo0?l0oooo[`3o
ool00`30`<000@410000002<0?ooo`006`3oool00`20P80000000410@0020820P00300000010@400
oooo0180oooo00<0`<300000000000001P0000000`30`<00oooo0?ooo`0=0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooon_0?ooo`030410@0000000P82008`0oooo000M0?ooo`<00000;P3oool40000
00030820P03oool0oooo0?l0oooo[`3oool2000008d0oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooon^0?ooo`030820P0000000@41008d0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0
o`3ooon^0?ooo`03000000010@40`<3008d0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oon]0?ooo`80000000<0@D510?ooo`3oool0S03oool004h0oooo100000000`20P800oooo0?ooo`3o
0?oooj`0oooo00<0P820000000000000S`3oool004h0oooo100000000`20P800oooo0?knoP3o0?oo
oj`0oooo0P0000000`20P800oooo0?ooo`2=0?ooo`00CP3oool4000000030820P03oool0oooo0?l0
ooooZ`3oool01030`<00000000000030`<2?0?ooo`00CP3oool600000?l0oooo[03oool00`10@400
00000820P02@0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooZP3oool00`20P8000000
0410@02A0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooZ@3oool00`30`<0000000041
0@2B0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooZ@3oool00`20P80000000820P02B
0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooZ03oool00`20P8000@410000002C0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0ooooY`3oool01030`<00000000000030`<2C0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0ooooYP3oool01030`<000@4100000010@42D0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0ooooYP3oool00`10@40000000820P02E0?ooo`00
CP3oool4000000030820P03oool0oooo0?l0ooooY@3oool00`20P80000000000002F0?ooo`00CP3o
ool4000000030820P03oool0oooo0?l0ooooY@3oool00`10@40000000<30`02F0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0ooooY03oool00`10@40000000410@02G0?ooo`00CP3oool40000
00030820P03oool0oooo0?l0ooooXP3oool01@30`<000000000000000000`<3009L0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooonQ0?ooo`050<30`0000000000000410@30`<00V03oool0
04h0oooo100000000`20P800oooo0?ooo`3o0?oooj40oooo0`0000000`20P800oooo0?ooo`2G0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0ooooX03oool01010@400000000000020P82J0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0ooooW`3oool01010@400000000000030`<2K0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0ooooW@3oool01@30`<00000000410@000000`<30
09`0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonM0?ooo`<0000000<0P8200?ooo`3o
ool0V`3oool004h0oooo100000000`20P800oooo0?ooo`2d0?ooo`@0P82000<0`<300?ooo`3oool0
]03oool40820P0030<30`03oool0oooo02@0oooo00D0`<3000000000000000000410@02N0?ooo`00
CP3oool4000000030820P03oool0oooo0;@0oooo100000000`20P800oooo0?ooo`2d0?ooo`@00000
00<0P8200?ooo`3oool08`3oool01@10@400000000000011@D40P82009l0oooo001>0?ooo`H00000
]@3oool4000000030820P03oool0oooo0;@0oooo100000000`20P800oooo0?ooo`0Q0?ooo`050820
P0000000000000000010@400X@3oool004h0oooo100000000`20P800oooo0?ooo`2d0?ooo`@00000
00<0P8200?ooo`3oool0]03oool4000000030820P03oool0oooo01l0oooo00<0`<300410@0000000
0P0000000`30`<00oooo0?ooo`2P0?ooo`00CP3oool4000000030820P03oool0oooo0;@0oooo1000
00000`20P800oooo0?ooo`2d0?ooo`@0000000<0P8200?ooo`3oool07`3oool4000000030820P03o
ool0oooo0:40oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonF0?ooo`030820P0000000
@4100:D0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooonG0?ooo`030<30`03oool0oooo
0:@0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oooo0?ooocl0oooo001>0?ooo`@0000000<0@4100820P03oool0o`3ooooo0?ooocl0oooo001>0?oo
o`@0000000<0@4100820P03oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3o
ool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo
001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooooo0?ooocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0]03oool4000000030820P03oool0oooo0;@0
oooo100000000`20P800oooo0?ooo`370?ooo`00CP3oool4000000030820P03oool0oooo0;@0oooo
100000000`20P800oooo0?ooo`2d0?ooo`@0000000<0P8200?ooo`3oool0a`3oool004h0oooo1@00
00000`010@40oooo0?ooo`2c0?ooo`@0000000<0P8200?ooo`3oool0]03oool4000000030820P03o
ool0oooo0<L0oooo001>0?ooo`@0000000<0P8200?ooo`3oool0]03oool4000000030820P03oool0
oooo0;@0oooo100000000`20P800oooo0?ooo`370?ooo`00CP3oool4000000030820P03oool0oooo
0;@0oooo1020P8000`30`<00oooo0?ooo`2d0?ooo`@0P82000<0`<300?ooo`3oool0a`3oool004h0
oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo
0?ooo`2d0?ooo`030?knoP3oool0oooo0?l0ooooQ`3oool004h0oooo100000000`20P800oooo0?oo
o`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool0
04h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800
oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo
?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo10000000
0`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?oo
ool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo
100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?oo
o`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool0
04h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo2000003o0?ooool0
oooo?P3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo1000
00000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o
0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0
oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo
0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20
P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0
oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo1000
00000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o
0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0
oooo100000000`1oOgl0oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo
0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`2d0?ooo`@0000000<0
P8200?ooo`3oool0]03oool4000000030820P03oool0oooo0<L0oooo001>0?ooo`@0000000<0@410
0820P03oool0]03oool4000000030820P03oool0oooo0;@0oooo100000000`20P800oooo0?ooo`37
0?ooo`00CP3oool4000000030410@020P800oooo0;@0oooo100000000`20P800oooo0?ooo`2d0?oo
o`@0000000<0P8200?ooo`3oool0a`3oool004h0oooo100000000`20P800oooo0?ooo`2d0?ooo`@0
000000<0P8200?ooo`3oool0]03oool4000000030820P03oool0oooo0<L0oooo001>0?ooo`@00000
00<0P8200?ooo`3oool0]03oool40820P0030<30`03oool0oooo0;@0oooo1020P8000`30`<00oooo
0?ooo`370?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo
0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00
CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03o
ool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo
0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool400000003
0820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0oooo
o`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4
000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo
0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00
CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03o
ool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool600000?l0ooooo`3ooom00?ooo`00CP3oool40000
00030410@020P800oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0
ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3o
ool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0
oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?oo
o`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820
P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3o
oolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool40000
00030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0
ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3o
ool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0
oooo0?l0ooooo`3ooolo0?ooo`00CP3oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?oo
o`00CP3oool4000000030820P03oool0oooo0;@0oooo1020P8000`30`<00oooo0?ooo`2d0?ooo`@0
P82000<0`<300?ooo`3oool0a`3oool004h0oooo100000000`10@400P8200?ooo`2d0?ooo`@00000
00<0P8200?ooo`3oool0]03oool4000000030820P03oool0oooo0<L0oooo001>0?ooo`H00000]@3o
ool4000000030820P03oool0oooo0;@0oooo100000000`20P800oooo0?ooo`370?ooo`00CP3oool4
000000030820P03oool0oooo0;@0oooo0`0000000`010@40P8200?ooo`2e0?ooo`@0000000<0P820
0?ooo`3oool0a`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0
oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo
0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20
P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0
oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo1000
00000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o
0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0
oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo
0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000001020
P800oooo0?ooo`3no_ko0?ooool0oooo?P3oool004h0oooo1P00003o0?ooool0oooo@03oool004h0
oooo100000000`10@400P8200?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo
0?ooo`3o0?ooool0oooo?`3oool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3o
ool004h0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool003@0oooo00<0`<300820
P020P8001@20P8000`30`<00oooo0?ooo`0?0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ocl0oooo000f0?ooo`050<30`0000000000000000030`<004`3oool4000000030820P03oool0oooo
0?l0ooooo`3ooolo0?ooo`00=`3oool3000001@0oooo100000000`20P800oooo0?ooo`3o0?ooool0
oooo?`3oool003L0oooo0`00000D0?ooo`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo
000g0?ooo`<00000503oool4000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00=`3oool3
000001@0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo?`3oool003L0oooo0`00000D0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooooo0?ooocl0oooo000g0?ooo`<00000503oool400000003
0820P03oool0oooo0140oooo00<0P8200<30`03oool0o`3ooooo0?ooob/0oooo000g0?ooo`<00000
503oool4000000030820P03oool0oooo0140oooo00<0P8200000003oool0o`3ooooo0?ooob/0oooo
000g0?ooo`<00000503oool4000000030820P03oool0oooo0140oooo00@0P820000000000000`<30
o`3ooooo0?ooobX0oooo000g0?ooo`<00000503oool4000000030820P03oool0oooo0140oooo00D0
P820000000000000@4100<30`03o0?ooool0oooo:@3oool003L0oooo0`00000D0?ooo`@0000000<0
P8200?ooo`3oool04@3oool01@20P80000000000003oool0@4100?l0oooo>P3oool00`3no_h0oooo
0?ooo`3[0?ooo`00=`3oool3000001@0oooo100000000`20P800oooo0?ooo`0A0?ooo`0600000001
0@4000000?ooo`30`<00@410W@3oool01@0000000@41000000000000P8200240oooo00D0P8200000
0000000000000820P00P0?ooo`050820P00000000@4100000020P8008@3oool00`20P80000000000
000200000200oooo100000000`20P800oooo0?ooo`0N0?ooo`@0000000<0P8200?ooo`3oool0a`3o
ool003L0oooo0`00000F0?ooo`H00000403oool300000080oooo0P20P82L0?ooo`@0000000<0P820
0?ooo`3oool07`3oool01@20P8000@41000000000000P8200200oooo00D0P8200000000000000000
0820P00Q0?ooo`030820P0000000000000800000803oool01@0000000@41000000000000P8200200
oooo100000000`20P800oooo0?ooo`370?ooo`00=`3oool3000001H0oooo1P00000@0?ooo`<00000
0`3oool00`000000oooo0?ooo`2J0?ooo`@0000000<0P8200?ooo`3oool07`3oool01@20P8000000
000000000000P8200200oooo00D0P82000000000000000000820P00Q0?ooo`030820P00000000000
00800000803oool30000000300410@20P800oooo01l0oooo100000000`20P800oooo0?ooo`370?oo
o`00=`3oool3000002`0oooo0P010@440?ooo`030<30`0000000`<3009X0oooo100000000`20P800
oooo0?ooo`0O0?ooo`050820P0000000000000410@20P800803oool01@20P8000000000000000000
P8200240oooo00<0P8200000000000000P00000P0?ooo`8000000P010@400`20P800oooo0?ooo`0N
0?ooo`@0000000<0P8200?ooo`3oool0a`3oool003L0oooo0`00000[0?ooo`030<30`00000000000
00D0oooo00<0P8200410@03oool0o`3ooooo0?ooob@0oooo000g0?ooo`<00000:`3oool00`20P800
0000000000060?ooo`030410@030`<00oooo0?l0ooooo`3ooolS0?ooo`00=`3oool3000002/0oooo
00<0P8200000000000001P3oool20820P?l0ooooo`3ooolT0?ooo`00=`3oool3000002/0oooo00<0
@41000000010@4001@3oool00`20P80000000000003o0?ooool0oooo903oool003@0oooo00H0P820
0?ooo`30`<00000000410@00000Z0?ooo`040820P000000000000820P0@0oooo00@0@41000000000
00000000o`3ooooo0?ooob@0oooo000d0?ooo`060<30`010@4000@41000000010@400000:03oool0
0`20P800000000000002000000030<30`03oool0oooo0080oooo0`0000000`10@400oooo0?ooo`3o
0?ooool0oooo8P3oool003H0oooo00@0`<300410@00000000000;03oool00`20P800oooo0?ooo`03
0?ooo`030<30`020P800P8200?l0ooooo`3ooolU0?ooo`00>@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooF03oool00?l0ooooI@3oool20820P0030<30`03oool0oooo0?l0oooo:P3oool00?l0oooo
I03oool01@10@4000000000000000000@41001T0oooo00H0`<300820P0010@400@4100000020P83o
0?ooo``0oooo003o0?ooof<0oooo00@0P82000000000000000000`20P80G0?ooo`090<30`0000000
P8200<30`03oool0`<300410@0000000`<300?l0oooo2P3oool00?l0ooooH`3oool00`20P8000000
000000030?ooo`030<30`03oool0oooo01@0oooo00<0`<3000410@20P8001@3oool2000000030<30
`03oool0oooo0?l0oooo1`3oool00?l0ooooH`3oool00`20P80000000000000J0?ooo`8000001`3o
ool00`0000000@410?ooo`3o0?ooo`P0oooo003o0?ooof<0oooo00<0P8200000000000006@3oool0
0`30`<000000000000070?ooo`030410@0000000`<300?l0oooo203oool00?l0ooooH`3oool00`20
P80000000000000I0?ooo`030820P0000000P82000H0oooo00@0o_kn0820P0010@40P820o`3oool8
0?ooo`00o`3ooomS0?ooo`030820P0000000000001T0oooo0P0000000`20P800oooo0?ooo`050?oo
o`030820P000000000000?l0oooo203oool00?l0ooooH`3oool00`20P80000000000000I0?ooo`80
00002@3oool200000?l0oooo203oool00?l0ooooH`3oool00`20P80000000000000H0?ooo`<00000
2@3oool2000000030820P03oool0oooo0?l0oooo1@3oool00?l0ooooH`3oool00`20P80000000000
00040?oooa80P8200P3oool3000000T0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`D0oooo003o
0?ooof<0oooo00<0P820000000000000103ooolB0820P080oooo0`0000090?ooo`80000000<0P820
0?ooo`3oool0o`3oool50?ooo`00o`3ooomS0?ooo`030820P0000000000001P0oooo00<00@410000
00010@402@3oool2000000030820P03oool0oooo0?l0oooo1@3oool00?l0ooooH`3oool01020P800
00000000003no_hG0?ooo`80000000<00@410?ooo`3oool01`3oool2000000030820P03oool0oooo
0?l0oooo1@3oool00?l0ooooH`3oool01020P80000000000003no_hG0?ooo`<000002@3oool20000
00030820P03oool0oooo0?l0oooo1@3oool00?l0ooooH03oool01030`<00Ogmo0820P010@4020000
00<0P82000<0`<300820P020P8004020P8020?ooo`<000002@3oool2000000030820P03oool0oooo
0?l0oooo1@3oool00?l0ooooH@3oool00`20P800@41000000002000000<0P82000<0`<300820P020
P8004020P8030?ooo`0300410@000000P82000P0oooo0P00003o0?ooo`P0oooo003o0?ooof<0oooo
00<0@4100000000000006@3oool00`010@4000000820P0070?ooo`030<30`000000000000?l0oooo
203oool00?l0ooooI03oool2000001T0oooo00<0P82000000020P8001`3oool00`20P80000000820
P03o0?ooo`P0oooo003o0?ooof@0oooo00<0P8200000003oool0603oool00`30`<0000000410@007
0?ooo`030820P0000000P8200?l0oooo203oool00?l0ooooI@3oool00`010@40oooo0?ooo`0H0?oo
o`030410@0010@40oooo00H0oooo0P00003o0?ooo`T0oooo003o0?ooofD0oooo00<0`<300?ooo`3o
ool0603oool00`30`<0000000410@0050?ooo`03000000010@40`<300?l0oooo2@3oool00?l0oooo
P@3oool01030`<000@410820P030`<020?ooo`030410@0010@40`<300?l0oooo2P3oool00?l0oooo
PP3oool00`20P80000000000000300000?l0oooo303oool00?l0ooooQ03oool30820P?l0oooo3@3o
ool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0oooo
o`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?oo
o`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo
0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo
003o0?ooool0ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0
ooooU03oool00?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool0
0?l0ooooo`3ooonD0?ooo`00o`3ooooo0?oooi@0oooo003o0?ooool0ooooU03oool00?l0ooooo`3o
oonD0?ooo`00o`3ooooo0?oooi@0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{219.562, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 1.5 Flow of a set of initial conditions for ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["x,v",
    FontSlant->"Italic"],
  ") = -",
  StyleBox["x",
    FontSlant->"Italic"],
  " - ",
  StyleBox["v.",
    FontSlant->"Italic"]
}], "Caption",
  CellTags->"Fig. 1.5"],

Cell[TextData[{
  "\tDissipative systems -- systems that lose energy-- have the property that \
phase-space area shrinks over time. On the other hand, nondissipative systems \
, which conserve energy, can be shown to conserve phase-space area. Consider, \
for example, the direction field associated with motion in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  ". Newton's equation of motion is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"m", " ", 
            FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
              MultilineFunction->None]}], "=", 
          RowBox[{"-", 
            FractionBox[\(\[PartialD]V\), \(\[PartialD]x\),
              MultilineFunction->None]}]}], TraditionalForm]]],
  ", or in terms of phase-space coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
              MultilineFunction->None], "=", "v"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
            FractionBox[\(\[DifferentialD]v\), \(\[DifferentialD]t\),
              MultilineFunction->None], "=", 
            RowBox[{\(-\(1\/m\)\), 
              RowBox[{
                FractionBox[\(\[PartialD]V\), \(\[PartialD]x\),
                  MultilineFunction->None], "."}]}]}]}], TraditionalForm]]],
  "\t"
}], "NE2",
  CellTags->"(1.2.11)"],

Cell[TextData[{
  "\tAccording to ",
  ButtonBox["Eq. (1.2.10)",
    ButtonData:>"(1.2.10)",
    ButtonStyle->"Hyperlink"],
  ", the projection of the direction field onto the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane has components (",
  StyleBox["v",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(-\(1\/m\)\), 
          FractionBox[\(\[PartialD]V\), \(\[PartialD]x\),
            MultilineFunction->None]}], TraditionalForm]]],
  " ). One can prove that this flow is area-conserving by showing that it is \
",
  StyleBox["divergence-free",
    FontSlant->"Italic"],
  ". It is easiest at first to discuss such flows in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane, rather than the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane. A flow in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane, described by a vector field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", \(x, y\), ")"}], 
          "=", \((\(v\_x\)(x, y), \(v\_y\)(x, y))\)}], TraditionalForm]]],
  ", is divergence-free if the flow satisfies "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              RowBox[{
                StyleBox["v",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontSlant->"Italic"], 
                StyleBox[\(x, y\),
                  FontSlant->"Italic"], 
                StyleBox[")",
                  FontSlant->"Italic"]}]}]}], "=", 
          RowBox[{
            RowBox[{
              FractionBox[\(\[PartialD]v\_x\), \(\[PartialD]x\),
                MultilineFunction->None], \( \[VerticalSeparator] \_y\), 
              RowBox[{"+", 
                FractionBox[\(\[PartialD]v\_y\), \(\[PartialD]y\),
                  MultilineFunction->None]}], \( \[VerticalSeparator] \_x\)}],
             "=", " ", "0"}]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(1.2.12)"],

Cell[TextData[{
  "where we have explicitly shown what is held fixed in the derivatives.  The \
connection between this divergence and the area of the flow can be understood \
by examining  Fig. ",
  ButtonBox["1.6",
    ButtonData:>"Fig. 1.6",
    ButtonStyle->"Hyperlink"],
  ", which depicts an area ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " moving with the flow. The  differential change ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]S\)]],
  " in the area as the boundary ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " moves by  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[DifferentialD]", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]S\), "=", 
          RowBox[{\(\[ContourIntegral]\_C\), 
            RowBox[{
              RowBox[{
                RowBox[{"\[DifferentialD]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], "\[CenterDot]", 
                OverscriptBox[
                  StyleBox["n",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"]}], \(\[DifferentialD]l\)}]}]}], 
        TraditionalForm]]],
  ",  where ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]l\)]],
  " is a line element along ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["n",
            FontWeight->"Bold",
            FontSlant->"Plain"], "^"], TraditionalForm]]],
  " is the unit vector normal to the edge, pointing out from the surface. \
Dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  ", using ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}]}], 
        TraditionalForm]]],
  ", and applying the ",
  StyleBox["divergence theorem",
    FontSlant->"Italic"],
  ",  we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]S/\[DifferentialD]t\), "=", 
          RowBox[{
            RowBox[{\(\[ContourIntegral]\_C\), 
              RowBox[{
                RowBox[{
                  StyleBox["v",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "\[CenterDot]", 
                  OverscriptBox[
                    StyleBox["n",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "^"]}], \(\[DifferentialD]l\)}]}], 
            "=", 
            RowBox[{\(\[Integral]\_S\), 
              RowBox[{
                RowBox[{"\[Del]", 
                  RowBox[{"\[CenterDot]", 
                    StyleBox["v",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]}], 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ".  "
}], "NE2",
  CellTags->"(1.2.13)"],

Cell[TextData[{
  "Thus, the rate of change of the area ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]S/\[DifferentialD]t\)]],
  " equals zero if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain",
            FontSlant->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", proving that divergence-free flows are area-conserving."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66116 
%%ImageSize: 605 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00157418 0.0157418 0.00157418 [
[ 0 0 0 0 ]
[ 1 .66116 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66116 L
0 .66116 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01574 translate
.95238 .62968 scale
1815 string
605 400 8 [605 0 0 400 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFF000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{173.75, 114.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000890001F2000`400?l00000o`00003ooooooooo
ooooo`_ooooo003ooooooooooooo2oooool00?ooooooooooool;ooooo`00ooooooooooooo`_ooooo
003ooooooooooooo2oooool00?ooooooooooool;ooooo`00ooooooooooooo`_ooooo003ooooooooo
oooo2oooool00?ooooooooooool;ooooo`003?oooooo0?oooo00oooo3_ooool000coooooeP3oool/
00000>d0oooo3_ooool000cooooo`03oool<0820P3d000001`20P83O0?ooo`kooooo000<oooook`0
ooooF`00003H0?ooo`kooooo000<oooookP0oooo7P00000/0<W9bAX00000d`3oool>ooooo`003?oo
oond0?oooaP00000?039bLTI00000<h0oooo3_ooool000coooooZ`3oool40820P0h00000101UIFE?
0<W9b@H0IFEU400000050820P<@0oooo3_ooool000coooooZ03ooolA00000680bLW94`0000310?oo
o`kooooo000<oooooj@0oooo00<0P8200000000000003P00001/0<W9bA000000_P3oool>ooooo`00
3?oooonQ0?ooo`l00000MP39bLT>000000030820P03oool0oooo0;P0oooo3_ooool000coooooW@3o
ool?000007h0bLW93@00002h0?ooo`kooooo000<oooooiH0oooo00@0`<300820P020P800P8202`00
000306EUI@0309NGU`39bLT0bLW90880bLW90`1UIFD:000000<0P82000<0`<300?ooo`3oool0[`3o
ool>ooooo`003?oooonD0?ooo`h00000TP39bLT<00000:l0oooo3_ooool000coooooTP3oool<0000
09P0bLW93000002]0?ooo`kooooo000<ooooohl0oooo3000002N0<W9b@`00000ZP3oool>ooooo`00
3?oooon:0?ooo`<0P8202000000206EUIJH0bLW90P1UIFD8000000<0P820Y@3oool>ooooo`003?oo
oon80?ooo`X0000000<0IFEU0<W9b@39bLT0[039bLT00`1UIFD000000000000800000:<0oooo3_oo
ool000coooooQ@3oool;00000;@0bLW92`00002P0?ooo`kooooo000<oooooh<0oooo2`00002h0<W9
b@X00000W`3oool>ooooo`003?oooon10?ooo`/00000_039bLT:000009d0oooo3_ooool000cooooo
OP3oool20820P0L000000P1UIFD00`2GUiL0bLW90<W9b@2n0<W9b@0309NGU`1UIFD0IFEU00H00000
00<0@4100820P020P800V@3oool>ooooo`003?ooooml0?ooo`P0000000<0IFEU0<W9b@39bLT0b039
bLT9000009L0oooo3_ooool000coooooN`3oool800000<d0bLW92@00002F0?ooo`kooooo000<oooo
ogP0oooo2@00003A0<W9b@T00000U03oool>ooooo`003?oooome0?ooo`80P8201P00000206EUIMD0
bLW90P1UIFD6000000030410@020P800oooo0900oooo3_ooool000coooooL`3oool80000000306EU
I@39bLT0bLW90=X0bLW92000002?0?ooo`kooooo000<ooooog80oooo2000003O0<W9b@T00000S@3o
ool>ooooo`003?oooom`0?ooo`P00000h`39bLT9000008/0oooo3_ooool000coooooKP3oool00`20
P80000000000000500000>H0bLW900<0IFEU0000000000001P0000000`20P800oooo0?ooo`270?oo
o`kooooo000<ooooof`0oooo0P20P8050000000306EUI@39bLT0bLW90>P0bLW90`1UIFD600000080
P820QP3oool>ooooo`003?oooom[0?ooo`L00000l039bLT8000008D0oooo3_ooool000coooooJ@3o
ool00`20P80000000000000500000?<0bLW91`0000240?ooo`kooooo000<ooooofT0oooo1P00003f
0<W9b@0306EUI@000000000000D00000PP3oool>ooooo`003?oooomV0?ooo`030820P00000000000
00@0000000<0IFEU0<W9b@39bLT0m`39bLT00`1UIFD0000000000004000000030410@03oool0oooo
07h0oooo3_ooool000coooooI@3oool600000?l0bLW91`00001n0?ooo`kooooo000<ooooof@0oooo
1@0000000`1UIFD0bLW90<W9b@3o0<W9b@P00000O03oool>ooooo`003?oooomS0?ooo`H00000o`39
bLT50<W9b@H0000000<0P8200?ooo`3oool0N@3oool>ooooo`003?oooomQ0?ooo`H00000o`39bLT8
0<W9b@L00000NP3oool>ooooo`003?oooomP0?ooo`030410@000000000000080000000<0UiNG0<W9
b@39bLT0o`39bLT80<W9b@80IFEU1P0000000`30`<00oooo0?ooo`1e0?ooo`kooooo000<oooooeh0
oooo1P00003o0<W9b@l0bLW91`00001f0?ooo`kooooo000<oooooed0oooo1P00003o0<W9bA40bLW9
00<0IFEU0000000000001@00001d0?ooo`kooooo000<oooooe`0oooo00<0P8200000000000000`00
003o0<W9bA@0bLW91`0000000`20P800oooo0?ooo`1`0?ooo`kooooo000<oooooe/0oooo00<0P820
0000000000000P0000000`0c<c<0bLW90<W9b@3o0<W9bA@0bLW900<0IFEU03<c<`00000010000002
0820P700oooo3_ooool000coooooF@3oool600000?l0bLW96`39bLT7000006l0oooo3_ooool000co
ooooF03oool600000?l0bLW97P39bLT6000006h0oooo3_ooool000coooooE`3oool00`20P8000000
0000000300000?l0bLW98039bLT6000006d0oooo3_ooool000coooooE`3oool50000000306EUI@39
bLT0bLW90?l0bLW97`39bLT7000006/0oooo3_ooool000coooooE03oool00`20P800000000000004
0000000306EUI@39bLT0bLW90?l0bLW98@39bLT206EUI@D0000000<0P8200?ooo`3oool0I`3oool>
ooooo`003?oooomC0?ooo`030820P0000000000000@00000@@39bLT[00000;X0bLW900<0IFEU0000
000000001000001X0?ooo`kooooo000<oooooe<0oooo00<0P8200000000000000P00000h0<W9bCd0
0000]@39bLT6000006L0oooo3_ooool000coooooD`3oool40000000306EUI@39bLT0bLW902X0bLW9
00<0IFEU000000000000C@00002_0<W9b@H0000000<0P8200?ooo`3oool0H`3oool>ooooo`003?oo
oomB0?ooo`<000000P1UIFDU0<W9b@@0IFEU00<0<c<c0000000000006000000[06EUIAD000001@1U
IFFU0<W9b@0303<c<`0000000000008000000P20P81S0?ooo`kooooo000<oooooe40oooo1000000S
0<W9bAP00000?039bLT00`1UIFD000000000000F00000:40bLW91`00001R0?ooo`kooooo000<oooo
oe00oooo1000000O0<W9bA800000C`39bLTF000009h0bLW91P00001Q0?ooo`kooooo000<ooooodl0
oooo100000000`1UIFD0bLW90<W9b@0I0<W9bA800000F@39bLT00`1UIFD000000000000B000009X0
bLW91P00001P0?ooo`kooooo000<ooooodh0oooo00D0P820000000000000000006EUI@0F0<W9b@<0
IFEU3@00000406EUIF80bLW91P1UIFD=000000<0IFEU00<0UiNG0<W9b@39bLT0TP39bLT00`1UIFD0
00000000000300000080P820G@3oool>ooooo`003?oooom>0?ooo`@000004`39bLT00`1UIFD00000
0000000<000007H0bLW93`00002C0<W9b@H0000000<0P8200?ooo`3oool0FP3oool>ooooo`003?oo
oom=0?ooo`@000004039bLT?000007h0bLW93@00002C0<W9b@H00000F`3oool>ooooo`003?oooom<
0?ooo`@000003P39bLT?000008@0bLW93@0000000`1UIFD0bLW90<W9b@2=0<W9b@0306EUI@000000
000000@00000FP3oool>ooooo`003?oooom;0?ooo`@000003039bLT>0000000306EUI@39bLT0bLW9
08T0bLW93@00002>0<W9b@D00000FP3oool>ooooo`003?oooom:0?ooo`050820P000000000000000
000c<c<01`39bLT206EUI@X00000101UIFFB0<W9b@80IFEU2P00000306EUIHX0bLW900<0IFEU03<c
<`0000000P0000000`20P800oooo0?ooo`1F0?ooo`kooooo000<ooooodX0oooo100000050<W9b@03
06EUI@000000000000T00000W`39bLT;000008T0bLW900<0IFEU0000000000000`00001G0?ooo`ko
oooo000<ooooodT0oooo100000050<W9b@X00000Y@39bLT:0000000306EUI@39bLT0bLW908D0bLW9
1P00001F0?ooo`kooooo000<ooooodT0oooo100000020<W9b@X00000ZP39bLT;000008H0bLW91P00
001E0?ooo`kooooo000<ooooodL0oooo00<0P8200000000000000P0000000`1UIFD0000000000005
000000<0IFEU[`39bLT206EUI@P0000000<0<c<c06EUI@1UIFD0P`39bLT00`1UIFD0000000000002
000000030<30`03oool0oooo0540oooo3_ooool000coooooA`3oool<00000;L0bLW92P0000000`1U
IFD0bLW90<W9b@200<W9b@0306EUI@000000000000<00000DP3oool>ooooo`003?oooom50?ooo`03
0820P0000000000000P00000_039bLT:00000880bLW91P00001A0?ooo`kooooo000<oooood@0oooo
2P0000310<W9b@T00000P@39bLT600000500oooo3_ooool000cooooo@P3oool900000<H0bLW92@00
00210<W9b@D00000C`3oool>ooooo`003?oooolo0?ooo`80P820200000000`1UIFD0bLW90<W9b@37
0<W9b@0306EUI@0c<c<0000000H0000000<0IFEU09NGU`39bLT0O039bLT00`2GUiL0000000000002
000000030410@03oool0oooo04`0oooo3_ooool000cooooo?03oool00`20P80000000000000:0000
0<d0bLW92@00001n0<W9b@H00000C03oool>ooooo`003?oooolk0?ooo`P0000000<0oooo00000000
00000P00003A0<W9b@P00000O@39bLT6000004/0oooo3_ooool000cooooo>@3oool8000000030820
P03oool0oooo00@00000dP39bLT80000000306EUI@39bLT0bLW907X0bLW91@0000000`20P800oooo
0?ooo`180?ooo`kooooo000<ooooocH0oooo0P20P80600000080P8200`3oool400000=D0bLW900<0
IFEU03<c<`0000001@00000206EUI@0309NGU`39bLT0bLW907L0bLW900<0UiNG0000000000000P00
00000`20P800oooo0?ooo`170?ooo`kooooo000<ooooocD0oooo1`0000000`20P800oooo0?ooo`03
0?ooo`@00000f@39bLT9000007X0bLW91P0000170?ooo`kooooo000<oooooc<0oooo00<0P8200000
00000000100000080?ooo`@00000f`39bLT9000007T0bLW91P0000160?ooo`kooooo000<oooooc<0
oooo1@0000000`20P800oooo0?ooo`060?ooo`050820P000000000000000001UIFD0g039bLT00`1U
IFD00000000000060000000306EUI@39bLT0bLW907H0bLW91@0000000`20P800oooo0?ooo`130?oo
o`kooooo000<oooooc40oooo1`0000090?ooo`050820P000000000000000001UIFD0g`39bLT60000
000306EUI@39bLT0bLW907L0bLW91@0000150?ooo`kooooo000<ooooobl0oooo00<0P82000000000
00000`0000000`20P800oooo0?ooo`090?ooo`040410@0000000000000000>40bLW900<0UiNG06EU
I@0000001000000206EUIGL0bLW900<0IFEU0000000000000P0000000`20P800oooo0?ooo`110?oo
o`kooooo000<ooooobh0oooo1@0000000`20P800oooo0?ooo`0;0?ooo`@00000i@39bLT500000003
06EUI@39bLT0bLW907H0bLW91@0000120?ooo`kooooo000<ooooob`0oooo1P00000>0?ooo`@00000
i`39bLT00`1UIFD0000000000003000007P0bLW9100000000`20P800oooo0?ooo`0o0?ooo`kooooo
000<ooooobX0oooo00<0P8200000000000001000000?0?ooo`<00000j@39bLT7000007H0bLW900<0
IFEU0000000000000P0000110?ooo`kooooo000<ooooobP0oooo0P20P804000000030820P030`<00
oooo00l0oooo0`00003[0<W9b@0306EUI@0c<c<0000000<0000000<0<c<c06EUI@39bLT0L`39bLT0
0`1UIFD0000000000002000000030820P03oool0oooo03d0oooo3_ooool000cooooo9`3oool60000
0180oooo1000003^0<W9b@L00000M039bLT5000003h0oooo3_ooool000cooooo9P3oool5000001@0
oooo0`00003`0<W9b@H0000000<0IFEU0<W9b@39bLT0LP39bLT5000003d0oooo3_ooool000cooooo
9@3oool5000001D0oooo0`00003b0<W9b@H00000L`39bLT00`1UIFD0000000000002000000030820
P03oool0oooo03X0oooo3_ooool000cooooo903oool5000001H0oooo0`00003c0<W9b@L00000LP39
bLT5000003`0oooo3_ooool000cooooo8P3oool00`20P800000000000002000000030820P03oool0
oooo01@0oooo0`0000000`0c<c<0bLW90<W9b@3b0<W9b@80IFEU1@0000000`0c<c<0IFEU0<W9b@1_
0<W9b@0306EUI@00000000000080000000<0P8200?ooo`3oool0>03oool>ooooo`003?oooolQ0?oo
o`D0000000<0P8200?ooo`3oool05@3oool30000000306EUI@39bLT0bLW90?D0bLW91`00001a0<W9
b@D00000>@3oool>ooooo`003?oooolP0?ooo`H000005`3oool40000000306EUI@39bLT0bLW90?H0
bLW91`0000000`1UIFD0bLW90<W9b@1^0<W9b@@0000000<0P8200?ooo`3oool0=P3oool>ooooo`00
3?oooolO0?ooo`H00000603oool400000?/0bLW91`00001_0<W9b@0306EUI@000000000000800000
>03oool>ooooo`003?oooolM0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0603o
ool400000?`0bLW900<0UiNG06EUI@0000001000000206EUIFd0bLW900<0IFEU0000000000000P00
00000`20P800oooo0?ooo`0d0?ooo`kooooo000<oooooad0oooo100000000`20P800oooo0?ooo`0H
0?ooo`030820P0000000000000800000o`39bLT60000000306EUI@39bLT0bLW906`0bLW91@00000e
0?ooo`kooooo000<oooooa`0oooo1@00000K0?ooo`040820P0000000000000000?l0bLW90P39bLT0
0`1UIFD0000000000003000006l0bLW91@00000d0?ooo`kooooo000<oooooaX0oooo1P00000L0?oo
o`040820P0000000000000000?l0bLW90`39bLT7000006d0bLW900<0IFEU0000000000000P000000
0`20P800oooo0?ooo`0a0?ooo`kooooo000<oooooaT0oooo1P00000M0?ooo`040820P00000000000
00000?l0bLW91@39bLT6000006d0bLW91P00000b0?ooo`kooooo000<oooooaP0oooo00<0@4100000
000000000P0000000`20P800oooo0?ooo`0L0?ooo`<0000000<0IFEU0<W9b@39bLT0o`39bLT40<W9
b@0306EUI@0c<c<000000080000000<0<c<c06EUI@39bLT0J`39bLT00`1UIFD00000000000030000
0340oooo3_ooool000cooooo5`3oool500000200oooo0`00003o0<W9b@T0bLW91P00001]0<W9b@D0
0000<03oool>ooooo`003?oooolF0?ooo`D000008@3oool300000?l0bLW92`39bLT6000006`0bLW9
100000000`20P800oooo0?ooo`0]0?ooo`kooooo000<oooooaH0oooo0`00000S0?ooo`<00000o`39
bLT<0<W9b@D0000000<0IFEU0<W9b@39bLT0J@39bLT00`1UIFD0000000000002000002l0oooo3_oo
ool000cooooo503oool01@30`<000000000000000000@41002<0oooo00@0@4100000000000000000
o`39bLT;0<W9b@0309NGU`1UIFD0000000<000000P1UIFEY0<W9b@0309NGU`000000000000<00000
;P3oool>ooooo`003?oooolD0?ooo`@00000903oool01020P800000000000000003o0<W9b@h0bLW9
1P00001Z0<W9b@D00000;@3oool>ooooo`003?oooolC0?ooo`@000009@3oool01020P80000000000
0000003o0<W9bA00bLW9100000000`1UIFD0bLW90<W9b@1X0<W9b@D00000;03oool>ooooo`003?oo
oolC0?ooo`<000009P3oool01020P800000000000000003o0<W9bA00bLW900<0IFEU000000000000
0`00001Z0<W9b@D00000:`3oool>ooooo`003?oooolB0?ooo`@000009P3oool01020P80000000000
0000003o0<W9bA40bLW91P00001Y0<W9b@0306EUI@00000000000080000000<0P8200?ooo`3oool0
:03oool>ooooo`003?ooool@0?ooo`050820P0000000000000000010@4009`3oool01@20P8000000
000000000000IFEU0?l0bLW94P39bLT00`1UIFD00000000000020000000306EUI@2GUiL0bLW906H0
bLW900D0IFEU00000000000000000410@00Z0?ooo`kooooo000<ooooo`l0oooo00<0P82000000000
00000P00000X0?ooo`030820P0000000000000800000o`39bLTD0<W9b@D00000J039bLT5000002T0
oooo3_ooool000cooooo3`3oool5000002P0oooo00<0P8200000000000000P00003D0<W9b@030000
0039bLT0bLW900<0bLW91@00000e0<W9b@D00000J039bLT5000002P0oooo3_ooool000cooooo3`3o
ool4000002X0oooo1000003D0<W9b@8000000P39bLT00`1UIFD00000000000040<W9b@80000000<0
IFEU0<W9b@39bLT0<P39bLT4000006P0bLW91000000X0?ooo`kooooo000<ooooo`d0oooo00D0P820
00000000000000000820P00[0?ooo`@00000e039bLT01@1UIFD00000000000000000<c<c00L0bLW9
00<0IFEU0000001UIFD0<`39bLT00`1UIFD00000000000020000000303<c<`39bLT0bLW906D0bLW9
00D0<c<c00000000000000000<30`00V0?ooo`kooooo000<ooooo`d0oooo1000000/0?ooo`@00000
e@39bLT3000000T0bLW90P00000d0<W9b@0306EUI@000000000000<00000I`39bLT4000002H0oooo
3_ooool000cooooo3@3oool3000002d0oooo100000000`1UIFD0bLW90<W9b@3B0<W9b@<000002@39
bLT00`1UIFD000000000000e0<W9b@D00000I`39bLT4000002D0oooo3_ooool000cooooo303oool3
000000030820P03oool0oooo02/0oooo100000000`1UIFD0bLW90<W9b@3B0<W9b@8000002P39bLT0
0`1UIFD000000000000f0<W9b@D00000I`39bLT3000002D0oooo3_ooool000cooooo2`3oool01@20
P8000000000000000000P82002d0oooo100000000`1UIFD0bLW90<W9b@3B0<W9b@8000002P39bLT0
101UIFD0000000000000000f0<W9b@D0000000<0IFEU0<W9b@39bLT0H`39bLT4000002@0oooo3_oo
ool000cooooo2`3oool01010@400000000000000000^0?ooo`@0000000<0IFEU0<W9b@39bLT0d`39
bLT00`000000bLW90<W9b@080<W9b@0406EUI@0000000000000003H0bLW900<0UiNG000000000000
0`0000000`1UIFD0bLW90<W9b@1S0<W9b@0503<c<`000000000000000020P8008P3oool>ooooo`00
3?ooool;0?ooo`<00000;`3oool40000000306EUI@39bLT0bLW90=<0bLW900<000000<W9b@39bLT0
2039bLT4000003T0bLW91@00001U0<W9b@@000008P3oool>ooooo`003?ooool:0?ooo`@00000<03o
ool30000000306EUI@39bLT0bLW90=d0bLW91@00000j0<W9b@D00000I@39bLT3000000030820P03o
ool0oooo01l0oooo3_ooool000cooooo2P3oool300000340oooo1000003O0<W9b@D00000>`39bLT4
0000000306EUI@39bLT0bLW90680bLW91000000Q0?ooo`kooooo000<ooooo`T0oooo0`0000000`20
P800oooo0?ooo`0_0?ooo`@00000g@39bLT00`1UIFD0000000000003000003`0bLW900<0UiNG0000
000000000`0000000`1UIFD0bLW90<W9b@1Q0<W9b@0406EUI@00000000000820P200oooo3_ooool0
00cooooo203oool400000380oooo1000003L0<W9b@H00000?`39bLT6000006<0bLW91000000O0?oo
o`kooooo000<ooooo`P0oooo0`0000000`20P800oooo0?ooo`0a0?ooo`<00000f`39bLT00`1UIFD0
00000000000300000480bLW91@00001S0<W9b@<000007`3oool>ooooo`003?ooool70?ooo`@00000
00<0P8200?ooo`3oool0<@3oool400000=X0bLW900<0IFEU0000000000000P0000000`1UIFD0bLW9
0<W9b@100<W9b@0306EUI@00000000000080000000<0IFEU0<W9b@39bLT0H039bLT0101UIFD00000
00000000000N0?ooo`kooooo000<ooooo`L0oooo1000000e0?ooo`<00000fP39bLT50000000306EU
I@39bLT0bLW90440bLW91P00001Q0<W9b@0506EUI@000000000000000020P8007@3oool>ooooo`00
3?ooool60?ooo`050820P0000000000000000020P800=@3oool300000=P0bLW900<0IFEU00000000
00000`0000000`1UIFD0bLW90<W9b@130<W9b@0306EUI@000000000000<0000000<0IFEU0<W9b@39
bLT0GP39bLT0101UIFD0000000000010@40M0?ooo`kooooo000<ooooo`H0oooo1000000f0?ooo`@0
0000e`39bLT5000004X0bLW9100000000`1UIFD0bLW90<W9b@1N0<W9b@@00000703oool>ooooo`00
3?ooool60?ooo`<00000>03oool300000=H0bLW91@0000070<W9b@0306EUI@39bLT0bLW90440bLW9
00<0IFEU0000000000000P00001Q0<W9b@<00000703oool>ooooo`003?ooool50?ooo`@00000>03o
ool300000=H0bLW9100000080<W9b@0306EUI@39bLT0bLW90480bLW91@00001Q0<W9b@<000006`3o
ool>ooooo`003?ooool40?ooo`050820P0000000000000000020P800>03oool30000000306EUI@39
bLT0bLW90=<0bLW90`0000000`0c<c<0bLW90<W9b@060<W9b@80IFEUA039bLT00`1UIFD000000000
00020000000306EUI@39bLT0bLW905d0bLW900@0<c<c00000000000000006P3oool>ooooo`003?oo
ool40?ooo`<00000>P3oool01020P800000000000000003E0<W9b@<0000000<0IFEU0<W9b@39bLT0
1P39bLT00`1UIFD000000<W9b@150<W9b@D00000G`39bLT4000001T0oooo3_ooool000cooooo103o
ool3000003X0oooo00@0P8200000000000000000e@39bLT30000000306EUI@39bLT0bLW900H0bLW9
0P0000160<W9b@0306EUI@00000000000080000000<0IFEU0<W9b@39bLT0G039bLT4000000030820
P03oool0oooo01H0oooo3_ooool000cooooo103oool3000003X0oooo00@0P8200000000000000000
eP39bLT20000000306EUI@39bLT0bLW900H0bLW90P0000170<W9b@D00000G`39bLT3000000030820
P03oool0oooo01H0oooo3_ooool000cooooo0`3oool4000003X0oooo00D0P8200000000000000000
06EUI@3E0<W9b@<000002039bLT2000004P0bLW91@00001O0<W9b@<00000603oool>ooooo`003?oo
ool30?ooo`<0000000<0P8200?ooo`3oool0>@3oool30000000306EUI@39bLT0bLW90=@0bLW900@0
IFEU0000001UIFD0IFEU0`39bLT206EUI@040000001UIFD00000000004P0bLW900<0IFEU00000000
00000P0000000`1UIFD0bLW90<W9b@1K0<W9b@0406EUI@0000000000000001L0oooo3_ooool000co
oooo0`3oool3000000030820P03oool0oooo03T0oooo0`0000000`1UIFD0bLW90<W9b@3F0<W9b@D0
00001@39bLT00`000000bLW90<W9b@180<W9b@@0000000<0IFEU0<W9b@39bLT0G039bLT3000001H0
oooo3_ooool000cooooo0P3oool01@20P8000000000000000000P82003/0oooo1000003o0<W9bBh0
bLW900<0IFEU0000000000000P00001N0<W9b@@000005@3oool>ooooo`003?ooool20?ooo`040820
P00000000000000003d0oooo0`00003o0<W9bC00bLW91000001M0<W9b@0406EUI@00000000000000
01D0oooo3_ooool000cooooo0P3oool01010@400000000000000000m0?ooo`<00000o`39bLTa0<W9
b@0506EUI@00000000000000001UIFD0G039bLT3000000030820P03oool0oooo0180oooo3_ooool0
00cooooo0P3oool3000003h0oooo1000003o0<W9bC40bLW900<0IFEU0000000000000P00001L0<W9
b@<00000503oool>ooooo`003?ooool20?ooo`<00000?`3oool300000?l0bLW9<P39bLT400000003
06EUI@39bLT0bLW905T0bLW90`00000D0?ooo`kooooo000<ooooo`80oooo0`00000o0?ooo`<00000
o`39bLTc0<W9b@@00000G039bLT3000001<0oooo3_ooool000cooooo00<0oooo0000000000000P00
000o0?ooo`@00000o`39bLTc0<W9b@@00000F`39bLT3000001<0oooo3_ooool000cooooo00@0oooo
0000000000000000@03oool01@20P8000000000000000000IFEU0?l0bLW9<`39bLT01@1UIFD00000
000000000000IFEU05X0bLW90`00000B0?ooo`kooooo000<ooooo`040?ooo`000000000000000440
oooo1000003o0<W9bC@0bLW900<0IFEU0000000000000P00001I0<W9b@0406EUI@00000000000000
0140oooo3_ooool000cooooo100000110?ooo`030820P0000000000000800000o`39bLTd0<W9b@D0
0000F039bLT00`1UIFD000000000000200000100oooo3_ooool000cooooo0`0000120?ooo`030820
P0000000000000800000o`39bLTd0<W9b@D00000F@39bLT400000100oooo3_ooool000cooooo0`00
00130?ooo`@0000000<0UiNG0<W9b@39bLT0o`39bLTb0<W9b@0306EUI@00000000000080000000<0
IFEU0<W9b@39bLT0E@39bLT01@1UIFD00000000000000000P82000l0oooo3_ooool000cooooo0`00
00140?ooo`<0000000<0IFEU0<W9b@39bLT0o`39bLTd0<W9b@D00000E`39bLT4000000l0oooo3_oo
ool000cooooo00@0oooo0000000000000000@`3oool400000?l0bLW9=P39bLT50000000306EUI@39
bLT0bLW905D0bLW90`00000?0?ooo`kooooo000<ooooo`040?ooo`0000000000000004@0oooo0`00
003o0<W9bCH0bLW900<0IFEU0000000000000P0000000`1UIFD0bLW90<W9b@1E0<W9b@@000003P3o
ool>ooooo`003?ooool0103oool000000000000000140?ooo`@00000o`39bLTf0<W9b@D00000F039
bLT3000000h0oooo3_ooool000cooooo00@0oooo0000000000000000A03oool01020P80000000000
0000003o0<W9bCL0bLW900<0IFEU0000000000000P0000000`1UIFD0bLW90<W9b@1D0<W9b@0406EU
I@0000000000000000d0oooo3_ooool000cooooo00@0oooo0000000000000000A@3oool400000?l0
bLW9>039bLT5000005H0bLW91000000<0?ooo`kooooo000<ooooo`040?ooo`0000000000000004H0
oooo0`00003o0<W9bCT0bLW91000001F0<W9b@0406EUI@0000000000000000`0oooo3_ooool000co
oooo0P3oool3000004D0oooo1000003o0<W9bCP0bLW900D0IFEU000000000000000006EUI@1E0<W9
b@0506EUI@000000000000000020P8002`3oool>ooooo`003?ooool20?ooo`<00000A@3oool01@20
P8000000000000000000UiNG0?l0bLW9=`39bLT00`2GUiL00000000000020000000306EUI@39bLT0
bLW905<0bLW90`0000000`20P800oooo0?ooo`090?ooo`kooooo000<ooooo`80oooo0`0000160?oo
o`@00000o`39bLTi0<W9b@@00000E@39bLT4000000/0oooo3_ooool000cooooo0P3oool3000004H0
oooo1000003o0<W9bCX0bLW91000001E0<W9b@<000002`3oool>ooooo`003?ooool20?ooo`<00000
A`3oool400000?l0bLW9>P39bLT4000005@0bLW91000000:0?ooo`kooooo000<ooooo`80oooo0`00
00180?ooo`@00000o`39bLTi0<W9b@0306EUI@000000000000800000E039bLT3000000X0oooo3_oo
ool000cooooo0P3oool01020P80000000000000000170?ooo`050820P000000000000000001UIFD0
o`39bLTi0<W9b@0506EUI@00000000000000001UIFD0D`39bLT0101UIFD000000000000000090?oo
o`kooooo000<ooooo`80oooo00@0P8200000000000000000B03oool00`20P8000000000000020000
0?l0bLW9>@39bLT4000005@0bLW90`0000090?ooo`kooooo000<ooooo`80oooo00@0P82000000000
00000000B03oool00`20P80000000000000200000?l0bLW9>P39bLT4000005<0bLW9100000080?oo
o`kooooo000<ooooo`80oooo00@0P8200000000000000000B@3oool40000000306EUI@39bLT0bLW9
0?l0bLW9>039bLT400000580bLW900@0IFEU0000000000000000203oool>ooooo`003?ooool20?oo
o`040820P00000000000000004X0oooo1000003o0<W9bC/0bLW900@0<c<c000000000000IFEUD@39
bLT00`2GUiL0000000000002000000L0oooo3_ooool000cooooo0`3oool3000000030820P03oool0
oooo04P0oooo1000003o0<W9bCX0bLW900D0IFEU000000000000000006EUI@1A0<W9b@@000001`3o
ool>ooooo`003?ooool30?ooo`<0000000<0P8200?ooo`3oool0B03oool500000?l0bLW9>P39bLT3
0000000306EUI@39bLT0bLW904l0bLW9100000000`20P800oooo0?ooo`040?ooo`kooooo000<oooo
o`<0oooo0`0000000`20P800oooo0?ooo`190?ooo`@00000o`39bLTk0<W9b@<00000DP39bLT30000
00030820P03oool0oooo00@0oooo3_ooool000cooooo0`3oool3000000030820P03oool0oooo04X0
oooo100000000`2GUiL0bLW90<W9b@3o0<W9bCL0bLW900@0IFEU0000000000000000D@39bLT30000
00030410@03oool0oooo00@0oooo3_ooool000cooooo0`3oool4000004`0oooo00D0P82000000000
0000000006EUI@3o0<W9bC/0bLW90`00001A0<W9b@<000001P3oool>ooooo`003?ooool40?ooo`<0
0000C@3oool500000?l0bLW9>P39bLT400000500bLW90`0000060?ooo`kooooo000<ooooo`@0oooo
0`00001=0?ooo`H00000o`39bLTi0<W9b@0406EUI@000000000000000500bLW9100000050?ooo`ko
oooo000<ooooo`@0oooo0`00001>0?ooo`H00000o`39bLTi0<W9b@@00000D039bLT3000000D0oooo
3_ooool000cooooo103oool01020P800000000000000001?0?ooo`050410@000000000000000001U
IFD0o`39bLTh0<W9b@0506EUI@00000000000000001UIFD0C`39bLT3000000030820P03oool0oooo
0080oooo3_ooool000cooooo1@3oool300000500oooo100000000`1UIFD0bLW90<W9b@3o0<W9bCL0
bLW90`00001@0<W9b@<00000103oool>ooooo`003?ooool50?ooo`<00000D@3oool400000?l0bLW9
>@39bLT4000004l0bLW90`0000040?ooo`kooooo000<ooooo`D0oooo1000001A0?ooo`@00000o`39
bLTi0<W9b@<00000C`39bLT3000000@0oooo3_ooool000cooooo1P3oool300000580oooo00D0P820
000000000000000006EUI@3o0<W9bCP0bLW90`0000000`1UIFD0bLW90<W9b@1;0<W9b@0403<c<`00
00000000000000<0oooo3_ooool000cooooo1P3oool3000005<0oooo100000000`1UIFD0bLW90<W9
b@3o0<W9bCD0bLW900@0IFEU0000000000000000C@39bLT0101UIFD000000000000000030?ooo`ko
oooo000<ooooo`H0oooo1000001B0?ooo`050820P000000000000000001UIFD0o`39bLTh0<W9b@<0
000000<0IFEU0<W9b@39bLT0BP39bLT0101UIFD000000000000000030?ooo`kooooo000<ooooo`H0
oooo00@0P8200000000000000000D`3oool400000?l0bLW9>039bLT4000004`0bLW900@0IFEU0000
0000000000000`3oool>ooooo`003?ooool60?ooo`040820P00000000000000005@0oooo1000003o
0<W9bCP0bLW90`00001<0<W9b@0406EUI@0000000000000000<0oooo3_ooool000cooooo1P3oool0
1@20P8000000000000000000P82005@0oooo00<0P8200000000000000P0000000`1UIFD0UiNG0<W9
b@3o0<W9bC@0bLW90`00000206EUIDT0bLW900D0UiNG00000000000000000820P0020?ooo`kooooo
000<ooooo`L0oooo1000001E0?ooo`030820P0000000000000<00000o`39bLTf0<W9b@@00000BP39
bLT3000000030820P03oool0oooo00kooooo000<ooooo`L0oooo1000001F0?ooo`H00000o`39bLTe
0<W9b@0306EUI@000000000000800000B@39bLT3000000030820P03oool0oooo00kooooo000<oooo
o`L0oooo1000001G0?ooo`L00000o`39bLTc0<W9b@0306EUI@000000000000800000B@39bLT30000
00030820P03oool0oooo00kooooo000<ooooo`L0oooo00D0P82000000000000000000820P01H0?oo
o`030820P000000000000080000000<0<c<c0<W9b@39bLT0o`39bLTa0<W9b@@0000000<0IFEU0<W9
b@39bLT0AP39bLT3000000030410@03oool0oooo00kooooo000<ooooo`P0oooo0`0000000`20P800
oooo0?ooo`1G0?ooo`030820P0000000000000@00000o`39bLTb0<W9b@@00000B039bLT400000080
oooo3_ooool000cooooo203oool4000005/0oooo1P00003o0<W9bC40bLW9100000180<W9b@@00000
0P3oool>ooooo`003?ooool80?ooo`@00000G03oool600000?l0bLW9<@39bLT4000004P0bLW90`00
00020?ooo`kooooo000<ooooo`T0oooo1000001L0?ooo`030820P0000000000000<00000o`39bLT`
0<W9b@@00000B039bLT300000080oooo3_ooool000cooooo2@3oool01@20P8000000000000000000
P82005`0oooo00<0P820000000000000100000000`1UIFD0UiNG0<W9b@3o0<W9bB`0bLW910000017
0<W9b@<0000000<0P8200?ooooooool03Oooool000cooooo2P3oool4000005l0oooo1`00003o0<W9
bBd0bLW9100000160<W9b@@0000000<0ooooooooooooool03?ooool000cooooo2`3oool300000600
oooo2000003o0<W9bB/0bLW9100000160<W9b@@0000000<0ooooooooooooool03?ooool000cooooo
2`3oool400000640oooo1`0000000`1UIFD0bLW90<W9b@3o0<W9bBL0bLW900D0IFEU000000000000
000006EUI@150<W9b@@0000000<0ooooooooooooool03?ooool000cooooo2`3oool01@20P8000000
000000000000`<300680oooo00<0P8200000000000001000000206EUIOl0bLW99P39bLT01@2GUiL0
0000000000000000<c<c04D0bLW9100000000`3oooooooooooooo`0<ooooo`003?ooool<0?ooo`<0
000000<0P8200?ooo`3oool0H`3oool700000?l0bLW99P39bLT4000004D0bLW9100000000`3ooooo
ooooooooo`0<ooooo`003?ooool<0?ooo`@00000IP3oool8000003H0bLW90P0000000`1UIFD0bLW9
0<W9b@3Y0<W9b@@00000A039bLT4000000030?oooooooooooooo00cooooo000<ooooo`d0oooo0`00
001W0?ooo`030820P0000000000000H00000<@39bLT600000>/0bLW9100000140<W9b@@0000000<0
ooooooooooooool03?ooool000cooooo3@3oool3000002X0oooo100000050?ooo`80000000<0P820
0?ooo`3oool0103oool9000002@0oooo2000000]0<W9b@T00000k039bLT4000004@0bLW90`000000
0`3oooooooooooooo`0<ooooo`003?ooool>0?ooo`<000009`3oool01030`<000000000000000004
0820P080oooo0`0000000`10@400P8200820P0050?ooo`030820P0000000000000<0000000<0@410
0?ooo`3oool09@3oool00`20P8000000000000060000000306EUI@39bLT0bLW90240bLW900<0UiNG
06EUI@1UIFD03000003/0<W9b@0506EUI@00000000000000001UIFD0@`39bLT3000000030?oooooo
oooooooo00cooooo000<ooooo`l0oooo0`00000V0?ooo`@00000103oool00`000000oooo00000002
000000040820P03oool0oooo000000D0oooo1@0000000`20P800oooo0?ooo`0Y0?ooo`T000007@39
bLTB00000>d0bLW9100000130<W9b@<0000000<0ooooooooooooool03?ooool000cooooo3`3oool3
000002H0oooo0`0000060?ooo`050820P0000000000000000020P8000`3oool00`000000oooo0?oo
o`020?ooo`D0000000<0P8200?ooo`3oool0:P3oool00`20P8000000000000060000000306EUI@39
bLT0bLW901L0bLW95000003]0<W9b@0406EUI@0000000000000004<0bLW90`0000000`3ooooooooo
ooooo`0<ooooo`003?ooool?0?ooo`040820P00000000000000002D0oooo0`0000060?ooo`050820
P0000000000000000020P8000`3oool00`000000oooo0?ooo`020?ooo`D0000000<0P8200?ooo`3o
ool0;@3oool9000001@0bLW95`00003]0<W9b@0406EUI@0000000000000004<0bLW90`0000000`3o
ooooooooooooo`0<ooooo`003?ooool?0?ooo`050<30`0000000000000000020P800903oool30000
00L0oooo100000080?ooo`D0000000<0P8200?ooo`3oool0;P3oool00`30`<00P8200820P0090000
00@0IFEU1`39bLT206EUIA/00000k039bLT00`2GUiL000000000000200000480bLW90`0000000`3o
ooooooooooooo`0<ooooo`003?ooool@0?ooo`@00000903oool3000000P0oooo0`0000080?ooo`D0
000000<0P8200?ooo`3oool0<`3oool_00000>d0bLW9100000000`1UIFD0bLW90<W9b@0o0<W9b@<0
000000<0ooooooooooooool03?ooool000cooooo4@3oool3000000030820P03oool0oooo0240oooo
100000070?ooo`@000001`3oool5000000030820P03oool0oooo03D0oooo;@00003^0<W9b@<00000
00<0IFEU0<W9b@39bLT0?`39bLT3000000030?oooooooooooooo00cooooo000<oooooa40oooo1000
000S0?ooo`040820P00000000000000000P0oooo0`0000070?ooo`D0000000<0P8200?ooo`3oool0
>03ooolZ00000>h0bLW9100000110<W9b@<0000000<0ooooooooooooool03?ooool000cooooo4P3o
ool400000280oooo00@0P8200000000000000000203oool3000000L0oooo1@0000000`20P800oooo
0?ooo`0g0?ooob/00000@039bLTQ000008h0bLW90`0000110<W9b@<0000000<0ooooooooooooool0
3?ooool000cooooo4`3oool3000000030820P03oool0oooo0200oooo0`0000000`20P800oooo0?oo
o`050?ooo`040820P000000000000820P0H0oooo1@0000000`20P800oooo0?ooo`0e0?ooo`030820
P0000000000000@0000000<0@4100820P00000008`00000b0<W9b@L0IFEU;@00000406EUIHD0bLW9
0`0000000`1UIFD0bLW90<W9b@0m0<W9b@<000000P3oool>ooooo`003?oooolD0?ooo`@000008P3o
ool2000000030820P03oool0oooo00H0oooo0`0000060?ooo`D0000000<0P8200?ooo`3oool0=03o
ool9000000<0oooo9@00000P0<W9bDT00000Q039bLT3000003l0bLW90`0000020?ooo`kooooo000<
oooooa@0oooo00@0P82000000000000000008P3oool3000000P0oooo0`0000060?ooo`D0000000<0
P8200?ooo`3oool0<`3oool5000000050?ooo`000000000000000020P800103ooomX000001T0oooo
3`0000210<W9b@@00000?P39bLT300000080oooo3_ooool000cooooo503oool01@20P80000000000
00000000P8200280oooo0P0000080?ooo`<000001P3oool5000000030820P03oool0oooo00<0oooo
0`00000/0?ooo`D0000000<0P8200?ooo`0000000P0000000`20P800oooo0?ooo`040?ooof000000
903oool00`20P80000000000000:000007l0bLW90`00000n0<W9b@<000000P3oool>ooooo`003?oo
oolE0?ooo`@000008`3oool00`10@40000000820P0060?ooo`@000001@3oool6000000<0oooo00<0
`<300000000000000`00000X0?ooo`80P820100000020820P0030?ooo`00000000000080000000<0
`<300?ooo`3oool01P3oool00`30`<00P8200000000J000000<0P8208000000?0820P2H0oooo00<0
`<300820P020P8001020P80:0?ooo`80P820200000000`0c<c<0IFEU0<W9b@1k0<W9b@<0000000<0
IFEU0<W9b@39bLT0>P39bLT0101UIFD000000000000000020?ooo`kooooo000<oooooaH0oooo1000
000S0?ooo`<000001@3oool4000000D0oooo1`0000020?ooo`H000009`3oool00`20P80000000000
0003000000@0oooo1000000=0?ooo`030820P0000000000001H00000EP3oool;000000d0oooo00<0
P8200000000000001P0000000`1UIFD0bLW90<W9b@1g0<W9b@0406EUI@0000000000000003`0bLW9
0`0000000`20P800oooo0?ooo`0>ooooo`003?oooolG0?ooo`@000008`3oool3000000@0oooo1000
00050?ooo`D0000000<0P8200000000000001`00000W0?ooo`D0000000D0P8200?ooo`3oool0oooo
0820P004000000l0oooo5P00001F0?ooo`D000001@3oool3000000l0oooo2000001h0<W9b@0406EU
I@0000000000000003`0bLW90`0000000`20P800oooo0?ooo`0>ooooo`003?oooolG0?ooo`D00000
8`3oool2000000050820P03oool0oooo0?ooo`20P800100000030?ooo`H0000000<0P8200?ooo`3o
ool01P0000000`20P800oooo0?ooo`0S0?ooo`H000001@3oool00`20P80000000000000200000180
oooo4`00001E0?ooo`@0000000<0P8200?ooo`3oool01P3oool00`20P80000000000000?0?ooo`P0
0000MP39bLT01@1UIFD00000000000000000IFEU03X0bLW900D0IFEU00000000000000000820P002
0?ooo`kooooo000<oooooaP0oooo1000000U0?ooo`@0000000<0oooo0000000000000P0000020?oo
o`L0000000@0P8200?ooo`3oool0oooo1@00000U0?ooo`H000001P3oool01020P800000000000000
000D0?oooa800000E03oool00`20P800000000000002000000/0oooo0P00000?0?ooo`P0000000<0
IFEU0<W9b@39bLT0L`39bLT30000000306EUI@39bLT0bLW903P0bLW900@0IFEU0000000000000000
0`3oool>ooooo`003?oooolH0?ooo`030820P000000000000080000000<0`<300?ooo`3oool09P3o
ool01@20P8000000000000000000`<3003@0oooo00<0P8200410@00000000P0000000`10@400P820
0?ooo`060?ooo`@000005`3oool00`20P80000000000000;000000030820P03oool0oooo0580oooo
0`0000000`20P800oooo0?ooo`0;0?ooo`030820P010@400oooo0100oooo00<0P820000000000000
1000000206EUIG80bLW90`0000000`0c<c<0bLW90<W9b@0h0<W9b@0406EUI@0000000000000000<0
oooo3_ooool000cooooo6@3oool5000002T0oooo0`0000000`20P800oooo0?ooo`0a0?ooo`H00000
2@3oool3000001`0oooo2P0000000`20P800oooo0?ooo`1A0?ooo`@000003`3oool00`20P800oooo
0?ooo`0B0?ooo`L00000LP39bLT3000003X0bLW9100000030?ooo`kooooo000<oooooa/0oooo1000
000X0?ooo`<0000000<0P8200?ooo`3oool0<03oool6000000T0oooo1000000M0?ooo`030820P000
0000000000H00000E03oool3000002H0oooo1`00001a0<W9b@<00000>P39bLT3000000@0oooo3_oo
ool000cooooo703oool4000002L0oooo0`0000000`20P800oooo0?ooo`0_0?ooo`H000002P3oool4
000001l0oooo1`00001C0?ooo`@000009`3oool00`20P800000000000005000006l0bLW91000000i
0<W9b@<00000103oool>ooooo`003?oooolM0?ooo`@0000000<0`<300?ooo`3oool0903oool30000
01d0oooo0P0000000`20P800oooo0?ooo`0=0?ooo`030820P0000000000000<0000000<0`<300?oo
o`3oool02@3oool300000280oooo0P20P802000000030820P03oool0oooo0540oooo1000000Y0?oo
o`80P8201@0000000`0c<c<0IFEU0<W9b@1/0<W9b@<00000>039bLT3000000030820P03oool0oooo
0080oooo3_ooool000cooooo7@3oool00`20P800000000000002000002H0oooo0`00000L0?ooo`D0
00003@3oool6000000`0oooo1000001j0?ooo`@00000:`3oool00`20P800000000000006000006/0
bLW90`00000h0<W9b@<000001@3oool>ooooo`003?oooolN0?ooo`@000009P3oool4000001X0oooo
1`00000:0?ooo`030820P0000000000000<000003P3oool4000007X0oooo1000000]0?ooo`L00000
00<0IFEU0<W9b@39bLT0J039bLT4000003L0bLW90`0000050?ooo`kooooo000<oooooal0oooo1000
000R0?ooo`030820P0000000000000@000006P3oool8000000030820P03oool0oooo00H0oooo1@00
000?0?ooo`<000004@3oool4000000D0oooo0P0000070?ooo`T00000C`3oool4000002l0oooo1`00
001Z0<W9b@<00000=P39bLT4000000D0oooo3_ooool000cooooo803oool4000002D0oooo0`00000I
0?ooo`030820P0000000000000P000001P3oool5000000030820P03oool0oooo00`0oooo1000000@
0?ooo`H000000`3oool5000000D0oooo00<0P8200000000000001@00001@0?ooo`@00000<03oool0
0`20P800000000000004000006T0bLW90`00000f0<W9b@<000001P3oool>ooooo`003?oooolQ0?oo
o`050410@0000000000000000020P800?`3oool<000000030820P03oool0P82000D0000000<0P820
0?ooo`3oool03P3oool3000000030410@03oool0oooo00`0oooo00@0P8200000000000000000103o
ool00`20P800oooo0?ooo`0300000080oooo00<0P8200<30`03oool00`3oool600000540oooo00D0
P82000000000000000000820P00a0?ooo`030820P0000000000000@0000000<0UiNG0<W9b@39bLT0
I039bLT3000003D0bLW900@0IFEU00000000000000001P3oool>ooooo`003?oooolR0?ooo`@00000
00<0P8200?ooo`3oool0>`3oool>000000030820P0000000000000<000004@3oool01@20P8000000
000000000000P82000h0oooo0`0000000`20P800oooo0?ooo`030?ooo`030000003oool000000080
00000`3oool00`20P800oooo0?ooo`020?ooo`H00000DP3oool4000003<0oooo00<0P82000000000
00001000001U0<W9b@<00000=@39bLT3000000030820P03oool0oooo00@0oooo3_ooool000cooooo
8P3oool6000003/0oooo500000000`20P800oooo0?ooo`0?0?ooo`050820P0000000000000000020
P8003P3oool3000000030820P03oool0oooo00@0oooo100000030?ooo`030820P03oool0oooo0080
oooo1P00001B0?ooo`@00000=03oool7000006@0bLW91000000c0<W9b@@0000000<0P8200?ooo`3o
ool0103oool>ooooo`003?oooolS0?ooo`L00000>@3ooolC000001<0oooo00@0P820000000000000
00003`3oool3000000030820P03oool0oooo00D0oooo100000070?ooo`H00000D`3oool4000003D0
oooo1P00001S0<W9b@0406EUI@0000000000000003<0bLW9100000070?ooo`kooooo000<ooooob@0
oooo00<0P8200000000000000`0000000`10@400oooo0?ooo`0d0?ooo`030820P000000000000100
000000<0P8200?ooo`3oool04P3oool01010@400000000000000000?0?ooo`<0000000<0P8200?oo
o`3oool01@3oool01020P80000000000000000070?ooo`H00000D`3oool01010@400000000000000
000f0?ooo`030820P010@40000000080000000<0<c<c06EUI@39bLT0H039bLT0101UIFD000000000
0000000b0<W9b@0406EUI@0000000000000000P0oooo3_ooool000cooooo9P3oool00`20P8000000
00000004000003@0oooo5000000D0?ooo`@000003`3oool4000000P0oooo100000060?ooo`H00000
D`3oool00`20P80000000000000200000100oooo00<000000?ooo`3oool08`3oool00`20P8000000
0000000400000600bLW900@0IFEU0000000000000000<P39bLT3000000T0oooo3_ooool000cooooo
:03oool600000380oooo00<0P8200000000000004`00000C0?ooo`<000004@3oool3000000P0oooo
00@0P82000000000000000001P3oool6000005@0oooo100000000`20P800oooo0?ooo`0=0?ooo`03
0000003oool0oooo02D0oooo1P00001O0<W9b@0406EUI@000000000000000380bLW90`0000090?oo
o`kooooo000<ooooobT0oooo1P00000a0?oooaH000004P3oool400000140oooo0`0000080?ooo`04
0820P00000000000000000H0oooo1P00001E0?ooo`<0000000<0P8200?ooo`3oool03@3oool00`00
0000oooo0?ooo`0V0?ooo`H00000G`39bLT400000300bLW90`00000:0?ooo`kooooo000<ooooobX0
oooo1P00000`0?oooaL000004@3oool400000180oooo0`0000070?ooo`040820P000000000000000
00H0oooo1P00001F0?ooo`<000003`3oool2000002P0oooo00<0P8200000000000000`00001N0<W9
b@@00000<039bLT3000000X0oooo3_ooool000cooooo:`3oool00`20P80000000000000300000003
0820P03oool0oooo02/0oooo600000000`30`<00oooo0?ooo`0=0?ooo`040820P000000000000000
01<0oooo00<0P820000000000000203oool4000000D0oooo1P00001G0?ooo`040820P00000000000
0820P0`0oooo00<0P820000000000000:@3oool20820P0@0000000<0IFEU0<W9b@39bLT0FP39bLT4
000002h0bLW900@0IFEU00000000000000002`3oool>ooooo`003?ooool^0?ooo`D0000000<0P820
0?ooo`3oool0:03ooolI000000030820P03oool0oooo00d0oooo1000000D0?ooo`<000001`3oool4
000000D0oooo1P00001H0?ooo`040820P00000000000000000X0oooo1000000/0?ooo`D00000F`39
bLT4000002h0bLW90`0000000`20P800oooo0?ooo`090?ooo`kooooo000<ooooobl0oooo1@00000Y
0?oooaX0000000<0P8200?ooo`3oool03@3oool3000001D0oooo00<0P8200000000000001`3oool4
000000D0oooo1P00001J0?ooo`<00000203oool00`20P800000000000002000002d0oooo00D0P820
000000000000000006EUI@1J0<W9b@@00000;@39bLT0101UIFD0000000000000000<0?ooo`kooooo
000<ooooobl0oooo00<0P8200000000000000`00000X0?oooa/000003`3oool3000001H0oooo0`00
00060?ooo`@0000000<0P8200?ooo`3oool00P3oool6000005`0oooo0`0000060?ooo`D0000000<0
P8200?ooo`3oool0:`3oool5000005X0bLW90`0000000`1UIFD0bLW90<W9b@0Z0<W9b@@00000303o
ool>ooooo`003?oooola0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool08@3oool0
0`10@40000000000000I000000h0oooo0`0000000`10@400oooo0?ooo`0E0?ooo`040820P0000000
00000<30`0@0oooo100000000`20P800oooo0?ooo`020?ooo`H00000GP3oool70820P0060<30`03o
ool0oooo0?ooo`20P800`<30;P3oool00`20P8000000000000020000000306EUI@39bLT0bLW905H0
bLW90`0000000`1UIFD0bLW90<W9b@0X0<W9b@0506EUI@000000000000000020P8003@3oool>oooo
o`003?oooold0?ooo`L000008@3ooolM000000d0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`80
0000103oool4000000030820P03oool0oooo0080oooo1P00002K0?ooo`030820P000000000000080
0000E`39bLT30000000306EUI@39bLT0bLW902P0bLW91000000>0?ooo`kooooo000<ooooocH0oooo
1P0000000`20P800oooo0?ooo`0L0?oooah00000303oool4000000030820P03oool0oooo01P0oooo
0P0000030?ooo`030000003oool0000000800000103oool6000009`0oooo1@00001E0<W9b@@00000
00<0IFEU0<W9b@39bLT09`39bLT4000000l0oooo3_ooool000cooooo>03oool7000001/0oooo7@00
00000`20P800oooo0?ooo`0;0?ooo`@0000000<0P8200?ooo`3oool06@3oool400000080oooo0`00
00040?ooo`H00000W@3oool5000005@0bLW9100000000`1UIFD0bLW90<W9b@0V0<W9b@@0000000<0
P8200?ooo`3oool03@3oool>ooooo`003?ooooli0?ooo`P000006@3ooolK00000100oooo1000000R
0?ooo`<00000103oool6000009h0oooo1@00001C0<W9b@@0000000<0IFEU0<W9b@39bLT09@39bLT0
0`1UIFD0000000000002000000030820P03oool0oooo00d0oooo3_ooool000cooooo>P3oool20820
P0H000000P20P80D0?ooo`030820P0000000000001D000000P20P8000`30`<00oooo0?ooo`0?0?oo
o`030820P00000000000008000008`3oool3000000<0oooo1P00002P0?ooo`050410@00000000000
0000002GUiL0D@39bLT40000000306EUI@39bLT0bLW902@0bLW900<0IFEU0000000000000P000000
0`20P800oooo0?ooo`0>0?ooo`kooooo000<ooooocd0oooo200000000`20P800oooo0?ooo`0@0?oo
oaD000005`3oool01020P800000000000000000T0?ooo`<000000`3oool600000:40oooo1@00001A
0<W9b@<0000000<0IFEU0<W9b@39bLT08`39bLT500000180oooo3_ooool000cooooo?`3oool90000
00l0oooo00<0P8200000000000003`0000000`20P800oooo0?ooo`0H0?ooo`040820P00000000000
000002@0oooo0`0000030?ooo`H00000XP3oool500000500bLW90`0000000`1UIFD0bLW90<W9b@0R
0<W9b@D000004`3oool>ooooo`003?oooom10?ooo`T0000000<0P8200?ooo`3oool02P3ooolA0000
01`0oooo1000000U0?ooo`<000000P3oool600000:<0oooo1@00001?0<W9b@<0000000<0IFEU0<W9
b@39bLT08@39bLT00`1UIFD0000000000002000001@0oooo3_ooool000cooooo@`3oool20820P0P0
000000<0P8200<30`03oool01P3oool00`20P80000000000000:00000080P82000<0`<300?ooo`3o
ool0703oool3000002H0oooo0`0000020?ooo`H00000Y03oool00`30`<0000000000000200000003
06EUI@39bLT0bLW904/0bLW90`0000000`1UIFD0bLW90<W9b@0P0<W9b@0306EUI@00000000000080
000000<0`<300?ooo`3oool04P3oool>ooooo`003?oooom70?ooo`X00000103oool;000002<0oooo
1000000V0?ooo`@0000000<0P8200000000000001000002V0?ooo`D00000C039bLT30000000306EU
I@39bLT0bLW901l0bLW91@00000F0?ooo`kooooo000<ooooodT0oooo2P0000000`20P800oooo0000
0006000000030820P03oool0oooo02@0oooo1000000S0?ooo`h00000Y`3oool5000004/0bLW90`00
00000`1UIFD0bLW90<W9b@0N0<W9b@D000005`3oool>ooooo`003?oooom;0?ooo`l00000:@3oool3
000002L0oooo00@0P8200000000000000000/03oool4000004X0bLW90`0000000`1UIFD0bLW90<W9
b@0M0<W9b@D00000603oool>ooooo`003?oooom=0?ooo``00000:@3oool400000=/0oooo00<0P820
0000000000000P0000190<W9b@<0000000<0IFEU0<W9b@39bLT07039bLT00`1UIFD0000000000002
000000030820P03oool0oooo01H0oooo3_ooool000coooooC`3oool40820P0T0000000@0@4100820
P020P800P8208P3oool3000000030820P03oool0oooo0=X0oooo00<0P8200000000000000P000002
06EUIDH0bLW90`0000000`1UIFD0bLW90<W9b@0J0<W9b@0306EUI@0000000000008000000P20P80I
0?ooo`kooooo000<oooooeH0oooo4P00000J0?ooo`<00000?P3ooolJ000008P0oooo1@0000150<W9
b@<0000000<0IFEU0<W9b@39bLT06@39bLT5000001`0oooo3_ooool000coooooF03ooolH00000140
oooo1000000g0?ooobL00000PP3oool00`20P8000000000000020000000306EUI@39bLT0bLW90440
bLW91000000K0<W9b@0306EUI@0000000000008000007@3oool>ooooo`003?oooomL0?oooa`00000
2@3oool3000000030820P03oool0oooo02L0oooo>00000200?ooo`H00000@P39bLT4000001/0bLW9
100000000`20P800oooo0?ooo`0K0?ooo`kooooo000<oooooel0oooo1P20P80K000000050820P000
0000000000000010@4006P20P8000`10@40000000000000Q000000030410@020P800P82001H0P820
300000040820P7/0oooo0P20P8040000000306EUI@39bLT0bLW903h0bLW91000000G0<W9b@80IFEU
100000000`20P800oooo0?ooo`0M0?ooo`kooooo000<ooooofX0ooooD`00000U0?ooo``00000O03o
ool5000003l0bLW91000000F0<W9b@0306EUI@000000000000<000008@3oool>ooooo`003?oooom_
0?ooocl00000=`3oool;000007X0oooo00<0P8200000000000000`00000n0<W9b@@000005@39bLT6
00000280oooo3_ooool000coooooP03ooolO000000030820P03oool0oooo04D0oooo00<0P8200000
000000001`00001j0?ooo`H00000?039bLT00`1UIFD0000000000002000001@0bLW91@00000T0?oo
o`kooooo000<oooooh00oooo1000001W0?ooo`T00000N@3oool5000003/0bLW900@0IFEU00000000
000000004`39bLT00`1UIFD0000000000003000002D0oooo3_ooool000coooooP03oool3000006X0
oooo0P20P806000000030410@020P800oooo07H0oooo00<0P8200000000000000P0000000`0c<c<0
bLW90<W9b@0g0<W9b@0403<c<`000000000000000100bLW90P1UIFD5000000030<30`03oool0oooo
02@0oooo3_ooool000coooooO`3oool4000006d0oooo00<0P8200000000000001P00001g0?ooo`L0
0000=P39bLT3000000l0bLW900<0IFEU0000000000001000000Y0?ooo`kooooo000<ooooogl0oooo
0`00001a0?ooo`P00000MP3oool60000000306EUI@39bLT0bLW903<0bLW90`00000=0<W9b@L00000
00<0P8200?ooo`3oool0:03oool>ooooo`003?oooomo0?ooo`<00000L`3oool7000007L0oooo1P00
000d0<W9b@<000002`39bLT00`1UIFD0000000000005000002`0oooo3_ooool000coooooLP3oool0
0`20P80000000000000<000000030820P03oool0oooo0780oooo00<0P8200000000000001@000000
0`20P800oooo0?ooo`1b0?ooo`030<30`020P800000000@000000P1UIFD`0<W9b@<0000000<0IFEU
0<W9b@39bLT01P39bLT206EUI@H000000P20P80]0?ooo`kooooo000<ooooog80oooo00<0P8200000
000000003P00001f0?ooo`P00000M@3oool60000000306EUI@39bLT0bLW902d0bLW90`0000070<W9
b@T00000<03oool>ooooo`003?oooomb0?ooo`030820P0000000000000l0000000<0P8200?ooo`3o
ool0L`3oool8000007D0oooo00<0P8200000000000001000000]0<W9b@@000001@39bLT900000380
oooo3_ooool000coooooLP3oool00`20P80000000000000A000007H0oooo1`00001f0?ooo`H00000
;039bLT3000000@0bLW900<0IFEU0000000000001P0000000`20P800oooo0?ooo`0a0?ooo`kooooo
000<ooooog80oooo00<0P8200000000000004`00001e0?ooo`P00000M@3oool60000000306EUI@39
bLT0bLW902P0bLW90`0000020<W9b@T00000=P3oool>ooooo`003?oooomb0?ooo`030820P0000000
000001@0000000<0P8200?ooo`3oool0LP3oool00`30`<00P82000000005000000030820P030`<00
oooo07<0oooo00<0@4100000000000001000000206EUIBD0bLW900<0IFEU0000000000001`000002
0820P0030<30`03oool0oooo03H0oooo3_ooool000coooooLP3oool00`20P80000000000000F0000
07L0oooo1P00001f0?ooo`P000008P39bLT:000003d0oooo3_ooool000coooooLP3oool00`20P800
00000000000G000007L0oooo1`00001f0?ooo`T0000000<0IFEU0<W9b@39bLT06039bLT;00000400
oooo3_ooool000coooooLP3oool00`20P80000000000000F000007T0oooo1`00001f0?ooo`/00000
5039bLT00`1UIFD000000000000<00000400oooo3_ooool000coooooLP3oool00`20P80000000000
000E000000030820P03oool0oooo07T0oooo00<0P8200000000000000`0000000`20P800oooo0?oo
o`1d0?ooo`80P8202P00000=06EUI@d0000000@0@4100000000000000000@P3oool>ooooo`003?oo
oomb0?ooo`030820P0000000000001@0000000<0P8200?ooo`3oool00P3oool9000000<0oooo2@00
001U0?ooo`D00000O03ooolL000000@0oooo0`0000130?ooo`kooooo000<ooooog80oooo00<0P820
000000000000500000060?ooo`L0000000<0P8200?ooo`3oool00P3oool7000006L0oooo1@00001m
0?oooaL000001P3oool4000004<0oooo3_ooool000coooooLP3oool00`20P80000000000000D0000
00L0oooo1P0000050?ooo`030820P0000000000000<00000JP3oool5000007h0oooo00<0P8200000
000000003000000;0?ooo`<00000A03oool>ooooo`003?oooomb0?ooo`030820P000000000000180
000000<0P8200?ooo`3oool01P3oool6000000D0oooo00<0P8200000000000000`00001Z0?ooo`03
0820P000000000000080000000<0@4100820P03oool0Q03oool00`30`<00oooo0?ooo`0=0?ooo`<0
0000A@3oool>ooooo`003?oooomb0?ooo`030820P00000000000018000002@3oool6000000D0oooo
00<0P8200000000000000`00001/0?ooo`H00000T`3oool3000000030820P03oool0oooo04<0oooo
3_ooool000coooooLP3oool00`20P80000000000000A000000X0oooo1P0000050?ooo`030820P000
0000000000<00000KP3oool500000980oooo0`0000000`20P800oooo0?ooo`130?ooo`kooooo000<
ooooog80oooo00<0P8200000000000004000000;0?ooo`H000001@3oool00`20P800000000000003
000006l0oooo1@00002@0?ooo`@00000AP3oool>ooooo`003?oooomb0?ooo`030820P00000000000
00l0000000<0P8200?ooo`3oool02@3oool6000000D0oooo00<0P8200000000000000`00001`0?oo
o`D00000SP3oool00`20P800000000000002000004H0oooo3_ooool000coooooLP3oool00`20P800
00000000000?000000030<30`03oool0oooo00T0oooo1P0000050?ooo`030820P0000000000000<0
0000L@3oool20820P0<0000000<0P8200?ooo`3oool0RP3oool01010@400000000000020P8170?oo
o`kooooo000<ooooog<0oooo4000000=0?ooo`H000001@3oool00`20P800000000000003000007<0
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`270?ooo`@00000B03oool>ooooo`00
3?oooomc0?ooo`l000003P3oool6000000D0oooo00<0P8200000000000000`00001d0?ooo`D00000
R03oool4000004T0oooo3_ooool000coooooL`3oool>000000l0oooo1P0000050?ooo`030820P000
0000000000<00000M@3oool5000008H0oooo1000001:0?ooo`kooooo000<ooooog<0oooo3@000000
0`10@400oooo0?ooo`0=0?ooo`H000001@3oool00`20P800000000000003000007L0oooo00H0P820
00000000000000000820P030`<220?ooo`050<30`0000000000000000010@400BP3oool>ooooo`00
3?oooomc0?ooo`d00000403oool6000000D0oooo00<0P8200000000000000`00001h0?ooo`030820
P0000000000000800000PP3oool4000004/0oooo3_ooool000coooooL`3oool=00000100oooo1P00
00050?ooo`030820P0000000000000<00000N@3oool500000800oooo1@00001;0?ooo`kooooo000<
ooooog<0oooo3000000A0?ooo`H0000000<0P8200?ooo`3oool00P3oool00`20P800000000000003
000007/0oooo1000001n0?ooo`D00000C03oool>ooooo`003?oooomc0?ooo`/000004P3oool70000
00@0oooo1@00001m0?ooo`@00000O03oool5000004d0oooo3_ooool000coooooL`3oool900000003
0820P03oool0oooo0100oooo00<0P820000000000000100000000`30`<0000000000000600000003
0410@03oool0oooo07/0oooo00<0`<300000000000000P0000000`10@400oooo0?ooo`1f0?ooo`03
0<30`000000000000080000000<0@4100?ooo`3oool0C03oool>ooooo`003?oooomc0?ooo`T00000
4P3oool8000000<0oooo1@0000210?ooo`D00000M`3oool5000004l0oooo3_ooool000coooooL`3o
ool8000000030820P03oool0oooo0:<0oooo1000001e0?ooo`D00000D03oool>ooooo`003?oooomc
0?ooo`P00000Y`3oool4000000030820P03oool0oooo0700oooo1@00001A0?ooo`kooooo000<oooo
og<0oooo1P0000000`20P800oooo0?ooo`2V0?ooo`030<30`000000000000080000000<0P8200?oo
o`3oool0K@3oool00`30`<00000000000002000000030820P03oool0oooo0500oooo3_ooool000co
ooooL`3oool600000:`0oooo1000001^0?ooo`@0000000<0P8200?ooo`3oool0D@3oool>ooooo`00
3?oooomc0?ooo`D00000[P3oool5000006/0oooo1@00001D0?ooo`kooooo000<ooooog<0oooo1000
00000`20P800oooo0?ooo`2/0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0IP3o
ool6000005D0oooo3_ooool000coooooL`3oool400000;00oooo1P00001V0?ooo`D00000E`3oool>
ooooo`003?oooomc0?ooo`<000006@3oool01@20P8000000000000000000P82000/0oooo00<0`<30
0000000000000P0000000`30`<00oooo0?ooo`220?ooo`030820P000000000000080000000<0P820
0?ooo`3oool0H@3oool00`10@400000000000002000000030<30`03oool0oooo05D0oooo3_ooool0
00coooooL`3oool2000001`0oooo1000000:0?ooo`@00000R03oool500000640oooo1@00001I0?oo
o`kooooo000<ooooog<0oooo00<000000?ooo`3oool0703oool4000000P0oooo100000290?ooo`03
0820P0000000000000<00000GP3oool5000005/0oooo3_ooool000coooooTP3oool01@20P8000000
000000000000P82000H0oooo1000002<0?ooo`D00000G03oool5000005`0oooo3_ooool000cooooo
T`3oool01@20P8000000000000000000P82000<0oooo00D0`<3000000000000000000410@02>0?oo
o`030820P0000000000000<0000000<0`<300?ooo`3oool0E03oool20820P0@0000000<0P8200<30
`03oool0F`3oool>ooooo`003?oooonE0?ooo`@000000P3oool400000900oooo1P00001E0?ooo`D0
0000H03oool>ooooo`003?oooonF0?ooo`P00000TP3oool6000005<0oooo1@0000000`20P800oooo
0?ooo`1N0?ooo`kooooo000<oooooiH0oooo00<0P8200000000000001000002D0?ooo`L00000C`3o
ool600000680oooo3_ooool000coooooU`3oool5000009L0oooo1@0000000`20P800oooo0?ooo`1:
0?ooo`030820P0000000000000@00000H`3oool>ooooo`003?oooonH0?ooo`040820P00000000000
0<30`9P0oooo00<0P8200000000000000P0000020820P4H0oooo0`20P806000006D0oooo3_ooool0
00coooooo`3ooolg0?ooo`L00000@`3oool9000006H0oooo3_ooool000coooooo`3oooli0?ooo`H0
0000@03oool9000006P0oooo3_ooool000coooooo`3ooolj0?ooo`H00000?@3oool00`20P8000000
00000006000000030820P03oool0oooo06L0oooo3_ooool000coooooo`3ooolk0?ooo`80P8201@00
00000`20P800oooo0?ooo`0d0?ooo`80P8201`0000020820P6`0oooo3_ooool000coooooo`3oooln
0?ooo`H00000=03oool9000006l0oooo3_ooool000coooooo`3ooolo0?ooo`L00000;`3oool:0000
0740oooo3_ooool000coooooo`3ooom00?ooo`P00000;03oool9000007<0oooo3_ooool000cooooo
o`3ooom20?ooo`P000009P3oool;000007D0oooo3_ooool000coooooo`3ooom30?ooo`80P8201P00
00001010@400P8200820P020P80J0?ooo`@0P8202P0000000`20P800`<300?ooo`1f0?ooo`kooooo
000<ooooool0ooooA`3oool:000001D0oooo3P0000000`20P800oooo0?ooo`1i0?ooo`kooooo000<
ooooool0ooooB03oool<000000030820P03oool0oooo00/0oooo3`00001o0?ooo`kooooo000<oooo
ool0ooooBP3ooolT00000880oooo3_ooool000coooooo`3ooom>0?ooo`80P82000<0@41000000000
0000500000040820P8D0oooo3_ooool000coooooo`3ooomD0?ooo`h0000000<0P8200?ooo`3oool0
R`3oool>ooooo`003?oooooo0?oooed0oooo00<0P8200?ooo`3oool0T03oool>ooooo`00oooooooo
ooooo`_ooooo003ooooooooooooo2oooool00?ooooooooooool;ooooo`00ooooooooooooo`_ooooo
003ooooooooooooo2oooool00?ooooooooooool;ooooo`00ooooooooooooo`_ooooo003ooooooooo
oooo2oooool00001\
\>"],
  ImageRangeCache->{{{0, 216.75}, {143, 0}} -> {-15.7931, -10.0021, 3.67086, \
3.67086}}],

Cell[TextData[{
  "Fig. 1.6  Surface  ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " moving by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[DifferentialD]", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "in time ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  "."
}], "Caption",
  CellTags->"Fig. 1.6"],

Cell[TextData[{
  "\tReturning to the flow of the direction field in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane given by ",
  ButtonBox["Eq. (1.2.11)",
    ButtonData:>"(1.2.11)",
    ButtonStyle->"Hyperlink"],
  ",  the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-component of the flow field is ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  StyleBox[", ",
    FontSlant->"Italic"],
  " and the ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  "-component is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"-", 
            StyleBox[\(1\/m\),
              FontSize->14]}], 
          FractionBox[\(\[PartialD]V\), \(\[PartialD]x\),
            MultilineFunction->None]}], TraditionalForm]]],
  " . The divergence of this flow is, by analogy to Eqs. ",
  ButtonBox["(1.2.12)",
    ButtonData:>"(1.2.12)",
    ButtonStyle->"Hyperlink"],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]v\), \(\[PartialD]x\),
              MultilineFunction->None], \( \[VerticalSeparator] \_v\), 
            RowBox[{
              RowBox[{"+", 
                FractionBox["\[PartialD]", \(\[PartialD]v\),
                  MultilineFunction->None]}], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    StyleBox[\(1\/m\),
                      FontSize->14]}], 
                  FractionBox[\(\[PartialD]V\), \(\[PartialD]x\),
                    MultilineFunction->None]}], 
                ")"}]}], \( \[VerticalSeparator] \_x\)}], "=", "0"}], 
        TraditionalForm]]],
  ". \t"
}], "NE2",
  CellTags->"(1.2.14)"],

Cell["Therefore, the flow is area-conserving. ", "Text"],

Cell[TextData[{
  "\tWhy should we care whether a flow is area-conserving?  Because the \
direction field for area-conserving flows looks very different than that for \
a non-area-conserving flow such as the damped harmonic oscillator. In \
area-conserving flows, there are no attracting fixed points toward which \
orbits fall; rather, the orbits tend to circulate indefinitely. This property \
is epitomized by the phase-space flow for the undamped harmonic oscillator, \
shown in Fig. ",
  ButtonBox["1.7",
    ButtonData:>"Fig. 1.7",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"i:113"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.432501 0.5 0.432501 [
[.0675 .4875 -6 -9 ]
[.0675 .4875 6 0 ]
[.28375 .4875 -12 -9 ]
[.28375 .4875 12 0 ]
[.71625 .4875 -9 -9 ]
[.71625 .4875 9 0 ]
[.9325 .4875 -3 -9 ]
[.9325 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 .0675 -12 -4.5 ]
[.4875 .0675 0 4.5 ]
[.4875 .28375 -24 -4.5 ]
[.4875 .28375 0 4.5 ]
[.4875 .71625 -18 -4.5 ]
[.4875 .71625 0 4.5 ]
[.4875 .9325 -6 -4.5 ]
[.4875 .9325 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0675 .5 m
.0675 .50625 L
s
[(-1)] .0675 .4875 0 1 Mshowa
.28375 .5 m
.28375 .50625 L
s
[(-0.5)] .28375 .4875 0 1 Mshowa
.71625 .5 m
.71625 .50625 L
s
[(0.5)] .71625 .4875 0 1 Mshowa
.9325 .5 m
.9325 .50625 L
s
[(1)] .9325 .4875 0 1 Mshowa
.125 Mabswid
.11075 .5 m
.11075 .50375 L
s
.154 .5 m
.154 .50375 L
s
.19725 .5 m
.19725 .50375 L
s
.2405 .5 m
.2405 .50375 L
s
.327 .5 m
.327 .50375 L
s
.37025 .5 m
.37025 .50375 L
s
.4135 .5 m
.4135 .50375 L
s
.45675 .5 m
.45675 .50375 L
s
.54325 .5 m
.54325 .50375 L
s
.5865 .5 m
.5865 .50375 L
s
.62975 .5 m
.62975 .50375 L
s
.673 .5 m
.673 .50375 L
s
.7595 .5 m
.7595 .50375 L
s
.80275 .5 m
.80275 .50375 L
s
.846 .5 m
.846 .50375 L
s
.88925 .5 m
.88925 .50375 L
s
.02425 .5 m
.02425 .50375 L
s
.97575 .5 m
.97575 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .0675 m
.50625 .0675 L
s
[(-1)] .4875 .0675 1 0 Mshowa
.5 .28375 m
.50625 .28375 L
s
[(-0.5)] .4875 .28375 1 0 Mshowa
.5 .71625 m
.50625 .71625 L
s
[(0.5)] .4875 .71625 1 0 Mshowa
.5 .9325 m
.50625 .9325 L
s
[(1)] .4875 .9325 1 0 Mshowa
.125 Mabswid
.5 .11075 m
.50375 .11075 L
s
.5 .154 m
.50375 .154 L
s
.5 .19725 m
.50375 .19725 L
s
.5 .2405 m
.50375 .2405 L
s
.5 .327 m
.50375 .327 L
s
.5 .37025 m
.50375 .37025 L
s
.5 .4135 m
.50375 .4135 L
s
.5 .45675 m
.50375 .45675 L
s
.5 .54325 m
.50375 .54325 L
s
.5 .5865 m
.50375 .5865 L
s
.5 .62975 m
.50375 .62975 L
s
.5 .673 m
.50375 .673 L
s
.5 .7595 m
.50375 .7595 L
s
.5 .80275 m
.50375 .80275 L
s
.5 .846 m
.50375 .846 L
s
.5 .88925 m
.50375 .88925 L
s
.5 .02425 m
.50375 .02425 L
s
.5 .97575 m
.50375 .97575 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.0675 .0675 m
.02381 .11119 L
s
% Start of user PostScript
-1. -1. -1.10102 -0.898985 MAarrowhead1
% End of user PostScript
.0675 .12928 m
.02729 .1762 L
s
% Start of user PostScript
-1. -0.857143 -1.09297 -0.748678 MAarrowhead1
% End of user PostScript
.0675 .19107 m
.03159 .24135 L
s
% Start of user PostScript
-1. -0.714286 -1.08303 -0.598038 MAarrowhead1
% End of user PostScript
.0675 .25286 m
.03684 .3065 L
s
% Start of user PostScript
-1. -0.571429 -1.07088 -0.447394 MAarrowhead1
% End of user PostScript
.0675 .31464 m
.04316 .37143 L
s
% Start of user PostScript
-1. -0.428571 -1.05627 -0.297265 MAarrowhead1
% End of user PostScript
.0675 .37643 m
.05052 .43584 L
s
% Start of user PostScript
-1. -0.285714 -1.03925 -0.148354 MAarrowhead1
% End of user PostScript
.0675 .43821 m
.05876 .49938 L
s
% Start of user PostScript
-1. -0.142857 -1.0202 -0.00143579 MAarrowhead1
% End of user PostScript
.0675 .5 m
.0675 .56179 L
s
% Start of user PostScript
-1. 0 -1. 0.142857 MAarrowhead1
% End of user PostScript
.0675 .56179 m
.07624 .62295 L
s
% Start of user PostScript
-1. 0.142857 -0.979797 0.284278 MAarrowhead1
% End of user PostScript
.0675 .62357 m
.08447 .68298 L
s
% Start of user PostScript
-1. 0.285714 -0.960754 0.423075 MAarrowhead1
% End of user PostScript
.0675 .68536 m
.09184 .74215 L
s
% Start of user PostScript
-1. 0.428571 -0.943726 0.559878 MAarrowhead1
% End of user PostScript
.0675 .74714 m
.09815 .80079 L
s
% Start of user PostScript
-1. 0.571429 -0.929123 0.695463 MAarrowhead1
% End of user PostScript
.0675 .80893 m
.10341 .85921 L
s
% Start of user PostScript
-1. 0.714286 -0.916966 0.830533 MAarrowhead1
% End of user PostScript
.0675 .87072 m
.10771 .91763 L
s
% Start of user PostScript
-1. 0.857143 -0.90703 0.965608 MAarrowhead1
% End of user PostScript
.0675 .9325 m
.11119 .97619 L
s
% Start of user PostScript
-1. 1. -0.898985 1.10102 MAarrowhead1
% End of user PostScript
.12928 .0675 m
.08237 .10771 L
s
% Start of user PostScript
-0.857143 -1. -0.965608 -0.90703 MAarrowhead1
% End of user PostScript
.12928 .12928 m
.0856 .17297 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.958158 -0.756128 MAarrowhead1
% End of user PostScript
.12928 .19107 m
.08973 .23854 L
s
% Start of user PostScript
-0.857143 -0.714286 -0.948598 -0.60454 MAarrowhead1
% End of user PostScript
.12928 .25286 m
.09501 .30427 L
s
% Start of user PostScript
-0.857143 -0.571429 -0.936386 -0.452564 MAarrowhead1
% End of user PostScript
.12928 .31464 m
.10165 .36991 L
s
% Start of user PostScript
-0.857143 -0.428571 -0.921031 -0.300796 MAarrowhead1
% End of user PostScript
.12928 .37643 m
.10975 .43504 L
s
% Start of user PostScript
-0.857143 -0.285714 -0.902318 -0.150188 MAarrowhead1
% End of user PostScript
.12928 .43821 m
.11913 .49916 L
s
% Start of user PostScript
-0.857143 -0.142857 -0.880628 -0.00194373 MAarrowhead1
% End of user PostScript
.12928 .5 m
.12928 .56179 L
s
% Start of user PostScript
-0.857143 0 -0.857143 0.142857 MAarrowhead1
% End of user PostScript
.12928 .56179 m
.13944 .62273 L
s
% Start of user PostScript
-0.857143 0.142857 -0.833657 0.283771 MAarrowhead1
% End of user PostScript
.12928 .62357 m
.14882 .68219 L
s
% Start of user PostScript
-0.857143 0.285714 -0.811967 0.42124 MAarrowhead1
% End of user PostScript
.12928 .68536 m
.15692 .74062 L
s
% Start of user PostScript
-0.857143 0.428571 -0.793255 0.556347 MAarrowhead1
% End of user PostScript
.12928 .74714 m
.16356 .79855 L
s
% Start of user PostScript
-0.857143 0.571429 -0.7779 0.690293 MAarrowhead1
% End of user PostScript
.12928 .80893 m
.16884 .85639 L
s
% Start of user PostScript
-0.857143 0.714286 -0.765688 0.824032 MAarrowhead1
% End of user PostScript
.12928 .87072 m
.17297 .9144 L
s
% Start of user PostScript
-0.857143 0.857143 -0.756128 0.958158 MAarrowhead1
% End of user PostScript
.12928 .9325 m
.1762 .97271 L
s
% Start of user PostScript
-0.857143 1. -0.748678 1.09297 MAarrowhead1
% End of user PostScript
.19107 .0675 m
.14079 .10341 L
s
% Start of user PostScript
-0.714286 -1. -0.830533 -0.916966 MAarrowhead1
% End of user PostScript
.19107 .12928 m
.14361 .16884 L
s
% Start of user PostScript
-0.714286 -0.857143 -0.824032 -0.765688 MAarrowhead1
% End of user PostScript
.19107 .19107 m
.14738 .23476 L
s
% Start of user PostScript
-0.714286 -0.714286 -0.815301 -0.61327 MAarrowhead1
% End of user PostScript
.19107 .25286 m
.15247 .3011 L
s
% Start of user PostScript
-0.714286 -0.571429 -0.803528 -0.459876 MAarrowhead1
% End of user PostScript
.19107 .31464 m
.15928 .36762 L
s
% Start of user PostScript
-0.714286 -0.428571 -0.787785 -0.306072 MAarrowhead1
% End of user PostScript
.19107 .37643 m
.16812 .43379 L
s
% Start of user PostScript
-0.714286 -0.285714 -0.767342 -0.153075 MAarrowhead1
% End of user PostScript
.19107 .43821 m
.17895 .4988 L
s
% Start of user PostScript
-0.714286 -0.142857 -0.742302 -0.00277419 MAarrowhead1
% End of user PostScript
.19107 .5 m
.19107 .56179 L
s
% Start of user PostScript
-0.714286 0 -0.714286 0.142857 MAarrowhead1
% End of user PostScript
.19107 .56179 m
.20319 .62237 L
s
% Start of user PostScript
-0.714286 0.142857 -0.686269 0.28294 MAarrowhead1
% End of user PostScript
.19107 .62357 m
.21402 .68094 L
s
% Start of user PostScript
-0.714286 0.285714 -0.66123 0.418354 MAarrowhead1
% End of user PostScript
.19107 .68536 m
.22286 .73834 L
s
% Start of user PostScript
-0.714286 0.428571 -0.640786 0.55107 MAarrowhead1
% End of user PostScript
.19107 .74714 m
.22967 .79539 L
s
% Start of user PostScript
-0.714286 0.571429 -0.625044 0.682981 MAarrowhead1
% End of user PostScript
.19107 .80893 m
.23476 .85262 L
s
% Start of user PostScript
-0.714286 0.714286 -0.61327 0.815301 MAarrowhead1
% End of user PostScript
.19107 .87072 m
.23854 .91027 L
s
% Start of user PostScript
-0.714286 0.857143 -0.60454 0.948598 MAarrowhead1
% End of user PostScript
.19107 .9325 m
.24135 .96841 L
s
% Start of user PostScript
-0.714286 1. -0.598038 1.08303 MAarrowhead1
% End of user PostScript
.25286 .0675 m
.19921 .09815 L
s
% Start of user PostScript
-0.571429 -1. -0.695463 -0.929123 MAarrowhead1
% End of user PostScript
.25286 .12928 m
.20145 .16356 L
s
% Start of user PostScript
-0.571429 -0.857143 -0.690293 -0.7779 MAarrowhead1
% End of user PostScript
.25286 .19107 m
.20461 .22967 L
s
% Start of user PostScript
-0.571429 -0.714286 -0.682981 -0.625044 MAarrowhead1
% End of user PostScript
.25286 .25286 m
.20917 .29655 L
s
% Start of user PostScript
-0.571429 -0.571429 -0.672444 -0.470413 MAarrowhead1
% End of user PostScript
.25286 .31464 m
.21578 .36407 L
s
% Start of user PostScript
-0.571429 -0.428571 -0.657143 -0.314286 MAarrowhead1
% End of user PostScript
.25286 .37643 m
.22522 .43169 L
s
% Start of user PostScript
-0.571429 -0.285714 -0.635316 -0.157939 MAarrowhead1
% End of user PostScript
.25286 .43821 m
.23787 .49816 L
s
% Start of user PostScript
-0.571429 -0.142857 -0.606077 -0.00426536 MAarrowhead1
% End of user PostScript
.25286 .5 m
.25286 .56179 L
s
% Start of user PostScript
-0.571429 0 -0.571429 0.142857 MAarrowhead1
% End of user PostScript
.25286 .56179 m
.26784 .62173 L
s
% Start of user PostScript
-0.571429 0.142857 -0.536781 0.281449 MAarrowhead1
% End of user PostScript
.25286 .62357 m
.28049 .67883 L
s
% Start of user PostScript
-0.571429 0.285714 -0.507541 0.41349 MAarrowhead1
% End of user PostScript
.25286 .68536 m
.28993 .73479 L
s
% Start of user PostScript
-0.571429 0.428571 -0.485714 0.542857 MAarrowhead1
% End of user PostScript
.25286 .74714 m
.29655 .79083 L
s
% Start of user PostScript
-0.571429 0.571429 -0.470413 0.672444 MAarrowhead1
% End of user PostScript
.25286 .80893 m
.3011 .84753 L
s
% Start of user PostScript
-0.571429 0.714286 -0.459876 0.803528 MAarrowhead1
% End of user PostScript
.25286 .87072 m
.30427 .90499 L
s
% Start of user PostScript
-0.571429 0.857143 -0.452564 0.936386 MAarrowhead1
% End of user PostScript
.25286 .9325 m
.3065 .96316 L
s
% Start of user PostScript
-0.571429 1. -0.447394 1.07088 MAarrowhead1
% End of user PostScript
.31464 .0675 m
.25785 .09184 L
s
% Start of user PostScript
-0.428571 -1. -0.559878 -0.943726 MAarrowhead1
% End of user PostScript
.31464 .12928 m
.25938 .15692 L
s
% Start of user PostScript
-0.428571 -0.857143 -0.556347 -0.793255 MAarrowhead1
% End of user PostScript
.31464 .19107 m
.26166 .22286 L
s
% Start of user PostScript
-0.428571 -0.714286 -0.55107 -0.640786 MAarrowhead1
% End of user PostScript
.31464 .25286 m
.26521 .28993 L
s
% Start of user PostScript
-0.428571 -0.571429 -0.542857 -0.485714 MAarrowhead1
% End of user PostScript
.31464 .31464 m
.27095 .35833 L
s
% Start of user PostScript
-0.428571 -0.428571 -0.529587 -0.327556 MAarrowhead1
% End of user PostScript
.31464 .37643 m
.28037 .42784 L
s
% Start of user PostScript
-0.428571 -0.285714 -0.507814 -0.16685 MAarrowhead1
% End of user PostScript
.31464 .43821 m
.2951 .49683 L
s
% Start of user PostScript
-0.428571 -0.142857 -0.473747 -0.00733096 MAarrowhead1
% End of user PostScript
.31464 .5 m
.31464 .56179 L
s
% Start of user PostScript
-0.428571 0 -0.428571 0.142857 MAarrowhead1
% End of user PostScript
.31464 .56179 m
.33418 .6204 L
s
% Start of user PostScript
-0.428571 0.142857 -0.383396 0.278383 MAarrowhead1
% End of user PostScript
.31464 .62357 m
.34891 .67498 L
s
% Start of user PostScript
-0.428571 0.285714 -0.349329 0.404579 MAarrowhead1
% End of user PostScript
.31464 .68536 m
.35833 .72905 L
s
% Start of user PostScript
-0.428571 0.428571 -0.327556 0.529587 MAarrowhead1
% End of user PostScript
.31464 .74714 m
.36407 .78422 L
s
% Start of user PostScript
-0.428571 0.571429 -0.314286 0.657143 MAarrowhead1
% End of user PostScript
.31464 .80893 m
.36762 .84072 L
s
% Start of user PostScript
-0.428571 0.714286 -0.306072 0.787785 MAarrowhead1
% End of user PostScript
.31464 .87072 m
.36991 .89835 L
s
% Start of user PostScript
-0.428571 0.857143 -0.300796 0.921031 MAarrowhead1
% End of user PostScript
.31464 .9325 m
.37143 .95684 L
s
% Start of user PostScript
-0.428571 1. -0.297265 1.05627 MAarrowhead1
% End of user PostScript
.37643 .0675 m
.31702 .08447 L
s
% Start of user PostScript
-0.285714 -1. -0.423075 -0.960754 MAarrowhead1
% End of user PostScript
.37643 .12928 m
.31781 .14882 L
s
% Start of user PostScript
-0.285714 -0.857143 -0.42124 -0.811967 MAarrowhead1
% End of user PostScript
.37643 .19107 m
.31906 .21402 L
s
% Start of user PostScript
-0.285714 -0.714286 -0.418354 -0.66123 MAarrowhead1
% End of user PostScript
.37643 .25286 m
.32117 .28049 L
s
% Start of user PostScript
-0.285714 -0.571429 -0.41349 -0.507541 MAarrowhead1
% End of user PostScript
.37643 .31464 m
.32502 .34891 L
s
% Start of user PostScript
-0.285714 -0.428571 -0.404579 -0.349329 MAarrowhead1
% End of user PostScript
.37643 .37643 m
.33274 .42012 L
s
% Start of user PostScript
-0.285714 -0.285714 -0.38673 -0.184699 MAarrowhead1
% End of user PostScript
.37643 .43821 m
.3488 .49348 L
s
% Start of user PostScript
-0.285714 -0.142857 -0.349602 -0.0150818 MAarrowhead1
% End of user PostScript
.37643 .5 m
.37643 .56179 L
s
% Start of user PostScript
-0.285714 0 -0.285714 0.142857 MAarrowhead1
% End of user PostScript
.37643 .56179 m
.40406 .61705 L
s
% Start of user PostScript
-0.285714 0.142857 -0.221827 0.270632 MAarrowhead1
% End of user PostScript
.37643 .62357 m
.42012 .66726 L
s
% Start of user PostScript
-0.285714 0.285714 -0.184699 0.38673 MAarrowhead1
% End of user PostScript
.37643 .68536 m
.42784 .71963 L
s
% Start of user PostScript
-0.285714 0.428571 -0.16685 0.507814 MAarrowhead1
% End of user PostScript
.37643 .74714 m
.43169 .77478 L
s
% Start of user PostScript
-0.285714 0.571429 -0.157939 0.635316 MAarrowhead1
% End of user PostScript
.37643 .80893 m
.43379 .83188 L
s
% Start of user PostScript
-0.285714 0.714286 -0.153075 0.767342 MAarrowhead1
% End of user PostScript
.37643 .87072 m
.43504 .89025 L
s
% Start of user PostScript
-0.285714 0.857143 -0.150188 0.902318 MAarrowhead1
% End of user PostScript
.37643 .9325 m
.43584 .94948 L
s
% Start of user PostScript
-0.285714 1. -0.148354 1.03925 MAarrowhead1
% End of user PostScript
.43821 .0675 m
.37705 .07624 L
s
% Start of user PostScript
-0.142857 -1. -0.284278 -0.979797 MAarrowhead1
% End of user PostScript
.43821 .12928 m
.37727 .13944 L
s
% Start of user PostScript
-0.142857 -0.857143 -0.283771 -0.833657 MAarrowhead1
% End of user PostScript
.43821 .19107 m
.37763 .20319 L
s
% Start of user PostScript
-0.142857 -0.714286 -0.28294 -0.686269 MAarrowhead1
% End of user PostScript
.43821 .25286 m
.37827 .26784 L
s
% Start of user PostScript
-0.142857 -0.571429 -0.281449 -0.536781 MAarrowhead1
% End of user PostScript
.43821 .31464 m
.3796 .33418 L
s
% Start of user PostScript
-0.142857 -0.428571 -0.278383 -0.383396 MAarrowhead1
% End of user PostScript
.43821 .37643 m
.38295 .40406 L
s
% Start of user PostScript
-0.142857 -0.285714 -0.270632 -0.221827 MAarrowhead1
% End of user PostScript
.43821 .43821 m
.39452 .4819 L
s
% Start of user PostScript
-0.142857 -0.142857 -0.243872 -0.0418419 MAarrowhead1
% End of user PostScript
.43821 .5 m
.43821 .56179 L
s
% Start of user PostScript
-0.142857 0 -0.142857 0.142857 MAarrowhead1
% End of user PostScript
.43821 .56179 m
.4819 .60548 L
s
% Start of user PostScript
-0.142857 0.142857 -0.0418419 0.243872 MAarrowhead1
% End of user PostScript
.43821 .62357 m
.49348 .6512 L
s
% Start of user PostScript
-0.142857 0.285714 -0.0150818 0.349602 MAarrowhead1
% End of user PostScript
.43821 .68536 m
.49683 .7049 L
s
% Start of user PostScript
-0.142857 0.428571 -0.00733096 0.473747 MAarrowhead1
% End of user PostScript
.43821 .74714 m
.49816 .76213 L
s
% Start of user PostScript
-0.142857 0.571429 -0.00426536 0.606077 MAarrowhead1
% End of user PostScript
.43821 .80893 m
.4988 .82105 L
s
% Start of user PostScript
-0.142857 0.714286 -0.00277419 0.742302 MAarrowhead1
% End of user PostScript
.43821 .87072 m
.49916 .88087 L
s
% Start of user PostScript
-0.142857 0.857143 -0.00194373 0.880628 MAarrowhead1
% End of user PostScript
.43821 .9325 m
.49938 .94124 L
s
% Start of user PostScript
-0.142857 1. -0.00143579 1.0202 MAarrowhead1
% End of user PostScript
.5 .0675 m
.43821 .0675 L
s
% Start of user PostScript
0 -1. -0.142857 -1. MAarrowhead1
% End of user PostScript
.5 .12928 m
.43821 .12928 L
s
% Start of user PostScript
0 -0.857143 -0.142857 -0.857143 MAarrowhead1
% End of user PostScript
.5 .19107 m
.43821 .19107 L
s
% Start of user PostScript
0 -0.714286 -0.142857 -0.714286 MAarrowhead1
% End of user PostScript
.5 .25286 m
.43821 .25286 L
s
% Start of user PostScript
0 -0.571429 -0.142857 -0.571429 MAarrowhead1
% End of user PostScript
.5 .31464 m
.43821 .31464 L
s
% Start of user PostScript
0 -0.428571 -0.142857 -0.428571 MAarrowhead1
% End of user PostScript
.5 .37643 m
.43821 .37643 L
s
% Start of user PostScript
0 -0.285714 -0.142857 -0.285714 MAarrowhead1
% End of user PostScript
.5 .43821 m
.43821 .43821 L
s
% Start of user PostScript
0 -0.142857 -0.142857 -0.142857 MAarrowhead1
% End of user PostScript
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .56179 m
.56179 .56179 L
s
% Start of user PostScript
0 0.142857 0.142857 0.142857 MAarrowhead1
% End of user PostScript
.5 .62357 m
.56179 .62357 L
s
% Start of user PostScript
0 0.285714 0.142857 0.285714 MAarrowhead1
% End of user PostScript
.5 .68536 m
.56179 .68536 L
s
% Start of user PostScript
0 0.428571 0.142857 0.428571 MAarrowhead1
% End of user PostScript
.5 .74714 m
.56179 .74714 L
s
% Start of user PostScript
0 0.571429 0.142857 0.571429 MAarrowhead1
% End of user PostScript
.5 .80893 m
.56179 .80893 L
s
% Start of user PostScript
0 0.714286 0.142857 0.714286 MAarrowhead1
% End of user PostScript
.5 .87072 m
.56179 .87072 L
s
% Start of user PostScript
0 0.857143 0.142857 0.857143 MAarrowhead1
% End of user PostScript
.5 .9325 m
.56179 .9325 L
s
% Start of user PostScript
0 1. 0.142857 1. MAarrowhead1
% End of user PostScript
.56179 .0675 m
.50062 .05876 L
s
% Start of user PostScript
0.142857 -1. 0.00143579 -1.0202 MAarrowhead1
% End of user PostScript
.56179 .12928 m
.50084 .11913 L
s
% Start of user PostScript
0.142857 -0.857143 0.00194373 -0.880628 MAarrowhead1
% End of user PostScript
.56179 .19107 m
.5012 .17895 L
s
% Start of user PostScript
0.142857 -0.714286 0.00277419 -0.742302 MAarrowhead1
% End of user PostScript
.56179 .25286 m
.50184 .23787 L
s
% Start of user PostScript
0.142857 -0.571429 0.00426536 -0.606077 MAarrowhead1
% End of user PostScript
.56179 .31464 m
.50317 .2951 L
s
% Start of user PostScript
0.142857 -0.428571 0.00733096 -0.473747 MAarrowhead1
% End of user PostScript
.56179 .37643 m
.50652 .3488 L
s
% Start of user PostScript
0.142857 -0.285714 0.0150818 -0.349602 MAarrowhead1
% End of user PostScript
.56179 .43821 m
.5181 .39452 L
s
% Start of user PostScript
0.142857 -0.142857 0.0418419 -0.243872 MAarrowhead1
% End of user PostScript
.56179 .5 m
.56179 .43821 L
s
% Start of user PostScript
0.142857 0 0.142857 -0.142857 MAarrowhead1
% End of user PostScript
.56179 .56179 m
.60548 .5181 L
s
% Start of user PostScript
0.142857 0.142857 0.243872 0.0418419 MAarrowhead1
% End of user PostScript
.56179 .62357 m
.61705 .59594 L
s
% Start of user PostScript
0.142857 0.285714 0.270632 0.221827 MAarrowhead1
% End of user PostScript
.56179 .68536 m
.6204 .66582 L
s
% Start of user PostScript
0.142857 0.428571 0.278383 0.383396 MAarrowhead1
% End of user PostScript
.56179 .74714 m
.62173 .73216 L
s
% Start of user PostScript
0.142857 0.571429 0.281449 0.536781 MAarrowhead1
% End of user PostScript
.56179 .80893 m
.62237 .79681 L
s
% Start of user PostScript
0.142857 0.714286 0.28294 0.686269 MAarrowhead1
% End of user PostScript
.56179 .87072 m
.62273 .86056 L
s
% Start of user PostScript
0.142857 0.857143 0.283771 0.833657 MAarrowhead1
% End of user PostScript
.56179 .9325 m
.62295 .92376 L
s
% Start of user PostScript
0.142857 1. 0.284278 0.979797 MAarrowhead1
% End of user PostScript
.62357 .0675 m
.56416 .05052 L
s
% Start of user PostScript
0.285714 -1. 0.148354 -1.03925 MAarrowhead1
% End of user PostScript
.62357 .12928 m
.56496 .10975 L
s
% Start of user PostScript
0.285714 -0.857143 0.150188 -0.902318 MAarrowhead1
% End of user PostScript
.62357 .19107 m
.56621 .16812 L
s
% Start of user PostScript
0.285714 -0.714286 0.153075 -0.767342 MAarrowhead1
% End of user PostScript
.62357 .25286 m
.56831 .22522 L
s
% Start of user PostScript
0.285714 -0.571429 0.157939 -0.635316 MAarrowhead1
% End of user PostScript
.62357 .31464 m
.57216 .28037 L
s
% Start of user PostScript
0.285714 -0.428571 0.16685 -0.507814 MAarrowhead1
% End of user PostScript
.62357 .37643 m
.57988 .33274 L
s
% Start of user PostScript
0.285714 -0.285714 0.184699 -0.38673 MAarrowhead1
% End of user PostScript
.62357 .43821 m
.59594 .38295 L
s
% Start of user PostScript
0.285714 -0.142857 0.221827 -0.270632 MAarrowhead1
% End of user PostScript
.62357 .5 m
.62357 .43821 L
s
% Start of user PostScript
0.285714 0 0.285714 -0.142857 MAarrowhead1
% End of user PostScript
.62357 .56179 m
.6512 .50652 L
s
% Start of user PostScript
0.285714 0.142857 0.349602 0.0150818 MAarrowhead1
% End of user PostScript
.62357 .62357 m
.66726 .57988 L
s
% Start of user PostScript
0.285714 0.285714 0.38673 0.184699 MAarrowhead1
% End of user PostScript
.62357 .68536 m
.67498 .65109 L
s
% Start of user PostScript
0.285714 0.428571 0.404579 0.349329 MAarrowhead1
% End of user PostScript
.62357 .74714 m
.67883 .71951 L
s
% Start of user PostScript
0.285714 0.571429 0.41349 0.507541 MAarrowhead1
% End of user PostScript
.62357 .80893 m
.68094 .78598 L
s
% Start of user PostScript
0.285714 0.714286 0.418354 0.66123 MAarrowhead1
% End of user PostScript
.62357 .87072 m
.68219 .85118 L
s
% Start of user PostScript
0.285714 0.857143 0.42124 0.811967 MAarrowhead1
% End of user PostScript
.62357 .9325 m
.68298 .91553 L
s
% Start of user PostScript
0.285714 1. 0.423075 0.960754 MAarrowhead1
% End of user PostScript
.68536 .0675 m
.62857 .04316 L
s
% Start of user PostScript
0.428571 -1. 0.297265 -1.05627 MAarrowhead1
% End of user PostScript
.68536 .12928 m
.63009 .10165 L
s
% Start of user PostScript
0.428571 -0.857143 0.300796 -0.921031 MAarrowhead1
% End of user PostScript
.68536 .19107 m
.63238 .15928 L
s
% Start of user PostScript
0.428571 -0.714286 0.306072 -0.787785 MAarrowhead1
% End of user PostScript
.68536 .25286 m
.63593 .21578 L
s
% Start of user PostScript
0.428571 -0.571429 0.314286 -0.657143 MAarrowhead1
% End of user PostScript
.68536 .31464 m
.64167 .27095 L
s
% Start of user PostScript
0.428571 -0.428571 0.327556 -0.529587 MAarrowhead1
% End of user PostScript
.68536 .37643 m
.65109 .32502 L
s
% Start of user PostScript
0.428571 -0.285714 0.349329 -0.404579 MAarrowhead1
% End of user PostScript
.68536 .43821 m
.66582 .3796 L
s
% Start of user PostScript
0.428571 -0.142857 0.383396 -0.278383 MAarrowhead1
% End of user PostScript
.68536 .5 m
.68536 .43821 L
s
% Start of user PostScript
0.428571 0 0.428571 -0.142857 MAarrowhead1
% End of user PostScript
.68536 .56179 m
.7049 .50317 L
s
% Start of user PostScript
0.428571 0.142857 0.473747 0.00733096 MAarrowhead1
% End of user PostScript
.68536 .62357 m
.71963 .57216 L
s
% Start of user PostScript
0.428571 0.285714 0.507814 0.16685 MAarrowhead1
% End of user PostScript
.68536 .68536 m
.72905 .64167 L
s
% Start of user PostScript
0.428571 0.428571 0.529587 0.327556 MAarrowhead1
% End of user PostScript
.68536 .74714 m
.73479 .71007 L
s
% Start of user PostScript
0.428571 0.571429 0.542857 0.485714 MAarrowhead1
% End of user PostScript
.68536 .80893 m
.73834 .77714 L
s
% Start of user PostScript
0.428571 0.714286 0.55107 0.640786 MAarrowhead1
% End of user PostScript
.68536 .87072 m
.74062 .84308 L
s
% Start of user PostScript
0.428571 0.857143 0.556347 0.793255 MAarrowhead1
% End of user PostScript
.68536 .9325 m
.74215 .90816 L
s
% Start of user PostScript
0.428571 1. 0.559878 0.943726 MAarrowhead1
% End of user PostScript
.74714 .0675 m
.6935 .03684 L
s
% Start of user PostScript
0.571429 -1. 0.447394 -1.07088 MAarrowhead1
% End of user PostScript
.74714 .12928 m
.69573 .09501 L
s
% Start of user PostScript
0.571429 -0.857143 0.452564 -0.936386 MAarrowhead1
% End of user PostScript
.74714 .19107 m
.6989 .15247 L
s
% Start of user PostScript
0.571429 -0.714286 0.459876 -0.803528 MAarrowhead1
% End of user PostScript
.74714 .25286 m
.70345 .20917 L
s
% Start of user PostScript
0.571429 -0.571429 0.470413 -0.672444 MAarrowhead1
% End of user PostScript
.74714 .31464 m
.71007 .26521 L
s
% Start of user PostScript
0.571429 -0.428571 0.485714 -0.542857 MAarrowhead1
% End of user PostScript
.74714 .37643 m
.71951 .32117 L
s
% Start of user PostScript
0.571429 -0.285714 0.507541 -0.41349 MAarrowhead1
% End of user PostScript
.74714 .43821 m
.73216 .37827 L
s
% Start of user PostScript
0.571429 -0.142857 0.536781 -0.281449 MAarrowhead1
% End of user PostScript
.74714 .5 m
.74714 .43821 L
s
% Start of user PostScript
0.571429 0 0.571429 -0.142857 MAarrowhead1
% End of user PostScript
.74714 .56179 m
.76213 .50184 L
s
% Start of user PostScript
0.571429 0.142857 0.606077 0.00426536 MAarrowhead1
% End of user PostScript
.74714 .62357 m
.77478 .56831 L
s
% Start of user PostScript
0.571429 0.285714 0.635316 0.157939 MAarrowhead1
% End of user PostScript
.74714 .68536 m
.78422 .63593 L
s
% Start of user PostScript
0.571429 0.428571 0.657143 0.314286 MAarrowhead1
% End of user PostScript
.74714 .74714 m
.79083 .70345 L
s
% Start of user PostScript
0.571429 0.571429 0.672444 0.470413 MAarrowhead1
% End of user PostScript
.74714 .80893 m
.79539 .77033 L
s
% Start of user PostScript
0.571429 0.714286 0.682981 0.625044 MAarrowhead1
% End of user PostScript
.74714 .87072 m
.79855 .83644 L
s
% Start of user PostScript
0.571429 0.857143 0.690293 0.7779 MAarrowhead1
% End of user PostScript
.74714 .9325 m
.80079 .90185 L
s
% Start of user PostScript
0.571429 1. 0.695463 0.929123 MAarrowhead1
% End of user PostScript
.80893 .0675 m
.75865 .03159 L
s
% Start of user PostScript
0.714286 -1. 0.598038 -1.08303 MAarrowhead1
% End of user PostScript
.80893 .12928 m
.76146 .08973 L
s
% Start of user PostScript
0.714286 -0.857143 0.60454 -0.948598 MAarrowhead1
% End of user PostScript
.80893 .19107 m
.76524 .14738 L
s
% Start of user PostScript
0.714286 -0.714286 0.61327 -0.815301 MAarrowhead1
% End of user PostScript
.80893 .25286 m
.77033 .20461 L
s
% Start of user PostScript
0.714286 -0.571429 0.625044 -0.682981 MAarrowhead1
% End of user PostScript
.80893 .31464 m
.77714 .26166 L
s
% Start of user PostScript
0.714286 -0.428571 0.640786 -0.55107 MAarrowhead1
% End of user PostScript
.80893 .37643 m
.78598 .31906 L
s
% Start of user PostScript
0.714286 -0.285714 0.66123 -0.418354 MAarrowhead1
% End of user PostScript
.80893 .43821 m
.79681 .37763 L
s
% Start of user PostScript
0.714286 -0.142857 0.686269 -0.28294 MAarrowhead1
% End of user PostScript
.80893 .5 m
.80893 .43821 L
s
% Start of user PostScript
0.714286 0 0.714286 -0.142857 MAarrowhead1
% End of user PostScript
.80893 .56179 m
.82105 .5012 L
s
% Start of user PostScript
0.714286 0.142857 0.742302 0.00277419 MAarrowhead1
% End of user PostScript
.80893 .62357 m
.83188 .56621 L
s
% Start of user PostScript
0.714286 0.285714 0.767342 0.153075 MAarrowhead1
% End of user PostScript
.80893 .68536 m
.84072 .63238 L
s
% Start of user PostScript
0.714286 0.428571 0.787785 0.306072 MAarrowhead1
% End of user PostScript
.80893 .74714 m
.84753 .6989 L
s
% Start of user PostScript
0.714286 0.571429 0.803528 0.459876 MAarrowhead1
% End of user PostScript
.80893 .80893 m
.85262 .76524 L
s
% Start of user PostScript
0.714286 0.714286 0.815301 0.61327 MAarrowhead1
% End of user PostScript
.80893 .87072 m
.85639 .83116 L
s
% Start of user PostScript
0.714286 0.857143 0.824032 0.765688 MAarrowhead1
% End of user PostScript
.80893 .9325 m
.85921 .89659 L
s
% Start of user PostScript
0.714286 1. 0.830533 0.916966 MAarrowhead1
% End of user PostScript
.87072 .0675 m
.8238 .02729 L
s
% Start of user PostScript
0.857143 -1. 0.748678 -1.09297 MAarrowhead1
% End of user PostScript
.87072 .12928 m
.82703 .0856 L
s
% Start of user PostScript
0.857143 -0.857143 0.756128 -0.958158 MAarrowhead1
% End of user PostScript
.87072 .19107 m
.83116 .14361 L
s
% Start of user PostScript
0.857143 -0.714286 0.765688 -0.824032 MAarrowhead1
% End of user PostScript
.87072 .25286 m
.83644 .20145 L
s
% Start of user PostScript
0.857143 -0.571429 0.7779 -0.690293 MAarrowhead1
% End of user PostScript
.87072 .31464 m
.84308 .25938 L
s
% Start of user PostScript
0.857143 -0.428571 0.793255 -0.556347 MAarrowhead1
% End of user PostScript
.87072 .37643 m
.85118 .31781 L
s
% Start of user PostScript
0.857143 -0.285714 0.811967 -0.42124 MAarrowhead1
% End of user PostScript
.87072 .43821 m
.86056 .37727 L
s
% Start of user PostScript
0.857143 -0.142857 0.833657 -0.283771 MAarrowhead1
% End of user PostScript
.87072 .5 m
.87072 .43821 L
s
% Start of user PostScript
0.857143 0 0.857143 -0.142857 MAarrowhead1
% End of user PostScript
.87072 .56179 m
.88087 .50084 L
s
% Start of user PostScript
0.857143 0.142857 0.880628 0.00194373 MAarrowhead1
% End of user PostScript
.87072 .62357 m
.89025 .56496 L
s
% Start of user PostScript
0.857143 0.285714 0.902318 0.150188 MAarrowhead1
% End of user PostScript
.87072 .68536 m
.89835 .63009 L
s
% Start of user PostScript
0.857143 0.428571 0.921031 0.300796 MAarrowhead1
% End of user PostScript
.87072 .74714 m
.90499 .69573 L
s
% Start of user PostScript
0.857143 0.571429 0.936386 0.452564 MAarrowhead1
% End of user PostScript
.87072 .80893 m
.91027 .76146 L
s
% Start of user PostScript
0.857143 0.714286 0.948598 0.60454 MAarrowhead1
% End of user PostScript
.87072 .87072 m
.9144 .82703 L
s
% Start of user PostScript
0.857143 0.857143 0.958158 0.756128 MAarrowhead1
% End of user PostScript
.87072 .9325 m
.91763 .89229 L
s
% Start of user PostScript
0.857143 1. 0.965608 0.90703 MAarrowhead1
% End of user PostScript
.9325 .0675 m
.88881 .02381 L
s
% Start of user PostScript
1. -1. 0.898985 -1.10102 MAarrowhead1
% End of user PostScript
.9325 .12928 m
.89229 .08237 L
s
% Start of user PostScript
1. -0.857143 0.90703 -0.965608 MAarrowhead1
% End of user PostScript
.9325 .19107 m
.89659 .14079 L
s
% Start of user PostScript
1. -0.714286 0.916966 -0.830533 MAarrowhead1
% End of user PostScript
.9325 .25286 m
.90185 .19921 L
s
% Start of user PostScript
1. -0.571429 0.929123 -0.695463 MAarrowhead1
% End of user PostScript
.9325 .31464 m
.90816 .25785 L
s
% Start of user PostScript
1. -0.428571 0.943726 -0.559878 MAarrowhead1
% End of user PostScript
.9325 .37643 m
.91553 .31702 L
s
% Start of user PostScript
1. -0.285714 0.960754 -0.423075 MAarrowhead1
% End of user PostScript
.9325 .43821 m
.92376 .37705 L
s
% Start of user PostScript
1. -0.142857 0.979797 -0.284278 MAarrowhead1
% End of user PostScript
.9325 .5 m
.9325 .43821 L
s
% Start of user PostScript
1. 0 1. -0.142857 MAarrowhead1
% End of user PostScript
.9325 .56179 m
.94124 .50062 L
s
% Start of user PostScript
1. 0.142857 1.0202 0.00143579 MAarrowhead1
% End of user PostScript
.9325 .62357 m
.94948 .56416 L
s
% Start of user PostScript
1. 0.285714 1.03925 0.148354 MAarrowhead1
% End of user PostScript
.9325 .68536 m
.95684 .62857 L
s
% Start of user PostScript
1. 0.428571 1.05627 0.297265 MAarrowhead1
% End of user PostScript
.9325 .74714 m
.96316 .6935 L
s
% Start of user PostScript
1. 0.571429 1.07088 0.447394 MAarrowhead1
% End of user PostScript
.9325 .80893 m
.96841 .75865 L
s
% Start of user PostScript
1. 0.714286 1.08303 0.598038 MAarrowhead1
% End of user PostScript
.9325 .87072 m
.97271 .8238 L
s
% Start of user PostScript
1. 0.857143 1.09297 0.748678 MAarrowhead1
% End of user PostScript
.9325 .9325 m
.97619 .88881 L
s
% Start of user PostScript
1. 1. 1.10102 0.898985 MAarrowhead1
% End of user PostScript
.5 Mabswid
.71625 .5 m
.71624 .50168 L
.71623 .5032 L
.71619 .50496 L
.71615 .50663 L
.71604 .50959 L
.71587 .5128 L
.71563 .51633 L
.71532 .52007 L
.71459 .52676 L
.71362 .53365 L
.71251 .54006 L
.70926 .55453 L
.70494 .56901 L
.70011 .58198 L
.68627 .60986 L
.67109 .63227 L
.65146 .65435 L
.63021 .67265 L
.60515 .68896 L
.5921 .69566 L
.5775 .70189 L
.56455 .70639 L
.55003 .71038 L
.5431 .71191 L
.53561 .7133 L
.52911 .71428 L
.522 .71513 L
.51783 .71551 L
.51396 .7158 L
.51026 .71601 L
.50839 .71609 L
.50632 .71616 L
.50447 .7162 L
.50276 .71623 L
.5009 .71625 L
.49996 .71625 L
.49893 .71625 L
.49719 .71623 L
.49534 .7162 L
.49358 .71616 L
.49199 .7161 L
.4887 .71596 L
.48508 .71574 L
.47779 .71511 L
.47105 .7143 L
.46478 .71336 L
.45075 .71057 L
.43593 .70654 L
.42227 .7018 L
Mistroke
.40779 .69561 L
.38273 .6817 L
.36016 .66495 L
.33874 .64408 L
.32003 .61989 L
.3057 .59494 L
.29998 .5822 L
.29485 .56839 L
.2909 .55516 L
.28805 .54292 L
.28578 .52956 L
.28489 .52215 L
.28456 .51875 L
.28428 .51512 L
.28408 .51203 L
.284 .51038 L
.28392 .50861 L
.28386 .50699 L
.28382 .50551 L
.28379 .50409 L
.28376 .50259 L
.28375 .50096 L
.28375 .49921 L
.28376 .49757 L
.28378 .49608 L
.28382 .49432 L
.28388 .49242 L
.28403 .48897 L
.28423 .4856 L
.2845 .48198 L
.28514 .47548 L
.28617 .46777 L
.28734 .46077 L
.29067 .44572 L
.29482 .4317 L
.30552 .40545 L
.31841 .38258 L
.33418 .36119 L
.35451 .34001 L
.37603 .32281 L
.4015 .30749 L
.4277 .29619 L
.44139 .29184 L
.44921 .2898 L
.45667 .28813 L
.46357 .28684 L
.4711 .28569 L
.47797 .28487 L
.48433 .28432 L
.48789 .28409 L
Mistroke
.49123 .28393 L
.49314 .28386 L
.49489 .28381 L
.49585 .28379 L
.49691 .28377 L
.4979 .28376 L
.49883 .28375 L
.49979 .28375 L
.50084 .28375 L
.50182 .28376 L
.50273 .28377 L
.50445 .2838 L
.50627 .28384 L
.50822 .28391 L
.51005 .28398 L
.51419 .28422 L
.51789 .28449 L
.52131 .2848 L
.52903 .28571 L
.53581 .28674 L
.54297 .28806 L
.55523 .29092 L
.56853 .2949 L
.5941 .3053 L
.61993 .32005 L
.64262 .33744 L
.6638 .35881 L
.68076 .3813 L
.69379 .40402 L
.69998 .41771 L
.70494 .43099 L
.70869 .44332 L
.71185 .45658 L
.71376 .46725 L
.7146 .47335 L
.71524 .47907 L
.71568 .48433 L
.71598 .48915 L
.7161 .49181 L
.71614 .49322 L
.71619 .49472 L
.71622 .49616 L
.71624 .49746 L
.71625 .49877 L
.71625 .5 L
Mfstroke
.9325 .5 m
.93249 .50335 L
.93245 .50641 L
.93239 .50993 L
.9323 .51326 L
.93208 .51918 L
.93174 .5256 L
.93127 .53266 L
.93063 .54014 L
.92918 .55353 L
.92723 .56729 L
.92502 .58012 L
.91853 .60905 L
.90988 .63803 L
.90022 .66396 L
.87254 .71971 L
.84217 .76453 L
.80292 .8087 L
.76042 .84531 L
.71031 .87793 L
.6842 .89132 L
.655 .90377 L
.6291 .91279 L
.60006 .92077 L
.5862 .92383 L
.57123 .9266 L
.55822 .92856 L
.54401 .93026 L
.53566 .93103 L
.52792 .9316 L
.52052 .93201 L
.51677 .93218 L
.51264 .93232 L
.50893 .93241 L
.50553 .93247 L
.50179 .9325 L
.49992 .9325 L
.49786 .9325 L
.49438 .93246 L
.49067 .9324 L
.48717 .93231 L
.48398 .9322 L
.4774 .93191 L
.47017 .93147 L
.45558 .93021 L
.44211 .92861 L
.42955 .92673 L
.4015 .92114 L
.37185 .91308 L
.34455 .9036 L
Mistroke
.31558 .89121 L
.26547 .86339 L
.22033 .82991 L
.17747 .78815 L
.14005 .73978 L
.1114 .68987 L
.09996 .6644 L
.0897 .63678 L
.08181 .61033 L
.0761 .58585 L
.07156 .55912 L
.06977 .54431 L
.06913 .53749 L
.06856 .53025 L
.06817 .52406 L
.068 .52077 L
.06784 .51723 L
.06772 .51398 L
.06764 .51101 L
.06758 .50817 L
.06753 .50518 L
.0675 .50192 L
.0675 .49843 L
.06753 .49514 L
.06757 .49216 L
.06765 .48864 L
.06776 .48483 L
.06806 .47793 L
.06846 .47119 L
.069 .46397 L
.07029 .45095 L
.07233 .43553 L
.07468 .42154 L
.08135 .39143 L
.08964 .3634 L
.11103 .31089 L
.13681 .26515 L
.16837 .22237 L
.20902 .18002 L
.25207 .14562 L
.303 .11497 L
.35541 .09238 L
.38278 .08369 L
.39843 .07959 L
.41334 .07627 L
.42714 .07368 L
.4422 .07138 L
.45594 .06975 L
.46867 .06864 L
.47578 .06818 L
Mistroke
.48245 .06785 L
.48628 .06772 L
.48978 .06762 L
.49171 .06758 L
.49381 .06754 L
.49581 .06752 L
.49765 .06751 L
.49958 .0675 L
.50167 .0675 L
.50365 .06751 L
.50546 .06753 L
.5089 .06759 L
.51253 .06768 L
.51644 .06781 L
.52009 .06797 L
.52837 .06843 L
.53578 .06898 L
.54263 .0696 L
.55807 .07141 L
.57162 .07347 L
.58593 .07612 L
.61045 .08184 L
.63707 .08979 L
.68821 .1106 L
.73985 .1401 L
.78523 .17489 L
.82759 .21762 L
.86152 .26259 L
.88757 .30804 L
.89996 .33542 L
.90989 .36198 L
.91738 .38664 L
.9237 .41317 L
.92751 .4345 L
.9292 .44669 L
.93047 .45814 L
.93136 .46867 L
.93196 .4783 L
.93219 .48363 L
.93229 .48644 L
.93237 .48943 L
.93243 .49231 L
.93247 .49492 L
.93249 .49754 L
.9325 .5 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`1oooooo`;o0000
>oooool00:Wooooo0_l00020ooooo`?o0000>_ooool00:Wooooo00?o0000ooooooooool0JOooool2
o`0001Gooooo1?l0000hooooo`00ZOooool00ol0003oooooooooo`1Cooooo`;o00005?ooool4o`00
01Cooooo1?l0000gooooo`00ZOooool00ol0003oooooooooo`1Dooooo`Co00004_ooool5o`0001;o
oooo1Ol0000fooooo`00ZOooool00ol0003oooooooooo`0mooooo`?o00005Oooool5o`00017ooooo
1Ol0000Booooo`?o0000=oooool00:Wooooo00?o0000ooooooooool0?_ooool5o`0001?ooooo1Ol0
000Aooooo`Co00004oooool00ol0003oooooo`00000fooooo`00ZOooool00ol0003oooooooooo`0X
ooooo`Go00004_ooool6o`0001;ooooo0ol0000Cooooo`04o`000?ooooooooooo`0001Gooooo00?o
0000ooooooooool0<oooool00:Wooooo00?o0000ooooooooool0:_ooool6o`00013ooooo1Ol0000C
ooooo`04o`000?oooooo0000o`0001Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0booooo`00ZOooool00ol0003oooooooooo`0Booooo`Go00005?ooool5o`00017ooooo1Ol0000F
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0a
ooooo`00ZOooool00ol0003oooooooooo`0Dooooo`Ko00004_ooool5o`00017ooooo00Co0000oooo
oooooooooooo0_l0000Eooooo`;o00005?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo033ooooo002Yooooo`03o`000?oooooooooo01Gooooo1_l0000Booooo`04o`000?oooooooooo
ooooo`?o00005?ooool2o`0001Gooooo00?o0000ooooooooool04_ooool2o`0001Cooooo00?o0000
ooooooooool0;oooool00:Wooooo2?l0000Booooo`;o00000_ooool4o`0001Gooooo0_l0000Doooo
o`;o00005?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0;_ooool009kooooo1?l000000ol@413oooooooooo`04ooooo`03o`000?oooooo000000So
00004?ooool00ol0003oooooooooo`04ooooo`?o00005?ooool2o`0001Cooooo00?o0000oooooooo
ool04_ooool2o`0001Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`00
V?ooool4o`0000Cooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool3o`0000Co
oooo1ol0000Cooooo`?o00004oooool3o`0001;ooooo0_l0000Dooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0/ooooo`005oooool00ol0003ooooo
ooooo`0Aooooo`;o00004oooool2o`0001?ooooo0_l0000Booooo`;o00004_ooool3o`00017ooooo
9?l00006ooooo`?o00004oooool2o`0001Cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0[ooooo`005oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool2o`00017ooooo0ol0000Aooooo`?o00001oooool3o`0000?ooooo1ol0
0002ooooo`co000000?oooooo`000?ooool01oooool00ol0003oooooooooo`09ooooo`_o0000Z?oo
ool001Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`;o00004_ooool2
o`00017ooooo0_l0000:ooooo`;o00001Oooool3o`0000Oooooo2Ol00004ooooo`Go00001oooool2
o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`Co0000Y?ooool0
01Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03oooool2o`0000_ooooo0ol000000ooooooo0000o`000002o`00
00Sooooo2?l00002ooooo`Go00004_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Sooooo1?l0002Pooooo`005?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool2o`0000cooooo0_l000001?oooooo0000o`000?l0000;oooo
o`Ko00004Oooool5o`0001Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Loooo
o`Go0000Voooool001?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`;o
00004Oooool2o`0000gooooo1?l0000=ooooo`Oo00003oooool3o`0001Wooooo00?oEEEEofIVI_l0
00002?ooool00ol0003oooooooooo`0Qooooo`Co0000Foooool2o`0003[ooooo000Booooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`Co0000
3Oooool6o`0000cooooo2?l0000=ooooo`;o00009oooool00ol0003oooooooooo`0Uooooo`?o0000
@_ooool2o`0001Cooooo0ol0000iooooo`004Oooool00ol0003oooooooooo`0?ooooo`;o00003ooo
ool01?l0003oooooo`000?l0000?ooooo`?o00003_ooool7o`0001kooooo0ol0000Yooooo`03o`00
0?oooooooooo02Sooooo0ol0000oooooo`?o00005?ooool4o`0003Oooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooool000004Oooool2o`00013ooooo1Ol0000<ooooo`Co00007ooo
ool3o`0002cooooo00?o0000ooooooooool0:oooool2o`0002Oooooo0_l0000Eooooo`Co00004_oo
ool5o`0003Kooooo000<ooooo`;o000000?oooooo`000?ooool03oooool2o`00017ooooo0ol0000?
ooooo`Ko0000;?ooool3o`0002oooooo00?o0000ooooooooool0;Oooool3o`0000kooooo0_l0000D
ooooo`Co00005?ooool4o`0001;ooooo1Ol0000eooooo`003?ooool3o`00013ooooo1?l0000?oooo
o`Go00003Oooool3o`0002gooooo0ol0000booooo`03o`000?oooooooooo033ooooo0_l0000<oooo
o`Go00004_ooool5o`0001;ooooo1Ol0000Aooooo`?o0000=oooool000_ooooo1Ol0000>ooooo`Ko
00003Oooool4o`0003gooooo0_l0000eooooo`03o`000?oooooooooo03;ooooo0ol0000:ooooo`Ko
00004Oooool5o`0001;ooooo0ol0000Cooooo`03o`000?oooooo000003Kooooo000;ooooo`?o0000
4?ooool4o`0000kooooo0_l0000mooooo`?o0000=oooool00ol0003oooooooooo`0Xooooo`Go0000
2?ooool2o`0000Wooooo1_l0000Aooooo`Co00004oooool00ol0003oooooo`00000Eooooo`03o`00
0?oooooooooo03?ooooo000:ooooo`?o00004?ooool2o`0004gooooo0ol0000jooooo`03o`000?oo
oooooooo02[ooooo1_l00007ooooo`;o00002?ooool5o`0001;ooooo00Co0000oooooooooooo0000
5Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03;ooooo000:ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Boooool2o`0003gooooo00?o0000ooooooooool04_oo
ool5o`0001Cooooo1Ol00009ooooo`?o00001_ooool5o`0001Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03;ooooo0009ooooo`03o`000?oooooo
oooo05_ooooo0ol0000oooooo`;o00005Oooool6o`0001;ooooo1?l0000<ooooo`;o00001Oooool0
1Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo037ooooo001Uooooo`;o0000@_ooool00ol0003oooooooooo`0E
ooooo`Go00004oooool00ol0003oooooooooo`03o`0000_ooooo0_l00008ooooo`;o00005?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool0
06?ooooo0_l00014ooooo`So00004_ooool2o`000004ooooool0003o0000o`0001Kooooo0_l0000;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool2o`0001Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0_ooooo`00H_ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooo000000Ko00004_ooool00ol0003oooooooooo`02ooooo`?o00005Oooool2o`00
00[ooooo0_l00008ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo001Pooooo`;o0000=oooool3o`0000go
oooo00Co0000oooooooooooooooo0ol00002ooooo`Go00005Oooool3o`0001Cooooo0_l0000:oooo
o`;o00001oooool2o`0001Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02gooooo001Nooooo`;o0000=_ooool6o`0000gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`Go00004oooool3o`0001?ooooo0_l0000:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0;?ooool001Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Aooooo`;o00004oooool2o`0000Kooooo00?o0000ooooooooool0
2Oooool2o`0001;ooooo0ol0000AoooooaWo00004_ooool2o`0001Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`08ooooo`;o00001oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`005ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`00017ooooo0ol00007ooooo`?o00000ooo
ool7o`0000Kooooo1Ol0000=ooooo`03o`000?oooooooooo04Sooooo0_l0001booooo`005_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool2
o`0000Gooooo0_l0000:ooooo`;o00004?ooool3o`0000Oooooo2Ol0000@ooooo`;o00003Oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`;o00001_ooool00ol0
003oooooooooo`08ooooo`;o00002oooool2o`000003ooooool0003o000000;o00002?ooool8o`00
02;ooooo00?o0000ooooooooool0Boooool2o`0006oooooo000Dooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool2o`0001;ooooo00?o0000ooooooooool01?ooool2o`0000Wo
oooo0_l0000;ooooo`Go00004Oooool3o`0002;ooooo00?o0000ooooooooool0COooool2o`0003?o
oooo0_l0000hooooo`004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
2oooool7o`0003Kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Jooooo`;o0000
5?ooool3o`0003Oooooo000Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool0
1Oooool4o`0000cooooo2?l0000fooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
0oooool2o`0001Cooooo0ol0000Dooooo`?o0000=_ooool001;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo0ol00007ooooo`03o`000?oo
oooooooo00Gooooo1Ol0001:ooooo`03o`000?oooooooooo057ooooo0_l00003ooooo`?o00005?oo
ool3o`0001?ooooo1?l0000eooooo`004Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooool000003oooool4o`0000Kooooo00?o0000ooooooooool01Oooool7
o`0004Wooooo0_l00010ooooo`;o00004_ooool01?l0003oooooooooooooool3o`0001?ooooo1?l0
000Booooo`Go0000=?ooool000gooooo00Co0000oooooooooooo00004?ooool00ol0003oooooo`00
000Aooooo`;o00003oooool6o`0000Cooooo00?o0000ooooooooool01Oooool4o`0004gooooo00?o
0000ooooooooool0?oooool5o`00013ooooo0_l000000ooooooo0000o`000002o`0001?ooooo1?l0
000Booooo`;o0000=_ooool000gooooo0ol0000Aooooo`;o00004Oooool4o`0000gooooo1?l00006
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0:Oooool3o`0001Cooooo1_l0000@
ooooo`03o`000?oooooo000000?o00004_ooool3o`0001?ooooo00?o0000ooooool00000=Oooool0
00cooooo1?l0000@ooooo`Co00003oooool3o`0000kooooo0_l00007ooooo`;o0000F_ooool00ol0
003oooooooooo`0Zooooo`Go00004_ooool6o`00013ooooo1?l0000Dooooo`;o00005_ooool00ol0
003oooooooooo`0booooo`003?ooool5o`0000kooooo0ol0000@ooooo`;o00006?ooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo02_ooooo1_l0000Aooooo`Co00004_ooool2o`000003
ooooool0003ooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0booooo`00
2oooool4o`00013ooooo0_l0000@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`0Cooooo`Go00005?ooool5o`0001;ooooo00Co0000oooooooooooo
00004oooool00ol0003oooooo`00000Eooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0<Oooool000_ooooo0ol0000@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Eooooo`Ko00004_ooool4o`0001Kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooo`00000Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
<?ooool000_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool05_ooool5o`0001?ooooo00?o0000ooooooooool00_l0
000Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooool000005Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo033ooooo000:ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0G_ooool01?l0003oooooooooooooool4o`0001;ooooo1Ol0000Gooooo`;o00005?oo
ool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0_ooooo`00Aoooool00ol0003oooooooooo`1Oooooo`So00004ooo
ool01?l0003oooooooooooooool3o`0001Kooooo00?o0000ooooooooool04_ooool2o`00017ooooo
00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02ko
oooo0016ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000001_l0000Iooooo`;o0000
5Oooool2o`0001Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooool0000Dooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0;Oooool004Gooooo00?o0000ooooooooool0
DOooool3o`0000gooooo00Co0000oooooooooooooooo0ol00002ooooo`Go00005_ooool2o`0001Go
oooo0_l0000Cooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00005?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo0014ooooo`03o`000?oooooooooo04oo
oooo1_l0000=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool5o`0001?o
oooo0ol0000Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool01?l0003o
ooooooooool0000Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;?ooool001Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?oo
ool04?ooool2o`0001;ooooo0_l0000Cooooo`;o00004OoooolIo`0001;ooooo0_l0000Dooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[oooo
o`005oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00Co0000oooooooo
oooo00004Oooool00ol0003oooooooooo`0@ooooo`;o00004_ooool3o`0000Oooooo0_l00005oooo
o`Go00002?ooool3o`0000gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Goooo
o`005_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00Co0000oooooooo
oooo00004Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo0ol00007oooo
o`[o00007Oooool2o`0006Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0foooo
o`005Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00Co0000oooooooo
oooo00004?ooool2o`00017ooooo0_l0000:ooooo`;o00000oooool3o`0000Sooooo1ol0000Roooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01_ooool2o`0001Cooooo0_l0000goooo
o`005?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00Co0000oooooooo
oooo00004?ooool00ol0003oooooooooo`0?ooooo`;o00002oooool3o`000003ooooool0003o0000
00[ooooo2?l0000Rooooo`03o`000?oooooooooo05Oooooo0_l0000<ooooo`03o`000?oooooooooo
00Gooooo0ol0000Cooooo`?o0000=_ooool001Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo000000cooooo1Ol0000fooooo`03o`000?oooooooooo05Oooooo0ol0000<
ooooo`03o`000?oooooooooo00Gooooo0ol0000Cooooo`?o0000=Oooool001?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000oooooo0_l0000>
ooooo`04o`000?oooooo0000o`0000cooooo1ol0000eooooo`03o`000?oooooooooo047ooooo0_l0
000Eooooo`Co00002oooool00ol0003oooooooooo`04ooooo`Co00004_ooool4o`0003Cooooo000B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool0
000=ooooo`03o`000?oooooo000000oooooo0ol0000=ooooo`Co0000>Oooool00ol0003ooooooooo
o`11ooooo`Co00004oooool5o`0000_ooooo00?o0000ooooooooool01?ooool4o`00017ooooo1Ol0
000cooooo`004Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`0<ooooo`;o00003oooool5o`0004Wooooo00?o0000
ooooooooool0:_ooool2o`0001Kooooo1Ol0000Booooo`Go00002oooool00ol0003oooooooooo`03
ooooo`Go00004Oooool2o`0003Gooooo000Aooooo`03o`000?oooooooooo00kooooo00Co0000oooo
oooooooo00004?ooool2o`0000;ooooo00?o0000ooooooooool03?ooool3o`0000kooooo1?l0001;
ooooo`03o`000?oooooooooo02[ooooo1Ol0000Cooooo`Ko00004Oooool3o`0000kooooo00?o0000
ooooooooool00_ooool3o`0001?ooooo00?o0000ooooool00000=?ooool000kooooo0ol0000Aoooo
o`?o00004?ooool3o`000003ooooool0003ooooo00gooooo1Ol0000<ooooo`;o0000C_ooool00ol0
003oooooooooo`0[ooooo`Ko00004_ooool4o`0001?ooooo0_l0000>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000005Oooool00ol0003oooooooooo`0aooooo`003_ooool3o`00013o
oooo1?l0000?ooooo`Ko00003Oooool4o`0005kooooo00?o0000ooooooooool04oooool3o`0001Ko
oooo1_l0000Aooooo`Co00005Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0aooooo`003Oooool5o`0000oooooo
0ol0000@ooooo`?o000000?oooooo`000?ooool03?ooool2o`00067ooooo00?o0000ooooooooool0
5Oooool4o`0001Cooooo1?l0000Cooooo`04o`000?ooooooooooo`0001Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0<?ooool000gooooo0ol0000@ooooo`?o00004?ooool2o`0000;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Kooooo1Ol0000Cooooo`03o`00
0?oooooooooo00;o00005Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo
000<ooooo`?o00004Oooool2o`00013ooooo00Go0000ooooooooooooooooo`00001booooo`03o`00
0?oooooooooo01Oooooo1?l0000Hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0_ooooo`003?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0L?ooool8o`0001?ooooo0_l000001?oooooo0000o`00
0?l0000Fooooo`;o00005?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02kooooo
000;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1aooooo`So00005?ooool00ol0003oooooooooo`02ooooo`;o00005_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;_ooool003Cooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`08o`0001Sooooo0_l0000Eooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`00=?ooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`Co00005_ooool2o`00
01Cooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool003?o
oooo00?o0000ooooooooool0H_ooool4o`0000gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`Co00005?ooool2o`0001Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02cooooo000Gooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04?ooool2o`0001?ooooo0_l0000BoooooaSo00004_ooool2o`0001Cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0:oooool001Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo017ooooo0_l0000@ooooo`Co00001Oooool5o`0000gooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`16ooooo`005_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool2o`0000Wooooo0_l00003
ooooo`Co00003?ooool2o`0000gooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03?ooooo000Fooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo1ol0000Ooooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<oooool001Gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0?ooooo`;o00004Oooool2o`0000Sooooo1ol0000Qooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo0_l0000dooooo`005?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02o`0000Wooooo
2?l0000Qooooo`03o`000?oooooooooo04?ooooo0_l0000Eooooo`;o00005?ooool2o`0000Cooooo
00?o0000ooooooooool03Oooool3o`0003?ooooo000Dooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`Co0000=?ooool00ol0003ooooooooo
o`0/ooooo`;o00005Oooool3o`0001Gooooo0_l0000Cooooo`?o00001?ooool00ol0003ooooooooo
o`0=ooooo`;o0000<oooool001?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<
ooooo`04o`000?ooooooooooo`0000kooooo1?l0000eooooo`03o`000?oooooooooo02cooooo0ol0
000Eooooo`?o00005?ooool3o`0001?ooooo0ol00004ooooo`03o`000?oooooooooo00cooooo0ol0
000booooo`004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooool000003_ooool5o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo00?o0000ooooooooool0;Oooool4o`0001?ooooo
1?l0000Cooooo`Co00004_ooool4o`0000?ooooo00?o0000ooooooooool03?ooool4o`00037ooooo
000Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000ooooo`0>ooooo`?o00003_oo
ool4o`0001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`05ooooo`03o`000?oooooooooo02kooooo1?l0000Cooooo`Co00004oooool2o`0001?ooooo
0ol00005ooooo`03o`000?oooooooooo00_ooooo0ol0000booooo`004_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool0000?ooooo`?o00003oooool5o`0000cooooo0_l0000Fooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`?o
00005_ooool5o`0001;ooooo0ol0000Dooooo`03o`000?oooooo000001Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo000Aooooo`03o`00
0?oooooooooo00oooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00Wooooo
0ol0000?ooooo`Go00003_ooool3o`0002kooooo00Go0000ooooooooooooooooo`00000<oooooaOo
00003?ooool6o`0001Cooooo0ol0000Dooooo`;o00005_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0_ooooo`00
3oooool3o`00017ooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo1?l0000?ooooo`?o0000
3oooool2o`00033ooooo00Go0000ooooooooooooooooo`000007ooooo`Ko000000Co8B4Qo`000?lb
<S;oc<c<1_ooool00ol0003oooooooooo`09ooooo`Go00002?ooool6o`0001Cooooo00?o0000oooo
ool000005Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo000?ooooo`Co
00004?ooool4o`0000?ooooo00?o0000ooooooooool02Oooool3o`0000oooooo0ol0000?ooooo`03
o`000?oooooooooo033ooooo00Go410@oooooooooooooooooa0@4002ooooo`Go00001Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo1Ol00004ooooo`Go00005oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;oooool000ko
oooo1?l0000@ooooo`Co00001?ooool00ol0003oooooooooo`08ooooo`?o00004?ooool00ol0003o
ooooooooo`12ooooo`04ogMgMonHV9SooooooiRHV0?o00002_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01?ooooo0ol00002ooooo`Go00005oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool000kooooo0ol0000Aooooo`?o
00001?ooool00ol0003oooooooooo`09ooooo`;o00004?ooool00ol0003oooooooooo`13ooooo`05
onk^k_lb<S;o0000o`000?o^k^h03?ooool4o`0000Oooooo2?l0000Aooooo`;o000000?oooooo`00
0?ooool00_ooool2o`0001Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02kooooo000>ooooo`;o00004_ooool2o`0000Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1Eooooo`;o00006_ooool00ol0003oooooooooo`05o`0001?o
oooo0_l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02gooooo000=ooooo`;o00004_ooool2o`0000Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Cooooo`?o00007?ooool00ol0003ooooo
ooooo`02ooooo`Go00004oooool2o`0000Cooooo0_l0000Eooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0]ooooo`003Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool2o`0001oooooo00?o
0000ooooooooool00oooool01?l0003oooooooooooooool3o`0001;ooooo0_l00004ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02cooooo000Wooooo`03o`000?oooooooooo05cooooo0_l0000Aooooo`?o00003Ooo
ool00ol0003oooooooooo`0:ooooo`?o00004Oooool2o`0000?ooooo0_l0000Dooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0/ooooo`009_ooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo00kooooo1_l0000=ooooo`03o`000?oooooo
oooo00gooooo0ol0000@ooooo`;o00000oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0/ooooo`005oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool2o`00
00?ooooo0_l0000>oooooaOo00004_ooool2o`00013ooooo00Go0000ooooooooooooooooo`00000D
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[
ooooo`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooooooool2o`0000gooooo0ol00004ooooo`Go00003Oooool0
0ol0003oooooooooo`0Sooooo`;o0000COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`03o`000?oooooooooo
00[ooooo0ol0000:ooooo`;o00003Oooool00ol0003oooooooooo`0Uooooo`;o00007oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo000Fooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
o`;o00001Oooool2o`0000?ooooo0ol0000Looooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo0_l0000=oooo
o`03o`000?oooooooooo00Cooooo0_l0000booooo`005_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo0000
00Kooooo1_l0000Oooooo`;o0000:Oooool00ol0003oooooooooo`04ooooo`;o00005Oooool2o`00
01Gooooo0_l0000Cooooo`?o00003?ooool00ol0003oooooooooo`04ooooo`;o0000<_ooool001Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo0_l00003ooooo`03o`000?oooooooooo00?ooooo1_l0000Qooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool00oooool3o`0001Gooooo0_l0000Dooooo`?o00004oooool2o`0000go
oooo00?o0000ooooooooool00oooool3o`00037ooooo000Eooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool7o`00027ooooo00?o0000ooooooooool05oooool2o`00017ooooo
00?o0000ooooooooool00oooool3o`0001Cooooo0ol0000Cooooo`Co00004_ooool3o`0000cooooo
00?o0000ooooooooool00oooool3o`00037ooooo000Dooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo0000o`0000Cooooo
00?o0000ooooooooool00oooool4o`0002Gooooo00?o0000ooooooooool05oooool3o`00017ooooo
00?o0000ooooooooool00_ooool4o`0001?ooooo1?l0000Booooo`Go00004Oooool4o`0000cooooo
00?o0000ooooooooool00_ooool4o`00033ooooo000Dooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`;o00001Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Sooooo1?l0000@ooooo`;o00000oooool4o`0001?ooooo1?l0
000Aooooo`?o00004oooool2o`0000kooooo00?o0000ooooooooool00_ooool3o`00037ooooo000C
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool2o`000003ooooool0003o
oooo00gooooo1?l00003ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool4
o`00017ooooo00?o0000ooooooooool00ol0000Dooooo`;o00005Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_
ooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`0000oooooo0ol0000>
ooooo`?o00001?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Wooooo1Ol0000A
ooooo`03o`000?oooooooooo00;o00005_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02kooooo000Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0>ooooo`;o000000?oooooo`000?ooool03oooool3o`0000oooooo1Ol0000<oooo
o`;o00001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01[ooooo0ol0000Coooo
o`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02kooooo000@ooooo`?o00003_ooool00ol0003oooooooooo`04o`00013ooooo0ol0000@oooo
o`Co00003oooool3o`0000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooo000000?o00006?ooool00ol0003oooooo`00000Cooooo`04o`000?oooooooooo
o`0001Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`004?ooool3o`00
00gooooo00Co0000oooooooooooooooo1?l0000@ooooo`Co00003oooool3o`0000oooooo0ol0000D
ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooooooo1Ol0000Hooooo`03o`000?oo
oooooooo017ooooo00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02kooooo000@ooooo`Co00003?ooool01?l0003oooooooooooooool4o`0000oooooo
1?l0000?ooooo`?o00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool00_ooool4o`0001Wooooo00?o0000ooooooooool04Oooool01?l0003ooooo
ooooool0000Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool0013ooooo
1?l0000<ooooo`04o`000?ooooooooooooooo`?o00004?ooool3o`00013ooooo0_l0000@ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`03ooooo`Co
00006Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000001Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0]ooooo`003oooool4o`0000cooooo00Co0000oooooooooooo
oooo0ol0000Aooooo`;o00004Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02o`0001Sooooo00?o0000oooooooo
ool04?ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;Oooool000oooooo0ol0000=ooooo`04o`000?ooooooooooooooo`?o00004?ooool2o`00
017ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Wooooo0_l0000Gooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo000?ooooo`;o00003_ooool01?l0
003oooooooooooooool2o`00017ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00_ooooo0_l0000Fooooo`03o`000?oooooooooo013ooooo00Co0000
oooooooooooo00004oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02cooooo000?
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo02Oooooo0ol0000=ooooo`;o00003_ooool2o`0001Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0;?ooool001kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Uoooo
o`Ko00003Oooool00ol0003oooooooooo`0?ooooo`;o00005?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[
ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`;o00004ooooolGo`0001?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000004Oooool01?l0003ooooo
ooooool0000>ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0:oooool001Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00
00oooooo00?o0000ooooooooool04Oooool2o`0000Cooooo1Ol0000=ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
o`00033ooooo000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool01?l0
003oooooooooool0000?ooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`;o00003Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0>ooooo`;o00005?ooool2o`0001Cooooo0_l0000@ooooo`03o`000?oooooo
oooo00;o0000;oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@oooo
o`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0?ooooo`;o00006_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oooooo
oooo00gooooo0_l0000Dooooo`;o00005?ooool2o`00017ooooo00Co0000ooooool0003o0000;ooo
ool001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo
ooooo`0000kooooo00?o0000ooooooooool03Oooool3o`0001cooooo00?o0000ooooooooool07Ooo
ool2o`0001Gooooo0ol00004ooooo`03o`000?oooooooooo00cooooo0ol0000Cooooo`?o00004_oo
ool3o`00017ooooo1?l0000_ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0:ooooo`Co00007ooo
ool00ol0003oooooooooo`0Mooooo`?o00005Oooool2o`0000Cooooo00?o0000ooooooooool03?oo
ool4o`0001;ooooo0ol0000Booooo`Co00004?ooool5o`0002kooooo000Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool02_ooool3o`00027ooooo00?o0000ooooooooool00oooool2o`0001Wooooo0ol0
000Dooooo`?o00001?ooool00ol0003oooooooooo`0;ooooo`Co00004_ooool3o`0001;ooooo1?l0
000Aooooo`Co0000;_ooool001Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool02Oooool6o`00023ooooo00?o
0000ooooooooool00oooool3o`0001Sooooo1?l0000Cooooo`Co00000oooool00ol0003ooooooooo
o`0;ooooo`Go00004Oooool4o`00017ooooo0ol0000Booooo`?o0000;oooool001Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000003?oo
ool00ol0003oooooooooo`09ooooo`Oo00008?ooool00ol0003oooooooooo`04ooooo`Co00005_oo
ool3o`0001Cooooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000;ooo
ool001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`05o`000?oooooo
ooooooooool000002oooool2o`0000_ooooo1?l0000Tooooo`03o`000?oooooooooo00Cooooo1Ol0
000Eooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooo000002oooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04?ooool01?l0003oooooooooool0000<ooooo`;o0000<oooool00ol0003ooooooooo
o`05ooooo`Go00005oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooo`00000_ooooo`005?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00kooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo1?l0000b
ooooo`03o`000?oooooooooo00Gooooo0ol0000Iooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000002kooooo000Doooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>oooo
o`?o00004Oooool3o`00013ooooo1?l000000ooooooo0000ooooo`0:ooooo`?o0000=?ooool2o`00
00Oooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00000^ooooo`004_ooool3o`0000Go
oooo00?o0000ooooooooool02Oooool3o`00017ooooo0ol0000Aooooo`Co00003_ooool4o`0000;o
oooo00?o0000ooooooooool02?ooool2o`0003Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooo000002kooooo000Booooo`Co00001?ooool00ol0003ooooo
ooooo`09ooooo`Co00004?ooool4o`0000oooooo1?l0000?ooooo`?o00000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooo000002kooooo000Booooo`Co00001?ooool00ol0003ooooooooo
o`09ooooo`Co00004?ooool4o`0000oooooo0ol0000@ooooo`;o00000oooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00
000^ooooo`004_ooool3o`0000Gooooo00?o0000ooooooooool02Oooool3o`00013ooooo1?l0000@
ooooo`;o00004?ooool2o`0000Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo017ooooo0_l0000^ooooo`004_ooool3o`0000Gooooo00?o0000oooo
ooooool02Oooool3o`00013ooooo0ol0000@ooooo`;o00004Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aoooo
o`;o0000;_ooool001;ooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo0_l0000Aooooo`;o
00004Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000002gooooo000Booooo`;o0000
1Oooool00ol0003oooooooooo`0:ooooo`;o00004Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo03;ooooo0ol0000=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooo`00000]ooooo`004_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0`ooooo`Ko00003Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000;Ooo
ool001Oooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04OoooolGo`0001?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooo`00000]ooooo`005oooool00ol0003oooooo`00000Booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo0ol0000=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool2o`00
02gooooo000Gooooo`;o00004oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017o
oooo0_l0000Booooo`?o00004_ooool2o`0000Oooooo00?o0000ooooooooool02Oooool2o`0001?o
oooo0_l0000Booooo`?o00004_ooool2o`0002gooooo000Gooooo`;o00004oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo017ooooo0_l0000Booooo`?o00004_ooool2o`0000Oooooo
00?o0000ooooooooool02Oooool2o`0001?ooooo0_l0000Booooo`?o00004_ooool2o`0002gooooo
000Fooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0@ooooo`?o00004_ooool3o`0001;ooooo0ol00007ooooo`03o`000?oooooooooo00Oooooo0ol0
000Booooo`?o00004_ooool3o`0001;ooooo0ol0000/ooooo`005_ooool00ol0003oooooo`00000B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool4o`00013ooooo1Ol0000@
ooooo`Co00001oooool00ol0003oooooooooo`07ooooo`Co00004Oooool4o`00013ooooo1Ol0000@
ooooo`Co0000;?ooool001Kooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Ioooo
o`;o00004Oooool4o`00013ooooo1Ol0000@ooooo`Co00001oooool00ol0003oooooooooo`07oooo
o`Co00004Oooool4o`00013ooooo1Ol0000@ooooo`Co0000;?ooool001Kooooo00?o0000ooooool0
00001?l000000ol@413oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01?l0
003oooooob4Q8OlQ8B43ooooo`03o`000?ooooooA4A400;o000000?o<S8bomgMgOooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00Gok^k^o`000?l0003o<S8bonk^
kP05ooooo`03o`000?lQ8B7ooooo00Cooooo00GoA4A4o`000?l0003o<S8bo`00000Dooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04?ooool4o`000003oa0@4?oooooooooo02Wooooo
000Fooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o8B4Q0oooool00ol0003oooooooooo`02ooooo`03
ogMgMolb<S;ooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000Mooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`05
ogMgMol0003ooooooiRHV?mgMgL01Oooool00ol0003o8B4Qooooo`07ooooo`03ogMgMol0003ooooo
01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`;o0000;Oooool0013o
oooo1ol000001Ooooooo0000oooooooooooo000000oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0?ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool2o`0001kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo017ooooo00Go410@o`000?oooooooooooa0@4005ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo017ooooo0_l0000]ooooo`005_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00omgMgOo<S8booooo`0:ooooo`03o`000?oooooooooo00_ooooo0ol0
000Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
MgMgo`000?ooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo0_l0
000]ooooo`005Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00So0000oooooooooooo
0000ob4Q8Ol0003o<S8bolc<c0Sooooo0_l000000ooooooo0000ooooo`0;ooooo`Go00007Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool2
o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_l000005?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo0_l0
000]ooooo`005Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00Go
410@oooooooooooooooooa0@4002ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003o
ooooooooo`0:ooooo`?o00003Oooool3o`0001oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo00Go410@o`000?oooooooooooa0@4006oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`005?ooool3o`00
0005ooooool0003oooooooooool000003?ooool3o`00017ooooo0ol0000Booooo`?o00001Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00Co0000oooooooooooooooo1?l00002ooooo`03o`00
0?oooooooooo00[ooooo1?l0000;ooooo`;o00008Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool01OmgMgOo0000oooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo000Dooooo`Go
000000?oEEEEofIVI_l000003?ooool4o`00013ooooo1Ol0000@ooooo`Co00001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002Oooool4
o`0000[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool01Oo^k^ko0000o`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool00oooool5o`0001Cooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0@ooooo`03oeEEEOmVIVKo000002gooooo000Dooooo`Co00004?ooool4o`00013ooooo1Ol0000@
ooooo`Co00002oooool01?l0003oooooooooooooool3o`0000oooooo1?l0000_ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`005?ooool4
o`00013ooooo0ol0000Aooooo`Co00004Oooool3o`0000cooooo00Co0000oooooooooooooooo0ol0
000?ooooo`?o0000<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:oooool001Cooooo1?l0000Aooooo`;o00004_ooool3o`00017ooooo0ol0000<
ooooo`04o`000?ooooooooooooooo`;o00004?ooool2o`00037ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo000Dooooo`;o000000?ooooo
o`000?ooool04?ooool2o`0001;ooooo0_l0000Booooo`;o00003Oooool01?l0003ooooooooooooo
ool2o`00013ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool07oooool2o`0000;ooooo0_l00006ooooo`005?ooool2
o`000003ooooool0003ooooo013ooooo00?o0000ooooooooool04Oooool2o`0001;ooooo0_l0000=
ooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool07oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Ko
oooo00000ooooooo0000o`00003oo`0004oo00003?ooool01?oMgMgo0000oa0@4?o<c<`7ooooo`00
2Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000
3Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooool000003?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000>oooo
o`;o00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool0000>ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool04_ooool01?o^k^ko8B4Qoa0@4?o^k^h7ooooo`002Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000003Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000ko
oooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`0Booooo`04ob4Q8OmgMgOoMgMgoc8b<POooooo000Gooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00kooooo0_l00003ooooo`03o`000?oooooooooo00cooooo0_l0000Aooooo`;o00004_ooool2
o`00017ooooo00Co0000ooooool0003o00007_ooool2o`0000;ooooo0_l00006ooooo`005oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;_ooool2
o`00013ooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo0ol0000Aooooo`;o00004_ooool2
o`00017ooooo00Co0000ooooool0003o0000:_ooool001Oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo0ol0000?ooooo`?o00000oooool0
0ol0003oooooooooo`0;ooooo`;o00004Oooool4o`00017ooooo0ol0000@ooooo`Co0000:_ooool0
01Oooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07oooool2o`00
00cooooo0_l0000@ooooo`?o00000oooool00ol0003oooooooooo`0:ooooo`?o00004Oooool4o`00
013ooooo1?l0000@ooooo`Co0000:_ooool001Oooooo0_l0000Cooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool07_ooool3o`0000_ooooo0ol0000?ooooo`Co00000oooool00ol0003o
ooooooooo`09ooooo`Co00004?ooool5o`00013ooooo1?l0000@ooooo`Co0000:_ooool001Oooooo
0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool4o`0000_ooooo
1?l0000@ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02oooool2o`0001;ooooo
0ol0000Aooooo`03o`000?oooooo0000013ooooo00?o0000ooooool00000:oooool001Oooooo0_l0
000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool4o`0000gooooo00?o
0000ooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooo0000:oooool001Oooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool06_ooool5o`0000cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000:oooool001Oooooo0_l0
000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool3o`0000gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooo0000:oooool001Oooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000002cooooo000G
ooooo`;o00004oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04?ooool00ol0003oooooo`00000/ooooo`005_ooool4o`00013ooooo1Ol0000@oooo
o`Go00004?ooool4o`0000Wooooo00?o0000ooooooooool01Oooool4o`00013ooooo1Ol0000@oooo
o`Co00004oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000oooo
ool00000;?ooool001Kooooo1?l0000@ooooo`Go00004?ooool5o`00013ooooo1?l00009ooooo`03
o`000?oooooooooo00Gooooo1?l0000@ooooo`Go00004?ooool4o`0001?ooooo0_l0000Hooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo013ooooo00?o0000ooooool00000;?ooool001Kooooo1?l0000@ooooo`Go0000
4?ooool5o`00013ooooo1?l00009ooooo`03o`000?oooooooooo00Gooooo1?l0000@ooooo`Go0000
4?ooool4o`0001?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooo000002cooooo000Fooooo`?o00004_ooool3o`0001;ooooo0ol0000Booooo`?o00002Ooo
ool00ol0003oooooooooo`05ooooo`?o00004_ooool3o`0001;ooooo0ol0000Cooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00000/ooooo`005oooool3
o`00017ooooo0ol0000Booooo`?o00004_ooool2o`0000_ooooo00?o0000ooooooooool01Oooool2
o`0001;ooooo0ol0000Booooo`;o00005?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooool00000;?ooool001Oooooo0ol0000Aooooo`?o00004_ooool3o`00
01;ooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo0_l0000Booooo`?o00004_ooool2o`00
01Cooooo00?o0000ooooooooool02oooool3o`0000Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool2o`00
02gooooo000Gooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0;ooooo`Ko000000?oooooo`000?ooool04oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool2o`0002gooooo000Gooooo`03o`00
0?oooooo000001;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_oooolEo`0001Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000
;Oooool001Oooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00_ooooo1Ol0000booooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo000Gooooo`03o`000?oooooo
000001;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`;o0000=?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool0
01Oooooo00?o0000ooooool000004oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool05?ooool2o`0001;ooooo00?o0000ooooooooool04?ooool2o`00
00_ooooo00?o0000ooooooooool00oooool2o`0002Sooooo000Hooooo`03o`000?oooooo000001;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`11ooooo`04o`000?oooooooooooooo
o`;o00004?ooool3o`00017ooooo0_l0000Aooooo`?o00002oooool00ol0003oooooooooo`03oooo
o`;o0000:?ooool001Sooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo043ooooo00Co0000oooooooooooooooo0ol0000?ooooo`?o00004Oooool3o`00
017ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo0ol0000Xooooo`006?ooool00ol0003o
ooooo`00000Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=?ooool2o`0000[o
oooo00?o0000ooooooooool00ol0000?ooooo`Co00004?ooool3o`00017ooooo0ol0000;ooooo`03
o`000?oooooooooo00?ooooo0ol0000Xooooo`006?ooool00ol0003oooooo`00000Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0<oooool3o`0000[ooooo00?o0000ooooool00000
0ol0000>ooooo`Go00003oooool4o`00013ooooo1?l0000;ooooo`03o`000?oooooooooo00;ooooo
1?l0000Xooooo`006?ooool00ol0003oooooo`00000Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo0_l0
000booooo`Co00002oooool6o`00013ooooo0_l0000Booooo`;o00004_ooool2o`0000_ooooo00?o
0000ooooooooool00oooool00ol0003oooooo`00000Xooooo`006?ooool00ol0003oooooo`00000C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0F
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0<?ooool4o`0000_ooooo00Co
0000oooooooooooooooo0_l0000Aooooo`;o00004Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`006?oo
ool00ol0003oooooo`00000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Fooooo`?o00002Oooool00ol0003oooooooooo`0_ooooo`Go00002ooo
ool01_l0003oooooooooool0003oooooo`00013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Xooooo`006Oooool00ol0003oooooo`00000Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`Co00002?ooool00ol0003ooooo
ooooo`0`ooooo`?o00002oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Xooooo`006Oooool00ol0003oooooo`00000Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04oooool01?l0003oooooo`000?l0000Gooooo`;o
00002?ooool00ol0003oooooooooo`0Qooooo`Co00002_ooool00ol0003oooooo`00000;ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Wooooo000Iooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool04_ooool2o`0001?o
oooo0ol0000<ooooo`03o`000?oooooooooo00?ooooo0ol0000Cooooo`Co00006?ooool2o`0000Oo
oooo00?o0000ooooooooool07Oooool6o`0000_ooooo00?o0000ooooooooool03?ooool01?l0003o
ooooooooool0000Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool001So
oooo1?l0000Aooooo`Co00004Oooool4o`00017ooooo1Ol0000<ooooo`03o`000?oooooooooo00;o
oooo1?l0000Cooooo`Co00006Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01go
oooo1Ol0000;ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool001Sooooo1Ol0000@ooooo`Co
00004Oooool4o`00017ooooo1Ol0000=ooooo`04o`000?ooooooooooooooo`Co00005?ooool3o`00
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`Co00002oooool00ol0
003oooooooooo`0=ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Yooooo`006?ooool5o`00017ooooo0ol0000Booooo`?o00004_ooool4o`00
00kooooo00Co0000oooooooooooooooo0ol0000Eooooo`?o00008?ooool00ol0003oooooooooo`0J
ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_oo
ool001Wooooo1?l0000Aooooo`?o00004_ooool3o`0001?ooooo0ol0000>ooooo`03o`000?oooooo
oooo00;ooooo0ol0000Dooooo`?o00008?ooool00ol0003oooooooooo`0Hooooo`;o00004?ooool0
0ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Zooooo`006Oooool2o`0000;ooooo00?o0000ooooooooool03oooool2
o`0001?ooooo0_l0000Cooooo`?o00003oooool01?l0003oooooooooooooool3o`0001Gooooo0_l0
000Pooooo`03o`000?oooooooooo01Kooooo0_l0000Aooooo`03o`000?oooooooooo00kooooo00Co
0000oooooooooooo00004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo
000Iooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`;o00004oooool2o`0001Cooooo0_l0
000?ooooo`03o`000?oooooooooo00;ooooo0_l0000Fooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02oooool3o`0000Kooooo0_l0000Booooo`03o`000?oooooooooo00kooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
:_ooool001[ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool02oooool6o`000003ooooool0003o000001?ooooo
00?o0000ooooooooool03oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:oooool001Oooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooo000001;ooooo0_l0000Cooooo`;o00004ooooolEo`0001Co
oooo00?o0000ooooooooool03oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:oooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool04_ooool2o`00
017ooooo00?o0000ooooooooool02oooool3o`0002[ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo000Gooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo
01?ooooo0_l0000?ooooo`;o0000>?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`006?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo00004oooool00ol0
003oooooooooo`0Dooooo`;o00003Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00_ooooo0_l0000Uooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017o
oooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0Eooooo`;o00002oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo02?ooooo0_l0000Aooooo`;o00004Oooool2o`00
00?ooooo00?o0000ooooooooool02oooool3o`0002Gooooo000Hooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo
01Kooooo0_l000000ooooooo0000o`000006ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool08oooool3o`00013ooooo0_l0000Aooooo`?o00000oooool00ol0003oooooooooo`0;oooo
o`;o00009_ooool001Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`04
o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool05oooool4o`0000Gooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Booooo`;o00003oooool3o`00013ooooo0ol0000@oooo
o`?o00001?ooool00ol0003oooooooooo`0:ooooo`?o00009_ooool001Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;o00004oooool00ol0003o
ooooooooo`0Fooooo`Go00001?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017o
oooo1?l0000>ooooo`Co00003oooool4o`0000oooooo1?l00003ooooo`03o`000?oooooooooo00[o
oooo1?l0000Vooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo
1_l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04?ooool5o`0000kooooo
1?l0000?ooooo`Co00004Oooool3o`0000?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
o`00000Vooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`;o00006Oooool3o`0000;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`03ooooo`;o00002oooool6o`0000oooooo0ol0
000Aooooo`;o00004Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool09_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool2o`0001kooooo00?o0000
ooooooooool0;_ooool2o`0000?ooooo1Ol0000<ooooo`Co00004?ooool2o`00017ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`?o00000oooool00ol0003oooooooooo`0>ooooo`Co00007Oooool00ol0003oooooooooo`0]oooo
o`04o`000?ooooooooooooooo`Ko00003_ooool3o`0000oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Wooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04oooool3o`0001?ooooo0_l0000Cooooo`?o00001?ooool00ol0
003oooooooooo`0?ooooo`?o00007?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00;ooooo1Ol0000>ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Wooooo`006oooool3o`0000Cooooo00?o0000ooooooooool03?ooool2o`0001;o
oooo1?l0000Aooooo`Co00005?ooool3o`0000Cooooo00?o0000ooooooooool04?ooool2o`0001_o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`Co00003_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool001[ooooo
1?l00004ooooo`03o`000?oooooooooo00[ooooo1?l0000Booooo`Co00004_ooool4o`0001Cooooo
0_l00005ooooo`;o00004_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo
1?l00004ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo
000Jooooo`Co00001Oooool00ol0003oooooooooo`09ooooo`Co00004oooool3o`0001?ooooo0ol0
000Eooooo`;o00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01kooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool001_ooooo0ol00005
ooooo`03o`000?oooooooooo00[ooooo0ol0000Dooooo`?o00004oooool2o`0001Kooooo00?o0000
ooooooooool01Oooool2o`0002[ooooo0_l0000Oooooo`Go00001?ooool2o`0000?ooooo0_l0000B
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Y
ooooo`006oooool3o`0000Kooooo00?o0000ooooooooool02_ooool3o`0001?ooooo0ol0000Doooo
o`;o00005_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool06oooool3o`000003ooooool0003o000000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Yooooo`007?ooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`0001Co
oooo0_l0000Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Hooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0:_ooool001cooooo0_l00006ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0eooooo`;o00009_ooool00ol0003ooooo
ooooo`0;ooooo`?o00001oooool3o`0000_ooooo0_l00003ooooo`;o00004oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool001gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`;o00009?ooool00ol0003ooooooooo
o`0;ooooo`Ko000000Coooooo`000?l0003o00003Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02[ooooo000Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Ooo
ool2o`0001?ooooo0_l00004ooooo`;o00003Oooool3o`0001;ooooo5Ol0000?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0:oooool001Oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0=ooooo`?o00003oooool00ol0003oooooooooo`0;ooooo`?o00004Oooool2
o`0005kooooo00?o0000ooooooooool0>_ooool001Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`;o00004?ooool3o`00
00Gooooo0_l00005ooooo`03o`000?oooooooooo01cooooo0ol0001Oooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool08Oooool001Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool2o`00017o
oooo0ol00002ooooo`?o00001?ooool00ol0003oooooooooo`0Jooooo`;o0000H_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo013ooooo0_l0000Sooooo`006Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool2o`0000Gooooo
0_l0000Booooo`Ko00000oooool00ol0003oooooooooo`0Hooooo`;o0000E_ooool2o`0000cooooo
00?o0000ooooooooool00_ooool2o`00017ooooo0ol0000Sooooo`006Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool2o`0000Gooooo0_l0
000Aooooo`Ko00000_ooool00ol0003oooooooooo`0Fooooo`;o0000Eoooool3o`0000_ooooo00?o
0000ooooooooool00_ooool3o`00013ooooo0ol0000Tooooo`006_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0
0003ooooo`?o00003_ooool7o`000003ooooool0003ooooo01Cooooo0ol00017ooooo`;o00003ooo
ool3o`0000cooooo00Co0000oooooooooooooooo0ol0000@ooooo`Co00009?ooool001[ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo0ol0
00001_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`Co00000_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01_ooool00ol0003oooooooooo`0@ooooo`?o0000B?ooool4o`0000kooooo1?l0000;oooo
o`04o`000?ooooooooooooooo`Co00003oooool5o`0002Cooooo000Kooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000Eooooo`?o000000CoV9RHoooo
oonHV9SoMgMg1Oooool5o`0000Gooooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0:
ooooo`Ko0000>_ooool2o`0000gooooo1Ol0000>ooooo`Co00003?ooool00ol0003oooooooooo`05
o`00017ooooo0_l0000Uooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Gooooo0_l0000Dooooo`Go00000_ooool00ol@413oooooooooo`08ooooo`So00001Oooool00ol0
003oooooooooo`05ooooo`Go0000?Oooool5o`0000cooooo1_l0000?ooooo`?o00002oooool00ol0
003oooooooooo`02ooooo`?o00004Oooool00ol0003oooooo`00000Uooooo`007?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooo000001Cooooo0ol0000Fooooo`?o000000?oooooo`000?oo
ool03_ooool00omgMgOo<S8booooo`0=o`00043ooooo1_l0000>ooooo`Co00004?ooool2o`0000co
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo02Go
oooo000Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
o`000?l0000Cooooo`;o00005?ooool2o`0001?ooooo1Ol0000Eooooo`03o`000?oooooooooo00;o
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0=_ooool4o`00
00_ooooo1Ol0000>ooooo`03o`000?oooooo000000;o00003oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Voooo
o`007?ooool3o`0000gooooo00?o0000ooooooooool00oooool3o`0001;ooooo0ol0000Cooooo`Co
00005?ooool3o`0001Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0<_ooool6o`0000gooooo1?l0000>ooooo`05o`000?oooooooooo
ooooool000003oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000005?oo
ool00ol0003oooooooooo`0Vooooo`006oooool4o`0000kooooo00Co0000oooooooooooooooo1?l0
000Cooooo`?o00005?ooool2o`0001Kooooo0_l0000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo1Ol0000=ooooo`04o`00
0?ooooooooooo`0000kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Wooooo`00
6oooool4o`0000kooooo00Co0000oooooooooooooooo1?l0000Dooooo`;o00005Oooool2o`0001Oo
oooo00?o0000ooooooooool04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00007oooo
o`03o`000?oooooooooo03;ooooo0ol0000=ooooo`;o00004Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02Oooooo000Looooo`Co00003_ooool01?l0003oooooooooooooool4o`00
01Cooooo0_l0000Eooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07_ooool8o`00
00Wooooo0ol000000ooooooo0000ooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Xooooo`007Oooool3o`0000oooooo00Co0000oooooooo
oooooooo0ol0000Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0Nooooo`Ko00002Oooool2o`00017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02Wooooo000Nooooo`;o00003oooool00ol0003o
ooooooooo`02ooooo`;o00005_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01_o
oooo1ol00009ooooo`;o00004Oooool2o`0001;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Yooooo`007oooool2o`0000oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo01Oooooo1?l00004ooooo`03o`000?oooooooooo00Oooooo
0_l0000Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Zooooo`008?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool02oooool4o`0000Cooooo1?l0000@ooooo`;o00004oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:_ooool001Oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`;o00004oooool2o`0001?ooooo0ol0000B
oooooaKo00004oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`005oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool2o`0001Cooooo1?l0000>oooo
o`03o`000?oooooooooo00_ooooo1Ol0001Sooooo`03o`000?oooooooooo04Kooooo000Hooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`;o
00005_ooool4o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00_ooooo0_l0001Uooooo`03
o`000?oooooooooo04Oooooo000Iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4oooool2o`0001Gooooo0_l0000Hooooo`Oo00000oooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo04Oooooo000Iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Dooooo`;o00006?ooool7o`000003ooooool0003o000007;ooooo00?o
0000ooooooooool09Oooool2o`00027ooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;o00004oooool9
o`0007;ooooo00?o0000ooooooooool04_ooool2o`00017ooooo0ol0000Qooooo`006_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo0_l0000Fooooo`Go00006_ooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo00;o00004?ooool3o`00013ooooo0ol0000Roooo
o`006oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooo
oooo00004oooool5o`0001Wooooo00?o0000ooooooooool0Koooool00ol0003oooooo`000002o`00
00oooooo0ol0000@ooooo`Co00008_ooool001cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooo000001?ooooo1_l0000Hooooo`03o`000?oooooooooo05oo
oooo0_l0000=ooooo`Go00003oooool4o`0000oooooo1?l0000Sooooo`007?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Cooooo`04o`000?oooooo0000o`0001Cooooo0ol0000Eooooo`Co00005oooool00ol0003o
ooooooooo`1Looooo`Go00003?ooool5o`0000oooooo1?l0000?ooooo`Go00008oooool001gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo
0ol0000Cooooo`?o00004oooool5o`0001Oooooo0_l0000Fooooo`03o`000?oooooooooo04_ooooo
0ol0000<ooooo`Ko00003?ooool6o`00013ooooo0ol0000Aooooo`?o00008oooool001gooooo00?o
0000ooooooooool04oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00gooooo0ol0
000Booooo`Go00005?ooool3o`0002oooooo00?o0000ooooooooool0B?ooool5o`0000cooooo1_l0
000<ooooo`03o`000?oooooooooo00?o00004Oooool2o`00017ooooo00?o0000ooooool000009?oo
ool001kooooo0ol0000Cooooo`;o00001?ooool00ol0003oooooooooo`0;ooooo`Go00004oooool3
o`0001Kooooo0_l0000^ooooo`03o`000?oooooooooo04Kooooo1_l0000=ooooo`Go00003?ooool0
1_l0003oooooooooool0003oooooo`00017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Tooooo`007Oooool4o`0001;ooooo1?l00004ooooo`03o`000?oooooooooo00cooooo0ol0
000Dooooo`?o00005oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Kooooo1?l0
000<ooooo`Go00003_ooool4o`0000cooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02Gooooo000Nooooo`Co00004oooool2o`0000Gooooo0_l0
000=ooooo`?o00005Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03;ooooo1_l0
000>ooooo`Co00003Oooool2o`0000;ooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ool0000Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09_ooool001oooooo0ol0
000Dooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`0booooo`Go00003Oooool2o`0000;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`008?ooool2o`0001Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0<Oooool5o`0000cooooo0_l0000Aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool000004oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Oooooo000Qoooo
o`;o00005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool07oooool8o`0000Oooooo0ol00003ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Xooooo`008_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool07_ooool7o`0000Oooooo0_l0000Aooooo`;o
00004Oooool2o`00017ooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo02Wooooo0012ooooo`03o`000?oooooooooo06Cooooo0_l0000<ooooo`?o0000
2oooool5o`000004ooooool0003o0000o`0000Sooooo0_l0000Aooooo`;o00004_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Yooooo`00@oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00_ooooo
1_l00003ooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`?o00004_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooool000005?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo02[ooooo000Gooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04_ooool01?l0003oooooooooool0000Aooooo`;o00004_ooool2o`0001?ooooo
0_l0000Cooooo`Co00004OoooolGo`0001;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00oooooo0_l000000ooooooo0000ooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0:oooool001Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Booooo`?o00005?ooool5o`0000Gooooo0_l00005ooooo`03o`00
0?oooooooooo00_ooooo1Ol0001@ooooo`03o`000?oooooooooo05Wooooo000Hooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Booooo`03o`00
0?oooooooooo017ooooo0_l0000Eooooo`;o00005oooool9o`0000?ooooo00?o0000ooooooooool0
2oooool2o`0005;ooooo00?o0000ooooooooool0F_ooool001Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0
4_ooool2o`0001Gooooo0_l0000Iooooo`Oo000000?oooooo`000?ooool0Goooool00ol0003ooooo
ooooo`1Kooooo`006Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00Co
0000oooooooooooo00004_ooool2o`0001Cooooo00?o0000ooooooooool05?ooool3o`0000;ooooo
0_l0000Booooo`Wo0000Goooool00ol0003oooooooooo`1Looooo`006_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`0Booooo`;o00005oooool5o`0001Wooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0kooooo`;o00008?ooool001_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Dooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool04oooool2o`000003oooo
ool0003ooooo01?ooooo1Ol0000Hooooo`03o`000?oooooooooo05[ooooo0_l0000[ooooo`;o0000
4?ooool3o`00023ooooo000Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`02o`0001;ooooo00Co0000oooooooooooo00004oooool3o`0001;ooooo
1ol0000Gooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool05oooool2o`00017ooooo
0ol0000?ooooo`?o00008Oooool001cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Dooooo`05o`000?ooooooooooooooool000004_ooool3o`0001?ooooo1?l0000Fooooo`?o0000
5_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Kooooo1?l0000?ooooo`Co0000
3oooool4o`00027ooooo000Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?oo
ool01Ol0003oooooo`000?oooooo0000017ooooo1?l0000Booooo`Go0000;_ooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`Go00003oooool4o`0000oooooo
1?l0000Rooooo`007_ooool01?l0003oooooo`000?l0000Booooo`03o`000?oooooo000001Cooooo
0_l00002ooooo`;o00003_ooool6o`0001Cooooo0ol0000]ooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool01?ooool4o`0000gooooo1Ol0000?ooooo`Go00004?ooool3o`0002;ooooo
000Nooooo`Co00004oooool2o`0001?ooooo1?l00003ooooo`03o`000?oooooooooo00gooooo1?l0
000Gooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Boooool3o`0000Oooooo00?o
0000ooooooooool00oooool5o`0000kooooo1Ol0000@ooooo`?o00004Oooool2o`0002?ooooo000N
ooooo`Co00004_ooool4o`0001Cooooo0ol00003ooooo`;o00004?ooool2o`0004?ooooo0_l00019
ooooo`Go00001_ooool2o`0000Gooooo1Ol0000?ooooo`Co00004?ooool00ol0003oooooo`00000A
ooooo`03o`000?oooooooooo02?ooooo000Oooooo`Co00004oooool2o`0001Gooooo0_l00005oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`16oooo
o`Ko00001_ooool00ol0003oooooooooo`05ooooo`Co00003oooool01?l0003oooooooooool0000@
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool0023ooooo0ol0000Doooo
o`;o00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool0=oooool4o`0000_ooooo1Ol00005ooooo`;o00001oooool01?l0003oooooooooool0000>
ooooo`;o00004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Gooooo000Qoooo
o`;o00005Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0_l0001Aoooo
o`03o`000?oooooooooo03?ooooo1_l0000<ooooo`Go00001Oooool00ol0003oooooooooo`05oooo
o`;o00004Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09_ooool002;ooooo0_l0000Eooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0cooooo`Go00002oooool2o`0000?ooooo00?o0000oooooooo
ool00_ooool2o`0000Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool09oooool002?ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01oooooo2?l00009ooooo`?o0000
00?oooooo`000?l000002oooool2o`0000Sooooo0_l00007ooooo`;o00004_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool005[ooooo0_l0
001=ooooo`03o`000?oooooooooo01kooooo1ol00008ooooo`?o00001?ooool00ol0003ooooooooo
o`08ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo001L
ooooo`;o0000Boooool00ol0003oooooooooo`0;ooooo`?o00002oooool5o`000004ooooool0003o
0000o`0000Sooooo0ol0000Aooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o00004ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Ooo
ool005kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`Ko00000oooool5
o`0000Kooooo00?o0000ooooooooool01Oooool3o`0001;ooooo0_l00009ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0:_ooool001Oooooo00?o0000ooooooooool04_ooool2o`00
01?ooooo0_l0000Cooooo`;o00001oooool2o`0000Wooooo0_l0000Cooooo`?o00004_ooool4o`00
00[ooooo0_l00005oooooaOo00004_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Oooooo0_l00008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo000Gooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Ko
oooo0_l00009ooooo`;o00005?ooool3o`0001?ooooo1ol00003ooooo`Co00000oooool00ol0003o
ooooooooo`0;ooooo`?o0000=_ooool00ol0003oooooooooo`1eooooo`006?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool2o`0000Sooooo
00?o0000ooooooooool02?ooool2o`0001Gooooo0ol0000Gooooo`Wo000000?oooooo`000?ooool0
@oooool2o`0007Sooooo000Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`;o00005_oo
ool4o`000003ooooool0003o000001;ooooo2Ol00012ooooo`;o0000N_ooool001[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Booooo`;o00005?ooool2o`0000Sooooo0_l0000:
ooooo`?o00005oooool5o`00013ooooo1?l00004ooooo`03o`000?oooooooooo03kooooo0_l0001l
ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool2o`0000Sooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003o0000
01;ooooo1ol0000Fooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0O?ooool001co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooool000001_ooool2o`0000cooooo1?l0000Aooooo`So00005Oooool2o`0003co
oooo0_l0001Nooooo`;o00007oooool001gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Cooooo`04o`000?ooooooooooo`0001?ooooo0ol00007ooooo`;o00002_ooool5o`0002go
oooo00?o0000ooooooooool0>Oooool2o`0004gooooo0_l0000?ooooo`Co00007oooool001kooooo
00?o0000ooooooooool05?ooool00ol0003oooooo`00000Cooooo`03o`000?oooooo000001?ooooo
1?l00008ooooo`;o00001oooool7o`0002cooooo00?o0000ooooooooool0=oooool2o`0003_ooooo
0_l0000@ooooo`Co00003Oooool5o`00023ooooo000Oooooo`04o`000?oooooo0000o`0001?ooooo
0_l0000Dooooo`?o00004Oooool6o`0000Wooooo0ol00009ooooo`?o0000:oooool00ol0003ooooo
ooooo`0dooooo`?o0000>oooool4o`0000kooooo1Ol0000=ooooo`Ko00008?ooool0023ooooo0ol0
000Cooooo`?o00004_ooool5o`0001?ooooo1?l0000;ooooo`;o0000=Oooool00ol0003ooooooooo
o`0booooo`;o0000;?ooool3o`0000gooooo1Ol0000>ooooo`Go00003oooool4o`00027ooooo000O
ooooo`Go00004Oooool5o`0001?ooooo0ol0000Fooooo`;o00003?ooool3o`0003;ooooo00?o0000
ooooooooool0<?ooool2o`0002_ooooo1Ol0000=ooooo`Go00003oooool5o`0000oooooo1?l0000Q
ooooo`008Oooool3o`0001?ooooo0ol0000Eooooo`;o00009_ooool3o`0002oooooo00?o0000oooo
ooooool0;Oooool3o`0001_ooooo1?l0000<ooooo`Ko00003_ooool5o`0000kooooo00?o0000oooo
ool000000_l0000?ooooo`04o`000?ooooooooooo`0002;ooooo000Rooooo`?o00005?ooool2o`00
01Kooooo00?o0000ooooooooool09_ooool3o`0002cooooo00?o0000ooooooooool0:_ooool3o`00
01[ooooo1_l0000>ooooo`Go00003Oooool2o`000004ooooool0003o0000o`0000kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo02Cooooo000Tooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0?oooool4o`0002Sooooo00?o0000ooooooooool09_ooool4
o`0001gooooo1Ol0000=ooooo`;o000000Coooooo`000?l0003o00003Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Uooooo`009Oooool00ol0003oooooooooo`1Iooooo`?o00009Oooool00ol0003oooooooooo`0S
ooooo`?o00003Oooool8o`0000_ooooo1Ol0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool2o`0001?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0V
ooooo`00Q?ooool3o`0002;ooooo00?o0000ooooooooool08?ooool3o`00013ooooo1_l0000:oooo
o`?o00000_ooool2o`0000cooooo0_l0000Aooooo`03o`000?oooooooooo017ooooo0_l0000Coooo
o`03o`000?oooooooooo02Oooooo0027ooooo`Co00007_ooool00ol0003oooooooooo`0Looooo`So
00003?ooool7o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo0_l0000Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`00
Roooool5o`0000kooooo1?l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo
2_l00003ooooo`So00001Oooool4o`0000Cooooo00?o0000ooooooooool02?ooool2o`00017ooooo
0_l0000Booooo`;o00004oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo
002@ooooo`Wo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo1ol0
0004ooooo`ko00001?ooool4o`00013ooooo0ol0000Aooooo`;o00004oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:_ooool001Oooooo00?o0000
ooooooooool04_ooool2o`0001?ooooo0_l0000Cooooo`;o00004_ooool2o`0001?ooooo0ol0000B
ooooo`Co000000?oooooo`000?l000009ol00009ooooo`;o00001Oooool2o`0001?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`006?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aoooo
o`;o00005?ooool3o`0001?ooooo1ol000000ooooooo0000ooooo`03o`0000Cooooo00?o0000oooo
ooooool02oooool5o`000:cooooo000Iooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`0001Gooooo0ol0000Gooooo`Wo
000000?oooooo`000?ooool03?ooool2o`000:oooooo000Jooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool2o`0001Cooooo0_l0000Cooooo`;o00005_ooool4o`000003oooo
ool0003o0000017ooooo2_l0002nooooo`006oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`?o00000ooo
ool00ol0003oooooooooo`0Aooooo`Go00003oooool5o`0000Cooooo00?o0000ooooooooool0_?oo
ool001cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01?ooooo0_l0000Eooooo`;o000000?oooooo`000?l000004_ooool7o`0000_ooooo00?oEEEE
ofIVI_l000002?ooool00ol0003oooooooooo`2looooo`007Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo0_l0000Eooooo`;o000000?oooooo`000?ooool04_ooool4o`00
017ooooo2?l0000Eooooo`03o`000?oooooooooo0;cooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l0000Eooooo`03o`000?oooooo000001Cooooo0ol0000Booooo`Go0000;Oooool00ol0003o
ooooooooo`2looooo`007oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000001?ooooo
0_l0000Dooooo`Co00004Oooool6o`0002cooooo00?o0000ooooooooool0_?ooool0023ooooo00?o
0000ooooool000005?ooool2o`0001?ooooo0ol0000Booooo`Ko00005?ooool3o`0002_ooooo00?o
0000ooooooooool0_?ooool0027ooooo0_l0000Dooooo`?o00004Oooool5o`0001Cooooo1?l00011
ooooo`03o`000?oooooooooo0;cooooo000Qooooo`?o00004_ooool5o`0001;ooooo1?l0000Foooo
o`;o0000@?ooool00ol0003oooooooooo`2looooo`008?ooool5o`0001?ooooo0ol0000Eooooo`;o
0000Eoooool00ol0003oooooooooo`2looooo`008_ooool3o`0001Gooooo0_l0000Fooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool0_?ooool002Cooooo0_l0000Fooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool0_?ooool002Kooooo00?o0000ooooooooool0P?ooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Xooooo`03ob4Q8Olb<S;ooooo0;gooooo002Wooooo`04oiRHV?lb<S;o410@okZj
^[gooooo002Wooooo`04oa0@4?nj^[[oV9RHoc8b<[gooooo002Vooooo`06oiRHV?lb<S;ooooooooo
ool@413o^[Zj_?ooool00:Gooooo00?ok^k^o`000?oMgMd00_ooool00onHV9So<S8booooo`2koooo
o`00YOooool00ol@413o0000o`000002ooooo`?o0000^oooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.16469, -1.15608, 0.00861177, \
0.00861177}}],

Cell[TextData[{
  "Fig. 1.7 phase-space flow and constant-",
  StyleBox["H",
    FontSlant->"Italic"],
  " curves for the undamped harmonic oscillator, ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["x,v",
    FontSlant->"Italic"],
  ") = -",
  StyleBox["x",
    FontSlant->"Italic"],
  "."
}], "Caption",
  CellTags->"Fig. 1.7"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hamiltonian Systems", "Section",
  CellTags->"c:14"],

Cell[TextData[{
  ButtonBox["Equations (1.2.11)",
    ButtonData:>"(1.2.11)",
    ButtonStyle->"Hyperlink"],
  " are a specific example of a more general class of area-conserving flows \
called Hamiltonian flows. These flows have equations of motion of the form "
}], "Text",
  CellTags->"i:21"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
            MultilineFunction->None], "=", 
          FractionBox[\(\[PartialD]\(H(x, p, t)\)\), \(\[PartialD]p\),
            MultilineFunction->None]}], TraditionalForm]]],
  ",\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FractionBox[\(\[DifferentialD]p\), \(\[DifferentialD]t\),
              MultilineFunction->None], "=", 
            RowBox[{"-", 
              FractionBox[\(\[PartialD]\(H(x, p, t)\)\), \(\[PartialD]x\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(1.2.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is the ",
  StyleBox["momentum associated with the variable",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " The function ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, p, t)\)]],
  " is the ",
  StyleBox[ButtonBox["Hamiltonian",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Hamilton.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "of the system. These flows are area-conserving, because their phase-space \
divergence is zero: "
}], "Text",
  CellTags->"i:22"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]x\), 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], 
            StyleBox["+",
              FontSize->15], 
            RowBox[{\(\[PartialD]\/\[PartialD]p\), 
              FractionBox[\(\[DifferentialD]p\), \(\[DifferentialD]t\),
                MultilineFunction->None]}]}], "=", 
          RowBox[{
            RowBox[{
              
              FractionBox[\(\[PartialD]\^2\( H(x, p, 
                    t)\)\), \(\[PartialD]x \[PartialD]p\),
                MultilineFunction->None], "-", 
              
              FractionBox[\(\[PartialD]\^2\( H(x, p, 
                    t)\)\), \(\[PartialD]x \[PartialD]p\),
                MultilineFunction->None]}], "=", "0"}]}], TraditionalForm]]],
  ". "
}], "NE2",
  CellTags->"(1.2.16)"],

Cell[TextData[{
  "For ",
  ButtonBox["Eqs. (1.2.11)",
    ButtonData:>"(1.2.11)",
    ButtonStyle->"Hyperlink"],
  ", the momentum is ",
  Cell[BoxData[
      \(TraditionalForm\`p\  = \ m\ v\)]],
  ", and the Hamiltonian is the total energy of the system, given by the sum \
of kinetic and potential energies:"
}], "Text",
  CellTags->"i:23"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"H", "=", 
          RowBox[{
            RowBox[{
              StyleBox[\(\(m\ v\^2\)\/2\),
                FontSize->15], "+", \(V(x)\)}], 
            "=", \(p\^2\/\(2\ m\) + \ V(x)\)}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(1.2.17)"],

Cell[TextData[{
  "\tIf the Hamiltonian is time-independent, it can easily be seen that the \
direction field is everywhere tangent to surfaces of constant ",
  StyleBox["H",
    FontSlant->"Italic"],
  ". Consider the change ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]H\)]],
  " in the value of ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "as a particle follows along the flow for a time ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  ". This change is given by"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]H\), "=", 
          RowBox[{
            RowBox[{
              RowBox[{\(\[DifferentialD]x\), " ", 
                FractionBox[\(\[PartialD]H\), \(\[PartialD]x\),
                  MultilineFunction->None]}], "+", 
              RowBox[{\(\[DifferentialD]p\), " ", 
                FractionBox[\(\[PartialD]H\), \(\[PartialD]p\),
                  MultilineFunction->None]}]}], "=", 
            RowBox[{"\[DifferentialD]", 
              RowBox[{"t", "(", 
                RowBox[{
                  RowBox[{
                    FractionBox[\(\[PartialD]H\), \(\[PartialD]x\),
                      
                      MultilineFunction->
                        None], \(\(\(\[DifferentialD]x\)\(\ \)\)\/\
\[DifferentialD]t\)}], "+", 
                  RowBox[{
                    FractionBox[\(\[PartialD]H\), \(\[PartialD]p\),
                      
                      MultilineFunction->
                        None], \(\(\(\[DifferentialD]p\)\(\ \)\)\/\
\[DifferentialD]t\)}]}], ")"}]}]}]}], TraditionalForm]]]
}], "Text"],

Cell["Using the equations of motion, we have ", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[DifferentialD]H\), "=", 
        RowBox[{
          RowBox[{"\[DifferentialD]", 
            RowBox[{"t", "[", 
              RowBox[{
                RowBox[{
                  FractionBox[\(\[PartialD]H\), \(\[PartialD]x\),
                    MultilineFunction->None], 
                  FractionBox[\(\[PartialD]H\), \(\[PartialD]p\),
                    MultilineFunction->None]}], "+", 
                RowBox[{
                  FractionBox[\(\[PartialD]H\), \(\[PartialD]p\),
                    MultilineFunction->None], 
                  RowBox[{"(", 
                    RowBox[{"-", 
                      FractionBox[\(\[PartialD]H\), \(\[PartialD]x\),
                        MultilineFunction->None]}], ")"}]}]}], "]"}]}], "=", 
          "0"}]}], TraditionalForm]]]], "NE2",
  CellTags->"(1.2.18)"],

Cell[TextData[{
  " In other words energy is conserved, so that the flow is along constant-",
  StyleBox["H ",
    FontSlant->"Italic"],
  "surfaces.",
  StyleBox[" ",
    FontSlant->"Italic"],
  "Some of these constant ",
  StyleBox["H ",
    FontSlant->"Italic"],
  "surfaces are shown in Fig. ",
  ButtonBox["1.7",
    ButtonData:>"Fig. 1.7",
    ButtonStyle->"Hyperlink"],
  " for the harmonic oscillator. As usual, we plot the direction field in the \
",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " plane rather than in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " plane. "
}], "Text"],

Cell[TextData[{
  "\tFor a time-independent Hamiltonian ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, p)\)]],
  ", curves of constant-",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  " are nested curves in phase-space,  which describe the orbits.  Even for \
very complicated Hamiltonian functions, these constant-",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " curves must be nested (think of contours of constant altitude on a \
topographic map). The resulting orbits must always remain on a given \
constant-",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "contour in a given region of phase-space. Different regions of phase-space \
are isolated from one another by these curves. Such motion is said to be ",
  StyleBox["integrable",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"i:24"],

Cell[TextData[{
  "\tHowever, this situation can change if the Hamiltonian depends explicitly \
on time so that energy is not conserved, or if phase-space has four or more \
dimensions [as, for example,  can occur for two coupled oscillators, which \
have phase-space (",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  ")]. Now energy surfaces no longer necessarily isolate different regions of \
phase-space. In these situations, it is possible for particles to explore \
large regions of phase-space. The study of such systems is a burgeoning area \
of mathematical physics called ",
  StyleBox["chaos theory",
    FontSlant->"Italic"],
  ". A comprehensive examination of the properties of chaotic systems would \
take us too far afield, but we will consider a few basic properties of \
chaotic systems in Sec. ",
  ButtonBox["1.4",
    ButtonData:>"Sec. 1.4",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:112"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 1.2", "Subsubtitle",
  CellTags->{"Ex. 1.2", "c:15"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Find, by hand,  three valid solutions to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              
              FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
                
                MultilineFunction->None], ")"}], "3"], "=", \(t\ \(x(t)\)\)}],
         TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = \(\(x\^\[Prime]\)(0) = 0\)\)]],
  ". ",
  StyleBox["(Hint: Try solutions of the form ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["a ",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.00389105]],
  Cell[BoxData[
      \(TraditionalForm\`t\^n\)]],
  StyleBox["for some constants ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["a",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" and ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["n",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[".)",
    FontColor->RGBColor[0, 0, 0.00389105]]
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Plot the direction field for the following differential equations in the \
given ranges, and discuss the qualitative behavior of solutions for initial \
conditions in the given ranges of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]y\), \(\[DifferentialD]t\),
            MultilineFunction->None], "=", \(\@t\ y\^2\)}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < \ 4, \ \ \(-2\) < y < 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]y\), \(\[DifferentialD]t\),
            MultilineFunction->None], "=", \(sin(t + y)\)}], 
        TraditionalForm]]],
  " ,",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 15, \(-8\) < t < 8\)]],
  " .   "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(Hint: You can increase the resolution of the vector field using \
the ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["PlotPoints",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" option, as in ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["PlotPoints",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["25",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[".)",
    FontColor->RGBColor[0, 0, 0.00389105]]
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " For a Hamiltonian ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, v, t)\)]],
  ", that depends explicitly on time, show that rate of change of energy ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]H/\[DifferentialD]t\)]],
  " along a particular trajectory in phase-space is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]H\/\[DifferentialD]t\), "=", 
          RowBox[{
            FractionBox[\(\[PartialD]H\), \(\[PartialD]t\),
              
              MultilineFunction->None], \( \[VerticalSeparator] \_\(x, 
                v\)\)}]}], TraditionalForm]]],
  "\t"
}], "NE2",
  CellTags->"(1.2.19)"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " A simple pendulum follows the differential equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\^\[DoublePrime]\)(t) = \(-\(g\/l\)\) 
          sin\ \(\[Theta](t)\)\)]],
  ", where ",
  StyleBox["\[Theta]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  " is the angle the pendulum makes with the vertical, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              FormBox[
                SuperscriptBox[
                  StyleBox["s",
                    FontSlant->"Plain"], "2"],
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  " is the acceleration of gravity, and ",
  StyleBox["l",
    FontSlant->"Italic"],
  " is the length of the pendulum. (See Fig. ",
  ButtonBox["1.8",
    ButtonData:>"Fig. 1.8",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellTags->"i:37"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=>0003Gb000`400?l00000o`00003oo`3ooooo
0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00
o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA
0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0oooo
o`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?oo
ool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo
003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oo
oe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3o
oooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooomd0oooo1P0000020041
0B<00000503oool40?knoS00oooo003o0?ooool0oooog@3oool6000000800@418`00000D0?ooo`@0
o_kn<03oool00?l0ooooo`3oooo<0?ooo`80o_kn203ooolh00000480oooo003o0?ooool0ooooc03o
ool20?knoPP0oooo>00000120?ooo`00o`3ooooo0?oool80oooo0P3no_h>0?ooo`H000000P010@4;
000000800@41:`00000n0?ooo`00o`3ooooo0?oool80oooo0P3no_h>0?ooo`H000000P010@4;0000
00800@41:`00000n0?ooo`00o`3ooooo0?oool80oooo0P3no_h:0?ooo`@000000P010@4=00000080
0@410P00000H0?oooaT00000>P3oool00?l0ooooo`3oooo20?ooo`80o_kn2P3oool4000000800@41
3@00000200410@800000603ooolI000003X0oooo003o0?ooool0ooooaP3oool20?knoP80oooo5@00
000U0?oooa0000000P010@42000000800@41=P3oool00?l0ooooo`3oooo60?ooo`80o_kn0P3ooolE
000002D0oooo4000000200410@8000000P010@4f0?ooo`00o`3ooooo0?ooolP0oooo4000000b0?oo
oa800000103oool20?knoP80oooo0P3no_hZ0?ooo`00o`3ooooo0?ooolP0oooo4000000b0?oooa80
0000103oool20?knoP80oooo0P3no_hZ0?ooo`00o`3ooooo0?ooolH0oooo400000020?knoSH0oooo
3P00000200410@800000<03oool00?l0ooooo`3oooo60?oooa0000000P3no_hf0?ooo`h000000P01
0@4200000300oooo003o0?ooool0oooo`P3oool@000002T0oooo0P3no_hE0?oooa000000;P3oool0
0?l0ooooo`3oooo20?oooa000000:@3oool20?knoQD0oooo4000000^0?ooo`00o`3ooooo0?oool00
oooo3P0000160?ooo``000000P010@42000000l0oooo0P3no_hK0?ooo`00o`3ooooo0?oool00oooo
3P0000160?ooo``000000P010@42000000l0oooo0P3no_hK0?ooo`00o`3ooooo0?oookh0oooo0P3n
o_h:000000800@41BP3oool>000000L0oooo0P3no_hS0?ooo`00o`3ooooo0?oookh0oooo0P3no_h:
000000800@41BP3oool>000000L0oooo0P3no_hS0?ooo`00o`3ooooo0?oookh0oooo0P3no_h:0000
00800@41BP3oool>000000L0oooo0P3no_hS0?ooo`00o`3ooooo0?ooojl0oooo0P3no_h;0?ooo`h0
0000D03oool<000002X0oooo003o0?ooool0oooo[`3oool20?knoP/0oooo3P00001@0?ooo``00000
:P3oool00?l0ooooo`3ooonl0?ooo`X00000EP3oool=000000H0oooo0P3no_h80?ooo`80o_kn5@3o
ool00?l0ooooo`3ooonl0?ooo`X00000EP3oool=000000H0oooo0P3no_h80?ooo`80o_kn5@3oool0
0?l0ooooo`3ooonj0?ooo`X00000G03oool9000002L0oooo003o0?ooool0oooo^P3oool:000005`0
oooo2@00000W0?ooo`00o`3ooooo0?ooojL0oooo0P3no_h?0?ooo``00000GP3oool9000002D0oooo
003o0?ooool0ooooY`3oool20?knoPl0oooo3000001N0?ooo`T000009@3oool00?l0ooooo`3ooonf
0?ooo``00000H03oool;000002<0oooo003o0?ooool0oooo]P3oool<00000600oooo2`00000S0?oo
o`00o`3ooooo0?ooojL0oooo0P3no_h40?ooo`80o_kn1`3oool4000000800@411000001T0?ooo`/0
0000203oool20?knoQL0oooo003o0?ooool0ooooY`3oool20?knoP@0oooo0P3no_h70?ooo`@00000
0P010@44000006@0oooo2`0000080?ooo`80o_kn5`3oool00?l0ooooo`3ooonc0?ooo`/00000J03o
ool900000240oooo003o0?ooool0oooo/`3oool;000006P0oooo2@00000Q0?ooo`00o`3ooooo0?oo
ok<0oooo1@00000200410@@00000J`3oool8000001l0oooo003o0?ooool0oooo/`3oool500000080
0@411000001[0?ooo`P000007`3oool00?l0ooooo`3ooon[0?ooo`@0o_kn0P3oool;000006@0oooo
0P3no_h70?ooo`@000000P010@42000001l0oooo003o0?ooool0ooooZ`3oool40?knoP80oooo2`00
001T0?ooo`80o_kn1`3oool4000000800@410P00000O0?ooo`00o`3ooooo0?oook40oooo1`000002
00410@800000K`3oool8000001d0oooo003o0?ooool0oooo/@3oool7000000800@410P00001_0?oo
o`P000007@3oool00?l0ooooo`3ooon]0?ooo`80o_kn2`00001a0?ooo`P000007@3oool00?l0oooo
o`3ooon]0?ooo`80o_kn2`00001a0?ooo`P000007@3oool00?l0ooooo`3ooonY0?ooo`80o_kn0P3o
ool20?knoP/00000L`3oool8000001/0oooo003o0?ooool0ooooZ@3oool20?knoP80oooo0P3no_h;
000007<0oooo2000000K0?ooo`00o`3ooooo0?ooojd0oooo2`00001e0?ooo`X000006@3oool00?l0
ooooo`3ooon]0?ooo`/00000M@3oool:000001T0oooo003o0?ooool0ooooZ`3oool20?knoPT00000
N@3oool2000000800@410P00000200410AT0oooo003o0?ooool0ooooZ`3oool20?knoPT00000N@3o
ool2000000800@410P00000200410AT0oooo003o0?ooool0oooo[@3oool200410@L000000P3no_ig
0?ooo`P000006@3oool00?l0ooooo`3ooon]0?ooo`800@411`0000020?knoWL0oooo2000000I0?oo
o`00o`3ooooo0?oooj/0oooo2`00001i0?ooo`X000005`3oool00?l0ooooo`3ooon[0?ooo`/00000
N@3oool:000001L0oooo003o0?ooool0ooooZ`3oool8000007`0oooo0P3no_h8000001L0oooo003o
0?ooool0ooooZ`3oool8000007`0oooo0P3no_h8000001L0oooo003o0?ooool0ooooZ`3oool40000
00800@410P00001n0?ooo`P000005`3oool00?l0ooooo`3ooon[0?ooo`@000000P010@42000007h0
oooo2000000G0?ooo`00o`3ooooo0?oooj/0oooo1000000200410@800000OP3oool8000001L0oooo
003o0?ooool0ooooZ`3oool8000000<0oooo0P3no_ig0?ooo`X000005`3oool00?l0ooooo`3ooon[
0?ooo`P000000`3oool20?knoWL0oooo2P00000G0?ooo`00o`3ooooo0?oooj/0oooo2000001l0?oo
o`X000005`3oool00?l0ooooo`3ooon[0?ooo`P00000O03oool:000001L0oooo003o0?ooool0oooo
Z`3oool8000007P0oooo103no_h2000000800@411P00000G0?ooo`00o`3ooooo0?oooj/0oooo2000
001h0?ooo`@0o_kn0P00000200410@H000005`3oool00?l0ooooo`3ooonY0?ooo`X00000O03oool2
0?knoPP000005`3oool00?l0ooooo`3ooonY0?ooo`X00000O03oool20?knoPP000005`3oool00?l0
ooooo`3ooonY0?ooo`P00000P03oool8000001L0oooo003o0?ooool0ooooZ@3oool800000800oooo
2000000G0?ooo`00o`3ooooo0?ooojT0oooo200000200?ooo`P000005`3oool00?l0ooooo`3ooonY
0?ooo`P00000P03oool8000001L0oooo003o0?ooool0ooooZ@3oool8000007`0oooo0P3no_h20?oo
o`P000005`3oool00?l0ooooo`3ooonY0?ooo`P00000O03oool20?knoP80oooo2000000G0?ooo`00
o`3ooooo0?ooojT0oooo200000200?ooo`P000005`3oool00?l0ooooo`3ooonY0?ooo`P00000P03o
ool8000001L0oooo003o0?ooool0ooooZ@3oool800000800oooo2000000G0?ooo`00o`3ooooo0?oo
ojT0oooo200000200?ooo`P000005`3oool00?l0ooooo`3ooon[0?ooo`P00000OP3oool8000001L0
oooo003o0?ooool0ooooZ`3oool8000007h0oooo2000000G0?ooo`00o`3ooooo0?oooj/0oooo2000
001l0?ooo`X000005`3oool00?l0ooooo`3ooon[0?ooo`P00000O03oool:000001L0oooo003o0?oo
ool0ooooZ`3oool8000007`0oooo2P00000G0?ooo`00o`3ooooo0?oooj/0oooo2000001l0?ooo`X0
00005`3oool00?l0ooooo`3ooonY0?ooo`80o_kn1000000200410@800000O03oool:000001L0oooo
003o0?ooool0ooooZ@3oool20?knoP@000000P010@42000007`0oooo2P00000G0?ooo`00o`3ooomn
0?ooo`80o_kn1@3oool20?kno_l0oooo803oool20?knoP80oooo2`0000020?knoWL0oooo10000002
00410@@000005`3oool00?l0ooooOP3oool20?knoPD0oooo0P3no_ko0?ooob00oooo0P3no_h20?oo
o`/000000P3no_ig0?ooo`@000000P010@44000001L0oooo003o0?ooool0ooooZ@3oool20?knoP/0
0000203oool20?knoVl0oooo2P00000G0?ooo`00o`3ooooo0?ooojT0oooo0P3no_h;000000P0oooo
0P3no_i_0?ooo`X000005`3oool00?l0ooooo`3ooon]0?ooo`T000000P3no_ig0?ooo`P000006@3o
ool00?l0ooooo`3ooon]0?ooo`T000000P3no_ig0?ooo`P000006@3oool00?l0ooooo`3ooon]0?oo
o`/00000M@3oool:000001T0oooo003o0?ooool0oooo[@3oool;000007D0oooo2P00000I0?ooo`00
o`3ooon00?ooo`T00000o`3ooolT0?ooo`T000000P010@4>0?ooo`80o_knI@3oool200410@P00000
0P3oool20?knoQD0oooo003o0?oooh00oooo2@00003o0?ooob@0oooo2@00000200410@h0oooo0P3n
o_iU0?ooo`800@41200000020?ooo`80o_kn5@3oool00?l0ooooP03oool900000?l0oooo903oool9
000000800@413P3oool20?knoVD0oooo0P010@4800000080oooo0P3no_hE0?ooo`00o`3ooon00?oo
o`<000000P010@4400000?l0oooo9P3oool;000007<0oooo2000000K0?ooo`00o`3ooon00?ooo`<0
00000P010@4400000?l0oooo9P3oool;000007<0oooo2000000K0?ooo`00o`3ooon00?ooo`T00000
o`3ooolV0?ooo`/000001P3oool20?knoP@0oooo0P3no_iS0?ooo`P000000P010@4K0?ooo`00o`3o
oon00?ooo`T00000o`3ooolV0?ooo`/000001P3oool20?knoP@0oooo0P3no_iS0?ooo`P000000P01
0@4K0?ooo`00o`3ooon00?ooo`T00000o`3ooolX0?ooo`/00000K`3oool8000001d0oooo003o0?oo
oh00oooo2@00003o0?ooobP0oooo2`00001_0?ooo`P000007@3oool00?l0ooooP03oool900000?l0
oooo:03oool5000000800@411000001P0?ooo`80o_kn2`3oool8000001l0oooo003o0?oooh00oooo
2@00003o0?ooobP0oooo1@00000200410@@00000H03oool20?knoP/0oooo2000000O0?ooo`00o`3o
oon00?ooo`T00000o`3ooolZ0?ooo`/00000J`3oool8000001l0oooo003o0?oooh00oooo2@00003o
0?ooobX0oooo2`00001[0?ooo`P000007`3oool00?l0ooooP03oool900000?l0oooo:P3oool30000
00800@412000001T0?ooo`L000000P010@4200000240oooo003o0?oooh00oooo2@00003o0?ooobX0
oooo0`00000200410@P00000I03oool7000000800@410P00000Q0?ooo`00o`3ooon00?ooo`T00000
o`3oool]0?ooo``00000HP3oool;00000240oooo003o0?oooh00oooo2@00003o0?ooobd0oooo3000
001R0?ooo`/000008@3oool00?l0ooooP03oool900000?l0oooo;@3oool2000000800@412000001P
0?ooo`/000008`3oool00?l0ooooP03oool900000?l0oooo;@3oool2000000800@412000001P0?oo
o`/000008`3oool00?l0ooooP03oool900000?l0oooo;`3oool<000005`0oooo2`00000U0?ooo`00
o`3ooon00?ooo`T00000o`3oool_0?ooo``00000G03oool;000002D0oooo003o0?oooh00oooo2@00
003o0?oooc40oooo3000001H0?ooo`H000000P010@45000000h0oooo0P3no_hE0?ooo`00o`3ooon0
0?ooo`T00000o`3ooola0?ooo``00000F03oool6000000800@411@00000>0?ooo`80o_kn5@3oool0
0?l0ooooP03oool900000?l0oooo<@3oool<000005H0oooo3@00000W0?ooo`00o`3ooon00?ooo`T0
0000o`3ooola0?ooo``00000EP3oool=000002L0oooo003o0?oooh00oooo2@00003o0?oooc<0oooo
2P00000200410@800000D03oool<000002X0oooo003o0?oooh00oooo2@00003o0?oooc<0oooo2P00
000200410@800000D03oool<000002X0oooo003o0?oooh00oooo2@00003o0?ooocD0oooo3P00000<
0?ooo`80o_kn;P3oool20?knoP`0oooo3P0000020?knoRX0oooo003o0?oooh00oooo2@00003o0?oo
ocD0oooo3P00000<0?ooo`80o_kn;P3oool20?knoP`0oooo3P0000020?knoRX0oooo003o0?oooh00
oooo2@00003o0?ooocT0oooo2P00000200410DH0oooo3P00000^0?ooo`00o`3ooon00?ooo`T00000
o`3oooli0?ooo`X000000P010@560?ooo`h00000;P3oool00?l0ooooP03oool900000?l0oooo?@3o
ool<000000H0oooo0P3no_h^0?ooo`80o_kn203oool>00000300oooo003o0?oooh00oooo2@00003o
0?ooocd0oooo300000060?ooo`80o_kn;P3oool20?knoPP0oooo3P00000`0?ooo`00o`3ooon00?oo
o`T00000o`3ooolo0?ooo``00000>P3oool>000003@0oooo003o0?oooh00oooo2@00003o0?ooocl0
oooo3000000j0?ooo`h00000=03oool00?l0ooooP03oool900000?l0oooo@@3oool>00000380oooo
3000000200410@800000=P3oool00?l0ooooP03oool900000?l0oooo@@3oool>00000380oooo3000
000200410@800000=P3oool00?l0ooooP03oool900000?l0oooo>`3oool20?knoPH0oooo0P010@42
000000800@413@00000U0?oooa@00000>03oool00?l0ooooP03oool900000?l0oooo>`3oool20?kn
oPH0oooo0P010@42000000800@413@00000U0?oooa@00000>03oool00?l0ooooP03oool900000?l0
oooo>`3oool20?knoPH0oooo0P010@42000000800@413@00000U0?oooa@00000>03oool00?l0oooo
P03oool9000009`0oooo0P3no_jV0?ooo`H000000P010@47000000800@411P00000H0?oooaL00000
?03oool00?l0ooooP03oool9000009`0oooo0P3no_jV0?ooo`H000000P010@47000000800@411P00
000H0?oooaL00000?03oool00?l0ooooo`3ooolC0?ooo`l00000ZP3ooom6000003h0oooo003o0?oo
ool0oooo4`3oool?00000:X0ooooAP00000n0?ooo`00o`3ooooo0?ooo`d0oooo3`00000200410@P0
0000VP3oool20?knoPX0oooo3P00000300410@X000000P010@4U00000480oooo003o0?ooool0oooo
3@3oool?000000800@412000002J0?ooo`80o_kn2P3oool>000000<00@412P00000200410BD00000
@P3oool00?l0ooooo`3oool;0?ooo`X000002`3oool200410@P00000X03oool:000000T0oooo0P00
000200410BL00000B03oool00?l0ooooo`3oool;0?ooo`X000002`3oool200410@P00000X03oool:
000000T0oooo0P00000200410BL00000B03oool00?l0ooooo`3oool90?ooo`800@41200000090?oo
o`80o_kn1P3oool8000009`0oooo3000000?0?oooa`00000D@3oool00?l0ooooo`3oool90?ooo`80
0@41200000090?ooo`80o_kn1P3oool8000009`0oooo3000000?0?oooa`00000D@3oool00?l0oooo
o`3oool50?ooo`80o_kn0P3oool4000000800@410P00000;0?ooo`80o_kn203oool8000008X0oooo
0P3no_h>0?ooo`X00000@P3oool40?knoSP0oooo003o0?ooool0oooo1@3oool20?knoP80oooo1000
000200410@8000002`3oool20?knoPP0oooo2000002:0?ooo`80o_kn3P3oool:00000480oooo103n
o_hh0?ooo`00o`3ooooo0?ooo`L0oooo2P00000E0?ooo`X00000UP3oool:00000800oooo003o0?oo
ool0oooo1`3oool:000001D0oooo2P00002F0?ooo`X00000P03oool00?l0ooooo`3oool70?ooo`X0
00005`3oool200410@H00000R03oool20?knoP@0oooo0P3no_h60?ooo`X00000@03oool20?knoSh0
oooo003o0?ooool0oooo1`3oool:000001L0oooo0P010@46000008P0oooo0P3no_h40?ooo`80o_kn
1P3oool:00000400oooo0P3no_hn0?ooo`00o`3ooooo0?ooo`L0oooo0P010@46000000800@415`3o
ool200410@P00000TP3oool:00000080oooo0P3no_in0?ooo`00o`3ooooo0?ooo`L0oooo0P010@46
000000800@415`3oool200410@P00000TP3oool:00000080oooo0P3no_in0?ooo`00o`3ooooo0?oo
o`L0oooo2P00000I0?ooo`X00000SP3oool<00000880oooo003o0?ooool0oooo1`3oool:000001T0
oooo2P00002>0?ooo``00000PP3oool00?l0ooooo`3oool50?ooo`X000000P010@4I0?ooo`X00000
303oool30?knoWl0oooo2P0000240?ooo`00o`3ooooo0?ooo`D0oooo2P00000200410AT0oooo2P00
000<0?ooo`<0o_knO`3oool:000008@0oooo003o0?ooool0oooo1@3oool<000001/0oooo2P00002:
0?ooo`X00000QP3oool00?l0ooooo`3oool50?ooo``000006`3oool:000008X0oooo2P0000260?oo
o`00o`3ooooo0?ooo`D0oooo0P00000200410@P000005`3oool20?knoP80oooo2P00002:0?ooo`X0
0000QP3oool00?l0ooooo`3oool50?ooo`8000000P010@48000001L0oooo0P3no_h20?ooo`X00000
RP3oool:000008H0oooo003o0?ooool0oooo1@3oool8000000800@410P00000K0?ooo``00000QP3o
ool8000000800@41R03oool00?l0ooooo`3oool50?ooo`P000000P010@42000001/0oooo30000026
0?ooo`P000000P010@680?ooo`00o`3ooon00?ooo`T00000N`3oool<000001<0oooo0P3no_h60?oo
o``00000Q03oool<000008P0oooo003o0?oooh00oooo2@00001k0?ooo``000004`3oool20?knoPH0
oooo300000240?ooo``00000R03oool00?l0ooooP03oool9000007/0oooo3000000M0?ooo`X00000
PP3oool20?knoPX00000203oool20?knoX00oooo003o0?oooh00oooo2@00001k0?ooo``000007@3o
ool:00000880oooo0P3no_h:000000P0oooo0P3no_j00?ooo`00o`3ooon00?ooo`T00000N`3oool<
000001d0oooo3000001i0?ooo`<0o_kn103oool8000000800@41S03oool00?l0ooooP03oool90000
07/0oooo3000000M0?ooo``00000N@3oool30?knoP@0oooo2000000200410H`0oooo003o0?oooh00
oooo2@00001k0?ooo``000007@3oool<00000800oooo2P00002<0?ooo`00o`3ooon00?ooo`T00000
N`3oool<000001d0oooo300000200?ooo`X00000S03oool00?l0ooooP03oool9000007/0oooo3000
000M0?ooo``00000P03oool:000008`0oooo003o0?oooh00oooo2@00001m0?ooo``000006`3oool<
000007h0oooo1P00000200410@800000SP3oool00?l0ooooP03oool9000007d0oooo3000000K0?oo
o``00000OP3oool6000000800@410P00002>0?ooo`00o`3ooon00?ooo`T00000N`3oool20?knoPX0
00000P010@4M0?ooo`@000000P010@46000007X0oooo3000002>0?ooo`00o`3ooon00?ooo`T00000
N`3oool20?knoPX000000P010@4M0?ooo`@000000P010@46000007X0oooo3000002>0?ooo`00o`3o
oon00?ooo`T00000O@3oool<000001d0oooo300000070?ooo`80o_knL@3oool:000000@0oooo0P3n
o_j:0?ooo`00o`3ooon00?ooo`T00000O@3oool<000001d0oooo300000070?ooo`80o_knL@3oool:
000000@0oooo0P3no_j:0?ooo`00o`3ooon00?ooo`T00000O@3oool4000000800@411P00000M0?oo
o``000001`3oool20?knoVh0oooo1@00000200410@@00000TP3oool00?l0ooooP03oool9000007d0
oooo1000000200410@H000007@3oool<000000L0oooo0P3no_i^0?ooo`D000000P010@4400000980
oooo003o0?oooh00oooo2@00001m0?ooo``000007@3oool<000006d0oooo0P3no_h80?ooo`/00000
103oool40?knoXX0oooo003o0?oooh00oooo2@00001m0?ooo``000007@3oool<000006d0oooo0P3n
o_h80?ooo`/00000103oool40?knoXX0oooo003o0?oooh00oooo2@00001o0?oooc<00000M@3oool;
000009@0oooo003o0?oooh00oooo2@00001o0?oooc<00000M@3oool;000009@0oooo003o0?oooh00
oooo2@00001o0?ooocD00000L@3oool=000000P0oooo0P3no_j:0?ooo`00o`3ooon00?ooo`T00000
O`3ooole00000740oooo3@0000080?ooo`80o_knRP3oool00?l0ooooP03oool9000007l0oooo3000
000=0?ooo`80o_kn0P3oool20?knoPX0oooo3000001a0?ooo`/00000UP3oool00?l0ooooP03oool9
000007l0oooo3000000=0?ooo`80o_kn0P3oool20?knoPX0oooo3000001a0?ooo`/00000UP3oool0
0?l0ooooP03oool9000007l0oooo3000000M0?ooo``00000K`3oool2000000800@411`00002H0?oo
o`00o`3ooon00?ooo`T00000O`3oool<000001d0oooo3000001_0?ooo`8000000P010@47000009P0
oooo003o0?oooh00oooo2@0000210?ooo`800@412000000M0?ooo``00000K`3oool6000000<00@41
0P00002H0?ooo`00o`3ooon00?ooo`T00000P@3oool200410@P000007@3oool<000006l0oooo1P00
000300410@800000V03oool00?l0ooooP03oool9000007l0oooo0P3no_h<00000140oooo0P3no_h2
0?ooo`80o_kn1P3oool:000006d0oooo2`0000060?ooo`80o_kn203oool20?knoXP0oooo003o0?oo
oh00oooo2@00001o0?ooo`80o_kn3000000A0?ooo`80o_kn0P3oool20?knoPH0oooo2P00001]0?oo
o`/000001P3oool20?knoPP0oooo0P3no_j80?ooo`00o`3ooon00?ooo`T00000N@3oool20?knoPH0
oooo2000000200410@8000003@3oool20?knoPH0oooo0P3no_h60?ooo`X00000J`3oool=000009X0
oooo003o0?oooh00oooo2@00001i0?ooo`80o_kn1P3oool8000000800@410P00000=0?ooo`80o_kn
1P3oool20?knoPH0oooo2P00001[0?ooo`d00000VP3oool00?l0ooooP03oool9000008<0oooo2P00
00070?ooo`80o_kn103oool20?knoPX0oooo0P3no_h20?ooo`X00000J`3oool:000000D0oooo0P3n
o_jF0?ooo`00o`3ooon00?ooo`T00000P`3oool:000000L0oooo0P3no_h40?ooo`80o_kn2P3oool2
0?knoP80oooo2P00001[0?ooo`X000001@3oool20?knoYH0oooo003o0?oooh00oooo2@00001i0?oo
o`80o_kn103oool20?knoP80oooo0P010@4:000001/0oooo2P00001Y0?ooo`H000000P010@420000
00D0oooo0P3no_h80?ooo`80o_knSP3oool00?l0ooooP03oool9000007T0oooo0P3no_h40?ooo`80
o_kn0P3oool200410@X000006`3oool:000006T0oooo1P00000200410@8000001@3oool20?knoPP0
oooo0P3no_j>0?ooo`00o`3ooon00?ooo`T00000N@3oool20?knoPX0oooo2P00000K0?ooo`X00000
J@3oool2000000800@411P00002O0?ooo`00o`3ooon00?ooo`T00000N@3oool20?knoPX0oooo2P00
000K0?ooo`X00000J@3oool2000000800@411P00002O0?ooo`00o`3ooon00?ooo`T00000Q@3oool:
000000L0oooo0P3no_hB0?ooo`X000000P3no_iU0?ooo`@000000P010@4400000:40oooo003o0?oo
oh00oooo2@0000250?ooo`X000001`3oool20?knoQ80oooo2P0000020?knoVD0oooo100000020041
0@@00000X@3oool00?l0ooooP03oool9000008L0oooo2`0000020?ooo`80o_kn303oool20?knoPH0
oooo2P0000050?ooo`80o_knGP3oool<00000080o_knW`3oool00?l0ooooP03oool9000008L0oooo
2`0000020?ooo`80o_kn303oool20?knoPH0oooo2P0000050?ooo`80o_knGP3oool<00000080o_kn
W`3oool00?l0ooooP03oool9000008L0oooo2`0000060?ooo`80o_kn403oool:000006D0oooo2P00
00020?ooo`80o_kn1@3oool20?knoYP0oooo003o0?oooh00oooo2@0000270?ooo`/000001P3oool2
0?knoQ00oooo2P00001U0?ooo`X000000P3oool20?knoPD0oooo0P3no_jH0?ooo`00o`3ooon00?oo
o`T00000R@3oool200410@T000005P3oool4000000800@410P0000070?ooo`80o_knEP3oool20?kn
oP@0oooo2P00002U0?ooo`00o`3ooon00?ooo`T00000R@3oool200410@T000005P3oool400000080
0@410P0000070?ooo`80o_knEP3oool20?knoP@0oooo2P00002U0?ooo`00o`3ooon00?ooo`T00000
R@3oool200410@T000005P3oool4000000800@410P0000070?ooo`80o_knEP3oool20?knoP@0oooo
2P00002U0?ooo`00o`3ooomn0?ooo`80o_kn2@00002;0?ooo`T000001P3oool20?knoPh0oooo1000
000200410@8000000P3no_h20?ooo`<0o_knGP3oool2000000800@411P00002U0?ooo`00o`3ooomn
0?ooo`80o_kn2@00002;0?ooo`T000001P3oool20?knoPh0oooo1000000200410@8000000P3no_h2
0?ooo`<0o_knGP3oool2000000800@411P00002U0?ooo`00o`3ooon00?ooo`T00000S@3oool90000
0180oooo2P00001S0?ooo`X00000Y`3oool00?l0ooooP03oool9000008d0oooo2@00000B0?ooo`X0
0000H`3oool:00000:L0oooo003o0?ooool0oooo5@3oool20?knoP80oooo2@0000020?ooo`80o_kn
103oool20?knoPH0oooo2000001S0?ooo`@000000P010@4600000:L0oooo003o0?ooool0oooo5@3o
ool20?knoP80oooo2@0000020?ooo`80o_kn103oool20?knoPH0oooo2000001S0?ooo`@000000P01
0@4600000:L0oooo003o0?ooool0oooo703oool2000000800@411P0000020?ooo`80o_kn1P3oool8
000000P0oooo0`3no_iJ0?ooo`X00000Z@3oool00?l0ooooo`3ooolL0?ooo`8000000P010@460000
0080oooo0P3no_h60?ooo`P00000203oool30?knoUX0oooo2P00002Y0?ooo`00o`3ooooo0?oooah0
oooo6000001U0?ooo`X00000Z`3oool00?l0ooooo`3ooolN0?oooaP00000I@3oool:00000:/0oooo
003o0?ooool0oooo903oool>000005d0oooo0P3no_h:0?ooo`X00000Z`3oool00?l0ooooo`3ooolT
0?ooo`h00000G@3oool20?knoPX0oooo2P00002[0?ooo`00o`3ooooo0?oooah0oooo0P3no_ii0?oo
o`X000000P3oool20?knoZT0oooo003o0?ooool0oooo7P3oool20?knoWT0oooo2P0000020?ooo`80
o_knZ@3oool00?l0ooooo`3ooolh0?ooo`80o_kn2@3oool20?knoU80oooo3000002]0?ooo`00o`3o
oooo0?ooocP0oooo0P3no_h90?ooo`80o_knDP3oool<00000:d0oooo003o0?ooool0oooo5@3oool2
0?knoVl0oooo0P3no_h?0?ooo`X00000[`3oool00?l0ooooo`3ooolE0?ooo`80o_knK`3oool20?kn
oPl0oooo2P00002_0?ooo`00o`3ooooo0?oooaD0oooo0P3no_hM0?ooo`80o_knG`3oool:00000;40
oooo003o0?ooool0oooo5@3oool20?knoQd0oooo0P3no_iO0?ooo`X00000/@3oool00?l0ooooo`3o
ooll0?ooo`80o_knB03oool20?knoP@0oooo0`3no_h60?ooo`X00000/@3oool00?l0ooooo`3oooll
0?ooo`80o_knB03oool20?knoP@0oooo0`3no_h60?ooo`X00000/@3oool00?l0ooooo`3ooonC0?oo
o`X000000P3oool20?knoZl0oooo003o0?ooool0ooooT`3oool:00000080oooo0P3no_j_0?ooo`00
o`3ooooo0?oooi40oooo3000002c0?ooo`00o`3ooooo0?oooi40oooo3000002c0?ooo`00o`3ooooo
0?oooi40oooo2P00002e0?ooo`00o`3ooooo0?oooi40oooo2P00002e0?ooo`00o`3ooomn0?ooo`80
o_kn2@00003o0?ooo`H0oooo2P00002g0?ooo`00o`3ooomn0?ooo`80o_kn2@00003o0?ooo`H0oooo
2P00002g0?ooo`00o`3ooon00?ooo`T000000P3oool20?kno_l0oooo0P3oool:00000;L0oooo003o
0?oooh00oooo2@0000020?ooo`80o_kno`3oool20?ooo`X00000]`3oool00?l0ooooP03oool90000
0?l0oooo0`3oool9000000800@41^@3oool00?l0ooooP03oool900000?l0oooo0`3oool900000080
0@41^@3oool00?l0ooooP03oool900000?l0oooo0@3oool=00000;T0oooo003o0?oooh00oooo2@00
003o0?ooo`40oooo3@00002i0?ooo`00o`3ooon00?ooo`T00000o`3oool10?ooo`d00000^@3oool0
0?l0ooooP03oool900000?h0oooo0P3no_h;000000P0oooo0P3no_ja0?ooo`00o`3ooon00?ooo`T0
0000oP3oool20?knoP/00000203oool20?kno[40oooo003o0?oooh00oooo2@00000B0?ooo`80o_kn
i03oool20?knoP@0oooo2@00000200410Kd0oooo003o0?oooh00oooo2@00000B0?ooo`80o_kni03o
ool20?knoP@0oooo2@00000200410Kd0oooo003o0?oooh00oooo2@0000130?ooo`<0o_kn^03oool;
00000;d0oooo003o0?oooh00oooo2@0000130?ooo`<0o_kn^03oool;00000;d0oooo003o0?oooh00
oooo2@00003l0?ooo`H000000`010@4200000;l0oooo003o0?oooh00oooo2@00003l0?ooo`H00000
0`010@4200000;l0oooo003o0?oooh00oooo2@00000<0?ooo`80o_knk03oool=00000;l0oooo003o
0?oooh00oooo2@00000<0?ooo`80o_knk03oool=00000;l0oooo003o0?oooh00oooo2@00000B0?oo
o`80o_kniP3oool;000000@0oooo0P3no_jk0?ooo`00o`3ooon00?ooo`T000004P3oool20?kno^H0
oooo2`0000040?ooo`80o_kn^`3oool00?l0ooooP03oool9000000P0oooo6`00003E0?ooo`@00000
0P010@4400000<@0oooo003o0?oooh00oooo2@0000080?oooa/00000e@3oool4000000800@411000
00340?ooo`00o`3ooon00?ooo`T00000203ooolB000000800@418@00002a0?ooo`80o_kn203oool:
000000D0oooo103no_jk0?ooo`00o`3ooon00?ooo`T00000203ooolB000000800@418@00002a0?oo
o`80o_kn203oool:000000D0oooo103no_jk0?ooo`00o`3ooon00?ooo`T00000203oool400000080
0@410P00000200410C400000/`3oool:00000<H0oooo003o0?oooh00oooo2@0000080?ooo`@00000
0P010@42000000800@41<@00002c0?ooo`X00000aP3oool00?l0ooooP03oool9000000P0ooooA000
00020?knoQ00oooo0P3no_h40?ooo`80o_kn4@3oool20?knoW/0oooo300000090?ooo`80o_kn^`3o
ool00?l0ooooP03oool9000000P0ooooA00000020?knoQ00oooo0P3no_h40?ooo`80o_kn4@3oool2
0?knoW/0oooo300000090?ooo`80o_kn^`3oool00?l0ooooP03oool9000002<0oooo8`0000020041
0@X000009@3oool20?knoW/0oooo2P0000380?ooo`00o`3ooon00?ooo`T000008`3ooolS00000080
0@412P00000U0?ooo`80o_knN`3oool:00000<P0oooo003o0?oooh00oooo2@00000U0?ooo`80o_kn
503ooolO000000@0oooo0P3no_jB0?ooo`8000000P010@4600000<X0oooo003o0?oooh00oooo2@00
000U0?ooo`80o_kn503ooolO000000@0oooo0P3no_jB0?ooo`8000000P010@4600000<X0oooo003o
0?oooh00oooo2@0000110?ooo`d000000P010@4@000000l0oooo0P3no_j10?ooo`H000000P010@42
00000<X0oooo003o0?oooh00oooo2@0000110?ooo`d000000P010@4@000000l0oooo0P3no_j10?oo
o`H000000P010@4200000<X0oooo003o0?oooh00oooo2@0000060?ooo`80o_kn@P3ooolN000008P0
oooo2P0000060?ooo`80o_kn2@3oool20?kno[T0oooo003o0?oooh00oooo2@0000060?ooo`80o_kn
@P3ooolN000008P0oooo2P0000060?ooo`80o_kn2@3oool20?kno[T0oooo003o0?oooh00oooo2@00
000J0?ooo`80o_kn=03oool4000000800@416@0000080?ooo`80o_knM@3oool<00000<`0oooo003o
0?oooh00oooo2@00000J0?ooo`80o_kn=03oool4000000800@416@0000080?ooo`80o_knM@3oool<
00000<`0oooo003o0?oooh00oooo2@00000B0?ooo`80o_kn3@3oool20?knoR/0oooo0P3no_h80?oo
o`8000000P010@4C000000800@411000001i0?ooo`X00000103oool20?kno/P0oooo003o0?oooh00
oooo2@00000B0?ooo`80o_kn3@3oool20?knoR/0oooo0P3no_h80?ooo`8000000P010@4C00000080
0@411000001i0?ooo`X00000103oool20?kno/P0oooo003o0?oooh00oooo2@00000@0?ooo`80o_kn
C03oool4000000800@415@00001c0?ooo`H000000P010@42000000@0oooo0P3no_h90?ooo`80o_kn
_`3oool00?l0ooooP03oool900000100oooo0P3no_i<0?ooo`@000000P010@4E000007<0oooo1P00
000200410@800000103oool20?knoPT0oooo0P3no_jo0?ooo`00o`3ooon00?ooo`T00000IP3oool=
000000800@412000000K0?ooo`80o_knDP3oool2000000800@411P00003@0?ooo`00o`3ooon00?oo
o`T00000IP3oool=000000800@412000000K0?ooo`80o_knDP3oool2000000800@411P00003@0?oo
o`00o`3ooon00?ooo`T00000IP3oool=000000800@412000000K0?ooo`80o_knDP3oool200000080
0@411P00003@0?ooo`00o`3ooon00?ooo`T00000K@3ooolB000006/0oooo1000000200410@@00000
dP3oool00?l0ooooP03oool9000006d0oooo4P00001[0?ooo`@000000P010@4400000=80oooo003o
0?oooh00oooo2@00001a0?ooo`P000000P010@48000006D0oooo300000020?kno]00oooo003o0?oo
oh00oooo2@00001a0?ooo`P000000P010@48000006D0oooo300000020?kno]00oooo003o0?oooh00
oooo2@00001e0?ooo`P0000010010@4600000640oooo2P0000020?ooo`80o_kn103oool20?kno/X0
oooo003o0?oooh00oooo2@00001e0?ooo`P0000010010@4600000640oooo2P0000020?ooo`80o_kn
103oool20?kno/X0oooo003o0?oooo40oooo1@3no_h<0?oooa800000E@3oool20?knoP@0oooo2P00
003F0?ooo`00o`3ooooa0?ooo`D0o_kn303ooolB000005D0oooo0P3no_h40?ooo`X00000eP3oool0
0?l0ooooo`3oool50?oooa@00000E`3oool2000000800@411P00003F0?ooo`00o`3ooooo0?ooo`D0
oooo5000001G0?ooo`8000000P010@4600000=H0oooo003o0?ooool0oooo0@3oool40?knoP@0oooo
5@00001@0?ooo`X00000f03oool00?l0ooooo`3oool10?ooo`@0o_kn103ooolE00000500oooo2P00
003H0?ooo`00o`3ooooo0?ooo`d0oooo3000000300410@@00000C03oool4000000800@411P00003H
0?ooo`00o`3ooooo0?ooo`d0oooo3000000300410@@00000C03oool4000000800@411P00003H0?oo
o`00o`3ooooo0?oooa40oooo4`00000@0?ooo`80o_kn0P3oool20?knoS80oooo2P00003J0?ooo`00
o`3ooooo0?oooa40oooo4`00000@0?ooo`80o_kn0P3oool20?knoS80oooo2P00003J0?ooo`00o`3o
oooo0?oooaD0oooo4`0000020?ooo`@0o_kn?03oool:00000=`0oooo003o0?ooool0oooo5@3ooolC
00000080oooo103no_hl0?ooo`X00000g03oool00?l0ooooo`3ooolI0?oooa4000001P3oool20?kn
oR/0oooo0P3no_h;0?ooo`X00000g03oool00?l0ooooo`3ooolI0?oooa4000001P3oool20?knoR/0
oooo0P3no_h;0?ooo`X00000g03oool00?l0ooooo`3ooolL0?ooo`h000000P010@42000000H0oooo
0P3no_ha0?ooo`/000000P3oool20?kno]X0oooo003o0?ooool0oooo703oool>000000800@410P00
00060?ooo`80o_kn<@3oool;00000080oooo0P3no_kJ0?ooo`00o`3ooooo0?ooob00oooo20000002
00410@H000003P3oool20?knoRD0oooo3@00003N0?ooo`00o`3ooooo0?ooob00oooo200000020041
0@H000003P3oool20?knoRD0oooo3@00003N0?ooo`00o`3ooooo0?ooob@0oooo3P00000S0?ooo`80
o_kn3P3oool;00000>00oooo003o0?ooool0oooo903oool>000002<0oooo0P3no_h>0?ooo`/00000
h03oool00?l0ooooo`3ooolV0?ooo`h00000;`3oool;00000>80oooo003o0?ooool0oooo9P3oool>
000002l0oooo2`00003R0?ooo`00o`3ooooo0?oooaD0oooo0P3no_h70?ooo`80o_kn2P3oool>0000
01d0oooo0P3no_h40?ooo`80o_kn1P3oool;00000>80oooo003o0?ooool0oooo5@3oool20?knoPL0
oooo0P3no_h:0?ooo`h000007@3oool20?knoP@0oooo0P3no_h60?ooo`/00000hP3oool00?l0oooo
o`3oool/0?ooo`h000009`3oool;00000080oooo0P3no_kP0?ooo`00o`3ooooo0?ooob`0oooo3P00
000W0?ooo`/000000P3oool20?kno^00oooo003o0?oooh00oooo2@00002T0?ooo`X000000P010@42
000002<0oooo3@00003T0?ooo`00o`3ooon00?ooo`T00000Y03oool:000000800@410P00000S0?oo
o`d00000i03oool00?l0ooooOP3oool20?knoPT00000YP3oool<000000800@418@3oool;00000>H0
oooo003o0?ooogh0oooo0P3no_h900000:H0oooo3000000200410B40oooo2`00003V0?ooo`00o`3o
oomn0?ooo`80o_kn2@00002V0?ooo``000000P010@4Q0?ooo`/00000iP3oool00?l0ooooP03oool9
00000:80oooo0P3no_h40?oooa4000006P3oool:00000>T0oooo003o0?oooh00oooo2@00002R0?oo
o`80o_kn103ooolA000001X0oooo2P00003Y0?ooo`00o`3ooon00?ooo`T00000ZP3ooolA00000080
o_kn5P3oool:00000>T0oooo003o0?oooh00oooo2@00002Z0?oooa4000000P3no_hF0?ooo`X00000
j@3oool00?l0ooooP03oool900000:h0oooo3`00000D0?ooo`P000000P010@7[0?ooo`00o`3ooon0
0?ooo`T00000[P3oool?000001@0oooo2000000200410N/0oooo003o0?oooh00oooo2@00002`0?oo
o`d000000P010@4@0?ooo``00000j`3oool00?l0ooooP03oool900000;00oooo3@00000200410A00
oooo3000003[0?ooo`00o`3ooon00?ooo`T00000/P3ooolA000000X0oooo0P3no_h:000000T0oooo
0P3no_kR0?ooo`00o`3ooon00?ooo`T00000/P3ooolA000000X0oooo0P3no_h:000000T0oooo0P3n
o_kR0?ooo`00o`3ooon00?ooo`T00000]03ooolA000000P0oooo2000000200410Nl0oooo003o0?oo
oh00oooo2@00002d0?oooa400000203oool8000000800@41k`3oool00?l0ooooP03oool900000;H0
oooo0`010@4>000000H0oooo2P00003_0?ooo`00o`3ooon00?ooo`T00000]P3oool300410@h00000
1P3oool:00000>l0oooo003o0?oooh00oooo2@00002i0?ooo`8000000P010@48000000H0oooo1P00
000200410@800000l@3oool00?l0ooooP03oool900000;T0oooo0P00000200410@P000001P3oool6
000000800@410P00003a0?ooo`00o`3ooon00?ooo`T00000^`3oool20?knoPP00000103oool<0000
0?40oooo003o0?oooh00oooo2@00002k0?ooo`80o_kn200000040?ooo``00000l@3oool00?l0oooo
P03oool900000;l0oooo100000020?knoP@0oooo2P0000040?ooo`80o_knk@3oool00?l0ooooP03o
ool900000;l0oooo100000020?knoP@0oooo2P0000040?ooo`80o_knk@3oool00?l0ooooP03oool9
00000<L0oooo1000000200410@@00000m@3oool00?l0ooooP03oool900000<L0oooo100000020041
0@@00000m@3oool00?l0ooooP03oool900000;/0oooo0P3no_h:0?ooo`X00000103oool40?kno^d0
oooo003o0?oooh00oooo2@00002k0?ooo`80o_kn2P3oool:000000@0oooo103no_k]0?ooo`00o`3o
oon00?ooo`T00000a@3oool:00000?L0oooo003o0?oooh00oooo2@0000350?ooo`X00000m`3oool0
0?l0ooooP03oool900000<<0oooo300000080?ooo`80o_knk@3oool00?l0ooooP03oool900000<<0
oooo300000080?ooo`80o_knk@3oool00?l0ooooP03oool900000<<0oooo2P00003i0?ooo`00o`3o
oon00?ooo`T00000``3oool:00000?T0oooo003o0?oooh00oooo2@0000310?ooo`8000000P010@46
00000?/0oooo003o0?oooh00oooo2@0000310?ooo`8000000P010@4600000?/0oooo003o0?oooh00
oooo2@0000310?ooo`H000000P010@4200000?/0oooo003o0?oooh00oooo2@0000310?ooo`H00000
0P010@4200000?/0oooo003o0?oooh00oooo2@00002o0?ooo`X000001P3oool20?knoPP0oooo0P3n
o_k[0?ooo`00o`3ooon00?ooo`T00000_`3oool:000000H0oooo0P3no_h80?ooo`80o_knj`3oool0
0?l0ooooP03oool900000;l0oooo2P0000060?ooo`80o_kn203oool20?kno^/0oooo003o0?oooh00
oooo2@00002m0?ooo``00000o@3oool00?l0ooooP03oool900000;d0oooo3000003m0?ooo`00o`3o
oon00?ooo`T00000_@3oool:000000@0oooo0P3no_ki0?ooo`00o`3ooon00?ooo`T00000_@3oool:
000000@0oooo0P3no_ki0?ooo`00o`3ooon00?ooo`T00000^`3oool6000000800@410P0000040?oo
o`80o_kn203oool20?kno_40oooo003o0?oooh00oooo2@00002k0?ooo`H000000P010@42000000@0
oooo0P3no_h80?ooo`80o_knl@3oool00?l0ooooP03oool900000;/0oooo0P00000200410@H00000
o`3oool20?ooo`00o`3ooon00?ooo`T00000^`3oool2000000800@411P00003o0?ooo`80oooo003o
0?oooh00oooo2@00002i0?ooo`@000000P010@4400000?l0oooo103oool00?l0ooooP03oool90000
0;T0oooo1000000200410@@00000o`3oool40?ooo`00o`3ooooo0?oood00oooo3@0000020?kno_l0
oooo0P3oool00?l0ooooo`3ooom00?ooo`d000000P3no_ko0?ooo`80oooo003o0?ooool0oooo@03o
ool;00000080oooo0P3no_h40?ooo`80o_knn`3oool00?l0ooooo`3ooom00?ooo`/000000P3oool2
0?knoP@0oooo0P3no_kk0?ooo`00o`3ooooo0?ooocP0oooo0P3no_h40?ooo`/00000o`3oool80?oo
o`00o`3ooooo0?ooocP0oooo0P3no_h40?ooo`/00000o`3oool80?ooo`00o`3ooooo0?oooch0oooo
0P00000300410@H00000o`3oool80?ooo`00o`3ooooo0?oooch0oooo0P00000300410@H00000o`3o
ool80?ooo`00o`3ooooo0?oooc`0oooo2`00003o0?ooo`X0oooo003o0?ooool0oooo?03oool;0000
0?l0oooo2P3oool00?l0ooooo`3ooolj0?ooo`@000000P010@4700000?l0oooo2P3oool00?l0oooo
o`3ooolj0?ooo`@000000P010@4700000?l0oooo2P3oool00?l0ooooo`3ooolj0?ooo`/00000o`3o
ool<0?ooo`00o`3ooooo0?ooocX0oooo2`00003o0?ooo``0oooo003o0?ooool0oooo>03oool;0000
0?l0oooo3P3oool00?l0ooooo`3ooolh0?ooo`/00000o`3oool>0?ooo`00o`3ooooo0?ooob`0oooo
0P3no_h:0?ooo`/00000o`3oool>0?ooo`00o`3ooooo0?ooob`0oooo0P3no_h:0?ooo`/00000o`3o
ool>0?ooo`00o`3ooooo0?ooocH0oooo2P0000030?ooo`80o_kno`3oool<0?ooo`00o`3ooooo0?oo
ocH0oooo2P0000030?ooo`80o_kno`3oool<0?ooo`00o`3ooooo0?oooc@0oooo3000003o0?oooa40
oooo003o0?ooool0oooo=03oool<00000?l0oooo4@3oool00?l0ooooo`3ooolT0?ooo`80o_kn3P3o
ool:00000?l0oooo4`3oool00?l0ooooo`3ooolT0?ooo`80o_kn3P3oool:00000?l0oooo4`3oool0
0?l0ooooP03oool900000:P0oooo2P00003o0?oooaD0oooo003o0?oooh00oooo2@00002X0?ooo`X0
0000o`3ooolE0?ooo`00o`3ooon00?ooo`T00000Z03oool:00000?l0oooo5@3oool00?l0ooooP03o
ool9000009X0oooo0P3no_h40?ooo`80o_kn1P3oool:00000?l0oooo5@3oool00?l0ooooP03oool9
000009X0oooo0P3no_h40?ooo`80o_kn1P3oool:00000?l0oooo5@3oool00?l0ooooP03oool90000
0:H0oooo2P00003o0?oooaL0oooo003o0?oooh00oooo2@00002V0?ooo`X00000o`3ooolG0?ooo`00
o`3ooon00?ooo`T00000YP3oool:00000?l0oooo5`3oool00?l0ooooP03oool900000:H0oooo2P00
003o0?oooaL0oooo003o0?oooh00oooo2@00002T0?ooo`X00000o`3ooolI0?ooo`00o`3ooon00?oo
o`T00000Y03oool:00000?l0oooo6@3oool00?l0ooooP03oool900000:80oooo3000000;0?ooo`80
o_kno`3oool<0?ooo`00o`3ooon00?ooo`T00000XP3oool<000000/0oooo0P3no_ko0?ooo``0oooo
003o0?oooh00oooo2@00002R0?ooo`X00000o`3ooolK0?ooo`00o`3ooon00?ooo`T00000XP3oool:
00000?l0oooo6`3oool00?l0ooooP03oool900000:00oooo2P00000:0?ooo`80o_kno`3ooolA0?oo
o`00o`3ooon00?ooo`T00000X03oool:000000X0oooo0P3no_ko0?oooa40oooo003o0?oooh00oooo
2@00002P0?ooo`H000000P010@42000000H0oooo0P3no_ko0?oooaD0oooo003o0?oooh00oooo2@00
002P0?ooo`H000000P010@42000000H0oooo0P3no_ko0?oooaD0oooo003o0?oooh00oooo2@00002N
0?ooo`X00000o`3ooolO0?ooo`00o`3ooon00?ooo`T00000WP3oool:00000?l0oooo7`3oool00?l0
ooooP03oool9000009`0oooo3000003o0?oooal0oooo003o0?oooh00oooo2@00002L0?ooo``00000
o`3ooolO0?ooo`00o`3ooon00?ooo`T00000W03oool:00000?l0oooo8@3oool00?l0ooooP03oool9
000009`0oooo2P00003o0?ooob40oooo003o0?oooh00oooo2@00002D0?ooo`80o_kn103oool:0000
0?l0oooo8`3oool00?l0ooooP03oool9000009@0oooo0P3no_h40?ooo`X00000o`3ooolS0?ooo`00
o`3ooon00?ooo`T00000VP3oool:00000?l0oooo8`3oool00?l0ooooP03oool9000009X0oooo2P00
003o0?ooob<0oooo003o0?oooh00oooo2@00002D0?ooo`80o_kn0P3oool:00000?l0oooo9@3oool0
0?l0ooooP03oool9000009@0oooo0P3no_h20?ooo`X00000o`3ooolU0?ooo`00o`3ooon00?ooo`T0
0000R@3oool20?knoP/0oooo3000003o0?ooobD0oooo003o0?oooh00oooo2@0000290?ooo`80o_kn
2`3oool<00000?l0oooo9@3oool00?l0ooooP03oool9000008T0oooo0P3no_h;0?ooo`800@412000
003o0?ooobL0oooo003o0?oooh00oooo2@0000290?ooo`80o_kn2`3oool200410@P00000o`3ooolW
0?ooo`00o`3ooon00?ooo`T00000U03oool:00000?l0oooo:@3oool00?l0ooooP03oool9000009@0
oooo2P00003o0?ooobT0oooo003o0?oooh00oooo2@00002D0?ooo`X00000o`3ooolY0?ooo`00o`3o
oon00?ooo`T00000U03oool:00000?l0oooo:@3oool00?l0ooooP03oool900000980oooo2P00003o
0?ooob/0oooo003o0?oooh00oooo2@00002B0?ooo`X00000o`3oool[0?ooo`00o`3ooon00?ooo`T0
0000TP3oool:00000?l0oooo:`3oool00?l0ooooP03oool9000008l0oooo3@0000060?ooo`80o_kn
o`3ooolS0?ooo`00o`3ooon00?ooo`T00000S`3oool=000000H0oooo0P3no_ko0?ooob<0oooo003o
0?oooh00oooo2@00002?0?ooo`/00000o`3oool]0?ooo`00o`3ooon00?ooo`T00000S`3oool;0000
0?l0oooo;@3oool00?l0ooooP03oool9000008d0oooo2`00003o0?ooobl0oooo003o0?oooh00oooo
2@00002=0?ooo`/00000o`3oool_0?ooo`00o`3ooomn0?ooo`80o_kn2@00002=0?ooo`800@410`00
000200410@@00000o`3oool_0?ooo`00o`3ooomn0?ooo`80o_kn2@00002=0?ooo`800@410`000002
00410@@00000o`3oool_0?ooo`00o`3ooon00?ooo`T00000R`3oool;00000?l0oooo<@3oool00?l0
ooooP03oool9000008/0oooo2`00003o0?oooc40oooo003o0?ooool0oooo4`3oool=00000?l0oooo
<@3oool00?l0ooooo`3ooolC0?ooo`d00000o`3ooola0?ooo`00o`3ooooo0?oooa<0oooo2`00003o
0?oooc<0oooo003o0?ooool0oooo4`3oool;00000?l0oooo<`3oool00?l0ooooo`3oool=0?ooo`@0
o_kn1P00000200410@<00000o`3ooole0?ooo`00o`3ooooo0?ooo`d0oooo103no_h6000000800@41
0`00003o0?ooocD0oooo003o0?ooool0oooo4@3oool;00000?l0oooo=@3oool00?l0ooooo`3ooolA
0?ooo`/00000o`3ooole0?ooo`00o`3ooooo0?ooo`l0oooo2P00003o0?ooocP0oooo003o0?ooool0
oooo3`3oool:00000?l0oooo>03oool00?l0ooooo`3oool=0?ooo``00000o`3ooolh0?ooo`00o`3o
oooo0?ooo`d0oooo3000003o0?ooocP0oooo003o0?ooool0oooo3@3oool:00000?l0oooo>P3oool0
0?l0ooooo`3oool=0?ooo`X00000o`3ooolj0?ooo`00o`3ooooo0?ooo`/0oooo2P00003o0?oooc`0
oooo003o0?ooool0oooo2`3oool:00000?l0oooo?03oool00?l0ooooo`3oool;0?ooo`X00000o`3o
ooll0?ooo`00o`3ooooo0?ooo`/0oooo2P00003o0?oooc`0oooo003o0?ooool0oooo1@3oool20?kn
oP80oooo1000000200410@@00000o`3oooln0?ooo`00o`3ooooo0?ooo`D0oooo0P3no_h20?ooo`@0
00000P010@4400000?l0oooo?P3oool00?l0ooooo`3oool70?ooo``00000o`3oooln0?ooo`00o`3o
oooo0?ooo`L0oooo3000003o0?oooch0oooo003o0?ooooX0oooo0P3no_h:0?ooo`@000000P010@44
00000?l0oooo@03oool00?l0oooonP3oool20?knoPX0oooo1000000200410@@00000o`3ooom00?oo
o`00o`3ooooo0?ooo`D0oooo1P00000200410@800000o`3ooom20?ooo`00o`3ooooo0?ooo`D0oooo
1P00000200410@800000o`3ooom20?ooo`00o`3ooooo0?ooo`D0oooo1P00000200410@800000o`3o
oom20?ooo`00o`3ooon00?ooo`T00000N`3oool:00000?l0oooo@P3oool00?l0ooooP03oool90000
07/0oooo2P00003o0?oood80oooo003o0?oooh00oooo2@00001X0?ooo`80o_kn3`3oool:00000?l0
ooooA03oool00?l0ooooP03oool9000006P0oooo0P3no_h?0?ooo`X00000o`3ooom40?ooo`00o`3o
oon00?ooo`T00000M`3oool<00000?l0ooooA03oool00?l0ooooP03oool9000007L0oooo3000003o
0?oood@0oooo003o0?oooh00oooo2@00001X0?ooo`80o_kn1@3oool20?knoPH0oooo2P00003o0?oo
odH0oooo003o0?oooh00oooo2@00001X0?ooo`80o_kn1@3oool20?knoPH0oooo2P00003o0?ooodH0
oooo003o0?oooh00oooo2@00001e0?ooo`X00000o`3ooom80?ooo`00o`3ooon00?ooo`T00000M@3o
ool:00000?l0ooooB03oool00?l0ooooP03oool9000007D0oooo2P00003o0?ooodP0oooo003o0?oo
oh00oooo2@00001e0?ooo`X00000o`3ooom80?ooo`00o`3ooon00?ooo`T00000L`3oool:00000?l0
ooooBP3oool00?l0ooooP03oool9000007<0oooo2P00003o0?ooodX0oooo003o0?oooh00oooo2@00
001a0?ooo``000002P3oool20?kno_l0oooo?P3oool00?l0ooooP03oool900000740oooo3000000:
0?ooo`80o_kno`3oooln0?ooo`00o`3ooon00?ooo`T00000L@3oool:00000?l0ooooC03oool00?l0
ooooP03oool900000740oooo2P00003o0?oood`0oooo003o0?oooh00oooo2@00001_0?ooo`X00000
2P3oool20?kno_l0oooo@P3oool00?l0ooooP03oool9000006l0oooo2P00000:0?ooo`80o_kno`3o
oom20?ooo`00o`3ooon00?ooo`T00000K`3oool6000000800@410P0000060?ooo`80o_kno`3ooom6
0?ooo`00o`3ooon00?ooo`T00000K`3oool6000000800@410P0000060?ooo`80o_kno`3ooom60?oo
o`00o`3ooon00?ooo`T00000K@3oool:00000?l0ooooD03oool00?l0ooooP03oool9000006d0oooo
2P00003o0?oooe00oooo003o0?oooh00oooo2@00001Z0?ooo`d00000o`3ooom@0?ooo`00o`3ooon0
0?ooo`T00000JP3oool=00000?l0ooooD03oool00?l0ooooP03oool9000006X0oooo2`00003o0?oo
oe80oooo003o0?oooh00oooo2@00001Z0?ooo`/00000o`3ooomB0?ooo`00o`3ooon00?ooo`T00000
HP3oool20?knoP@0oooo2`00003o0?oooe@0oooo003o0?oooh00oooo2@00001R0?ooo`80o_kn103o
ool;00000?l0ooooE03oool00?l0ooooP03oool9000006P0oooo2`00003o0?oooe@0oooo003o0?oo
oh00oooo2@00001X0?ooo`/00000o`3ooomD0?ooo`00o`3ooon00?ooo`T00000HP3oool20?knoP80
oooo2`00003o0?oooeH0oooo003o0?oooh00oooo2@00001R0?ooo`80o_kn0P3oool;00000?l0oooo
EP3oool00?l0ooooP03oool9000005P0oooo0P3no_h:0?ooo`d00000o`3ooomF0?ooo`00o`3ooon0
0?ooo`T00000F03oool20?knoPX0oooo3@00003o0?oooeH0oooo003o0?oooh00oooo2@00001H0?oo
o`80o_kn2P3oool=00000?l0ooooEP3oool00?l0ooooP03oool9000005P0oooo0P3no_h:0?ooo`80
0@412@00003o0?oooeP0oooo003o0?oooh00oooo2@00001H0?ooo`80o_kn2P3oool200410@T00000
o`3ooomH0?ooo`00o`3ooon00?ooo`T00000HP3oool;00000?l0ooooFP3oool00?l0ooooP03oool9
00000680oooo2`00003o0?oooeX0oooo003o0?oooh00oooo2@00001R0?ooo`/00000o`3ooomJ0?oo
o`00o`3ooon00?ooo`T00000HP3oool;00000?l0ooooFP3oool00?l0ooooP03oool900000600oooo
2P00003o0?oooed0oooo003o0?oooh00oooo2@00001P0?ooo`X00000o`3ooomM0?ooo`00o`3ooon0
0?ooo`T00000GP3oool<000000L0oooo0P3no_ko0?oooe@0oooo003o0?oooh00oooo2@00001N0?oo
o``000001`3oool20?kno_l0ooooE03oool00?l0ooooP03oool900000080oooo0P3no_iJ0?ooo`X0
0000o`3ooomO0?ooo`00o`3ooon00?ooo`T000000P3oool20?knoUX0oooo2P00003o0?oooel0oooo
003o0?ooogh0oooo0P3no_h9000005`0oooo2P00003o0?ooof40oooo003o0?ooogh0oooo0P3no_h9
000005`0oooo2P00003o0?ooof40oooo003o0?ooonD0oooo0P010@42000000800@411000003o0?oo
of40oooo003o0?ooonD0oooo0P010@42000000800@411000003o0?ooof40oooo003o0?ooon<0oooo
2P00003o0?ooof<0oooo003o0?ooon<0oooo2P00003o0?ooof<0oooo003o0?ooon40oooo3000003o
0?ooof<0oooo003o0?ooon40oooo3000003o0?ooof<0oooo003o0?ooon40oooo2P00003o0?ooofD0
oooo003o0?ooon40oooo2P00003o0?ooofD0oooo003o0?ooom/0oooo103no_h6000000800@410P00
003o0?ooofL0oooo003o0?ooom/0oooo103no_h6000000800@410P00003o0?ooofL0oooo003o0?oo
oml0oooo2P00003o0?ooofL0oooo003o0?oooml0oooo2P00003o0?ooofL0oooo003o0?ooomd0oooo
2P00003o0?ooofT0oooo003o0?ooomd0oooo2P00003o0?ooofT0oooo003o0?ooom/0oooo3000003o
0?ooofT0oooo003o0?ooom/0oooo3000003o0?ooofT0oooo003o0?ooom/0oooo2P00003o0?ooof/0
oooo003o0?ooom/0oooo2P00003o0?ooof/0oooo003o0?ooomT0oooo2P00003o0?ooofd0oooo003o
0?ooomT0oooo2P00003o0?ooofd0oooo003o0?ooomT0oooo2P00003o0?ooofd0oooo003o0?ooomT0
oooo2P00003o0?ooofd0oooo003o0?ooomT0oooo2P00003o0?ooofd0oooo003o0?ooom<0oooo0P3n
o_h20?ooo`@000000P010@4400000?l0ooooK`3oool00?l0ooood`3oool20?knoP80oooo10000002
00410@@00000o`3ooom_0?ooo`00o`3ooon00?ooo`T00000C03oool<00000?l0ooooK`3oool00?l0
ooooP03oool9000004`0oooo3000003o0?ooofl0oooo003o0?ooogh0oooo0P3no_h9000003l0oooo
0P3no_h;0?ooo`@000000P010@4400000?l0ooooL@3oool00?l0ooooOP3oool20?knoPT00000?`3o
ool20?knoP/0oooo1000000200410@@00000o`3oooma0?ooo`00o`3ooon00?ooo`T00000BP3oool6
000000800@410P00003o0?ooog<0oooo003o0?oooh00oooo2@00001:0?ooo`H000000P010@420000
0?l0ooooL`3oool00?l0ooooP03oool9000004X0oooo2P00003o0?ooog<0oooo003o0?oooh00oooo
2@00001:0?ooo`X00000o`3ooomc0?ooo`00o`3ooon00?ooo`T00000=`3oool20?knoPl0oooo2P00
003o0?ooogD0oooo003o0?oooh00oooo2@00000g0?ooo`80o_kn3`3oool:00000?l0ooooM@3oool0
0?l0ooooP03oool9000004H0oooo3000003o0?ooogD0oooo003o0?oooh00oooo2@0000160?ooo``0
0000o`3ooome0?ooo`00o`3ooon00?ooo`T00000=`3oool20?knoP@0oooo0P3no_h70?ooo`X00000
o`3ooomg0?ooo`00o`3ooon00?ooo`T00000=`3oool20?knoP@0oooo0P3no_h70?ooo`X00000o`3o
oomg0?ooo`00o`3ooon00?ooo`T00000@`3oool;00000?l0ooooN@3oool00?l0ooooP03oool90000
04<0oooo2`00003o0?ooogT0oooo003o0?oooh00oooo2@0000130?ooo`/00000o`3ooomi0?ooo`00
o`3ooon00?ooo`T00000@`3oool;00000?l0ooooN@3oool00?l0ooooP03oool900000440oooo2`00
003o0?ooog/0oooo003o0?oooh00oooo2@0000110?ooo`/00000o`3ooomk0?ooo`00o`3ooon00?oo
o`T00000?`3oool=000000X0oooo0P3no_ko0?ooofl0oooo003o0?oooh00oooo2@00000o0?ooo`d0
00002P3oool20?kno_l0ooooK`3oool00?l0ooooP03oool9000003l0oooo2`00003o0?ooogd0oooo
003o0?oooh00oooo2@00000o0?ooo`/00000o`3ooomm0?ooo`00o`3ooon00?ooo`T00000?@3oool;
000000X0oooo0P3no_ko0?ooog<0oooo003o0?oooh00oooo2@00000m0?ooo`/000002P3oool20?kn
o_l0ooooL`3oool00?l0ooooP03oool9000003d0oooo1P00000300410@8000001P3oool20?kno_l0
ooooM`3oool00?l0ooooP03oool9000003d0oooo1P00000300410@8000001P3oool20?kno_l0oooo
M`3oool00?l0ooooP03oool9000003/0oooo2`00003o0?oooh40oooo003o0?oooh00oooo2@00000k
0?ooo`/00000o`3ooon10?ooo`00o`3ooon00?ooo`T00000>@3oool=00000?l0ooooP@3oool00?l0
ooooP03oool9000003T0oooo3@00003o0?oooh40oooo003o0?oooh00oooo2@00000i0?ooo`X00000
o`3ooon40?ooo`00o`3ooon00?ooo`T00000>@3oool:00000?l0ooooQ03oool00?l0ooooP03oool9
000003T0oooo2P00003o0?oooh@0oooo003o0?oooh00oooo2@00000a0?ooo`80o_kn103oool:0000
0?l0ooooQP3oool00?l0ooooP03oool900000340oooo0P3no_h40?ooo`X00000o`3ooon60?ooo`00
o`3ooon00?ooo`T00000=`3oool:00000?l0ooooQP3oool00?l0ooooP03oool9000003L0oooo2P00
003o0?ooohH0oooo003o0?oooh00oooo2@00000a0?ooo`80o_kn0P3oool:00000?l0ooooR03oool0
0?l0ooooP03oool900000340oooo0P3no_h20?ooo`X00000o`3ooon80?ooo`00o`3ooon00?ooo`T0
00009`3oool20?knoPX0oooo3000003o0?ooohP0oooo003o0?oooh00oooo2@00000W0?ooo`80o_kn
2P3oool<00000?l0ooooR03oool00?l0ooooP03oool9000002L0oooo0P3no_h:0?ooo`800@412000
003o0?ooohX0oooo003o0?oooh00oooo2@00000W0?ooo`80o_kn2P3oool200410@P00000o`3ooon:
0?ooo`00o`3ooon00?ooo`T00000<@3oool:00000?l0ooooS03oool00?l0ooooP03oool900000340
oooo2P00003o0?oooh`0oooo003o0?oooh00oooo2@00000a0?ooo`X00000o`3ooon<0?ooo`00o`3o
oon00?ooo`T00000<@3oool:00000?l0ooooS03oool00?l0ooooP03oool9000002l0oooo2P00003o
0?ooohh0oooo003o0?oooh00oooo2@00000_0?ooo`X00000o`3ooon>0?ooo`00o`3ooonf0?ooo``0
00001P3oool20?kno_l0ooooQP3oool00?l0oooo]P3oool<000000H0oooo0P3no_ko0?ooohH0oooo
003o0?oookH0oooo2P00003o0?oooi00oooo003o0?oookH0oooo2P00003o0?oooi00oooo003o0?oo
ok@0oooo2P00003o0?oooi80oooo003o0?oook@0oooo2P00003o0?oooi80oooo003o0?oook@0oooo
0P010@42000000800@411000003o0?oooi80oooo003o0?oook@0oooo0P010@42000000800@411000
003o0?oooi80oooo003o0?oook80oooo2P00003o0?oooi@0oooo003o0?oook80oooo2P00003o0?oo
oi@0oooo003o0?oook00oooo3000003o0?oooi@0oooo003o0?oook00oooo3000003o0?oooi@0oooo
003o0?oook00oooo2P00003o0?oooiH0oooo003o0?oook00oooo2P00003o0?oooiH0oooo003o0?oo
ojX0oooo103no_h6000000800@410P00003o0?oooiP0oooo003o0?ooojX0oooo103no_h600000080
0@410P00003o0?oooiP0oooo003o0?ooojh0oooo2P00003o0?oooiP0oooo003o0?ooojh0oooo2P00
003o0?oooiP0oooo003o0?oooj`0oooo2P00003o0?oooiX0oooo003o0?oooj`0oooo2P00003o0?oo
oiX0oooo003o0?ooojX0oooo3000003o0?oooiX0oooo003o0?ooojX0oooo3000003o0?oooiX0oooo
003o0?ooojX0oooo3000003o0?oooiX0oooo003o0?ooojX0oooo2P00003o0?oooi`0oooo003o0?oo
ojX0oooo2P00003o0?oooi`0oooo003o0?ooojP0oooo2P00003o0?oooih0oooo003o0?ooojP0oooo
2P00003o0?oooih0oooo003o0?oooh00oooo2@00000O0?ooo`X00000o`3ooonN0?ooo`00o`3ooon0
0?ooo`T000007`3oool:00000?l0ooooWP3oool00?l0ooooP03oool9000001P0oooo0P3no_h20?oo
o`D000000P010@4400000?l0ooooX03oool00?l0ooooP03oool9000001P0oooo0P3no_h20?ooo`D0
00000P010@4400000?l0ooooX03oool00?l0ooooP03oool9000001X0oooo3@00003o0?oooj00oooo
003o0?oooh00oooo2@00000J0?ooo`d00000o`3ooonP0?ooo`00o`3ooon00?ooo`T000003P3oool2
0?knoPX0oooo1@00000200410@@00000o`3ooonR0?ooo`00o`3ooon00?ooo`T000003P3oool20?kn
oPX0oooo1@00000200410@@00000o`3ooonR0?ooo`00o`3ooon00?ooo`T00000603oool700000080
0@410P00003o0?oooj@0oooo003o0?oooh00oooo2@00000H0?ooo`L000000P010@4200000?l0oooo
Y03oool00?l0ooooP03oool9000001P0oooo2`00003o0?oooj@0oooo003o0?oooh00oooo2@00000H
0?ooo`/00000o`3ooonT0?ooo`00o`3ooon00?ooo`T000001P3oool20?knoPh0oooo2`00003o0?oo
ojH0oooo003o0?oooh00oooo2@0000060?ooo`80o_kn3P3oool;00000?l0ooooYP3oool00?l0oooo
P03oool9000001@0oooo3@00003o0?ooojH0oooo003o0?oooh00oooo2@00000D0?ooo`d00000o`3o
oonV0?ooo`00o`3ooon00?ooo`T000001P3oool20?knoP@0oooo0P3no_h60?ooo`/00000o`3ooonX
0?ooo`00o`3ooon00?ooo`T000001P3oool20?knoP@0oooo0P3no_h60?ooo`/00000o`3ooonX0?oo
o`00o`3ooon00?ooo`T000004P3oool:00000?l0ooooZ`3oool00?l0ooooP03oool900000180oooo
2P00003o0?oooj/0oooo003o0?oooh00oooo2@00000B0?ooo`X00000o`3ooon[0?ooo`00o`3ooon0
0?ooo`T000004P3oool:00000?l0ooooZ`3oool00?l0ooooP03oool900000100oooo2P00003o0?oo
ojd0oooo003o0?oooh00oooo2@00000@0?ooo`X00000o`3ooon]0?ooo`00o`3ooon00?ooo`T00000
3P3oool<000000/0oooo0P3no_ko0?oooj00oooo003o0?oooh00oooo2@00000>0?ooo``000002`3o
ool20?kno_l0ooooX03oool00?l0ooooP03oool9000000h0oooo2P00003o0?ooojl0oooo003o0?oo
oh00oooo2@00000>0?ooo`X00000o`3ooon_0?ooo`00o`3ooon00?ooo`T00000303oool:000000/0
oooo0P3no_ko0?oooj@0oooo003o0?oooh00oooo2@00000<0?ooo`X000002`3oool20?kno_l0oooo
Y03oool00?l0ooooP03oool9000000`0oooo1P00000200410@8000001P3oool30?kno_l0ooooZ03o
ool00?l0ooooP03oool9000000`0oooo1P00000200410@8000001P3oool30?kno_l0ooooZ03oool0
0?l0ooooP03oool9000000`0oooo1P00000200410@8000001P3oool30?kno_l0ooooZ03oool00?l0
ooooP03oool9000000X0oooo2P00003o0?oook<0oooo003o0?oooh00oooo2@00000:0?ooo`X00000
o`3ooonc0?ooo`00o`3ooon00?ooo`T00000203oool<00000?l0oooo/`3oool00?l0ooooP03oool9
000000P0oooo3000003o0?oook<0oooo003o0?oooh00oooo1@00000200410@800000203oool:0000
0?l0oooo]@3oool00?l0ooooP03oool5000000800@410P0000080?ooo`X00000o`3ooone0?ooo`00
o`3ooon00?ooo`T000000P3no_h40?ooo`X00000o`3ooong0?ooo`00o`3ooon00?ooo`T000000P3n
o_h40?ooo`X00000o`3ooong0?ooo`00o`3ooon00?ooo`T000001P3oool:00000?l0oooo]`3oool0
0?l0ooooP03oool9000000H0oooo2P00003o0?oookL0oooo003o0?oooh00oooo2@0000020?knoP80
oooo2P00003o0?oookT0oooo003o0?oooh00oooo2@0000020?knoP80oooo2P00003o0?oookT0oooo
003o0?ooogh0oooo0P3no_h900000080oooo3000003o0?oookT0oooo003o0?ooogh0oooo0P3no_h9
00000080oooo3000003o0?oookT0oooo003o0?ooogh0oooo0P3no_h300410@H000000P3oool20041
0@P00000o`3ooonk0?ooo`00o`3ooomn0?ooo`80o_kn0`010@4600000080oooo0P010@4800000?l0
oooo^`3oool00?l0ooooP03ooolC00000?l0oooo_@3oool00?l0ooooP03ooolC00000?l0oooo_@3o
ool001X0oooo0P3no_h?0?ooo``00000303oool20?knoR40oooo2P00000b0?ooo``000004`3oool2
0?knoQ`0oooo3@00000<0?ooo`80o_kn8`3oool:00000080o_kn;@3oool=00000180oooo0P3no_hA
0?ooo`X000000P3oool<000000d0oooo0P3no_hQ0?ooo``00000<@3oool=00000340oooo30000004
0?ooo`80o_kn:@3oool;00000080o_kn;`3oool<00000800oooo000J0?ooo`80o_kn3`3oool<0000
00`0oooo0P3no_hQ0?ooo`X00000<P3oool<000001<0oooo0P3no_hL0?ooo`d00000303oool20?kn
oR<0oooo2P0000020?knoRd0oooo3@00000B0?ooo`80o_kn4@3oool:00000080oooo3000000=0?oo
o`80o_kn8@3oool<00000340oooo3@00000a0?ooo``00000103oool20?knoRT0oooo2`0000020?kn
oRl0oooo300000200?ooo`006P3ooolK000000800@41SP00000200410B<000000P010@4k00000080
0@41D000000200410B<000000P010@5l000000800@41>`00000200410AD000000P010@4O00000080
0@41?@00000200410B400000F`3oool001X0oooo6`00000200410Hh000000P010@4S000000800@41
>`00000200410E0000000P010@4S000000800@41O000000200410C/000000P010@4E000000800@41
7`00000200410Cd000000P010@4Q000005/0oooo000J0?ooof<000000P010@6i000000800@41XP00
000200410@h000000P010@5a000000800@41@000000200410E000000F`3oool001X0ooooH`000002
00410KT000000P010@6R000000800@413P00000200410G4000000P010@50000000800@41D000001K
0?ooo`006P3ooon2000000@00@412000000200410JH0000010010@49000000800@418`0000040041
0M4000000P010@6>000000800@412P00001K0?ooo`006P3ooon2000000@00@412000000200410JH0
000010010@49000000800@418`00000400410M4000000P010@6>000000800@412P00001K0?ooo`00
6P3ooolA000000800@41@@00000200410@L000000P010@5V000000800@41@P00000200410@X00000
1@010@6`000000@00@41:`00000200410ET000000P010@4M000000800@412P00000400410B/00000
0P010@4Y000005/0oooo000J0?oooa4000000P010@51000000800@411`00000200410FH000000P01
0@52000000800@412P00000500410K00000010010@4[000000800@41F@00000200410Ad000000P01
0@4:000000@00@41:`00000200410BT00000F`3oool002T0oooo0P3no_h:0?ooo``000000P3oool2
0?knoR/0oooo2`00000[0?ooo`80o_kn103oool<000002D0oooo0P3no_h;0?ooo``000000P3oool2
0?knoRd0oooo0P00000200410@H00000:P3oool20?knoP@0oooo3000000O0?ooo`80o_kn403oool=
00000080oooo0P3no_hW0?ooo`80o_kn0P3oool<00000340oooo3@00000a0?ooo``00000<03oool2
000000800@411P00000a0?ooo``00000MP3oool002T0oooo0P3no_h:0?ooo``000000P3oool20?kn
oR/0oooo2`00000[0?ooo`80o_kn103oool<000002D0oooo0P3no_h;0?ooo``000000P3oool20?kn
oRd0oooo0P00000200410@H00000:P3oool20?knoP@0oooo3000000O0?ooo`80o_kn403oool=0000
0080oooo0P3no_hW0?ooo`80o_kn0P3oool<00000340oooo3@00000a0?ooo``00000<03oool20000
00800@411P00000a0?ooo``00000MP3oool001`0oooo0P3no_h80?ooo`<0o_kn3P3oool400000080
0@411P00000_0?ooo`/00000<@3oool<00000240oooo0P3no_h?0?ooo`@000000P010@46000002<0
oooo0P3no_h<0?ooo`/00000;`3oool<00000340oooo1000000300410@H00000;`3oool<000002T0
oooo0P3no_h70?ooo``00000<@3oool<00000240oooo0P3no_h=0?ooo`X00000:@3oool20?knoPH0
oooo3@00001c0?ooo`00703oool20?knoPP0oooo0`3no_h>0?ooo`@000000P010@46000002l0oooo
2`00000a0?ooo``000008@3oool20?knoPl0oooo1000000200410@H000008`3oool20?knoP`0oooo
2`00000_0?ooo``00000<@3oool4000000<00@411P00000_0?ooo``00000:@3oool20?knoPL0oooo
3000000a0?ooo``000008@3oool20?knoPd0oooo2P00000Y0?ooo`80o_kn1P3oool=000007<0oooo
000i0?ooo``00000:@3oool20?knoPD0oooo2P00000U0?ooo`80o_kn2P3oool<000000T0oooo0P3n
o_hW0?ooo``00000<@3oool;00000280oooo0`3no_h:0?ooo``00000203oool20?knoPl0oooo0P3n
o_hF0?ooo`d00000;`3oool200410@X000008@3oool20?knoPl0oooo3000000a0?ooo``00000<03o
ool:00000240oooo0P3no_h>0?ooo`d000002P3oool20?knoVD0oooo000i0?ooo``00000:@3oool2
0?knoPD0oooo2P00000U0?ooo`80o_kn2P3oool<000000T0oooo0P3no_hW0?ooo``00000<@3oool;
00000280oooo0`3no_h:0?ooo``00000203oool20?knoPl0oooo0P3no_hF0?ooo`d00000;`3oool2
00410@X000008@3oool20?knoPl0oooo3000000a0?ooo``00000<03oool:00000240oooo0P3no_h>
0?ooo`d000002P3oool20?knoVD0oooo000L0?ooo`80o_kn6@3oool20?knoP80oooo3000000`0?oo
o`X00000103oool20?knoR/0oooo3000000C0?ooo`80o_kn6@3oool20?knoP80oooo3000000a0?oo
o`/00000403oool20?knoQd0oooo3000000C0?ooo`80o_kn603oool20?knoP80oooo2`0000020041
0@80oooo0P3no_h20?ooo`80o_kn9`3oool<00000140oooo0P3no_hD0?ooo`80o_kn2@3oool<0000
00H0oooo0P3no_hY0?ooo`d00000;`3oool:00000100oooo0`3no_hD0?ooo`80o_kn203oool=0000
00H0oooo0P3no_iW0?ooo`00703oool20?knoQT0oooo0P3no_h20?ooo``00000<03oool:000000@0
oooo0P3no_h[0?ooo``000004`3oool20?knoQT0oooo0P3no_h20?ooo``00000<@3oool;00000100
oooo0P3no_hM0?ooo``000004`3oool20?knoQP0oooo0P3no_h20?ooo`/000000P010@420?ooo`80
o_kn0P3oool20?knoRL0oooo3000000A0?ooo`80o_kn503oool20?knoPT0oooo300000060?ooo`80
o_kn:@3oool=000002l0oooo2P00000@0?ooo`<0o_kn503oool20?knoPP0oooo3@0000060?ooo`80
o_knI`3oool001`0oooo0P3no_hI0?ooo`80o_kn0P3oool<00000300oooo2P0000040?ooo`80o_kn
:`3oool<000001<0oooo0P3no_hI0?ooo`80o_kn0P3oool<00000340oooo2`00000@0?ooo`80o_kn
7@3oool<000001<0oooo0P3no_hH0?ooo`80o_kn0P3oool;000000800@410P3oool20?knoP80oooo
0P3no_hW0?ooo``000004@3oool20?knoQ@0oooo0P3no_h90?ooo``000001P3oool20?knoRT0oooo
3@00000_0?ooo`X00000403oool30?knoQ@0oooo0P3no_h80?ooo`d000001P3oool20?knoVL0oooo
000D0?ooo`80o_kn9`3oool<00000300oooo2P00000a0?ooo`800@412`0000080?ooo`80o_kn9`3o
ool<00000340oooo2`0000020?ooo`80o_kn303oool20?knoQd0oooo0P010@4:000000P0oooo0P3n
o_hX0?ooo``00000;`3oool<00000080oooo0P3no_h=0?ooo`80o_kn7`3oool<00000340oooo3@00
000_0?ooo`X000000P3oool20?knoPd0oooo0P3no_hN0?ooo`d00000K@3oool001@0oooo0P3no_hW
0?ooo``00000<03oool:00000340oooo0P010@4;000000P0oooo0P3no_hW0?ooo``00000<@3oool;
00000080oooo0P3no_h<0?ooo`80o_kn7@3oool200410@X00000203oool20?knoRP0oooo3000000_
0?ooo``000000P3oool20?knoPd0oooo0P3no_hO0?ooo``00000<@3oool=000002l0oooo2P000002
0?ooo`80o_kn3@3oool20?knoQh0oooo3@00001]0?ooo`00?`3oool200410@X000000`3oool20?kn
oR/0oooo2P00000a0?ooo`/000000P010@4a0?ooo`800@412P0000020?ooo`80o_kn;@3oool50000
00800@411000000:0?ooo`80o_kn8`3oool:000000800@41<P3oool200410@X00000;`3oool60000
00800@411000000;0?ooo`80o_kn9@3oool<00000340oooo3@0000020?ooo`80o_kn:`3oool40000
00800@411000000:0?ooo`80o_kn9@3oool=000006/0oooo000o0?ooo`800@412P0000030?ooo`80
o_kn:`3oool:00000340oooo2`00000200410C40oooo0P010@4:00000080oooo0P3no_h]0?ooo`D0
00000P010@44000000X0oooo0P3no_hS0?ooo`X000000P010@4b0?ooo`800@412P00000_0?ooo`H0
00000P010@44000000/0oooo0P3no_hU0?ooo``00000<@3oool=00000080oooo0P3no_h[0?ooo`@0
00000P010@44000000X0oooo0P3no_hU0?ooo`d00000J`3oool001P0oooo0P3no_h80?ooo`80o_kn
7@3oool=00000080oooo0P3no_h[0?ooo`X00000<@3oool;000000800@41203oool20?knoPP0oooo
0P3no_hM0?ooo``000000P3oool20?knoRh0oooo2P0000060?ooo`80o_kn9`3oool:000000800@41
2@3oool20?knoPP0oooo0P3no_hM0?ooo`h00000;@3oool<000000L0oooo0P3no_hY0?ooo``00000
:`3oool20?knoP@0oooo3@00000_0?ooo`X000001P3oool20?knoRT0oooo3@00001Y0?ooo`00603o
ool20?knoPP0oooo0P3no_hM0?ooo`d000000P3oool20?knoR/0oooo2P00000a0?ooo`/000000P01
0@480?ooo`80o_kn203oool20?knoQd0oooo300000020?ooo`80o_kn;P3oool:000000H0oooo0P3n
o_hW0?ooo`X000000P010@490?ooo`80o_kn203oool20?knoQd0oooo3P00000]0?ooo``000001`3o
ool20?knoRT0oooo3000000[0?ooo`80o_kn103oool=000002l0oooo2P0000060?ooo`80o_kn:@3o
ool=000006T0oooo000k0?ooo`80o_kn1P3oool=000002l0oooo2P0000040?ooo`80o_kn:`3oool=
000002T0oooo0P3no_h60?ooo``00000:`3oool20?knoPD0oooo2P00000_0?ooo``00000:@3oool3
0?knoPH0oooo3P00000Y0?ooo`80o_kn0P3oool=000001`0oooo0P3no_h90?ooo`80o_kn203oool2
00410@X00000<@3oool=000002T0oooo0P3no_h40?ooo`X000007@3oool20?knoPP0oooo0P3no_h9
0?ooo`800@412P00001W0?ooo`00>`3oool20?knoPH0oooo3@00000_0?ooo`X00000103oool20?kn
oR/0oooo3@00000Y0?ooo`80o_kn1P3oool<000002/0oooo0P3no_h50?ooo`X00000;`3oool<0000
02T0oooo0`3no_h60?ooo`h00000:@3oool20?knoP80oooo3@00000L0?ooo`80o_kn2@3oool20?kn
oPP0oooo0P010@4:00000340oooo3@00000Y0?ooo`80o_kn103oool:000001d0oooo0P3no_h80?oo
o`80o_kn2@3oool200410@X00000I`3oool003T0oooo0P3no_h:0?ooo`@000000P010@47000002l0
oooo2P00000a0?ooo`d000009@3oool20?knoPX0oooo1000000200410@H00000:`3oool30?knoP@0
oooo2000000200410Bl0oooo3000000U0?ooo`80o_kn2`3oool>000002T0oooo0P3no_h20?ooo`/0
00000P010@4a0?ooo`800@412P00000a0?ooo`d00000:@3oool20?knoP@0oooo2000000200410C80
oooo0P010@4:000006D0oooo000i0?ooo`80o_kn2P3oool4000000800@411`00000_0?ooo`X00000
<@3oool=000002D0oooo0P3no_h:0?ooo`@000000P010@46000002/0oooo0`3no_h40?ooo`P00000
0P010@4_0?ooo``000009@3oool20?knoP/0oooo3P00000Y0?ooo`80o_kn0P3oool;000000800@41
<@3oool200410@X00000<@3oool=000002T0oooo0P3no_h40?ooo`P000000P010@4b0?ooo`800@41
2P00001U0?ooo`00503oool2000001l0oooo0P3no_h<0?ooo`80o_kn0P3oool=000002l0oooo2P00
000a0?ooo`d000007`3oool20?knoP`0oooo0P3no_h20?ooo``00000<P3oool:000002l0oooo3000
000O0?ooo`80o_kn3@3oool20?knoP@0oooo3000000]0?ooo`d000009`3oool20?knoPP0oooo2P00
000200410C80oooo1000000200410@H00000;`3oool:000002L0oooo0P3no_h90?ooo`X000000P01
0@5S0?ooo`00503oool2000001l0oooo0P3no_h<0?ooo`80o_kn0P3oool=000002l0oooo2P00000a
0?ooo`d000007`3oool20?knoP`0oooo0P3no_h20?ooo``00000<P3oool:000002l0oooo3000000O
0?ooo`80o_kn3@3oool20?knoP@0oooo3000000]0?ooo`d000009`3oool20?knoPP0oooo2P000002
00410C80oooo1000000200410@H00000;`3oool:000002L0oooo0P3no_h90?ooo`X000000P010@5S
0?ooo`00503oool4000000P0oooo0P3no_hE0?ooo`80o_kn403oool=000002l0oooo2P00000Y0?oo
o`80o_kn1`3oool<000000P0oooo0P3no_hE0?ooo`80o_kn403oool<00000380oooo2P0000020?oo
o`80o_kn8`3oool20?knoPH0oooo3@0000080?ooo`80o_kn503oool20?knoQ<0oooo3000000]0?oo
o`d000000P3oool20?knoQP0oooo0`3no_hB0?ooo``00000<P3oool<000002l0oooo2P0000020?oo
o`<0o_kn603oool20?knoQ<0oooo3000001Q0?ooo`00503oool4000000P0oooo0P3no_hE0?ooo`80
o_kn403oool=000002l0oooo2P00000Y0?ooo`80o_kn1`3oool<000000P0oooo0P3no_hE0?ooo`80
o_kn403oool<00000380oooo2P0000020?ooo`80o_kn8`3oool20?knoPH0oooo3@0000080?ooo`80
o_kn503oool20?knoQ<0oooo3000000]0?ooo`d000000P3oool20?knoQP0oooo0`3no_hB0?ooo``0
0000<P3oool<000002l0oooo2P0000020?ooo`<0o_kn603oool20?knoQ<0oooo3000001Q0?ooo`00
503oool6000001<0oooo0P3no_hH0?ooo`80o_kn0P3oool=000002l0oooo2P0000040?ooo`80o_kn
;03oool<00000180oooo0P3no_hI0?ooo`80o_kn0P3oool<00000380oooo2P00000@0?ooo`<0o_kn
703oool=00000180oooo0P3no_hO0?ooo``00000;@3oool=00000100oooo0P3no_hE0?ooo`80o_kn
203oool<000000L0oooo0P3no_hY0?ooo``00000;`3oool:00000140oooo0P3no_hD0?ooo`<0o_kn
203oool<000000H0oooo0P3no_iG0?ooo`00503oool6000001<0oooo0P3no_hH0?ooo`80o_kn0P3o
ool=000002l0oooo2P0000040?ooo`80o_kn;03oool<00000180oooo0P3no_hI0?ooo`80o_kn0P3o
ool<00000380oooo2P00000@0?ooo`<0o_kn703oool=00000180oooo0P3no_hO0?ooo``00000;@3o
ool=00000100oooo0P3no_hE0?ooo`80o_kn203oool<000000L0oooo0P3no_hY0?ooo``00000;`3o
ool:00000140oooo0P3no_hD0?ooo`<0o_kn203oool<000000H0oooo0P3no_iG0?ooo`00503oool8
000000P0oooo0P3no_hX0?ooo``00000;`3oool:00000380oooo0P010@4:000000P0oooo0P3no_hW
0?ooo`d00000<@3oool:00000080oooo0P3no_h=0?ooo`80o_kn703oool200410@/00000203oool2
0?knoRT0oooo3000000]0?ooo`d000000P3oool20?knoP`0oooo0P3no_hO0?ooo``00000<P3oool<
000002l0oooo2`0000020?ooo`80o_kn303oool20?knoQl0oooo3000001M0?ooo`00503oool80000
00P0oooo0P3no_hX0?ooo``00000;`3oool:00000380oooo0P010@4:000000P0oooo0P3no_hW0?oo
o`d00000<@3oool:00000080oooo0P3no_h=0?ooo`80o_kn703oool200410@/00000203oool20?kn
oRT0oooo3000000]0?ooo`d000000P3oool20?knoP`0oooo0P3no_hO0?ooo``00000<P3oool<0000
02l0oooo2`0000020?ooo`80o_kn303oool20?knoQl0oooo3000001M0?ooo`00503oool800000080
0@41<P3oool200410@X000000P3oool20?knoR/0oooo2P00000b0?ooo`X000000P010@4a0?ooo`80
0@412`0000020?ooo`80o_kn;@3oool4000000800@411000000:0?ooo`80o_kn8`3oool;00000080
0@41<`3oool<00000080oooo0P3no_hZ0?ooo`H000000P010@44000000X0oooo0P3no_hU0?ooo``0
0000<P3oool<00000080oooo0P3no_h[0?ooo`@000000P010@45000000X0oooo0P3no_hU0?ooo``0
0000F`3oool001@0oooo2000000200410C80oooo0P010@4:00000080oooo0P3no_h[0?ooo`X00000
<P3oool:000000800@41<@3oool200410@/000000P3oool20?knoRd0oooo1000000200410@@00000
2P3oool20?knoR<0oooo2`00000200410C<0oooo300000020?ooo`80o_kn:P3oool6000000800@41
1000000:0?ooo`80o_kn9@3oool<00000380oooo300000020?ooo`80o_kn:`3oool4000000800@41
1@00000:0?ooo`80o_kn9@3oool<000005/0oooo000D0?ooo`X000000P010@490?ooo`80o_kn203o
ool20?knoQd0oooo300000020?ooo`80o_kn:`3oool:00000380oooo2P00000200410@P0oooo0P3n
o_h90?ooo`80o_kn703oool=00000080oooo0P3no_h]0?ooo`X000001P3oool20?knoRL0oooo2`00
000200410@P0oooo0P3no_h80?ooo`80o_kn6@3oool20?knoP@0oooo3000000^0?ooo``000001P3o
ool20?knoRT0oooo3@00000[0?ooo`80o_kn103oool<000002l0oooo2`0000060?ooo`80o_kn:@3o
ool<000005T0oooo000D0?ooo`X000000P010@490?ooo`80o_kn203oool20?knoQd0oooo30000002
0?ooo`80o_kn:`3oool:00000380oooo2P00000200410@P0oooo0P3no_h90?ooo`80o_kn703oool=
00000080oooo0P3no_h]0?ooo`X000001P3oool20?knoRL0oooo2`00000200410@P0oooo0P3no_h8
0?ooo`80o_kn6@3oool20?knoP@0oooo3000000^0?ooo``000001P3oool20?knoRT0oooo3@00000[
0?ooo`80o_kn103oool<000002l0oooo2`0000060?ooo`80o_kn:@3oool<000005T0oooo000F0?oo
o``00000:@3oool30?knoPH0oooo3000000_0?ooo`X000001@3oool20?knoR/0oooo3000000Y0?oo
o`80o_kn1P3oool=000002/0oooo0P3no_h40?ooo`X00000;`3oool=000003<0oooo3000000Z0?oo
o`80o_kn0P3oool<000001d0oooo0P3no_h80?ooo`80o_kn203oool200410@/00000<@3oool<0000
02T0oooo0P3no_h40?ooo`/00000703oool20?knoPT0oooo0P3no_h80?ooo`800@412P0000060?oo
o`<0o_knCP3oool001H0oooo3000000Y0?ooo`<0o_kn1P3oool<000002l0oooo2P0000050?ooo`80
o_kn:`3oool<000002T0oooo0P3no_h60?ooo`d00000:`3oool20?knoP@0oooo2P00000_0?ooo`d0
0000<`3oool<000002X0oooo0P3no_h20?ooo``000007@3oool20?knoPP0oooo0P3no_h80?ooo`80
0@412`00000a0?ooo``00000:@3oool20?knoP@0oooo2`00000L0?ooo`80o_kn2@3oool20?knoPP0
oooo0P010@4:000000H0oooo0`3no_i>0?ooo`00603oool<000002D0oooo0P3no_h;0?ooo`@00000
0P010@46000002l0oooo2`00000a0?ooo``000009@3oool20?knoPX0oooo1@00000200410@H00000
:`3oool20?knoP@0oooo2000000200410C00oooo3000000c0?ooo`d00000:@3oool20?knoP80oooo
2P00000200410C40oooo0P010@4;00000340oooo3000000Y0?ooo`80o_kn103oool9000000800@41
<@3oool200410@X00000E@3oool001P0oooo3000000U0?ooo`80o_kn2`3oool4000000800@411P00
000_0?ooo`/00000<@3oool<000002D0oooo0P3no_h:0?ooo`D000000P010@46000002/0oooo0P3n
o_h40?ooo`P000000P010@4`0?ooo``00000<`3oool=000002T0oooo0P3no_h20?ooo`X000000P01
0@4a0?ooo`800@412`00000a0?ooo``00000:@3oool20?knoP@0oooo2@00000200410C40oooo0P01
0@4:000005D0oooo000J0?ooo``000007`3oool20?knoPd0oooo0P3no_h20?ooo``00000;`3oool;
00000340oooo3000000O0?ooo`80o_kn303oool20?knoP80oooo3@00000a0?ooo`X00000<03oool<
000003<0oooo1000000200410@L00000;@3oool<000002L0oooo0P3no_h80?ooo`/000000P010@4a
0?ooo`@000000P010@4600000300oooo2P00000W0?ooo`80o_kn203oool:000005D0oooo000J0?oo
o``000007`3oool20?knoPd0oooo0P3no_h20?ooo``00000;`3oool;00000340oooo3000000O0?oo
o`80o_kn303oool20?knoP80oooo3@00000a0?ooo`X00000<03oool<000003<0oooo100000020041
0@L00000;@3oool<000002L0oooo0P3no_h80?ooo`/000000P010@4a0?ooo`@000000P010@460000
0300oooo2P00000W0?ooo`80o_kn203oool:000005D0oooo000D0?ooo`80o_kn1P3oool=000000P0
oooo0P3no_hD0?ooo`80o_kn4@3oool<000002l0oooo2`00000Y0?ooo`80o_kn1P3oool<000000P0
oooo0`3no_hD0?ooo`80o_kn4@3oool<00000340oooo2P0000020?ooo`<0o_kn8P3oool20?knoPL0
oooo300000080?ooo`80o_kn:@3oool=000002d0oooo300000020?ooo`80o_kn6@3oool20?knoQ80
oooo3@00000a0?ooo``00000<03oool:00000080oooo0P3no_hI0?ooo`80o_kn4P3oool8000000@0
oooo0`3no_h20?ooo`80o_knBP3oool001@0oooo0P3no_h60?ooo`d00000203oool20?knoQ@0oooo
0P3no_hA0?ooo``00000;`3oool;000002T0oooo0P3no_h60?ooo``00000203oool30?knoQ@0oooo
0P3no_hA0?ooo``00000<@3oool:00000080oooo0`3no_hR0?ooo`80o_kn1`3oool<000000P0oooo
0P3no_hY0?ooo`d00000;@3oool<00000080oooo0P3no_hI0?ooo`80o_kn4P3oool=00000340oooo
3000000`0?ooo`X000000P3oool20?knoQT0oooo0P3no_hB0?ooo`P00000103oool30?knoP80oooo
0P3no_i:0?ooo`007P3oool=00000180oooo0P3no_hI0?ooo`80o_kn0P3oool<000002l0oooo2`00
00040?ooo`80o_kn:`3oool<000001<0oooo0P3no_hH0?ooo`<0o_kn0P3oool<00000340oooo2P00
000A0?ooo`80o_kn7@3oool<000003<0oooo3@00000]0?ooo``000004@3oool20?knoQ@0oooo0P3n
o_h80?ooo`d000001P3oool20?knoRT0oooo3000000`0?ooo`X00000403oool20?knoQD0oooo0P3n
o_h80?ooo`H00000103oool30?knoP80oooo0P3no_i:0?ooo`007P3oool=00000180oooo0P3no_hI
0?ooo`80o_kn0P3oool<000002l0oooo2`0000040?ooo`80o_kn:`3oool<000001<0oooo0P3no_hH
0?ooo`<0o_kn0P3oool<00000340oooo2P00000A0?ooo`80o_kn7@3oool<000003<0oooo3@00000]
0?ooo``000004@3oool20?knoQ@0oooo0P3no_h80?ooo`d000001P3oool20?knoRT0oooo3000000`
0?ooo`X00000403oool20?knoQD0oooo0P3no_h80?ooo`H00000103oool30?knoP80oooo0P3no_i:
0?ooo`00803oool200410@/00000203oool20?knoRL0oooo3000000_0?ooo`/00000<@3oool20041
0@X000002@3oool20?knoRL0oooo3000000a0?ooo`/000000P3oool20?knoP`0oooo0P3no_hM0?oo
o`800@412P00000c0?ooo`d00000;@3oool<00000080oooo0P3no_h=0?ooo`80o_kn7`3oool<0000
0340oooo3000000`0?ooo`X000000P3oool20?knoP`0oooo0P3no_hO0?ooo`@00000E@3oool00200
oooo0P010@4;000000P0oooo0P3no_hW0?ooo``00000;`3oool;00000340oooo0P010@4:000000T0
oooo0P3no_hW0?ooo``00000<@3oool;00000080oooo0P3no_h<0?ooo`80o_kn7@3oool200410@X0
0000<`3oool=000002d0oooo300000020?ooo`80o_kn3@3oool20?knoQl0oooo3000000a0?ooo``0
0000<03oool:00000080oooo0P3no_h<0?ooo`80o_kn7`3oool4000005D0oooo000R0?ooo`/00000
0P010@4a0?ooo`800@412P0000020?ooo`80o_kn;03oool:00000340oooo2P00000200410C80oooo
0P010@4:00000080oooo0P3no_h]0?ooo`@000000P010@45000000X0oooo0P3no_hS0?ooo`@00000
0P010@4800000340oooo3@0000020?ooo`80o_kn:@3oool6000000800@411000000;0?ooo`80o_kn
9@3oool<00000340oooo3@0000020?ooo`80o_kn:`3oool4000000800@411000000:0?ooo`80o_kn
9@3oool2000005D0oooo000R0?ooo`/000000P010@4a0?ooo`800@412P0000020?ooo`80o_kn;03o
ool:00000340oooo2P00000200410C80oooo0P010@4:00000080oooo0P3no_h]0?ooo`@000000P01
0@45000000X0oooo0P3no_hS0?ooo`@000000P010@4800000340oooo3@0000020?ooo`80o_kn:@3o
ool6000000800@411000000;0?ooo`80o_kn9@3oool<00000340oooo3@0000020?ooo`80o_kn:`3o
ool4000000800@411000000:0?ooo`80o_kn9@3oool2000005D0oooo000R0?ooo`/000000P010@4a
0?ooo`800@412P0000020?ooo`80o_kn;03oool:00000340oooo2P00000200410C80oooo0P010@4:
00000080oooo0P3no_h]0?ooo`@000000P010@45000000X0oooo0P3no_hS0?ooo`@000000P010@48
00000340oooo3@0000020?ooo`80o_kn:@3oool6000000800@411000000;0?ooo`80o_kn9@3oool<
00000340oooo3@0000020?ooo`80o_kn:`3oool4000000800@411000000:0?ooo`80o_kn9@3oool2
000005D0oooo000T0?ooo`/000000P010@480?ooo`80o_kn203oool20?knoQd0oooo300000020?oo
o`80o_kn;03oool:00000340oooo2P00000200410@T0oooo0P3no_h80?ooo`80o_kn7@3oool<0000
0080oooo0P3no_h]0?ooo`/000001P3oool20?knoRL0oooo3P00000[0?ooo`80o_kn1@3oool<0000
02d0oooo300000070?ooo`80o_kn:@3oool<000002/0oooo0P3no_h40?ooo`d00000;`3oool:0000
00H0oooo0P3no_h]0?ooo`<0o_knCP3oool002@0oooo2`00000200410@P0oooo0P3no_h80?ooo`80
o_kn7@3oool<00000080oooo0P3no_h/0?ooo`X00000<@3oool:000000800@412@3oool20?knoPP0
oooo0P3no_hM0?ooo``000000P3oool20?knoRd0oooo2`0000060?ooo`80o_kn9`3oool>000002/0
oooo0P3no_h50?ooo``00000;@3oool<000000L0oooo0P3no_hY0?ooo``00000:`3oool20?knoP@0
oooo3@00000_0?ooo`X000001P3oool20?knoRd0oooo0`3no_i>0?ooo`009P3oool=000002T0oooo
0P3no_h60?ooo``00000<03oool:000000@0oooo0P3no_h[0?ooo`d00000:@3oool20?knoPH0oooo
3000000[0?ooo`80o_kn103oool;000002l0oooo1000000200410@P00000<P3oool<000002T0oooo
0P3no_h20?ooo``000007@3oool20?knoPP0oooo0P3no_h90?ooo`800@412P00000a0?ooo`d00000
:@3oool20?knoP@0oooo2P00000M0?ooo`80o_kn203oool20?knoU/0oooo000V0?ooo`d00000:@3o
ool20?knoPH0oooo3000000`0?ooo`X00000103oool20?knoR/0oooo3@00000Y0?ooo`80o_kn1P3o
ool<000002/0oooo0P3no_h40?ooo`/00000;`3oool4000000800@412000000b0?ooo``00000:@3o
ool20?knoP80oooo3000000M0?ooo`80o_kn203oool20?knoPT0oooo0P010@4:00000340oooo3@00
000Y0?ooo`80o_kn103oool:000001d0oooo0P3no_h80?ooo`80o_knF`3oool002T0oooo3000000U
0?ooo`80o_kn2P3oool4000000800@411P00000`0?ooo`X00000<@3oool=000002D0oooo0P3no_h:
0?ooo`@000000P010@46000002/0oooo0P3no_h40?ooo`T000000P010@4a0?ooo``00000<P3oool<
000002T0oooo0P3no_h20?ooo`X000000P010@4b0?ooo`800@412P00000a0?ooo`d00000:@3oool2
0?knoP@0oooo2000000200410H80oooo000Y0?ooo``000009@3oool20?knoPX0oooo100000020041
0@H00000<03oool:00000340oooo3@00000U0?ooo`80o_kn2P3oool4000000800@411P00000[0?oo
o`80o_kn103oool9000000800@41<@3oool<00000380oooo3000000Y0?ooo`80o_kn0P3oool:0000
00800@41<P3oool200410@X00000<@3oool=000002T0oooo0P3no_h40?ooo`P000000P010@620?oo
o`00:`3oool<000001l0oooo0P3no_h<0?ooo`80o_kn0P3oool=000002l0oooo2P00000a0?ooo`d0
00007P3oool20?knoPd0oooo0P3no_h20?ooo``00000<P3oool:000002/0oooo0P3no_h40?ooo`X0
00000P010@4b0?ooo`@000000P010@46000002d0oooo3@00000W0?ooo`80o_kn203oool:00000080
0@41<@3oool5000000800@411P00000_0?ooo`X000009`3oool20?knoUL0oooo000[0?ooo``00000
7`3oool20?knoP`0oooo0P3no_h20?ooo`d00000;`3oool:00000340oooo3@00000N0?ooo`80o_kn
3@3oool20?knoP80oooo3000000b0?ooo`X00000:`3oool20?knoP@0oooo2P00000200410C80oooo
1000000200410@H00000;@3oool=000002L0oooo0P3no_h80?ooo`X000000P010@4a0?ooo`D00000
0P010@46000002l0oooo2P00000W0?ooo`80o_knE`3oool002@0oooo0P3no_h70?ooo``00000203o
ool20?knoQD0oooo0P3no_h@0?ooo`d00000;`3oool:000002T0oooo0P3no_h60?ooo`d00000203o
ool20?knoQ@0oooo0`3no_h@0?ooo``00000<P3oool:00000080oooo0P3no_h]0?ooo``00000<P3o
ool<000002d0oooo3@0000020?ooo`80o_kn603oool20?knoQ<0oooo3000000a0?ooo`d00000;`3o
ool:00000080oooo0P3no_hI0?ooo`80o_knG`3oool002@0oooo0P3no_h70?ooo``00000203oool2
0?knoQD0oooo0P3no_h@0?ooo`d00000;`3oool:000002T0oooo0P3no_h60?ooo`d00000203oool2
0?knoQ@0oooo0`3no_h@0?ooo``00000<P3oool:00000080oooo0P3no_h]0?ooo``00000<P3oool<
000002d0oooo3@0000020?ooo`80o_kn603oool20?knoQ<0oooo3000000a0?ooo`d00000;`3oool:
00000080oooo0P3no_hI0?ooo`80o_knG`3oool002l0oooo3000000C0?ooo`80o_kn603oool20?kn
oP80oooo3@00000_0?ooo`X00000103oool20?knoR/0oooo3@00000B0?ooo`80o_kn6@3oool20?kn
oP80oooo3000000b0?ooo`X00000403oool20?knoQD0oooo0P3no_h80?ooo`d000001P3oool20?kn
oRT0oooo3000000]0?ooo`d00000403oool20?knoQD0oooo0P3no_h80?ooo``000001P3oool20?kn
oRX0oooo3000000_0?ooo`X000004@3oool20?knoVT0oooo000_0?ooo``000004`3oool20?knoQP0
oooo0P3no_h20?ooo`d00000;`3oool:000000@0oooo0P3no_h[0?ooo`d000004P3oool20?knoQT0
oooo0P3no_h20?ooo``00000<P3oool:00000100oooo0P3no_hE0?ooo`80o_kn203oool=000000H0
oooo0P3no_hY0?ooo``00000;@3oool=00000100oooo0P3no_hE0?ooo`80o_kn203oool<000000H0
oooo0P3no_hZ0?ooo``00000;`3oool:00000140oooo0P3no_iY0?ooo`00<@3oool200410@X00000
203oool20?knoRL0oooo3@00000_0?ooo`X00000<@3oool300410@X00000203oool20?knoRL0oooo
3000000b0?ooo`X000000P3oool20?knoP`0oooo0P3no_hO0?ooo`d00000<@3oool<000002d0oooo
3@0000020?ooo`80o_kn303oool20?knoQl0oooo3000000b0?ooo``00000;`3oool:00000080oooo
0P3no_h=0?ooo`80o_knI`3oool00340oooo0P010@4:000000P0oooo0P3no_hW0?ooo`d00000;`3o
ool:00000340oooo0`010@4:000000P0oooo0P3no_hW0?ooo``00000<P3oool:00000080oooo0P3n
o_h<0?ooo`80o_kn7`3oool=00000340oooo3000000]0?ooo`d000000P3oool20?knoP`0oooo0P3n
o_hO0?ooo``00000<P3oool<000002l0oooo2P0000020?ooo`80o_kn3@3oool20?knoVL0oooo000c
0?ooo`X000000P010@4a0?ooo`800@412`0000020?ooo`80o_kn:`3oool:00000380oooo2P000002
00410C40oooo0P010@4:000000<0oooo0P3no_h]0?ooo`@000000P010@44000000X0oooo0P3no_hU
0?ooo`d00000<@3oool<00000080oooo0P3no_hY0?ooo`L000000P010@44000000X0oooo0P3no_hU
0?ooo``00000<P3oool<00000080oooo0P3no_h[0?ooo`@000000P010@44000000/0oooo0P3no_i[
0?ooo`00<`3oool:000000800@41<@3oool200410@/000000P3oool20?knoR/0oooo2P00000b0?oo
o`X000000P010@4a0?ooo`800@412P0000030?ooo`80o_kn;@3oool4000000800@411000000:0?oo
o`80o_kn9@3oool=00000340oooo300000020?ooo`80o_kn:@3oool7000000800@411000000:0?oo
o`80o_kn9@3oool<00000380oooo300000020?ooo`80o_kn:`3oool4000000800@411000000;0?oo
o`80o_knJ`3oool003D0oooo2P00000200410@P0oooo0P3no_h90?ooo`80o_kn703oool=00000080
oooo0P3no_h[0?ooo`X00000<P3oool:000000800@41203oool20?knoPP0oooo0P3no_hM0?ooo`d0
00000P3oool20?knoRd0oooo2P0000060?ooo`80o_kn:@3oool=000002/0oooo0P3no_h40?ooo``0
0000;@3oool=000000H0oooo0P3no_hY0?ooo``00000;03oool20?knoP@0oooo3000000_0?ooo`X0
00001`3oool20?knoVd0oooo000e0?ooo`X000000P010@480?ooo`80o_kn2@3oool20?knoQ`0oooo
3@0000020?ooo`80o_kn:`3oool:00000380oooo2P00000200410@P0oooo0P3no_h80?ooo`80o_kn
7@3oool=00000080oooo0P3no_h]0?ooo`X000001P3oool20?knoRT0oooo3@00000[0?ooo`80o_kn
103oool<000002d0oooo3@0000060?ooo`80o_kn:@3oool<000002`0oooo0P3no_h40?ooo``00000
;`3oool:000000L0oooo0P3no_i]0?ooo`00=`3oool<000002T0oooo0P3no_h70?ooo``00000;`3o
ool:000000@0oooo0`3no_h[0?ooo``00000:@3oool20?knoPH0oooo3@00000[0?ooo`80o_kn103o
ool:000001d0oooo0P3no_h80?ooo`80o_kn203oool200410@/00000<@3oool<000002T0oooo0P3n
o_h30?ooo``000007@3oool20?knoPP0oooo0P3no_h80?ooo`800@412P00000b0?ooo``00000:@3o
ool20?knoP@0oooo2`00001c0?ooo`00=`3oool<000002T0oooo0P3no_h70?ooo``00000;`3oool:
000000@0oooo0`3no_h[0?ooo``00000:@3oool20?knoPH0oooo3@00000[0?ooo`80o_kn103oool:
000001d0oooo0P3no_h80?ooo`80o_kn203oool200410@/00000<@3oool<000002T0oooo0P3no_h3
0?ooo``000007@3oool20?knoPP0oooo0P3no_h80?ooo`800@412P00000b0?ooo``00000:@3oool2
0?knoP@0oooo2`00001c0?ooo`00>@3oool<000002D0oooo0P3no_h;0?ooo`@000000P010@460000
02l0oooo2P00000b0?ooo``000009@3oool20?knoPX0oooo1000000200410@L00000:`3oool20?kn
oP@0oooo2000000200410C40oooo0`010@4:00000340oooo3000000Y0?ooo`<0o_kn0P3oool:0000
00800@41<@3oool200410@X00000<P3oool<000002T0oooo0P3no_h40?ooo`T000000P010@5a0?oo
o`00>@3oool<000002D0oooo0P3no_h;0?ooo`@000000P010@46000002l0oooo2P00000b0?ooo``0
00009@3oool20?knoPX0oooo1000000200410@L00000:`3oool20?knoP@0oooo2000000200410C40
oooo0`010@4:00000340oooo3000000Y0?ooo`<0o_kn0P3oool:000000800@41<@3oool200410@X0
0000<P3oool<000002T0oooo0P3no_h40?ooo`T000000P010@5a0?ooo`00>`3oool<000001l0oooo
0P3no_h=0?ooo`80o_kn0P3oool<000002l0oooo2P00000b0?ooo``000007`3oool20?knoP`0oooo
0P3no_h20?ooo`d00000<@3oool:000002L0oooo0P3no_h90?ooo`X000000P010@4a0?ooo`@00000
0P010@46000002h0oooo3000000W0?ooo`80o_kn203oool:000000<00@41<@3oool4000000800@41
1P00000_0?ooo`/00000K`3oool003/0oooo3000000O0?ooo`80o_kn3@3oool20?knoP80oooo3000
000_0?ooo`X00000<P3oool<000001l0oooo0P3no_h<0?ooo`80o_kn0P3oool=00000340oooo2P00
000W0?ooo`80o_kn2@3oool:000000800@41<@3oool4000000800@411P00000^0?ooo``000009`3o
ool20?knoPP0oooo2P00000300410C40oooo1000000200410@H00000;`3oool;000006l0oooo000e
0?ooo`80o_kn1P3oool<000000T0oooo0P3no_hD0?ooo`80o_kn4@3oool<000002l0oooo2`00000Y
0?ooo`80o_kn1P3oool<000000P0oooo0P3no_hE0?ooo`80o_kn403oool=00000340oooo2P000002
0?ooo`80o_kn6@3oool20?knoQ<0oooo3000000a0?ooo``00000;P3oool<00000080oooo0P3no_hI
0?ooo`80o_kn4P3oool=00000340oooo3000000_0?ooo`/000000P3oool20?knoVT0oooo000e0?oo
o`80o_kn1P3oool<000000T0oooo0P3no_hD0?ooo`80o_kn4@3oool<000002l0oooo2`00000Y0?oo
o`80o_kn1P3oool<000000P0oooo0P3no_hE0?ooo`80o_kn403oool=00000340oooo2P0000020?oo
o`80o_kn6@3oool20?knoQ<0oooo3000000a0?ooo``00000;P3oool<00000080oooo0P3no_hI0?oo
o`80o_kn4P3oool=00000340oooo3000000_0?ooo`/000000P3oool20?knoVT0oooo000o0?ooo``0
00004`3oool20?knoQT0oooo0P3no_h20?ooo``00000;`3oool;000000@0oooo0P3no_h[0?ooo``0
00004`3oool20?knoQP0oooo0P3no_h20?ooo`d00000<@3oool:00000140oooo0P3no_hD0?ooo`80
o_kn2@3oool<000000H0oooo0P3no_hY0?ooo`d00000;@3oool<00000100oooo0`3no_hD0?ooo`80
o_kn203oool=000000H0oooo0P3no_hY0?ooo``00000;`3oool;00000100oooo0P3no_iI0?ooo`00
?`3oool<000001<0oooo0P3no_hI0?ooo`80o_kn0P3oool<000002l0oooo2`0000040?ooo`80o_kn
:`3oool<000001<0oooo0P3no_hH0?ooo`80o_kn0P3oool=00000340oooo2P00000A0?ooo`80o_kn
503oool20?knoPT0oooo300000060?ooo`80o_kn:@3oool=000002d0oooo3000000@0?ooo`<0o_kn
503oool20?knoPP0oooo3@0000060?ooo`80o_kn:@3oool<000002l0oooo2`00000@0?ooo`80o_kn
F@3oool00440oooo0P010@4;000000P0oooo0P3no_hW0?ooo``00000;`3oool;00000340oooo0P01
0@4:000000P0oooo0P3no_hX0?ooo``00000<@3oool:00000080oooo0P3no_h=0?ooo`80o_kn7`3o
ool<00000340oooo3@00000]0?ooo``000000P3oool20?knoPd0oooo0P3no_hN0?ooo`d00000<@3o
ool<00000300oooo2P0000020?ooo`80o_kn303oool20?knoUL0oooo00110?ooo`800@412`000008
0?ooo`80o_kn9`3oool<000002l0oooo2`00000a0?ooo`800@412P0000080?ooo`80o_kn:03oool<
00000340oooo2P0000020?ooo`80o_kn3@3oool20?knoQl0oooo3000000a0?ooo`d00000;@3oool<
00000080oooo0P3no_h=0?ooo`80o_kn7P3oool=00000340oooo3000000`0?ooo`X000000P3oool2
0?knoP`0oooo0P3no_iG0?ooo`00@`3oool;000000800@41<@3oool200410@X000000P3oool20?kn
oR/0oooo2`00000a0?ooo`X000000P010@4b0?ooo`800@412P0000020?ooo`80o_kn;@3oool:0000
00/0oooo0P3no_hU0?ooo``00000<@3oool=00000080oooo0P3no_hY0?ooo`H000000P010@440000
00X0oooo0P3no_hU0?ooo`d00000<@3oool<00000080oooo0P3no_h/0?ooo`@000000P010@440000
00X0oooo0P3no_iK0?ooo`00@`3oool;000000800@41<@3oool200410@X000000P3oool20?knoR/0
oooo2`00000a0?ooo`X000000P010@4b0?ooo`800@412P0000020?ooo`80o_kn;@3oool:000000/0
oooo0P3no_hU0?ooo``00000<@3oool=00000080oooo0P3no_hY0?ooo`H000000P010@44000000X0
oooo0P3no_hU0?ooo`d00000<@3oool<00000080oooo0P3no_h/0?ooo`@000000P010@44000000X0
oooo0P3no_iK0?ooo`00A@3oool;000000800@41203oool20?knoPP0oooo0P3no_hM0?ooo``00000
0P3oool20?knoR/0oooo2`00000a0?ooo`X000000P010@490?ooo`80o_kn203oool20?knoQd0oooo
300000020?ooo`80o_kn;@3oool:000000L0oooo0P3no_hY0?ooo``00000:`3oool20?knoP@0oooo
3@00000]0?ooo``000001P3oool20?knoRT0oooo3@00000[0?ooo`80o_kn103oool<00000300oooo
2P0000060?ooo`80o_knG@3oool004D0oooo2`00000200410@P0oooo0P3no_h80?ooo`80o_kn7@3o
ool<00000080oooo0P3no_h[0?ooo`/00000<@3oool:000000800@412@3oool20?knoPP0oooo0P3n
o_hM0?ooo``000000P3oool20?knoRd0oooo2P0000070?ooo`80o_kn:@3oool<000002/0oooo0P3n
o_h40?ooo`d00000;@3oool<000000H0oooo0P3no_hY0?ooo`d00000:`3oool20?knoP@0oooo3000
000`0?ooo`X000001P3oool20?knoUd0oooo000D0?ooo`800000103oool20?knoR/0oooo3@00000Y
0?ooo`80o_kn1P3oool<00000300oooo2P0000040?ooo`80o_kn:`3oool<000002T0oooo0`3no_h6
0?ooo``00000:`3oool20?knoP80oooo3@00000L0?ooo`80o_kn2@3oool20?knoPP0oooo0P010@4:
00000340oooo3@00000Y0?ooo`80o_kn0P3oool<000001d0oooo0P3no_h80?ooo`80o_kn2@3oool2
00410@X00000<@3oool<000002X0oooo0P3no_h40?ooo`X00000H`3oool001@0oooo0P0000040?oo
o`80o_kn:`3oool=000002T0oooo0P3no_h60?ooo``00000<03oool:000000@0oooo0P3no_h[0?oo
o``00000:@3oool30?knoPH0oooo3000000[0?ooo`80o_kn0P3oool=000001`0oooo0P3no_h90?oo
o`80o_kn203oool200410@X00000<@3oool=000002T0oooo0P3no_h20?ooo``000007@3oool20?kn
oPP0oooo0P3no_h90?ooo`800@412P00000a0?ooo``00000:P3oool20?knoP@0oooo2P00001S0?oo
o`00503oool2000000@0oooo0P3no_h[0?ooo`d00000:@3oool20?knoPH0oooo3000000`0?ooo`X0
0000103oool20?knoR/0oooo3000000Y0?ooo`<0o_kn1P3oool<000002/0oooo0P3no_h20?ooo`d0
0000703oool20?knoPT0oooo0P3no_h80?ooo`800@412P00000a0?ooo`d00000:@3oool20?knoP80
oooo3000000M0?ooo`80o_kn203oool20?knoPT0oooo0P010@4:00000340oooo3000000Z0?ooo`80
o_kn103oool:000006<0oooo000D0?ooo`@00000<@3oool=000002D0oooo0P3no_h:0?ooo`@00000
0P010@4600000300oooo2P00000a0?ooo``000009@3oool20?knoP/0oooo1000000200410@H00000
:`3oool20?knoP80oooo1000000200410@D000000P010@4a0?ooo`800@412P00000a0?ooo`d00000
:@3oool20?knoP80oooo2P00000200410C80oooo0P010@4:00000340oooo3@00000Y0?ooo`80o_kn
103oool8000000800@41H@3oool001@0oooo1000000a0?ooo`d000009@3oool20?knoPX0oooo1000
000200410@H00000<03oool:00000340oooo3000000U0?ooo`80o_kn2`3oool4000000800@411P00
000[0?ooo`80o_kn0P3oool4000000800@411@00000200410C40oooo0P010@4:00000340oooo3@00
000Y0?ooo`80o_kn0P3oool:000000800@41<P3oool200410@X00000<@3oool=000002T0oooo0P3n
o_h40?ooo`P000000P010@5Q0?ooo`00503oool600000340oooo3@00000O0?ooo`80o_kn303oool2
0?knoP80oooo3000000`0?ooo`X00000<@3oool<000001l0oooo0P3no_h=0?ooo`80o_kn0P3oool<
000002l0oooo3@00000W0?ooo`80o_kn203oool:000000800@41<P3oool4000000800@411P00000]
0?ooo``000009`3oool20?knoPT0oooo2P00000200410C40oooo1000000200410@L00000;`3oool:
000005l0oooo000D0?ooo`H00000<@3oool=000001l0oooo0P3no_h<0?ooo`80o_kn0P3oool<0000
0300oooo2P00000a0?ooo``000007`3oool20?knoPd0oooo0P3no_h20?ooo``00000;`3oool=0000
02L0oooo0P3no_h80?ooo`X000000P010@4b0?ooo`@000000P010@46000002d0oooo3000000W0?oo
o`80o_kn2@3oool:000000800@41<@3oool4000000800@411`00000_0?ooo`X00000G`3oool001@0
oooo2000000Y0?ooo`80o_kn1`3oool<000000P0oooo0P3no_hE0?ooo`80o_kn403oool<00000300
oooo2P00000Y0?ooo`80o_kn1P3oool=000000P0oooo0P3no_hD0?ooo`80o_kn4@3oool<000002l0
oooo3@0000020?ooo`80o_kn603oool30?knoQ80oooo3000000b0?ooo``00000;@3oool<00000080
oooo0`3no_hH0?ooo`80o_kn4`3oool<00000340oooo3@00000_0?ooo`X000000P3oool20?knoUT0
oooo000D0?ooo`P00000:@3oool20?knoPL0oooo300000080?ooo`80o_kn5@3oool20?knoQ00oooo
3000000`0?ooo`X00000:@3oool20?knoPH0oooo3@0000080?ooo`80o_kn503oool20?knoQ40oooo
3000000_0?ooo`d000000P3oool20?knoQP0oooo0`3no_hB0?ooo``00000<P3oool<000002d0oooo
300000020?ooo`<0o_kn603oool20?knoQ<0oooo3000000a0?ooo`d00000;`3oool:00000080oooo
0P3no_iI0?ooo`00503oool:00000380oooo3000000B0?ooo`80o_kn6@3oool20?knoP80oooo3000
000`0?ooo`X00000103oool20?knoR/0oooo3@00000B0?ooo`80o_kn6@3oool20?knoP80oooo3000
000_0?ooo`d00000403oool20?knoQD0oooo0P3no_h80?ooo``000001`3oool20?knoRT0oooo3000
000]0?ooo``000004@3oool20?knoQ@0oooo0`3no_h80?ooo``000001P3oool20?knoRT0oooo3@00
000_0?ooo`X00000F`3oool001@0oooo2P00000b0?ooo``000004P3oool20?knoQT0oooo0P3no_h2
0?ooo``00000<03oool:000000@0oooo0P3no_h[0?ooo`d000004P3oool20?knoQT0oooo0P3no_h2
0?ooo``00000;`3oool=00000100oooo0P3no_hE0?ooo`80o_kn203oool<000000L0oooo0P3no_hY
0?ooo``00000;@3oool<00000140oooo0P3no_hD0?ooo`<0o_kn203oool<000000H0oooo0P3no_hY
0?ooo`d00000;`3oool:000005/0oooo000D0?ooo`H000000P010@4400000380oooo0P010@4:0000
00P0oooo0P3no_hW0?ooo`d00000;`3oool:00000340oooo0P010@4;000000P0oooo0P3no_hW0?oo
o``00000;`3oool=00000080oooo0P3no_h<0?ooo`80o_kn7`3oool<00000380oooo3000000]0?oo
o`d000000P3oool20?knoP`0oooo0P3no_hO0?ooo``00000<@3oool=000002l0oooo2P00001I0?oo
o`00503oool6000000800@411000000b0?ooo`800@412P0000080?ooo`80o_kn9`3oool=000002l0
oooo2P00000a0?ooo`800@412`0000080?ooo`80o_kn9`3oool<000002l0oooo3@0000020?ooo`80
o_kn303oool20?knoQl0oooo3000000b0?ooo``00000;@3oool=00000080oooo0P3no_h<0?ooo`80
o_kn7`3oool<00000340oooo3@00000_0?ooo`X00000F@3oool001H0oooo3000000b0?ooo`X00000
0P010@4a0?ooo`800@412`0000020?ooo`80o_kn:`3oool:00000340oooo2`00000200410C40oooo
0P010@4:00000080oooo0P3no_h/0?ooo`H000000P010@44000000X0oooo0P3no_hU0?ooo``00000
<P3oool<00000080oooo0P3no_hY0?ooo`H000000P010@45000000X0oooo0P3no_hU0?ooo``00000
<@3oool=00000080oooo0P3no_h[0?ooo`@000000P010@44000005L0oooo000F0?ooo``00000<P3o
ool:000000800@41<@3oool200410@/000000P3oool20?knoR/0oooo2P00000a0?ooo`/000000P01
0@4a0?ooo`800@412P0000020?ooo`80o_kn;03oool6000000800@411000000:0?ooo`80o_kn9@3o
ool<00000380oooo300000020?ooo`80o_kn:@3oool6000000800@411@00000:0?ooo`80o_kn9@3o
ool<00000340oooo3@0000020?ooo`80o_kn:`3oool4000000800@411000001G0?ooo`00603oool<
00000380oooo2P00000200410@P0oooo0P3no_h90?ooo`80o_kn703oool=00000080oooo0P3no_h[
0?ooo`X00000<@3oool;000000800@41203oool20?knoPP0oooo0P3no_hM0?ooo``000000P3oool2
0?knoR`0oooo300000060?ooo`80o_kn:@3oool=000002/0oooo0P3no_h40?ooo``00000;@3oool=
000000H0oooo0P3no_hY0?ooo``00000:`3oool20?knoPD0oooo3000000_0?ooo`X00000E@3oool0
01P0oooo3000000b0?ooo`X000000P010@480?ooo`80o_kn2@3oool20?knoQ`0oooo3@0000020?oo
o`80o_kn:`3oool:00000340oooo2`00000200410@P0oooo0P3no_h80?ooo`80o_kn7@3oool<0000
0080oooo0P3no_h/0?ooo``000001P3oool20?knoRT0oooo3@00000[0?ooo`80o_kn103oool<0000
02d0oooo3@0000060?ooo`80o_kn:@3oool<000002/0oooo0P3no_h50?ooo``00000;`3oool:0000
05D0oooo000J0?ooo``000001@3oool20?knoR/0oooo3000000Y0?ooo`80o_kn1P3oool=000002l0
oooo2P0000040?ooo`80o_kn:`3oool=000002T0oooo0P3no_h60?ooo``00000;03oool20?knoP80
oooo3000000M0?ooo`80o_kn203oool20?knoPP0oooo0P010@4;00000340oooo3000000Y0?ooo`80
o_kn0P3oool=000001`0oooo0P3no_h90?ooo`80o_kn203oool200410@X00000<P3oool<000002T0
oooo0P3no_h40?ooo`P00000103oool30?knoTh0oooo000J0?ooo``000001@3oool20?knoR/0oooo
3000000Y0?ooo`80o_kn1P3oool=000002l0oooo2P0000040?ooo`80o_kn:`3oool=000002T0oooo
0P3no_h60?ooo``00000;03oool20?knoP80oooo3000000M0?ooo`80o_kn203oool20?knoPP0oooo
0P010@4;00000340oooo3000000Y0?ooo`80o_kn0P3oool=000001`0oooo0P3no_h90?ooo`80o_kn
203oool200410@X00000<P3oool<000002T0oooo0P3no_h40?ooo`P00000103oool30?knoTh0oooo
000H0?ooo`80o_kn0P3oool=00000340oooo3000000U0?ooo`80o_kn2P3oool5000000800@411P00
000_0?ooo`X00000<P3oool<000002D0oooo0P3no_h:0?ooo`@000000P010@46000002`0oooo0P3n
o_h20?ooo`X000000P010@4a0?ooo`800@412`00000a0?ooo``00000:@3oool20?knoP80oooo2`00
000200410C40oooo0P010@4:00000380oooo3000000Y0?ooo`80o_kn103oool6000000@0oooo0`3n
o_i>0?ooo`00603oool20?knoP80oooo3@00000a0?ooo``000009@3oool20?knoPX0oooo1@000002
00410@H00000;`3oool:00000380oooo3000000U0?ooo`80o_kn2P3oool4000000800@411P00000/
0?ooo`80o_kn0P3oool:000000800@41<@3oool200410@/00000<@3oool<000002T0oooo0P3no_h2
0?ooo`/000000P010@4a0?ooo`800@412P00000b0?ooo``00000:@3oool20?knoP@0oooo1P000004
0?ooo`<0o_knCP3oool001h0oooo3@00000a0?ooo``000007`3oool20?knoP`0oooo0P3no_h20?oo
o`d00000;`3oool:00000380oooo3000000O0?ooo`80o_kn303oool20?knoP80oooo3@00000_0?oo
o``000009`3oool20?knoPP0oooo2`00000200410C40oooo1000000200410@H00000;@3oool=0000
02L0oooo0P3no_h80?ooo`X000000P010@4b0?ooo`@000000P010@46000002l0oooo1000001E0?oo
o`007P3oool=00000340oooo3000000O0?ooo`80o_kn303oool20?knoP80oooo3@00000_0?ooo`X0
0000<P3oool<000001l0oooo0P3no_h<0?ooo`80o_kn0P3oool=000002l0oooo3000000W0?ooo`80
o_kn203oool;000000800@41<@3oool4000000800@411P00000]0?ooo`d000009`3oool20?knoPP0
oooo2P00000200410C80oooo1000000200410@H00000;`3oool4000005D0oooo000P0?ooo`d00000
:@3oool20?knoPH0oooo300000080?ooo`<0o_kn503oool20?knoQ40oooo3000000_0?ooo`X00000
:@3oool20?knoPL0oooo300000080?ooo`80o_kn5@3oool20?knoQ00oooo3@00000_0?ooo``00000
0P3oool20?knoQT0oooo0P3no_hB0?ooo`d00000<@3oool<000002h0oooo300000020?ooo`80o_kn
6@3oool20?knoQ80oooo3000000b0?ooo``00000;`3oool2000005D0oooo000P0?ooo`d00000:@3o
ool20?knoPH0oooo300000080?ooo`<0o_kn503oool20?knoQ40oooo3000000_0?ooo`X00000:@3o
ool20?knoPL0oooo300000080?ooo`80o_kn5@3oool20?knoQ00oooo3@00000_0?ooo``000000P3o
ool20?knoQT0oooo0P3no_hB0?ooo`d00000<@3oool<000002h0oooo300000020?ooo`80o_kn6@3o
ool20?knoQ80oooo3000000b0?ooo``00000;`3oool2000005D0oooo000R0?ooo`d00000<@3oool<
000001<0oooo0P3no_hH0?ooo`<0o_kn0P3oool<000002l0oooo2P0000050?ooo`80o_kn:`3oool<
000001<0oooo0P3no_hL0?ooo`/00000<@3oool<00000140oooo0P3no_hD0?ooo`80o_kn203oool=
000000H0oooo0P3no_hY0?ooo``00000;P3oool<00000100oooo0P3no_hE0?ooo`80o_kn203oool=
000000H0oooo0P3no_hY0?ooo``00000Q03oool00280oooo3@00000a0?ooo``000004`3oool20?kn
oQP0oooo0`3no_h20?ooo``00000;`3oool:000000D0oooo0P3no_h[0?ooo``000004`3oool20?kn
oQ`0oooo2`00000a0?ooo``000004@3oool20?knoQ@0oooo0P3no_h80?ooo`d000001P3oool20?kn
oRT0oooo3000000^0?ooo``00000403oool20?knoQD0oooo0P3no_h80?ooo`d000001P3oool20?kn
oRT0oooo300000240?ooo`00903oool7000000800@411000000a0?ooo`800@412P0000090?ooo`80
o_kn9`3oool<000002l0oooo2P00000b0?ooo`800@412P0000080?ooo`80o_kn9`3oool;00000080
oooo0P3no_h]0?ooo``000000P3oool20?knoPd0oooo0P3no_hO0?ooo``00000<@3oool<000002h0
oooo300000020?ooo`80o_kn303oool20?knoQl0oooo3@00000a0?ooo``00000PP3oool002@0oooo
1`00000200410@@00000<@3oool200410@X000002@3oool20?knoRL0oooo3000000_0?ooo`X00000
<P3oool200410@X00000203oool20?knoRL0oooo2`0000020?ooo`80o_kn;@3oool<00000080oooo
0P3no_h=0?ooo`80o_kn7`3oool<00000340oooo3000000^0?ooo``000000P3oool20?knoP`0oooo
0P3no_hO0?ooo`d00000<@3oool<00000880oooo000V0?ooo`d00000<@3oool:000000800@41<P3o
ool200410@X000000P3oool20?knoR/0oooo2`00000a0?ooo`X000000P010@4]0?ooo`80o_kn0P3o
ool9000000800@410P3oool20?knoRd0oooo1P00000200410@@000002`3oool20?knoRD0oooo3000
000a0?ooo`d000000P3oool20?knoRT0oooo1P00000200410@@000002P3oool20?knoRD0oooo3@00
000a0?ooo``000000P3oool20?knoW`0oooo000V0?ooo`d00000<@3oool:000000800@41<P3oool2
00410@X000000P3oool20?knoR/0oooo2`00000a0?ooo`X000000P010@4]0?ooo`80o_kn0P3oool9
000000800@410P3oool20?knoRd0oooo1P00000200410@@000002`3oool20?knoRD0oooo3000000a
0?ooo`d000000P3oool20?knoRT0oooo1P00000200410@@000002P3oool20?knoRD0oooo3@00000a
0?ooo``000000P3oool20?knoW`0oooo000Y0?ooo``00000<@3oool:000000800@412@3oool20?kn
oPP0oooo0P3no_hM0?ooo``000000P3oool20?knoR/0oooo2`00000a0?ooo`X000000P010@480?oo
o`80o_kn2@3oool20?knoQX0oooo3@00000a0?ooo``000001`3oool20?knoRT0oooo3000000[0?oo
o`80o_kn103oool=000002d0oooo300000060?ooo`80o_kn:@3oool=000002/0oooo0P3no_h40?oo
o``00000OP3oool002T0oooo3000000a0?ooo`X000000P010@490?ooo`80o_kn203oool20?knoQd0
oooo300000020?ooo`80o_kn:`3oool;00000340oooo2P00000200410@P0oooo0P3no_h90?ooo`80
o_kn6P3oool=00000340oooo300000070?ooo`80o_kn:@3oool<000002/0oooo0P3no_h40?ooo`d0
0000;@3oool<000000H0oooo0P3no_hY0?ooo`d00000:`3oool20?knoP@0oooo3000001n0?ooo`00
:`3oool<000000@0oooo0P3no_h[0?ooo`d00000:@3oool20?knoPH0oooo3000000_0?ooo`/00000
103oool20?knoR/0oooo3000000_0?ooo`d000000P3oool20?knoRT0oooo0P3no_h20?ooo``00000
7@3oool20?knoPP0oooo0P3no_h90?ooo`800@412P00000a0?ooo`d00000:@3oool20?knoP80oooo
3000000M0?ooo`80o_kn203oool20?knoPP0oooo0P010@4;00000340oooo3000001l0?ooo`00:`3o
ool<000000@0oooo0P3no_h[0?ooo`d00000:@3oool20?knoPH0oooo3000000_0?ooo`/00000103o
ool20?knoR/0oooo3000000_0?ooo`d000000P3oool20?knoRT0oooo0P3no_h20?ooo``000007@3o
ool20?knoPP0oooo0P3no_h90?ooo`800@412P00000a0?ooo`d00000:@3oool20?knoP80oooo3000
000M0?ooo`80o_kn203oool20?knoPP0oooo0P010@4;00000340oooo3000001l0?ooo`00:@3oool2
0?knoP80oooo3000000a0?ooo`d000009@3oool20?knoPX0oooo1000000200410@H00000;`3oool;
00000340oooo3000000`0?ooo``000000P3oool20?knoRT0oooo0P3no_h20?ooo`X000000P010@4b
0?ooo`800@412P00000a0?ooo`d00000:@3oool20?knoP80oooo2P00000200410C40oooo0`010@4:
00000340oooo3000001j0?ooo`00:@3oool20?knoP80oooo3000000a0?ooo`d000009@3oool20?kn
oPX0oooo1000000200410@H00000;`3oool;00000340oooo3000000`0?ooo``000000P3oool20?kn
oRT0oooo0P3no_h20?ooo`X000000P010@4b0?ooo`800@412P00000a0?ooo`d00000:@3oool20?kn
oP80oooo2P00000200410C40oooo0`010@4:00000340oooo3000001j0?ooo`00;`3oool<00000340
oooo3@00000N0?ooo`80o_kn3@3oool20?knoP80oooo3000000_0?ooo`/00000<@3oool<00000300
oooo2P00000200410C40oooo3@00000W0?ooo`80o_kn203oool:000000800@41<@3oool500000080
0@411P00000]0?ooo``000009`3oool20?knoPT0oooo2P00000200410C40oooo1000000200410@H0
0000N03oool002l0oooo3000000a0?ooo`d000007P3oool20?knoPd0oooo0P3no_h20?ooo``00000
;`3oool;00000340oooo3000000`0?ooo`X000000P010@4a0?ooo`d000009`3oool20?knoPP0oooo
2P00000200410C40oooo1@00000200410@H00000;@3oool<000002L0oooo0P3no_h90?ooo`X00000
0P010@4a0?ooo`@000000P010@46000007P0oooo000_0?ooo``00000<@3oool=000001h0oooo0P3n
o_h=0?ooo`80o_kn0P3oool<000002l0oooo2`00000a0?ooo``00000<03oool:000000800@41<@3o
ool=000002L0oooo0P3no_h80?ooo`X000000P010@4a0?ooo`D000000P010@46000002d0oooo3000
000W0?ooo`80o_kn2@3oool:000000800@41<@3oool4000000800@411P00001h0?ooo`00<@3oool<
000002T0oooo0P3no_h60?ooo`d00000203oool20?knoQ@0oooo0`3no_h@0?ooo``00000<03oool:
000002T0oooo0P3no_h60?ooo``000002@3oool20?knoQh0oooo0`3no_h40?ooo``00000<@3oool=
00000080oooo0P3no_hH0?ooo`80o_kn4`3oool<00000340oooo3@00000]0?ooo``000000P3oool2
0?knoQT0oooo0P3no_hC0?ooo``00000<@3oool<000007H0oooo000a0?ooo``00000:@3oool20?kn
oPH0oooo3@0000080?ooo`80o_kn503oool30?knoQ00oooo3000000`0?ooo`X00000:@3oool20?kn
oPH0oooo300000090?ooo`80o_kn7P3oool30?knoP@0oooo3000000a0?ooo`d000000P3oool20?kn
oQP0oooo0P3no_hC0?ooo``00000<@3oool=000002d0oooo300000020?ooo`80o_kn6@3oool20?kn
oQ<0oooo3000000a0?ooo``00000MP3oool003<0oooo3000000a0?ooo`d000004P3oool20?knoQT0
oooo0P3no_h20?ooo``00000<03oool:000000@0oooo0P3no_h[0?ooo``00000<03oool<00000340
oooo3@00000@0?ooo`80o_kn5@3oool20?knoPP0oooo300000060?ooo`80o_kn:P3oool<000002d0
oooo3000000A0?ooo`80o_kn503oool20?knoPT0oooo300000060?ooo`80o_kn:@3oool=000007<0
oooo000c0?ooo``00000<@3oool=00000180oooo0P3no_hI0?ooo`80o_kn0P3oool<00000300oooo
2P0000040?ooo`80o_kn:`3oool<00000300oooo3000000a0?ooo`d00000403oool20?knoQD0oooo
0P3no_h80?ooo``000001P3oool20?knoRX0oooo3000000]0?ooo``000004@3oool20?knoQ@0oooo
0P3no_h90?ooo``000001P3oool20?knoRT0oooo3@00001c0?ooo`00=@3oool6000000800@411000
000a0?ooo`<00@412P0000080?ooo`80o_kn9`3oool<00000300oooo2P00000a0?ooo`800@412`00
000_0?ooo``000000P3oool20?knoRd0oooo3@0000020?ooo`80o_kn303oool20?knoQl0oooo3000
000b0?ooo``00000;@3oool<00000080oooo0P3no_h=0?ooo`80o_kn7`3oool<00000340oooo3@00
001a0?ooo`00=@3oool6000000800@411000000a0?ooo`<00@412P0000080?ooo`80o_kn9`3oool<
00000300oooo2P00000a0?ooo`800@412`00000_0?ooo``000000P3oool20?knoRd0oooo3@000002
0?ooo`80o_kn303oool20?knoQl0oooo3000000b0?ooo``00000;@3oool<00000080oooo0P3no_h=
0?ooo`80o_kn7`3oool<00000340oooo3@00001a0?ooo`00=`3oool<00000380oooo2P0000020041
0C40oooo0P010@4:000000<0oooo0P3no_h[0?ooo`X00000<@3oool;000000800@41;@3oool20?kn
oP8000000P010@46000000800@410P3oool20?knoRd0oooo1`00000200410@@000002P3oool20?kn
oRD0oooo3000000b0?ooo``000000P3oool20?knoRT0oooo1P00000200410@@000002`3oool20?kn
oRD0oooo3000000a0?ooo`d000000P3oool20?knoV/0oooo000g0?ooo``00000<P3oool:00000080
0@41<@3oool200410@X000000`3oool20?knoR/0oooo2P00000a0?ooo`/000000P010@4]0?ooo`80
o_kn0P00000200410@H000000P010@420?ooo`80o_kn;@3oool7000000800@411000000:0?ooo`80
o_kn9@3oool<00000380oooo300000020?ooo`80o_kn:@3oool6000000800@411000000;0?ooo`80
o_kn9@3oool<00000340oooo3@0000020?ooo`80o_knJ`3oool003T0oooo3000000b0?ooo`X00000
0P010@480?ooo`80o_kn203oool20?knoQd0oooo3@0000020?ooo`80o_kn:`3oool:00000340oooo
2`00000200410Bl0oooo3000000a0?ooo`d000001P3oool20?knoRT0oooo3000000/0?ooo`80o_kn
103oool<000002d0oooo300000070?ooo`80o_kn:@3oool<000002/0oooo0P3no_h40?ooo`d00000
K@3oool003T0oooo3000000b0?ooo`X000000P010@480?ooo`80o_kn203oool20?knoQd0oooo3@00
00020?ooo`80o_kn:`3oool:00000340oooo2`00000200410Bl0oooo3000000a0?ooo`d000001P3o
ool20?knoRT0oooo3000000/0?ooo`80o_kn103oool<000002d0oooo300000070?ooo`80o_kn:@3o
ool<000002/0oooo0P3no_h40?ooo`d00000K@3oool003/0oooo300000040?ooo`<0o_kn:`3oool<
000002T0oooo0P3no_h60?ooo`d00000;`3oool:000000@0oooo0P3no_h[0?ooo`d00000;@3oool2
0?knoP`000000P3oool20?knoRT0oooo0P3no_h30?ooo``000007@3oool20?knoPP0oooo0P3no_h8
0?ooo`800@412P00000b0?ooo``00000:@3oool20?knoP80oooo3@00000L0?ooo`80o_kn2@3oool2
0?knoPP0oooo0P010@4:00000340oooo3@00001[0?ooo`00>`3oool<000000@0oooo0`3no_h[0?oo
o``00000:@3oool20?knoPH0oooo3@00000_0?ooo`X00000103oool20?knoR/0oooo3@00000]0?oo
o`80o_kn300000020?ooo`80o_kn:@3oool20?knoP<0oooo3000000M0?ooo`80o_kn203oool20?kn
oPP0oooo0P010@4:00000380oooo3000000Y0?ooo`80o_kn0P3oool=000001`0oooo0P3no_h90?oo
o`80o_kn203oool200410@X00000<@3oool=000006/0oooo000i0?ooo`80o_kn0P3oool<00000380
oooo3000000U0?ooo`80o_kn2P3oool4000000800@411`00000_0?ooo`X00000<@3oool=000002l0
oooo300000020?ooo`80o_kn:@3oool30?knoP80oooo2P00000200410C40oooo0P010@4:00000380
oooo3000000Y0?ooo`80o_kn0P3oool;000000800@41<@3oool200410@X00000<@3oool=000006T0
oooo000i0?ooo`80o_kn0P3oool<00000380oooo3000000U0?ooo`80o_kn2P3oool4000000800@41
1`00000_0?ooo`X00000<@3oool=000002l0oooo300000020?ooo`80o_kn:@3oool30?knoP80oooo
2P00000200410C40oooo0P010@4:00000380oooo3000000Y0?ooo`80o_kn0P3oool;000000800@41
<@3oool200410@X00000<@3oool=000006T0oooo000o0?ooo``00000<P3oool<000001l0oooo0P3n
o_h<0?ooo`80o_kn0P3oool=000002l0oooo2P00000a0?ooo`l00000;@3oool:000000800@41<P3o
ool<000002L0oooo0P3no_h80?ooo`X000000`010@4a0?ooo`@000000P010@46000002d0oooo3@00
000W0?ooo`80o_kn203oool:000000800@41<P3oool4000000800@411P00001W0?ooo`00?`3oool<
00000380oooo3000000O0?ooo`80o_kn303oool20?knoP80oooo3@00000_0?ooo`X00000<@3oool?
000002d0oooo2P00000200410C80oooo3000000W0?ooo`80o_kn203oool:000000<00@41<@3oool4
000000800@411P00000]0?ooo`d000009`3oool20?knoPP0oooo2P00000200410C80oooo10000002
00410@H00000I`3oool00440oooo3@00000Y0?ooo`80o_kn1P3oool<000000P0oooo0P3no_hE0?oo
o`80o_kn403oool=000002l0oooo2P00000Y0?ooo`80o_kn1`3oool>000002d0oooo3000000b0?oo
o``000000P3oool20?knoQT0oooo0P3no_hB0?ooo`d00000<@3oool<000002d0oooo3@0000020?oo
o`80o_kn603oool30?knoQ80oooo3000000b0?ooo``00000I@3oool00440oooo3@00000Y0?ooo`80
o_kn1P3oool<000000P0oooo0P3no_hE0?ooo`80o_kn403oool=000002l0oooo2P00000Y0?ooo`80
o_kn1`3oool>000002d0oooo3000000b0?ooo``000000P3oool20?knoQT0oooo0P3no_hB0?ooo`d0
0000<@3oool<000002d0oooo3@0000020?ooo`80o_kn603oool30?knoQ80oooo3000000b0?ooo``0
0000I@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo
0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00
o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA
0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0oooo
o`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?oo
ool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo
003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oo
oe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{92.8125, 105.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" Fig. 1.8 Simple pendulum", "Caption",
  CellTags->"Fig. 1.8"],

Cell[TextData[{
  "Plot the direction field for this equation projected into the ",
  "phase-space",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Theta], \[Theta]\^\[Prime])\)\)]],
  ", in the ranges ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\)\  < \ \[Theta]\  < \ \[Pi]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(-4\), " ", 
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], \(-1\)]}], " ", "<", " ", 
          FormBox[\(\[Theta]\^\[Prime]\),
            "TraditionalForm"], "  ", "<", " ", 
          RowBox[{"4", " ", 
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  " , assuming a length ",
  StyleBox["l ",
    FontSlant->"Italic"],
  "of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"10", " ", 
          StyleBox["m",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Discuss the qualitative features of the solutions. Do all phase-space \
trajectories circle the origin? If not, why not? What do these trajectories \
correspond to physically?"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the energy ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(H\)\(\ \)\)\)]],
  "for this motion in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\^\[Prime]\)]],
  ". Plot several curves of constant ",
  StyleBox["H ",
    FontSlant->"Italic"],
  "on top of your direction field, to verify that the field is tangent to \
them."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Find an expression for the momentum ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Theta]\)]],
  " associated with the variable ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ", so that  one can write the equations of motion for the pendulum in \
Hamiltonian form,  "
}], "Text",
  CellTags->"i:108"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\[Theta]\), \(\[DifferentialD]t\),
              MultilineFunction->None], "=", 
            
            FractionBox[\(\[PartialD]\(H(\[Theta], p\_\[Theta], 
                  t)\)\), \(\[PartialD]p\_\[Theta]\),
              MultilineFunction->None]}], 
          StyleBox[",",
            FontSize->15], "\[IndentingNewLine]", 
          RowBox[{
            
            FractionBox[\(\[DifferentialD]p\_\[Theta]\), \
\(\[DifferentialD]t\),
              MultilineFunction->None], "=", 
            RowBox[{"-", 
              RowBox[{
                
                FractionBox[\(\[PartialD]\(H(\[Theta], p\_\[Theta], 
                      t)\)\), \(\[PartialD]\[Theta]\),
                  MultilineFunction->None], "."}]}]}]}], TraditionalForm]]],
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\ \)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " The Van der Pol oscillator ODE models some properties of excitable \
systems, such as heart muscle or certain electronic circuits. The ODE is"
}], "Text",
  CellTags->"i:38"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] + \((x\^2 - 1)\) x\^\[Prime] + x = 
        0\)]],
  "."
}], "NE2",
  CellTags->"(1.2.20)"],

Cell[TextData[{
  "The restoring force is a simple Hooke's law, but the \"drag force\" is \
more complicated, actually accelerating \"particles\" with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(x\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ".  (Here, ",
  StyleBox["x",
    FontSlant->"Italic"],
  " could actually mean the oscillation amplitude of a chunk of muscle, or \
the current in a nonlinear electrical circuit.) At low amplitudes the \
oscillations build up, but at large amplitudes they decay. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Draw the direction field projected into the phase-space (",
  StyleBox["x",
    FontSlant->"Italic"],
  ",",
  StyleBox["x'",
    FontSlant->"Italic"],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) < x < 2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) < x\^\[Prime] < 2\)]],
  ".  Discuss the qualitative behavior of solutions that begin (i) near the \
origin, (ii) far from the origin.  "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Does this system conserve phase-space area, where ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, x\^\[Prime])\)\)]],
  " is the phase-space?"
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " A particle orbiting around a stationary mass ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "(the sun, for example) follows the following differential equation for \
radius as a function of time, ",
  Cell[BoxData[
      \(TraditionalForm\`r(t)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is the distance measured from the stationary mass:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 r\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", \(L\^2\/r\^3 - \(G\ M\)\/r\^2\)}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(1.2.21)"],

Cell[TextData[{
  "Here,  ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  " is the gravitational constant, and  ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  "  is a constant of the motion - the specific angular momentum of the \
particle, determined by radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " and angular velocity ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Theta]\& . \)\)\)]],
  "  as"
}], "Text",
  CellTags->"i:39"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L = r\^2\ \[Theta]\& . \)]],
  "."
}], "NE2",
  CellTags->"(1.2.22)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is nonzero, find a transformation of time and spatial scales, ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_ = r/a, t\&_ = t/t\_o\)]],
  ", that puts this equation into the dimensionless form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FractionBox[\(\[DifferentialD]\^2 r\&_\), \(\[DifferentialD]t\&_\^2\
\),
            MultilineFunction->None], "=", \(1\/r\&_\^3 - 1\/r\&_\^2\)}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(1.2.23)"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Plot the projection of the direction field for this equation into the \
phase-space  ",
  Cell[BoxData[
      \(TraditionalForm\`\((r\&_, r\&_\^\[Prime])\)\)]],
  " in the range 0.1< ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_\)]],
  "<4, -0.7< ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_\^\[Prime]\)]],
  "<0.7."
}], "Text"],

Cell[TextData[{
  "(i) What is the physical significance of the point ",
  Cell[BoxData[
      \(TraditionalForm\`\((r\&_, r\&_\^\[Prime])\)\)]],
  "=(1,0)?"
}], "Text"],

Cell[TextData[{
  "(ii) What happens to particles that start with large radial velocities at \
large radii, ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_\)]],
  ">>1? "
}], "Text"],

Cell[TextData[{
  "(iii) What happens to particles with zero radial velocities at small \
radius, ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&_\) << 1\)]],
  "?  Explain this in physical terms."
}], "Text"],

Cell[TextData[{
  "(iv) For particles that start with velocities close to the point  ",
  Cell[BoxData[
      \(TraditionalForm\`\((r\&_, r\&_\^\[Prime])\)\)]],
  "=(1,0), the closed trajectories correspond to elliptical orbits, with the \
two points where  ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_\^\[Prime]\)]],
  "=0 corresponding to distance of closest approach ",
  Cell[BoxData[
      \(TraditionalForm\`r\_o\)]],
  "(perihelion) and farthest distance ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_\_1\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(aphelion) from the fixed mass. Therefore, one closed orbit in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r\&_, r\&_\^\[Prime])\)\)]],
  " plane corresponds to a whole set of actual orbits with different scale \
parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " but the same elliptical shape. How do the periods of this set of orbits \
scale with the size of the orbit? (This scaling is sometimes referred to as \
Kepler's third law.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find the Hamiltonian ",
  StyleBox["H",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\((r\&_, r\&_\^\[Prime])\)\)]],
  " associated with the motion described above. Plot a few curves of constant \
",
  StyleBox["H",
    FontSlant->"Italic"],
  " on top of the direction field, verifying that the field is everywhere \
tangent to the flow."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Magnetic and electric fields are often visualized by drawing the ",
  StyleBox["field lines",
    FontSlant->"Italic"],
  " associated with these fields. These field lines are the trajectories \
through space that are everywhere tangent to the given field. Thus, they are \
analogous to the trajectories followed by particles as they propagate tangent \
to the direction field. Consider a field line that passes through the point \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". We parametrize this field line by the displacement ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " measured along the field line from the point ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"],
          FontWeight->"Plain"], TraditionalForm]]],
  ". Thus, the field line is given by a curve through space, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "s", ")"}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "0", ")"}], "=", 
          StyleBox[
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"],
            FontWeight->"Plain"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tA displacement ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[DifferentialD]", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " along the field line with magnitude ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]s\)]],
  " is in the direction of the local field: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[DifferentialD]", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{\(\[DifferentialD]s\), " ", 
              RowBox[{
                RowBox[{
                  StyleBox["E",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["(",
                    FontWeight->"Plain"], 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ")"}], "/"}]}], "|", 
            RowBox[{
              StyleBox["E",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox["|",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". Dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]s\)]],
  " yields the following differential equation for the field line:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[DifferentialD]\/\[DifferentialD]s\), 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["s",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["E",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], "/"}], "|", 
            RowBox[{
              StyleBox["E",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox["|",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->{"(1.2.24)", "i:36"}],

Cell[TextData[{
  "Equation ",
  ButtonBox["(1.2.24)",
    ButtonData:>"(1.2.24)",
    ButtonStyle->"Hyperlink"],
  " is a set of coupled first",
  "-order",
  " ODEs for the components of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox["s",
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", with initial condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "0", ")"}], "=", 
          StyleBox[
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using ",
  StyleBox["PlotVectorField",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", plot the electric field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["E",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(x, y\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(-\[Del]\(\[Phi](x, y)\)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " that arises from the following electrostatic potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\  = \ x\^2 - y\^2\)]],
  "."
}], "Text"],

Cell[TextData[{
  "(This field satisfies Laplace's equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 0\)]],
  " .) Make the plot in the ranges  ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) < x < 2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) < y < 2\)]],
  "  ."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that for this potential, Eq. ",
  ButtonBox["(1.2.24)",
    ButtonData:>"(1.2.24)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y/\[DifferentialD]x\  = \ \(-y\)/
          x\)]],
  " along a field line. Solve this ODE analytically to obtain the general \
solution for  ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ", and plot the resulting field lines in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane for initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_o, y\_o)\)\  = \ \((m, \ n)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(-1\), 0, 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(-1\), 0, 1\)]],
  " (nine plots in all). Then superimpose these plots on the previous plot of \
the field. [Hint 1: Make a table of plots, then use a single ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command to superimpose them.] Hint 2: ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[DifferentialD]x/\[DifferentialD]s)\)\ /\ \((\
\[DifferentialD]y/\[DifferentialD]s)\)\  = \ \[DifferentialD]x/\
\[DifferentialD]y\)]],
  ".]"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["1.3 Analytic Solution of ",
    FontFamily->"Helvetica",
    FontSlant->"Plain"],
  StyleBox["Initial-Value",
    FontSlant->"Plain"],
  StyleBox[" Problems via ",
    FontFamily->"Helvetica",
    FontSlant->"Plain"],
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Subtitle",
  FontSlant->"Italic",
  CellTags->{"Sec. 1.3", "c:16"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "1.3.1 ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Subsubtitle",
  CellTags->"c:17"],

Cell[TextData[{
  "The solution to some  (but not all) ODEs can be determined analytically. \
This section will discuss how to use ",
  StyleBox["Mathematica's",
    FontSlant->"Italic"],
  " analytic differential equation solver ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in order to find these analytic solutions. "
}], "Text"],

Cell["\<\
\tConsider a simple differential equation with an analytic \
solution, such as the harmonic oscillator equation\
\>", "Text",
  CellTags->"i:29"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 x\/\[DifferentialD]t\^2 = \(-\
\[Omega]\_o\^2\) x\)]],
  "."
}], "NE3",
  CellTags->"(1.3.1)"],

Cell[TextData[{
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can provide the general solution to this second",
  "-order",
  " ODE . The syntax is as follows:"
}], "Text"],

Cell[TextData[{
  StyleBox["\tDSolve[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ODE, unknown function, independent variable",
    FontSlant->"Italic"],
  StyleBox["].",
    FontWeight->"Bold"]
}], "Text",
  CellTags->"i:30"],

Cell[TextData[{
  "The ODE is written as a ",
  StyleBox["logical",
    FontSlant->"Italic"],
  " expression, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SuperscriptBox[
                StyleBox["x",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[DoublePrime]"],
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["t",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], 
          StyleBox["==",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox[\(-\[Omega]\_o\^2\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["x",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["t",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  " . ",
  StyleBox["Note that in the ODE you must refer to ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["t",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["not merely ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  StyleBox[" as we did in",
    FontSlant->"Italic"],
  " ",
  ButtonBox["Eq. (1.3.1)",
    ButtonData:>"(1.3.1)",
    ButtonStyle->"Hyperlink"],
  StyleBox[".",
    FontWeight->"Bold"],
  " The unknown function is ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " in this example. Then we specify the independent variable ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", and evaluate the cell: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\(x''\)[t] \[Equal] \(-\[Omega]\_o^2\)\ x[t], x[t], 
      t]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.7"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          C[2]\ Cos[t\ \[Omega]\_o] + C[1]\ Sin[t\ \[Omega]\_o]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a list of solutions (in this case there is only one \
solution), written in terms of two undetermined constants, ",
  StyleBox["C[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["C[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". As we know, these constants  are set by specifying initial conditions. "
}], "Text"],

Cell[TextData[{
  "\tIt is possible to obtain a unique solution",
  StyleBox[" ",
    FontSlant->"Italic"],
  "to the ODE by specifying particular initial conditions in ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Now the syntax is "
}], "Text"],

Cell[TextData[{
  StyleBox["\tDSolve[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["{",
    FontFamily->"Courier"],
  StyleBox["ODE, initial conditions",
    FontSlant->"Italic"],
  "},",
  StyleBox["unknown function, independent variable",
    FontSlant->"Italic"],
  StyleBox["]. ",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "Just as with the ODE, the initial conditions are specified by ",
  StyleBox["logical",
    FontSlant->"Italic"],
  " expressions, ",
  StyleBox["not",
    FontSlant->"Italic"],
  " assignments, for example,   ",
  StyleBox["x[0]==x0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["v[0]== v0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\(x''\)[
            t] \[Equal] \(-\[Omega]\_o^2\)\ x[
              t], \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ x[
            0] \[Equal] x0, \(x'\)[0] \[Equal] v0}, x[t], t]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.8"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          x0\ Cos[t\ \[Omega]\_o] + \(v0\ Sin[t\ \
\[Omega]\_o]\)\/\[Omega]\_o}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As expected, the result matches our previous solution, ",
  ButtonBox["Eq. (1.1.9)",
    ButtonData:>"(1.1.9)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can also be used to provide solutions to systems of coupled ODEs. Now, \
one provides a list of ODEs in the first argument, along with a list of the \
unknown functions in the second argument. For instance, consider the \
following coupled ODEs, which describe a set of two coupled harmonic \
oscillators with positions ",
  StyleBox["x1[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["x2[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and with given initial conditions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\(x1''\)[t] \[Equal] \(-x1[t]\)\  + \ 
            2 \((x2[t] - 
                  x1[t])\), \ \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(x2''\)[t] \[Equal] \(-x2[t]\)\  + \ 2\ \((x1[t] - x2[t])\), 
        x1[0] \[Equal] 0, \(x1'\)[0] \[Equal] 0, 
        x2[0] \[Equal] 1, \(x2'\)[0] \[Equal] 0}, {x1[t], x2[t]}, 
      t]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.9"],

Cell[BoxData[
    \({{x1[
            t] \[Rule] \(-\(1\/4\)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
t - \[ImaginaryI]\ \@5\ t\)\ \((\[ExponentialE]\^\(\[ImaginaryI]\ t\) - \
\[ExponentialE]\^\(\[ImaginaryI]\ \@5\ t\) - \[ExponentialE]\^\(2\ \
\[ImaginaryI]\ t + \[ImaginaryI]\ \@5\ t\) + \[ExponentialE]\^\(\[ImaginaryI]\
\ t + 2\ \[ImaginaryI]\ \@5\ t\))\), 
        x2[t] \[Rule] 
          1\/4\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ t - \[ImaginaryI]\ \@5\
\ t\)\ \((\[ExponentialE]\^\(\[ImaginaryI]\ t\) + \[ExponentialE]\^\(\
\[ImaginaryI]\ \@5\ t\) + \[ExponentialE]\^\(2\ \[ImaginaryI]\ t + \
\[ImaginaryI]\ \@5\ t\) + \[ExponentialE]\^\(\[ImaginaryI]\ t + 2\ \
\[ImaginaryI]\ \@5\ t\))\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " found the solution, although it is not in the simplest possible form. For \
example, ",
  StyleBox["x1[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be simplified by applying ",
  StyleBox["FullSimplify",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[x1[t] /. %[\([1]\)]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.10"],

Cell[BoxData[
    \(1\/2\ \((Cos[t] - Cos[\@5\ t])\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\tMathematica ",
    FontSlant->"Italic"],
  " knows how to solve a large number of quite complex ODEs analytically. For \
example, it can find the solution to a harmonic oscillator ODE where the \
square of natural frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " is time-dependent, decreasing linearly with time : ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\%2 = \(-\ t\)\)]],
  " .  This ODE is called the",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Airy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Airy.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["equation",
    FontSlant->"Italic"],
  ":"
}], "Text",
  CellTags->"i:31"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[DoublePrime]\)(t) = t\ \(x(t)\)\)]],
  "."
}], "NE3",
  CellTags->"(1.3.2)"],

Cell["The general solution to this equation is ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\(x''\)[t]\  - \ t\ x[t] \[Equal] 0, x[t], t]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.11"],

Cell[BoxData[
    \({{x[t] \[Rule] AiryAi[t]\ C[1] + AiryBi[t]\ C[2]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The two independent solutions to the ODE are special functions called ",
  StyleBox["Airy ",
    FontSlant->"Italic"],
  " functions, ",
  Cell[BoxData[
      \(TraditionalForm\`Ai(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Bi(x)\)]],
  ". These are called special functions in order to distinguish them from the \
elementary functions  such as ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ x\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`log\ x\)]],
  " that appear on your calculator. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  refers to these functions as ",
  StyleBox["AiryAi[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["AiryBi[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These are only two of the huge number of special functions that ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "knows. Just as for the elementary functions, one can plot these special \
functions, as shown in Cell ",
  ButtonBox["1.12",
    ButtonData:>"Cell 1.12",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:133"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(Plot[{AiryAi[x], AiryBi[x]}, {x, \(-10\), 3}, 
        PlotStyle \[Rule] {Red, Green}, 
        PlotLabel \[Rule] 
          TableForm[{{StyleForm["\<Ai[x]\>", 
                  FontColor \[Rule] RGBColor[1, 0, 0]], "\<,\>", 
                StyleForm["\<Bi[x]\>", FontColor \[Rule] Green]}}, 
            TableSpacing \[Rule] 0]];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.12"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.75641 0.0732601 0.152891 0.303742 [
[.02381 .14039 -9 -9 ]
[.02381 .14039 9 0 ]
[.17033 .14039 -6 -9 ]
[.17033 .14039 6 0 ]
[.31685 .14039 -6 -9 ]
[.31685 .14039 6 0 ]
[.46337 .14039 -6 -9 ]
[.46337 .14039 6 0 ]
[.60989 .14039 -6 -9 ]
[.60989 .14039 6 0 ]
[.90293 .14039 -3 -9 ]
[.90293 .14039 3 0 ]
[.74391 .00102 -24 -4.5 ]
[.74391 .00102 0 4.5 ]
[.74391 .30476 -18 -4.5 ]
[.74391 .30476 0 4.5 ]
[.74391 .45663 -6 -4.5 ]
[.74391 .45663 0 4.5 ]
[.74391 .6085 -18 -4.5 ]
[.74391 .6085 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12.3125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .15289 m
.02381 .15914 L
s
[(-10)] .02381 .14039 0 1 Mshowa
.17033 .15289 m
.17033 .15914 L
s
[(-8)] .17033 .14039 0 1 Mshowa
.31685 .15289 m
.31685 .15914 L
s
[(-6)] .31685 .14039 0 1 Mshowa
.46337 .15289 m
.46337 .15914 L
s
[(-4)] .46337 .14039 0 1 Mshowa
.60989 .15289 m
.60989 .15914 L
s
[(-2)] .60989 .14039 0 1 Mshowa
.90293 .15289 m
.90293 .15914 L
s
[(2)] .90293 .14039 0 1 Mshowa
.125 Mabswid
.06044 .15289 m
.06044 .15664 L
s
.09707 .15289 m
.09707 .15664 L
s
.1337 .15289 m
.1337 .15664 L
s
.20696 .15289 m
.20696 .15664 L
s
.24359 .15289 m
.24359 .15664 L
s
.28022 .15289 m
.28022 .15664 L
s
.35348 .15289 m
.35348 .15664 L
s
.39011 .15289 m
.39011 .15664 L
s
.42674 .15289 m
.42674 .15664 L
s
.5 .15289 m
.5 .15664 L
s
.53663 .15289 m
.53663 .15664 L
s
.57326 .15289 m
.57326 .15664 L
s
.64652 .15289 m
.64652 .15664 L
s
.68315 .15289 m
.68315 .15664 L
s
.71978 .15289 m
.71978 .15664 L
s
.79304 .15289 m
.79304 .15664 L
s
.82967 .15289 m
.82967 .15664 L
s
.8663 .15289 m
.8663 .15664 L
s
.93956 .15289 m
.93956 .15664 L
s
.97619 .15289 m
.97619 .15664 L
s
.25 Mabswid
0 .15289 m
1 .15289 L
s
.75641 .00102 m
.76266 .00102 L
s
[(-0.5)] .74391 .00102 1 0 Mshowa
.75641 .30476 m
.76266 .30476 L
s
[(0.5)] .74391 .30476 1 0 Mshowa
.75641 .45663 m
.76266 .45663 L
s
[(1)] .74391 .45663 1 0 Mshowa
.75641 .6085 m
.76266 .6085 L
s
[(1.5)] .74391 .6085 1 0 Mshowa
.125 Mabswid
.75641 .03139 m
.76016 .03139 L
s
.75641 .06177 m
.76016 .06177 L
s
.75641 .09214 m
.76016 .09214 L
s
.75641 .12252 m
.76016 .12252 L
s
.75641 .18327 m
.76016 .18327 L
s
.75641 .21364 m
.76016 .21364 L
s
.75641 .24401 m
.76016 .24401 L
s
.75641 .27439 m
.76016 .27439 L
s
.75641 .33514 m
.76016 .33514 L
s
.75641 .36551 m
.76016 .36551 L
s
.75641 .39588 m
.76016 .39588 L
s
.75641 .42626 m
.76016 .42626 L
s
.75641 .48701 m
.76016 .48701 L
s
.75641 .51738 m
.76016 .51738 L
s
.75641 .54776 m
.76016 .54776 L
s
.75641 .57813 m
.76016 .57813 L
s
.25 Mabswid
.75641 0 m
.75641 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.3125 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Ai) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(@) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
87.000 13.000 moveto
(D) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
93.000 13.000 moveto
(,) show
99.000 13.000 moveto
0.000 0.000 rmoveto
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
(Bi) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
111.000 13.000 moveto
(@) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
123.000 13.000 moveto
(D) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .16511 m
.03279 .20037 L
.03793 .21775 L
.04262 .23087 L
.04758 .24137 L
.0503 .2455 L
.05156 .24698 L
.05288 .24827 L
.05402 .24913 L
.05527 .24982 L
.0564 .25022 L
.05747 .25039 L
.05872 .25033 L
.05987 .25004 L
.06119 .24943 L
.06244 .24857 L
.06381 .24734 L
.0651 .24589 L
.0675 .24247 L
.07289 .23156 L
.07755 .21892 L
.08259 .20249 L
.10458 .11658 L
.10956 .09866 L
.11489 .08192 L
.11984 .06933 L
.12452 .06042 L
.12703 .05697 L
.12836 .05554 L
.12977 .05432 L
.13095 .05353 L
.13226 .05293 L
.13345 .05261 L
.13456 .05251 L
.1352 .05255 L
.13591 .05266 L
.13664 .05286 L
.13733 .05313 L
.13855 .05378 L
.13986 .05474 L
.14141 .05621 L
.14286 .05793 L
.14558 .06198 L
.15021 .07123 L
.1553 .0845 L
.1656 .11889 L
.18405 .18985 L
.19403 .22291 L
.19894 .23581 L
.2035 .24524 L
Mistroke
.20603 .24934 L
.20872 .25274 L
.21026 .25424 L
.21171 .25534 L
.21301 .25608 L
.21374 .25639 L
.21441 .2566 L
.21561 .25683 L
.21673 .25685 L
.21796 .25667 L
.21927 .25625 L
.21993 .25594 L
.22065 .25554 L
.22195 .25462 L
.22439 .25227 L
.22673 .24927 L
.22925 .24524 L
.23381 .23599 L
.2442 .20689 L
.26522 .13037 L
.27563 .0943 L
.2853 .06757 L
.29018 .05753 L
.29269 .05342 L
.29539 .04979 L
.29694 .04812 L
.29837 .04683 L
.2997 .04586 L
.30041 .04543 L
.30117 .04504 L
.30249 .04454 L
.30372 .04426 L
.30444 .04419 L
.30513 .04418 L
.30642 .04432 L
.30755 .04462 L
.30878 .04512 L
.30993 .04576 L
.31099 .04649 L
.31346 .0487 L
.31605 .05181 L
.32095 .0597 L
.3263 .07116 L
.34471 .12708 L
.36594 .20136 L
.37598 .23098 L
.38524 .25167 L
.38991 .25916 L
.39227 .26213 L
.39486 .26474 L
Mistroke
.39746 .26667 L
.39892 .26744 L
.39961 .26773 L
.40025 .26796 L
.40149 .26827 L
.40215 .26837 L
.40284 .26843 L
.40413 .2684 L
.4053 .26823 L
.40649 .26791 L
.40774 .26741 L
.40882 .26686 L
.40999 .26613 L
.41262 .26399 L
.41506 .2614 L
.4195 .25527 L
.42425 .24679 L
.43444 .22288 L
.44551 .19027 L
.46564 .12417 L
.48542 .06705 L
.49542 .04612 L
.5011 .0373 L
.50387 .03388 L
.50644 .03122 L
.5089 .02916 L
.51114 .02769 L
.51233 .02707 L
.51362 .02652 L
.51434 .02627 L
.51499 .02608 L
.51628 .0258 L
.51752 .02565 L
.51868 .02562 L
.51995 .0257 L
.52066 .02581 L
.52131 .02593 L
.52262 .02628 L
.52404 .02681 L
.52664 .02816 L
.52908 .02988 L
.53129 .03181 L
.53624 .03733 L
.54514 .05116 L
.55521 .07194 L
.56444 .09474 L
.58528 .15337 L
.60576 .21117 L
.62484 .25703 L
.63429 .27529 L
Mistroke
.64322 .28946 L
.64816 .29595 L
.65352 .30191 L
.65803 .30606 L
.66289 .30966 L
.66543 .31119 L
.66776 .31238 L
.67012 .31339 L
.67232 .31416 L
.67487 .31483 L
.67621 .3151 L
.67765 .31532 L
.67831 .3154 L
.67902 .31547 L
.68031 .31556 L
.68156 .31559 L
.68271 .31558 L
.68393 .31552 L
.68523 .31541 L
.68647 .31526 L
.68759 .31508 L
.69033 .3145 L
.69294 .31377 L
.69811 .31179 L
.70374 .30892 L
.71313 .30269 L
.72351 .29415 L
.74451 .27342 L
.7847 .23126 L
.82338 .19829 L
.84341 .18563 L
.8645 .17542 L
.88424 .16837 L
.9026 .16357 L
.91312 .16145 L
.92305 .1598 L
.93207 .15855 L
.94163 .15745 L
.95019 .15663 L
.95961 .15588 L
.97619 .15489 L
Mfstroke
0 1 0 r
.02381 .05731 m
.02499 .05801 L
.02605 .05887 L
.02846 .06151 L
.03068 .06482 L
.03279 .0687 L
.0375 .07982 L
.04262 .09521 L
.06244 .1725 L
.07308 .21202 L
.07844 .22802 L
.08153 .23558 L
.08435 .24132 L
.08676 .24526 L
.08938 .24852 L
.09082 .24984 L
.09152 .25036 L
.09216 .25076 L
.09344 .25136 L
.09414 .25158 L
.0948 .2517 L
.09599 .25175 L
.09724 .25155 L
.09832 .25117 L
.0995 .25053 L
.10076 .24959 L
.10213 .24829 L
.10458 .24522 L
.10714 .24102 L
.10986 .23553 L
.11475 .22318 L
.12582 .18608 L
.1355 .14805 L
.14594 .10799 L
.15089 .09125 L
.1561 .07614 L
.16055 .06572 L
.1631 .06091 L
.16541 .05732 L
.16777 .05446 L
.16999 .05251 L
.17121 .05175 L
.17234 .05125 L
.17357 .05092 L
.17488 .05083 L
.17593 .05094 L
.17705 .05124 L
.17811 .05169 L
.17908 .05226 L
.18144 .05421 L
Mistroke
.18369 .05682 L
.18629 .06072 L
.18874 .0652 L
.1933 .07558 L
.20354 .10659 L
.22194 .17564 L
.23173 .21024 L
.23707 .22631 L
.24205 .23881 L
.24631 .24731 L
.2485 .25081 L
.25087 .25394 L
.25222 .25539 L
.25347 .25652 L
.25464 .25739 L
.25593 .25814 L
.25709 .25862 L
.25817 .25891 L
.25931 .25904 L
.26054 .25899 L
.2618 .25873 L
.26295 .25831 L
.26427 .2576 L
.26551 .25673 L
.26773 .25468 L
.27014 .25176 L
.27559 .24255 L
.28062 .23118 L
.29088 .20101 L
.30173 .16274 L
.31191 .1255 L
.32157 .09304 L
.33024 .06903 L
.33513 .05836 L
.33967 .05064 L
.34183 .04774 L
.34416 .04519 L
.34549 .04401 L
.34671 .0431 L
.34796 .04235 L
.34912 .04181 L
.35024 .04143 L
.35145 .0412 L
.35214 .04113 L
.35279 .04113 L
.35401 .04124 L
.35529 .04155 L
.35648 .04199 L
.35778 .04267 L
.35916 .04359 L
Mistroke
.36163 .04577 L
.3643 .04885 L
.36911 .05625 L
.37483 .0679 L
.38006 .08093 L
.40067 .14651 L
.41979 .21028 L
.42932 .23657 L
.43829 .25563 L
.44326 .26337 L
.44587 .26657 L
.44863 .26929 L
.45096 .27105 L
.45228 .27183 L
.45352 .2724 L
.45465 .27281 L
.45568 .27308 L
.45688 .27327 L
.458 .27333 L
.45915 .27327 L
.46037 .27308 L
.46154 .27277 L
.4626 .27238 L
.46378 .27182 L
.46507 .27108 L
.46767 .26914 L
.47024 .26665 L
.47298 .26339 L
.47793 .25603 L
.48758 .23668 L
.49635 .21444 L
.51717 .15162 L
.53636 .09343 L
.55506 .04807 L
.56448 .03191 L
.56983 .02503 L
.57243 .02232 L
.57484 .02018 L
.57746 .01825 L
.57983 .01687 L
.58246 .01573 L
.5839 .01529 L
.58455 .01513 L
.58526 .01498 L
.58647 .01481 L
.58774 .01472 L
.58892 .01472 L
.59001 .01479 L
.59131 .01497 L
.59249 .01521 L
Mistroke
.59386 .0156 L
.59514 .01606 L
.59739 .01708 L
.59977 .01847 L
.60403 .02171 L
.60863 .02623 L
.61369 .03237 L
.63309 .06536 L
.65396 .11225 L
.69517 .21349 L
.73487 .29893 L
.77305 .37099 L
.79436 .41537 L
.81368 .46552 L
.82336 .49652 L
.83382 .5363 L
Mfstroke
.83382 .5363 m
.85017 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{345.562, 213.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_00012R000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooolR0?ooo`<000001P3oool2000000D0oooo
1000001j0?ooo`00o`3ooolQ0?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000T0oooo
00<000000?ooo`3oool0M`3oool00?l0oooo6@3oool600000080oooo00D000000?ooo`3oool0oooo
0000000@0?ooo`030000003oool0oooo00@0oooo0`00001`0?ooo`00o`3ooolQ0?ooo`050000003o
ool0oooo0?ooo`000000403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0700oooo
003o0?ooob40oooo00D000000?ooo`3oool0oooo0000000<0?ooo`@000001`3oool00`000000oooo
0?ooo`1`0?ooo`00o`3ooolQ0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0700oooo003o0?ooob40oooo00D000000?ooo`3oool0oooo
0000000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L03oool00?l0oooo8P3o
ool3000000d0oooo100000070?ooo`030000003oool0oooo0700oooo003h0?ooo`H00?l0?P3oool0
0`000000oooo0?ooo`1`0?ooo`00mP3oool2003o00H0oooo0P00o`0l0?ooo`030000003oool0oooo
0700oooo003e0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0>@3oool00`000000
oooo0?ooo`1`0?ooo`00m03oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo03P0oooo
00<000000?ooo`3oool0L03oool00=d0oooo1@3o000A0?ooo`03003o003oool0oooo00`0oooo00<0
0?l00?ooo`3oool0=`3oool00`000000oooo0?ooo`1`0?ooo`00f`3oool30?l000@0oooo00<0o`00
0?ooo`3oool03@3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo03L0oooo00<00000
0?ooo`3oool0L03oool00=X0oooo00<0o`000?ooo`3oool01P3oool20?l000`0oooo00<00?l00?oo
o`3oool03`3oool00`00o`00oooo0?ooo`0f0?ooo`800000L@3oool00=T0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3o
ool0=@3oool00`000000oooo0?ooo`1`0?ooo`00f@3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo0?ooo`0e0?ooo`030000
003oool0oooo0700oooo003H0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`0B0?ooo`03003o003oool0oooo03@0oooo00<000000?ooo`3oool0L03o
ool009d0oooo1000o`0g0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool0L03oool0
08/0oooo0`3o000>0?ooo`800?l00`3oool00`00o`00oooo0?ooo`0c0?ooo`030?l0003oool0oooo
00d0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo
03<0oooo00<000000?ooo`3oool0L03oool008X0oooo0P3o00020?ooo`80o`002`3oool00`00o`00
oooo0?ooo`040?ooo`03003o003oool0oooo0340oooo00<0o`000?ooo`3oool03`3oool00`3o0000
oooo0?ooo`030?ooo`03003o003oool0oooo01H0oooo00<00?l00?ooo`3oool0<P3oool00`000000
oooo0?ooo`1`0?ooo`00R03oool20?l000D0oooo00<0o`000?ooo`3oool0203oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0oooo0300oooo00<0o`000?ooo`3oool0403oool01@3o0000oooo
0?ooo`3oool00?l001X0oooo00<00?l00?ooo`3oool0<@3oool00`000000oooo0?ooo`1`0?ooo`00
BP3oool00`3o0000oooo0?ooo`0;0?ooo`@00?l0;03oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo00L0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0_0?ooo`030?l0
003oool0oooo0180oooo00@0o`000?ooo`3oool00?l06P3oool00`00o`00oooo0?ooo`0a0?ooo`03
0000003oool0oooo0700oooo00180?ooo`D0o`002P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo02P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03003o
003oool0oooo00L0oooo00<00?l00?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0
003oool00?l001`0oooo00<00?l00?ooo`3oool0<03oool00`000000oooo0?ooo`1`0?ooo`007`3o
ool00`00o`00oooo0?ooo`0U0?ooo`80o`00103oool00`3o0000oooo0?ooo`060?ooo`03003o003o
ool0oooo00@0oooo00<00?l00?ooo`3oool09P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003o
ool0oooo00D0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`0/0?ooo`030?l0003o
ool0oooo01@0oooo00<0o`00003o003oool0703oool00`00o`00oooo0?ooo`0_0?ooo`030000003o
ool0oooo0700oooo000O0?ooo`800?l09P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0V0?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0
oooo02`0oooo00<0o`000?ooo`3oool0503oool00`3o00000?l00?ooo`0L0?ooo`03003o003oool0
oooo02l0oooo00<000000?ooo`3oool0L03oool00240oooo00<00?l00?ooo`3oool08P3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool01P3oool00`00
o`00oooo0?ooo`0U0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool05@3oool00`00
o`00oooo0?ooo`0M0?ooo`03003o003oool0oooo02h0oooo0P00001a0?ooo`008P3oool00`00o`00
oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00o`00
oooo0?ooo`070?ooo`03003o003oool0oooo02<0oooo00<0o`000?ooo`3oool02`3oool01@3o0000
oooo0?ooo`3oool00?l000h0oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0E0?oo
o`03003o003o0000oooo01h0oooo00<00?l00?ooo`3oool0;@3oool00`000000oooo0?ooo`1`0?oo
o`008P3oool00`00o`00oooo0?ooo`0P0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo02<0oooo00<0o`000?ooo`3o
ool02`3oool01@3o0000oooo0?ooo`3oool00?l000l0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0E0?ooo`03003o003oool0o`0001l0oooo00<00?l00?ooo`3oool0;@3oool00`00
0000oooo0?ooo`1`0?ooo`008P3oool00`00o`00oooo0?ooo`0O0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo0280
oooo00<0o`000?ooo`3oool02`3oool0103o0000oooo0?ooo`00o`0@0?ooo`03003o003oool0oooo
02P0oooo00<0o`000?ooo`3oool05@3oool00`00o`00oooo0?l0000P0?ooo`03003o003oool0oooo
02`0oooo00<000000?ooo`3oool0L03oool00280oooo00<00?l00?ooo`3oool07`3oool00`3o0000
oooo0?ooo`090?ooo`040?l0003oool0oooo003o00`0oooo00<00?l00?ooo`3oool08@3oool00`3o
0000oooo0?ooo`0=0?ooo`030?l0003oool00?l00140oooo00<00?l00?ooo`3oool09`3oool00`3o
0000oooo0?ooo`0D0?ooo`05003o003oool0oooo0?ooo`3o00007`3oool00`00o`00oooo0?ooo`0/
0?ooo`030000003oool0oooo0700oooo000S0?ooo`03003o003oool0oooo01d0oooo00<0o`000?oo
o`3oool02P3oool0103o0000oooo0?ooo`00o`0=0?ooo`03003o003oool0oooo0200oooo00<0o`00
0?ooo`3oool03@3oool00`3o00000?l00?ooo`0A0?ooo`03003o003oool0oooo02H0oooo00<0o`00
0?ooo`3oool05@3oool01@00o`00oooo0?ooo`3oool0o`0001l0oooo00<00?l00?ooo`3oool0;03o
ool00`000000oooo0?ooo`1`0?ooo`008`3oool00`00o`00oooo0?ooo`0M0?ooo`030?l0003oool0
oooo00/0oooo00<0o`00003o003oool03@3oool00`00o`00oooo0?ooo`0P0?ooo`030?l0003oool0
oooo00h0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`0V0?ooo`030?l0003oool0
oooo01D0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0M0?ooo`03003o003oool0
oooo02/0oooo00<000000?ooo`3oool0L03oool002@0oooo00<00?l00?ooo`3oool0703oool00`3o
0000oooo0?ooo`0;0?ooo`030?l00000o`00oooo00h0oooo00<00?l00?ooo`3oool07P3oool00`3o
0000oooo0?ooo`0?0?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool09@3oool00`3o
0000oooo0?ooo`0D0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool07@3oool00`00
o`00oooo0?ooo`0[0?ooo`030000003oool0oooo0700oooo000T0?ooo`03003o003oool0oooo01/0
oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo01h0
oooo00<0o`000?ooo`3oool03P3oool00`00o`00o`000?ooo`0B0?ooo`03003o003oool0oooo02@0
oooo00<0o`000?ooo`3oool05@3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo01d0
oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?ooo`1`0?ooo`009@3oool00`00o`00oooo
0?ooo`0J0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?l0003oool03P3oool00`00o`00oooo
0?ooo`0N0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3o00004P3oool00`00o`00oooo
0?ooo`0T0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0M0?ooo`03003o003oool0oooo02X0oooo00<000000?ooo`3oool0L03oool002D0oooo00<0
0?l00?ooo`3oool06@3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003o0000oooo00l0oooo00<0
0?l00?ooo`3oool0703oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0o`0001<0oooo00<0
0?l00?ooo`3oool08`3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo00D0oooo00<0
o`000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0Y0?ooo`030000003oool0oooo0700oooo000U
0?ooo`03003o003oool0oooo01T0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?l0000@
0?ooo`03003o003oool0oooo01`0oooo00<0o`000?ooo`3oool03P3oool01000o`00oooo0?ooo`3o
000C0?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool05@3oool00`00o`00oooo0?oo
o`060?ooo`030?l0003oool0oooo01d0oooo00<00?l00?ooo`3oool0:@3oool00`000000oooo0?oo
o`1`0?ooo`009P3oool00`00o`00oooo0?ooo`0H0?ooo`030?l0003oool0oooo00`0oooo00@00?l0
0?ooo`3oool0o`003`3oool00`00o`00oooo0?ooo`0L0?ooo`030?l0003oool0oooo00h0oooo00D0
0?l00?ooo`3oool0oooo0?l0000B0?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool0
503oool00`00o`00oooo0?ooo`070?ooo`030?l0003oool0oooo01d0oooo00<00?l00?ooo`3oool0
:@3oool200000740oooo000V0?ooo`03003o003oool0oooo01L0oooo00<0o`000?ooo`3oool03@3o
ool01000o`00oooo0?ooo`3o000@0?ooo`03003o003oool0oooo01X0oooo00<0o`000?ooo`3oool0
3`3oool01@00o`00oooo0?ooo`3oool0o`0001<0oooo00<00?l00?ooo`3oool08@3oool00`3o0000
oooo0?ooo`0D0?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool07@3oool00`00o`00
oooo0?ooo`0X0?ooo`030000003oool0oooo0700oooo000V0?ooo`03003o003oool0oooo01L0oooo
00<0o`000?ooo`3oool0303oool01@00o`00oooo0?ooo`3oool0o`000100oooo00<00?l00?ooo`3o
ool06P3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool0403oool00`00o`00oooo0?ooo`0P0?ooo`030?l0003oool0oooo01D0oooo00<00?l00?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0M0?ooo`03003o003oool0oooo02P0oooo00<000000?ooo`3o
ool0L03oool002H0oooo00<00?l00?ooo`3oool05`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o
003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0J0?ooo`030?l0
003oool0oooo00h0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0@0?ooo`03003o
003oool0oooo0200oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`0:0?ooo`030?l0
003oool0oooo01d0oooo00<00?l00?ooo`3oool09`3oool00`000000oooo0?ooo`1`0?ooo`009`3o
ool00`00o`00oooo0?ooo`0F0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo01P0oooo00<0o`000?ooo`3oool03`3o
ool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool07`3o
ool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`3oool07@3o
ool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo0700oooo000W0?ooo`03003o003oool0
oooo01D0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0
oooo00h0oooo00<00?l00?ooo`3oool0603oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0
oooo00@0oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0N0?ooo`030?l0003oool0
oooo01D0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo0?ooo`0N0?ooo`03003o003oool0
oooo02H0oooo00<000000?ooo`3oool0L03oool002L0oooo00<00?l00?ooo`3oool05@3oool00`3o
0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool03@3oool00`00
o`00oooo0?ooo`0H0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0@0?ooo`03003o003oool0oooo01h0oooo00<0o`000?ooo`3oool0503oool00`00
o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo01d0oooo00<00?l00?ooo`3oool09P3oool00`00
0000oooo0?ooo`1`0?ooo`009`3oool00`00o`00oooo0?ooo`0E0?ooo`030?l0003oool0oooo00`0
oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo01L0
oooo00<0o`000?ooo`3oool03`3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo0100
oooo00<00?l00?ooo`3oool07@3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo00`0
oooo00<0o`000?ooo`3oool07@3oool00`00o`00oooo0?ooo`0V0?ooo`030000003oool0oooo0700
oooo000X0?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo
0?ooo`040?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool05P3oool00`3o0000oooo
0?ooo`0?0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo
0?ooo`0L0?ooo`030?l0003oool0oooo01D0oooo00<00?l00?ooo`3oool0303oool00`3o0000oooo
0?ooo`0N0?ooo`03003o003oool0oooo02D0oooo00<000000?ooo`3oool0L03oool002P0oooo00<0
0?l00?ooo`3oool04`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00H0oooo00<0
o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0F0?ooo`030?l0003oool0oooo00h0oooo00<0
0?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo01`0oooo00<0
o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo01d0oooo00<0
0?l00?ooo`3oool09@3oool00`000000oooo0?ooo`1`0?ooo`007@3oool5000000<0oooo0`000000
0`00o`00oooo0?ooo`0C0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool01P3oool0
103o0000oooo0?ooo`3oool3000000T0oooo00<00?l00?ooo`3oool05P3oool00`3o0000oooo0?oo
o`0>0?ooo`03003o003oool0oooo00<000001@3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003o
ool0oooo01`0oooo00@0o`0000000000000000004`3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00d0oooo1@00000<0?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool0
<`3oool5000003P0oooo000O0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0oooo
00000000o`0D0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool01P3oool0103o0000
oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool05@3oool00`3o
0000oooo0?ooo`0?0?ooo`03003o003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0@0?ooo`03003o003oool0oooo01X0oooo00@0o`000?ooo`3oool00000503oool0
0`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00@000000?ooo`3oool00000303o
ool00`00o`00oooo0?ooo`0T0?ooo`030000003oool0oooo03@0oooo00@000000?ooo`3oool00000
>03oool001@0oooo1P0000050?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0oooo
00000000o`0C0?ooo`030?l0003oool0oooo00d0oooo00@00?l00?ooo`3oool0oooo1@000000103o
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3oool0503oool0
0`3o0000oooo0?ooo`090?ooo`D0000000@00?l00?ooo`3oool000000`3oool00`000000oooo0?oo
o`020?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool04P3oool600000080oooo00<0
o`000000000000000P00000B0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool0103o
ool6000000@0oooo00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`0T0?ooo`800000=P3o
ool00`000000oooo0?ooo`0h0?ooo`007`3oool00`000000oooo0?ooo`020?ooo`060000003oool0
oooo0?ooo`0000000?l04`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00P0oooo
00<0o`000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo01@0oooo
00<0o`000?ooo`3oool03P3oool01000o`00oooo0?ooo`0000030?ooo`030000003oool0oooo00<0
oooo00<0o`000?ooo`3oool03`3oool00`00o`00oooo0?ooo`0J0?ooo`040?l0003oool0oooo0000
01<0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo
00`0oooo00<00?l00?ooo`3oool08`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
03L0oooo000O0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0oooo00000000o`0C
0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`03
000000X0oooo00<00?l00?ooo`3oool04`3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0
oooo00@000001P3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo01T0oooo00@0o`00
0000003oool000004`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo00<0
00000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0=P3oool001l0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3o
ool000000?ooo`00o`004P3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00P0oooo
00<0o`000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo01<0oooo
00<0o`000?ooo`3oool03`3oool01000o`00oooo0?ooo`0000090?ooo`030?l0003oool0oooo0100
oooo00<00?l00?ooo`3oool0603oool01@3o0000oooo0000003oool0000001<0oooo00<00?l00?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<00?l00?oo
o`3oool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo000O0?ooo`03
0000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool00?l00140oooo00<0o`00
0?ooo`3oool03@3oool00`00o`00oooo0?ooo`080?ooo`030?l0003oool0000000<0oooo00<00000
0?ooo`3oool0203oool00`00o`00oooo0?ooo`0B0?ooo`030?l0003oool0oooo00h0oooo00<00?l0
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo00l0oooo00<00?l0
0?ooo`3oool0603oool00`3o0000oooo0?ooo`0200000180oooo00<00?l00?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`00o`00oooo0?oo
o`0R0?ooo`030000003oool0oooo03<0oooo00D000000?ooo`3oool0oooo0000000h0?ooo`007@3o
ool3000000D0oooo0`0000020?ooo`03003o003oool0oooo00l0oooo00<0o`000?ooo`3oool0303o
ool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool00000008000002`3oool00`00o`00oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool00`3oool3000000H0oooo00<0
o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0G0?ooo`050?l0003oool0oooo0?ooo`000000
4P3oool00`00o`00oooo0?ooo`0B0?ooo`030?l0003oool0oooo00`0oooo0`00000?0?ooo`03003o
003oool0oooo0280oooo00<000000?ooo`3oool0=03oool3000003T0oooo000Z0?ooo`03003o003o
ool0oooo00l0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00d0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003o
ool0oooo00`0oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo01D0oooo00<00?l00?ooo`3oool04`3oool00`3o0000oooo0?ooo`0N0?ooo`03003o003o
ool0oooo0240oooo00<000000?ooo`3oool0L03oool002/0oooo00<00?l00?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool0
0`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo01H0oooo00<0o`000?ooo`3oool0503oool0
0`00o`00oooo0?ooo`0D0?ooo`030?l0003oool0oooo01h0oooo00<00?l00?ooo`3oool08@3oool0
0`000000oooo0?ooo`1`0?ooo`00:`3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00`0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo
0100oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo
0100oooo00<00?l00?ooo`3oool05@3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo
01@0oooo00<0o`000?ooo`3oool07`3oool00`00o`00oooo0?ooo`0P0?ooo`030000003oool0oooo
0700oooo000[0?ooo`03003o003oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`00o`00
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0?0?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3oool0403oool00`00o`00
oooo0?ooo`0D0?ooo`030?l0003oool0oooo01D0oooo00<00?l00?ooo`3oool05@3oool00`3o0000
oooo0?ooo`0N0?ooo`03003o003oool0oooo0200oooo00<000000?ooo`3oool0L03oool002/0oooo
00<00?l00?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00`0oooo
00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo
00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo01@0oooo
00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`0F0?ooo`030?l0003oool0oooo01l0oooo
00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`1`0?ooo`005P3ooolF00000003003o0000
0000000000`0000000<0o`00000000000000300000000`00o`0000000000000<000000030?l00000
0000000000h0000000<00?l00000000000003P0000000`3o000000000000000>00000003003o0000
000000000100000000<0o`000000000000003`0000000`00o`0000000000000D000000030?l00000
0000000001@0000000<00?l00000000000005P0000000`3o000000000000000O00000003003o0000
0000000007h00000503oool001l0oooo00<000000?ooo`3oool02P3oool00`00o`0000000?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool02`3oool00`000000o`000?ooo`0;
0?ooo`050000003oool0oooo0?ooo`00o`002@3oool00`000000oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?ooo`030000003o
ool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`03003o003o
ool0oooo00H0oooo00<000000?ooo`3oool02@3oool0103o0000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00@0oooo00<00?l00?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00H0oooo00<00?l00?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00P0oooo103o000M0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`03003o0000
0000oooo00/0oooo00<0o`000000003oool0303oool00`00o`0000000?ooo`0<0?ooo`030000003o
ool0o`0000/0oooo00D000000?ooo`3oool0oooo003o00090?ooo`030000003oool0oooo00<0oooo
00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`040?l0003oool0oooo000000d0
oooo00<000000?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01`3oool01@00o`00oooo0?ooo`3oool0000000d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo303o00030?oo
o`030000003oool0oooo01/0oooo000O0?ooo`030000003oool0oooo00/0oooo00<00?l00?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00`0oooo00<000000?ooo`3o
00003`3oool00`00o`00oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3o
ool04P3oool0103o0000oooo0?ooo`00000C0?ooo`03003o003oool0oooo01T0oooo00<0o`000?oo
o`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`03003o003oool0oooo01h0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`030?ooo`L0o`00;@3oool002d0oooo00<00?l00?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3o
ool03P3oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3o
ool0503oool00`00o`00oooo0?ooo`0I0?ooo`030?l0003oool0oooo01l0oooo00<00?l00?ooo`3o
ool07@3oool00`000000oooo0?ooo`0h0?ooo`@0o`00=03oool001l0oooo00<0o`000?ooo`3oool0
2`3oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo00`0oooo00<0o`000?ooo`3oool0
3P3oool00`00o`00oooo0?ooo`0B0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool0
403oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo01X0oooo00<0o`000?ooo`3oool0
7`3oool00`00o`00oooo0?ooo`0M0?ooo`030000003oool0oooo0380oooo1P3o000h0?ooo`007`3o
ool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3oool03@3o
ool00`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo0180oooo00<0o`000?ooo`3oool0403o
ool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool06`3o
ool00`3o0000oooo0?ooo`0N0?ooo`03003o003oool0oooo01d0oooo00<000000?ooo`3oool0;@3o
ool50?l003h0oooo000O0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03@3oool0
0`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0503oool0
0`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<0o`000?ooo`3oool0503oool0
0`00o`00oooo0?ooo`0K0?ooo`030?l0003oool0oooo01l0oooo00<00?l00?ooo`3oool0703oool0
0`000000oooo0?ooo`0Z0?ooo`<0o`00@`3oool00200oooo00<0o`000?ooo`3oool02`3oool00`00
o`00oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0403oool00`3o
0000oooo0?ooo`0>0?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`00
o`00oooo0?ooo`0D0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0D0?ooo`03003o003oool0oooo01`0oooo00<0o`000?ooo`3oool07`3oool00`00
o`00oooo0?ooo`0L0?ooo`030000003oool0oooo02P0oooo0P3o00160?ooo`00803oool00`3o0000
oooo0?ooo`0;0?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`00o`00
oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0?0?ooo`03003o003oool0oooo01@0oooo00<0o`000?ooo`3oool0403oool00`00o`00
oooo0?ooo`0>0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool07@3oool00`3o0000
oooo0?ooo`0O0?ooo`03003o003oool0oooo01/0oooo00<000000?ooo`3oool09P3oool20?l004P0
oooo000P0?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo
0?ooo`0=0?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo
0?ooo`090?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool0503oool00`3o0000oooo
0?ooo`0A0?ooo`03003o003oool0oooo00d0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo
0?ooo`0M0?ooo`030?l0003oool0oooo01l0oooo00<00?l00?ooo`3oool06`3oool00`000000oooo
0?ooo`0T0?ooo`80o`00BP3oool00200oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?oo
o`060?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0=0?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?oo
o`0F0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool0303oool00`3o0000oooo0?oo
o`0D0?ooo`03003o003oool0oooo01h0oooo00<0o`000?ooo`3oool07`3oool00`00o`00oooo0?oo
o`0K0?ooo`030000003oool0oooo0240oooo0`3o001<0?ooo`00803oool00`3o0000oooo0?ooo`0<
0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`0B
0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`0>
0?ooo`03003o003oool0oooo01H0oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0<
0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O
0?ooo`03003o003oool0oooo01X0oooo0P00000P0?ooo`80o`00C`3oool00240oooo00<0o`000?oo
o`3oool02`3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00`0oooo00<00?l00?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo00L0oooo00<0o`000?oo
o`3oool03`3oool00`00o`00oooo0?ooo`0F0?ooo`030?l0003oool0oooo0140oooo00<00?l00?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo01l0oooo00<0o`000?oo
o`3oool07`3oool00`00o`00oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo0P3o001A0?oo
o`008@3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3o
ool0303oool00`00o`00oooo0?ooo`0C0?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo01L0oooo00<0o`000?ooo`3o
ool04@3oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3o
ool08@3oool00`3o0000oooo0?ooo`0O0?ooo`03003o003oool0oooo01T0oooo00<000000?ooo`3o
ool0703oool00`3o0000oooo0?ooo`1A0?ooo`008@3oool00`3o0000oooo0?ooo`0<0?ooo`03003o
003oool0oooo00@0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`0D0?ooo`030?l0
003oool0oooo00h0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`03003o
003oool0oooo01P0oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0:0?ooo`030?l0
003oool0oooo01@0oooo00<00?l00?ooo`3oool08@3oool00`3o0000oooo0?ooo`0O0?ooo`03003o
003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool20?l005@0oooo000Q0?ooo`030?l0003o
ool0oooo00`0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`0<0?ooo`03003o003o
ool0oooo01@0oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`060?ooo`030?l0003o
ool0oooo00h0oooo00<00?l00?ooo`3oool0603oool00`3o0000oooo0?ooo`0A0?ooo`03003o003o
ool0oooo00T0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo0200oooo00<00?l00?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo05@0oooo000Q0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo01@0oooo00<0o`000?ooo`3oool03P3oool0
0`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool0603oool0
0`3o0000oooo0?ooo`0A0?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool0503oool0
0`00o`00oooo0?ooo`0S0?ooo`030?l0003oool0oooo01l0oooo00<00?l00?ooo`3oool0603oool0
0`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo05D0oooo000R0?ooo`030?l0003oool0oooo
00`0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo
01H0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo
00h0oooo00<00?l00?ooo`3oool06P3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo
00P0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`0S0?ooo`030?l0003oool0oooo
01l0oooo00<00?l00?ooo`3oool0603oool00`000000oooo0?ooo`0F0?ooo`80o`00F03oool00280
oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00`0
oooo00<00?l00?ooo`3oool05P3oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo00@0
oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`0J0?ooo`030?l0003oool0oooo0140
oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo02<0
oooo00<0o`000?ooo`3oool0803oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0oooo01D0
oooo00<0o`000?ooo`3oool0F03oool00280oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo
0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool05P3oool00`3o0000oooo
0?ooo`0>0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool03`3oool00`00o`00oooo
0?ooo`0J0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo
0?ooo`0D0?ooo`03003o003oool0oooo02D0oooo00<0o`000?ooo`3oool07`3oool00`00o`00oooo
0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0F@3oool00280oooo00<0
o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<0
0?l00?ooo`3oool0603oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo00<0oooo00<0
o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`0L0?ooo`030?l0003oool0oooo0100oooo00<0
0?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo02D0oooo00<0
o`000?ooo`3oool0803oool00`00o`00oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<0
o`000?ooo`3oool0FP3oool002<0oooo00<0o`000?ooo`3oool0303oool01000o`00oooo0?ooo`3o
000>0?ooo`03003o003oool0oooo01P0oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?oo
o`020?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0703oool00`3o0000oooo0?oo
o`0A0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool05@3oool00`00o`00oooo0?oo
o`0U0?ooo`030?l0003oool0oooo0200oooo00<00?l00?ooo`3oool05P3oool00`000000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo05/0oooo000S0?ooo`030?l0003oool0oooo00`0oooo00@00?l0
0?ooo`3oool0o`003P3oool00`00o`00oooo0?ooo`0H0?ooo`030?l0003oool0oooo00h0oooo00D0
0?l00?ooo`3oool0oooo0?l0000A0?ooo`03003o003oool0oooo01`0oooo00<0o`000?ooo`3oool0
4@3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool0
9`3oool00`3o0000oooo0?ooo`0O0?ooo`03003o003oool0oooo01H0oooo00<000000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`1L0?ooo`008`3oool00`3o0000oooo0?ooo`0<0?ooo`04003o003o
ool0oooo0?l000d0oooo00<00?l00?ooo`3oool06P3oool00`3o0000oooo0?ooo`0=0?ooo`05003o
003oool0oooo0?ooo`3o0000403oool00`00o`00oooo0?ooo`0N0?ooo`030?l0003oool0oooo0100
oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo02L0
oooo00<0o`000?ooo`3oool0803oool00`00o`00oooo0?ooo`0E0?ooo`800000403oool20?l005l0
oooo000T0?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3o00003P3oool00`00o`00oooo
0?ooo`0J0?ooo`030?l0003oool0oooo00h0oooo00@00?l00?ooo`3oool0o`00403oool00`00o`00
oooo0?ooo`0N0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0E0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool07`3oool00`00o`00
oooo0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0G`3oool002@0oooo
00<0o`000?ooo`3oool0303oool00`00o`00o`000?ooo`0=0?ooo`03003o003oool0oooo01X0oooo
00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?l0000A0?ooo`03003o003oool0oooo01h0oooo
00<0o`000?ooo`3oool04@3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo01@0oooo
00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0P0?ooo`03003o003oool0oooo01@0oooo
00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`1P0?ooo`00903oool00`3o0000oooo0?oo
o`0<0?ooo`03003o003o0000oooo00`0oooo00<00?l00?ooo`3oool0703oool00`3o0000oooo0?oo
o`0=0?ooo`03003o003oool0o`000100oooo00<00?l00?ooo`3oool0803oool00`3o0000oooo0?oo
o`0@0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo0200oooo00<00?l00?ooo`3oool0503oool00`000000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo0640oooo000U0?ooo`030?l0003oool0oooo00/0oooo00<00?l0
0?ooo`3oool0303oool00`00o`00oooo0?ooo`0L0?ooo`030?l0003oool0oooo00h0oooo00<00?l0
0?l0003oool03`3oool00`00o`00oooo0?ooo`0P0?ooo`030?l0003oool0oooo0100oooo00D00?l0
0?ooo`3oool0oooo0?l0000F0?ooo`03003o003oool0oooo02/0oooo00<0o`000?ooo`3oool0803o
ool00`00o`00oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0HP3o
ool002D0oooo00<0o`000?ooo`3oool02`3oool00`3o00000?l00?ooo`0<0?ooo`03003o003oool0
oooo01`0oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0
oooo0200oooo00<0o`000?ooo`3oool04@3oool01000o`00oooo0?ooo`3o000F0?ooo`03003o003o
ool0oooo02/0oooo00<0o`000?ooo`3oool0803oool00`00o`00oooo0?ooo`0C0?ooo`030000003o
ool0oooo00X0oooo00<0o`000?ooo`3oool0H`3oool002D0oooo00<0o`000?ooo`3oool02`3oool0
0`3o00000?l00?ooo`0;0?ooo`03003o003oool0oooo01h0oooo00<0o`000?ooo`3oool03@3oool0
0`00o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool0403oool0
0`00o`00oooo0?l0000G0?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3oool0803oool0
0`00o`00oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0I03oool0
02H0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo003o000<0?ooo`03003o003oool0oooo
01h0oooo00<0o`000?ooo`3oool03@3oool00`3o00000?l00?ooo`0>0?ooo`03003o003oool0oooo
0280oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?l0000F0?ooo`03003o003oool0oooo
02d0oooo00<0o`000?ooo`3oool0803oool00`00o`00oooo0?ooo`0B0?ooo`030000003oool0oooo
00P0oooo00<0o`000?ooo`3oool0I@3oool002H0oooo00<0o`000?ooo`3oool02@3oool0103o0000
oooo0?ooo`00o`0;0?ooo`03003o003oool0oooo01h0oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo003o000?0?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool04@3oool00`00
o`00o`000?ooo`0E0?ooo`03003o003oool0oooo02d0oooo00<0o`000?ooo`3oool0803oool00`00
o`00oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0IP3oool002L0
oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool00?l000X0oooo00<00?l00?oo
o`3oool0803oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool00?l000h0oooo00<00?l00?oo
o`3oool0903oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo01@0oooo00<00?l00?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`0P0?ooo`03003o003oool0oooo0140oooo00<000000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`1W0?ooo`009`3oool00`3o0000oooo0?ooo`070?ooo`05
0?l0003oool0oooo0?ooo`00o`002P3oool00`00o`00oooo0?ooo`0P0?ooo`030?l0003oool0oooo
00/0oooo00@0o`000?ooo`3oool00?l03@3oool00`00o`00oooo0?ooo`0T0?ooo`030?l0003oool0
oooo0100oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo0?ooo`0_0?ooo`030?l0003oool0
oooo0200oooo00<00?l00?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0
oooo06P0oooo000X0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`00
o`00oooo0?ooo`060?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool02@3oool01@3o
0000oooo0?ooo`3oool00?l000`0oooo00<00?l00?ooo`3oool09@3oool00`3o0000oooo0?ooo`0@
0?ooo`030?l00000o`00oooo01<0oooo00<00?l00?ooo`3oool0<03oool00`3o0000oooo0?ooo`0Q
0?ooo`03003o003oool0oooo0100oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`1Y
0?ooo`00:@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<00?l00?oo
o`3oool0103oool00`00o`00oooo0?ooo`0T0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool00`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo02H0oooo00<0o`000?oo
o`3oool03P3oool00`3o0000oooo003o000D0?ooo`03003o003oool0oooo0340oooo00<0o`000?oo
o`3oool0803oool00`00o`00oooo0?ooo`0@0?ooo`800000103oool00`3o0000oooo0?ooo`1Z0?oo
o`00:P3oool0103o0000oooo0?ooo`3oool20?l000L0oooo00<00?l00?ooo`3oool0103oool00`00
o`00oooo0?ooo`0T0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool00`00
o`00oooo0?ooo`080?ooo`03003o003oool0oooo02L0oooo00<0o`000?ooo`3oool03P3oool0103o
0000oooo0?ooo`00o`0B0?ooo`03003o003oool0oooo0380oooo00<0o`000?ooo`3oool08@3oool0
0`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0J`3oool0
02X0oooo1@3o00090?ooo`800?l00P3oool2003o02P0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool09`3oool00`3o
0000oooo0?ooo`0>0?ooo`050?l0003oool0oooo0?ooo`00o`004@3oool00`00o`00oooo0?ooo`0c
0?ooo`030?l0003oool0oooo0200oooo00<00?l00?ooo`3oool03`3oool01@000000oooo0?ooo`3o
ool0o`0006h0oooo000i0?ooo`@00?l0:P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00H0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0
oooo00`0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0
oooo03@0oooo00<0o`000?ooo`3oool08@3oool00`00o`00oooo0?ooo`0>0?ooo`040000003oool0
oooo0?l006l0oooo001W0?ooo`80o`000P3oool20?l000X0oooo0P00o`050?ooo`03003o003oool0
oooo02X0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0
oooo00d0oooo00<00?l00?ooo`3oool0=03oool00`3o0000oooo0?ooo`0Q0?ooo`03003o003oool0
oooo00h0oooo00<000000?ooo`3o0000L03oool006P0oooo103o000<0?ooo`800?l00P3oool2003o
02h0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo
00`0oooo00<00?l00?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0Q0?ooo`03003o003oool0oooo
00d0oooo00<000000?l0003oool0L03oool007X0oooo0P00o`0a0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo03L0
oooo00<0o`000?ooo`3oool08@3oool00`00o`00oooo0?ooo`0=0?ooo`030?l0003oool0oooo0700
oooo002^0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo03T0oooo00<0o`000?ooo`3oool0803oool00`00o`00oooo
0?ooo`0<0?ooo`030?l000000000oooo0740oooo002_0?ooo`030?l0003oool0oooo00<0oooo0P3o
000;0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0>@3oool00`3o0000oooo0?oo
o`0Q0?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`000000LP3oool00;00oooo1P3o000=
0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0P
0?ooo`03003o003oool0oooo00T0oooo00@0o`000?ooo`3oool00000LP3oool00<@0oooo0P00o`04
0?ooo`800?l0?`3oool00`3o0000oooo0?ooo`0P0?ooo`03003o003oool0oooo00L0oooo00D0o`00
0?ooo`3oool0oooo0000001b0?ooo`00a@3oool6003o0400oooo00<0o`000?ooo`3oool0803oool0
0`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0L03oool0
0?l0oooo3@3oool00`3o0000oooo0?ooo`0P0?ooo`03003o003oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool200000740oooo003o0?ooo`d0oooo00<0o`000?ooo`3oool0803oool00`00o`00
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool0L03oool00?l0oooo
3P3oool00`3o0000oooo0?ooo`0P0?ooo`05003o003oool0oooo0?ooo`3o00001`3oool00`000000
oooo0?ooo`1`0?ooo`00o`3oool?0?ooo`030?l0003oool0oooo01l0oooo00@00?l00?ooo`3oool0
o`00203oool00`000000oooo0?ooo`1`0?ooo`00o`3oool?0?ooo`030?l0003oool0oooo0200oooo
00<00?l00?l0003oool0203oool00`000000oooo0?ooo`1`0?ooo`00o`3oool@0?ooo`030?l0003o
ool0oooo01l0oooo00<00?l00?ooo`3oool0203oool00`000000oooo0?ooo`1`0?ooo`00o`3ooolA
0?ooo`030?l0003oool0oooo01d0oooo00<0o`00003o003oool02@3oool00`000000oooo0?ooo`1`
0?ooo`00o`3ooolB0?ooo`030?l0003oool0oooo01/0oooo00@0o`000?ooo`3oool00?l02@3oool0
0`000000oooo0?ooo`1`0?ooo`00o`3ooolC0?ooo`030?l0003oool0oooo01T0oooo00D0o`000?oo
o`3oool0oooo003o00090?ooo`030000003oool0oooo0700oooo003o0?oooa@0oooo00<0o`000?oo
o`3oool02`3oool3000000H0oooo0P0000000`3oool0o`000?ooo`020?ooo`80000000<00?l00000
003oool01P3oool00`000000oooo0?ooo`1`0?ooo`00o`3ooolE0?ooo`030?l0003oool0oooo00T0
oooo00D000000?ooo`3oool0oooo000000050?ooo`80000000<0o`000?ooo`3oool0103oool00`00
o`00oooo000000060?ooo`030000003oool0oooo0700oooo003o0?oooaD0oooo00<0o`000?ooo`3o
ool02@3oool01@000000oooo0?ooo`3oool0000000D0oooo0P3o00080?ooo`03003o00000000oooo
00D0oooo0`00001`0?ooo`00o`3ooolF0?ooo`80o`002@3oool01@000000oooo0?ooo`3oool00000
00<0oooo0P3o000:0?ooo`03003o00000000oooo00D0oooo00<000000?ooo`3oool0L03oool00?l0
oooo603oool00`3o0000oooo0?ooo`060?ooo`060000003oool0oooo0?ooo`000000oooo0P3o0009
0?ooo`@0000000<00?l00?ooo`3oool0103oool00`000000oooo0?ooo`1`0?ooo`00o`3ooolI0?oo
o`80o`001P3oool010000000oooo0?ooo`3oool20?l000/0oooo00D000000?ooo`3oool0oooo003o
00060?ooo`030000003oool0oooo0700oooo003o0?oooa/0oooo0`3o00030?ooo`050000003oool0
o`000?l000000000303oool00`000000oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0
00000?ooo`3oool0L03oool00?l0oooo7@3oool60?l0008000003@3oool4000000030?ooo`00o`00
oooo00@0oooo00<000000?ooo`3oool0L03oool00?l0oooo>03oool00`00o`00oooo0?ooo`020?oo
o`030000003oool0oooo0700oooo003o0?ooocT0oooo00D00?l00?ooo`3oool0oooo0000001b0?oo
o`00o`3oooli0?ooo`05003o003oool0oooo0?ooo`000000LP3oool00?l0oooo>P3oool01000o`00
oooo0?ooo`00001b0?ooo`00o`3ooolj0?ooo`04003o003oool0oooo00000780oooo003o0?oooc/0
oooo00<00?l00?ooo`000000LP3oool00?l0oooo>`3oool01000o`00oooo00000000001a0?ooo`00
o`3oooll0?ooo`03003o00000000oooo0740oooo003o0?oooc`0oooo00<00?l00000003oool0L@3o
ool00?l0oooo?@3oool00`00o`00oooo0?ooo`1`0?ooo`00o`3ooolm0?ooo`03003o003oool0oooo
0700oooo003o0?ooocd0oooo00<00000003o003oool0L03oool00?l0oooo?@3oool00`0000000?l0
0?ooo`1`0?ooo`00o`3ooolm0?ooo`030000003oool00?l00700oooo003o0?ooocd0oooo00@00000
0?ooo`3oool00?l0K`3oool00?l0oooo?@3oool010000000oooo0?ooo`00o`1_0?ooo`00o`3ooolm
0?ooo`050000003oool0oooo0?ooo`00o`00KP3oool00?l0oooo?@3oool01@000000oooo0?ooo`3o
ool00?l006h0oooo003o0?ooocd0oooo0P0000030?ooo`03003o003oool0oooo06/0oooo003o0?oo
ocd0oooo00<000000?ooo`3oool00P3oool00`00o`00oooo0?ooo`1[0?ooo`00o`3ooolm0?ooo`03
0000003oool0oooo00<0oooo00<00?l00?ooo`3oool0JP3oool00?l0oooo?@3oool00`000000oooo
0?ooo`030?ooo`03003o003oool0oooo06X0oooo003o0?ooocd0oooo00<000000?ooo`3oool0103o
ool00`00o`00oooo0?ooo`1Y0?ooo`00o`3ooolm0?ooo`030000003oool0oooo00@0oooo00<00?l0
0?ooo`3oool0J@3oool00?l0oooo?@3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo
06P0oooo003o0?ooocd0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`1X0?ooo`00
o`3ooolm0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0I`3oool00?l0oooo?@3o
ool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo06L0oooo003o0?ooocd0oooo00<00000
0?ooo`3oool01`3oool00`00o`00oooo0?ooo`1V0?ooo`00o`3ooolm0?ooo`030000003oool0oooo
00L0oooo00<00?l00?ooo`3oool0IP3oool00?l0oooo?@3oool2000000P0oooo00<00?l00?ooo`3o
ool0IP3oool00?l0oooo?@3oool00`000000oooo0?ooo`080?ooo`03003o003oool0oooo06D0oooo
003o0?ooocd0oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?ooo`1U0?ooo`00o`3ooolm
0?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0I03oool00?l0oooo?@3oool00`00
0000oooo0?ooo`090?ooo`03003o003oool0oooo06@0oooo003o0?ooocd0oooo00<000000?ooo`3o
ool02P3oool00`00o`00oooo0?ooo`1S0?ooo`00o`3ooolm0?ooo`030000003oool0oooo00X0oooo
00<00?l00?ooo`3oool0H`3oool00?l0oooo?@3oool00`000000oooo0?ooo`0;0?ooo`03003o003o
ool0oooo0680oooo003o0?ooocd0oooo00<000000?ooo`3oool02`3oool00`00o`00oooo0?ooo`1R
0?ooo`00o`3ooolm0?ooo`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool0H@3oool00?l0
oooo?@3oool00`000000oooo0?ooo`0<0?ooo`03003o003oool0oooo0640oooo003o0?ooocd0oooo
00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`1Q0?ooo`00o`3ooolm0?ooo`8000003P3o
ool00`00o`00oooo0?ooo`1P0?ooo`00o`3ooolm0?ooo`030000003oool0oooo00d0oooo00<00?l0
0?ooo`3oool0H03oool00?l0oooo?@3oool00`000000oooo0?ooo`0>0?ooo`03003o003oool0oooo
05l0oooo003o0?ooocd0oooo00<000000?ooo`3oool03P3oool00`00o`00oooo0?ooo`1O0?ooo`00
o`3ooolm0?ooo`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool0G`3oool00?l0oooo?@3o
ool00`000000oooo0?ooo`0?0?ooo`03003o003oool0oooo05h0oooo003o0?ooocd0oooo00<00000
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`1N0?ooo`00o`3ooolm0?ooo`030000003oool0oooo
0100oooo00<00?l00?ooo`3oool0G@3oool00?l0oooo?@3oool00`000000oooo0?ooo`0@0?ooo`03
003o003oool0oooo05d0oooo003o0?oooc80oooo1@0000060?ooo`030000003oool0oooo0100oooo
00<00?l00?ooo`3oool0G@3oool00?l0oooo=03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0140oooo00<00?l00?ooo`3oool0G03oool00?l0oooo=03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0140oooo00<00?l00?ooo`3oool0G03oool00?l0oooo=03oool00`00
0000oooo0?ooo`060?ooo`<000004P3oool00`00o`00oooo0?ooo`1K0?ooo`00o`3ooold0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0?ooo`1K0?ooo`00
o`3ooold0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`00o`00oooo
0?ooo`1K0?ooo`00o`3ooold0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3o
ool00`00o`00oooo0?ooo`1J0?ooo`00o`3ooolb0?ooo`<00000203oool00`000000oooo0?ooo`0C
0?ooo`03003o003oool0oooo05X0oooo003o0?ooocd0oooo00<000000?ooo`3oool0503oool00`00
o`00oooo0?ooo`1I0?ooo`00o`3ooolm0?ooo`030000003oool0oooo01@0oooo00<00?l00?ooo`3o
ool0F@3oool00?l0oooo?@3oool00`000000oooo0?ooo`0D0?ooo`03003o003oool0oooo05T0oooo
003o0?ooocd0oooo00<000000?ooo`3oool05@3oool00`00o`00oooo0?ooo`1H0?ooo`00o`3ooolm
0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool0F03oool00?l0oooo?@3oool00`00
0000oooo0?ooo`0E0?ooo`03003o003oool0oooo05P0oooo003o0?ooocd0oooo0P00000G0?ooo`03
003o003oool0oooo05L0oooo003o0?ooocd0oooo00<000000?ooo`3oool05P3oool00`00o`00oooo
0?ooo`1G0?ooo`00o`3ooolm0?ooo`030000003oool0oooo01H0oooo00<00?l00?ooo`3oool0E`3o
ool00?l0oooo?@3oool00`000000oooo0?ooo`0G0?ooo`03003o003oool0oooo05H0oooo003o0?oo
ocd0oooo00<000000?ooo`3oool05`3oool00`00o`00oooo0?ooo`1F0?ooo`00o`3ooolm0?ooo`03
0000003oool0oooo01L0oooo00<00?l00?ooo`3oool0EP3oool00?l0oooo?@3oool00`000000oooo
0?ooo`0G0?ooo`03003o003oool0oooo05H0oooo003o0?ooocd0oooo00<000000?ooo`3oool0603o
ool00`00o`00oooo0?ooo`1E0?ooo`00o`3ooolm0?ooo`030000003oool0oooo01P0oooo00<00?l0
0?ooo`3oool0E@3oool00?l0oooo?@3oool00`000000oooo0?ooo`0H0?ooo`03003o003oool0oooo
05D0oooo003o0?ooocd0oooo00<000000?ooo`3oool0603oool00`00o`00oooo0?ooo`1E0?ooo`00
o`3ooolm0?ooo`030000003oool0oooo01T0oooo00<00?l00?ooo`3oool0E03oool00?l0oooo?@3o
ool2000001X0oooo00<00?l00?ooo`3oool0E03oool00?l0oooo?@3oool00`000000oooo0?ooo`0I
0?ooo`03003o003oool0oooo05@0oooo003o0?ooocd0oooo00<000000?ooo`3oool06P3oool00`00
o`00oooo0?ooo`1C0?ooo`00o`3ooolm0?ooo`030000003oool0oooo01X0oooo00<00?l00?ooo`3o
ool0D`3oool00?l0oooo?@3oool00`000000oooo0?ooo`0J0?ooo`03003o003oool0oooo05<0oooo
003o0?ooocd0oooo00<000000?ooo`3oool06P3oool00`00o`00oooo0?ooo`1C0?ooo`00o`3ooolm
0?ooo`030000003oool0oooo01/0oooo00<00?l00?ooo`3oool0DP3oool00?l0oooo?@3oool00`00
0000oooo0?ooo`0K0?ooo`03003o003oool0oooo0580oooo003o0?ooocd0oooo00<000000?ooo`3o
ool06`3oool00`00o`00oooo0?ooo`1B0?ooo`00o`3ooolm0?ooo`030000003oool0oooo01/0oooo
00<00?l00?ooo`3oool0DP3oool00?l0oooo?@3oool00`000000oooo0?ooo`0K0?ooo`03003o003o
ool0oooo0580oooo003o0?ooocd0oooo00<000000?ooo`3oool0703oool00`00o`00oooo0?ooo`1A
0?ooo`00o`3ooolm0?ooo`8000007@3oool00`00o`00oooo0?ooo`1A0?ooo`00o`3ooolm0?ooo`03
0000003oool0oooo01`0oooo00<00?l00?ooo`3oool0D@3oool00?l0oooo?@3oool00`000000oooo
0?ooo`0L0?ooo`03003o003oool0oooo0540oooo003o0?ooocd0oooo00<000000?ooo`3oool0703o
ool00`00o`00oooo0?ooo`1A0?ooo`00o`3ooolm0?ooo`030000003oool0oooo01d0oooo00<00?l0
0?ooo`3oool0D03oool00?l0oooo?@3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo
0500oooo003o0?ooocd0oooo00<000000?ooo`3oool07@3oool00`00o`00oooo0?ooo`1@0?ooo`00
o`3ooolm0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0D03oool00?l0oooo?@3o
ool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo0500oooo003o0?ooocd0oooo00<00000
0?ooo`3oool07P3oool00`00o`00oooo0?ooo`1?0?ooo`00o`3ooolm0?ooo`030000003oool0oooo
01h0oooo00<00?l00?ooo`3oool0C`3oool00?l0oooo?@3oool00`000000oooo0?ooo`0N0?ooo`03
003o003oool0oooo04l0oooo003o0?ooocd0oooo0P00000O0?ooo`03003o003oool0oooo04l0oooo
003o0?ooocd0oooo00<000000?ooo`3oool07P3oool00`00o`00oooo0?ooo`1?0?ooo`00o`3ooolm
0?ooo`030000003oool0oooo01h0oooo00<00?l00?ooo`3oool0C`3oool00?l0oooo?@3oool00`00
0000oooo0?ooo`0O0?ooo`03003o003oool0oooo04h0oooo003o0?ooocd0oooo00<000000?ooo`3o
ool07`3oool00`00o`00oooo0?ooo`1>0?ooo`00o`3ooolm0?ooo`030000003oool0oooo01l0oooo
00<00?l00?ooo`3oool0CP3oool00?l0oooo?@3oool00`000000oooo0?ooo`0O0?ooo`03003o003o
ool0oooo04h0oooo003o0?ooocd0oooo00<000000?ooo`3oool07`3oool00`00o`00oooo0?ooo`1>
0?ooo`00o`3ooolm0?ooo`030000003oool0oooo0200oooo00<00?l00?ooo`3oool0C@3oool00?l0
oooo8P3oool5000000@0oooo0P0000050?ooo`@000001`3oool00`000000oooo0?ooo`0P0?ooo`03
003o003oool0oooo04d0oooo003o0?ooob@0oooo00<000000?ooo`3oool0103oool2000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`03003o003oool0oooo04d0oooo
003o0?ooob@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0200oooo00<00?l00?ooo`3oool0C@3oool00?l0oooo903oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo0`00000P0?ooo`03003o003oool0oooo04d0oooo003o0?oo
ob@0oooo00<000000?ooo`3oool02`3oool4000000L0oooo00<000000?ooo`3oool08@3oool00`00
o`00oooo0?ooo`1<0?ooo`00o`3ooolT0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo04`0oooo003o0?ooob@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0240oooo
00<00?l00?ooo`3oool0C03oool00?l0oooo8P3oool3000000d0oooo1000001j0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00`P3oool20?l000/0oooo0P3o00050?ooo`030000003oool0oooo01H0oooo0P00o`0;0?oo
o`800?l0/@3oool00<80oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`030?ooo`80
00005`3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo0:l0oooo002_0?ooo`<0o`00
0P3oool30?l00080oooo1@3o00040?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l000@0
oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`H00?l0103oool5003o00@0
oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`800?l0103oool00`00o`00oooo0?ooo`2_0?oo
o`00/03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?l000D0oooo00<0o`000?oo
o`3oool0103oool2000000@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?oo
o`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`05
0?ooo`03003o003oool0oooo0:l0oooo002`0?ooo`H0o`001@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo0P3o00060?ooo`030?l0003oool0oooo00X0oooo00<00?l00?oo
o`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<00?l00?oo
o`3oool00`3oool2003o00H0oooo00<00?l00?ooo`3oool0[`3oool00;40oooo00@0o`000?ooo`3o
ool0o`001P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo0P3o00060?oo
o`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?oo
o`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool2003o00H0oooo00<00?l00?oo
o`3oool0[`3oool00;40oooo00@0o`000?ooo`3oool0o`001P3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`0:
0?ooo`D00?l01P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00@00?l0
0?ooo`3oool00?l01@3oool00`00o`00oooo0?ooo`2_0?ooo`00/@3oool0103o0000oooo0?ooo`3o
00040?ooo`<0o`001P3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o00040?ooo`030?l0
003oool0oooo00X0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`<00?l01P3oool01000o`00
oooo0?ooo`3oool2003o0080oooo0P00o`040?ooo`03003o003oool0oooo0:l0oooo002b0?ooo`80
o`003P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00D00?l00?ooo`3o
ool0oooo003o000=0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0[`3oool00;00
oooo103o00070?ooo`030?l0003oool0oooo00@0oooo0P3o000;0?ooo`80o`002`3oool5003o00L0
oooo00<00?l00?ooo`3oool0103oool2003o00/0oooo0P00o`2a0?ooo`00^`3oool00`3o0000oooo
0?ooo`0Z0?ooo`03003o003oool0oooo0<@0oooo003o0?oook00oooo003o0?oook00oooo0000\
\>"],
  ImageRangeCache->{{{0, 430.938}, {265.688, 0}} -> {-11, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
\tOn the other hand, there are many seemingly straightforward ODEs \
that have no solution in terms of either special functions or elementary \
functions. Here is an example:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\(x'\)[t]\  \[Equal] t/\((x[t] + t)\)^2, x[t], t]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.13"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "==", \(t\/\((t + x[t])\)\^2\)}], ",", \(x[t]\), ",", "t"}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " could not find an analytic solution for this simple first-order ODE, \
although if we wished we could plot the direction field to find the \
qualitative form of the solutions. Of course, that doesn't mean that there is \
no analytic solution in terms of predefined functions - after all, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is not omniscient. However, as far as I know there really is no such \
solution to this equation."
}], "Text"],

Cell[TextData[{
  "\tYou may wonder why a reasonably simple first-order ODE has no analytic \
solution, but a second-order ODE like the Airy equation does have an analytic \
solution. The reason in this instance is mainly historical, not mathematical. \
The solutions of the Airy equation are of physical interest, and were \
explored originally by the British mathematician ",
  ButtonBox["George B. Airy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Airy.html"],
       None},
    ButtonStyle->"Hyperlink"],
  ". The equation is important in the study of wave propagation through \
inhomogeneous media, and in the quantum theory of tunneling, as we will see \
in Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  Many of the special functions that we will encounter in this course - \
Bessel functions, Mathieu functions, Legendre functions, etc. - have a \
similar history: they were originally studied because of their importance to \
some area of science or mathematics."
}], "Text",
  CellTags->"i:32"],

Cell["\<\
\tOur simple first-order ODE, above, has no analytic solution (as \
far as I know) simply because no one has ever felt the need to define one.  \
Perhaps some day the need will arise, and the solutions will then be detailed \
and named.\
\>", "Text"],

Cell[TextData[{
  "\tHowever, there are many ODEs for which ",
  StyleBox["no exact analytic solution can be written down",
    FontSlant->"Italic"],
  ".  These ODEs have ",
  StyleBox["chaotic",
    FontSlant->"Italic"],
  " solutions that are so complex that they cannot be predicted on the basis \
of analytic formulae. Over long times, the solutions cannot even be predicted \
numerically with any accuracy (as we will see in the next section).\n\tThe \
syntax for ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is summarized in Table ",
  ButtonBox["1.1",
    ButtonData:>"Table 1.1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:33"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Table 1.1",
    FontFamily->"Courier",
    FontSize->8],
  StyleBox["  ",
    FontSize->8],
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontSize->9,
    FontWeight->"Bold"],
  " \n",
  Cell[BoxData[GridBox[{
          {
            RowBox[{
              StyleBox["DSolve",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["eqn",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox[\(x[t]\),
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["t",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}], 
            RowBox[{
            "Solve", " ", "a", " ", "differential", " ", "equation", " ", 
              "for", " ", 
              StyleBox[\(x[t]\),
                FontFamily->"Courier",
                FontWeight->"Bold"]}]},
          {
            RowBox[{
              StyleBox["DSolve",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                RowBox[{
                  StyleBox["{",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[\(eqn1, eqn2, \[Ellipsis]\),
                    FontSlant->"Italic"], 
                  StyleBox["}",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Italic"]}], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["{",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox[\(x1[t]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[\(x2[t]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["\[Ellipsis]",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Italic"]}], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["t",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], 
              StyleBox["]",
                FontFamily->"Courier",
                
                FontWeight->
                  "Bold"]}], \(\(Solve\)\(\ \)\(coupled\)\(\ \)\(differential\
\)\(\ \)\(equations\)\(\ \)\)}
          },
        ColumnSpacings->1.8,
        ColumnAlignments->{Left}]],
    FontFamily->"Times"]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 1.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 1.3 ", "Subsubtitle",
  CellTags->{"Ex. 1.3", "c:18"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " In the process of radioactive decay, an atom spontaneously changes form \
by emitting particles from the nucleus. The rate ",
  StyleBox["\[Nu]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "at which this decay happens is defined as the fraction of nuclei that \
decay per unit of time in a sample of material. Write down and solve a \
differential equation for the mass of radioactive material remaining at time \
",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", ",
  StyleBox["m",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), given an amount ",
  Cell[BoxData[
      \(TraditionalForm\`m\_o\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "at ",
  StyleBox["t",
    FontSlant->"Italic"],
  "=0. How long does it take for half the material to decay?"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A spaceship undergoing constant acceleration ",
  StyleBox["g",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{"=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  " (as felt by the passengers) will follow Newton's second law, with the \
addition (by ",
  ButtonBox["Einstein",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Einstein.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ") that the apparent mass of the ship as seen from a stationary  observer \
will increase with velocity ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") in proportion to the factor ",
  Cell[BoxData[
      \(TraditionalForm\`1/\@\(1 - v\^2\/c\^2\)\)]],
  ". This implies that the velocity satisfies the following first-order ODE:"
}], "Text",
  CellTags->"i:128"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              FractionBox["\[DifferentialD]", \(\[DifferentialD]t\),
                MultilineFunction->None],
              FontSize->12], \((v\/\@\(1 - v\^2\/c\^2\))\)}], 
          "=", \(\(g\)\(.\)\)}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "Find the general solution, using pencil and paper, for the position as a \
function of time."
}], "Text"],

Cell[TextData[{
  StyleBox["(b) ",
    FontWeight->"Bold"],
  "After 100 earth years of acceleration, starting from rest, how far has the \
ship gone in light-years (one light-year = 9.45 \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`10\^15\)]],
  "m)?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Thanks to relativistic time dilation, the amount of time ",
  StyleBox["\[Tau]  ",
    FontFamily->"Symbol"],
  "that has passed onboard the ship is considerably shorter than 100 years, \
and is given by the solution to the differential equation ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FractionBox[\(\[DifferentialD]\[Tau]\), \(\[DifferentialD]t\),
              MultilineFunction->None], 
            "=", \(\@\(1 - \(v(t)\)\^2\/c\^2\)\)}],
          FontSize->12], TraditionalForm]]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](0) = 0\)]],
  " . Solve this ODE, using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and the solution for ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") from part (b) above, to find the amount of time that has gone by for \
passengers on the ship. (Note: The nearest star is only about 4.3 light years \
from earth).  What was the average speed of the ship over the course of the \
trip, in units of ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", as far as the passengers are concerned? "
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " The charge ",
  StyleBox["Q",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") on the capacitor in an ",
  StyleBox["L R C",
    FontSlant->"Italic"],
  " electrical circuit obeys a second-order differential equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L\ Q\^\[DoublePrime] + R\ Q\^\[Prime] + Q/C = 
        V(t)\)]],
  "."
}], "NE3",
  CellTags->"(1.3.3)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the general solution to the equation, taking ",
  StyleBox["V",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = 0."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  "  Plot this solution for the case ",
  StyleBox["Q(0)",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-5\)\)]],
  "  coulomb, ",
  Cell[BoxData[
      \(TraditionalForm\`\(Q\^\[Prime]\)(0) = 0\)]],
  StyleBox[", ",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  "taking ",
  StyleBox["R",
    FontSlant->"Italic"],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`10\^4\)]],
  " ohms, ",
  StyleBox["C",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-5\)\)]],
  " farad, ",
  StyleBox["L",
    FontSlant->"Italic"],
  " =  0.1 henry. What is the frequency of the oscillation being plotted (in \
radians per second)? What is the rate of decay of the envelope (in ",
  Cell[BoxData[
      \(TraditionalForm\`inverse\ seconds\)]],
  ")?"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " A man throws a pebble straight up. Its height ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") satisfies the differential equation ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[DoublePrime] + \[Gamma]\ y\^\[Prime] = \
\(-g\)\)]],
  ", where ",
  StyleBox["g ",
    FontSlant->"Italic"],
  "is the acceleration of gravity and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  "  is the damping rate due to frictional drag with the air. "
}], "Text",
  CellTags->"i:110"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the general solution to this ODE"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the solution ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") for the case where the initial speed is 6 m/s, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(0) = 0, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"\[Gamma]", "=", " ", 
            RowBox[{"0.2", " ", 
              FormBox[
                SuperscriptBox[
                  StyleBox["s",
                    FontSlant->"Plain"], \(-1\)],
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  " . Plot this solution vs. time."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find the time when the pebble returns to the ground (this may require a \
numerical solution of an algebraic equation)."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Atomic Hydrogen ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          StyleBox["H",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " recombines into molecular Hydrogen (",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["H",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  ") according to the simple chemical reaction ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["H",
              FontSlant->"Plain"], "+", 
            StyleBox["H",
              FontSlant->"Plain"]}], "\[RightArrowLeftArrow]", 
          SubscriptBox[
            StyleBox["H",
              FontSlant->"Plain"], "2"]}], TraditionalForm]]],
  ". The rate of the forward recombination reaction (number of reactions per \
unit time per unit volume) is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Nu]\_1\), 
          SuperscriptBox[
            SubscriptBox["n", 
              StyleBox["H",
                FontSlant->"Plain"]], "2"]}], TraditionalForm]]],
  " , where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["n", 
          StyleBox["H",
            FontSlant->"Plain"]], TraditionalForm]]],
  " is the number density (in ",
  Cell[BoxData[
      \(TraditionalForm\`atoms\ per\ cubic\ meter\)]],
  ") of atomic hydrogen, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_1\)]],
  " is a constant. The rate of the reverse reaction (spontaneous \
decomposition into atomic hydrogen) is  ",
  StyleBox[" ",
    FontFamily->"Symbol"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Nu]\_2\), 
          SubscriptBox["n", 
            SubscriptBox[
              StyleBox["H",
                FontSlant->"Plain"], "2"]]}], TraditionalForm]]],
  ",",
  StyleBox[" ",
    FontFamily->"Symbol"],
  " where  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["n", 
          SubscriptBox[
            StyleBox["H",
              FontSlant->"Plain"], "2"]], TraditionalForm]]],
  " is the number density of molecular hydrogen. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Write down two coupled first-order ODEs for the densities of molecular and \
atomic hydrogen as a function of time."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Solve these equations for general initial densities."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Show that the solutions to these equations satisfy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["n", 
              StyleBox["H",
                FontSlant->"Plain"]], "+", " ", 
            RowBox[{"2", 
              SubscriptBox["n", 
                SubscriptBox[
                  StyleBox["H",
                    FontSlant->"Plain"], "2"]]}]}], "=", "const"}], 
        TraditionalForm]]],
  ".  Take the constant equal to ",
  Cell[BoxData[
      \(TraditionalForm\`n\_o\)]],
  " (the total number density of hydrogen atoms in the system, counting those \
that are combined into molecules), and find the ratio of densities ",
  StyleBox["in equilibrium",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"i:115"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Plot the densities as a function of time for the initial condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            SubscriptBox["n", 
              SubscriptBox[
                StyleBox["H",
                  FontSlant->"Plain"], "2"]],
            "TraditionalForm"], " ", "=", "1"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            SubscriptBox["n", 
              StyleBox["H",
                FontSlant->"Plain"]],
            "TraditionalForm"], " ", "=", " ", "0"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Nu]\_1\),
            "TraditionalForm"], " ", "=", " ", "3"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Nu]\_2\),
            "TraditionalForm"], " ", "=", " ", "1."}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " A charged particle, of mass ",
  StyleBox["m ",
    FontSlant->"Italic"],
  " and charge ",
  StyleBox["q",
    FontSlant->"Italic"],
  ",  moves in uniform magnetic and electric fields ",
  StyleBox["B ",
    FontWeight->"Bold"],
  "= (0,0,",
  Cell[BoxData[
      \(TraditionalForm\`B\_o\)]],
  "), ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["E", 
                StyleBox["\[UpTee]",
                  FontFamily->"Symbol"]], ",", "0", ",", \(E\_z\)}], ")"}]}], 
        TraditionalForm]]],
  ".",
  StyleBox[" ",
    FontSlant->"Italic"],
  " The particle satisfies the nonrelativistic equations of motion, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["v",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}]}], " ", 
          "=", " ", 
          RowBox[{"q", "(", 
            RowBox[{
              StyleBox["E",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["+",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["v",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Plain"], "\[Times]", 
                StyleBox["B",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " . "
}], "NE3",
  CellTags->"(1.3.4)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find, using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",  the general solution of these coupled first-order ODES for the velocity \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontSlant->"Italic"], 
            StyleBox["t",
              FontSlant->"Italic"], 
            StyleBox[")",
              FontSlant->"Italic"]}], 
          StyleBox["=",
            FontSlant->"Italic"], 
          StyleBox[\((\(v\_x\)(t), \(v\_y\)(t), \(v\_z\)(t))\),
            FontSlant->"Italic"]}], TraditionalForm]]],
  StyleBox[" . ",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "Note that in general there is a constant velocity perpendicular to ",
  StyleBox["B",
    FontWeight->"Bold"],
  ", on which there is superimposed a circular motion. The constant velocity \
is called an ",
  StyleBox["E",
    FontWeight->"Bold"],
  "\[Times]",
  StyleBox["B",
    FontWeight->"Bold"],
  " ",
  StyleBox["drift",
    FontSlant->"Italic"],
  ". The circular motion is called a ",
  StyleBox["cyclotron orbit",
    FontSlant->"Italic"],
  ".  What is the frequency of the cyclotron orbit? What are the magnitude \
and direction of the ",
  StyleBox["E",
    FontWeight->"Bold"],
  "\[Times]",
  StyleBox["B",
    FontWeight->"Bold"],
  " drift?"
}], "Text",
  CellTags->"i:135"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find ",
  StyleBox["v",
    FontWeight->"Bold"],
  "(t) for the case for an electron with ",
  StyleBox["r",
    FontWeight->"Bold"],
  "(0)",
  StyleBox["=",
    FontSlant->"Italic"],
  StyleBox["v",
    FontWeight->"Bold"],
  "(0)=0, ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z\)]],
  " = 0, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["E", 
          StyleBox["\[UpTee]",
            FontFamily->"Symbol"]], TraditionalForm]]],
  " =5000V/m, and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox["B",
            "TraditionalForm"], "o"], TraditionalForm]]],
  " = 0.005 tesla (these are the proper S.I. units for the equation of motion \
as written above). Plot ",
  Cell[BoxData[
      \(TraditionalForm\`v\_x\)]],
  "(t) and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_y\)]],
  "(t) vs. ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " for a time of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-7\)\)]],
  " s. "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Use the results of part (b) to obtain ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "). Plot ",
  StyleBox["x",
    FontSlant->"Italic"],
  " vs. ",
  StyleBox["y",
    FontSlant->"Italic"],
  " using a parametric plot to look at the trajectory of the electron.  Plot \
the trajectory again in a frame moving at the ",
  StyleBox["E",
    FontWeight->"Bold"],
  "\[Times]",
  StyleBox["B",
    FontWeight->"Bold"],
  " drift speed. The radius of the circle is called the ",
  StyleBox["cyclotron radius",
    FontSlant->"Italic"],
  ". What is the magnitude of the radius (in meters) for this example?"
}], "Text",
  CellTags->"i:137"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " The trajectory ",
  StyleBox["r",
    FontSlant->"Italic"],
  "(",
  StyleBox["\[Theta]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  ") of a particle orbiting a fixed mass ",
  StyleBox["M",
    FontSlant->"Italic"],
  "  at the origin of the (",
  StyleBox["r,",
    FontSlant->"Italic"],
  StyleBox["\[Theta]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  ") plane satisfies the following differential equation:"
}], "Text",
  CellTags->"i:146"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\/r\^2\) \(\[DifferentialD]\/\[DifferentialD]\
\[Theta]\) \((\(L\/r\^2\) \[DifferentialD]r\/\[DifferentialD]\[Theta])\) - 
          L\^2\/r\^3 = \(-\(\(G\ M\)\/r\^2\)\)\)]],
  ","
}], "NE3",
  CellTags->"(1.3.5)"],

Cell[TextData[{
  "where ",
  StyleBox["L",
    FontSlant->"Italic"],
  " is the specific angular momentum, as in ",
  ButtonBox["Eq. (1.2.22)",
    ButtonData:>"(1.2.22)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Introduce a scaled radius  ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_ = r/a\)]],
  " to show that with proper choice of ",
  StyleBox["a",
    FontSlant->"Italic"],
  " this equation can be written in dimensionless form as "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(1\/r\&_\^2\), 
              FractionBox["\[DifferentialD]", \(\[DifferentialD]\[Theta]\),
                MultilineFunction->None], 
              RowBox[{"(", 
                RowBox[{\(1\/r\&_\^2\), 
                  
                  FractionBox[\(\[DifferentialD]r\&_\), \(\[DifferentialD]\
\[Theta]\),
                    MultilineFunction->None]}], ")"}]}], 
            "-", \(1\/r\&_\^3\)}], "=", \(-\(1\/r\&_\^2\)\)}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the general solution for the trajectory, and show that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'",
  StyleBox["s",
    FontSlant->"Italic"],
  " expression is equivalent to the expression  \n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[\(1\/\(r(\[Theta])\)\),
              FontSize->12], 
            StyleBox["=",
              FontSize->12], 
            RowBox[{
              StyleBox[\(\(G\ M\)\/L\^2\),
                FontSize->12], 
              StyleBox[" ",
                
                FontSize->12], \((e\ \(cos(\[Theta] - \[Theta]\_o)\) + 
                  1)\)}]}], ","}], TraditionalForm]]],
  " where ",
  StyleBox["e",
    FontSlant->"Italic"],
  " is the eccentricity and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_o\)]],
  " is the angular position of perihelion. [See Eq. ",
  ButtonBox["(1.2.21)",
    ButtonData:>"(1.2.21)",
    ButtonStyle->"Hyperlink"],
  " and Exercise (3) of ",
  ButtonBox["Sec. 9.6",
    ButtonData:>{"Chapter9.nb", "Ex. 9.6"},
    ButtonStyle->"Hyperlink"],
  "). "
}], "Text",
  CellTags->"i:34"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Consider the electric field from a unit point dipole at the origin. This \
field is given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(-\[Del]\(\[Phi](\[Rho], z)\)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " in cylindrical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Rho], \[Theta], z)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = z/\((\[Rho]\^2 + z\^2)\)\^\(3/2\)\)]],
  ". In cylindrical coordinates the field lines equation, Eq. ",
  ButtonBox["(1.2.24)",
    ButtonData:>"(1.2.24)",
    ButtonStyle->"Hyperlink"],
  ",  has components"
}], "Text",
  CellTags->"i:35"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[DifferentialD]\[Rho]/\[DifferentialD]s\), "=", " ", 
            RowBox[{
              RowBox[{
                RowBox[{\(E\_\[Rho]\), "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ")"}], "/"}], "|", 
              RowBox[{
                StyleBox["E",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              StyleBox["|",
                FontWeight->"Plain"]}]}], ",", "\[IndentingNewLine]", 
          
          RowBox[{\(\[Rho]\ \[DifferentialD]\ \[Theta]/\[DifferentialD]s\), 
            "=", " ", 
            RowBox[{
              RowBox[{
                RowBox[{\(E\_\[Theta]\), "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ")"}], "/"}], "|", 
              RowBox[{
                StyleBox["E",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              StyleBox["|",
                FontWeight->"Plain"]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
            FormBox[
              RowBox[{\(\[DifferentialD]z/\[DifferentialD]s\), "=", " ", 
                RowBox[{
                  RowBox[{
                    RowBox[{\(E\_z\), "(", 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], ")"}], "/"}], "|", 
                  RowBox[{
                    StyleBox["E",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "(", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox["|",
                    FontWeight->"Plain"]}]}],
              "TraditionalForm"], "."}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(1.3.6)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Use ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to determine  the field lines for the dipole that pass through the \
following points:\n",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Rho]\_o, z\_o)\) = \((1, \ 0.5\ n)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3, 4\)]],
  " . Make a table of ",
  StyleBox["ParametricPlot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "graphics images of these field lines in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Rho], z)\)\)]],
  " plane for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-10\) < s < 10\)]],
  " and superimpose them all with a ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command to visualize the field lines from this dipole. \n(Hint: Create a \
vector function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", \(s, z\_o\), ")"}], 
          "=", \({\[Rho](s, z\_o), z(s, z\_o)}\)}], TraditionalForm]]],
  " using the ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution,  for initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](0) = \(\[Rho]\_o = 1\), \ z(0) = z\_o\)]],
  ". Then plot that vector function for the given values of ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o\)]],
  ".)."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " A simple analytic form for the field lines from a dipole.can be found in \
spherical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], \[Phi])\)\)]],
  ". In these coordinates ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox["s",
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\((r(s), \[Theta](s), \[Phi](s))\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " and Eq. ",
  ButtonBox["(1.2.24)",
    ButtonData:>"(1.2.24)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[DifferentialD]r/\[DifferentialD]s\), "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{\(E\_r\), "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], "/"}], "|", 
            RowBox[{
              StyleBox["E",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox["|",
              FontWeight->"Plain"]}]}], 
        StyleBox[",",
          FontWeight->"Plain"], "\[IndentingNewLine]", 
        RowBox[{\(r\ \[DifferentialD]\ \[Theta]/\[DifferentialD]s\), "=", " ",
           
          RowBox[{
            RowBox[{
              RowBox[{\(E\_\[Theta]\), "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], "/"}], "|", 
            RowBox[{
              StyleBox["E",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox["|",
              FontWeight->"Plain"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          FormBox[
            
            RowBox[{\(r\ sin\[Theta] \[DifferentialD]\[Phi]/\[DifferentialD]s\
\), "=", " ", 
              RowBox[{
                RowBox[{
                  RowBox[{\(E\_\[Phi]\), "(", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ")"}], "/"}], "|", 
                RowBox[{
                  StyleBox["E",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox["|",
                  FontWeight->"Plain"]}]}],
            "TraditionalForm"], "."}]}], TraditionalForm]]]], "NE3",
  CellTags->"(1.3.7)"],

Cell[TextData[{
  "Also, since ",
  Cell[BoxData[
      \(TraditionalForm\`r = \@\(\[Rho]\^2 + z\^2\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z = r\ cos\[Theta]\)\(,\)\)\)]],
  " the dipole potential has the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta]) = cos\[Theta]/r\^2\)]],
  ". An equation for the variation of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " along a field line can be obtained  as follows:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/r\) \[DifferentialD]r\/\[DifferentialD]\[Theta] \
= \(\(\(\[DifferentialD]r/\[DifferentialD]s\)\/\(r\ \[DifferentialD]\ \
\[Theta]/\[DifferentialD]s\)\)\(=\)\(\(\(E\_r\)(
                r, \[Theta])\)\/\(\(E\_\[Theta]\)(
                r, \[Theta])\)\)\(\ \)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Solve this differential equation for ",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta])\)]],
  " with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta]\_o) = r\_o\)]],
  " to show that the equation for the field lines of a point dipole  in \
spherical coordinates is  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta]) = 
        r\_o\ \(sin\^2\) \[Theta]/sin\^2  \[Theta]\_o\)]],
  "."
}], "NE3",
  CellTags->"(1.3.8)"],

Cell[TextData[{
  "Superimpose plots of ",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta])\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`r\_o = 1, 2, 3, 4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_o = \[Pi]/2\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.4 Numerical Solution of Initial-Value Problems", "Subtitle",
  CellTags->{"Sec. 1.4", "i:42", "c:19"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "1.4.1 ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Subsubtitle",
  CellTags->"c:20"],

Cell[TextData[{
  "    ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " can solve ODE ",
  "initial-value",
  " problems numerically via the intrinsic function",
  StyleBox[" NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . The syntax for ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is almost identical to that for ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["NDSolve[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ODE, initial conditions",
    FontSlant->"Italic"],
  StyleBox["},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["],{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t,tmin,tmax",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  CellTags->"i:40"],

Cell[TextData[{
  "Three things must be remembered when using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[TextData[{
  "(1) Initial conditions must ",
  StyleBox["always",
    FontSlant->"Italic"],
  " be specified."
}], "Text"],

Cell["\<\
(2) No non-numerical constants can appear in the list of ODEs or \
the initial conditions. \
\>", "Text"],

Cell[TextData[{
  "(3) A finite interval of time must be provided, over which the solution \
for ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " is to be determined. "
}], "Text"],

Cell[TextData[{
  "\tAs an example,  we will solve the problem from the previous section that \
had no analytic solution, for the specific initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x(0)\  = \ 1\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NDSolve[{\(x'\)[t]\  \[Equal] t/\((x[t]\  + \ t)\)^2, x[0] \[Equal] 1}, 
      x[t], {t, 0, 10}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.14"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(x[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a list of possible substitutions for ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ", just as when using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". However, the function ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " is now determined numerically via an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "s are also used for interpolating lists of data (see ",
  ButtonBox["Sec. 9.11",
    ButtonData:>{"Chapter9.nb", "Sec. 9.11"},
    ButtonStyle->"Hyperlink"],
  "). The reason why an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used by ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will become clear in the next section, but can be briefly stated as \
follows: When ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " numerically solves an ODE, it finds  values for ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " only at specific values of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " between ",
  Cell[BoxData[
      FormBox[
        StyleBox["tmin",
          FontSlant->"Italic"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["tmax",
          FontSlant->"Italic"], TraditionalForm]]],
  ", and then uses an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to interpolate between these values of",
  StyleBox[" t",
    FontSlant->"Italic"],
  ".  "
}], "Text",
  CellTags->"i:41"],

Cell[TextData[{
  "\tAs discussed in ",
  ButtonBox["Sec. 9.11",
    ButtonData:>{"Chapter9.nb", "Sec. 9.11"},
    ButtonStyle->"Hyperlink"],
  " , the ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be evaluated at any point in its range of validity from ",
  Cell[BoxData[
      FormBox[
        StyleBox["tmin",
          FontSlant->"Italic"], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`tmax\)],
    FontSlant->"Italic"],
  ".  For example, we can plot the solution by first extracting the function \
from the list of possible solutions, "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[t] /. %[\([1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.15"],

Cell[BoxData[
    RowBox[{
      TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
        False,
        Editable->False], "[", "t", "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and then plotting the result, as shown in Cell ",
  ButtonBox["1.16",
    ButtonData:>"Cell 1.16",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[%, {t, 0, 10}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.16"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.474551 0.489266 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .11257 -18 -4.5 ]
[.01131 .11257 0 4.5 ]
[.01131 .21042 -18 -4.5 ]
[.01131 .21042 0 4.5 ]
[.01131 .30827 -18 -4.5 ]
[.01131 .30827 0 4.5 ]
[.01131 .40613 -18 -4.5 ]
[.01131 .40613 0 4.5 ]
[.01131 .50398 -6 -4.5 ]
[.01131 .50398 0 4.5 ]
[.01131 .60183 -18 -4.5 ]
[.01131 .60183 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11257 m
.03006 .11257 L
s
[(1.2)] .01131 .11257 1 0 Mshowa
.02381 .21042 m
.03006 .21042 L
s
[(1.4)] .01131 .21042 1 0 Mshowa
.02381 .30827 m
.03006 .30827 L
s
[(1.6)] .01131 .30827 1 0 Mshowa
.02381 .40613 m
.03006 .40613 L
s
[(1.8)] .01131 .40613 1 0 Mshowa
.02381 .50398 m
.03006 .50398 L
s
[(2)] .01131 .50398 1 0 Mshowa
.02381 .60183 m
.03006 .60183 L
s
[(2.2)] .01131 .60183 1 0 Mshowa
.125 Mabswid
.02381 .03918 m
.02756 .03918 L
s
.02381 .06364 m
.02756 .06364 L
s
.02381 .08811 m
.02756 .08811 L
s
.02381 .13703 m
.02756 .13703 L
s
.02381 .16149 m
.02756 .16149 L
s
.02381 .18596 m
.02756 .18596 L
s
.02381 .23488 m
.02756 .23488 L
s
.02381 .25935 m
.02756 .25935 L
s
.02381 .28381 m
.02756 .28381 L
s
.02381 .33274 m
.02756 .33274 L
s
.02381 .3572 m
.02756 .3572 L
s
.02381 .38166 m
.02756 .38166 L
s
.02381 .43059 m
.02756 .43059 L
s
.02381 .45505 m
.02756 .45505 L
s
.02381 .47952 m
.02756 .47952 L
s
.02381 .52844 m
.02756 .52844 L
s
.02381 .55291 m
.02756 .55291 L
s
.02381 .57737 m
.02756 .57737 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01475 L
.02605 .01485 L
.02729 .01503 L
.02846 .01526 L
.03053 .01583 L
.03279 .01664 L
.0379 .01913 L
.04262 .02211 L
.06244 .03917 L
.10458 .08433 L
.14393 .1267 L
.18177 .16482 L
.22205 .20225 L
.26083 .23546 L
.30205 .2681 L
.34176 .29729 L
.37995 .32354 L
.4206 .34976 L
.45973 .37354 L
.50131 .39739 L
.54137 .41916 L
.57993 .4391 L
.62093 .45932 L
.66042 .47792 L
.69839 .49507 L
.73881 .51261 L
.77772 .52884 L
.81908 .54545 L
.85893 .56087 L
.89726 .5752 L
.93804 .58996 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00F?ooool5o`0003kooooo0_l000000ol@413ooooo
ooooo`0jooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0??ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
03Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1?ooool005Sooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00oooooo`03o`000?oooooooooo03_ooooo00GoEEEEogMgMooooooo
V9RHob4Q8@0looooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40>_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool005Wooooo00?oV9RHob4Q8Oo^k^h0?Oooool5o`00
03cooooo00Go0000ooooooooooooooooo`00000looooo`05o`000?ooooooooooooooool00000>_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001?ooool005[ooooo00?o
V9RHob4Q8Oo^k^h0??ooool01?m4A4CogMgMooooool0000mooooo`05o`000?nHV9SooooooiRHV?lQ
8B40??ooool01Olb<S;oV9RHoooooonHV9So<S8b03[ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo001Kooooo`03ogMgMomVIVKooooo03_ooooo00CogMgMoeEE
EOoooooo0000?Oooool01Ol0003oEEEEo`000?l@413oc<c<03cooooo00Goc<c<o`000?l0003o0000
olc<c00jooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`00
G?ooool00ol0003oooooooooo`0kooooo`03ogMgMoo<c<co000003gooooo00?oEEEEohN7Qoooool0
?_ooool01Ol@413o^[Zjoooooonj^[[o410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Cooooo001Hooooo`05o`000?nj^[[ooooooiRHV?l@4100?Oooool00oo^
k^koA4A4o`00000mooooo`03omgMgOl@413oV9RH03kooooo00Go0000okZj^_oooooo^[Zjo`00000j
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`00F?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<03kooooo00?oMgMgo`000?ooool0?Oooool01?o<c<coA4A4o`00
0?l@410looooo`05ojVYZOl@413o0000oa0@4?nYZJT0>?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Boooooooo0000Eol0000001[ooooo00?o0000ooooooooool00_ooool2o`0000Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`07ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooA?ooool0
01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooood?ooooo000Jooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`3ooooood3ooooo000Jooooo`?o00002_ooool00ol0003oooooooooo`3o
ooooocoooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooooolooooo
o`006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo?_ooool001[ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`3oooooocgooooo000Jooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0oooooollooooo`006_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo0?oooooo>oooool001[ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`3ooooooc[ooooo000Jooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0ooooooliooooo`006_ooool3o`00017ooooo00?o0000ooooooooool0oooooolhooooo`006_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo=oooool001[ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`3oooooocKooooo000Jooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0ooooooleooooo`006_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo=?ooool001[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`3ooooooc?ooooo000Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0oooo
oolbooooo`006_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?oooooo<Oooool0
01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3ooooooc3ooooo000Jooooo`?o
00006Oooool00ol0003oooooooooo`3ooooooc3ooooo000Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0ooooool_ooooo`006_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo0?oooooo;_ooool001[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`3o
ooooobgooooo000Jooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0ooooool/oooo
o`006_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?oooooo:oooool000Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0oooooolZooooo`000_ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`3oooooobWooooo0002ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`00027ooooo00?o0000ooooooooool0oooooolXooooo`000_ooool00ol0003oooooooooo`0<
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3o
ooooobOooooo0002ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo9_ooool000;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0oooooolUooooo`000_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo9?ooool00003oeEE
EOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0oooooolSooooo`006_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0?oooooo8_ooool001[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`3oooooob7ooooo000Jooooo`?o0000:Oooool00ol0003oooooooooo`3oooooob3ooooo000Joooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0oooooolOooooo`006_ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo7_ooool001[ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`3ooooooagooooo000Jooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0oooooolLooooo`006_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo0?oooooo6oooool001[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3ooooo
oa[ooooo000Jooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0oooooolIooooo`00
6_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo6?ooool001[ooooo0ol0
000booooo`03o`000?oooooooooo0?oooooo5oooool001[ooooo00?o0000ooooooooool0<oooool2
o`000?oooooo5oooool001[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3ooooo
oaCooooo000Jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0oooooolCooooo`00
6_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0?oooooo4_ooool001[ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`3ooooooa7ooooo000Jooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0ooooool@ooooo`006_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo0?oooooo3oooool001[ooooo0ol0000kooooo`03o`000?oooooooooo0?oo
oooo3_ooool001[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`3oooooo`gooooo
000Jooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0ooooool<ooooo`006_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo0?oooooo2oooool001[ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`3oooooo`[ooooo000Jooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool0ooooool9ooooo`001?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool2o`000?oooooo
2Oooool000;ooooo00?o0000ooooooooool01?ooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0?oooooo1_ooool000;ooooo00?o0000
ooooooooool02_ooool5o`0000Kooooo0ol00014ooooo`03o`000?oooooooooo0?oooooo1Oooool0
00;ooooo00?o0000ooooooooool02_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0ooooool4ooooo`000_ooool00ol0003oooooooooo`0:oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3o
ooooo`?ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`17ooooo`;o0000ooooool3ooooo`000_ooool00ol0003oooooooooo`0;ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`3oooooo`00
00?oEEEEofIVI_l000003_ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0o_ooool001[ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`3mooooo`006_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0?cooooo000Joooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0noooool001[ooooo0ol0001>ooooo`;o
0000noooool001[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`3hooooo`006_oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0?Oooooo000Jooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool0m_ooool001[ooooo00?o0000ooooooooool0Doooool2o`00
0?Kooooo000Jooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0loooool001[ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`3booooo`006_ooool00ol0003ooooooooo
o`1Gooooo`;o0000l_ooool001[ooooo0ol0001Iooooo`03o`000?oooooooooo0>oooooo000Joooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0k_ooool001[ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`3]ooooo`006_ooool00ol0003oooooooooo`1Looooo`;o0000
kOooool001[ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`3Zooooo`006_ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo0>Wooooo000Jooooo`03o`000?oooooooooo
063ooooo0_l0003Yooooo`006_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0>Ko
oooo000Jooooo`?o0000Hoooool00ol0003oooooooooo`3Uooooo`006_ooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo0>Cooooo000Jooooo`03o`000?oooooooooo06Gooooo0_l0003T
ooooo`006_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo0>7ooooo000Jooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0h?ooool001[ooooo00?o0000ooooooooool0
JOooool2o`000>3ooooo0004o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo0=gooooo
0002ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1/ooooo`;o0000gOooool000;ooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`3Jooooo`000_ooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`0006oooooo0_l0003Jooooo`000_ooool00ol0003oooooooooo`0:ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo0=Oooooo
0002ooooo`03o`000?oooooooooo00[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo0=Kooooo0002ooooo`03o`000?oooooooooo00[ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`1cooooo`;o0000e_ooool00003oeEEEOmVIVKo0000
00gooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1eooooo`03o`000?oooooo
oooo0=?ooooo000Jooooo`03o`000?oooooooooo07Kooooo0_l0003Cooooo`006_ooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo0=3ooooo000Jooooo`03o`000?oooooooooo07Wooooo
0_l0003@ooooo`006_ooool3o`0007_ooooo00?o0000ooooooooool0cOooool001[ooooo00?o0000
ooooooooool0O?ooool2o`000<gooooo000Jooooo`03o`000?oooooooooo07kooooo0_l0003;oooo
o`006_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo0<Sooooo000Jooooo`03o`00
0?oooooooooo087ooooo0_l00038ooooo`006_ooool00ol0003oooooooooo`23ooooo`03o`000?oo
oooooooo0<Gooooo000Jooooo`03o`000?oooooooooo08Cooooo0_l00035ooooo`006_ooool00ol0
003oooooooooo`26ooooo`;o0000`oooool001[ooooo0ol00028ooooo`03o`000?oooooooooo0<3o
oooo000Jooooo`03o`000?oooooooooo08Wooooo0_l00030ooooo`006_ooool00ol0003ooooooooo
o`2;ooooo`;o0000__ooool001[ooooo00?o0000ooooooooool0SOooool2o`000;cooooo000Joooo
o`03o`000?oooooooooo08oooooo00?o0000ooooooooool0^Oooool001[ooooo00?o0000oooooooo
ool0T?ooool2o`000;Wooooo000Jooooo`03o`000?oooooooooo09;ooooo0_l0002gooooo`006_oo
ool00ol0003oooooooooo`2Dooooo`;o0000]Oooool001[ooooo00?o0000ooooooooool0U_ooool0
0ol0003oooooooooo`2booooo`006_ooool3o`0009Oooooo0_l0002booooo`006_ooool00ol0003o
ooooooooo`2Iooooo`;o0000/?ooool001[ooooo00?o0000ooooooooool0Voooool2o`000:kooooo
000Jooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0Zoooool001[ooooo00?o0000
ooooooooool0W_ooool2o`000:_ooooo000Jooooo`03o`000?oooooooooo0:3ooooo0_l0002Yoooo
o`001?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0X_ooool2o`000:Oooooo0002ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Toooo
o`;o0000YOooool000;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0002Vooooo`;o0000Xoooool000;ooooo00?o0000ooooooooool02_ooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`2Poooo
o`000_ooool00ol0003oooooooooo`0:ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`2Yooooo`;o0000X?ooool000;ooooo00?o0000ooooooooool02_ooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Zoooool2o`0009kooooo0002ooooo`03
o`000?oooooooooo00[ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0:gooooo0_l0002Looooo`0000?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0[oooool2o`0009[ooooo000Jooooo`03o`000?oooooooooo0;7o
oooo0_l0002Hooooo`006_ooool00ol0003oooooooooo`2cooooo`;o0000U_ooool001[ooooo0ol0
002eooooo`;o0000U?ooool001[ooooo00?o0000ooooooooool0]oooool2o`0009;ooooo000Joooo
o`03o`000?oooooooooo0;Wooooo0_l0002@ooooo`006_ooool00ol0003oooooooooo`2kooooo`;o
0000S_ooool001[ooooo00?o0000ooooooooool0_Oooool2o`0008cooooo000Jooooo`03o`000?oo
oooooooo0;oooooo0_l0002:ooooo`006_ooool00ol0003oooooooooo`31ooooo`;o0000R?ooool0
01[ooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`25ooooo`006_ooool00ol0003o
ooooooooo`34ooooo`;o0000QOooool001[ooooo0ol00036ooooo`;o0000Poooool001[ooooo00?o
0000ooooooooool0b?ooool2o`00087ooooo000Jooooo`03o`000?oooooooooo0<[ooooo0ol0001n
ooooo`006_ooool00ol0003oooooooooo`3=ooooo`;o0000O?ooool001[ooooo00?o0000oooooooo
ool0coooool2o`0007[ooooo000Jooooo`03o`000?oooooooooo0=7ooooo0ol0001gooooo`006_oo
ool00ol0003oooooooooo`3Dooooo`;o0000MOooool001[ooooo00?o0000ooooooooool0e_ooool2
o`0007?ooooo000Jooooo`?o0000f?ooool2o`00077ooooo000Jooooo`03o`000?oooooooooo0=[o
oooo0_l0001_ooooo`006_ooool00ol0003oooooooooo`3Looooo`?o0000K?ooool001[ooooo00?o
0000ooooooooool0goooool2o`0006[ooooo000Jooooo`03o`000?oooooooooo0>7ooooo0_l0001X
ooooo`006_ooool00ol0003oooooooooo`3Sooooo`;o0000I_ooool000oooooo1Ol00006ooooo`03
o`000?oooooooooo0>Gooooo0ol0001Sooooo`003oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0j?ooool2o`00067ooooo000@ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
0ol0003Zooooo`;o0000Goooool0017ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`3/ooooo`?o0000G?ooool001;ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3_
ooooo`;o0000F_ooool001?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3aoooo
o`;o0000F?ooool000oooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
0??ooooo0_l0001Fooooo`003oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0mOooool2o`0005Cooooo000Jooooo`03o`000?oooooooooo0?Oooooo0ol0001Aooooo`00
6_ooool00ol0003oooooooooo`3jooooo`;o0000Coooool001[ooooo00?o0000ooooooooool0o?oo
ool2o`0004gooooo000Jooooo`?o0000o_ooool2o`0004_ooooo000Jooooo`03o`000?oooooooooo
0?oooooo0Oooool3o`0004Sooooo000Jooooo`03o`000?oooooooooo0?oooooo1?ooool3o`0004Go
oooo000Jooooo`03o`000?oooooooooo0?oooooo1oooool3o`0004;ooooo000Jooooo`03o`000?oo
oooooooo0?oooooo2_ooool3o`0003oooooo000Jooooo`03o`000?oooooooooo0?oooooo3Oooool2
o`0003gooooo000Jooooo`03o`000?oooooooooo0?oooooo3oooool2o`0003_ooooo000Jooooo`03
o`000?oooooooooo0?oooooo4Oooool2o`0003Wooooo000Jooooo`?o0000oooooolCooooo`?o0000
=_ooool001[ooooo00?o0000ooooooooool0oooooolFooooo`;o0000=?ooool001[ooooo00?o0000
ooooooooool0oooooolHooooo`;o0000<_ooool001[ooooo00?o0000ooooooooool0oooooolJoooo
o`;o0000<?ooool001[ooooo00?o0000ooooooooool0oooooolLooooo`?o0000;Oooool001[ooooo
00?o0000ooooooooool0oooooolOooooo`?o0000:_ooool001[ooooo00?o0000ooooooooool0oooo
oolRooooo`?o00009oooool001[ooooo00?o0000ooooooooool0oooooolUooooo`?o00009?ooool0
01[ooooo0ol0003oooooobSooooo0_l0000Rooooo`006_ooool00ol0003oooooooooo`3oooooob[o
oooo0ol0000Oooooo`006_ooool00ol0003oooooooooo`3oooooobgooooo0ol0000Looooo`006_oo
ool00ol0003oooooooooo`3ooooooc3ooooo0_l0000Jooooo`006_ooool00ol0003oooooooooo`3o
oooooc;ooooo0ol0000Gooooo`006_ooool00ol0003oooooooooo`3oooooocGooooo0ol0000Doooo
o`001?l00005ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooolhooooo`?o
00004Oooool00004ob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`3ooooooc_ooooo0ol0000>ooooo`0000?oV9RHob4Q8Oo^
k^h03Oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo?_ooool3o`0000_o
oooo00001?ooooooV9RHob4Q8Oo^k^h=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood7o
oooo0_l00009ooooo`000_ooool00omgMgOoIVIVooooo`0=ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom<ooooo`0000Co^[ZjoooooonHV9So410@2ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
410@o`000?lQ8B7oc<c<2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.825443, 0.905626, \
0.0385637, 0.00750662}}]
}, Open  ]],

Cell[TextData[{
  "\tNow we come to an important question: how do we know that the answer \
provided by ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is correct? The numerical solution clearly matches the initial condition, \
",
  Cell[BoxData[
      \(TraditionalForm\`x(0)\  = \ 1\)]],
  ".  How do we tell if it also solves the ODE? One way to tell this is to \
plug the solution back into the ODE to see if the ODE is satisfied. We can do \
this just as we have done with previous analytic solutions, except that the \
answer will now evaluate to a numerical function of time, which must then be \
plotted to see how much it differs from zero (see Cell ",
  ButtonBox["1.17",
    ButtonData:>"Cell 1.17",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellTags->"i:45"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_]\  = \ %%;\)\), "\n", 
    \(\(error[t_]\  = \ \(x'\)[t]\  - \ t/\((x[t] + t)\)^2;\)\), "\n", 
    \(\(Plot[error[t], {t, 0, 10}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.17"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.310672 33090.6 [
[.21429 .29817 -3 -9 ]
[.21429 .29817 3 0 ]
[.40476 .29817 -3 -9 ]
[.40476 .29817 3 0 ]
[.59524 .29817 -3 -9 ]
[.59524 .29817 3 0 ]
[.78571 .29817 -3 -9 ]
[.78571 .29817 3 0 ]
[.97619 .29817 -6 -9 ]
[.97619 .29817 6 0 ]
[.01131 .06249 -51 -6.25 ]
[.01131 .06249 0 6.25 ]
[.01131 .14522 -39 -6.25 ]
[.01131 .14522 0 6.25 ]
[.01131 .22795 -51 -6.25 ]
[.01131 .22795 0 6.25 ]
[.01131 .3934 -45 -6.25 ]
[.01131 .3934 0 6.25 ]
[.01131 .47613 -33 -6.25 ]
[.01131 .47613 0 6.25 ]
[.01131 .55885 -45 -6.25 ]
[.01131 .55885 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .31067 m
.21429 .31692 L
s
[(2)] .21429 .29817 0 1 Mshowa
.40476 .31067 m
.40476 .31692 L
s
[(4)] .40476 .29817 0 1 Mshowa
.59524 .31067 m
.59524 .31692 L
s
[(6)] .59524 .29817 0 1 Mshowa
.78571 .31067 m
.78571 .31692 L
s
[(8)] .78571 .29817 0 1 Mshowa
.97619 .31067 m
.97619 .31692 L
s
[(10)] .97619 .29817 0 1 Mshowa
.125 Mabswid
.07143 .31067 m
.07143 .31442 L
s
.11905 .31067 m
.11905 .31442 L
s
.16667 .31067 m
.16667 .31442 L
s
.2619 .31067 m
.2619 .31442 L
s
.30952 .31067 m
.30952 .31442 L
s
.35714 .31067 m
.35714 .31442 L
s
.45238 .31067 m
.45238 .31442 L
s
.5 .31067 m
.5 .31442 L
s
.54762 .31067 m
.54762 .31442 L
s
.64286 .31067 m
.64286 .31442 L
s
.69048 .31067 m
.69048 .31442 L
s
.7381 .31067 m
.7381 .31442 L
s
.83333 .31067 m
.83333 .31442 L
s
.88095 .31067 m
.88095 .31442 L
s
.92857 .31067 m
.92857 .31442 L
s
.25 Mabswid
0 .31067 m
1 .31067 L
s
.02381 .06249 m
.03006 .06249 L
s
gsave
.01131 .06249 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .14522 m
.03006 .14522 L
s
gsave
.01131 .14522 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .22795 m
.03006 .22795 L
s
gsave
.01131 .22795 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .3934 m
.03006 .3934 L
s
gsave
.01131 .3934 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .47613 m
.03006 .47613 L
s
gsave
.01131 .47613 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .55885 m
.03006 .55885 L
s
gsave
.01131 .55885 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02381 .07904 m
.02756 .07904 L
s
.02381 .09558 m
.02756 .09558 L
s
.02381 .11213 m
.02756 .11213 L
s
.02381 .12867 m
.02756 .12867 L
s
.02381 .16176 m
.02756 .16176 L
s
.02381 .17831 m
.02756 .17831 L
s
.02381 .19486 m
.02756 .19486 L
s
.02381 .2114 m
.02756 .2114 L
s
.02381 .24449 m
.02756 .24449 L
s
.02381 .26104 m
.02756 .26104 L
s
.02381 .27758 m
.02756 .27758 L
s
.02381 .29413 m
.02756 .29413 L
s
.02381 .32722 m
.02756 .32722 L
s
.02381 .34376 m
.02756 .34376 L
s
.02381 .36031 m
.02756 .36031 L
s
.02381 .37685 m
.02756 .37685 L
s
.02381 .40994 m
.02756 .40994 L
s
.02381 .42649 m
.02756 .42649 L
s
.02381 .44303 m
.02756 .44303 L
s
.02381 .45958 m
.02756 .45958 L
s
.02381 .49267 m
.02756 .49267 L
s
.02381 .50922 m
.02756 .50922 L
s
.02381 .52576 m
.02756 .52576 L
s
.02381 .54231 m
.02756 .54231 L
s
.02381 .04595 m
.02756 .04595 L
s
.02381 .0294 m
.02756 .0294 L
s
.02381 .01286 m
.02756 .01286 L
s
.02381 .5754 m
.02756 .5754 L
s
.02381 .59194 m
.02756 .59194 L
s
.02381 .60849 m
.02756 .60849 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02498 .61803 m
.02499 .1019 L
s
.02499 .1019 m
.02535 .61803 L
s
.02784 .61803 m
.02824 0 L
s
.02865 0 m
.02902 .61803 L
s
.03108 .61803 m
.03155 0 L
s
.0317 0 m
.03212 .61803 L
s
.03689 .61803 m
.03746 .02805 L
s
.03746 .02805 m
.0375 0 L
s
.03949 0 m
.04004 .61803 L
s
.0403 .61803 m
.04132 .21038 L
.04262 .19086 L
s
.04262 .19086 m
.04316 .61803 L
s
.04408 .61803 m
.04447 0 L
s
.04797 0 m
.04837 .45255 L
s
.04837 .45255 m
.0486 .61803 L
s
.05002 .61803 m
.05042 0 L
s
.05312 0 m
.05349 .20734 L
.05423 .53285 L
s
.05423 .53285 m
.05469 .61803 L
s
.055 .61803 m
.05597 0 L
s
.05837 0 m
.05866 .1183 L
.05991 .54173 L
.06122 .11487 L
s
.06122 .11487 m
.06163 0 L
s
.06342 0 m
.06393 .12024 L
.06461 .26947 L
.06533 .50527 L
s
.06533 .50527 m
.06565 .61803 L
s
.06694 .61803 m
.06795 .08394 L
s
.06795 .08394 m
.06815 0 L
s
.06989 0 m
.07022 .11498 L
.07098 .29863 L
.07169 .32473 L
.07234 .29538 L
.07306 .24002 L
.07382 .28704 L
s
.07382 .28704 m
.07459 .61803 L
s
.07869 .61803 m
.07935 .33765 L
s
.07935 .33765 m
.07993 0 L
s
.08196 0 m
.08262 .61803 L
s
.08513 .61803 m
.08519 .58412 L
.0859 .40052 L
.08716 .25221 L
.08843 .13327 L
.08958 .34248 L
.09086 .57486 L
.09158 .5349 L
.09225 .4442 L
.09296 .37214 L
.09361 .33564 L
.09431 .2915 L
.09506 .23306 L
.09628 .24882 L
.09741 .41178 L
.09863 .46484 L
.09932 .41667 L
.09996 .36935 L
.10112 .32081 L
.10219 .26626 L
.10342 .25482 L
.10458 .36681 L
.10572 .42379 L
.10694 .36814 L
.10916 .29335 L
.11044 .24434 L
.11109 .24824 L
.1118 .29635 L
.11305 .47081 L
s
.11305 .47081 m
.11421 .61803 L
s
.11587 .61803 m
.11681 .54983 L
.11917 .348 L
.12051 .16678 L
.12118 .07435 L
.12192 .03635 L
.12324 .23167 L
.12446 .56709 L
s
.12446 .56709 m
.12482 .61803 L
s
.12703 .61803 m
.12801 .47941 L
.1291 .38483 L
.13115 .23995 L
.1323 .15373 L
.13334 .17742 L
.13457 .35323 L
.1357 .52197 L
.13694 .56119 L
.13825 .46294 L
.14047 .33731 L
.14164 .28424 L
.14288 .21808 L
.14351 .20654 L
.1442 .22862 L
.14543 .34196 L
.14667 .45312 L
.14784 .4657 L
.14898 .41066 L
.15002 .36044 L
.15116 .32976 L
.15236 .29714 L
.15358 .25622 L
.15488 .25581 L
.15611 .32166 L
.15722 .38907 L
.15853 .40911 L
.15927 .39098 L
.15995 .36744 L
.1612 .33438 L
.16184 .32467 L
.16253 .31427 L
.16376 .28927 L
.16492 .27046 L
.16596 .28242 L
.1671 .32568 L
.16833 .36799 L
.16965 .36974 L
.17089 .34431 L
.17201 .32601 L
.1742 .30214 L
.17536 .28409 L
.17657 .27268 L
.17764 .28405 L
.17881 .32659 L
.17988 .38512 L
.18087 .44218 L
.18214 .49587 L
.18278 .50901 L
.18348 .51164 L
Mistroke
.18473 .49109 L
.1859 .45584 L
.18736 .40947 L
.18875 .36571 L
.19 .31614 L
.19136 .24311 L
.19256 .17601 L
.19384 .14677 L
.19504 .1928 L
.19614 .29103 L
.19741 .42773 L
.19808 .48844 L
.19878 .53314 L
.20008 .55171 L
.20128 .50795 L
.20233 .44932 L
.20347 .39306 L
.20455 .35834 L
.20555 .33646 L
.20794 .27267 L
.20907 .23781 L
.21013 .22065 L
.21129 .23544 L
.21257 .29301 L
.21392 .37334 L
.21516 .42927 L
.21626 .44658 L
.21741 .43193 L
.21858 .39808 L
.21985 .36133 L
.22117 .33689 L
.22238 .32206 L
.22369 .30356 L
.22513 .2777 L
.22638 .26105 L
.22755 .2637 L
.22879 .28997 L
.22948 .31216 L
.23012 .33385 L
.23131 .36891 L
.23241 .38565 L
.23362 .38302 L
.23491 .36386 L
.23945 .31341 L
.24078 .30173 L
.2415 .29434 L
.24217 .28798 L
.2429 .28332 L
.2437 .28274 L
.24439 .2868 L
Mistroke
.24511 .29562 L
.24643 .31896 L
.24712 .33178 L
.24785 .34314 L
.24849 .34992 L
.2492 .35333 L
.25044 .3496 L
.25174 .3379 L
.25242 .33137 L
.25313 .32552 L
.25445 .31833 L
.25565 .31373 L
.25793 .30211 L
.25922 .29576 L
.2604 .295 L
.26165 .30193 L
.26228 .30791 L
.26298 .3154 L
.26415 .32725 L
.26541 .33454 L
.26664 .33431 L
.26776 .32939 L
.26883 .32341 L
.26996 .31821 L
.27126 .31453 L
.27247 .31185 L
.27377 .30814 L
.2752 .30288 L
.27643 .2984 L
.27713 .2966 L
.27776 .29579 L
.27893 .29735 L
.28017 .30428 L
.28132 .31581 L
.28236 .32991 L
.28471 .36726 L
.28575 .38268 L
.28689 .39616 L
.28795 .40462 L
.28894 .40833 L
.29009 .40781 L
.29116 .40332 L
.29234 .39518 L
.2936 .38434 L
.29855 .33904 L
.30344 .26803 L
.30412 .25608 L
.30485 .2443 L
.30554 .23525 L
.30618 .22952 L
Mistroke
.30738 .22754 L
.30865 .24007 L
.30934 .25288 L
.31007 .27067 L
.31138 .31029 L
.31292 .3602 L
.31368 .38259 L
.31438 .40047 L
.31502 .41381 L
.31571 .4242 L
.31639 .43042 L
.31715 .43243 L
.31846 .42516 L
.31969 .40916 L
.32213 .36866 L
.32332 .3519 L
.3244 .34028 L
.32554 .3313 L
.32677 .3238 L
.32936 .30671 L
.3307 .29539 L
.33215 .28234 L
.33282 .27696 L
.33353 .2723 L
.33479 .26808 L
.33602 .27057 L
.33717 .27922 L
.33843 .29471 L
.33978 .31558 L
.34109 .33623 L
.34233 .35263 L
.34301 .35951 L
.34375 .36477 L
.34504 .36825 L
.34627 .36526 L
.34758 .35717 L
.34991 .33817 L
.35123 .32905 L
.35196 .32514 L
.35264 .32216 L
.35397 .31793 L
.35518 .31493 L
.35799 .30682 L
.35952 .30125 L
.36027 .29857 L
.36096 .29639 L
.36211 .29386 L
.36334 .29339 L
.36399 .29426 L
.36469 .2961 L
Mistroke
.36597 .30162 L
.36839 .31651 L
.36945 .32289 L
.3706 .32848 L
.3713 .33094 L
.37195 .33246 L
.37322 .33331 L
.37387 .33272 L
.37458 .33141 L
.37533 .32948 L
.37602 .32733 L
.37729 .3231 L
.37864 .31899 L
.37979 .3163 L
.38106 .31426 L
.3823 .31294 L
.38364 .31175 L
.38606 .30915 L
.38743 .30737 L
.38871 .30579 L
.38935 .30516 L
.39004 .30467 L
.39081 .30442 L
.3915 .30451 L
.39277 .30551 L
.39349 .30651 L
.39415 .30767 L
.39666 .31303 L
.39785 .31536 L
.39896 .317 L
.40012 .31795 L
.4014 .31806 L
.40254 .31744 L
.40379 .31623 L
.40489 .31496 L
.40607 .31367 L
.40723 .31262 L
.40828 .31194 L
.40934 .31149 L
.41034 .31121 L
.41274 .31066 L
.41531 .30991 L
.41655 .30953 L
.41774 .30926 L
.41879 .30913 L
.41995 .30917 L
.42112 .30939 L
.42237 .3098 L
.42461 .31076 L
.42578 .31122 L
Mistroke
.42704 .31157 L
.42776 .31169 L
.42843 .31175 L
.42972 .3117 L
.43097 .3115 L
.43213 .31124 L
.4335 .31093 L
.43475 .3107 L
.43607 .31056 L
.43731 .31052 L
.43862 .31055 L
.43936 .31059 L
.44005 .31063 L
.44226 .31081 L
.44432 .31103 L
.44558 .31119 L
.44678 .31132 L
.44785 .3114 L
.44902 .31144 L
.45018 .3114 L
.4514 .31122 L
.45256 .31091 L
.45361 .31047 L
.45483 .30977 L
.45614 .30874 L
.45852 .30616 L
.46091 .30265 L
.46347 .29804 L
.46807 .28857 L
.47308 .27905 L
.47445 .27697 L
.47591 .27511 L
.47717 .27382 L
.47852 .27276 L
.47925 .27233 L
.47992 .27203 L
.48122 .27168 L
.48195 .27163 L
.48275 .27167 L
.4835 .2718 L
.4842 .27201 L
.4849 .27229 L
.48556 .27261 L
.48679 .27337 L
.48956 .27568 L
.49439 .28121 L
.49961 .28921 L
.50198 .29385 L
.50452 .29983 L
.50911 .31397 L
Mistroke
.51411 .33449 L
.51674 .34545 L
.51819 .3504 L
.51889 .35238 L
.51954 .35387 L
.52022 .35504 L
.52094 .35584 L
.52169 .35611 L
.52248 .35573 L
.52378 .35355 L
.52452 .35141 L
.5252 .34882 L
.52656 .34199 L
.52779 .33388 L
.53056 .30992 L
.53544 .25614 L
.53811 .22677 L
.54061 .20324 L
.5429 .18694 L
.54418 .18045 L
.54536 .17628 L
.54664 .17368 L
.54737 .17308 L
.54804 .17308 L
.54927 .17437 L
.55059 .17744 L
.55178 .18154 L
.55307 .18715 L
.55541 .1995 L
.55979 .22544 L
.56971 .27597 L
.58058 .3497 L
.58315 .37202 L
.58558 .39079 L
.58692 .39885 L
.58767 .40238 L
.58837 .40487 L
.58961 .40728 L
.59092 .40674 L
.59206 .4035 L
.59329 .39705 L
.59444 .38815 L
.5955 .37771 L
.59797 .34599 L
.60056 .30432 L
.60543 .22026 L
.60811 .1813 L
.60942 .16602 L
.61063 .15464 L
.61131 .14943 L
Mistroke
.61207 .14475 L
.61282 .14117 L
.61362 .13859 L
.6143 .13737 L
.61502 .13703 L
.61633 .13879 L
.61701 .14084 L
.61776 .14387 L
.61911 .15129 L
.62163 .17027 L
.64138 .3006 L
.64618 .33003 L
.65136 .36771 L
.6528 .3771 L
.65432 .38526 L
.65562 .39028 L
.65635 .39217 L
.65704 .39325 L
.65773 .39361 L
.65839 .39324 L
.65962 .39066 L
.66031 .3881 L
.66094 .38503 L
.66238 .37563 L
.66363 .36484 L
.66481 .35255 L
.66704 .32519 L
.67206 .25497 L
.67415 .2279 L
.67639 .20401 L
.67767 .19329 L
.67884 .18574 L
.68001 .18031 L
.68112 .1772 L
.68231 .176 L
.68363 .17713 L
.68429 .17861 L
.685 .18081 L
.68628 .18623 L
.68876 .20088 L
.69103 .21702 L
.69623 .2535 L
.69885 .26792 L
.70175 .2801 L
.71167 .31473 L
.71645 .33766 L
.71855 .34815 L
.72084 .3582 L
.72214 .36263 L
.72335 .36559 L
Mistroke
.72463 .36725 L
.72535 .36745 L
.726 .36715 L
.72671 .36628 L
.72737 .36497 L
.72809 .36295 L
.72886 .36017 L
.73014 .35403 L
.73155 .34529 L
.73675 .30056 L
.74161 .25569 L
.74286 .24604 L
.74419 .23723 L
.74535 .23098 L
.74659 .22578 L
.74736 .22341 L
.74806 .22179 L
.74873 .22075 L
.74944 .22017 L
.75067 .22039 L
.75137 .22117 L
.75202 .22229 L
.75331 .22553 L
.75452 .22966 L
.7568 .23944 L
.76191 .26458 L
.76415 .27436 L
.76653 .28293 L
.77079 .29407 L
.78045 .31702 L
.78526 .33266 L
.78764 .33994 L
.7888 .34289 L
.78985 .34508 L
.79107 .34689 L
.79237 .34782 L
.79306 .34784 L
.79379 .34749 L
.79449 .34679 L
.79513 .34582 L
.79625 .34339 L
.79748 .33966 L
.79997 .32904 L
.80447 .3027 L
.80684 .28777 L
.80936 .27331 L
.81156 .26307 L
.81281 .25855 L
.81398 .25527 L
.81506 .25312 L
Mistroke
.81604 .25187 L
.81712 .25128 L
.81826 .25151 L
.81948 .25265 L
.82079 .25477 L
.82201 .2575 L
.82313 .26047 L
.82846 .27744 L
.83776 .29898 L
.84864 .31621 L
.85341 .32678 L
.85595 .33227 L
.85734 .33489 L
.85867 .33695 L
.85987 .33834 L
.86118 .33925 L
.86237 .33945 L
.86348 .33904 L
.86462 .33798 L
.86566 .33645 L
.86686 .33398 L
.86798 .33099 L
.87045 .32228 L
.87272 .312 L
.87784 .28403 L
.88037 .26984 L
.88308 .25597 L
.88558 .2453 L
.88796 .23775 L
.88924 .23485 L
.88996 .23358 L
.89062 .23265 L
.8918 .23157 L
.89305 .23118 L
.89371 .23129 L
.89442 .23163 L
.89571 .2328 L
.89645 .2338 L
.89724 .23506 L
.89864 .23783 L
.91863 .29017 L
.92734 .312 L
.93193 .32716 L
.93444 .33505 L
.93566 .33816 L
.93678 .34033 L
.93795 .34179 L
.93921 .34232 L
.93987 .34215 L
.94058 .34163 L
Mistroke
.94189 .33982 L
.94307 .33729 L
.94433 .33387 L
.94659 .32659 L
.9487 .31963 L
.95098 .31337 L
.95229 .31081 L
.95349 .30925 L
.95463 .30849 L
.95584 .30845 L
.95711 .30915 L
.95827 .31033 L
.96087 .3141 L
.96205 .31595 L
.96331 .31774 L
.96447 .3191 L
.96555 .32002 L
.9668 .32059 L
.96746 .32067 L
.96818 .32058 L
.96894 .32029 L
.96966 .31985 L
.97031 .31931 L
.97102 .3186 L
.9737 .31498 L
.97619 .31067 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00@oooool3o`000003ooooool0
003o000000Wo00000_ooool00ol0003oooooooooo`3ooooooa;ooooo0013ooooo`?o000000?ooooo
o`000?l000002Ol00002ooooo`03o`000?oooooooooo0?oooooo4_ooool004?ooooo0ol000000ooo
oooo0000o`000009o`0000;ooooo00?o0000ooooooooool0oooooolBooooo`00@oooool3o`000003
ooooool0003o000000Wo00000_ooool00ol0003oooooooooo`3ooooooa;ooooo0013ooooo`?o0000
00?oooooo`000?l000002Ol00002ooooo`03o`000?oooooooooo0?oooooo4_ooool004?ooooo0ol0
00000ooooooo0000o`000009o`0000;ooooo00?o0000ooooooooool0oooooolBooooo`00@oooool3
o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooooooo`3ooooooa;ooooo0013oooo
o`?o000000?oooooo`000?l000002Ol00002ooooo`03o`000?oooooooooo0?oooooo4_ooool004?o
oooo0ol000000ooooooo0000o`000009o`0000;ooooo00?o0000ooooooooool0oooooolBooooo`00
@oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooooooo`3ooooooa;ooooo
0013ooooo`?o000000?oooooo`000?l000002Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0ooooool6ooooo`00@oooool3o`000003ooooool0003o000000Wo00000_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo1_ooool004?ooooo0ol000000ooo
oooo0000o`000009o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3ooooo
o`Kooooo000Pooooo`;ok^k^0oooool2onk^kQcooooo0ol000000ooooooo0000o`000009o`0000;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooo`Kooooo000;ooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPgooooo0ol000000ooooooo0000o`000009o`0000;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`3oooooo`Kooooo000;ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48oooo
o`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo0ol000000ooooooo0000o`000009o`0000;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooo`Kooooo00000ooooooo0000
o`000004o`0000Cooooo00?oZJVYoeEEEOooool04?ooool01ol0003ooooooooooooooooogMgMo`00
0?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool3
o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo0?oooooo1_ooool000cooooo00?o8B4Qooooooooool03_ooool02OmgMgOo<S8boooooooooooo
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`?o000000?oooooo`000?l000002Ol00002ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0ooooool6ooooo`003?ooool00omEEEGoc<c<ooooo`0;ooooo`0=o`00
0?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`?o000000?oooooo`000?l0
00002Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool6ooooo`00
3?ooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool3o`000003
ooooool0003o000000Wo00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oo
oooo1_ooool000Wooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo0ol000000ooo
oooo0000o`000009o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3ooooo
o`Kooooo0009ooooo`Go00003?ooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo0_l00003ooooo`?o000000?oooooo`000?l000002Ol00002oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool6ooooo`00?Oooool01?l0003o
ooooooooool00002ooooo`?o000000?oooooo`000?l000002Ol00002ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0ooooool6ooooo`00>?ooool4o`000005ooooool0003ooooooooo
ool000000_ooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0?oooooo1_ooool003gooooo0ol00003ooooo`?o000000?oooooo`000?l0
00002Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool6ooooo`00
?_ooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?l000002Ol00002ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0ooooool6ooooo`00?oooool01?l0003ooooooooo
ooooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0?oooooo1_ooool004?ooooo0ol000000ooooooo0000o`000009o`0000;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`3oooooo`Kooooo0013ooooo`?o000000?ooooo
o`000?l000002Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool6
ooooo`00@oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0?oooooo1_ooool004?ooooo0ol000000ooooooo0000o`000009o`0000;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooo`Kooooo0013ooooo`?o0000
00?oooooo`000?l000002Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
ooooool6ooooo`00@oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0?oooooo1_ooool004?ooooo0ol000000ooooooo0000o`000009
o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooo`Kooooo0013oooo
o`?o000000?oooooo`000?l000002Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0ooooool6ooooo`00@oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0?oooooo1_ooool004?ooooo0ol000000ooooooo0000
o`000009o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooo`Kooooo
0013ooooo`?o000000?oooooo`000?l000002Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0ooooool6ooooo`007oooool2onk^kP?ooooo0_o^k^hMooooo`?o000000?ooooo
o`000?l000002Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool6
ooooo`006Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`?o0000
00?oooooo`000?l000002Ol00002ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
ooooool6ooooo`007?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`?o000000?ooooo
o`000?l000002Ol00002ooooo`03o`000?oooooo000000Wooooo0_l0003oooooo`Oooooo000@oooo
o`Ko00001oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool3o`000003ooooool0003o000000Wo0000
0_ooool00ol0003oooooo`000009ooooo`;o0000TOooool2o`0007?ooooo000Looooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000kooooo0ol000000ooooooo0000o`000009o`0000;ooooo00?o0000
ooooool000002Oooool2o`00097ooooo0_l0001cooooo`006Oooool03Ol0003o8B4Qo`000?lb<S;o
c<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000003_ooool3o`000003ooooool0003o000000Wo00000_ooool0
0ol0003oooooo`000009ooooo`;o00005?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
000007?ooooo000Iooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool3o`000003ooooool0003o
000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o00005?ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooo000007?ooooo000Iooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l00004ooooo`?o000000?ooooo
o`000?l000002Ol00002ooooo`03o`000?oooooo000000Wooooo0_l0000Dooooo`03o`000?oooooo
oooo07Wooooo00Co0000oooooooooooo0000L_ooool001Wooooo1?l0000<ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0000?ooooo
0ol000000ooooooo0000o`000009o`0000;ooooo00?o0000ooooool000002Oooool2o`000003oooo
ool0003ooooo017ooooo00?o0000ooooooooool0NOooool01?l0003oooooooooool0001booooo`00
=oooool4o`000005ooooool0003oooooooooool000000oooool3o`000003ooooool0003o000000Wo
00000_ooool00ol0003oooooo`000009ooooo`;o000000?oooooo`000?ooool04Oooool00ol0003o
ooooooooo`1iooooo`04o`000?ooooooooooo`0007;ooooo000looooo`?o00001?ooool3o`000003
ooooool0003o000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o000000?oooooo`000?oo
ool04?ooool2o`0007_ooooo00Co0000oooooooooooo0000L_ooool003gooooo00?o0000oooooooo
ool00oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o
000000?oooooo`000?ooool04?ooool2o`0007_ooooo00Co0000oooooooooooo0000L_ooool003ko
oooo00?o0000ooooooooool00_ooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003o
ooooo`000009ooooo`;o000000?oooooo`000?l000004?ooool2o`0007_ooooo00Co0000oooooooo
oooo0000L_ooool004?ooooo0ol000000ooooooo0000o`000009o`0000;ooooo00?o0000ooooool0
00002Oooool2o`000003ooooool0003o0000013ooooo0_l0001Xooooo`03o`000?oooooooooo013o
oooo00Co0000oooooooooooo0000L_ooool004?ooooo0ol000000ooooooo0000o`000009o`0000;o
oooo00?o0000ooooool000002Oooool2o`000003ooooool0003o0000013ooooo0_l0001Xooooo`;o
00004?ooool01Ol0003ooooooooooooooooo0000017ooooo0_l0001Oooooo`00@oooool3o`000003
ooooool0003o000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o000000?oooooo`000?l0
00004?ooool2o`0006Oooooo00?o0000ooooool000004?ooool01Ol0003ooooooooooooooooo0000
017ooooo0_l0001Oooooo`00@oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003o
ooooo`000009ooooo`;o000000?oooooo`000?l000004?ooool2o`0006Oooooo00?o0000ooooool0
00004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo0_l0001Oooooo`00
@oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0006Oooooo00Co0000oooooooooooo00003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000G_ooool004?o
oooo0ol000000ooooooo0000o`000009o`0000;ooooo00?o0000ooooool000002Oooool2o`000003
ooooool0003o0000013ooooo0_l0001Wooooo`04o`000?ooooooooooo`0000oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0005kooooo0013oooo
o`?o000000?oooooo`000?l000002Ol00002ooooo`03o`000?oooooo000000Wooooo0_l000000ooo
oooo0000o`00000@ooooo`;o0000Ioooool01?l0003oooooooooool0000?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0001Nooooo`00@oooool3
o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o000000?ooooo
o`000?l000004?ooool2o`0006Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0
001Nooooo`00@oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooo`000009
ooooo`;o000000?oooooo`000?l000004?ooool2o`0006Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool0
1?l0003oooooooooool0001Nooooo`00@oooool3o`000003ooooool0003o000000Wo00000_ooool0
0ol0003oooooo`000009ooooo`;o000000?oooooo`000?l000004?ooool2o`0006Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03Oooool01?l0003oooooooooool0001Nooooo`00@oooool3o`000003ooooool0003o
000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o000000?oooooo`000?l000000_ooool0
0ol0003oooooooooo`0;ooooo`;o0000I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooo
ooooo`0005kooooo000Pooooo`;ok^k^0oooool2onk^kQcooooo0ol000000ooooooo0000o`000009
o`0000;ooooo00?o0000ooooool000002Oooool2o`000003ooooool0003o000000;ooooo00?o0000
ooooooooool02oooool2o`0006Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0
001Nooooo`002Oooool5o`0000Gooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgooooo
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo0ol000000ooooooo0000o`000009o`0000;ooooo00?o0000ooooool0
00002Oooool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool02oooool2o`0006Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000005gooooo0009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03Oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o0000IOooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool00000GOooool00003ooooool0003o000000Co00000oooool00onH
V9So8B4Qonk^kP0Aooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`?o000000?oooooo`000?l00000
2Ol00002ooooo`03o`000?oooooo000000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000go
oooo0_l00004ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00kooooo0_l0001;ooooo`002oooool00onHV9So8B4Q
onk^kP0?ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo0ol000000ooooooo0000o`00
0009o`0000;ooooo00?o0000ooooool000002Oooool2o`000004ooooool0003o0000ooooo`;o0000
3Oooool2o`0000Cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool2o`0004_ooooo000<ooooo`03ogMgMomV
IVKooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo
0ol000000ooooooo0000o`000009o`0000;ooooo00?o0000ooooool000002Oooool2o`000004oooo
ool0003o0000ooooo`;o00003Oooool2o`0000Cooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooo`00001:ooooo`003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41003Oooool3o`000003ooooool0003o000000Wo00000_ooool00ol0003oooooo`000009ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o00001?ooool00ol0003oooooooooo`0Ioooo
o`;o0000@oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooo`00001:ooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@
00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03Oooool3o`000003ooooool0003o000000Wo00000_ooool01Ol0003oooooo`000?oo
oooo000000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l00003ooooo`;o0000
6oooool2o`0004?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00cooooo00Co0000oooooooooooo00009oooool3o`00023ooooo0009ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo0_l00003ooooo`?o000000?oooooo`000?l000002Ol00002oooo
o`05o`000?oooooo0000ooooool000001oooool2o`000004ooooool0003o0000ooooo`;o00003Ooo
ool2o`0000?ooooo0_l0000Kooooo`;o0000@oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000002Kooooo
00?o0000ooooool000008?ooool003gooooo00Co0000oooooooooooo00000_ooool3o`000003oooo
ool0003o000000[o000000?oooooo`000?ooool00ol00007ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000=ooooo`;o00000oooool2o`0001_ooooo0_l00013ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooooooo
ool000009_ooool01?l0003oooooooooool0000Oooooo`00>?ooool4o`000005ooooool0003ooooo
ooooool000000_ooool3o`000003ooooool0003o000000[o000000?oooooo`000?ooool01?l00006
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o00000oooool2o`0001_ooooo0_l0
0013ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool01?l0003ooooooooo
ool0000Oooooo`00?Oooool3o`0000?ooooo0ol000000ooooooo0000o`00000:o`000003ooooool0
003ooooo00Co00000oooool00ol0003oooooooooo`02o`000004ooooool0003o0000ooooo`;o0000
3Oooool2o`0000?ooooo0_l0000Kooooo`;o0000@oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`00?_oo
ool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?l000002_l000000ooooooo0000oooo
o`04o`0000?ooooo00?o0000ooooooooool00_l000001?oooooo0000o`000?ooool2o`0000gooooo
0_l00003ooooo`;o00006oooool2o`0004?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool003oooooo00Co
0000oooooooooooooooo0ol000000ooooooo0000o`00000:o`000003ooooool0003ooooo00Co0000
0oooool00ol0003oooooooooo`02o`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000?o
oooo0_l0000Kooooo`;o0000@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo0_l0000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool004?ooooo
0ol000000ooooooo0000o`00000:o`000003ooooool0003ooooo00Co000000Coooooo`000?oooooo
00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003oooooooooo`08oooo
o`;o00000oooool2o`0001_ooooo0_l00013ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06oooool004?ooooo0ol000000ooooooo0000o`00000:o`000003ooooool0003ooooo00Co
000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000o`00
0002ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o00006oooool2o`0004?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`00017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`00@oooool3o`000003ooooool0
003o000000[o000000?oooooo`000?ooool01_l000001ooooooo0000ooooool0003oooooo`000?oo
ool00_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o
00000oooool2o`0001Kooooo0_l00013ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03?ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06_ooool004?ooooo0ol000000ooooooo0000o`00000:o`000003ooooool0003ooooo00Ko
000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000?oooooo`000?l000000_ooool0
0ol0003oooooooooo`08ooooo`;o00000oooool2o`0000?ooooo0_l0000Eooooo`03o`000?oooooo
000004?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`05o`000?oooooo
ooooooooool000003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0013
ooooo`?o000000?oooooo`000?l000002_l000000ooooooo0000ooooo`06o`000007ooooool0003o
ooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo
00001oooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Eooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool04Oooool2o`000003oa0@4?oooooooooo02?ooooo00?o0000oooooooo
ool01oooool02_l0003oooooooooooooooook^k^oc8b<_l0003o410@olc<c?l0000:ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo00Wo0000ooooooooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo0013ooooo`?o000000?oooooo`000?l000002_l000000ooooooo0000ooooo`08o`000005oooo
ool0003oooooo`000?ooool00_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`06oiRHV?l0003o0000oooooom4A4Cooooo
0_l0000Eooooo`03o`000?oooooo000000Kooooo0_l0000Dooooo`03o`000?oooooooooo01;ooooo
1?l0000=ooooo`03o`000?oooooooooo00Sooooo00[o0000oooooooooooooooooeEEEOmgMgOooooo
oiRHV?lQ8B7o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`08o`000?ooooooooooob4Q8OnHV9So
oooooiRHV?lQ8B45ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo0013ooooo`?o000000?oooooo`000?l000002_l000000ooo
oooo0000ooooo`08o`000005ooooool0003oooooo`000?ooool00_l000000ooooooo0000o`000002
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`;o0000
00?ok^k^ooooooooool00_l0000Eooooo`03o`000?oooooo000000Kooooo0_l0000Aooooo`Go0000
4_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`05o`00
0?ooooooooooooooool000000oooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool004?ooooo0ol000000ooo
oooo0000o`00000:o`000003ooooool0003ooooo00So000000Goooooo`000?oooooo0000ooooo`02
o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000?ooooo0_l0
0003ooooo`;o000000?o8B4Qonk^k_ooool00_l0000Eooooo`03o`000?oooooo000000Kooooo0_l0
000Aooooo`04odA4A?oMgMgoooooo`0001?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Sooooo00[o0000ooooooooooooooooo`000?nHV9Sooooo
oiRHV?lQ8B7o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`08o`000?oooooooooooc8b<_nHV9So
oooooiRHV?lb<S85ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo0013ooooo`?o000000?oooooo`000?l000002_l000000ooo
oooo0000ooooo`08o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`;o00000oooool2o`000003ogMgMomV
IVKooooo00;o00000oooool2o`00013ooooo00?o0000ooooool000001_ooool2o`00017ooooo00Co
gMgMoeEEEOoooooo00004oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool02_l0003ooooooooooooooooo0000oeEEEOl0003o410@olc<c?l0
000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooooooooooc<c<0ol000000oo<c<cooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo0013ooooo`?o000000?oooooo`000?l000002_l000000ooooooo0000
ooooo`08o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`00
00;ooooo00?o0000ooooooooool00_l00003ooooo`;o00000oooool2o`000003ooooool0003ooooo
00;o00000oooool2o`00013ooooo00?o0000ooooool000001_ooool2o`0001;ooooo00?oMgMgolc<
c?l000004_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool01_l0003oooooooooooooooooEEEEohN7Q`?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`08o`000?oooooooooooa0@4?nj^[[ooooookZj^_l@4104oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo0013ooooo`?o000000?oooooo`000?l000002_l000000ooooooo0000ooooo`08o`00
0005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`0000;ooooo00?o
0000ooooooooool00_l00003ooooo`;o00000_ooool3o`000003oiRHV?l@413ooooo00;o00000ooo
ool2o`00013ooooo00?o0000ooooool000001_ooool00ol0003oooooo`00000Aooooo`03onk^k_m4
A4Co0000017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00Oo0000ooooooooooooooooomgMgOl@413oV9RH00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`07o`000?oooooo0000okZj^_oooooo^[Zjo`000004
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo0013ooooo`?o000000?oooooo`000?l000002_l000000ooooooo0000ooooo`08
o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`0000;ooooo
00?o0000ooooooooool00_l00003ooooo`;o00000_ooool01_nHV9So0000o`000?lQ8B7oc<c<oooo
o`;o00000oooool2o`00013ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006
ooooo`03o`000?oooooooooo00Wooooo00?oMgMgo`000?ooool04?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool02Ol0003ooooooooooooo
ooooc<c<odA4A?l0003o410@o`00000;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Ko0000ojVYZOl@
413o0000oa0@4?nYZJT4ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0013ooooo`?o000000?oooooo`000?l000002_l00000
0ooooooo0000ooooo`08o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`;o00000oooool2o`0000?ooooo
0_l00003ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooo000000Kooooo0_l0000Looooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05oooool004?ooooo0ol000000ooooooo0000o`00000:o`000003oooo
ool0003ooooo00So000000Goooooo`000?oooooo0000ooooo`02o`000004ooooool0003o0000oooo
o`;o00000_ooool00ol0003oooooooooo`02o`0000?ooooo0_l00003ooooo`;o00000oooool2o`00
00?ooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Fooooo`00@oooool3o`000003ooooool0003o000000[o000000?oooooo`00
0?ooool02?l000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000ooo
ool2o`0000?ooooo0_l00003ooooo`;o00001_ooool01?l0003oooooooooool00004ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool2o`0001?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Fooooo`00@oooool3o`000003ooooool0003o000000[o0000
00?oooooo`000?ooool02?l000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?l0
003ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000oooool2o`0000;ooooo00?o0000
ooooool000000oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo00Go0000
ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool00000
1Oooool3o`0001?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`00??oo
ooooo`0002co00000Oooool004?ooooo0ol000000ooooooo0000o`00000:o`000003ooooool0003o
000000So000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`02o`000008ooooool0003o
0000ooooool0003oooooo`000?ooool2o`0000?ooooo0_l00002ooooo`04o`000?oooooo0000o`00
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00;o00001?ooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo0_l00004ooooo`;o00001?ooool3o`0000gooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`00000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l0000;ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00003?ooool2o`0000Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`06ooooo`00@oooool3o`000003ooooool0003o000000[o000000?oooooo`000?l000002?l0
00000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Koooooo`000?l0003ooooo
o`000?ooool2o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`08o`000?oooooo0000o`00
0?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_oo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Gooooo0ol0000N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool2o`0000Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00008ooooo`00@oooool3
o`000003ooooool0003o000000[o000000?oooooo`000?l000002?l000000ooooooo0000ooooo`02
o`000003ooooool0003ooooo00;o000000Koooooo`000?l0003oooooo`000?ooool2o`000003oooo
ool0003ooooo00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000
0_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00002_oo
ool004?ooooo0ol000000ooooooo0000o`00000:o`000003ooooool0003o000000So000000?ooooo
o`000?ooool00_l000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo
0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02o`0000?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000009oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo0013ooooo`?o000000?oooooo`000?l0
00002?l000000ooooooo0000ooooo`0:o`000003ooooool0003ooooo00;o000000?oooooo`000?oo
ool00_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00_ooool2
o`0000;ooooo00?o0000ooooool000000_ooool02_l0003oooooooooool0003oooooo`000?oooooo
0000ooooool00003ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`00000Xooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`05
o`000?ooooooooooooooool000004Oooool004?ooooo0ol000000ooooooo0000o`000008o`000003
ooooool0003ooooo00;o000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`02o`000003
ooooool0003ooooo00;o000000Koooooo`000?l0003oooooo`000?ooool2o`000003ooooool0003o
oooo00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`?o0000:?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00
000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooo
oooooooo0000017ooooo0013ooooo`?o000000?oooooo`000?l000001?l000001ooooooo0000o`00
0?l0003oooooo`000?ooool00_l000000ooooooo0000o`000005o`000003ooooool0003ooooo00;o
000000?oooooo`000?ooool00_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000?ooooo
o`000?ooool00_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0000Dooooo`03o`00
0?oooooo000001;ooooo0013ooooo`?o000000?oooooo`000?l000001?l000001ooooooo0000o`00
0?l0003oooooo`000?ooool00_l000000ooooooo0000o`000005o`000003ooooool0003ooooo00;o
000000?oooooo`000?ooool00_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000?ooooo
o`000?ooool00_ooool2o`0000;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`00
0?oooooo000000;ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000<?ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo
000000oooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo000001Cooooo00?o
0000ooooool000004_ooool004?ooooo0ol000000ooooooo0000o`000004o`000007ooooool0003o
0000o`000?oooooo0000ooooo`02o`000003ooooool0003o000000Go000000?oooooo`000?ooool0
0_l000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo0_l000000ooo
oooo0000ooooo`02ooooo`;o00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo0_l0
0003ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000033ooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000@oooo
o`04o`000?ooooooooooo`00017ooooo0_l0000Eooooo`03o`000?oooooo000001;ooooo0013oooo
o`?o000000?oooooo`000?l000001?l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l0
00000ooooooo0000o`000005o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_l0
00001_oooooo0000o`000?oooooo0000ooooo`;o000000Ooooooo`000?ooooooooooo`000?oooooo
000000;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o00000oooool2o`0000Sooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`00000aooooo`04o`000?ooooooooooo`0000oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooool00000:_ooool0
0ol0003oooooooooo`0Aooooo`00@oooool3o`000003ooooool0003o000000Co000000Ooooooo`00
0?l0003o0000ooooool0003ooooo00;o000000?oooooo`000?l000001Ol000000ooooooo0000oooo
o`02o`000003ooooool0003ooooo00;o000000Koooooo`000?l0003oooooo`000?ooool2o`000007
ooooool0003oooooooooool0003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool2o`0000?ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000<Oooool01?l0003o
ooooooooool0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000@
ooooo`?o0000?_ooool004?ooooo0ol000000ooooooo0000o`000004o`000007ooooool0003o0000
o`000?oooooo0000ooooo`02o`000003ooooool0003o000000Go000000?oooooo`000?ooool00_l0
00000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo0_l000001ooooooo
0000oooooooooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`0000?ooooo0_l00003
ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooo`00000aooooo`04o`000?oooooo0000o`0000oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool01Ol0
003ooooooooooooooooo0000057ooooo0013ooooo`?o000000?oooooo`000?l000001?l000001ooo
oooo0000o`000?l0003oooooo`000?ooool00_l000000ooooooo0000o`000005o`000003ooooool0
003ooooo00;o000000?oooooo`000?ooool00_l000001_oooooo0000o`000?oooooo0000ooooo`;o
000000Ooooooo`000?ooooooooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00003
ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`00000booooo`;o00004?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000@ooooo`04
o`000?ooooooooooo`00057ooooo0013ooooo`?o000000?oooooo`000?l000001?l000001ooooooo
0000o`000?l0003oooooo`000?ooool00_l000000ooooooo0000o`000005o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool00_l000001_oooooo0000o`000?oooooo0000ooooo`;o0000
00Ooooooo`000?ooooooooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00003oooo
o`;o00003_ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooool00000<_ooool2o`00013ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0001Aooooo`00
@oooool3o`000003ooooool0003o000000Co000000Ooooooo`000?l0003o0000ooooool0003ooooo
00;o000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`02o`000003ooooool0003ooooo
00;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooool000000_ooool2o`0000?ooooo0_l0000>ooooo`04o`000?oooooooooo
o`0000Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000014ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo0000013ooooo
00?o0000ooooool00000D_ooool004?ooooo0ol000000ooooooo0000o`000004o`000007ooooool0
003o0000o`000?oooooo0000ooooo`02o`000003ooooool0003o000000Go000000?oooooo`000?oo
ool00_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000?oooooo`000?oo
ool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo0_l00003ooooo`;o
00003_ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000Gooooo0_l00016
ooooo`04o`000?ooooooooooo`00013ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`00
0?oooooo000005;ooooo0013ooooo`?o000000?oooooo`000?l000001?l000001ooooooo0000o`00
0?l0003oooooo`000?ooool00_l000000ooooooo0000o`000005o`000003ooooool0003ooooo00;o
000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`;o00000oooool2o`0000ko
oooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo04Cooooo00Co0000oooooooooooo00004?ooool01Ol0003ooooooooooooooooo0000017ooooo
0_l0001Booooo`00@oooool3o`000003ooooool0003o000000Co000000Ooooooo`000?l0003o0000
ooooool0003ooooo00;o000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`02o`000003
ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool2o`0000?ooooo0_l0000>ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo0000COooool01?l0003oooooooooool0
000@ooooo`05o`000?ooooooooooooooool00000IOooool004?ooooo0ol000000ooooooo0000o`00
0004o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`000003ooooool0003o000000Go
000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o
00001Oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo0_l00003ooooo`;o
00003_ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0004gooooo00Co0000
oooooooooooo00004Oooool00ol0003oooooo`00001Vooooo`007oooool2onk^kP?ooooo0_o^k^hM
ooooo`?o000000?oooooo`000?l000001?l000001ooooooo0000o`000?l0003oooooo`000?ooool0
0_l000000ooooooo0000o`000005o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool0
0_l000000ooooooo0000ooooo`02o`0000Gooooo00?o0000ooooool000000_ooool00ol0003ooooo
o`000002ooooo`;o00000oooool2o`0000kooooo00?o0000ooooool000001Oooool01?l0003ooooo
ooooool0001=ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooool00000I_ooool000So
oooo1Ol00005ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h>ooooo`?o000000?oooooo`000?l000001?l000001ooooooo0000o`000?l0003oooooo`000?oo
ool00_l000000ooooooo0000o`000005o`000003ooooool0003ooooo00;o000000?oooooo`000?oo
ool00_l000001?oooooo0000ooooool00006ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ool000000_ooool2o`0000?ooooo0_l0000>ooooo`03o`000?oooooo000000Gooooo00Co0000oooo
oooooooo0000COooool01?l0003oooooooooool0000Aooooo`03o`000?oooooo000006Kooooo0008
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00WoMgMgoc8b<_oooooooooo
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool3o`000003ooooool0003o000000Co000000Ooooooo`000?l0003o0000oooo
ool0003ooooo00;o000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`02o`000003oooo
ool0003ooooo00;o000000Coooooo`000?oooooo00001_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000000;ooooo0_l00003ooooo`;o00003_ooool00ol0003oooooo`000005ooooo`04
o`000?ooooooooooo`0004kooooo00?o0000ooooool000004Oooool00ol0003oooooo`00001Voooo
o`002Oooool00onHV9So8B4Qonk^kP0Aooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`?o000000?o
ooooo`000?l000001?l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l000000ooooooo
0000o`000004o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool00ol00002oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002oooo
o`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000Gooooo00Co0000oooo
oooooooo0000C_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooo000006Kooooo000:oooo
o`03oiRHV?lQ8B7ok^k^00oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool3o`000003
ooooool0003o000000Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000?ooooo
o`000?l000001?l000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00?o00000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_oo
ool2o`0001?ooooo00?o0000ooooool000001Oooool01?l0003oooooooooool0001>ooooo`03o`00
0?oooooo0000017ooooo00?o0000ooooool00000I_ooool000_ooooo00?oMgMgofIVI_ooool02ooo
ool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool3o`000003oooo
ool0003o000000Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000?oooooo`00
0?l000001?l000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00?o00000_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool2
o`0001?ooooo00?o0000ooooool000001_ooool2o`0004oooooo00?o0000ooooool000004_ooool0
0ol0003oooooooooo`1Uooooo`003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool3o`000003ooooool0003o000000Co000000Ooooooo`000?l0003o0000oooo
ool0003ooooo00;o000000Koooooo`000?l0003o0000ooooool00002ooooo`;o000000Koooooo`00
0?l0003oooooo`000?ooool3o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooo000000;ooooo0_l0000Cooooo`03o`000?oooooo000000Kooooo0_l0
001?ooooo`03o`000?oooooo000007[ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`;o00001?ooool3o`000003ooooool0003o000000Co000000Ooooooo`000?l0003o
0000ooooool0003ooooo00;o000000Koooooo`000?l0003o0000ooooool00002ooooo`;o000000Wo
ooooo`000?l0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool2o`0001?ooooo00?o0000oooo
ool000001_ooool2o`0004oooooo00?o0000ooooool00000N_ooool000Sooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01oooool01?l0003oooooooooool00003ooooo`?o000000?oooooo`000?l000001?l0
00001ooooooo0000o`000?l0003oooooo`000?ooool00_l000001_oooooo0000o`000?l0003ooooo
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo0_l0000Dooooo`;o0000
1_ooool2o`0004oooooo0_l0001kooooo`00=oooool4o`000005ooooool0003oooooooooool00000
0oooool3o`000003ooooool0003o000000Co000000Ooooooo`000?l0003o0000ooooool0003ooooo
00;o000000Koooooo`000?l0003o0000ooooool00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000000_ooool00ol0003o
ooooo`000002ooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`;o0000D?ooool00ol0003o
ooooooooo`1iooooo`00??ooool3o`0000Cooooo0ol000000ooooooo0000o`000004o`000007oooo
ool0003o0000o`000?oooooo0000ooooo`02o`000006ooooool0003oooooo`000?oooooo00000_oo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool2o`0001cooooo0_l0003<ooooo`00
?Oooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?l000001?l000001ooooooo0000
o`000?l0003oooooo`000?ooool00_l000001_oooooo0000ooooool0003oooooo`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
o`000002ooooo`03o`000?oooooo000000;ooooo0_l0000Looooo`;o0000c?ooool003kooooo00?o
0000ooooooooool00_ooool3o`000003ooooool0003o000000Co000000Ooooooo`000?l0003o0000
ooooool0003ooooo00;o000000Koooooo`000?oooooo0000ooooool00002ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000_oo
ool00ol0003oooooo`000002ooooo`;o00007?ooool2o`000<cooooo0013ooooo`?o000000?ooooo
o`000?l000001?l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l000001_oooooo0000
ooooool0003oooooo`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00?o0000
ooooooooool01oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo0_l0000L
ooooo`;o0000c?ooool004?ooooo0ol000000ooooooo0000o`000004o`000007ooooool0003o0000
o`000?oooooo0000ooooo`02o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`000004
ooooool0003o0000ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo0000
00;ooooo0_l00003ooooo`;o00007?ooool2o`000<cooooo0013ooooo`?o000000?oooooo`000?l0
00001?l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l000001?oooooo0000ooooool0
0004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000000_ooool2o`0000?ooooo0_l0000Looooo`;o0000c?ooool004?ooooo0ol0
00000ooooooo0000o`000004o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`000004
ooooool0003oooooo`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00?o0000
ooooooooool01oooool00ol0003oooooo`000002ooooo`;o00000oooool2o`0001cooooo00?o0000
ooooooooool0boooool004?ooooo0ol000000ooooooo0000o`000004o`000007ooooool0003o0000
o`000?oooooo0000ooooo`02o`000004ooooool0003oooooo`0000Cooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooo`000002ooooo`;o
00000oooool2o`0001cooooo00?o0000ooooooooool0boooool004?ooooo0ol000000ooooooo0000
o`000004o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`000004ooooool0003ooooo
o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00?o0000ooooooooool01ooo
ool2o`0000?ooooo0_l00003ooooo`;o0000j_ooool004?ooooo0ol000000ooooooo0000o`000004
o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`000004ooooool0003oooooo`0000Co
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00?o0000ooooooooool01oooool2o`00
00?ooooo0_l00003ooooo`03o`000?oooooooooo0>Wooooo0013ooooo`?o000000?oooooo`000?l0
00001?l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l000001?oooooo0000ooooool0
0004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo
0_l00003ooooo`;o00000oooool00ol0003oooooooooo`3Yooooo`00@oooool3o`000003ooooool0
003o000000Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000Coooooo`000?oo
oooo00001?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003oooooooooo`07
ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0jOooool004?ooooo0ol000000ooo
oooo0000o`000004o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`000004ooooool0
003oooooo`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00?o0000oooooooo
ool01oooool2o`0000?ooooo0_l0003_ooooo`00@oooool3o`000003ooooool0003o000000Co0000
00Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000Coooooo`000?oooooo00001?ooool2
o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`;o00000ooo
ool2o`000>oooooo000Nooooo`;ok^k^0oooool2onk^kQkooooo0ol000000ooooooo0000o`000004
o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`000004ooooool0003oooooo`0000Co
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00?o0000ooooooooool01oooool2o`00
00?ooooo0_l0003_ooooo`006?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h?ooooo`?o000000?oooooo`000?l000001?l000001ooooooo0000o`000?l0003oooooo`000?oo
ool00_l000001?oooooo0000ooooool00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o0000koooool001_ooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03oooool3o`000003ooooool0003o000000Co000000Ooooooo`000?l0
003o0000ooooool0003ooooo00;o000000Coooooo`000?oooooo00001?ooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`;o00000oooool2o`000>oooooo
000Looooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400?ooooo`?o000000?oooooo`000?l000001?l000001ooo
oooo0000o`000?l0003oooooo`000?ooool00_l000000ooooooo0000ooooo`05ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o0000
koooool001_ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool3o`000003ooooool0003o
000000Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000?oooooo`000?ooool0
1Oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000?ooooo0_l0003_ooooo`00
6?ooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool3o`000003
ooooool0003o000000Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000?ooooo
o`000?ooool01Oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000?ooooo0_l0
003_ooooo`006?ooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00oooooo0ol000000ooooooo0000o`00
0004o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00Go
oooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l00003ooooo`;o0000koooool001So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03oooool3o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`02
o`000004ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo
0_l00003ooooo`;o0000koooool001Sooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00001Oooool3o`000003ooooool0003o000000Co0000
00Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003oooooo`0000Kooooo0_l000001?oo
oooo0000o`000?ooool2o`0000cooooo0_l00003ooooo`;o0000koooool003_ooooo00Co0000oooo
oooooooo00001?ooool3o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000oooo
o`02o`000004ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000co
oooo0_l00003ooooo`;o0000koooool003Kooooo1?l000001Ooooooo0000oooooooooooo000000Co
oooo0ol000000ooooooo0000o`000004o`000005ooooool0003o0000o`000?ooool00_l000001?oo
oooo0000ooooool00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00000ooo
ool2o`000>oooooo000kooooo`?o00001Oooool3o`000003ooooool0003o000000Co000000Gooooo
o`000?l0003o0000ooooo`02o`000004ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000
o`000?ooool2o`0000cooooo0_l00003ooooo`;o0000koooool003cooooo00?o0000ooooooooool0
1?ooool3o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`02o`000004
ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l00003
ooooo`;o0000koooool003gooooo00?o0000ooooooooool00oooool3o`000003ooooool0003o0000
00Co000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003oooooo`0000Kooooo0_l0
00001?oooooo0000o`000?ooool2o`0000cooooo0_l00003ooooo`;o0000koooool004?ooooo0ol0
00000ooooooo0000o`000004o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000
ooooool00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00000oooool2o`00
0>oooooo0013ooooo`?o000000?oooooo`000?l000001?l000001Ooooooo0000o`000?l0003ooooo
00;o000000Coooooo`000?oooooo00001_ooool2o`000004ooooool0003o0000ooooo`;o00003?oo
ool2o`0000?ooooo0_l0003_ooooo`00@oooool3o`000003ooooool0003o000000Co000000Gooooo
o`000?l0003o0000ooooo`02o`000004ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000
o`000?ooool2o`0000gooooo00Co0000oooooooooooooooo0_l0003_ooooo`00@oooool3o`000003
ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003ooooo
o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l0003_ooooo`00@oooool3
o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0
003oooooo`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l0003_ooooo`00
@oooool3o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`02o`000004
ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l0003_
ooooo`00@oooool3o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`02
o`000004ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo
0_l0003_ooooo`00@oooool3o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000
ooooo`02o`000004ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00
017ooooo0_l0003_ooooo`00@oooool3o`000003ooooool0003o000000Co000000Goooooo`000?l0
003o0000ooooo`02o`000004ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000o`000?oo
ool2o`00017ooooo0_l0003_ooooo`00@oooool3o`000003ooooool0003o000000Co000000Gooooo
o`000?l0003o0000ooooo`02o`000004ooooool0003oooooo`0000Kooooo0_l000001?oooooo0000
o`000?ooool2o`00017ooooo0_l0003_ooooo`00@oooool3o`000003ooooool0003o000000Co0000
00Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003oooooo`0000Kooooo0_l000001?oo
oooo0000o`000?ooool2o`00017ooooo0_l0003_ooooo`007oooool2onk^kP?ooooo0_o^k^hMoooo
o`?o000000?oooooo`000?l000001?l000001Ooooooo0000o`000?l0003ooooo00;o000000Cooooo
o`000?oooooo00001_ooool2o`000004ooooool0003o0000ooooo`;o00004Oooool2o`000>oooooo
000:ooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kPkooooo0ol000000ooooooo0000o`000004o`0000;ooooo0_l000001ooo
oooo0000o`000?oooooo0000ooooool000001_ooool2o`000003ooooool0003o000000;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`3]ooooo`002_ooool00omEEEGoZJVYooooo`05
ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`?o000000?oooooo`00
0?l000001?l00002ooooo`;o000000Ooooooo`000?l0003oooooo`000?oooooo000000Kooooo0_l0
00000ooooooo0000o`000002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0kOoo
ool000[ooooo00?oZJVYoeEEEOooool04?ooool01ol0003ooooooooooooooooogMgMo`000?oMgMd0
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool3o`000003
ooooool0003o000000Co00000_ooool2o`000007ooooool0003o0000ooooool0003oooooo`000006
ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo0>gooooo000;ooooo`03ob4Q8Ooooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00003_ooool3o`000003ooooool0003o000000Co00000_ooool2o`000007ooooool0003o0000oooo
ool0003oooooo`000006ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`3o
ooooo`7ooooo000;ooooo`03oeEEEOo<c<cooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?oo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000kooooo0ol000000ooooooo0000o`000004o`0000;ooooo0_l00000
1ooooooo0000o`000?oooooo0000ooooool000001_ooool2o`000003ooooool0003o000000;ooooo
00?o0000ooooooooool0ooooool1ooooo`002oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool3o`000003ooooool0003o000000Co00000_ooool2o`000007oooo
ool0003o0000ooooool0003oooooo`000006ooooo`;o000000?oooooo`000?l000000_ooool00ol0
003oooooooooo`3oooooo`7ooooo0008ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`?o000000?oooooo`000?l000001?l00002ooooo`;o000000Ooooooo`000?l0003oooooo`00
0?oooooo000000Kooooo0_l000000ooooooo0000o`00003oooooo`Kooooo0008ooooo`Go00003?oo
ool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
0_l00004ooooo`?o000000?oooooo`000?l000001?l00002ooooo`;o000000Ooooooo`000?l0003o
ooooo`000?oooooo000000Kooooo0_l000000ooooooo0000o`00003oooooo`Kooooo000looooo`04
o`000?ooooooooooo`0000?ooooo0ol000000ooooooo0000o`000004o`0000;ooooo0_l000001ooo
oooo0000o`000?oooooo0000ooooool000001_ooool2o`000003ooooool0003o00000?oooooo1_oo
ool003Oooooo1?l000001Ooooooo0000oooooooooooo000000?ooooo0ol000000ooooooo0000o`00
0004o`0000;ooooo0_l000001ooooooo0000o`000?oooooo0000ooooool000001_ooool2o`000003
ooooool0003o00000?oooooo1_ooool003cooooo0ol00004ooooo`?o000000?oooooo`000?l00000
1?l00002ooooo`;o000000Goooooo`000?l0003oooooo`000008ooooo`;o000000?oooooo`000?l0
0000ooooool6ooooo`00?Oooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?l00000
1?l00002ooooo`;o000000Goooooo`000?l0003oooooo`000008ooooo`;o000000?oooooo`000?l0
0000ooooool6ooooo`00?_ooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?l00000
1?l00002ooooo`;o000000Goooooo`000?l0003oooooo`000008ooooo`;o000000?oooooo`000?l0
0000ooooool6ooooo`00@oooool3o`000003ooooool0003o000000Co00000_ooool2o`000005oooo
ool0003o0000ooooool000002?ooool00ol0003oooooooooo`02o`000?oooooo1_ooool004?ooooo
0ol000000ooooooo0000o`000004o`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000000So
oooo00?o0000ooooooooool00_l0003oooooo`Kooooo0013ooooo`?o000000?oooooo`000?l00000
1?l00002ooooo`;o000000Goooooo`000?l0003oooooo`000008ooooo`03o`000?oooooooooo00;o
0000ooooool6ooooo`00@oooool3o`000003ooooool0003o000000Co00000_ooool2o`000005oooo
ool0003o0000ooooool000002?ooool00ol0003oooooooooo`02o`000?oooooo1_ooool004?ooooo
0ol000000ooooooo0000o`000004o`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000000So
oooo00?o0000ooooooooool00_l0003oooooo`Kooooo0013ooooo`?o000000?oooooo`000?l00000
1?l00002ooooo`;o000000Goooooo`000?l0003oooooo`000008ooooo`03o`000?oooooooooo00;o
0000ooooool6ooooo`00@oooool3o`000003ooooool0003o000000Co00000_ooool2o`000005oooo
ool0003o0000ooooool000002?ooool00ol0003oooooooooo`02o`000?oooooo1_ooool004?ooooo
0ol000000ooooooo0000o`000004o`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000000So
oooo00?o0000ooooooooool00_l0003oooooo`Kooooo0013ooooo`?o000000?oooooo`000?l00000
1?l00002ooooo`;o000000Goooooo`000?l0003oooooo`000008ooooo`03o`000?oooooooooo00;o
0000ooooool6ooooo`00@oooool3o`000003ooooool0003o000000Co00000_ooool2o`000005oooo
ool0003o0000ooooool000002?ooool00ol0003oooooooooo`02o`000?oooooo1_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2.37586, -1.12665*^-5, \
0.044011, 1.26668*^-7}}]
}, Open  ]],

Cell["\<\
The plot shows that the error in the solution is small, but \
nonzero. \
\>", "Text"],

Cell[TextData[{
  "\tIn order to further investigate the accuracy of ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",  we will solve a problem with an analytic solution: the harmonic \
oscillator with frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\ \  = \ 1\)]],
  ", and with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = \ 1, \ \(x\^\[Prime]\)(0)\  = \ 0\)]],
  ". The exact solution is ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\  = \ cos\ t\)]],
  ".  ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " provides a numerical solution that can be compared with the exact \
solution, as shown in Cell ",
  ButtonBox["1.20",
    ButtonData:>"Cell 1.20",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[x];\)\), "\n", 
    \(NDSolve[{\(x''\)[t]\  \[Equal] \ \(-x[t]\), 
        x[0] \[Equal] 1, \(x'\)[0] \[Equal] 0}, x[t], {t, 0, 30}]\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 1.18"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(x[t]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0.`, 30.`}}, "<>"]\),
              False,
              Editable->False], "[", "t", "]"}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[t] /. %[\([1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.19"],

Cell[BoxData[
    RowBox[{
      TagBox[\(InterpolatingFunction[{{0.`, 30.`}}, "<>"]\),
        False,
        Editable->False], "[", "t", "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[%\  - \ Cos[t], {t, 0, 30}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.20"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.293279 7709.21 [
[.18254 .28078 -3 -9 ]
[.18254 .28078 3 0 ]
[.34127 .28078 -6 -9 ]
[.34127 .28078 6 0 ]
[.5 .28078 -6 -9 ]
[.5 .28078 6 0 ]
[.65873 .28078 -6 -9 ]
[.65873 .28078 6 0 ]
[.81746 .28078 -6 -9 ]
[.81746 .28078 6 0 ]
[.97619 .28078 -6 -9 ]
[.97619 .28078 6 0 ]
[.01131 .1391 -48 -4.5 ]
[.01131 .1391 0 4.5 ]
[.01131 .44746 -42 -4.5 ]
[.01131 .44746 0 4.5 ]
[.01131 .60165 -42 -4.5 ]
[.01131 .60165 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .29328 m
.18254 .29953 L
s
[(5)] .18254 .28078 0 1 Mshowa
.34127 .29328 m
.34127 .29953 L
s
[(10)] .34127 .28078 0 1 Mshowa
.5 .29328 m
.5 .29953 L
s
[(15)] .5 .28078 0 1 Mshowa
.65873 .29328 m
.65873 .29953 L
s
[(20)] .65873 .28078 0 1 Mshowa
.81746 .29328 m
.81746 .29953 L
s
[(25)] .81746 .28078 0 1 Mshowa
.97619 .29328 m
.97619 .29953 L
s
[(30)] .97619 .28078 0 1 Mshowa
.125 Mabswid
.05556 .29328 m
.05556 .29703 L
s
.0873 .29328 m
.0873 .29703 L
s
.11905 .29328 m
.11905 .29703 L
s
.15079 .29328 m
.15079 .29703 L
s
.21429 .29328 m
.21429 .29703 L
s
.24603 .29328 m
.24603 .29703 L
s
.27778 .29328 m
.27778 .29703 L
s
.30952 .29328 m
.30952 .29703 L
s
.37302 .29328 m
.37302 .29703 L
s
.40476 .29328 m
.40476 .29703 L
s
.43651 .29328 m
.43651 .29703 L
s
.46825 .29328 m
.46825 .29703 L
s
.53175 .29328 m
.53175 .29703 L
s
.56349 .29328 m
.56349 .29703 L
s
.59524 .29328 m
.59524 .29703 L
s
.62698 .29328 m
.62698 .29703 L
s
.69048 .29328 m
.69048 .29703 L
s
.72222 .29328 m
.72222 .29703 L
s
.75397 .29328 m
.75397 .29703 L
s
.78571 .29328 m
.78571 .29703 L
s
.84921 .29328 m
.84921 .29703 L
s
.88095 .29328 m
.88095 .29703 L
s
.9127 .29328 m
.9127 .29703 L
s
.94444 .29328 m
.94444 .29703 L
s
.25 Mabswid
0 .29328 m
1 .29328 L
s
.02381 .1391 m
.03006 .1391 L
s
[(-0.00002)] .01131 .1391 1 0 Mshowa
.02381 .44746 m
.03006 .44746 L
s
[(0.00002)] .01131 .44746 1 0 Mshowa
.02381 .60165 m
.03006 .60165 L
s
[(0.00004)] .01131 .60165 1 0 Mshowa
.125 Mabswid
.02381 .17764 m
.02756 .17764 L
s
.02381 .21619 m
.02756 .21619 L
s
.02381 .25473 m
.02756 .25473 L
s
.02381 .33183 m
.02756 .33183 L
s
.02381 .37037 m
.02756 .37037 L
s
.02381 .40892 m
.02756 .40892 L
s
.02381 .48601 m
.02756 .48601 L
s
.02381 .52456 m
.02756 .52456 L
s
.02381 .5631 m
.02756 .5631 L
s
.02381 .10055 m
.02756 .10055 L
s
.02381 .062 m
.02756 .062 L
s
.02381 .02346 m
.02756 .02346 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .29328 m
.04262 .28444 L
.04376 .28422 L
.04498 .28337 L
.04561 .28315 L
.04631 .28302 L
.04754 .28257 L
.0487 .27947 L
.04995 .27605 L
.05112 .27546 L
.0522 .27513 L
.05351 .27529 L
.05426 .27588 L
.05495 .27628 L
.05621 .27643 L
.05692 .27649 L
.05756 .27653 L
.05877 .27633 L
.06008 .27604 L
.06131 .27628 L
.06244 .27661 L
.06751 .27739 L
.06874 .27787 L
.07006 .27784 L
.07081 .27805 L
.0715 .27845 L
.07286 .27935 L
.07789 .28256 L
.08255 .28664 L
.08518 .2896 L
.08797 .29386 L
.09386 .30381 L
.10458 .32692 L
.11417 .34699 L
.12427 .36987 L
.1253 .3708 L
.12642 .37336 L
.1274 .37706 L
.12844 .37919 L
.12966 .37989 L
.13078 .38035 L
.13179 .38138 L
.1329 .38431 L
.13411 .38616 L
.13542 .38622 L
.13666 .38613 L
.13778 .3873 L
.1389 .38974 L
.14012 .39012 L
.14127 .38944 L
Mistroke
.14233 .38877 L
.14355 .38941 L
.14486 .39092 L
.14611 .38996 L
.14725 .38855 L
.14828 .3874 L
.14941 .38766 L
.1506 .38789 L
.1517 .38627 L
.15289 .38407 L
.15416 .382 L
.15482 .38163 L
.15555 .3815 L
.15683 .37966 L
.16168 .37011 L
.16695 .35612 L
.17175 .34034 L
.18253 .29815 L
.20355 .20028 L
.21274 .15918 L
.21526 .15157 L
.21795 .1411 L
.21926 .13684 L
.22049 .13412 L
.22158 .13191 L
.22279 .12993 L
.22398 .12917 L
.22508 .1286 L
.22625 .12742 L
.22751 .12627 L
.22868 .12544 L
.22978 .12527 L
.23078 .12583 L
.23186 .12622 L
.23303 .12639 L
.23433 .12682 L
.23498 .12715 L
.23568 .12764 L
.23695 .12917 L
.2394 .13238 L
.24167 .1359 L
.24408 .14082 L
.24671 .14704 L
.25203 .16356 L
.26153 .20209 L
.28024 .30154 L
.2901 .35752 L
.30054 .40755 L
.30582 .42897 L
.31163 .44769 L
Mistroke
.31418 .45366 L
.31558 .45723 L
.31691 .45981 L
.31815 .4616 L
.3195 .46325 L
.32063 .46453 L
.32186 .46605 L
.32257 .46676 L
.32323 .46718 L
.32452 .46759 L
.32569 .46768 L
.32692 .46756 L
.32756 .46747 L
.32825 .46736 L
.32949 .46684 L
.33025 .46626 L
.33097 .46559 L
.33231 .46408 L
.33472 .46066 L
.33696 .45653 L
.34201 .44366 L
.34665 .42834 L
.35164 .40766 L
.36069 .36265 L
.38129 .24196 L
.39169 .18693 L
.40135 .1451 L
.40622 .12917 L
.40872 .12306 L
.41143 .11693 L
.41298 .11427 L
.4144 .11237 L
.41574 .11087 L
.41645 .11007 L
.41721 .10923 L
.41852 .10826 L
.41976 .10787 L
.42048 .10778 L
.42117 .10778 L
.42245 .1079 L
.4237 .10816 L
.42441 .10853 L
.42506 .109 L
.4275 .11155 L
.42973 .11464 L
.43207 .11905 L
.43696 .13148 L
.44231 .1499 L
.45184 .19294 L
.46072 .2442 L
Mistroke
.47941 .36681 L
.48926 .42655 L
.49465 .45434 L
.49728 .46728 L
.49844 .4732 L
.4997 .47767 L
.501 .48155 L
.50224 .48495 L
.50497 .49458 L
.50572 .49711 L
.50642 .49878 L
.50724 .50018 L
.50798 .50128 L
.50933 .50298 L
.51077 .50454 L
.51199 .50576 L
.51268 .5062 L
.51333 .50643 L
.51446 .50657 L
.51568 .50643 L
.51711 .50618 L
.51781 .50617 L
.51846 .506 L
.51967 .50497 L
.52099 .50328 L
.52339 .49937 L
.52563 .4947 L
.53076 .48009 L
.53575 .46069 L
.54113 .43463 L
.56077 .309 L
.57116 .23557 L
.58226 .16325 L
.58779 .13255 L
.59301 .10797 L
.59548 .09859 L
.59809 .08796 L
.60032 .08115 L
.60278 .07544 L
.60395 .07248 L
.60506 .06966 L
.60634 .0676 L
.60751 .06635 L
.60965 .06475 L
.61083 .06358 L
.61194 .06262 L
.61323 .06271 L
.6144 .06337 L
.6155 .06428 L
.61669 .06541 L
Mistroke
.618 .06648 L
.61866 .06722 L
.61939 .06836 L
.62187 .07374 L
.62439 .08011 L
.62712 .08867 L
.6321 .10897 L
.64141 .16031 L
.66234 .31321 L
.68175 .45264 L
.68707 .48297 L
.6928 .50976 L
.69543 .52113 L
.69676 .52522 L
.6982 .52916 L
.70058 .5359 L
.70183 .53923 L
.70246 .54036 L
.70316 .54135 L
.70454 .54295 L
.70582 .54409 L
.70703 .54545 L
.70832 .54671 L
.70959 .5467 L
.71075 .54615 L
.71191 .54526 L
.71301 .54433 L
.71428 .54351 L
.71492 .54287 L
.71563 .54179 L
.71687 .53926 L
.71805 .5365 L
.72072 .52961 L
.72353 .5203 L
.72828 .50008 L
.73264 .47671 L
.74246 .41078 L
.7624 .24398 L
.77109 .17182 L
.78053 .10275 L
.78576 .07219 L
.79059 .04897 L
.79521 .03193 L
.79754 .02579 L
.79877 .02257 L
.80011 .01996 L
.80083 .01892 L
.8015 .01807 L
.80283 .01675 L
.80411 .0156 L
Mistroke
.80531 .01479 L
.806 .01472 L
.80674 .01485 L
.80803 .01548 L
.80876 .01602 L
.80953 .01666 L
.81026 .01724 L
.81092 .01788 L
.81212 .01968 L
.81341 .02223 L
.81575 .02786 L
.82104 .04583 L
.82585 .06776 L
.83096 .09776 L
.84013 .16524 L
.8609 .35469 L
.87049 .44188 L
.8806 .51904 L
.88477 .54576 L
.88922 .56741 L
.89054 .57403 L
.89178 .57933 L
.89411 .58661 L
.89627 .59253 L
.8975 .5962 L
.89866 .59849 L
.89979 .5999 L
.901 .60094 L
.90228 .60171 L
.90349 .60274 L
.9046 .60332 L
.90582 .60272 L
.90692 .60161 L
.90794 .60024 L
.90915 .59843 L
.91045 .59667 L
.91169 .59422 L
.91282 .59105 L
.91554 .58181 L
.91801 .57196 L
.92285 .54723 L
.92816 .513 L
.93887 .42553 L
.97619 .06558 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00?oooool00ol0003oooooooooo`3oooooobOooooo000oooooo`03o`00
0?oooooooooo0?oooooo9oooool003oooooo00?o0000ooooooooool0oooooolWooooo`00?oooool0
0ol0003oooooooooo`3oooooobOooooo000oooooo`03o`000?oooooooooo0?oooooo9oooool003oo
oooo00?o0000ooooooooool0jOooool3o`0003[ooooo000oooooo`03o`000?oooooooooo0>Sooooo
00Co0000oooooooooooo0000>_ooool003oooooo0_l0003Xooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=oooool003oooooo00?o0000ooooooooool0ioooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Oooooo000oooooo`03o`000?oooooooooo0>Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0fooooo`00?oooool00ol0003oooooooooo`3Voooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool003oooooo00?o0000oooooooo
ool0i_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo000oooooo`03o`00
0?oooooooooo0>Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`00?ooo
ool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Ooo
ool003oooooo00?o0000ooooooooool0iOooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03Gooooo000oooooo`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0eooooo`00?oooool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0=Oooool003oooooo00?o0000ooooooooool0iOooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Cooooo000oooooo`03o`000?oooooooooo0>Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0dooooo`00?oooool2o`000;3ooooo0_l0000c
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=?ooool003oooooo00?o0000oooo
ooooool0[_ooool01?l0003oooooo`000?l0000booooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`00?oooool00ol0003oooooooooo`2]oooo
o`05o`000?ooooooooooooooool00000<Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool01_ooool003oooooo00?o0000ooooooooool0[Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo000oooooo`03o`000?oooooooooo0:co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`00?oooool00ol0003ooooo
ooooo`2/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool003oooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo000o
ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07
ooooo`00?oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01oooool003oooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00Oooooo000oooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`07ooooo`00?oooool2o`000:_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`07ooooo`00?oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool01oooool003oooooo00?o0000ooooooooool0ZOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo000oooooo`03o`000?oooooooooo07Co
oooo1?l0000aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool003oooooo
00?o0000ooooooooool0Loooool2o`0000;ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Oooooo000oooooo`03o`000?oooooooooo07;ooooo0_l0
0004ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`07ooooo`00?oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo000ooooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool003oooooo00?o0000oooooooo
ool0>oooool3o`0003Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool003oooooo00?o0000ooooooooool0
>Oooool2o`0000;ooooo0_l0000booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo0005ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`Go00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`001Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o
0000ooooooooool0>?ooool2o`0000Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`08ooooo`000ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`0003Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Sooooo0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`08ooooo`001Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool02?ooool000Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Sooooo0005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo0005ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo
000oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Wooooo000oooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo000ooooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Wooooo000oooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo000oooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Wooooo000oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo000oooooo`;o0000=_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool0
03oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool02Oooool003oooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool003oooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool02_ooool003oooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool003oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02_ooool003oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool003oooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool02_ooool003oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02_ooool003oooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_oo
ool003oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02_ooool003oooooo0_l0000dooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`00?oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0;ooooo`00?oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0;ooooo`00?oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0;ooooo`00?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0;ooooo`00?oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0;oooo
o`00?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0;ooooo`00?oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0;ooooo`00?ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0;ooooo`00?oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0;ooooo`00?oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0<ooooo`00?oooool00ol0003oooooooooo`0[ooooo`06odA4A?l0003o0000oc8b
<_oMgMgo00005oooool00ol0003oooooooooo`0<ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`Co
000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00gooooo00?o0000oooo
ooooool04Oooool6o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`03o`000?oooooo
oooo00Oooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool00ol0003ooooooooo
o`0Looooo`05oiRHV?l0003o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo000oooooo`;o0000;oooool00omgMgOo<S8bo`00000Gooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_oo
ool03Oooool00ol0003oooooooooo`0Aooooo`0=oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000?oo
ooooMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`03o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool07?ooool01Ol@
413o0000oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00?oooool0
0ol0003oooooooooo`0_ooooo`;o00005oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04_ooool00onHV9So8B4Qonk^kP02ooooo`03o`000?oooooo410@00?ooooo00?o
410@ooooooooool05oooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Go
0000ooooooooooooooooo`00000Oooooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`00?oooool00ol0003oooooooooo`0^ooooo`03ogMgMolb<S;o000001So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0=ooooo`03o`000?oooooooooo01?ooooo00OoV9RHob4Q
8Oo^k^koooooo`000?oooooo000000?ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00_ooool00ol0003ooooooooo
o`0Mooooo`04o`000?ooooooZJVYoa0@40?ooooo00Go0000ooooooooooooooooo`000003ooooo`00
?oooool00ol0003oooooooooo`0[ooooo`06o`000?lQ8B7o0000oc8b<_o<c<co00006?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03Oooool00ol0003oooooooooo`0Eooooo`06ogMgMomV
IVKoooooo`000?oooooo00000oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_o
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00?o0000oooo
ooooool07Oooool01?l0003o410@o`000?nj^[X3ooooo`05o`000?ooooooooooooooool000000ooo
ool003oooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000001Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00Go0000ooooool0003o
oooooa0@4003ooooo`03oa0@4?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool01?l0003o
oooookZj^_lQ8B43ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo00?o0000oooo
ooooool0:oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01;ooooo00go0000okZj^_ooooooV9RHoa0@4?oooooo0000oooo
oomgMgOoV9RHoooooonHV9SoMgMg01Sooooo00?o0000ooooooooool02?ooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`05oa0@
4?l0003ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool5o`0001Wooooo00?o0000oooooooo
ool02oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?oEEEEofIVI_l000001Oooool4o`00
00kooooo00?o0000ooooooooool04_ooool03OnHV9So410@o`000?lQ8B7oc<c<ooooool0003ooooo
onk^k_lb<S;o0000oc8b<_o^k^h06?ooool00ol0003oooooooooo`08ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Cooooo00?o0000ooooooooool07?ooool01OnYZJWo0000o`000?l@
413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00?oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000Go00008_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool03?ooool003oooooo00?o0000ooooooooool01?ooool2
o`0000Kooooo0ol0000Oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0=ooooo`00?oooool00ol0003oooooooooo`02ooooo`?o00002Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0=ooooo`00?oooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool03Oooool003oooooo0ol0000@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo000hoooooooo0000<?l0
0001ooooo`00?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00008
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool2o`0000Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o00002?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Kooooo000o
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`00?oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo000oooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool003oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0=ooooo`00?oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00kooooo000oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool0
03oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`00?oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00kooooo000oooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool03_ooool003oooooo0_l0000Gooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo000o
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool003oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`00?oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00kooooo000oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3_ooool003oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`00?oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo000oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool03oooool003oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0?ooooo`00?oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo
000oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool003oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0?ooooo`00?oooool2o`0001gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool03oooool003oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`00
?oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00oooooo000oooooo`03o`000?oo
oooooooo01gooooo0_l00006ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0@ooooo`00?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00?ooooo0_l0000Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool0
03oooooo00?o0000ooooooooool07oooool2o`0000;ooooo0_l0000[ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool04?ooool003oooooo00?o0000ooooooooool08?ooool4o`0002co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`00?oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool003oooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo000o
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@
ooooo`00?oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo013ooooo000oooooo`;o0000D_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo013ooooo000oooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Aooooo`00?oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04Oooool003oooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo000oooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`00?oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool003oooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo000o
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0A
ooooo`00?oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00005ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`00
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;o
oooo0005ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0005Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`001Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo0005ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?oMgMg
ofIVI_ooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool000Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Boooo
o`001Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool000Go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool0E_ooool2o`0000;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool003oooooo00?o0000oooooooo
ool0Eoooool4o`00037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01?ooooo000oooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo000oooooo`03o`000?oo
oooooooo08gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01?ooooo000oooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo000oooooo`03o`000?oooooooooo
08gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01?ooooo000oooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo000oooooo`;o0000Soooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool003oooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05?ooool003oooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool003oooooo00?o0000oooo
ooooool0Soooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool05?ooool003oooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool003oooooo00?o0000ooooooooool0
T?ooool01?l0003oooooooooool0000cooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo000oooooo`03o`00
0?oooooooooo093ooooo1?l0000cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo000oooooo`03o`000?oo
oooooooo0<Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05Oooool003oooooo00?o0000ooooooooool0aoooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Eooooo`00?oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Gooooo000oooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool003oooooo
00?o0000ooooooooool0b?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`00?oooool2o`000<[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool003oooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0E
ooooo`00?oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo000oooooo`03
o`000?oooooooooo0<[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool003oooooo00?o0000ooooooooool0
b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Fooooo`00?oooool00ol0003oooooooooo`3;ooooo`04o`000?oo
ooooooooo`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`00?ooo
ool00ol0003oooooooooo`3<ooooo`;o0000<oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Kooooo000oooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Kooooo000oooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo000oooooo`03o`000?oooooooooo0?oo
oooo0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo000oooooo`03o`00
0?oooooooooo0?oooooo0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo
000oooooo`;o0000ooooool4ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05ooo
ool003oooooo00?o0000ooooooooool0ooooool4ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05oooool003oooooo00?o0000ooooooooool0ooooool4ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06?ooool003oooooo00?o0000ooooooooool0ooooool4ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool003oooooo00?o0000ooooooooool0
ooooool4ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool003oooooo00?o
0000ooooooooool0ooooool4ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?oo
ool003oooooo00?o0000ooooooooool0ooooool4ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06?ooool003oooooo00?o0000ooooooooool0ooooool5ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06?ooool003oooooo00?o0000ooooooooool0ooooool5ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool000Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo0005ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
ool6ooooo`04o`000?ooooooooooooooo`;o00006oooool000Gooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool5o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`04o`000?oooooo0000o`0001cooooo
0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo00001_ooool3o`000?oooooo
1oooool3o`0001gooooo0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00CogMgMoeEEEOoooooo0000
1_ooool00ol0003oooooooooo`3oooooobOooooo0005ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
MgMgolc<c?l000001_ooool00ol0003oooooooooo`3oooooobOooooo0005ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3oooooobOooooo0005oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3ooooo
obOooooo000oooooo`03o`000?oooooooooo0?oooooo9oooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.64995, -4.53392*^-5, \
0.130335, 5.36709*^-7}}]
}, Open  ]],

Cell[TextData[{
  "The difference between ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "'s solution and ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ t\)]],
  " is finite, and is growing with time. This is typical behavior for \
numerical solutions of initial-value problems: the errors tend to accumulate \
over time.  If this level of error is too large,  the error can be reduced by \
using two options for ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ": ",
  StyleBox["AccuracyGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PrecisionGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default values of these options is ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", meaning that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " decides what the accuracy of  the solution will be. We can intercede, \
however, choosing our own number of significant figures for the accuracy.  It \
is best to set both ",
  StyleBox["AccuracyGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PrecisionGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to about the same number, and to have this number smaller than ",
  StyleBox["$MachinePrecision",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (otherwise the requested accuracy cannot be achieved due to numerical \
roundoff error). Good values for my computer (with ",
  StyleBox["$MachinePrecision",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of 16) are ",
  StyleBox["AccuracyGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rule]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox["13",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PrecisionGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rule]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox["13",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->"i:111"],

Cell[BoxData[
    \(\(xsol[t_]\  = \ 
        x[t] /. \(NDSolve[{\(x''\)[t]\  \[Equal] \ \(-x[t]\), 
                x[0] \[Equal] 1, \(x'\)[0] \[Equal] 0}, x[t], {t, 0, 30}, 
              AccuracyGoal \[Rule] 13, 
              PrecisionGoal \[Rule] 13]\)[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.21"],

Cell[TextData[{
  "The results are shown in Cell ",
  ButtonBox["1.22",
    ButtonData:>"Cell 1.22",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[xsol[t]\  - \ Cos[t], {t, 0, 30}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.22"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.300159 3.31065e+11 [
[.18254 .28766 -3 -9 ]
[.18254 .28766 3 0 ]
[.34127 .28766 -6 -9 ]
[.34127 .28766 6 0 ]
[.5 .28766 -6 -9 ]
[.5 .28766 6 0 ]
[.65873 .28766 -6 -9 ]
[.65873 .28766 6 0 ]
[.81746 .28766 -6 -9 ]
[.81746 .28766 6 0 ]
[.97619 .28766 -6 -9 ]
[.97619 .28766 6 0 ]
[.01131 .05186 -55.5 -6.25 ]
[.01131 .05186 0 6.25 ]
[.01131 .13463 -43.5 -6.25 ]
[.01131 .13463 0 6.25 ]
[.01131 .21739 -55.5 -6.25 ]
[.01131 .21739 0 6.25 ]
[.01131 .38293 -49.5 -6.25 ]
[.01131 .38293 0 6.25 ]
[.01131 .46569 -37.5 -6.25 ]
[.01131 .46569 0 6.25 ]
[.01131 .54846 -49.5 -6.25 ]
[.01131 .54846 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .30016 m
.18254 .30641 L
s
[(5)] .18254 .28766 0 1 Mshowa
.34127 .30016 m
.34127 .30641 L
s
[(10)] .34127 .28766 0 1 Mshowa
.5 .30016 m
.5 .30641 L
s
[(15)] .5 .28766 0 1 Mshowa
.65873 .30016 m
.65873 .30641 L
s
[(20)] .65873 .28766 0 1 Mshowa
.81746 .30016 m
.81746 .30641 L
s
[(25)] .81746 .28766 0 1 Mshowa
.97619 .30016 m
.97619 .30641 L
s
[(30)] .97619 .28766 0 1 Mshowa
.125 Mabswid
.05556 .30016 m
.05556 .30391 L
s
.0873 .30016 m
.0873 .30391 L
s
.11905 .30016 m
.11905 .30391 L
s
.15079 .30016 m
.15079 .30391 L
s
.21429 .30016 m
.21429 .30391 L
s
.24603 .30016 m
.24603 .30391 L
s
.27778 .30016 m
.27778 .30391 L
s
.30952 .30016 m
.30952 .30391 L
s
.37302 .30016 m
.37302 .30391 L
s
.40476 .30016 m
.40476 .30391 L
s
.43651 .30016 m
.43651 .30391 L
s
.46825 .30016 m
.46825 .30391 L
s
.53175 .30016 m
.53175 .30391 L
s
.56349 .30016 m
.56349 .30391 L
s
.59524 .30016 m
.59524 .30391 L
s
.62698 .30016 m
.62698 .30391 L
s
.69048 .30016 m
.69048 .30391 L
s
.72222 .30016 m
.72222 .30391 L
s
.75397 .30016 m
.75397 .30391 L
s
.78571 .30016 m
.78571 .30391 L
s
.84921 .30016 m
.84921 .30391 L
s
.88095 .30016 m
.88095 .30391 L
s
.9127 .30016 m
.9127 .30391 L
s
.94444 .30016 m
.94444 .30391 L
s
.25 Mabswid
0 .30016 m
1 .30016 L
s
.02381 .05186 m
.03006 .05186 L
s
gsave
.01131 .05186 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.02381 .13463 m
.03006 .13463 L
s
gsave
.01131 .13463 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.02381 .21739 m
.03006 .21739 L
s
gsave
.01131 .21739 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.02381 .38293 m
.03006 .38293 L
s
gsave
.01131 .38293 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.02381 .46569 m
.03006 .46569 L
s
gsave
.01131 .46569 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.02381 .54846 m
.03006 .54846 L
s
gsave
.01131 .54846 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.125 Mabswid
.02381 .06841 m
.02756 .06841 L
s
.02381 .08497 m
.02756 .08497 L
s
.02381 .10152 m
.02756 .10152 L
s
.02381 .11807 m
.02756 .11807 L
s
.02381 .15118 m
.02756 .15118 L
s
.02381 .16773 m
.02756 .16773 L
s
.02381 .18429 m
.02756 .18429 L
s
.02381 .20084 m
.02756 .20084 L
s
.02381 .23395 m
.02756 .23395 L
s
.02381 .2505 m
.02756 .2505 L
s
.02381 .26705 m
.02756 .26705 L
s
.02381 .28361 m
.02756 .28361 L
s
.02381 .31671 m
.02756 .31671 L
s
.02381 .33327 m
.02756 .33327 L
s
.02381 .34982 m
.02756 .34982 L
s
.02381 .36637 m
.02756 .36637 L
s
.02381 .39948 m
.02756 .39948 L
s
.02381 .41603 m
.02756 .41603 L
s
.02381 .43258 m
.02756 .43258 L
s
.02381 .44914 m
.02756 .44914 L
s
.02381 .48224 m
.02756 .48224 L
s
.02381 .4988 m
.02756 .4988 L
s
.02381 .51535 m
.02756 .51535 L
s
.02381 .5319 m
.02756 .5319 L
s
.02381 .03531 m
.02756 .03531 L
s
.02381 .01875 m
.02756 .01875 L
s
.02381 .0022 m
.02756 .0022 L
s
.02381 .56501 m
.02756 .56501 L
s
.02381 .58156 m
.02756 .58156 L
s
.02381 .59812 m
.02756 .59812 L
s
.02381 .61467 m
.02756 .61467 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26708 m
.03279 .28163 L
.03405 .28553 L
.03543 .2909 L
.03673 .29472 L
.03793 .32765 L
.03902 .33423 L
.04021 .31471 L
.04145 .3056 L
.04262 .2995 L
.04387 .29887 L
.04501 .29917 L
.04634 .29968 L
.04758 .30005 L
.04888 .30031 L
.04956 .30111 L
.0503 .28821 L
.05154 .25627 L
.05288 .22584 L
.05354 .21459 L
.05423 .21364 L
.05546 .22911 L
.05672 .22944 L
.0579 .25872 L
.05894 .26079 L
.06007 .26769 L
.06131 .27129 L
.06244 .2709 L
.06369 .27489 L
.06439 .27397 L
.06505 .27551 L
.0665 .27791 L
.06783 .28064 L
.07022 .287 L
.07281 .29598 L
.08408 .34956 L
.0947 .39554 L
.09988 .41476 L
.10458 .43009 L
.10897 .44189 L
.11373 .45167 L
.11635 .45556 L
.11749 .45703 L
.11876 .45835 L
.11995 .45946 L
.12106 .46005 L
.12233 .46071 L
.1235 .46115 L
.12478 .46133 L
.12546 .46115 L
Mistroke
.12618 .46111 L
.12687 .46093 L
.12751 .46056 L
.12872 .45997 L
.12991 .45913 L
.13101 .45813 L
.13348 .45508 L
.13597 .45126 L
.1387 .44567 L
.1442 .43149 L
.15444 .39418 L
.16375 .35096 L
.18468 .2408 L
.19396 .19585 L
.2038 .15711 L
.20894 .14193 L
.21167 .13535 L
.2146 .12969 L
.21729 .1259 L
.21847 .1245 L
.21975 .12329 L
.22097 .12241 L
.2221 .122 L
.2233 .1216 L
.22458 .12142 L
.22582 .12153 L
.22652 .12189 L
.22718 .12211 L
.22787 .12252 L
.2285 .12303 L
.22992 .12428 L
.23113 .12553 L
.23245 .12722 L
.23485 .13123 L
.24062 .14468 L
.24596 .16196 L
.25574 .20375 L
.26613 .25901 L
.2858 .37332 L
.29441 .41859 L
.2993 .44086 L
.30385 .45872 L
.30877 .47467 L
.31326 .48552 L
.31572 .49011 L
.31805 .4932 L
.31924 .49449 L
.3205 .49563 L
.32116 .49588 L
.32189 .49632 L
Mistroke
.32317 .49658 L
.32383 .49673 L
.32456 .49662 L
.32588 .49636 L
.32717 .49577 L
.32836 .49493 L
.32909 .49415 L
.32977 .49349 L
.33106 .49173 L
.33394 .48702 L
.33646 .48162 L
.33878 .47545 L
.34402 .45828 L
.35376 .41484 L
.36286 .36367 L
.38352 .23225 L
.39399 .17137 L
.39913 .14579 L
.40389 .12557 L
.40812 .1109 L
.41278 .09837 L
.4152 .09341 L
.41747 .0901 L
.41864 .08859 L
.41987 .08742 L
.42051 .08705 L
.42122 .08657 L
.42245 .0862 L
.42377 .08606 L
.42499 .0862 L
.42563 .08654 L
.42633 .08676 L
.42706 .08738 L
.42774 .08779 L
.429 .08918 L
.43015 .09065 L
.43274 .09484 L
.43503 .09995 L
.43753 .10646 L
.44208 .12167 L
.45295 .1728 L
.46303 .23437 L
.48188 .36485 L
.49179 .42888 L
.50224 .48364 L
.50758 .50463 L
.5104 .51353 L
.51343 .52124 L
.51486 .52426 L
.51621 .52672 L
Mistroke
.51743 .52845 L
.51875 .52988 L
.52 .53106 L
.52063 .53154 L
.52132 .5319 L
.52255 .53231 L
.5237 .53227 L
.52495 .53187 L
.52565 .53168 L
.52631 .5312 L
.5276 .53018 L
.52878 .52885 L
.53103 .52529 L
.53343 .52066 L
.53601 .51386 L
.53881 .50496 L
.54389 .48464 L
.55339 .43399 L
.56382 .36398 L
.58488 .2068 L
.59489 .14057 L
.60438 .09153 L
.60962 .07198 L
.61258 .06349 L
.61399 .06014 L
.61532 .05743 L
.61762 .05386 L
.61884 .05235 L
.62015 .05118 L
.62146 .05059 L
.62212 .05033 L
.62283 .05037 L
.62411 .05048 L
.62529 .05092 L
.62657 .05184 L
.62721 .05254 L
.62792 .05335 L
.63034 .05706 L
.63316 .06316 L
.63581 .07077 L
.6406 .08841 L
.64574 .11267 L
.65545 .17214 L
.66433 .23791 L
.68495 .40311 L
.69498 .47372 L
.70407 .52385 L
.70866 .54264 L
.71107 .55043 L
.71361 .55726 L
Mistroke
.71584 .56179 L
.71703 .56377 L
.71829 .5655 L
.71945 .56664 L
.72051 .56726 L
.72158 .56778 L
.72259 .56789 L
.72372 .56767 L
.72497 .56711 L
.72628 .56616 L
.7275 .56476 L
.72969 .56127 L
.73204 .55605 L
.73465 .5487 L
.7374 .53914 L
.74231 .51749 L
.75187 .46049 L
.76208 .3829 L
.78046 .2251 L
.79072 .14292 L
.79612 .10535 L
.80183 .07147 L
.80683 .04765 L
.80948 .03739 L
.81233 .02857 L
.81494 .02229 L
.81618 .01993 L
.81732 .0181 L
.81847 .01685 L
.81972 .01567 L
.82082 .01497 L
.82199 .01472 L
.82313 .0149 L
.82437 .01534 L
.82566 .01633 L
.82687 .01769 L
.82903 .02115 L
.83024 .02361 L
.83134 .0264 L
.83653 .04327 L
.84143 .06562 L
.85019 .11954 L
.8597 .1941 L
.87915 .37082 L
.88947 .45986 L
.89516 .50268 L
.90057 .53775 L
.90565 .56458 L
.90833 .57594 L
.91119 .58612 L
Mistroke
.91383 .59354 L
.91622 .59836 L
.91738 .60023 L
.91863 .60174 L
.91981 .60266 L
.9209 .6031 L
.922 .60332 L
.92318 .60317 L
.92429 .60236 L
.92531 .60159 L
.9265 .60023 L
.9278 .59814 L
.93015 .59314 L
.93262 .58623 L
.93523 .57689 L
.93993 .55554 L
.94893 .49904 L
.95864 .41961 L
.97619 .25114 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00BOooool0
0ol0003oooooooooo`3ooooooagooooo0019ooooo`;o0000oooooolNooooo`00BOooool00ol0003o
ooooooooo`3ooooooagooooo0019ooooo`03o`000?oooooooooo0?oooooo7Oooool004Wooooo00?o
0000ooooooooool0oooooolMooooo`00BOooool00ol0003oooooooooo`3Uooooo`?o0000=?ooool0
04Wooooo0_l0003Uooooo`;o000000?oooooo`000?ooool0<oooool004Wooooo00?o0000oooooooo
ool0i?ooool01Ol0003ooooooooooooooooo000003?ooooo0019ooooo`03o`000?oooooooooo0>Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`00BOooool00ol0003ooooo
ooooo`3Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<?ooool0023ooooo0_o^
k^h3ooooo`;ok^k^8_ooool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0<?ooool000_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00goA4A4
o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool2o`000>?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0_ooooo`002oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo0>;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`0000?oooooo`000?l000001?l00004
ooooo`03ojVYZOmEEEGooooo013ooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000oooooooo
ool0hOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo000<ooooo`03ob4Q
8Ooooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`3Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool000cooooo00?oEEEE
olc<c?ooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004ooo
ool00ol0003oooooooooo`2[ooooo`;o0000=?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02oooooo000<ooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool00oooool2
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Cooooo`;o0000Zoooool2o`000003ooooool0003ooooo03;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0^ooooo`002Oooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo0009ooooo`Go00003?oo
ool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
0ol00002ooooo`;o00001?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo
000oooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00002[ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02gooooo000hooooo`Co00000oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooooooo`;o0000Z_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0]ooooo`00?oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0]ooooo`00?oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool0
0000Z_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0]ooooo`00?_ooool2o`0000?ooooo0_l00004ooooo`03o`00
0?oooooooooo0:Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool004Wooooo00?o0000ooooooooool0Yooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0]ooooo`00BOooool2o`000:Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool0
04Wooooo00?o0000ooooooooool0L?ooool4o`0003?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool004Wo
oooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02cooooo0019ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02cooooo0019ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo
0019ooooo`;o0000Koooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0;?ooool004Wooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;?ooool004Wooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0:oooool004Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0:oooool004Wooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
:oooool001oooooo0_o^k^h3ooooo`;ok^k^8oooool2o`0006kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo000Iooooo`0=odA4A?l0003o
0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQCooooo00?o0000ooooooooool0=_ooool3o`0003?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_o
oooo000Looooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool0=Ooo
ool2o`0000;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0:oooool0013ooooo1_l00007ooooo`07o`000?oooooo
oooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0[ooooo`007?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0[ooooo`006Oooool0
3Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005?ooool2o`0003Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`006Oooool00ol0003oooooooooo`03
ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02[ooooo000Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0ol00002ooooo`;o00001Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool001Wooooo1?l0000<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0:_ooool003Oooooo1?l00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0:_ooool003kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`;o0000<oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02[ooooo000nooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool0
03gooooo0_l00003ooooo`;o00001Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0:Oooool004Wooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02Wooooo0019ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Yooooo`00BOooool2o`00037ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Yooooo`00BOooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:Oooool004Wooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Wooooo0019ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Yooooo`00
BOooool2o`00033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`00BOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:?oo
ool004Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo02Sooooo0019ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Xooooo`00BOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0:?ooool0023ooooo0_o^k^h3ooooo`;ok^k^8_ooool2o`0002oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Xooooo`002Oooool5o`0000Gooooo0_lQ
8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo0009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL04oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0:?ooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^kP0Aooooo`07o`00
0?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Cooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Wooooo`002oooool00onHV9So8B4Qonk^kP0?ooooo`09ogMgMolb<S;ooooo
ooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool09oooool000cooooo00?oMgMgofIVI_ooool0
2oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool2o`0000Ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oo
oooo000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Cooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02Oooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool01Oooool2o`0002Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Wooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000
9_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo000hooooo`Co00000ooo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool2o`0002Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`00?oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`;o00009Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo02Oooooo000oooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000007ooooo`;o00009Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02Oooooo000nooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool01Ooo
ool2o`0002Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Vooooo`00BOooool0
0ol0003oooooooooo`05ooooo`;o00009Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02Kooooo0019ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000009?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo02Kooooo0019ooooo`;o00001_ooool00ol0003o
ooooo`00000Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`06ooooo`00BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000002?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo
0019ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000008Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM01Gooooo00?o0000ooooooooool03Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool03oooool00ol0003ooooo
ooooo`0=ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?o0000oooooooo
ool00_ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@07ooooo`03o`000?oooooooooo
01Kooooo00GoV9RHoa0@4?l0003o<S8bolc<c002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^
0oooool004Wooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000Sooooo`03o`000?mg
MgOo<S8b01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0?ooooo`03o`000?oooooooooo00gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So0000oiRHV?mgMgL07Oooool00ol0
003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`06
ooooo`03o`000?oooooooooo01Kooooo00Go410@okZj^_ooooooMgMgoc8b<P02ooooo`06o`000?mg
MgOoV9RHoooooonHV9SoMgMg0oooool004Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`00000Sooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413oooooo`000?oooooo410@
01cooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06_ooool01Ol0003oooooooooool0003o410@00?ooooo00?o410@
ooooooooool00Oooool004Wooooo0_l00006ooooo`03o`000?oooooo000002;ooooo00Co0000oooo
oomgMgOo<S8b5Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00?o0000ooooooooool04?oo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo0000ooooool000007?ooool00ol0003ooooo
ooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01_ooool00ol0003ooooo
ooooo`0Iooooo`04ojVYZOl@413oooooooooo`;o00000oooool00ol0003oooooooooo`01ooooo`00
BOooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`00023ooooo0ol000000olb<S;o
c<c<ooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`03o`000?oooooo
oooo017ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003oooooo`000?oooooo000001cooooo00?o
0000ooooooooool01_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
2?ooool00ol0003oooooooooo`0Gooooo`07oa0@4?l0003o^[Zjooooool0003oooooo`000003oooo
o`03o`000?oooooooooo007ooooo0019ooooo`;o00001Oooool01?l0003oooooooooooooool2o`00
01oooooo0_l0000Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`09o`000?ooooooooooooooool@413oooooo`000?oooooo410@01cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06?ooool01_nj^[[o8B4Qooooool0003ooooooa0@40?ooooo00?o410@ooooooooool00Oooool0
04Wooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool2o`00
01Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So0000oiRHV?mgMgL07?ooool00ol0003ooooo
ooooo`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Gooooo00go410@oiRHV?oooooo^[Zjo`000?oooooo0000oooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0019ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01gooooo1?l0000Gooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool06?ooool01_l0003o
oooooooooomEEEGoIVIVo`0000Gooooo1?l0000@ooooo`03o`000?oooooooooo00kooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h07?ooool00ol0003ooooo
ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Wooooo00?o0000oooooooo
ool05Oooool03OnYZJWo410@o`000?l@413oZJVYooooool0003oooooonk^k_lb<S;o0000oc8b<_o^
k^h00oooool004Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Oooooo0019ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`07ooooo`00BOooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool004Wooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo0012oooooooo0000
9_l00001ooooo`00BOooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`;o
00002?ooool004Wooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo
01[ooooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000001cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooool000002?ooool004Wooooo00Ko0000oooooooooooo0000ooooool00009ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Sooooo0019ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`08ooooo`00BOooool2o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`08ooooo`00BOooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?oo
ool004Wooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0019
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`00BOooool0
1Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool004Wooooo0_l00002
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool004Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`09ooooo`00BOooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Wooooo0019ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
2Oooool004Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`00BOooool2
o`0000oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02Oooool004Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`09ooooo`00BOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wo
oooo0019ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool001oooooo0_o^
k^h3ooooo`;ok^k^8oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo0008
ooooo`Go00001Oooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^5?ooool2o`00013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool000Sooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02_ooool000Wooooo00?oV9RHob4Q8Oo^k^h04Ooo
ool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41005?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00[ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
5?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo000;ooooo`03ogMgMomV
IVKooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Cooooo
0_l0000Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00[ooooo000<ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
2_ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0:ooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00co
oooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`?o00000_ooool2o`0000Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:oooo
o`00?_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0:ooooo`00=oooool4o`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`;o00004_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`00
?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0:ooooo`00?_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`00?Ooo
ool2o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02ooo
ool004Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`00BOooool2o`00
01Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0;ooooo`00BOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo
0019ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool004Wooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`00BOooool2o`0001Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02oooool004Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`00
BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo0019ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool03?ooool001kooooo0_o^k^h3ooooo`;ok^k^9?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo000Hooooo`0=odA4A?l0003o0000
oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kQGooooo0_l0000Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo
000Kooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0<ooooo`007?ooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005Oooool00ol0003ooooo
ooooo`0Hooooo`04o`000?ooooooooooooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00cooooo000Kooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Gooooo00?o
0000ooooooooool06Oooool4o`00037ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0=ooooo`006?ooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005Ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Ooo
ool001Sooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400Eooooo`;o0000D?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00gooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Hooooo`Co00003?ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l0
0006ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0=ooooo`00?Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000f
ooooo`Co00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001B
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool003gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`00?Oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00kooooo000looooo`;o00000oooool2o`0000Kooooo00?o0000oooooooo
ool0D_ooool01Ol0003ooooooooooooooooo000003;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo0019ooooo`03o`000?oooooooooo05?o
oooo00Co0000ooooool0003o0000<_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool004Wooooo0_l0001Eooooo`;o0000<oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool004Wooooo
00?o0000ooooooooool0R_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool004Wooooo00?o0000ooooooooool0R_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool004Wooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool004Wooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool004Wooooo0_l0002<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`00
BOooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0?ooooo`00BOooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`00BOooool0
0ol0003oooooooooo`2<ooooo`;o00000oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00oooooo0019ooooo`03o`000?oooooooooo08gooooo00Co0000oooooooooooo0000<_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0@ooooo`007oooool2onk^kP?ooooo0_o^k^hSooooo`;o0000Soooool2o`00
03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04?ooool000[ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Go
oooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^5?ooool00ol0003ooooooooo
o`34ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo000:ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48
ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool0a?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`002_ooool00onYZJWoEEEEooooo`0@ooooo`07o`000?oooooooooooooo
oooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Dooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool000_ooooo00?o8B4Q
ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo
0<Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04?ooool000_ooooo00?oEEEEolc<c?ooool02oooool03Ol0003o
8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000005?ooool2o`000<Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04Oooool000_ooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`03ooooo`;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
01Cooooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`002?ooool01Ol@413o
oooooooooooooooo<S8b00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool3o`0000;ooooo0_l00005ooooo`03o`000?oooooo
oooo0<Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04Oooool000Sooooo1Ol0000<ooooo`Co00003?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0a_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Aooooo`00=oooool4o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0<Oooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04Oooool003kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`;o0000bOooool3o`0003?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Aooooo`00?_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool003gooooo0_l00003ooooo`;o00001Oooool00ol0
003oooooooooo`3oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool004Wo
oooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;o
oooo0019ooooo`03o`000?oooooooooo0?oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Booooo`00BOooool2o`000?oooooo0_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01?ooooo0019ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo0019ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo0019ooooo`03o`000?oooooooooo0?oo
oooo0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo0019ooooo`;o0000
ooooool3ooooo`05o`000?ooooooooooooooool000005_ooool004Wooooo00?o0000ooooooooool0
ooooool3ooooo`03o`000?oooooo000001Oooooo0019ooooo`03o`000?oooooooooo0?oooooo1?oo
ool2o`0001Oooooo0019ooooo`03o`000?oooooooooo0?oooooo7Oooool004Wooooo00?o0000oooo
ooooool0oooooolMooooo`00BOooool2o`000?oooooo7_ooool004Wooooo00?o0000ooooooooool0
oooooolMooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-7.86783, -1.11671*^-12, \
0.134666, 1.29132*^-14}}]
}, Open  ]],

Cell[TextData[{
  "The error in the solution has now been considerably reduced. (Note that I \
have saved a little space by directly defining the solution of ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to be the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["xsol",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Italic"], 
          StyleBox["t",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", all in one line of code.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4.2 Error in Chaotic Systems",
  FontFamily->"Helvetica"]], "Subsubtitle",
  CellTags->{"i:26", "c:21"}],

Cell[CellGroupData[{

Cell["A Chaotic System: The Driven Pendulum", "Section",
  CellTags->"c:22"],

Cell[TextData[{
  "\tThe problem of error accumulation in numerical solutions of ODEs is \
radically worse when the solutions display chaotic behavior.  Consider the \
following equation of motion for a pendulum of length ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " (see Fig. ",
  ButtonBox["1.8",
    ButtonData:>"Fig. 1.8",
    ButtonStyle->"Hyperlink"],
  "):"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`l\ \(\(\[Theta]\^\[DoublePrime]\)(
            t)\)\  = \ \(-g\)\ sin\ \[Theta] - 
          f\ \(sin(\[Theta] - \[Omega]\ t)\)\)]],
  "."
}], "NE4",
  CellTags->{"(1.4.1)", "i:50"}],

Cell[TextData[{
  "The first term on the ",
  "right-hand",
  " side is the usual acceleration due to gravity, and the second term is an \
added time-dependent  force that can drive the pendulum into chaotic motion.  \
This term can arise if one rotates the pivot of the pendulum in a small \
circle, at frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ". (Think of a noisemaker on New Year's Eve.)"
}], "Text"],

Cell[TextData[{
  "\tWe can numerically integrate this equation of motion using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  In Fig. ",
  ButtonBox["1.9",
    ButtonData:>"Fig. 1.9",
    ButtonStyle->"Hyperlink"],
  " we show ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta](t)\)\(\ \)\)\)]],
  " for",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0 < t < 200\)\)\)]],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`l = \(g\  = \(f = \ 1\)\)\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Omega]\  = \ 2\)\)\)]],
  StyleBox[", ",
    FontFamily->"Symbol"],
  " and initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0)\  = \ \(-0.5\), \ \(\[Theta]\^\[Prime]\)(
          0)\  = \ 0\)]],
  ". One can see that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](t)\)]],
  " increases with time in a rather complicated manner as the pendulum \
rotates about the pivot, and sometimes  doesn't quite make it over the top. \
(Values of \[Theta] larger than ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\)]],
  " mean that the pendulum has undergone one or more rotations about the \
pivot.)"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0215678 0.00258203 [
[.2619 .00907 -6 -9 ]
[.2619 .00907 6 0 ]
[.5 .00907 -9 -9 ]
[.5 .00907 9 0 ]
[.7381 .00907 -9 -9 ]
[.7381 .00907 9 0 ]
[.97619 .00907 -9 -9 ]
[.97619 .00907 9 0 ]
[1.025 .02157 0 -6 ]
[1.025 .02157 10 6 ]
[.01131 .15067 -12 -4.5 ]
[.01131 .15067 0 4.5 ]
[.01131 .27977 -18 -4.5 ]
[.01131 .27977 0 4.5 ]
[.01131 .40887 -18 -4.5 ]
[.01131 .40887 0 4.5 ]
[.01131 .53797 -18 -4.5 ]
[.01131 .53797 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .02157 m
.2619 .02782 L
s
[(50)] .2619 .00907 0 1 Mshowa
.5 .02157 m
.5 .02782 L
s
[(100)] .5 .00907 0 1 Mshowa
.7381 .02157 m
.7381 .02782 L
s
[(150)] .7381 .00907 0 1 Mshowa
.97619 .02157 m
.97619 .02782 L
s
[(200)] .97619 .00907 0 1 Mshowa
.125 Mabswid
.07143 .02157 m
.07143 .02532 L
s
.11905 .02157 m
.11905 .02532 L
s
.16667 .02157 m
.16667 .02532 L
s
.21429 .02157 m
.21429 .02532 L
s
.30952 .02157 m
.30952 .02532 L
s
.35714 .02157 m
.35714 .02532 L
s
.40476 .02157 m
.40476 .02532 L
s
.45238 .02157 m
.45238 .02532 L
s
.54762 .02157 m
.54762 .02532 L
s
.59524 .02157 m
.59524 .02532 L
s
.64286 .02157 m
.64286 .02532 L
s
.69048 .02157 m
.69048 .02532 L
s
.78571 .02157 m
.78571 .02532 L
s
.83333 .02157 m
.83333 .02532 L
s
.88095 .02157 m
.88095 .02532 L
s
.92857 .02157 m
.92857 .02532 L
s
.25 Mabswid
0 .02157 m
1 .02157 L
s
gsave
1.025 .02157 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .15067 m
.03006 .15067 L
s
[(50)] .01131 .15067 1 0 Mshowa
.02381 .27977 m
.03006 .27977 L
s
[(100)] .01131 .27977 1 0 Mshowa
.02381 .40887 m
.03006 .40887 L
s
[(150)] .01131 .40887 1 0 Mshowa
.02381 .53797 m
.03006 .53797 L
s
[(200)] .01131 .53797 1 0 Mshowa
.125 Mabswid
.02381 .04739 m
.02756 .04739 L
s
.02381 .07321 m
.02756 .07321 L
s
.02381 .09903 m
.02756 .09903 L
s
.02381 .12485 m
.02756 .12485 L
s
.02381 .17649 m
.02756 .17649 L
s
.02381 .20231 m
.02756 .20231 L
s
.02381 .22813 m
.02756 .22813 L
s
.02381 .25395 m
.02756 .25395 L
s
.02381 .30559 m
.02756 .30559 L
s
.02381 .33141 m
.02756 .33141 L
s
.02381 .35723 m
.02756 .35723 L
s
.02381 .38305 m
.02756 .38305 L
s
.02381 .43469 m
.02756 .43469 L
s
.02381 .46051 m
.02756 .46051 L
s
.02381 .48633 m
.02756 .48633 L
s
.02381 .51215 m
.02756 .51215 L
s
.02381 .56379 m
.02756 .56379 L
s
.02381 .58962 m
.02756 .58962 L
s
.02381 .61544 m
.02756 .61544 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .02028 m
.02499 .02036 L
.02605 .02061 L
.02729 .02111 L
.02846 .02176 L
.03279 .02494 L
.03507 .0265 L
.03633 .0272 L
.0375 .02773 L
.03877 .02815 L
.03944 .02829 L
.04016 .02836 L
.04144 .0283 L
.04262 .028 L
.04384 .02746 L
.04514 .02672 L
.04748 .02528 L
.04891 .02433 L
.05026 .02325 L
.05278 .02054 L
.05395 .01926 L
.05504 .01828 L
.05618 .01752 L
.05742 .01694 L
.06004 .01605 L
.06244 .01523 L
.0631 .01503 L
.0638 .01486 L
.06506 .01472 L
.06576 .01474 L
.06641 .01483 L
.06713 .01501 L
.06791 .01531 L
.06922 .01606 L
.07061 .01718 L
.07179 .01841 L
.07308 .02003 L
.08278 .03613 L
.08824 .04677 L
.09124 .05131 L
.09407 .05541 L
.09536 .05699 L
.09671 .05837 L
.09742 .05895 L
.0982 .05949 L
.09892 .05988 L
.09958 .06016 L
.10082 .06047 L
.10151 .06052 L
.10216 .0605 L
Mistroke
.10332 .06028 L
.10458 .05986 L
.10714 .0588 L
.10849 .05822 L
.10991 .05752 L
.11116 .05667 L
.11252 .05541 L
.11492 .05274 L
.11613 .05161 L
.11727 .05079 L
.11858 .05007 L
.11977 .04952 L
.12192 .04854 L
.12306 .04806 L
.12429 .04767 L
.1256 .04749 L
.12683 .0476 L
.12751 .04777 L
.12823 .04804 L
.12952 .04876 L
.13072 .04969 L
.13183 .05077 L
.13435 .05391 L
.14528 .07232 L
.15034 .08185 L
.15301 .0863 L
.15583 .09036 L
.1583 .09286 L
.1597 .0939 L
.16101 .09468 L
.16331 .09567 L
.1646 .09606 L
.16577 .09636 L
.16693 .09665 L
.16815 .09701 L
.16919 .09742 L
.17035 .09804 L
.17158 .09896 L
.17291 .10025 L
.17532 .10327 L
.18437 .11441 L
.22548 .15722 L
.23058 .15838 L
.23308 .15921 L
.23418 .15956 L
.23539 .1599 L
.23668 .16017 L
.23739 .16027 L
.23805 .16033 L
.23878 .16035 L
Mistroke
.23944 .16034 L
.24021 .16031 L
.24094 .16026 L
.24219 .1602 L
.24335 .16024 L
.24463 .16047 L
.24534 .16069 L
.24598 .16097 L
.24718 .16169 L
.24845 .16275 L
.24952 .16392 L
.25071 .1655 L
.25582 .17411 L
.26057 .183 L
.26291 .18732 L
.26507 .19034 L
.26746 .19273 L
.27005 .19481 L
.27458 .19833 L
.27713 .20022 L
.27952 .20164 L
.28202 .20272 L
.28477 .20366 L
.28702 .2044 L
.28825 .20479 L
.28939 .2051 L
.29036 .2053 L
.29141 .20542 L
.29257 .20537 L
.29362 .20511 L
.29484 .20451 L
.29597 .20368 L
.29852 .20139 L
.30315 .19752 L
.3043 .19652 L
.30555 .19557 L
.30673 .19492 L
.30783 .19459 L
.3091 .19451 L
.30981 .19457 L
.31046 .19469 L
.31169 .19504 L
.31285 .19546 L
.32193 .19926 L
.33198 .20468 L
.34257 .21126 L
.34721 .21476 L
.34855 .21568 L
.34981 .21641 L
.35095 .21691 L
Mistroke
.35218 .21726 L
.35283 .21737 L
.35356 .21745 L
.35431 .21749 L
.35501 .2175 L
.35627 .21753 L
.35698 .21756 L
.35763 .21761 L
.35887 .21778 L
.36023 .21803 L
.36151 .21827 L
.36271 .21844 L
.36388 .21847 L
.36514 .21827 L
.36629 .21783 L
.36735 .21723 L
.3697 .21565 L
.37035 .21528 L
.37104 .21496 L
.37229 .21457 L
.37346 .2144 L
.37456 .21435 L
.37555 .21434 L
.37662 .21432 L
.37777 .21426 L
.379 .21416 L
.38004 .21407 L
.3812 .21403 L
.38241 .21415 L
.38354 .21445 L
.38478 .21502 L
.38548 .21545 L
.38611 .21591 L
.39128 .22076 L
.39357 .22306 L
.39604 .22592 L
.39838 .22956 L
.40053 .23385 L
.40577 .24379 L
.40832 .24831 L
.41066 .25192 L
.41192 .25344 L
.41312 .25458 L
.41439 .2555 L
.41577 .25622 L
.41651 .25649 L
.41718 .25667 L
.41795 .25682 L
.41868 .25692 L
.41998 .257 L
Mistroke
.4207 .25703 L
.42139 .25707 L
.42263 .25721 L
.42377 .25748 L
.42499 .25797 L
.42568 .25834 L
.42632 .25877 L
.42738 .25965 L
.42855 .26089 L
.43091 .26429 L
.43636 .27386 L
.44136 .28324 L
.44391 .28697 L
.44519 .28833 L
.44659 .28954 L
.45223 .2932 L
.46243 .30116 L
.50303 .34625 L
.5218 .36678 L
.5269 .37527 L
.52939 .37925 L
.53048 .38076 L
.53167 .38214 L
.5329 .38324 L
.53407 .38398 L
.53472 .38426 L
.53541 .38447 L
.53665 .38463 L
.53729 .38462 L
.53799 .38456 L
.53925 .38435 L
.54212 .38382 L
.54282 .38369 L
.54358 .38355 L
.54428 .38339 L
.54494 .38319 L
.54569 .3829 L
.54636 .38254 L
.54711 .38203 L
.54792 .38133 L
.55324 .37617 L
.55583 .37437 L
.55725 .37343 L
.55794 .37302 L
.55857 .3727 L
.5597 .37228 L
.56091 .3721 L
.56224 .37219 L
.56349 .37253 L
.56852 .37554 L
Mistroke
.57098 .37752 L
.57207 .37833 L
.57325 .3791 L
.57453 .37973 L
.57522 .37996 L
.57587 .38009 L
.57659 .38016 L
.57724 .38015 L
.57799 .38007 L
.57871 .37993 L
.57995 .37964 L
.58111 .37939 L
.58232 .37922 L
.58296 .37918 L
.58365 .37917 L
.58491 .37919 L
.58623 .3792 L
.58735 .37913 L
.58858 .37888 L
.58973 .37849 L
.59095 .37793 L
.59209 .37738 L
.59314 .37697 L
.59379 .3768 L
.59448 .3767 L
.59517 .37669 L
.59593 .37678 L
.59658 .37692 L
.59728 .37715 L
.59855 .37769 L
.6011 .37896 L
.60225 .37944 L
.60347 .37979 L
.6047 .37992 L
.60582 .37981 L
.60646 .37965 L
.60715 .37943 L
.6084 .37894 L
.60958 .37849 L
.61083 .37815 L
.6119 .37802 L
.61308 .37802 L
.61422 .37812 L
.61527 .37825 L
.61648 .37835 L
.61762 .37835 L
.61867 .37824 L
.61965 .37804 L
.6207 .37775 L
.62185 .37742 L
Mistroke
.6231 .37719 L
.62428 .37716 L
.62543 .37736 L
.6265 .37773 L
.62777 .37836 L
.62893 .37905 L
.63151 .38065 L
.6326 .38122 L
.63375 .38166 L
.63501 .38191 L
.63617 .38186 L
.63725 .38154 L
.63826 .38103 L
.64056 .37944 L
.64576 .3768 L
.64823 .37564 L
.64931 .37517 L
.65051 .37482 L
.65178 .37474 L
.65248 .37484 L
.65313 .37504 L
.65385 .37537 L
.65451 .37576 L
.65599 .37696 L
.66118 .38289 L
.70078 .43036 L
.72073 .45359 L
.72495 .45793 L
.72726 .46071 L
.72943 .46297 L
.73176 .46473 L
.733 .46542 L
.73434 .46608 L
.7365 .46717 L
.73886 .46878 L
.74026 .47013 L
.74156 .47173 L
.74413 .47594 L
.74894 .48444 L
.75129 .48829 L
.75384 .49247 L
.75501 .49418 L
.75625 .4957 L
.7573 .49673 L
.75846 .49757 L
.75915 .49794 L
.75979 .49819 L
.76052 .49839 L
.76121 .4985 L
.76244 .49855 L
Mistroke
.76313 .49851 L
.76378 .49845 L
.76498 .49833 L
.76611 .49823 L
.7673 .49818 L
.7686 .49815 L
.76992 .49809 L
.77058 .49802 L
.77131 .49787 L
.7726 .4974 L
.7738 .49665 L
.77522 .4954 L
.77651 .4941 L
.7794 .49135 L
.78191 .48901 L
.78314 .48787 L
.78426 .487 L
.78544 .48633 L
.7867 .48592 L
.78737 .48582 L
.78809 .48577 L
.7894 .48579 L
.79061 .48586 L
.79171 .48591 L
.79298 .48593 L
.79418 .4859 L
.79529 .48588 L
.79631 .4859 L
.79743 .48603 L
.79861 .48636 L
.79991 .48702 L
.80109 .48792 L
.80245 .48935 L
.80374 .49105 L
.80853 .49844 L
.81371 .50664 L
.81646 .5111 L
.818 .51303 L
.81941 .51434 L
.82064 .51517 L
.82198 .51583 L
.82324 .51629 L
.82441 .51666 L
.82558 .51704 L
.82668 .51748 L
.82795 .51816 L
.8291 .51899 L
.83035 .5202 L
.83167 .52183 L
.83404 .5255 L
Mistroke
.83938 .53355 L
.84362 .53974 L
.84596 .54297 L
.84711 .54422 L
.84817 .54514 L
.84942 .5459 L
.85008 .54619 L
.85078 .54641 L
.85191 .54663 L
.85316 .54674 L
.85782 .54709 L
.85905 .54726 L
.86037 .54742 L
.86161 .54746 L
.86273 .54735 L
.86401 .54698 L
.86521 .54636 L
.8665 .54544 L
.86791 .54429 L
.87232 .54036 L
.87465 .53781 L
.87594 .53662 L
.87716 .53582 L
.87784 .53551 L
.87859 .53526 L
.87989 .53496 L
.88243 .53447 L
.88514 .53379 L
.88591 .53363 L
.88665 .53353 L
.8873 .53349 L
.88801 .53351 L
.88933 .53375 L
.88999 .53398 L
.89072 .53431 L
.892 .53511 L
.8932 .53611 L
.89553 .53878 L
.89802 .54247 L
.90821 .56146 L
.91359 .56994 L
.91653 .57415 L
.91797 .57592 L
.91929 .57724 L
.92046 .57815 L
.92169 .57882 L
.92292 .57921 L
.92362 .57929 L
.92427 .57929 L
.92499 .5792 L
Mistroke
.92566 .57903 L
.92693 .57857 L
.92976 .57722 L
.9344 .57408 L
.93682 .57147 L
.93746 .57086 L
.93816 .57029 L
.93943 .5695 L
.94062 .56899 L
.94173 .56862 L
.94383 .568 L
.94486 .5677 L
.94582 .56744 L
.94683 .56726 L
.94794 .56721 L
.94908 .56738 L
.95029 .56784 L
.95131 .56847 L
.95244 .56943 L
.95365 .57078 L
.95495 .57255 L
.95729 .57621 L
.97619 .60332 L
Mfstroke
0 g
.02381 .02028 m
.02499 .02036 L
.02605 .02061 L
.02729 .02111 L
.02846 .02176 L
.03279 .02494 L
.03507 .0265 L
.03633 .0272 L
.0375 .02773 L
.03877 .02815 L
.03944 .02829 L
.04016 .02836 L
.04144 .0283 L
.04262 .028 L
.04384 .02746 L
.04514 .02672 L
.04748 .02528 L
.04891 .02433 L
.05026 .02325 L
.05278 .02054 L
.05395 .01926 L
.05504 .01828 L
.05618 .01752 L
.05742 .01694 L
.06004 .01605 L
.06244 .01523 L
.0631 .01503 L
.0638 .01486 L
.06506 .01472 L
.06576 .01474 L
.06641 .01483 L
.06713 .01501 L
.06791 .01531 L
.06922 .01606 L
.07061 .01718 L
.07179 .01841 L
.07308 .02003 L
.08278 .03613 L
.08824 .04677 L
.09124 .05131 L
.09407 .05541 L
.09536 .05699 L
.09671 .05837 L
.09742 .05895 L
.0982 .05949 L
.09892 .05988 L
.09958 .06016 L
.10082 .06047 L
.10151 .06052 L
.10216 .0605 L
Mistroke
.10332 .06028 L
.10458 .05986 L
.10714 .05879 L
.10849 .05822 L
.10991 .05752 L
.11116 .05667 L
.11252 .05541 L
.11492 .05274 L
.11613 .05161 L
.11727 .05079 L
.11858 .05007 L
.11977 .04952 L
.12192 .04854 L
.12306 .04806 L
.12429 .04767 L
.1256 .0475 L
.12683 .0476 L
.12751 .04777 L
.12823 .04805 L
.12952 .04876 L
.13072 .04969 L
.13183 .05077 L
.13435 .05391 L
.14528 .07233 L
.15034 .08185 L
.15301 .08631 L
.15583 .09036 L
.1583 .09286 L
.1597 .0939 L
.16101 .09467 L
.16219 .09523 L
.16331 .09565 L
.1646 .09604 L
.16577 .09633 L
.16693 .09661 L
.16802 .09692 L
.16915 .09736 L
.1704 .09803 L
.17147 .09882 L
.17246 .09972 L
.17468 .10237 L
.18437 .1145 L
.20488 .13566 L
.21002 .14313 L
.21487 .14938 L
.21699 .15223 L
.21815 .1536 L
.21924 .15466 L
.22041 .15555 L
.2217 .15624 L
Mistroke
.22279 .15661 L
.22397 .15686 L
.22519 .15701 L
.22632 .15713 L
.2289 .15748 L
.23016 .1577 L
.23135 .1579 L
.23242 .15803 L
.23358 .15805 L
.23466 .15792 L
.2358 .15757 L
.23677 .15709 L
.23783 .15637 L
.24237 .15266 L
.24489 .15013 L
.24613 .14876 L
.24728 .14764 L
.2486 .14668 L
.2493 .14632 L
.25004 .14604 L
.25123 .14573 L
.25255 .14549 L
.2549 .14501 L
.25614 .14471 L
.25745 .14442 L
.25859 .14428 L
.25984 .14432 L
.26098 .14457 L
.26204 .14499 L
.26332 .14576 L
.26467 .14691 L
.26583 .14816 L
.2671 .14983 L
.27258 .15863 L
.27737 .1681 L
.28252 .17691 L
.28754 .18342 L
.28869 .18479 L
.28992 .18605 L
.29108 .18699 L
.29212 .18761 L
.29326 .18801 L
.29433 .18811 L
.29549 .18795 L
.29673 .18751 L
.30111 .18538 L
.30572 .18233 L
.30704 .18129 L
.3083 .18055 L
.30942 .18016 L
Mistroke
.31065 .18005 L
.3113 .1801 L
.31201 .18023 L
.31276 .18044 L
.31346 .18068 L
.31606 .18176 L
.3211 .18332 L
.33126 .1867 L
.33265 .18743 L
.33339 .18777 L
.33418 .18809 L
.33494 .18834 L
.33562 .1885 L
.33631 .18859 L
.33696 .18861 L
.33827 .18838 L
.33947 .18783 L
.34079 .1869 L
.34218 .18573 L
.34705 .18205 L
.34944 .18022 L
.35049 .17954 L
.35166 .17902 L
.35289 .17879 L
.3542 .17889 L
.35489 .17907 L
.35563 .17935 L
.35697 .18006 L
.35949 .18189 L
.36181 .18377 L
.36288 .18456 L
.36402 .18526 L
.3651 .18574 L
.36608 .18599 L
.36723 .18605 L
.36847 .18583 L
.36965 .18543 L
.37074 .18499 L
.37179 .18459 L
.37291 .18425 L
.37415 .184 L
.37531 .18383 L
.3766 .18366 L
.37783 .1834 L
.37894 .18307 L
.38014 .1826 L
.38139 .18209 L
.3827 .18168 L
.38339 .18157 L
.38414 .18155 L
Mistroke
.38483 .18163 L
.38547 .18179 L
.38674 .18232 L
.38789 .18302 L
.39048 .18501 L
.39279 .18679 L
.394 .18756 L
.39529 .18817 L
.39642 .1885 L
.39766 .18858 L
.39879 .18837 L
.39985 .18792 L
.40107 .18714 L
.40242 .18612 L
.40512 .18416 L
.40765 .18234 L
.40995 .18052 L
.41062 .18006 L
.41135 .17965 L
.41204 .17936 L
.41268 .17919 L
.41335 .1791 L
.41409 .17912 L
.41486 .17925 L
.41559 .17946 L
.41691 .18003 L
.41812 .18071 L
.42083 .18255 L
.42202 .18334 L
.4233 .18409 L
.42451 .18462 L
.42562 .18492 L
.4268 .18502 L
.42804 .18493 L
.42932 .18471 L
.43004 .18457 L
.43072 .18446 L
.43192 .18434 L
.43301 .18434 L
.43419 .18445 L
.43546 .18463 L
.43658 .18477 L
.43776 .18483 L
.43877 .18476 L
.43988 .18452 L
.44054 .18429 L
.44126 .18398 L
.44258 .18333 L
.44387 .18275 L
.44504 .18241 L
Mistroke
.44576 .18232 L
.44644 .18231 L
.44715 .18237 L
.44792 .18252 L
.4486 .18271 L
.44931 .18293 L
.45059 .18338 L
.45179 .18378 L
.45307 .18409 L
.45428 .18421 L
.45538 .18416 L
.45667 .18392 L
.45807 .18357 L
.45872 .18343 L
.4594 .18331 L
.46063 .18323 L
.46177 .18335 L
.46301 .18365 L
.46431 .18412 L
.46552 .18461 L
.46663 .18505 L
.46769 .18538 L
.4689 .1856 L
.47 .18559 L
.47123 .18533 L
.47253 .18479 L
.47485 .18358 L
.47614 .18309 L
.47735 .18284 L
.47805 .18278 L
.47868 .18276 L
.47941 .18277 L
.48011 .1828 L
.48126 .18284 L
.4823 .18283 L
.48351 .18272 L
.48465 .18254 L
.48563 .18236 L
.48667 .18221 L
.48781 .18215 L
.48885 .18226 L
.48999 .18259 L
.49121 .18317 L
.49236 .18391 L
.4934 .1847 L
.49839 .18871 L
.53829 .22437 L
.55655 .24329 L
.55912 .24706 L
.56156 .25055 L
Mistroke
.5629 .2521 L
.56361 .25276 L
.56437 .25336 L
.56507 .2538 L
.5657 .25412 L
.56694 .25456 L
.5682 .25481 L
.56935 .25494 L
.57059 .25505 L
.57125 .25512 L
.57196 .25521 L
.57314 .25542 L
.57425 .25568 L
.57668 .25637 L
.57792 .25672 L
.57923 .25703 L
.57991 .25715 L
.58067 .25725 L
.58136 .25729 L
.582 .25728 L
.58327 .25718 L
.58443 .25699 L
.58508 .25687 L
.58578 .25674 L
.58705 .25659 L
.5882 .25656 L
.58924 .25665 L
.59048 .2569 L
.59165 .25726 L
.59398 .25823 L
.5965 .25954 L
.60651 .26493 L
.61182 .26684 L
.61474 .2681 L
.61619 .26874 L
.61752 .26929 L
.61876 .2697 L
.62009 .26999 L
.62084 .27005 L
.62155 .27002 L
.62219 .26991 L
.62288 .2697 L
.62412 .26904 L
.62543 .26804 L
.62778 .26599 L
.63242 .26231 L
.63375 .26122 L
.63501 .26037 L
.63615 .25987 L
.63738 .25964 L
Mistroke
.63869 .25972 L
.63935 .25986 L
.64008 .26009 L
.64136 .26064 L
.64257 .26128 L
.64493 .26272 L
.64741 .26416 L
.64873 .26476 L
.64948 .26502 L
.65018 .26521 L
.6514 .26542 L
.65271 .26553 L
.65345 .26556 L
.65425 .2656 L
.65501 .26566 L
.6557 .26575 L
.65702 .266 L
.65769 .26617 L
.65842 .26639 L
.66093 .26721 L
.66165 .26741 L
.66233 .26757 L
.6636 .2677 L
.66433 .26767 L
.66501 .26755 L
.66575 .26731 L
.66653 .26693 L
.66783 .26609 L
.66925 .26506 L
.67057 .26422 L
.67182 .26365 L
.67251 .26342 L
.67325 .26322 L
.67456 .26294 L
.67692 .26241 L
.67817 .2621 L
.67886 .26195 L
.67952 .26185 L
.68083 .26181 L
.68203 .26204 L
.68315 .26252 L
.68438 .26333 L
.68567 .26447 L
.68705 .26593 L
.68954 .26883 L
.69879 .2834 L
.70382 .29195 L
.70648 .29585 L
.70792 .29786 L
.70928 .2995 L
Mistroke
.71046 .30066 L
.71173 .30157 L
.71245 .30193 L
.71314 .30215 L
.71442 .30231 L
.7156 .30216 L
.71669 .30185 L
.71916 .30087 L
.7214 .29991 L
.72349 .29868 L
.72454 .29781 L
.72567 .29674 L
.72681 .29565 L
.72805 .29467 L
.72875 .29425 L
.7294 .29396 L
.73067 .29359 L
.73183 .29345 L
.73305 .29338 L
.73418 .29336 L
.73523 .29334 L
.73639 .29332 L
.73764 .29337 L
.73887 .29355 L
.73957 .29374 L
.74022 .29398 L
.7414 .29462 L
.74267 .29559 L
.74508 .29811 L
.74726 .30075 L
.7563 .31346 L
.759 .31805 L
.76152 .32119 L
.76415 .3237 L
.76703 .32638 L
.76969 .32906 L
.7722 .33139 L
.77329 .33221 L
.77445 .33292 L
.77572 .33351 L
.7769 .33393 L
.78133 .33515 L
.78257 .33549 L
.78388 .33584 L
.78499 .33608 L
.78621 .33625 L
.78749 .33624 L
.78869 .33599 L
.78998 .33542 L
.7907 .33497 L
Mistroke
.79136 .3345 L
.79618 .33051 L
.79868 .32797 L
.80005 .32655 L
.80133 .32549 L
.802 .32508 L
.80271 .32474 L
.8035 .32448 L
.80423 .32432 L
.80489 .32421 L
.8056 .32412 L
.8069 .32398 L
.80945 .3236 L
.81073 .32341 L
.81146 .32335 L
.81215 .32334 L
.81337 .32347 L
.81449 .32383 L
.81572 .32449 L
.81701 .32554 L
.85508 .36803 L
.85762 .36946 L
.86032 .37149 L
.86172 .37291 L
.86327 .37491 L
.866 .37954 L
.87096 .38898 L
.8737 .39455 L
.87631 .39924 L
.8788 .40245 L
.88151 .40514 L
.88627 .4095 L
.88862 .41133 L
.88993 .41207 L
.89111 .41252 L
.89223 .41276 L
.89343 .41286 L
.89456 .41286 L
.89561 .41284 L
.89679 .41283 L
.89787 .41287 L
.89911 .41296 L
.90029 .41303 L
.90137 .41303 L
.90238 .41292 L
.90348 .41263 L
.90465 .41209 L
.90693 .41056 L
.90812 .40979 L
.90937 .4092 L
Mistroke
.91004 .409 L
.91077 .40887 L
.91206 .4088 L
.91337 .40887 L
.91458 .40897 L
.91583 .40904 L
.91654 .40906 L
.91719 .40906 L
.91839 .40904 L
.91966 .40905 L
.92079 .40916 L
.92185 .4094 L
.92302 .40985 L
.92427 .41054 L
.92704 .41272 L
.92968 .41511 L
.93462 .41986 L
.94417 .43685 L
.94645 .44124 L
.94885 .44564 L
.9509 .44861 L
.95315 .45096 L
.95573 .45293 L
.95813 .45446 L
.9635 .45788 L
.97288 .46367 L
.97619 .46535 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Hoooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0fooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo001Voooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03_ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hoooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
=?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool006Oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100>?ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0<oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01Wooooo001Voooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
>?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0dooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000006Oooool006?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000g
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000006Oooool006?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03Sooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Gooooo`00Hooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0=?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool0023ooooo00?o0000ooooooooool0
@?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0iooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
0omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Wooooo000Pooooo`03o`000?oooooooooo0?ooooooA_ooool0023ooooo
00?o0000ooooooooool0oooooom6ooooo`008?ooool00ol0003oooooooooo`3oooooocOooooo00Go
V9RHo`000?l0003oA4A4okZj^P0:ooooo`008?ooool00ol0003oooooooooo`09ooooo`;o0000oooo
ool/ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002_ooool0023ooooo00?o0000ooooooooool01_oo
ool3o`0000;ooooo0_l0003oooooob[ooooo00?o0000ooooooooool03?ooool001Woooooool0000e
o`0000cooooo00?o0000ooooooooool03?ooool0023ooooo00Co0000oooooooooooo00000oooool2
o`0000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo00Co00002Oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo00oooooo00?o410@o`000?l000000ol0000;ooooo`008?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo9_ooool00ol0003oooooooooo`0<ooooo`00
8?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo9_ooool00ol0003ooooo
ooooo`0<ooooo`008?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo=?oo
ool0023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3oooooocCooooo000Poooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0oooooolcooooo`008?ooool2o`0001;o
oooo00?o0000ooooooooool01oooool3o`000?oooooo:?ooool0023ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`04ooooo`?o000000?oooooo`000?l00000oooooolWooooo`008?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3oooooobCooooo000Pooooo`03o`000?oooooooooo01;ooooo0_l00003
ooooo`;o00001_ooool00ol0003oooooooooo`3oooooobCooooo000Pooooo`03o`000?oooooooooo
01?ooooo1Ol00008ooooo`03o`000?oooooooooo0?oooooo8oooool0023ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`3oooooob?ooooo000Pooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0oooooolRooooo`008?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo0?oooooo8_ooool0023ooooo0_l0000Sooooo`03o`000?oooooooooo0?oooooo8Oooool0
023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3oooooob7ooooo000Pooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0oooooolPooooo`008?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo0?oooooo7oooool0023ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`3ooooooakooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0oooooolNooooo`008?ooool00ol0003oooooooooo`0Vooooo`;o0000oooooolNoooo
o`008?ooool00ol0003oooooooooo`0Wooooo`?o0000oooooolLooooo`008?ooool2o`0002_ooooo
0_l0003ooooooa[ooooo000Pooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0oooo
oolHooooo`008?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo6?ooool0
023ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`3ooooooaOooooo000Pooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0oooooolFooooo`008?ooool00ol0003ooooo
ooooo`0^ooooo`;o0000oooooolFooooo`008?ooool00ol0003oooooooooo`0_ooooo`03ool00?l0
003ooooo0?oooooo5?ooool0023ooooo00?o0000ooooooooool0<?ooool00ooo003o0000ooooo`3o
oooooa?ooooo000Pooooo`;o0000<_ooool00ooo003o0000ooooo`3ooooooa;ooooo000Pooooo`03
o`000?oooooooooo03;ooooo00?oo`00o`000?ooool0oooooolAooooo`008?ooool00ol0003ooooo
ooooo`0cooooo`03ool00?l0003ooooo0?oooooo4?ooool0023ooooo00?o0000ooooooooool0=?oo
ool00ooo003o0000ooooo`3oooooo`oooooo000Pooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0ooooool>ooooo`003_ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0oooo
ool=ooooo`004Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo03Kooooo00?o0000ool00?ooool02_ooool5o`000?gooooo000Booooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`0gooooo`03
o`000?oo003ooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo0?_ooooo000Aooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`04ooooo`?o0000>?ooool00ol0003o
o`00ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0n_ooool000kooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oo003ooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3jooooo`003_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool00ol0003oooooooooo`0jooooo`Ko00002Oooool00ol0003oooooooooo`3ioooo
o`003_ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`0mooooo`Koo`001_ooool00ol0003oooooooooo`3iooooo`003_ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo04;ooooo00?oo`00oooo
ooooool01Oooool00ol0003oooooooooo`3hooooo`008?ooool00ol0003oooooooooo`13ooooo`03
ool00?oooooooooo00Gooooo00?o0000ooooooooool0moooool0023ooooo00?o0000ooooooooool0
@oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo0?Oooooo000Pooooo`03o`000?oo
oooooooo04Cooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`3fooooo`008?ooool2
o`0004Gooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`3fooooo`008?ooool00ol0
003oooooooooo`15ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01?ooool3o`00
00[ooooo0ol00008ooooo`03o`000?oooooooooo00Gooooo0ol0003>ooooo`008?ooool00ol0003o
ooooooooo`16ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0000;o
oooo1?l00005ooooo`04o`000?ooooooooooooooo`;o00000_ooool6o`0000Cooooo0_l00003oooo
o`oo000000?oooooo`000?l000001Ol0002gooooo`008?ooool00ol0003oooooooooo`16ooooo`03
ool00?oooooooooo00Kooooo1?l00008ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Go
oooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0ol00006ooooo`03
o`000?oooooooooo0;Cooooo000Pooooo`03o`000?oooooooooo04Oooooo00?oo`00ooooooooool0
4oooool2o`00017ooooo00?o0000ooooooooool07?ooool2o`000;Cooooo000Pooooo`03o`000?oo
oooooooo04Sooooo00?oo`00ooooooooool02Oooool2ool003_ooooo00?o0000ooooooooool0/Ooo
ool0023ooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`07ooooo`Koo`00>Oooool0
0ol0003oooooooooo`2`ooooo`008?ooool00ol0003oooooooooo`1:ooooo`;oo`001_ooool00ooo
003oooooooooo`04ooooo`;oo`00>?ooool00ol0003oooooooooo`2_ooooo`008?ooool2o`0004go
oooo0ooo0002ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0=_ooool00ol0003o
ooooooooo`2^ooooo`008?ooool00ol0003oooooooooo`1>ooooo`?oo`002oooool2ool003Oooooo
00?o0000ooooooooool0[Oooool0023ooooo00?o0000ooooooooool0G_ooool00ooo003ooooooooo
o`0eooooo`03o`000?oooooooooo0:cooooo000Pooooo`03o`000?oooooooooo05oooooo00?oo`00
ooooooooool02?ooool2ool002_ooooo00?o0000ooooooooool0Zoooool0023ooooo00?o0000oooo
ooooool0H?ooool3ool000Cooooo1?oo00000oooooooo`00ooooo`0Zooooo`03o`000?oooooooooo
0:[ooooo000Pooooo`03o`000?oooooooooo06;ooooo1Ooo0006ooooo`03ool00?oooooooooo02Wo
oooo00?o0000ooooooooool0ZOooool0023ooooo00?o0000ooooooooool0K_ooool2ool002[ooooo
00?o0000ooooooooool0Z?ooool0023ooooo00?o0000ooooooooool0Koooool00ooo003ooooooooo
o`0Yooooo`;o0000Z?ooool0023ooooo0_l0001aooooo`03ool00?oooooooooo02[ooooo00?o0000
ooooooooool0YOooool0023ooooo00?o0000ooooooooool0L?ooool00ooo003oooooooooo`0[oooo
o`03o`000?oooooooooo0:Cooooo000Pooooo`03o`000?oooooooooo077ooooo00?oo`00oooooooo
ool0:oooool00ol0003oooooooooo`2Sooooo`008?ooool00ol0003oooooooooo`1aooooo`03ool0
0?oooooooooo02cooooo00?o0000ooooooooool0X_ooool0023ooooo00?o0000ooooooooool0L_oo
ool00ooo003oooooooooo`0/ooooo`03o`000?oooooooooo0:7ooooo000Pooooo`03o`000?oooooo
oooo07;ooooo00?oo`00ooooooooool0;?ooool00ol0003oooooooooo`2Qooooo`008?ooool00ol0
003oooooooooo`1cooooo`03ool00?oooooooooo02cooooo00?o0000ooooooooool0X?ooool0023o
oooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`0[ooooo`;o0000XOooool0023ooooo
0_l0001eooooo`;oo`00;Oooool5o`0009gooooo000Pooooo`03o`000?oooooooooo07Kooooo1?oo
000]ooooo`So00002oooool00ol0003oooooooooo`28ooooo`008?ooool00ol0003oooooooooo`1i
ooooo`03ool00?oooooooooo03?ooooo00?o0000ooooooooool01_ooool5o`0000Wooooo0ol0001l
ooooo`008?ooool00ol0003oooooooooo`1jooooo`03ool00?oooooooooo03?ooooo0_l00005oooo
o`03o`000?oooooooooo00?ooooo1?l00002ooooo`?o00000_ooool2o`0007_ooooo000Pooooo`03
o`000?oooooooooo07[ooooo00?oo`00ooooooooool0=Oooool3o`000003ooooool0003ooooo00So
oooo1?l00006ooooo`03o`000?oooooooooo07Sooooo0006ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo07_ooooo00?oo`00ooooooooool0=_ooool2o`0001Cooooo00?o0000ooooooooool0N?oo
ool000Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool0
C?ooool00ol0003oooooooooo`1gooooo`002?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool0O?ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo0008ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`0007gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`1foooo
o`002?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0OOooool00ooo003oooooooooo`1=
ooooo`03o`000?oooooooooo07Gooooo0008ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`1nooooo`;oo`00COooool00ol0003oooooooooo`1eooooo`002?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0Ooooool2ool004gooooo00?o0000ooooooooool0M?ooool000Kooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo087ooooo0_oo001;ooooo`03o`000?oooooooooo00Go
oooo1Ol0001Zooooo`008?ooool00ol0003oooooooooo`23ooooo`03ool00?oooooooooo04Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o0000JOooool0023ooooo00?o
0000ooooooooool0Q?ooool00ooo003oooooooooo`19ooooo`Go00001oooool00ol0003ooooooooo
o`1Vooooo`008?ooool00ol0003oooooooooo`24ooooo`03ool00?oooooooooo04[ooooo0_l00009
ooooo`03o`000?oooooooooo06Kooooo000Pooooo`;o0000Q_ooool00ooo003oooooooooo`1Eoooo
o`03o`000?oooooooooo06Gooooo000Pooooo`03o`000?oooooooooo08Kooooo00?oo`00oooooooo
ool0E?ooool00ol0003oooooooooo`1Uooooo`008?ooool00ol0003oooooooooo`27ooooo`03ool0
0?oooooooooo05Cooooo00?o0000ooooooooool0I?ooool0023ooooo00?o0000ooooooooool0R?oo
ool00ooo003oooooooooo`1Dooooo`03o`000?oooooooooo06?ooooo000Pooooo`03o`000?oooooo
oooo08Wooooo00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`1Rooooo`008?ooool00ol0
003oooooooooo`2:ooooo`03ool00?oooooooooo05Cooooo00?o0000ooooooooool02Oooool5o`00
05?ooooo000Pooooo`03o`000?oooooooooo08[ooooo00?oo`00ooooooooool0EOooool00ol0003o
ooooooooo`07ooooo`;o00000oooool00ol0003oooooooooo`1Aooooo`008?ooool00ol0003ooooo
ooooo`2;ooooo`03ool00?oooooooooo05Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo057ooooo000Pooooo`;o0000SOooool00ooo003ooooooooo
o`1Dooooo`?o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo000P
ooooo`03o`000?oooooooooo08gooooo00?oo`00ooooooooool0E_ooool4o`0000Wooooo00?o0000
ooooooooool0Coooool0023ooooo00?o0000ooooooooool0S_ooool00ooo003oooooooooo`1Soooo
o`03o`000?oooooooooo04kooooo000Pooooo`03o`000?oooooooooo08oooooo00?oo`00oooooooo
ool0Hoooool00ol0003oooooooooo`1=ooooo`008?ooool00ol0003oooooooooo`2@ooooo`03ool0
0?oooooooooo06?ooooo00?o0000ooooooooool0C?ooool0023ooooo00?o0000ooooooooool0TOoo
ool00ooo003oooooooooo`1Sooooo`03o`000?oooooooooo04_ooooo000Pooooo`03o`000?oooooo
oooo09;ooooo00?oo`00ooooooooool0Hoooool00ol0003oooooooooo`1:ooooo`008?ooool00ol0
003oooooooooo`2Cooooo`03ool00?oooooooooo06?ooooo00?o0000ooooooooool0BOooool0023o
oooo0_l0002Eooooo`03ool00?oooooooooo06?ooooo00?o0000ooooooooool0B?ooool0023ooooo
00?o0000ooooooooool0UOooool00ooo003oooooooooo`1Sooooo`03o`000?oooooooooo04Oooooo
000Pooooo`03o`000?oooooooooo09Kooooo00?oo`00ooooooooool0Hoooool00ol0003ooooooooo
o`16ooooo`008?ooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo06Cooooo00?o0000
ooooooooool0AOooool0023ooooo00?o0000ooooooooool0Uoooool00ooo003oooooooooo`07oooo
o`Coo`00FOooool2o`0004Gooooo000Pooooo`03o`000?oooooooooo09Sooooo00?oo`00oooooooo
ool01Oooool2ool000?ooooo00?oo`00ooooooooool05Oooool3ool003oooooo00?o0000oooooooo
ool0@oooool0023ooooo00?o0000ooooooooool0V?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo0_oo00000oooooooo`00ool0000>ool000?ooooo0_oo0002ooooo`;oo`00
?oooool00ol0003oooooooooo`12ooooo`008?ooool2o`0009[ooooo00Coo`00oooooooooooooooo
0_oo0008ooooo`;oo`001oooool00ooo003oooooooooo`05ooooo`?oo`001_ooool00ooo003ooooo
ooooo`0looooo`03o`000?oooooooooo04;ooooo000Pooooo`03o`000?oooooooooo09[ooooo1?oo
000Sooooo`03ool00?oooooooooo03gooooo00?o0000ooooooooool0@Oooool0023ooooo00?o0000
ooooooooool0`_ooool00ooo003oooooooooo`0mooooo`03o`000?oooooooooo043ooooo000Poooo
o`03o`000?oooooooooo0<?ooooo00?oo`00ooooooooool0??ooool00ol0003oooooooooo`10oooo
o`008?ooool00ol0003oooooooooo`34ooooo`03ool00?oooooooooo03_ooooo00?o0000oooooooo
ool0@?ooool0023ooooo00?o0000ooooooooool0aOooool00ooo003oooooooooo`0kooooo`03o`00
0?oooooooooo03oooooo0006ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b
<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0aOooool0
0ooo003oooooooooo`0looooo`03o`000?oooooooooo03kooooo0008ooooo`03o`000?oooooooooo
00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`36ooooo`03ool00?oooooooooo03cooooo00?o0000ooooooooool0?Oooool000Sooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Cooooo
0ol00037ooooo`03ool00?oooooooooo03_ooooo00?o0000ooooooooool01_ooool4o`0003?ooooo
0008ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0b?ooool00ooo003oooooooooo`0kooooo`;o0000
1?ooool2o`0000?ooooo0_l0000booooo`002?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0bOooool00ooo003oooooooooo`0looooo`Go00001_ooool2o`00033ooooo0008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool0bOooool00ooo003oooooooooo`18ooooo`03o`000?oooooooooo02ko
oooo0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0b_ooool00ooo003oooooooooo`18ooooo`03
o`000?oooooooooo02gooooo0006ooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3;ooooo`03ool00?oooooooooo04Oo
oooo00?o0000ooooooooool0;Oooool0023ooooo00?o0000ooooooooool0c?ooool00ooo003ooooo
ooooo`17ooooo`03o`000?oooooooooo02cooooo000Pooooo`03o`000?oooooooooo0<gooooo00?o
o`00ooooooooool0Aoooool00ol0003oooooooooo`0[ooooo`008?ooool2o`000<kooooo00?oo`00
ooooooooool0Aoooool00ol0003oooooooooo`0[ooooo`008?ooool00ol0003oooooooooo`3>oooo
o`03ool00?oooooooooo04Oooooo00?o0000ooooooooool0:_ooool0023ooooo00?o0000oooooooo
ool0coooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo02Wooooo000Pooooo`03o`00
0?oooooooooo0=3ooooo00?oo`00ooooooooool0A_ooool00ol0003oooooooooo`0Yooooo`008?oo
ool00ol0003oooooooooo`3Aooooo`03ool00?oooooooooo04Kooooo00?o0000ooooooooool0:?oo
ool0023ooooo00?o0000ooooooooool0d_ooool00ooo003oooooooooo`15ooooo`;o0000:Oooool0
023ooooo00?o0000ooooooooool0doooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo
02Kooooo000Pooooo`03o`000?oooooooooo0=Cooooo00?oo`00ooooooooool0A_ooool00ol0003o
ooooooooo`0Uooooo`008?ooool2o`000=Kooooo00?oo`00ooooooooool0A_ooool3o`0002Cooooo
000Pooooo`03o`000?oooooooooo0=Kooooo00?oo`00ooooooooool0B?ooool00ol0003ooooooooo
o`0Qooooo`008?ooool00ol0003oooooooooo`3Gooooo`;oo`00BOooool00ol0003oooooooooo`0P
ooooo`008?ooool00ol0003oooooooooo`3Iooooo`03ool00?oooooooooo06Wooooo000Pooooo`03
o`000?oooooooooo0=[ooooo00?oo`00ooooooooool0J?ooool0023ooooo00?o0000ooooooooool0
foooool00ooo003oooooooooo`1Wooooo`008?ooool00ol0003oooooooooo`3Kooooo`03ool00?oo
oooooooo06Oooooo000Pooooo`03o`000?oooooooooo0=cooooo00?oo`00ooooooooool0I_ooool0
023ooooo0_l0003Mooooo`03ool00?oooooooooo00Sooooo1_oo001Hooooo`008?ooool00ol0003o
ooooooooo`3Mooooo`03ool00?oooooooooo00Kooooo0_oo0004ooooo`;oo`00Eoooool0023ooooo
00?o0000ooooooooool0g_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0EOooool0023ooooo00?o0000ooooooooool0g_ooool2ool000Cooooo0_oo
0007ooooo`03ool00?oooooooooo05Gooooo000Pooooo`03o`000?oooooooooo0=oooooo1Ooo000:
ooooo`03ool00?oooooooooo05Cooooo000Pooooo`03o`000?oooooooooo0>kooooo00?oo`00oooo
ooooool0E?ooool0023ooooo00?o0000ooooooooool0koooool00ooo003oooooooooo`1Cooooo`00
8?ooool00ol0003oooooooooo`3`ooooo`03ool00?oooooooooo05;ooooo000Pooooo`;o0000l_oo
ool00ooo003oooooooooo`1Aooooo`008?ooool00ol0003oooooooooo`3booooo`;oo`00DOooool0
023ooooo00?o0000ooooooooool0loooool3ool004oooooo000Pooooo`03o`000?oooooooooo0?Go
oooo00?oo`00ooooooooool0COooool0023ooooo00?o0000ooooooooool0m_ooool00ooo003ooooo
ooooo`1<ooooo`008?ooool00ol0003oooooooooo`3fooooo`03ool00?oooooooooo04cooooo0005
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?Oooooo00?oo`00ooooooooool0Boooool000Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0n?ooool00ooo003oooooooooo`08oooo
o`Koo`00??ooool000Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000n?ooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo00;ooooo0_oo000kooooo`001oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0nOooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool0>Oooool000Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?[ooooo
0_oo0004ooooo`;oo`002?ooool00ooo003oooooooooo`0hooooo`002Oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0noooool6ool000Wooooo00?oo`00ooooooooool0>?ooool000Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0ooooool<ooooo`03ool00?oooooo
oooo03Oooooo0005ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo
3Oooool00ooo003oooooooooo`0fooooo`008?ooool00ol0003oooooooooo`3oooooo`gooooo00?o
o`00ooooooooool0=_ooool0023ooooo00?o0000ooooooooool0ooooool>ooooo`03ool00?oooooo
oooo03Gooooo000Pooooo`;o0000ooooool?ooooo`03ool00?oooooooooo03Gooooo000Pooooo`03
o`000?oooooooooo0?oooooo3oooool00ooo003oooooooooo`07ooooo`?oo`00:_ooool0023ooooo
00?o0000ooooooooool0ooooool@ooooo`03ool00?oooooooooo00Cooooo0_oo0002ooooo`;oo`00
:Oooool0023ooooo00?o0000ooooooooool0oooooolAooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0Wooooo`008?ooool00ol0003oooooooooo`3o
oooooa7ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo02Kooooo000P
ooooo`03o`000?oooooooooo0?oooooo4_ooool3ool000Sooooo00?oo`00ooooooooool09_ooool0
023ooooo00?o0000ooooooooool0oooooolNooooo`03ool00?oooooooooo02Gooooo000Pooooo`03
o`000?oooooooooo0?oooooo7oooool00ooo003oooooooooo`0Tooooo`008?ooool2o`000?oooooo
8Oooool00ooo003oooooooooo`0Sooooo`008?ooool00ol0003oooooooooo`3oooooob3ooooo00?o
o`00ooooooooool08oooool0023ooooo00?o0000ooooooooool0oooooolQooooo`03ool00?oooooo
oooo02;ooooo000Pooooo`03o`000?oooooooooo0?oooooo8_ooool00ooo003oooooooooo`0Qoooo
o`008?ooool00ol0003oooooooooo`3oooooob?ooooo00?oo`00ooooooooool08?ooool0023ooooo
00?o0000ooooooooool0oooooom6ooooo`008?ooool00ol0003oooooooooo`3oooooodKooooo000P
ooooo`03o`000?oooooooooo0?ooooooA_ooool0023ooooo0_l0003oooooodOooooo000Pooooo`03
o`000?oooooooooo0?ooooooA_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001gooooo00Kok^k^oc8b<_l0003o0000
oeEEEOo^k^koooooodKooooo000Mooooo`07oeEEEOmgMgOoooooonk^k_n7QhOo8B4Qonk^kP3ooooo
odGooooo000Mooooo`03o`000?oooooooooo00;ooooo00?oQhN7ogMgMoooool0oooooom4ooooo`00
7Oooool00ol0003oooooooooo`03ooooo`03ob4Q8Ooooooooooo0?oooooo@oooool001gooooo00?o
8B4Qo`000?l000001?l0003oooooodGooooo000Mooooo`03oiRHV?n7QhOooooo00?ooooo00?o0000
ooooooooool0oooooom3ooooo`007_ooool01_lb<S;oQhN7onk^k_ooooooQhN7oc8b<_ooooooAOoo
ool001kooooo00Kok^k^ogMgMol0003o0000oc8b<_o<c<coooooodGooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-22.071, -18.9977, 0.85287, \
1.5729}}],

Cell["\<\
Fig. 1.9 Two trajectories starting from the same initial \
conditions. The upper trajectory is integrated with higher accuracy than the \
lower trajectory.\
\>", "Caption",
  CellTags->"Fig. 1.9"],

Cell[TextData[{
  "\tIf we repeat this trajectory , but increase the accuracy by setting ",
  StyleBox["AccuracyGoal->13",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and",
  StyleBox[" PrecisionGoal->13",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the results for the two trajectories at late times bear little or no \
resemblance to one-another (Fig. ",
  ButtonBox["1.9",
    ButtonData:>"Fig. 1.9",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[{
  "\tThe difference ",
  StyleBox["\[CapitalDelta]\[Theta]",
    FontFamily->"Symbol"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "between the two \[Theta](",
  StyleBox["t",
    FontSlant->"Italic"],
  ") results is shown in Fig. ",
  ButtonBox["1.10",
    ButtonData:>"Fig. 1.10",
    ButtonStyle->"Hyperlink"],
  ". The error is exploding with time, as opposed to the relatively gentle \
increase observed in our previous examples.  The explosive growth of \
accumulated error is a general feature of chaotic systems. In fact, one can \
show that if one compares a given trajectory with groups of nearby \
trajectories , on average the difference between these trajectories increases \
",
  StyleBox["exponentially ",
    FontSlant->"Italic"],
  " with time: |",
  StyleBox["\[CapitalDelta]\[Theta]",
    FontFamily->"Symbol"],
  "|~ exp(",
  StyleBox["\[Lambda]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox["t",
    FontSlant->"Italic"],
  "). The rate of exponentiation of error, ",
  StyleBox["\[Lambda]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  ",  is called the ",
  StyleBox[ButtonBox["Lyapunov",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Lyapunov.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" exponent",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"i:27"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.258022 6.93494 [
[.21429 .24552 -6 -9 ]
[.21429 .24552 6 0 ]
[.40476 .24552 -6 -9 ]
[.40476 .24552 6 0 ]
[.59524 .24552 -6 -9 ]
[.59524 .24552 6 0 ]
[.78571 .24552 -6 -9 ]
[.78571 .24552 6 0 ]
[.97619 .24552 -6 -9 ]
[.97619 .24552 6 0 ]
[1.025 .25802 0 -6 ]
[1.025 .25802 10 6 ]
[.01131 .11932 -30 -4.5 ]
[.01131 .11932 0 4.5 ]
[.01131 .39672 -24 -4.5 ]
[.01131 .39672 0 4.5 ]
[.01131 .53542 -24 -4.5 ]
[.01131 .53542 0 4.5 ]
[.02381 .64303 -8 0 ]
[.02381 .64303 8 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .25802 m
.21429 .26427 L
s
[(10)] .21429 .24552 0 1 Mshowa
.40476 .25802 m
.40476 .26427 L
s
[(20)] .40476 .24552 0 1 Mshowa
.59524 .25802 m
.59524 .26427 L
s
[(30)] .59524 .24552 0 1 Mshowa
.78571 .25802 m
.78571 .26427 L
s
[(40)] .78571 .24552 0 1 Mshowa
.97619 .25802 m
.97619 .26427 L
s
[(50)] .97619 .24552 0 1 Mshowa
.125 Mabswid
.0619 .25802 m
.0619 .26177 L
s
.1 .25802 m
.1 .26177 L
s
.1381 .25802 m
.1381 .26177 L
s
.17619 .25802 m
.17619 .26177 L
s
.25238 .25802 m
.25238 .26177 L
s
.29048 .25802 m
.29048 .26177 L
s
.32857 .25802 m
.32857 .26177 L
s
.36667 .25802 m
.36667 .26177 L
s
.44286 .25802 m
.44286 .26177 L
s
.48095 .25802 m
.48095 .26177 L
s
.51905 .25802 m
.51905 .26177 L
s
.55714 .25802 m
.55714 .26177 L
s
.63333 .25802 m
.63333 .26177 L
s
.67143 .25802 m
.67143 .26177 L
s
.70952 .25802 m
.70952 .26177 L
s
.74762 .25802 m
.74762 .26177 L
s
.82381 .25802 m
.82381 .26177 L
s
.8619 .25802 m
.8619 .26177 L
s
.9 .25802 m
.9 .26177 L
s
.9381 .25802 m
.9381 .26177 L
s
.25 Mabswid
0 .25802 m
1 .25802 L
s
gsave
1.025 .25802 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .11932 m
.03006 .11932 L
s
[(-0.02)] .01131 .11932 1 0 Mshowa
.02381 .39672 m
.03006 .39672 L
s
[(0.02)] .01131 .39672 1 0 Mshowa
.02381 .53542 m
.03006 .53542 L
s
[(0.04)] .01131 .53542 1 0 Mshowa
.125 Mabswid
.02381 .154 m
.02756 .154 L
s
.02381 .18867 m
.02756 .18867 L
s
.02381 .22335 m
.02756 .22335 L
s
.02381 .2927 m
.02756 .2927 L
s
.02381 .32737 m
.02756 .32737 L
s
.02381 .36205 m
.02756 .36205 L
s
.02381 .4314 m
.02756 .4314 L
s
.02381 .46607 m
.02756 .46607 L
s
.02381 .50075 m
.02756 .50075 L
s
.02381 .08465 m
.02756 .08465 L
s
.02381 .04997 m
.02756 .04997 L
s
.02381 .0153 m
.02756 .0153 L
s
.02381 .57009 m
.02756 .57009 L
s
.02381 .60477 m
.02756 .60477 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dq) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .25802 m
.02846 .25802 L
.03068 .25801 L
.03178 .25801 L
.03279 .25801 L
.03398 .25801 L
.03527 .25801 L
.03754 .25801 L
.03871 .25801 L
.04 .25801 L
.04064 .25801 L
.04134 .25801 L
.04262 .25801 L
.04326 .25801 L
.04395 .25801 L
.04519 .25801 L
.04643 .25801 L
.04755 .25801 L
.04886 .25801 L
.0496 .25801 L
.05028 .25801 L
.05153 .25801 L
.05285 .25801 L
.054 .25802 L
.05522 .25802 L
.05637 .25802 L
.05743 .25802 L
.05866 .25803 L
.06 .25803 L
.06244 .25804 L
.0637 .25804 L
.0644 .25804 L
.06505 .25805 L
.06624 .25805 L
.06749 .25805 L
.06815 .25805 L
.06887 .25805 L
.07015 .25805 L
.07093 .25805 L
.07167 .25805 L
.07234 .25805 L
.07306 .25805 L
.07376 .25805 L
.07441 .25805 L
.07513 .25805 L
.07591 .25805 L
.07671 .25805 L
.07748 .25805 L
.07817 .25805 L
.07892 .25805 L
Mistroke
.07964 .25805 L
.08028 .25805 L
.08103 .25805 L
.08173 .25804 L
.08298 .25804 L
.08368 .25804 L
.08433 .25804 L
.08551 .25804 L
.08676 .25804 L
.08795 .25804 L
.08903 .25804 L
.09033 .25804 L
.09099 .25804 L
.09171 .25805 L
.09299 .25805 L
.09418 .25805 L
.09542 .25806 L
.09674 .25806 L
.09953 .25807 L
.10197 .25808 L
.10331 .25808 L
.10458 .25808 L
.10583 .25809 L
.10654 .25809 L
.10719 .25809 L
.10832 .25809 L
.10955 .25809 L
.11072 .25809 L
.1118 .25809 L
.11295 .25809 L
.11418 .25809 L
.11488 .25809 L
.11552 .25809 L
.11699 .25809 L
.11828 .2581 L
.11966 .2581 L
.12466 .25812 L
.12983 .25814 L
.1322 .25816 L
.13349 .25817 L
.13469 .25817 L
.13539 .25818 L
.13602 .25818 L
.13672 .25818 L
.13747 .25818 L
.13878 .25818 L
.14002 .25818 L
.14072 .25818 L
.14146 .25817 L
.14278 .25817 L
Mistroke
.14577 .25815 L
.18363 .25799 L
.18839 .25798 L
.19091 .25797 L
.19359 .25796 L
.19616 .25795 L
.1985 .25794 L
.20305 .25792 L
.20867 .25787 L
.21396 .25782 L
.22393 .2577 L
.23281 .25764 L
.23779 .2576 L
.24233 .25755 L
.2449 .25752 L
.24769 .25748 L
.24897 .25745 L
.25033 .25743 L
.25149 .2574 L
.25277 .25726 L
.25403 .25724 L
.25518 .25721 L
.25779 .25715 L
.25898 .25713 L
.26009 .25711 L
.26124 .2571 L
.26251 .2571 L
.26375 .2571 L
.26446 .25711 L
.26511 .25712 L
.2663 .25714 L
.26756 .25718 L
.27215 .25732 L
.28246 .25762 L
.30353 .25805 L
.31297 .25822 L
.31818 .25834 L
.32312 .25848 L
.33269 .25885 L
.34144 .25931 L
.35179 .2598 L
.35686 .26003 L
.36152 .26028 L
.36578 .2606 L
.37026 .26106 L
.37515 .26173 L
.37753 .26199 L
.37866 .26209 L
.3797 .26217 L
.38082 .26223 L
Mistroke
.38204 .26227 L
.38311 .26227 L
.38425 .26225 L
.38544 .26219 L
.38656 .2621 L
.38779 .26198 L
.38911 .26182 L
.39943 .26028 L
.42042 .25796 L
.43052 .25687 L
.43585 .25625 L
.44154 .25545 L
.447 .25441 L
.45196 .25316 L
.46163 .24995 L
.47098 .24676 L
.47609 .24515 L
.48087 .24331 L
.48336 .24205 L
.48603 .24041 L
.49171 .23564 L
.49654 .23022 L
.4992 .22714 L
.50168 .2246 L
.50299 .22353 L
.50419 .22278 L
.50484 .22247 L
.50553 .22223 L
.50621 .22208 L
.50696 .22202 L
.50819 .22216 L
.5095 .22261 L
.51073 .22331 L
.51185 .22413 L
.52291 .23544 L
.54303 .25144 L
.55235 .25917 L
.56221 .26811 L
.56736 .27419 L
.57303 .2832 L
.57818 .29422 L
.583 .30726 L
.59199 .33712 L
.60157 .36887 L
.60441 .37653 L
.60708 .38259 L
.60948 .3869 L
.61083 .38878 L
.61207 .39012 L
.61324 .39101 L
Mistroke
.61433 .39149 L
.61553 .39158 L
.61681 .39113 L
.61746 .39067 L
.61816 .38998 L
.61943 .38821 L
.62067 .38579 L
.62181 .3829 L
.62433 .3742 L
.6267 .36303 L
.63208 .32748 L
.64298 .23354 L
.65258 .15055 L
.65802 .1041 L
.66308 .06214 L
.66553 .04376 L
.66784 .02894 L
.66912 .02223 L
.6698 .01923 L
.67051 .01648 L
.67177 .01285 L
.67293 .011 L
.67416 .01075 L
.67548 .01255 L
.67673 .01629 L
.67787 .02143 L
.6792 .0295 L
.68065 .04064 L
.68329 .06645 L
.6929 .19451 L
.70181 .32452 L
Mfstroke
.70181 .32452 m
.7219 .61803 L
s
.75517 .61803 m
.75916 .48178 L
s
.75916 .48178 m
.77242 0 L
s
.81275 0 m
.81939 .27814 L
s
.81939 .27814 m
.82743 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00:Oooool0
0ol0003oooooooooo`3Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C?ooool0
02Wooooo00?o0000ooooooooool0hOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
04cooooo000Yooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1<ooooo`00:Oooool00ol0003oooooooooo`3Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0C?ooool002Wooooo00?o0000ooooooooool0`_ooool2o`0001gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1<ooooo`00:Oooool2o`000<?ooooo00?o0000
ooooool000007?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04cooooo000Yoooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooool000007?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04cooooo000Yooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooool0
00007?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04cooooo000Yooooo`03o`00
0?oooooooooo0<;ooooo00?o0000ooooool000007?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04cooooo000Yooooo`03o`000?oooooooooo0<7ooooo00Go0000oooooooooooooooo
o`00000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C?ooool002Wooooo00?o
0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1<ooooo`00:Oooool00ol0003oooooooooo`31ooooo`05o`000?oo
ooooooooooooool000006oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04cooooo
000Yooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C?ooool002Wooooo00?o0000
ooooooooool0`?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1<ooooo`00:Oooool00ol0003oooooooooo`30oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04cooooo000Yooooo`03o`000?oooooooooo0<3ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0C?ooool002Wooooo0_l00031ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04cooooo000Yooooo`03o`000?oo
oooooooo0<3ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0C?ooool002Wooooo00?o0000ooooooooool0`?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1<ooooo`00:Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
04cooooo000Yooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0C?ooool002Wooooo
00?o0000ooooooooool0`?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1<ooooo`00:Oooool00ol0003ooooooooo
o`30ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo04_ooooo000Yooooo`03o`000?oooooooooo0;oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Boooool002Wooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1;oooo
o`00:Oooool00ol0003oooooooooo`2oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo000Yooooo`;o0000
`?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1;ooooo`00:Oooool00ol0003oooooooooo`2oooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04_ooooo000Yooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Boooool0
02Wooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1;ooooo`00:Oooool00ol0003o
ooooooooo`2nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo000Yooooo`03o`000?oooooooooo0;kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Boooool002Wooooo00?o0000ooooooooool0__ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1;ooooo`00:Oooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`Go00001_ooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2nooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04_ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?ooooooooooooooool@41001?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
0;gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Boooool000Kooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000_Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1;ooooo`001_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0_Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1;ooooo`001_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
_Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1;ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`2mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Boooool002Wooooo00?o0000
ooooooooool0_Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1;ooooo`00:Oooool00ol0003oooooooooo`2loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo04_ooooo000Yooooo`03o`000?oooooooooo0;cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Boooool002Wooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1;ooooo`00:Ooo
ool00ol0003oooooooooo`2looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo000Yooooo`;o0000_Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1;ooooo`00:Oooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04_ooooo000Yooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Boooool002Wooooo
00?o0000ooooooooool0_?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1;ooooo`00:Oooool00ol0003ooooooooo
o`2looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo04_ooooo000Yooooo`03o`000?oooooooooo0;cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Boooool002Wooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1;oooo
o`00:Oooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo000Yooooo`03o`00
0?oooooooooo0;_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Boooool002Wooooo00?o0000ooooooooool0^ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1;ooooo`00:Oooool00ol0003oooooooooo`2kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo04_ooooo000Yooooo`;o0000_?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1;ooooo`00:Oooool00ol0003o
ooooooooo`2kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo04_ooooo000Yooooo`03o`000?oooooooooo0;_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0Boooool002Wooooo00?o0000ooooooooool0^oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1;ooooo`00:Oooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04_ooooo000Yoooo
o`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Boooool002Wooooo00?o0000oooooooo
ool0^oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1;ooooo`00:Oooool00ol0003oooooooooo`2kooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04[ooooo000Yooooo`03o`000?oooooooooo037ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^;Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0]
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`?o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Wooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo000Yooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;Oooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooo`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Zooooo`09ogMgMolb<S;ooooooooooomg
MgOoV9RHoooooonHV9SoMgMg01Oooooo000Yooooo`;o0000=?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41006?ooool3o`0001Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool0:oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo01Gooooo000Yooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002oooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00
000Dooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04_ooool01?m4A4Co0000ooooool00004ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Zooooo`05ogMgMolb<S;ooooo
ooooool000000oooool00ol0003oooooooooo`0Eooooo`00:Oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000`ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`;o00001?ooool00ol0003ooooooooo
o`0@ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04_ooool01?oMgMgo0000ooooool00004ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Wooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001Oooooo000Yooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@037ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0@ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@4009ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003o
c<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400Gooooo`00:Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0]
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo
00?o0000ooooooooool01oooool2o`0000gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01;ooooo00?o0000odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05ooo
ool002Wooooo00?o0000ooooooooool0<Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04_ooool00ol0003oMgMgo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Wooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01Oooooo000Yooooo`03o`000?oooooooooo08Sooooo0ol0000=ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0B_ooool002Wooooo00?o0000ooooooooool0Q_ooool2
o`00017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1:ooooo`00:Oooool00ol0
003oooooooooo`21ooooo`Go00005?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
047ooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`00:Oooool00ol0003oooooooooo`1ooooo
o`;o00006_ooool2o`0001cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@Oooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Cooooo000Yooooo`03o`000?oooooooooo07[ooooo1Ol0000Nooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`06ooooo`008_ooooooo`0003;o
00003?ooool00ol0003oooooooooo`06ooooo`00:Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01OoooolAo`0000[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03oooool00ol@413o0000o`000003o`0000Gooooo000Yooooo`03o`000?oo
oooooooo0:7ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo00Kooooo000Yooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`000?oooooooooo
0:?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1:ooooo`00:Oooool00ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0B_ooool002Wooooo
00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04[ooooo
000Yooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1:ooooo`00:Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0B_ooool002Wooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo04[ooooo000Yooooo`;o0000Yoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo04[ooooo000Yooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1:ooooo`00:Oooool00ol0003oooooooooo`2Vooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0B_ooool002Wooooo00?o0000ooooooooool0Yoooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[ooooo000Yooooo`03o`000?oooooooooo
0:Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1:ooooo`00:Oooool00ol0003o
ooooooooo`2Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B_ooool002Wooooo
00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[ooooo
000Yooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1:ooooo`00:Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0B_ooool002Wooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo04[ooooo000Yooooo`;o0000Z_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo04[ooooo000Yooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1:ooooo`00:Oooool00ol0003oooooooooo`2Zooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0B_ooool002Wooooo00?o0000ooooooooool0Z_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo000Yooooo`03o`000?oooooooooo
0:[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`00:Oooool00ol0003o
ooooooooo`2Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool002Wooooo
00?o0000ooooooooool0Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo
000Yooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`19ooooo`00:Oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0BOooool002Wooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04Wooooo000Yooooo`03o`000?oooooooooo0:cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`19ooooo`00:Oooool2o`000:gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`19ooooo`00:Oooool00ol0003oooooooooo`2]ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0BOooool002Wooooo00?o0000ooooooooool0[Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo000Yooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`00:Oooool00ol0003o
ooooooooo`2^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool002Wooooo
00?o0000ooooooooool0[_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo
000Yooooo`03o`000?oooooooooo0:oooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`00:Ooo
ool00ol0003oooooooooo`2_ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooool000006_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;7ooooo0_l0000J
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@
4004ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003=ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00?o0000ooooooooool0cOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0BOooool000Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0<go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wo
oooo0006ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`001_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`19ooooo`00:Oooool00ol0003oooooooooo`3=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`00:Ooo
ool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`19ooooo`00:Oooool00ol0003oooooooooo`3=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`00:Oooool00ol0
003oooooooooo`3=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`19ooooo`00:Oooool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`19ooooo`00:Oooool2o`000<oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Wooooo
000Yooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo04Wooooo000Yooooo`03o`000?oooooooooo0<kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Wooooo000Yoooo
o`03o`000?oooooooooo0<kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04Wooooo000Yooooo`03o`000?oooooooooo0<kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Wooooo000Yooooo`03o`00
0?oooooooooo0<kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo04Wooooo000Yooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo000Yooooo`03o`000?oooooo
oooo0<kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04Sooooo000Yooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo000Yooooo`03o`000?oooooooooo0<ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04So
oooo000Yooooo`;o0000coooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0c_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000
ooooooooool0c_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000oooooooo
ool0coooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0B?ooool002Wooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0cooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B?oo
ool002Wooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0coooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B?ooool002Wo
oooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0coooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B?ooool002Wooooo0_l0
003@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`18ooooo`00:Oooool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`18ooooo`00:Oooool00ol0003oooooooooo`3?oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`18oooo
o`00:Oooool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`18ooooo`00:Oooool00ol0003oooooooooo`3?ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`18ooooo`00:Ooo
ool00ol0003oooooooooo`3@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`18ooooo`00:Oooool00ol0003oooooooooo`3@ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`18ooooo`00:Oooool00ol0
003oooooooooo`3@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`18ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0d?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0B?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`18ooooo`001_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`Go00001_ooool00ol0003oooooooooo`3@ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`18ooooo`001_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0003@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`18ooooo`001_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0d?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B?oo
ool000Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
1?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0=3ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`3@ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`18ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0d?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0B?ooool002Wooooo00?o0000ooooooooool0d?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0
d?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
B?ooool002Wooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0dOooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B?ooool0
02Wooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0Aoooool002Wooooo0_l0003Booooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`17ooooo`00:Oooool00ol0003ooooo
ooooo`3Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`17ooooo`00:Oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`17ooooo`00:Oooool00ol0003oooooooooo`3A
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`17
ooooo`00:Oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`17ooooo`00:Oooool00ol0003oooooooooo`3Aooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`17ooooo`00
:Oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`17ooooo`00:Oooool00ol0003oooooooooo`3Aooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`17ooooo`00:Oooool0
0ol0003oooooooooo`3Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`17ooooo`00:Oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`17ooooo`00:Oooool00ol0003o
ooooooooo`3Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`17ooooo`00:Oooool2o`000=?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo04Oooooo000Yooooo`03o`000?oooooooooo0=;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Oooooo000Y
ooooo`03o`000?oooooooooo0=;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04Oooooo000Yooooo`03o`000?oooooooooo0=;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Oooooo000Yooooo`03
o`000?oooooooooo0=;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo04Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Qooooo`03oc8b<_l0003o000000?o000000Go
<S8booooooooooook^k^oc8b<P02o`000003oeEEEOo^k^kooooo0?oooooo>?ooool0027ooooo00?o
V9RHodA4A?ooool00_ooool02om4A4CoV9RHooooooooooooEEEEogMgMoooooook^k^ohN7QolQ8B7o
k^k^0?oooooo>?ooool002;ooooo00Go410@omgMgOoooooogMgMoa0@4003ooooo`03o`000?oooooo
oooo00;ooooo00?oQhN7ogMgMoooool0oooooolgooooo`008_ooool01On7QhOoMgMgoooooomVIVKo
QhN700?ooooo00?o0000ooooooooool00oooool00olQ8B7oooooooooo`3oooooocKooooo000Roooo
o`05onk^k_l@413ok^k^oa0@4?o^k^h00oooool00olQ8B7o0000o`000004o`000?oooooo>?ooool0
02?ooooo00?oMgMgob4Q8OmEEED01?ooool00onHV9SoQhN7ooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool002?ooooo00?ogMgMo`000?oMgMd01Oooool01_lb<S;oQhN7onk^k_ooooooQhN7
oc8b<_oooooo>?ooool002Cooooo00?oZJVYooooooooool01?ooool01_o^k^koMgMgo`000?l0003o
<S8bolc<c?oooooo>?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-7.11514, -0.0396575, \
0.215288, 0.000591314}}],

Cell["Fig. 1.10 Difference between the trajectories of Fig. 1.9.", "Caption",
  CellTags->"Fig. 1.10"],

Cell[TextData[{
  "\tThis rapid error accumulation is the signature of a chaotic system. It \
makes it ",
  "impossible",
  " to determine trajectories accurately over times long compared to 1/",
  StyleBox["\[Lambda]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  ".  One can easily see why this is so: a fast computer working at \
double-double precision (32-digit accuracy) can integrate for times up to \
roughly ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"ln", "(", 
              FormBox[\(10\^32\),
                "TraditionalForm"], ")"}], "/", \(\[Lambda]~\ 70\)}], "/", 
          "\[Lambda]"}], TraditionalForm]]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "before roundoff error in the 32nd digit causes order-unity deviation from \
the exact trajectory",
  StyleBox[".",
    FontFamily->"Symbol"],
  " To integrate accurately up to ",
  Cell[BoxData[
      \(TraditionalForm\`7000/\ \[Lambda]\)]],
  ", the accuracy would have to be increased by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^100\  = \ 
        2.6\ \[Cross]\ 10\^43\)]],
  " !  "
}], "Text"],

Cell["\<\
For chaotic systems,  small errors in computing  the trajectory, or \
in the initial conditions, lead to exponentially large errors at later times, \
making the trajectory unpredictable. \
\>", "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
\tChaotic trajectories are not an isolated feature of only a few \
unusual dynamical systems. Rather, chaos is the norm. It has been shown that \
almost all dynamical systems are chaotic. Integrable systems such as the \
harmonic oscillator are the truly unusual cases, even though such cases are \
emphasized in elementary books on mechanics (because they are analytically \
tractable). \
\>", "Text"],

Cell["\<\
\tSince almost all systems are chaotic, and since chaotic systems \
are unpredictable, one might question the usefulness of Newton's formulation \
of dynamics, wherein a given initial condition, together with the force law, \
is supposed to provide all the information necessary to predict future \
behavior. For chaotic systems this predictive power is lost. \
\>", "Text"],

Cell[TextData[{
  "\tFortunately, even chaotic systems have features that can be predicted \
and reproducibly observed. Although specific particle trajectories cannot be \
predicted over long times, average values based on many particle trajectories \
are reproducible. We will examine this statistical approach to complex \
dynamical systems in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Lyapunov Exponent", "Section",
  CellTags->{"i:28", "c:23"}],

Cell[TextData[{
  "\tOne example of a reproducible average quantity for a chaotic system is \
the Lyapunov exponent itself.  In order to define the Lyapunov exponent, note \
that since error accumulates on average as exp(",
  StyleBox["\[Lambda]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox["t",
    FontSlant->"Italic"],
  "), the ",
  StyleBox["logarithm",
    FontSlant->"Italic"],
  " of the error",
  StyleBox[" ",
    FontSlant->"Italic"],
  "should increase ",
  StyleBox["linearly",
    FontSlant->"Italic"],
  " with ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", with a slope equal to ",
  StyleBox["\[Lambda]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tTherefore, ",
  StyleBox["\[Lambda]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontFamily->"Symbol"],
  " is defined as follows: Consider a given initial conditions ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["z",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  "=(",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ").  For this choice, the phase-space trajectory is ",
  StyleBox["z",
    FontWeight->"Bold"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[
            SubscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ")=(",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t,",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ")",
  StyleBox[",v",
    FontSlant->"Italic"],
  "(",
  StyleBox["t,",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ")). Now consider a small displacement ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["d",
              FontSlant->"Plain"], "o"],
          FontWeight->"Bold",
          FontSlant->"Italic"], TraditionalForm]]],
  " = (",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["x",
            FontSize->13], "o"], TraditionalForm]]],
  ",",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ") to a nearby initial condition, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "+",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["d",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold",
          FontSlant->"Italic"], TraditionalForm]]],
  StyleBox[".",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox[" ",
    FontWeight->"Bold"],
  " \tThe Lyapunov exponent is defined as "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Lambda]", "(", 
          StyleBox[
            SubscriptBox["z", 
              StyleBox["o",
                FontWeight->"Plain",
                FontSlant->"Italic"]],
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], "=", " ", 
        RowBox[{
          UnderscriptBox["lim", 
            RowBox[{\(t \[Rule] \ \[Infinity]\), ",", 
              RowBox[{
                RowBox[{"|", 
                  SubscriptBox[
                    StyleBox["d",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"], "|"}], "\[Rule]", " ", 
                "0"}]}]], " ", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{\(1\/t\), "ln", " ", 
              RowBox[{"(", 
                FractionBox[
                  RowBox[{"|", 
                    RowBox[{
                      RowBox[{
                        StyleBox["z",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox["(",
                          FontWeight->"Plain"], 
                        RowBox[{
                          StyleBox["t",
                            FontWeight->"Plain"], 
                          StyleBox[",",
                            FontWeight->"Plain"], 
                          StyleBox[
                            RowBox[{
                              SubscriptBox[
                                StyleBox["z",
                                  FontSlant->"Plain"], 
                                StyleBox["o",
                                  FontWeight->"Plain"]], "+", 
                              SubscriptBox[
                                StyleBox["d",
                                  FontSlant->"Plain"], 
                                StyleBox["o",
                                  FontWeight->"Plain"]]}],
                            FontWeight->"Bold"]}], ")"}], 
                      StyleBox["-",
                        FontWeight->"Bold"], 
                      RowBox[{
                        StyleBox["z",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox["(",
                          FontWeight->"Plain"], 
                        RowBox[{
                          StyleBox["t",
                            FontWeight->"Plain"], 
                          StyleBox[",",
                            FontWeight->"Plain"], 
                          StyleBox[
                            SubscriptBox[
                              StyleBox["z",
                                FontSlant->"Plain"], 
                              StyleBox["o",
                                FontWeight->"Plain"]],
                            FontWeight->"Bold"]}], ")"}]}], "|"}], 
                  RowBox[{"|", 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["d",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox["o",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold",
                      FontSlant->"Italic"], 
                    StyleBox["|",
                      FontSlant->"Italic"]}]], ")"}]}], 
            "\[RightAngleBracket]"}]}]}], TraditionalForm]]]], "NE4",
  CellTags->"(1.4.2)"],

Cell[TextData[{
  "where the \[LeftAngleBracket] \[RightAngleBracket] stands for an average \
over many infinitesimal initial displacements ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["d",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "in different directions, and | ",
  StyleBox["z",
    FontWeight->"Bold"],
  " | corresponds to a vector magnitude in the phase-space. [Units are \
unimportant in this vector magnitude: both position and momentum can be \
regarded as dimensionless, so that ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "can be thought of  as a dimensionless vector for the purposes of Eq. ",
  ButtonBox["(1.4.2)",
    ButtonData:>"(1.4.2)",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We can numerically evaluate the Lyapunov exponent by averaging over a \
number of orbits nearby to a given initial condition, all with small  |",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["d",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  "|.  Then by plotting the ",
  "right-hand",
  " side of ",
  ButtonBox["Eq. (1.4.2)",
    ButtonData:>"(1.4.2)",
    ButtonStyle->"Hyperlink"],
  " as a function of time for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 50\)]],
  ", we can observe that this function asymptotes to a constant value, equal \
to ",
  StyleBox["\[Lambda]",
    FontFamily->"Symbol"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe will do this for our previous example of pendulum motion using the \
following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " statements. In keeping with the notation of this subsection, we use the \
notation  ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, v)\)\)]],
  " for the pendulum ",
  "phase-space",
  ", rather than  ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Theta], \[Theta]\^\[Prime])\)\)]],
  " ."
}], "Text"],

Cell[TextData[{
  "\tFirst, we create a test trajectory ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          RowBox[{"t", ",", 
            StyleBox[
              SubscriptBox[
                StyleBox["z",
                  FontSlant->"Plain"], "o"],
              FontWeight->"Bold",
              FontSlant->"Italic"]}], ")"}], TraditionalForm]]],
  " using the initial conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = \(-0.5\)\ , v(0) = 0\)]],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(z\  = \ {x[t], 
            v[t]} /. \(NDSolve[{\(x'\)[t]\  == \ 
                  v[t], \(v'\)[t]\  == \ \(-Sin[x[t]]\)\  - \ 
                    Sin[x[t]\  - \ 2\ t], x[0]\  \[Equal] \(-0.5\), 
                v[0]\  \[Equal] 0}, {x[t], v[t]}, {t, 0, 
                50}]\)[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.23"],

Cell[TextData[{
  "This trajectory is the same as the black trajectory shown in Fig. ",
  ButtonBox["1.9",
    ButtonData:>"Fig. 1.9",
    ButtonStyle->"Hyperlink"],
  ". Next,  we create 40 nearby initial conditions by choosing values of ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(0) and ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(0) scattered randomly around the point ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-0.5\), 0)\)\)]],
  ":   "
}], "Text"],

Cell[BoxData[
    \(\(z0\  = \ 
        Table[{\(-0.5\) + 10^\(-5\) \((2  Random[] - 1)\), 
            10^\(-5\) \((2  Random[] - 1)\)}, {m, 1, 40}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.24"],

Cell[TextData[{
  "Then, we integrate these initial conditions forward in time using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and evaluate the vector displacement between the resulting trajectories \
and the test trajectory ",
  StyleBox["z:",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[
    \(\(\[CapitalDelta]z[t_]\  = \ 
        Table[Sqrt[\(({x[t], v[t]} - z)\) . \(({x[t], v[t]} - 
                    z)\)] /. \(NDSolve[{\(x'\)[t]\  == \ 
                    v[t], \(v'\)[t]\  == \ \(-Sin[x[t]]\)\  - \ 
                      Sin[x[t]\  - \ 2\ t], x[0]\  \[Equal] z0[\([m, 1]\)], 
                  v[0]\  \[Equal] z0[\([m, 2]\)]}, {x[t], v[t]}, {t, 0, 
                  50}]\)[\([1]\)], {m, 1, 40}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.25"],

Cell[TextData[{
  "Finally, we evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"ln", "[", 
            RowBox[{
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["z",
                      FontSlant->"Italic"]}]], "(", "t", ")"}], "/", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["z",
                      FontSlant->"Italic"]}]], "(", "0", ")"}]}], "]"}], "/", 
          "t"}], TraditionalForm]]],
  ", averaged over the 40 trajectories, and plot the result in Cell ",
  ButtonBox["1.26",
    ButtonData:>"Cell 1.26",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Lambda][t_]\  = \ 
        1/40\ Sum[
              Log[\(\[CapitalDelta]z[t]\)[\([n]\)]/\(\[CapitalDelta]z[
                      0]\)[\([n]\)]], {n, 1, 40}]/t;\)\), "\n", 
    \(\(Plot[\[Lambda][t], {t, 0, 50}, PlotRange \[Rule] {0, 0.5}, 
        AxesLabel \[Rule] {"\<t\>", "\<\[Lambda](t)\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.26"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0 1.23607 [
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(10)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(30)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(40)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(50)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03294 m
.02499 .04197 L
.02605 .04407 L
.02729 .0452 L
.02846 .04515 L
.02954 .04428 L
.03053 .04289 L
.03163 .04086 L
.03279 .03828 L
.03523 .03219 L
.03786 .02593 L
.03913 .0234 L
.04035 .02141 L
.04143 .02003 L
.04262 .019 L
.04386 .01848 L
.04499 .01855 L
.04629 .01928 L
.04751 .02064 L
.04865 .02252 L
.04969 .02477 L
.05205 .03185 L
.05446 .04205 L
.05711 .05699 L
.05987 .07716 L
.06244 .10067 L
.07376 .26276 L
.07933 .36452 L
.08448 .45224 L
.08915 .5158 L
.09151 .54025 L
.09287 .55175 L
.09411 .56056 L
.09538 .56779 L
.09671 .5735 L
.0974 .5757 L
.09805 .57728 L
.09875 .57853 L
.09951 .5793 L
.10017 .57953 L
.10088 .57934 L
.10217 .57794 L
.10342 .5755 L
.10458 .57253 L
.10892 .55912 L
.11006 .55586 L
.11131 .55276 L
.11241 .55049 L
.11358 .54864 L
.11431 .54779 L
Mistroke
.11497 .54725 L
.11625 .54681 L
.11751 .54719 L
.11869 .54827 L
.11989 .55001 L
.12099 .55207 L
.12348 .55749 L
.12464 .55987 L
.12588 .56187 L
.12706 .56292 L
.12812 .56292 L
.12938 .56154 L
.13009 .56003 L
.13074 .55816 L
.13194 .55354 L
.13322 .54721 L
.13583 .53203 L
.13725 .52459 L
.13795 .52162 L
.13858 .51937 L
.13971 .51632 L
.14092 .51411 L
.14226 .51204 L
.14349 .50954 L
.14462 .50613 L
.14581 .50097 L
.14701 .49404 L
.14832 .48443 L
.15288 .43836 L
.15776 .37928 L
.163 .32103 L
.16554 .29834 L
.16794 .2812 L
.1701 .26955 L
.17122 .26483 L
.17246 .26053 L
.17468 .25487 L
.1759 .25268 L
.17704 .25111 L
.17811 .25003 L
.17909 .24934 L
.18016 .24892 L
.18129 .24889 L
.18252 .24936 L
.18322 .24988 L
.18386 .25053 L
.18503 .25218 L
.18628 .25459 L
.18844 .2604 L
.19082 .26908 L
Mistroke
.19608 .29497 L
.20101 .32383 L
.20979 .37246 L
.21219 .38287 L
.21476 .39186 L
.216 .39537 L
.21718 .39814 L
.21822 .40018 L
.21937 .40195 L
.22063 .40338 L
.22132 .40394 L
.22197 .40433 L
.22312 .40476 L
.22436 .40489 L
.22505 .40484 L
.22581 .40472 L
.22652 .40455 L
.22718 .40437 L
.22851 .40397 L
.22976 .40364 L
.23085 .40344 L
.23203 .40337 L
.23334 .40351 L
.23455 .40391 L
.23573 .40459 L
.23702 .40571 L
.23837 .40734 L
.23963 .4093 L
.24205 .41426 L
.24433 .41999 L
.2464 .42549 L
.24859 .43076 L
.24973 .43298 L
.25098 .4348 L
.25212 .43578 L
.25318 .43602 L
.25444 .43542 L
.25558 .43403 L
.2569 .43153 L
.25816 .42851 L
.26058 .42239 L
.2618 .41998 L
.26249 .41896 L
.26314 .41824 L
.26385 .41768 L
.26449 .41733 L
.26518 .41705 L
.26594 .41677 L
.26726 .41602 L
.26851 .41467 L
Mistroke
.26968 .41262 L
.27097 .40939 L
.27231 .40493 L
.27357 .39982 L
.27825 .37543 L
.28311 .34711 L
.28551 .3343 L
.28774 .32387 L
.28991 .31538 L
.29189 .30922 L
.29408 .304 L
.29642 .29994 L
.29877 .297 L
.3001 .29572 L
.30132 .29486 L
.30238 .29428 L
.30356 .29393 L
.30478 .29391 L
.30593 .29421 L
.30656 .29457 L
.30725 .29501 L
.30851 .29623 L
.30973 .298 L
.31086 .29982 L
.31342 .30528 L
.31615 .31265 L
.32625 .34574 L
.33156 .36104 L
.33422 .36703 L
.33575 .36981 L
.33714 .3719 L
.33836 .3734 L
.33968 .37465 L
.34041 .37521 L
.34108 .37563 L
.3424 .37619 L
.34353 .37646 L
.34478 .37659 L
.34608 .3766 L
.34729 .37652 L
.3485 .37642 L
.34964 .37636 L
.35066 .37634 L
.35178 .37642 L
.35299 .3766 L
.35428 .37697 L
.3555 .37753 L
.3566 .37822 L
.35775 .37917 L
.35896 .38043 L
Mistroke
.36113 .38338 L
.36602 .39247 L
.36806 .39641 L
.37025 .39997 L
.3715 .40149 L
.37264 .4024 L
.37379 .40274 L
.37488 .40267 L
.37602 .40204 L
.37725 .40077 L
.37842 .39915 L
.37948 .39741 L
.38455 .39125 L
.38693 .39056 L
.38761 .39034 L
.38825 .39008 L
.38946 .38916 L
.39015 .38843 L
.39079 .38758 L
.39224 .385 L
.39349 .38209 L
.39482 .37837 L
.4038 .34514 L
.40612 .33678 L
.40865 .32879 L
.41088 .32293 L
.41325 .31798 L
.41582 .31393 L
.41819 .31112 L
.42034 .30911 L
.42156 .30827 L
.42271 .30761 L
.42394 .30714 L
.42525 .3069 L
.42637 .30694 L
.42759 .30734 L
.4289 .30808 L
.42964 .30868 L
.43031 .3093 L
.43285 .31261 L
.4352 .31675 L
.43737 .32125 L
.44227 .33292 L
.45118 .35367 L
.45584 .36169 L
.45845 .36487 L
.4597 .36603 L
.46085 .36693 L
.46201 .36764 L
.46307 .36816 L
Mistroke
.46424 .36857 L
.46549 .36891 L
.46659 .36912 L
.46777 .36932 L
.46991 .36963 L
.4712 .36987 L
.4724 .37017 L
.47372 .3706 L
.47513 .37124 L
.47662 .37213 L
.47802 .37325 L
.48065 .37612 L
.48311 .37975 L
.48539 .38379 L
.49054 .39373 L
.49279 .39745 L
.49402 .39908 L
.49517 .40027 L
.49641 .40114 L
.49707 .4014 L
.49778 .40152 L
.49903 .40133 L
.50017 .4007 L
.50133 .39964 L
.5024 .39838 L
.50482 .39515 L
.50592 .39384 L
.50695 .39286 L
.50802 .39214 L
.50921 .39159 L
.51048 .39111 L
.51115 .39083 L
.51187 .39048 L
.51318 .38956 L
.5144 .38832 L
.51568 .38657 L
.51689 .38451 L
.51914 .37973 L
.52423 .36653 L
.52981 .35255 L
.53488 .34287 L
.5396 .33624 L
.54501 .3293 L
.54737 .32636 L
.54861 .32497 L
.54993 .32365 L
.55107 .32278 L
.55232 .32217 L
.55346 .32194 L
.55452 .32202 L
Mistroke
.55561 .32242 L
.55661 .32304 L
.55777 .32409 L
.55886 .32536 L
.56343 .33284 L
.56842 .34307 L
.57328 .35312 L
.57854 .36278 L
.58095 .36653 L
.5835 .36995 L
.58571 .37242 L
.58807 .37454 L
.58949 .37556 L
.59078 .37632 L
.5921 .37695 L
.59331 .37741 L
.59473 .37779 L
.59547 .37793 L
.59627 .37805 L
.59695 .37811 L
.5976 .37814 L
.5983 .37815 L
.59907 .37813 L
.60028 .37804 L
.60096 .37796 L
.6016 .37786 L
.60289 .37762 L
.60427 .37728 L
.60677 .37648 L
.60904 .37555 L
.62982 .36928 L
.63895 .36694 L
.64143 .36548 L
.64379 .36429 L
.64509 .36381 L
.64583 .36361 L
.64651 .36347 L
.64772 .36334 L
.649 .36337 L
.65025 .36353 L
.65095 .36368 L
.6516 .36385 L
.65406 .36468 L
.65624 .36552 L
.6574 .36595 L
.65864 .36636 L
.65983 .36668 L
.66091 .36688 L
.662 .36699 L
.66303 .36698 L
Mistroke
.66418 .36684 L
.66525 .36657 L
.66642 .36612 L
.66766 .36548 L
.67219 .36223 L
.67343 .36139 L
.67474 .3607 L
.67585 .36032 L
.67707 .36012 L
.67777 .36009 L
.67841 .36012 L
.67915 .3602 L
.67984 .36029 L
.68049 .36038 L
.68118 .36048 L
.68242 .36058 L
.68357 .36056 L
.68483 .36037 L
.68548 .3602 L
.68618 .35996 L
.68744 .35939 L
.69235 .35599 L
.69505 .35396 L
.69758 .35239 L
.69903 .35172 L
.69985 .35143 L
.7006 .35122 L
.70123 .35108 L
.70192 .35096 L
.70265 .35089 L
.70332 .35085 L
.70401 .35086 L
.70466 .35089 L
.70589 .35102 L
.70721 .35126 L
.70864 .3516 L
.7182 .35504 L
.72328 .35697 L
.72474 .35745 L
.72613 .35785 L
.7274 .35815 L
.72809 .35829 L
.72874 .3584 L
.72938 .35848 L
.73007 .35855 L
.73128 .3586 L
.73251 .35856 L
.73364 .35843 L
.73488 .35821 L
.73624 .35786 L
Mistroke
.73898 .35696 L
.74138 .35618 L
.74272 .35583 L
.74394 .3556 L
.74508 .35547 L
.74632 .35541 L
.74749 .35541 L
.74858 .35545 L
.74978 .35548 L
.75108 .35548 L
.7523 .35539 L
.75342 .35523 L
.75467 .35494 L
.75537 .35471 L
.75603 .35448 L
.75877 .35317 L
.76397 .35018 L
.76539 .34948 L
.7669 .34885 L
.76819 .34844 L
.76892 .34825 L
.76961 .34811 L
.77026 .348 L
.77097 .34791 L
.77223 .34781 L
.77293 .34779 L
.77369 .34778 L
.7744 .34779 L
.77504 .3478 L
.7763 .34783 L
.77701 .34784 L
.77766 .34785 L
.77886 .34783 L
.78013 .34773 L
.78131 .34757 L
.78258 .34729 L
.78377 .34692 L
.78486 .34649 L
.78753 .34508 L
.79006 .34347 L
.79231 .34208 L
.79354 .34143 L
.79469 .34092 L
.79575 .34053 L
.79672 .34026 L
.7978 .34002 L
.79897 .33982 L
.80158 .33944 L
.80286 .33923 L
.80404 .33899 L
Mistroke
.80625 .33839 L
.80865 .33752 L
.8134 .33532 L
.81847 .33295 L
.82077 .33205 L
.82291 .33136 L
.82515 .3308 L
.82633 .33059 L
.8276 .33042 L
.82827 .33035 L
.82899 .3303 L
.83027 .33027 L
.83098 .33029 L
.83164 .33032 L
.83237 .33038 L
.83316 .33048 L
.8338 .33058 L
.8345 .33071 L
.83591 .33105 L
.83843 .33191 L
.84091 .33307 L
.84355 .33463 L
.84832 .33817 L
.85854 .3473 L
.86393 .35166 L
.86687 .35357 L
.86963 .35496 L
.87204 .35583 L
.87339 .35617 L
.87462 .3564 L
.87532 .35649 L
.87597 .35656 L
.87668 .35662 L
.87744 .35667 L
.87816 .35669 L
.87884 .3567 L
.88011 .35669 L
.88129 .35667 L
.88253 .35662 L
.88476 .3565 L
.88978 .35615 L
.89926 .35562 L
.90448 .3553 L
.90705 .35515 L
.90818 .35509 L
.90943 .35502 L
.91058 .35494 L
.91166 .35484 L
.9128 .35469 L
.91402 .35446 L
Mistroke
.91529 .35414 L
.91663 .35371 L
.91902 .35266 L
.9232 .35019 L
.92777 .34698 L
.93306 .34344 L
.93565 .34202 L
.93805 .34097 L
.94023 .34021 L
.94253 .33959 L
.94484 .33911 L
.94739 .33867 L
.96834 .33539 L
.97619 .33447 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00F?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h[ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^02cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool005[ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0;?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0_oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg02;ooooo001Jooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400/ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400`ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Zooooo`Go00000oooool01Ol@413ooooooooooooooooo410@033ooooo00Co0000
oooooooooooo410@0oooool00ol@413oooooooooo`0Pooooo`00F_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool00000;Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool00000;oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
0000;?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000;oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool08?ooool005[ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000002kooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000002kooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo000002cooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000002cooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
8_ooool005[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02oooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02gooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@02gooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@02cooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@02;ooooo001Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0[ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg02co
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;Oooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool005Sooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0^ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0/ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo
003oooooofWooooo003ooooooeCooooo00GoV9RHo`000?l0003oA4A4okZj^P0@ooooo`00oooooomD
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41004?ooool00?ooooooE?ooool00ol0003oooooooooo`0B
ooooo`007_ooooooo`0002_o00002oooool00ol0003oooooooooo`0Booooo`009Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool002Gooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo
00?o410@o`000?l000000ol0000Aooooo`009Oooool00ol0003oooooooooo`3oooooobcooooo00?o
0000ooooooooool04_ooool002Gooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooo
oooo01;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool00_ooool3o`000?oooooo??ooool002Gooooo0_l00002ooooo`03o`000?oooooooooo00;o0000
oooooolkooooo`009Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
ooooooliooooo`009Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
ooooooliooooo`009Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo
>Oooool002Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooocWooooo
000Uooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0oooooolhooooo`009Oooool3
o`0000Kooooo00?o0000ooooooooool0oooooolhooooo`009Oooool2o`0000Oooooo00?o0000oooo
ooooool0oooooolhooooo`009Oooool2o`0000Oooooo00?o0000ooooooooool0oooooolhooooo`00
9Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=oooool002Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocOooooo000Uooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolgooooo`009Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo=oooool002Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocOooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
oooooolfooooo`009Oooool2o`0000Wooooo00?o0000ooooooooool0oooooolfooooo`009Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`3oooooocKooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooolf
ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo=_ooool002Go
oooo0_l00009ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0oooooolfooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3o
ooooocKooooo000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo=_ooool0
00[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3oooooocKooooo000:ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`?o00002Oooool00ol0003oooooooooo`3o
ooooocGooooo000:ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooooleooooo`002_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo0?oooooo=Oooool000[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3o
ooooocGooooo000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooooleooooo`009Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo=Oooool002Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`3oooooocGooooo000Uooooo`;o00002_ooool00ol0003ooooo
ooooo`3oooooocGooooo000Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooo
ooleooooo`009Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo=Oooool0
02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooocGooooo000Uooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooooleooooo`009Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo0?oooooo=?ooool002Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`3oooooocCooooo000Uooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0ooooooldooooo`009Oooool2o`0000_ooooo00?o0000ooooooooool0ooooooldoooo
o`009Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo=?ooool002Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooocCooooo000Uooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0ooooooldooooo`009Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo0?oooooo=?ooool002Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`3oooooocCooooo000Uooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0ooooooldooooo`009Oooool2o`0000_ooooo00?o0000ooooooooool0ooooooldooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo=?ooool002Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`3ooooooc?ooooo000Uooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0oooooolcooooo`009Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo0?oooooo<oooool002Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3ooooooc?ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooo
oolcooooo`009Oooool2o`0000cooooo00?o0000ooooooooool0oooooolcooooo`009Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo<oooool002Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`3ooooooc?ooooo000Uooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0oooooolcooooo`009Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0?oooooo<oooool000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3ooooooc?ooooo000:
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooooolcooooo`002_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0?oooooo<_ooool000[ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000<ooooo`03o`000?oooooooooo01cooooo
0_l0003ooooooaCooooo000:ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06oooool4o`000?oooooo
4oooool000[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`000?oo
oooo4oooool000[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00Co0000oooo
oooooooo0000oooooolCooooo`002_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo4?ooool002Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0ooooool@ooooo`009Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`oooooo000Uooooo`;o
00003Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0ooooool?ooooo`009Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`oooooo000Uooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo3oooool002Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool?ooooo`009Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooo`kooooo000Uooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo3_ooool002Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0ooooool>ooooo`009Oooool2o`0000gooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo1?l0003]ooooo`009Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool00000kOooool002Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06oooool01Ol0003ooooooooooooooooo00000>gooooo000Uooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o0000b_ooool0
02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01gooooo1?l00039ooooo`009Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<Ko
oooo000Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0a_ooool002Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`36ooooo`009Oooool2o`0000kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07_ooool3o`000:Cooooo000Uooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool07_ooool01?l0003oooooooooool0002Sooooo`009Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00001?ooooo`?o0000DOooool0
02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0BOooool3o`0000;ooooo0ol0001?ooooo`009Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`17ooooo`;o00002?ooool00ol0003oooooooooo`0Oooooo`Ko00009oooool002Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0@_ooool4o`0000_ooooo0_l0000Jooooo`Go0000;Oooool002Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0?oooool2o`00017ooooo00?o0000ooooooooool05?ooool3o`0003;ooooo000U
ooooo`;o00003_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0?Oooool2o`0001Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0c
ooooo`009Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0fooooo`Ko00005oooool00ol0003oooooooooo`0?oooo
o`;o0000=_ooool002Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool7o`0000cooooo00?o0000oooooooo
ool07?ooool2o`0000kooooo00?o0000ooooooooool0=_ooool002Gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8?ooool2o`0000Oooooo0_l00004ooooo`Ko00008Oooool>o`0003Wooooo000Uooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01_ooooo1?l0000;ooooo`Co0000K_ooool000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
4Oooool3o`0000Gooooo00?o0000ooooooooool0Ooooool000[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03oooool2o`0001;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`?o
00000_ooool6o`0008;ooooo000:ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`04ooooo`?o00003Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04?ooool5o`0000kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0:ooooo`?o0000SOooool000[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ojVYZOl@413ooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool2o`0000cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`?o0000T?ooool000[ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0?ooooo`Ko00002_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04Oooool2o`0000;ooooo1?l0002Cooooo`002_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Cooooo0_l00009ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Dooooo`?o0000U_ooool000[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0[Oooool000[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool2o`0001[ooooo00?o0000
ooooooooool01_ooool2o`000:oooooo000Uooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`04ooooo`;o00007?ooool00ol0003oooooooooo`04oooo
o`;o0000/?ooool002Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooooooool3o`00
0;7ooooo000Uooooo`;o00003oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`05o`000?oooooooooooooo
ool000008?ooool01Ol0003ooooooooooooooooo00000;?ooooo000Uooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`;o00003oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooo000002;ooooo0ol0002dooooo`009Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool6o`0000[o
oooo00?o0000ooooooooool06_ooool3o`0002?ooooo00?o0000ooooooooool0/oooool002Gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo
0_l00002ooooo`;o00002Oooool00ol0003oooooooooo`3fooooo`009Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?Oooooo000Uooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0moooool002Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool3o`000?Wooooo000Uooooo`;o
00003oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3iooooo`009Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?[ooooo000Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000o?ooool002Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00Co
0000oooooooooooo0000o?ooool002Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000oOooool002Gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo0ol0003m
ooooo`009Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0oooooolKooooo`009Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0oooooolKooooo`009Oooool2o`00013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`3ooooooa_ooooo000Uooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`3ooooooa_ooooo000Uooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3ooooooa_ooooo000Uoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3ooooo
oa_ooooo000Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`3ooooooa_ooooo000Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`3ooooooacooooo000Uooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`3ooooooacooooo000Uooooo`;o00004?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo7?ooool002Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo7?ooool002Go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oo
oooo7?ooool002Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo0?oooooo7?ooool002Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo0?oooooo7?ooool000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo7?ooool000[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3ooooooacooooo000:
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0oooooolLooooo`002_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0oooooolLooooo`002_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooolMooooo`002_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooolMooooo`002_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooolMooooo`002_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0oooooolNooooo`009Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0oooooolNooooo`009Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0oooo
oolOooooo`009Oooool2o`00017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3o
oooooaoooooo000Uooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`3ooooooaoooooo000Uooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`3ooooooaoooooo000Uooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooob3ooooo000Uooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooob3ooooo000U
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3o
ooooob3ooooo000Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`3oooooob7ooooo000Uooooo`;o00004_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0?oooooo8Oooool002Gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`04ooooo`;o00000oooool00ol0003oooooooooo`3oooooob7ooooo000Uooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l00002ooooo`03o`00
0?oooooooooo0?oooooo8Oooool002Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0oooooolQooooo`009Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooooooo
o`000?oooooo00000?oooooo8oooool002Gooooo00?o0000ooooooooool04_ooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l0003oooooobCooooo000Uooooo`03o`000?oooooooooo01;ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0?oooooo8_ooool002Gooooo
0_l0000Cooooo`05o`000?ooooooooooooooool00000oooooolZooooo`009Oooool00ol0003ooooo
ooooo`0Booooo`04o`000?ooooooooooo`000?oooooo:oooool002Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooo`00003oooooob_ooooo000Uooooo`03o`000?oooooooooo01?ooooo0_l0
003oooooobcooooo000Uooooo`03o`000?oooooooooo01?ooooo0_l0003oooooobcooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool000[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool000[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0ol0003ooooood7ooooo000:ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`3oooooodSooooo000:ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<0?ooooooBOooool000[ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo0?ooooooBoooool000[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo0?ooooooBoooool000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`008_ooool00omgMgOoIVIVooooo`08ooooo`03ofIVI_mgMgOooooo0?oooooo>Oooool0027o
oooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgMg@3oooooocWooooo000Gooooo`07o`00
0?n7QhOooooooooooooMgMgo<S8bo`000003ooooo`03oeEEEOnHV9Sooooo00?ooooo00GoV9RHo`00
0?l0003oA4A4okZj^P02ooooo`03ohN7QomVIVKooooo0?oooooo>?ooool001Oooooo00Kok^k^oc8b
<_nHV9SoooooodA4A?mgMgL4ooooo`03o`000?oooooooooo00?ooooo00Go410@okZj^_o^k^koMgMg
oa0@4002ooooo`03onk^k_l0003ooooo0?oooooo>?ooool001Sooooo00Gok^k^ob4Q8OnHV9So0000
omgMg@04ooooo`03oc8b<_oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocOooooo000Iooooo`03olc<c?l@413o000000Gooooo00?o<S8booooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=oooool001[ooooo00?oQhN7
o`000?ooool01?ooool00ol0003ok^k^ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?ok^k^
o`000?ooool0oooooolhooooo`006_ooool00oo^k^ko0000ooooo`04ooooo`05oeEEEOmgMgOooooo
ooooool@41001Ol00003ooooo`03ogMgMomEEEGooooo0?oooooo>?ooool001[ooooo00?oQhN7oeEE
EOooool01?ooool00ooMgMgo410@onk^kP03ooooo`03o`000?oooooooooo00?ooooo00?ok^k^oa0@
4?oMgMd0ooooooliooooo`006Oooool00ol0003oA4A4onk^kP06ooooo`03ogMgMomVIVKooooo00;o
oooo00?o0000ooooooooool00oooool00omVIVKoMgMgooooo`3oooooocWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The Lyapunov exponent can be seen to asymptote to a fairly constant value \
of about 0.3 at large times. Fluctuations in the result can be reduced by \
keeping more trajectories in the average. Thus, over a time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 50\)]],
  ", nearby orbits diverge in phase-space  by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(0.3\[Times]\ 50\) = 
        3. \[Times]10\^6\)]],
  ", on average. Over a time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 500\)]],
  ", initially nearby orbits diverge by the huge factor of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^65\)]],
  ". Even a tiny initial error gets blown up to a massive deviation over this \
length of time, leading to complete loss of predictability."
}], "Text"],

Cell[TextData[{
  "\tNote that the choice of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["d",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold",
          FontSlant->"Italic"], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "in the above numerical work is a rather tricky business. It must be larger \
than the intrinsic error of the numerical method, otherwise the effect of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["d",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold",
          FontSlant->"Italic"], TraditionalForm]]],
  " on the trajectory is swamped by numerical error. But on the other hand, \
",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["d",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold",
          FontSlant->"Italic"], TraditionalForm]]],
  " must not be so large that orbits diverge by a large amount over the \
plotted time interval; otherwise we are not properly evaluating the \
difference between \"infinitesimally nearby trajectories\"; that is, we \
require ",
  Cell[BoxData[
      FormBox[
        RowBox[{"|", 
          StyleBox[
            SubscriptBox[
              StyleBox["d",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold",
            FontSlant->"Italic"], "|", 
          " ", \(\(\[ExponentialE]\^\(\[Lambda]\ t\)\) << 1\)}], 
        TraditionalForm]]],
  ".  As a result of these trade-offs, this method for determining ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " is not particularly accurate, but it will do for our purposes. More \
accurate (and complicated!)  methods exist for determining a Lyapunov \
exponent: see, for example, ",
  ButtonBox["A.J. Lichtenberg and M. A. Lieberman",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " ",
  StyleBox["(",
    FontSlant->"Italic"],
  "1992",
  ", p. 315). "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.4.3 Euler's Method", "Subsubtitle",
  CellTags->{"i:46", "c:24"}],

Cell[TextData[{
  " \t In this section, we will create our own ODE solver by first \
considering a simple (and crude) numerical method called ",
  StyleBox[ButtonBox["Euler",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Euler.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox["'s method",
    FontSlant->"Italic"],
  ". Most ODE solvers are at their core merely more complex and accurate \
versions of Euler's method, so we will begin by examining this simplest of \
numerical ODE solvers. We will then consider more complicated numerical \
methods. "
}], "Text",
  CellTags->"i:47"],

Cell[TextData[{
  "Euler's method applies to the simple first",
  "-order",
  " ODE discussed in ",
  ButtonBox["Sec. 1.2",
    ButtonData:>"Sec. 1.2",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]v\), \(\[DifferentialD]t\),
            MultilineFunction->None], "=", \(f(t, v)\)}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`v(0) = v\_o\)]],
  "."
}], "NE4",
  CellTags->"(1.4.3)"],

Cell["\<\
Later, we will see how to modify Euler's method to apply to more \
general ODEs.\
\>", "Text"],

Cell[TextData[{
  "\tTo apply Euler's method to ",
  ButtonBox["Eq. (1.4.3)",
    ButtonData:>"(1.4.3)",
    ButtonStyle->"Hyperlink"],
  ", we first ",
  StyleBox["discretize",
    FontSlant->"Italic"],
  " the time variable, defining evenly spaced discrete ",
  StyleBox["timesteps",
    FontSlant->"Italic"],
  " "
}], "Text",
  CellTags->"i:140"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n = 0, 1, 2, 3,  ... \)\)\)]],
  "."
}], "NE4",
  CellTags->"(1.4.4)"],

Cell[TextData[{
  "The quantity ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is called the ",
  StyleBox["step size. ",
    FontSlant->"Italic"],
  "(Confusingly, some authors also refer to ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            StyleBox["\[CapitalDelta]",
              FontSlant->"Plain"], 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " as the timestep.) We will evaluate the solution ",
  StyleBox["v(t)",
    FontSlant->"Italic"],
  " ",
  StyleBox["only",
    FontSlant->"Italic"],
  " at the discrete timesteps given in Eq. ",
  ButtonBox["(1.4.4)",
    ButtonData:>"(1.4.4)",
    ButtonStyle->"Hyperlink"],
  ". Later, we will interpolate to find ",
  StyleBox["v(t)",
    FontSlant->"Italic"],
  " at times between the timesteps."
}], "Text",
  CellTags->"i:139"],

Cell[TextData[{
  "\tNext, we integrate both sides of ",
  ButtonBox["Eq. (1.4.3)",
    ButtonData:>"(1.4.3)",
    ButtonStyle->"Hyperlink"],
  " , and apply the fundamental theorem of calculus:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_\(t\_\(n - 1\)\)\%\(t\_n\)\), 
          RowBox[{
            FractionBox[\(\[DifferentialD]v\), \(\[DifferentialD]t\),
              MultilineFunction->None], \(\[DifferentialD]t\)}]}], 
        TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(v(t\_n)\)\(-\)\(v(t\_\(n - 1\))\)\(\ \)\)\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(t\_\(n - 1\)\)\%\(t\_n\)\(f(t, 
            v(t))\) \[DifferentialD]t\)]],
  "."
}], "NE4",
  CellTags->"(1.4.5)"],

Cell[TextData[{
  "Note that we must take account of the time variation of ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") in the integral over ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "on the ",
  "right-hand",
  " side."
}], "Text"],

Cell[TextData[{
  "\tSo far, no approximation has been made. However, we will now approximate \
the integral over ",
  StyleBox["f",
    FontSlant->"Italic"],
  ", assuming that ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " is so small that ",
  StyleBox["f",
    FontSlant->"Italic"],
  " does not vary appreciably over the range of integration:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_\(t\_\(n - 1\)\)\%\(t\_n\)\(f(t, 
                v(t))\) \[DifferentialD]t\), "\[TildeTilde]", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \(f(t\_\(n - 1\), v(t\_\(n - 1\)))\)}], " ", "+", " ", 
            RowBox[{
              StyleBox["O",
                FontSlant->"Italic"], "(", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "2"], ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(1.4.6)"],

Cell[TextData[{
  "The error in this approximation scales as \[CapitalDelta]",
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)]],
  " (see the exercises), and we use the notation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["O",
              FontSlant->"Italic"], "(", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "2"], ")"}], " "}], 
        TraditionalForm]]],
  " to indicate this fact. The same notation is used in power series \
expansions (Sec. ",
  ButtonBox["9.9",
    ButtonData:>{"Chapter9.nb", "Sec. 9.9"},
    ButtonStyle->"Hyperlink"],
  "), and indicates that if ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is reduced by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  ", the error in Eq. ",
  ButtonBox["(1.4.6)",
    ButtonData:>"(1.4.6)",
    ButtonStyle->"Hyperlink"],
  " is reduced by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`4\)]],
  " (for small ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "). "
}], "Text"],

Cell[TextData[{
  " \tEquation ",
  ButtonBox["(1.4.6)",
    ButtonData:>"(1.4.6)",
    ButtonStyle->"Hyperlink"],
  "  is a very crude approximation to the integral, but it has the distinct \
advantage that, when used in ",
  ButtonBox["Eq. (1.4.5)",
    ButtonData:>"(1.4.5)",
    ButtonStyle->"Hyperlink"],
  ", the result is a simple ",
  StyleBox["recursion relation",
    FontSlant->"Italic"],
  " for ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  ") :"
}], "Text",
  CellTags->"i:138"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(v(t\_n)\), "=", 
        RowBox[{\(v(t\_\(n - 1\))\), " ", "+", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], 
            " ", \(f(t\_\(n - 1\), v(t\_\(n - 1\)))\)}], "+", " ", 
          RowBox[{"O", "(", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "2"], ")"}]}]}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(1.4.7)"],

Cell[TextData[{
  ButtonBox["Equation (1.4.7)",
    ButtonData:>"(1.4.7)",
    ButtonStyle->"Hyperlink"],
  " is Euler's method. It is called a recursion relation because the value of \
",
  StyleBox["v",
    FontSlant->"Italic"],
  " at the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "th step is determined by quantities from the ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  "st step, which were themselves determined in terms of variables at the ",
  Cell[BoxData[
      \(TraditionalForm\`n - 2\)]],
  "nd step, and so on back to the initial condition at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ".  Recursion relations like this are at the heart of most numerical ODE \
solvers. Their differences lie mainly in the degree of approximation to the \
integral in ",
  ButtonBox["Eq. (1.4.6)",
    ButtonData:>"(1.4.6)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:124"],

Cell[TextData[{
  "\tTo see how Euler's method works, we will write a program that can be \
used to solve any ODE of the form of ",
  ButtonBox["Eq. (1.4.3)",
    ButtonData:>"(1.4.3)",
    ButtonStyle->"Hyperlink"],
  ".  In our code, we will employ the following simple notation for the \
velocity at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  ": a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", defined for integer arguments. We will employ the same notation for the \
time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  " defining a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["t",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[
              RowBox[{
                StyleBox["\[CapitalDelta]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["t",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]]}]}], TraditionalForm]]],
  ".  Then Euler's method can be written in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as"
}], "Text"],

Cell[BoxData[{
    \(\(t[n_]\  := \ n\ \[CapitalDelta]t;\)\), "\n", 
    \(\(v[n_]\  := \ 
        v[n - 1]\  + \ \[CapitalDelta]t\ \ f[t[n - 1], \ 
              v[n - 1]];\)\), "\n", 
    \(v[0]\  := \ \ \ v0\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.27"],

Cell[TextData[{
  "The first line defines the time at step ",
  StyleBox["n",
    FontSlant->"Italic"],
  "; the second is ",
  ButtonBox["Eq. (1.4.7)",
    ButtonData:>"(1.4.7)",
    ButtonStyle->"Hyperlink"],
  " and the third is the initial condition. Note that delayed evaluation is \
used for all three lines, since we have not yet specified a ",
  "step size",
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", an initial condition ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`v\_o\)]]]], TraditionalForm]]],
  ", or the function",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f\)\)\)]],
  ". However, even if these quantities are already specified, delayed \
evaluation ",
  StyleBox["must be used",
    FontSlant->"Italic"],
  " in the second line, since it is a recursion relation: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " is determined in terms of previous values of ",
  Cell[BoxData[
      FormBox[
        StyleBox["v",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and can therefore only be evaluated for a given specific integer value \
of ",
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNote that it is somewhat dangerous to write the code in the form given \
in Cell ",
  ButtonBox["1.27",
    ButtonData:>"Cell 1.27",
    ButtonStyle->"Hyperlink"],
  ", because it is up to us to ask only for nonnegative integer values of ",
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". If, for example, we ask for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["0.5",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", the second line will evaluate this in terms of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["-",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["0.5",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", which is then evaluated in terms of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["-",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[
              RowBox[{
                StyleBox["1",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox[".5",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", etc., leading to an ",
  StyleBox["infinite recursion",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v[0.5]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.28"],

Cell[BoxData[
    \($RecursionLimit::"reclim" \(\(:\)\(\ \)\) 
      "Recursion depth of \!\(256\) exceeded."\)], "Message"],

Cell[BoxData[
    \($RecursionLimit::"reclim" \(\(:\)\(\ \)\) 
      "Recursion depth of \!\(256\) exceeded."\)], "Message"],

Cell[BoxData[
    \($RecursionLimit::"reclim" \(\(:\)\(\ \)\) 
      "Recursion depth of \!\(256\) exceeded."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\($RecursionLimit :: \"reclim\"\) will be \
suppressed during this calculation."\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "In such errors,  the kernel will often grind away  fruitlessly for many \
minutes trying to evaluate the recursive tree, and the only way to stop the \
process is to quit the kernel. We can improve the code by adding conditions \
to the definition of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "  that require ",
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " to be a positive integer:"
}], "Text"],

Cell[BoxData[
    \(Clear[v]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.29"],

Cell[BoxData[{
    \(\(t[n_]\  := \ n\ \[CapitalDelta]t;\)\), "\n", 
    \(\(v[n_]\  := \ 
        v[n - 1]\  + \ \[CapitalDelta]t\ \ f[t[n - 1], \ v[n - 1]] /; 
          n > 0\  && \ n \[Element] Integers;\)\), "\n", 
    \(v[0]\  := \ \ \ v0\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.30"],

Cell[TextData[{
  "Here we have used the statement ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["\[Element]",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["Integers",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " , which stands for the logical statement \"",
  StyleBox["n",
    FontSlant->"Italic"],
  " is an element of the integers\", evaluating to a result of either ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The symbol \[Element]  stands for the intrinsic function ",
  StyleBox["Element",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and is available on the BasicInput palette. (Don't confuse ",
  Cell[BoxData[
      \(TraditionalForm\` \[Element] \)]],
  " with the Greek letter epsilon, ",
  StyleBox["\[Epsilon]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  ".) \n\tIf we now ask for ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              RowBox[{
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["0.5",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], TraditionalForm]]]]], 
        TraditionalForm]]],
  ", there is no error because we have only defined ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              RowBox[{
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["n",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], TraditionalForm]]]]], 
        TraditionalForm]]],
  " for positive integer argument:"
}], "Text",
  CellTags->"i:136"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v[0.5]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.31"],

Cell[BoxData[
    \(v[0.5`]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In principle, we could now run this code simply by asking for any value of \
",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              RowBox[{
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["n",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], TraditionalForm]]]]], 
        TraditionalForm]]],
  " for  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["\[Element]",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["Integers",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "   and t ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(n > 0\),
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will then evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(n - 1\),
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "  in terms of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(n - 2\),
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", and so on until it reaches ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["v",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["0",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["v0",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ".  The code stops here because the definition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["v",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["0",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["v0",
            FontFamily->"Courier",
            FontWeight->"Bold"], " "}], TraditionalForm]]],
  " takes precedence over the recursion relation. "
}], "Text"],

Cell[TextData[{
  "\tHowever, there are a few pitfalls that should be avoided.  First, it \
would not be a good idea to begin evaluating the code right now. We have not \
yet defined the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  ", the ",
  "step size",
  " ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  ", or the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ". Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will return perfectly valid results if we ask for, say, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["2",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", the result will be a complicated algebraic expression without much \
value. If we ask for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["100",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", the result will be so long and complicated that we will probably have to \
abort the evaluation. Numerical methods are really made for solving ",
  StyleBox["specific numerical instances ",
    FontSlant->"Italic"],
  " of the ODE in question. "
}], "Text"],

Cell[TextData[{
  "\tTherefore, let us solve the following specific problem, which we \
encountered in ",
  ButtonBox["Sec. 1.2.1",
    ButtonData:>"c:10",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t, v) = t - v\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`v(0) = 0\)]],
  "."
}], "NE4",
  CellTags->"(1.4.8)"],

Cell[TextData[{
  "The general solution was given in ",
  ButtonBox["Eq. (1.2.5)",
    ButtonData:>"(1.2.5)",
    ButtonStyle->"Hyperlink"],
  ", and for ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(0)=0 is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`v(t) = t + \[ExponentialE]\^\(-t\) - 1\)]]], "NE4",
  CellTags->"(1.4.9)"],

Cell[TextData[{
  "\tBefore we solve this problem using Euler's method, there is another \
pitfall that can be avoided by making a small change in the code. As it \
stands, the code will work, but it will be very slow, particularly if we ask \
for ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              RowBox[{
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["n",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], TraditionalForm]]]]], 
        TraditionalForm]]],
  "with  ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(n >> 1\),
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". The reason is that every time we ask for ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              RowBox[{
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["n",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], TraditionalForm]]]]], 
        TraditionalForm]]],
  ", it evaluates the recursion relations all the way back to ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              RowBox[{
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["0",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], TraditionalForm]]]]], 
        TraditionalForm]]],
  ", even if it has previously evaluated the values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(n - 1\),
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(n - 2\),
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", etc.  This wastes time. It is better to make ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " remember values of the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " that it has evaluated previously. This can be done as follows:  in the \
second line of the code, which specifies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", write two equal signs:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(v[n_]\), " ", ":=", 
        RowBox[{
          RowBox[{
            StyleBox["(",
              FontSize->16,
              FontColor->RGBColor[1, 0, 0]], 
            " ", \(v[n]\  = 
              v[n - 1]\  + \ \[CapitalDelta]t\ \ f[t[n - 1], \ v[n - 1]]\), 
            "  ", 
            StyleBox[")",
              FontSize->16,
              FontColor->RGBColor[1, 0, 0]]}], "/;", 
          " ", \(n > 0\  && \ n \[Element] Integers\)}]}], ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.32"],

Cell[TextData[{
  "The second equal sign causes ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to remember any value of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " that is evaluated by adding this value to the definition of ",
  Cell[BoxData[
      FormBox[
        StyleBox["v",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "; then, if this value is asked for again, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses this result rather than reevaluating the equation.  Note that we \
have placed parentheses around part of the ",
  "right-hand",
  " side of the equation. These parentheses must be included when the \
equation has conditions; otherwise the condition statement will not evaluate \
properly, because it will attach itself only to the second equality, not the \
first. "
}], "Text"],

Cell["\tThe modified Euler code is as follows:", "Text"],

Cell[BoxData[{
    \(\(t[n_]\  := \ n\ \[CapitalDelta]t;\)\), "\n", 
    \(\(v[
          n_]\  := \((v[
                n]\  = \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ v[
                  n - 1]\  + \ \[CapitalDelta]t\ \ f[t[n - 1], \ 
                    v[n - 1]])\) /; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
n > 0\  && \ n \[Element] Integers;\)\), "\n", 
    \(v[0]\  := \ \ \ v0\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.33"],

Cell[TextData[{
  "Let's now evaluate a solution numerically, from ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 4\)]],
  ".  To do so, first specify the step size, the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  ", and the initial condition: "
}], "Text"],

Cell[BoxData[{
    \(\(\[CapitalDelta]t = 0.2;\)\), "\n", 
    \(\(f[t_, v_]\  = \ t - v;\)\), "\n", 
    \(\(v0\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.34"],

Cell[TextData[{
  "Next, make a list of  data points ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["{",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            RowBox[{
              StyleBox["t",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["n",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["v",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["n",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], 
          StyleBox["}",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", calling this result our numerical ",
  StyleBox["solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution\  = \ 
      Table[{t[n], v[n]}, {n, 0, 4/\[CapitalDelta]t}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.35"],

Cell[BoxData[
    \({{0, 0}, {0.2`, 0}, {0.4`, 0.04000000000000001`}, {0.6000000000000001`, 
        0.112`}, {0.8`, 0.2096`}, {1.`, 0.32768`}, {1.2000000000000002`, 
        0.462144`}, {1.4000000000000001`, 0.6097152`}, {1.6`, 
        0.76777216`}, {1.8`, 0.934217728`}, {2.`, 1.1073741824`}, {2.2`, 
        1.28589934592`}, {2.4000000000000004`, 1.4687194767360001`}, {2.6`, 
        1.6549755813888`}, {2.8000000000000003`, 1.84398046511104`}, {3.`, 
        2.0351843720888323`}, {3.2`, 
        2.228147497671066`}, {3.4000000000000004`, 
        2.4225179981368528`}, {3.6`, 
        2.6180143985094824`}, {3.8000000000000003`, 
        2.814411518807586`}, {4.`, 3.011529215046069`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Finally, plot these points with a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and compare this Euler solution with the analytic solution of ",
  ButtonBox["Eq. (1.4.9)",
    ButtonData:>"(1.4.9)",
    ButtonStyle->"Hyperlink"],
  " by overlaying the two solutions in Cell ",
  ButtonBox["1.36",
    ButtonData:>"Cell 1.36",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = 
        ListPlot[solution, PlotStyle \[Rule] PointSize[0.015], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(b = 
        Plot[E^\(-t\)\  + \ t\  - 1, {t, 0, 4}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[a, b, DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.36"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.195011 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11222 -18 -4.5 ]
[.01131 .11222 0 4.5 ]
[.01131 .20973 -6 -4.5 ]
[.01131 .20973 0 4.5 ]
[.01131 .30723 -18 -4.5 ]
[.01131 .30723 0 4.5 ]
[.01131 .40474 -6 -4.5 ]
[.01131 .40474 0 4.5 ]
[.01131 .50224 -18 -4.5 ]
[.01131 .50224 0 4.5 ]
[.01131 .59975 -6 -4.5 ]
[.01131 .59975 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(1)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(2)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(3)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11222 m
.03006 .11222 L
s
[(0.5)] .01131 .11222 1 0 Mshowa
.02381 .20973 m
.03006 .20973 L
s
[(1)] .01131 .20973 1 0 Mshowa
.02381 .30723 m
.03006 .30723 L
s
[(1.5)] .01131 .30723 1 0 Mshowa
.02381 .40474 m
.03006 .40474 L
s
[(2)] .01131 .40474 1 0 Mshowa
.02381 .50224 m
.03006 .50224 L
s
[(2.5)] .01131 .50224 1 0 Mshowa
.02381 .59975 m
.03006 .59975 L
s
[(3)] .01131 .59975 1 0 Mshowa
.125 Mabswid
.02381 .03422 m
.02756 .03422 L
s
.02381 .05372 m
.02756 .05372 L
s
.02381 .07322 m
.02756 .07322 L
s
.02381 .09272 m
.02756 .09272 L
s
.02381 .13172 m
.02756 .13172 L
s
.02381 .15122 m
.02756 .15122 L
s
.02381 .17072 m
.02756 .17072 L
s
.02381 .19022 m
.02756 .19022 L
s
.02381 .22923 m
.02756 .22923 L
s
.02381 .24873 m
.02756 .24873 L
s
.02381 .26823 m
.02756 .26823 L
s
.02381 .28773 m
.02756 .28773 L
s
.02381 .32673 m
.02756 .32673 L
s
.02381 .34623 m
.02756 .34623 L
s
.02381 .36573 m
.02756 .36573 L
s
.02381 .38524 m
.02756 .38524 L
s
.02381 .42424 m
.02756 .42424 L
s
.02381 .44374 m
.02756 .44374 L
s
.02381 .46324 m
.02756 .46324 L
s
.02381 .48274 m
.02756 .48274 L
s
.02381 .52174 m
.02756 .52174 L
s
.02381 .54124 m
.02756 .54124 L
s
.02381 .56075 m
.02756 .56075 L
s
.02381 .58025 m
.02756 .58025 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.015 w
.02381 .01472 Mdot
.07143 .01472 Mdot
.11905 .02252 Mdot
.16667 .03656 Mdot
.21429 .05559 Mdot
.2619 .07862 Mdot
.30952 .10484 Mdot
.35714 .13362 Mdot
.40476 .16444 Mdot
.45238 .1969 Mdot
.5 .23066 Mdot
.54762 .26548 Mdot
.59524 .30113 Mdot
.64286 .33745 Mdot
.69048 .37431 Mdot
.7381 .4116 Mdot
.78571 .44923 Mdot
.83333 .48713 Mdot
.88095 .52526 Mdot
.92857 .56356 Mdot
.97619 .602 Mdot
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01474 L
.02846 .01475 L
.03053 .01479 L
.03279 .01485 L
.03527 .01494 L
.0379 .01505 L
.04262 .01531 L
.05205 .01603 L
.06244 .01715 L
.07293 .01859 L
.0842 .02049 L
.10458 .02477 L
.1458 .03645 L
.18551 .05103 L
.22371 .06765 L
.26435 .08773 L
.30348 .10901 L
.34506 .13342 L
.38513 .1584 L
.42368 .18358 L
.46468 .21141 L
.50417 .23908 L
.54214 .26635 L
.58257 .29601 L
.62148 .32506 L
.66284 .35641 L
.70268 .387 L
.74101 .41672 L
.78179 .44861 L
.82106 .47954 L
.85881 .50946 L
.89901 .54148 L
.9377 .57242 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00Oogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo002YOol7001jOol8001lOol40020Ool50009Ool0
0:aoo`03001oogoo07aoo`03001oogoo00=oo`03001oogoo07Uoo`03001oogoo009oo`03001oogoo
07moo`03001oogoo00Uoo`00[7oo00<007ooOol0OGoo00<007ooOol0OGoo00<007ooOol017oo00<0
07ooOol0OWoo00<007ooOol02Goo002/Ool00`00Oomoo`1nOol00`00Oomoo`23Ool00`00Oomoo`1h
Ool90009Ool00:aoo`03001oogoo07moo`03001oogoo089oo`03001oogoo07Uoo`03001oogoo009o
o`03001oogoo00Uoo`00[7oo00<007ooOol0P7oo00<007ooOol0P7oo00<007ooOol0NWoo00<007oo
Ool00Woo00<007ooOol02Goo002/Ool00`00Oomoo`21Ool00`00Oomoo`1lOol3001nOol01@00Oomo
ogoo00002goo002/Ool00`00Oomoo`22Ool00`00Oomoo`1nOol00`00Oomoo`1lOol01000Oomoo`00
2goo002/Ool00`00Oomoo`22Ool00`00Oomoo`1oOol00`00Oomoo`1kOol01000Oomoo`002goo002/
Ool00`00Oomoo`1lOol00`00Oomoo`03Ool00`00Oomoo`1oOol00`00Oomoo`1lOol00`00Ool0000;
Ool00:Uoo`@007ioo`8000=oo`03001oogoo07Yoo`03001oogoo009oo`03001oogoo07ioo`8000]o
o`00Zgoo0P00P7oo0`00OWoo1000PGoo0P002goo003oOoooOom2Ool002Yoo`03001oogoo0?mooomo
oaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001o
ogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000YOol4000FOol4003oOoojOol002Qo
o`H001Aoo`H00?moooUoo`009goo20004Woo2000ogoon7oo000MOooo003o000T0001Ool002Moo`P0
00Yooa0001Aoo`@001Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo
01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo
01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo
01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo00]oo`009goo2000
4Woo20004goo1P005Woo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol0
5goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol0
5goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol0
5goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol02goo000XOol6000D
Ool600000goo00000004000<Ool80019Ool00`00Oomoo`1oOol00`00Oomoo`1oOol00`00Oomoo`1o
Ool00`00Oomoo`0;Ool002Uoo`@001Ioo`@000Qoo`D000Moo`P00?moomioo`00:Woo00<007ooOol0
9goo1@000Woo2000ogoogWoo000ZOol00`00Oomoo`0/Ool:003oOooNOol002Yoo`03001oogoo02mo
o`H00?moommoo`00:Woo00<007ooOol0<7oo1P0057oo1000ogooaWoo000ZOol00`00Oomoo`0fOol3
000@Ool6003oOoo5Ool002Yoo`03001oogoo03Uoo`<000aoo`P00?moolAoo`00:Woo0`00?7oo0`00
2Goo2000ogooa7oo000ZOol00`00Oomoo`0oOol30006Ool8003oOoo4Ool002Yoo`03001oogoo049o
o`<000=oo`P00?moolAoo`00:Woo00<007ooOol0AGoo0`0000=oo`0000001000ogooaGoo000ZOol0
0`00Oomoo`18Ool6003oOoo6Ool002Yoo`03001oogoo04Yoo`<00?moolMoo`00:Woo00<007ooOol0
CGoo0P00ogooaGoo000ZOol00`00Oomoo`1?Ool3003oOoo2Ool002Yoo`03001oogoo059oo`<000mo
o`@00?moojaoo`00:Woo00<007ooOol0EGoo0P0037oo1P00ogooZgoo000ZOol3001GOol30008Ool8
003oOonZOol002Yoo`03001oogoo05Yoo`8000Ioo`P00?moojYoo`00:Woo00<007ooOol0G7oo0P00
17oo2000ogooZWoo000ZOol00`00Oomoo`1NOol300000goo00000006003oOonZOol002Yoo`03001o
ogoo065oo`P00?mooj]oo`00:Woo00<007ooOol0Hgoo1@00ogoo[7oo000ZOol00`00Oomoo`1UOol3
003oOon/Ool002Yoo`03001oogoo06Qoo`800?moojYoo`00:Woo00<007ooOol0JWoo0P00ogooZ7oo
000ZOol00`00Oomoo`1/Ool2003oOonVOol002Yoo`03001oogoo06ioo`8000ioo`@00?mooi9oo`00
:Woo0`00L7oo0P002goo1P00ogooTGoo000ZOol00`00Oomoo`1bOol20008Ool8003oOon@Ool002Yo
o`03001oogoo07Aoo`8000Ioo`P00?mooi1oo`00:Woo00<007ooOol0MWoo0P0017oo2000ogooT7oo
000ZOol00`00Oomoo`1hOol20002Ool8003oOon@Ool002Yoo`03001oogoo07Yoo`800003Ool00000
00@00?mooi5oo`00:Woo00<007ooOol0O7oo1P00ogooTWoo000ZOol00`00Oomoo`1nOol2003oOonD
Ool002Yoo`03001oogoo081oo`800?mooi9oo`00:Woo00<007ooOol0PWoo0P00ogooT7oo000ZOol0
0`00Oomoo`24Ool2003oOon>Ool002Yoo`<008Ioo`800?moohaoo`00:Woo00<007ooOol0R7oo0P00
ogooRWoo000ZOol00`00Oomoo`2:Ool2003oOon8Ool002Yoo`03001oogoo08aoo`8000Yoo`@00?mo
ogQoo`00:Woo00<007ooOol0SWoo0P001goo1P00ogooMgoo000ZOol00`00Oomoo`2@Ool20004Ool8
003oOomfOol000Aoo`@000Qoo`<000Moo`H000Yoo`03001oogoo099oo`80009oo`P00?moogIoo`00
0goo00<007ooOol00Woo00<007ooOol01Goo0`001Woo0P001Goo00<007ooOol01goo00<007ooOol0
U7oo2P00ogooMWoo0003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool3000>Ool00`00Oomoo`06Ool0
0`00Oomoo`2FOol8003oOomfOol0009oo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00Io
o`03001oogoo09Moo`H00?moogMoo`000Woo00<007ooOol017oo00<007ooOol05Goo00<007ooOol0
1Woo1@00UWoo1000ogooN7oo0002Ool00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomoo`06Ool0
0`00Oomoo`2KOol2003oOomgOol0009oo`03001oogoo00Aoo`03001oogoo00ioo`8000Aoo`03001o
ogoo00Moo`03001oogoo09eoo`03001oogoo0?moogAoo`000Woo00<007ooOol017oo00<007ooOol0
3Woo1P002Woo00<007ooOol0WWoo0P00ogooM7oo0002Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool0
0`00Oomoo`0=Ool00`00Oomoo`2POol00`00Oomoo`3oOomaOol000=oo`03001oogoo009oo`03001o
ogoo00moo`03001oogoo00eoo`03001oogoo0:5oo`800?moog5oo`000goo00<007ooOol00Woo00<0
07ooOol03goo00<007ooOol03Goo00<007ooOol0Xgoo00<007ooOol0ogooKWoo0004Ool4000BOol7
0009Ool00`00Oomoo`2TOol2003oOom^Ool002Yoo`03001oogoo0:Ioo`8000Uoo`@00?mooemoo`00
:Woo00<007ooOol0Z7oo00<007ooOol01Goo1P00ogooGWoo000ZOol00`00Oomoo`2YOol20004Ool8
003oOomMOol002Yoo`<00:]oo`04001oogooOol8003oOomMOol002Yoo`03001oogoo0:aoo`800003
Ool0000000H00?mooeeoo`00:Woo00<007ooOol0[Woo2@00ogooGGoo000ZOol00`00Oomoo`2`Ool6
003oOomNOol002Yoo`03001oogoo0;5oo`@00?mooemoo`00:Woo00<007ooOol0/goo0P00ogooGgoo
000ZOol00`00Oomoo`2eOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo0;Ioo`800?mooeaoo`00
:Woo00<007ooOol0^7oo0P00ogooFWoo000ZOol00`00Oomoo`2jOol00`00Oomoo`3oOomGOol002Yo
o`<00;]oo`800?mooeMoo`00:Woo00<007ooOol0_Goo0P00ogooEGoo000ZOol00`00Oomoo`2oOol0
0`00Oomoo`3oOomBOol002Yoo`03001oogoo0<1oo`800?mooe9oo`00:Woo00<007ooOol0`Woo0P00
1goo1000ogooAGoo000ZOol00`00Oomoo`34Ool00`00Oomoo`03Ool6003oOom4Ool002Yoo`03001o
ogoo0<Eoo`80009oo`P00?mood=oo`00:Woo00<007ooOol0agoo00<007oo00001`00ogoo@goo000Z
Ool00`00Oomoo`38Ool9003oOom3Ool002Yoo`03001oogoo0<Uoo`P00?mood=oo`00:Woo00<007oo
Ool0bWoo1P00ogooA7oo000ZOol3003;Ool4003oOom5Ool002Yoo`03001oogoo0<ioo`800?moodAo
o`00:Woo00<007ooOol0d7oo00<007ooOol0ogoo@Goo000ZOol00`00Oomoo`3AOol2003oOom1Ool0
02Yoo`03001oogoo0==oo`03001oogoo0?moocioo`00:Woo00<007ooOol0e7oo0P00ogoo?Woo000Z
Ool00`00Oomoo`3FOol00`00Oomoo`3oOolkOol002Yoo`03001oogoo0=Moo`800?mooc]oo`00:Woo
00<007ooOol0fGoo00<007ooOol0ogoo>7oo000ZOol00`00Oomoo`3JOol2003oOolhOol002Yoo`03
001oogoo0=aoo`03001oogoo0?moocEoo`00:Woo0`00gGoo0P001Woo1000ogoo:goo000ZOol00`00
Oomoo`3OOol00`00Oomoo`02Ool6003oOolZOol002Yoo`03001oogoo0>1oo`800003Ool0000000H0
0?moobUoo`00:Woo00<007ooOol0hWoo2@00ogoo:Goo000ZOol00`00Oomoo`3SOol8003oOolYOol0
02Yoo`03001oogoo0>=oo`P00?moobUoo`006goo1`0027oo00<007ooOol0i7oo1P00ogoo:Woo000N
Ool00`00Oomoo`09Ool00`00Oomoo`3UOol5003oOolZOol001ioo`03001oogoo00Uoo`03001oogoo
0>Yoo`03001oogoo0?moobMoo`007Woo00<007ooOol02Goo00<007ooOol0jgoo0P00ogoo9goo000N
Ool00`00Oomoo`09Ool5003[Ool00`00Oomoo`3oOolTOol001ioo`03001oogoo00Uoo`03001oogoo
0>ioo`800?moobAoo`007Woo00<007ooOol02Goo00<007ooOol0l7oo00<007ooOol0ogoo8Goo000N
Ool00`00Oomoo`09Ool00`00Oomoo`3aOol2003oOolQOol001ioo`03001oogoo00Uoo`03001oogoo
0?=oo`03001oogoo0?mooaioo`007Woo00<007ooOol02Goo00<007ooOol0m7oo00<007ooOol0ogoo
7Goo000KOol4000;Ool00`00Oomoo`3eOol2003oOolMOol001eoo`8000]oo`03001oogoo0?Moo`03
001oogoo0?mooaYoo`00:Woo00<007ooOol0n7oo0P001Goo1000ogoo4Goo000ZOol00`00Oomoo`3j
Ool01000Oomoogoo1P00ogoo47oo000ZOol00`00Oomoo`3kOol00`00Ool00007003oOol?Ool002Yo
o`<00?aoo`T00?moo`moo`00:Woo00<007ooOol0oGoo2000ogoo3goo000ZOol00`00Oomoo`3mOol8
003oOol?Ool002Yoo`03001oogoo0?ioo`H00?mooa1oo`00:Woo00<007ooOol0ogoo1000ogoo4Goo
000ZOol00`00Oomoo`3oOol4Ool2003oOol?Ool002Yoo`03001oogoo0?moo`Ioo`03001oogoo0?mo
o`aoo`00:Woo00<007ooOol0ogoo1goo0P00ogoo37oo000ZOol00`00Oomoo`3oOol9Ool00`00Oomo
o`3oOol9Ool002Yoo`03001oogoo0?moo`Yoo`03001oogoo0?moo`Qoo`00:Woo00<007ooOol0ogoo
2goo0P00ogoo27oo000ZOol3003oOol=Ool00`00Oomoo`3oOol5Ool002Yoo`03001oogoo0?moo`io
o`800?moo`Eoo`00:Woo00<007ooOol0ogoo47oo00<007ooOol0ogoo0Woo000ZOol00`00Oomoo`3o
OolAOol00`00Oomoo`3oOol1Ool002Yoo`03001oogoo0?mooa9oo`800?moo`5oo`00:Woo00<007oo
Ool0ogoo57oo00<007ooOol00goo1000mWoo000ZOol00`00Oomoo`3oOolEOol20002Ool6003eOol0
02Yoo`03001oogoo0?mooaMoo`T00?Aoo`00:Woo00<007ooOol0ogoo67oo2000m7oo000ZOol00`00
Oomoo`3oOolHOol8003dOol002Yoo`<00?mooaQoo`P00?Aoo`00:Woo00<007ooOol0ogoo6Goo1P00
mGoo000ZOol00`00Oomoo`3oOolJOol5003eOol002Yoo`03001oogoo0?mooamoo`03001oogoo0?9o
o`00:Woo00<007ooOol0ogoo87oo0P00lWoo000ZOol00`00Oomoo`3oOolROol00`00Oomoo`3_Ool0
02Yoo`03001oogoo0?moob=oo`03001oogoo0>ioo`00:Woo00<007ooOol0ogoo97oo0P00kWoo000Z
Ool00`00Oomoo`3oOolVOol00`00Oomoo`3[Ool002Yoo`03001oogoo0?moobMoo`03001oogoo0>Yo
o`00:Woo00<007ooOol0ogoo:7oo0P00jWoo000ZOol3003oOolZOol00`00Oomoo`3WOol002Yoo`03
001oogoo0?moob]oo`800>Moo`00:Woo00<007ooOol0ogoo;Goo00<007ooOol0i7oo000ZOol00`00
Oomoo`3oOol^Ool00`00Oomoo`3SOol002Yoo`03001oogoo0?moobmoo`8000=oo`@00=aoo`00:Woo
00<007ooOol0ogoo<Goo00<007oo00001@00fgoo0003Ool70006Ool30007Ool6000:Ool00`00Oomo
o`3oOolbOol8003JOol000Ioo`03001oogoo00Moo`<000Ioo`8000Eoo`03001oogoo00Moo`03001o
ogoo0?mooc9oo`P00=Yoo`001Woo00<007ooOol01goo0`003Woo00<007ooOol01Woo00<007ooOol0
ogoo<Woo2000fWoo0006Ool00`00Oomoo`0HOol00`00Oomoo`06Ool00`00Oomoo`3oOolbOol8003J
Ool000Ioo`03001oogoo01Qoo`03001oogoo00Ioo`D00?mooc5oo`H00=]oo`001Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0ogoo=7oo100000=oo`00Ool0fGoo0006Ool00`00Oomoo`0A
Ool20004Ool00`00Oomoo`07Ool00`00Oomoo`3oOoljOol00`00Oomoo`3GOol000Ioo`03001oogoo
015oo`H000Yoo`03001oogoo0?mooc]oo`03001oogoo0=Ioo`001Woo00<007ooOol04Goo00<007oo
Ool03Goo00<007ooOol0ogoo?7oo0P00eWoo0006Ool00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00
Oomoo`3oOolnOol00`00Oomoo`3COol000=oo`@001=oo`03001oogoo00eoo`03001oogoo0?moocmo
o`03001oogoo0=9oo`001Goo0P004goo1`002Goo00<007ooOol0ogoo@7oo0P00dWoo000ZOol00`00
Oomoo`3oOom2Ool00`00Oomoo`3?Ool002Yoo`03001oogoo0?mood=oo`03001oogoo0<ioo`00:Woo
00<007ooOol0ogooA7oo0P00cWoo000ZOol3003oOom6Ool00`00Oomoo`3;Ool002Yoo`03001oogoo
0?moodMoo`03001oogoo0<Yoo`00:Woo00<007ooOol0ogooB7oo0P00bWoo000ZOol00`00Oomoo`3o
Oom:Ool01000Oomoogoo1000`Woo000ZOol00`00Oomoo`3oOom;Ool00`00Ool000050031Ool002Yo
o`03001oogoo0?moodaoo`P00<1oo`00:Woo00<007ooOol0ogooC7oo2000`7oo000ZOol00`00Oomo
o`3oOom<Ool80030Ool002Yoo`03001oogoo0?moodaoo`P00<1oo`00:Woo00<007ooOol0ogooCGoo
1P00`Goo000ZOol00`00Oomoo`3oOom>Ool400000goo0000002oOol002Yoo`<00?mooeEoo`03001o
ogoo0;aoo`00:Woo00<007ooOol0ogooEWoo00<007ooOol0^goo000ZOol00`00Oomoo`3oOomGOol2
002kOol002Yoo`03001oogoo0?mooeUoo`03001oogoo0;Qoo`00:Woo00<007ooOol0ogooFWoo00<0
07ooOol0]goo000ZOol00`00Oomoo`3oOomKOol2002gOol002Yoo`03001oogoo0?mooeeoo`03001o
ogoo0;Aoo`00:Woo00<007ooOol0ogooGWoo00<007ooOol0/goo000ZOol00`00Oomoo`3oOomOOol0
0`00Oomoo`2bOol002Yoo`03001oogoo0?moof1oo`800;9oo`00:Woo0`00ogooHWoo00<007ooOol0
[goo000ZOol00`00Oomoo`3oOomSOol00`00Oomoo`2^Ool002Yoo`03001oogoo0?moofAoo`04001o
ogooOol4002XOol002Yoo`03001oogoo0?moofEoo`P00:Moo`00:Woo00<007ooOol0ogooIWoo2000
YWoo000ZOol00`00Oomoo`3oOomVOol8002VOol002Yoo`03001oogoo0?moofIoo`P00:Ioo`00:Woo
00<007ooOol0ogooIWoo2000YWoo000ZOol00`00Oomoo`3oOomWOol6002WOol002Yoo`03001oogoo
0?moofQoo`@00003Ool007oo0:Eoo`00:Woo00<007ooOol0ogooKWoo00<007ooOol0Xgoo000ZOol3
003oOom_Ool00`00Oomoo`2ROol002Yoo`03001oogoo0?moog1oo`800:9oo`00:Woo00<007ooOol0
ogooLWoo00<007ooOol0Wgoo000ZOol00`00Oomoo`3oOomcOol00`00Oomoo`2NOol002Yoo`03001o
ogoo0?moogAoo`8009ioo`00:Woo00<007ooOol0ogooMWoo00<007ooOol0Vgoo000ZOol00`00Oomo
o`3oOomgOol00`00Oomoo`2JOol001Yoo`P000Qoo`03001oogoo0?moogQoo`8009Yoo`006goo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol0ogooNWoo00<007ooOol0Ugoo000LOol00`00Oomo
o`0;Ool00`00Oomoo`3oOomkOol00`00Oomoo`2FOol001eoo`03001oogoo00Yoo`03001oogoo0?mo
ogaoo`03001oogoo09Eoo`007Woo00<007ooOol02Goo1@00ogooNgoo0P000goo1000SWoo000OOol0
0`00Oomoo`08Ool00`00Oomoo`3oOomoOol00`00Ool00005002=Ool0021oo`03001oogoo00Moo`03
001oogoo0?mooh1oo`P008aoo`008Goo00<007ooOol01Woo00<007ooOol0ogooP7oo2000S7oo000Q
Ool00`00Oomoo`06Ool00`00Oomoo`3oOon0Ool8002<Ool001]oo`03001oogoo00=oo`03001oogoo
00Ioo`03001oogoo0?mooh1oo`P008aoo`006goo0P000goo00<007ooOol01goo00<007ooOol0ogoo
PGoo1P00SGoo000MOol3000:Ool00`00Oomoo`3oOon2Ool400000goo001oo`2;Ool002Yoo`03001o
ogoo0?moohQoo`03001oogoo08Uoo`00:Woo00<007ooOol0ogooRGoo00<007ooOol0R7oo000ZOol3
003oOon:Ool20028Ool002Yoo`03001oogoo0?moohaoo`03001oogoo08Eoo`00:Woo00<007ooOol0
ogooSGoo00<007ooOol0Q7oo000ZOol00`00Oomoo`3oOon>Ool20024Ool002Yoo`03001oogoo0?mo
oi1oo`03001oogoo085oo`00:Woo00<007ooOol0ogooTGoo00<007ooOol0P7oo000ZOol00`00Oomo
o`3oOonBOol00`00Oomoo`1oOol002Yoo`03001oogoo0?mooi=oo`8007moo`00:Woo00<007ooOol0
ogooUGoo00<007ooOol0O7oo000ZOol00`00Oomoo`3oOonFOol00`00Oomoo`1kOol002Yoo`03001o
ogoo0?mooiMoo`8000=oo`@007Aoo`00:Woo0`00ogooVGoo00<007oo00001@00Lgoo000ZOol00`00
Oomoo`3oOonJOol8001bOol002Yoo`03001oogoo0?mooiYoo`P0079oo`00:Woo00<007ooOol0ogoo
VWoo2000LWoo000ZOol00`00Oomoo`3oOonJOol8001bOol002Yoo`03001oogoo0?mooi]oo`H007=o
o`00:Woo00<007ooOol0ogooW7oo1P00LWoo000ZOol00`00Oomoo`3oOonROol00`00Oomoo`1_Ool0
02Yoo`03001oogoo0?mooj=oo`03001oogoo06ioo`00:Woo00<007ooOol0ogooY7oo0P00KWoo000Z
Ool00`00Oomoo`3oOonVOol00`00Oomoo`1[Ool002Yoo`<00?moojMoo`03001oogoo06Yoo`00:Woo
00<007ooOol0ogooZ7oo00<007ooOol0JGoo000ZOol00`00Oomoo`3oOonYOol2001YOol002Yoo`03
001oogoo0?mooj]oo`03001oogoo06Ioo`00:Woo00<007ooOol0ogoo[7oo00<007ooOol0IGoo000Z
Ool00`00Oomoo`3oOon]Ool2001UOol002Yoo`03001oogoo0?moojmoo`03001oogoo069oo`00:Woo
00<007ooOol0ogoo/7oo00<007ooOol0HGoo000ZOol00`00Oomoo`3oOonaOol2001QOol002Yoo`03
001oogoo0?mook=oo`03001oogoo00@005Yoo`00:Woo0`00ogoo]7oo1`00FGoo000ZOol00`00Oomo
o`3oOondOol8001HOol002Yoo`03001oogoo0?mookAoo`P005Qoo`00:Woo00<007ooOol0ogoo]7oo
2000F7oo000ZOol00`00Oomoo`3oOondOol8001HOol002Yoo`03001oogoo0?mookEoo`H005Uoo`00
:Woo00<007ooOol0ogoo]Woo100000=oo`000000Egoo0002Ool80006Ool30007Ool6000:Ool00`00
Oomoo`3oOonmOol00`00Oomoo`1DOol000=oo`03001oogoo00=oo`03001oogoo00Aoo`<000Ioo`80
00Eoo`03001oogoo00Moo`03001oogoo0?mookioo`03001oogoo05=oo`0017oo00<007ooOol02Goo
0`003Woo00<007ooOol01Woo00<007ooOol0ogoo_goo00<007ooOol0DWoo0005Ool00`00Oomoo`0I
Ool00`00Oomoo`06Ool00`00Oomoo`3oOoo0Ool00`00Oomoo`1AOol000Ioo`03001oogoo01Qoo`03
001oogoo00Ioo`D00?mookmoo`80055oo`001goo00<007ooOol05goo00<007ooOol01Woo00<007oo
Ool0ogoo`goo00<007ooOol0CWoo0008Ool00`00Oomoo`0?Ool20004Ool00`00Oomoo`07Ool00`00
Oomoo`3oOoo4Ool00`00Oomoo`1=Ool000Uoo`03001oogoo00ioo`H000Yoo`03001oogoo0?moolEo
o`03001oogoo04aoo`002Goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol0ogooaWoo0P00
C7oo0003Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`3oOoo8Ool0
0`00Oomoo`19Ool000=oo`8000=oo`03001oogoo00moo`03001oogoo00eoo`03001oogoo0?moolUo
o`03001oogoo04Qoo`001Goo0`004Woo1`002Goo00<007ooOol0ogoobWoo00<007ooOol0Agoo000Z
Ool00`00Oomoo`3oOoo;Ool20017Ool002Yoo`03001oogoo0?mooleoo`03001oogoo00@0041oo`00
:Woo0`00ogoocWoo1`00?goo000ZOol00`00Oomoo`3oOoo>Ool8000nOol002Yoo`03001oogoo0?mo
olioo`P003ioo`00:Woo00<007ooOol0ogoocWoo2000?Woo000ZOol00`00Oomoo`3oOoo>Ool8000n
Ool002Yoo`03001oogoo0?moolmoo`H003moo`00:Woo00<007ooOol0ogood7oo100000=oo`00Ool0
?Goo000ZOol00`00Oomoo`3oOooFOol2000lOol002Yoo`03001oogoo0?moomQoo`03001oogoo03Uo
o`00:Woo00<007ooOol0ogoofGoo00<007ooOol0>7oo000ZOol00`00Oomoo`3oOooJOol00`00Oomo
o`0gOol002Yoo`<00?moom]oo`8003Moo`00:Woo00<007ooOol0ogoogGoo00<007ooOol0=7oo000Z
Ool00`00Oomoo`3oOooNOol00`00Oomoo`0cOol002Yoo`03001oogoo0?moommoo`8003=oo`00:Woo
00<007ooOol0ogoohGoo00<007ooOol0<7oo000ZOol00`00Oomoo`3oOooROol00`00Oomoo`0_Ool0
02Yoo`03001oogoo0?moon=oo`03001oogoo02ioo`00:Woo00<007ooOol0ogooi7oo0P00;Woo000Z
Ool00`00Oomoo`3oOooVOol00`00Oomoo`0[Ool002Yoo`03001oogoo0?moonMoo`03001oogoo00@0
02Ioo`00:Woo00<007ooOol0ogooj7oo1`009Goo000ZOol3003oOooXOol8000TOol002Yoo`03001o
ogoo0?moonQoo`P002Aoo`00:Woo00<007ooOol0ogooj7oo200097oo000ZOol00`00Oomoo`3oOooX
Ool8000TOol002Yoo`03001oogoo0?moonUoo`L002Aoo`00:Woo00<007ooOol0ogoojWoo10000Woo
00<007ooOol08Goo000ZOol00`00Oomoo`3oOooaOol2000QOol002Yoo`03001oogoo0?mooo=oo`03
001oogoo01ioo`00:Woo00<007ooOol0ogoom7oo00<007ooOol07Goo000ZOol00`00Oomoo`3oOooe
Ool00`00Oomoo`0LOol002Yoo`<00?moooIoo`8001aoo`00:Woo00<007ooOol0ogoon7oo00<007oo
Ool06Goo000ZOol00`00Oomoo`3oOooiOol00`00Oomoo`0HOol002Yoo`03001oogoo0?moooYoo`03
001oogoo01Moo`00:Woo00<007ooOol0ogoongoo0P005goo000ZOol00`00Oomoo`3oOoomOol00`00
Oomoo`0DOol002Yoo`03001oogoo0?moooioo`03001oogoo01=oo`0077oo10002Woo00<007ooOol0
ogooogoo00<007ooOol04Woo000KOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOooo
Ool1Ool00`00Oomoo`0AOol001Yoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo0?mooomo
o`9oo`800003Ool00000008000aoo`008Goo00<007ooOol01Woo00<007ooOol0ogooogoo17oo1P00
2goo000QOol00`00Oomoo`06Ool5003oOoooOol1Ool8000:Ool0021oo`03001oogoo00Moo`03001o
ogoo0?mooomoo`=oo`P000Yoo`007Goo0`002Woo00<007ooOol0ogooogoo0goo20002Woo000POol0
0`00Oomoo`07Ool00`00Oomoo`3oOoooOol3Ool8000:Ool0025oo`03001oogoo00Ioo`03001oogoo
0?mooomoo`Aoo`H000]oo`008Goo00<007ooOol01Woo00<007ooOol0ogooogoo1Goo100037oo000K
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOoooOolEOol001aoo`@000Yoo`03001o
ogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol0
02Yoo`03001oogoo0?mooomooaEoo`00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The Euler solution, shown by the dots, is quite close to the exact \
solution, shown by the solid line.  \n\tWe have used an option in the ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions to turn off intermediate plots and thereby save space. The \
option ",
  StyleBox["DisplayFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rule]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox["Identity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " creates a plot, but does not display the result. After the plots are \
overlaid with the ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, the display option was turned on again using ",
  StyleBox["DisplayFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rule]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " ",
  StyleBox["$DisplayFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  CellTags->"i:147"],

Cell[TextData[{
  "\tIf we wish to obtain the numerical solution at times between the \
timesteps we can apply an interpolation to the data and define a numerical \
function ",
  StyleBox["vEuler[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vEuler[t_]\  = \ \(Interpolation[solution]\)[t]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.37"],

Cell[BoxData[
    RowBox[{
      TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
        False,
        Editable->False], "[", "t", "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "One thing that we can do with this function is plot the difference between \
the numerical solution and the exact solution to see the error in the \
numerical method--see Cell ",
  ButtonBox["1.38",
    ButtonData:>"Cell 1.38",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(vExact[t_]\  = \ E^\(-t\)\  + \ t\  - \ 1;\)\), "\n", 
    \(\(p1\  = \ Plot[vEuler[t]\  - \ vExact[t], {t, 0, 4}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.38"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.603319 14.6133 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -3 -9 ]
[.5 .59082 3 0 ]
[.7381 .59082 -3 -9 ]
[.7381 .59082 3 0 ]
[.97619 .59082 -3 -9 ]
[.97619 .59082 3 0 ]
[.01131 .01879 -30 -4.5 ]
[.01131 .01879 0 4.5 ]
[.01131 .16492 -30 -4.5 ]
[.01131 .16492 0 4.5 ]
[.01131 .31105 -30 -4.5 ]
[.01131 .31105 0 4.5 ]
[.01131 .45719 -30 -4.5 ]
[.01131 .45719 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(1)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(2)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(3)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(4)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01879 m
.03006 .01879 L
s
[(-0.04)] .01131 .01879 1 0 Mshowa
.02381 .16492 m
.03006 .16492 L
s
[(-0.03)] .01131 .16492 1 0 Mshowa
.02381 .31105 m
.03006 .31105 L
s
[(-0.02)] .01131 .31105 1 0 Mshowa
.02381 .45719 m
.03006 .45719 L
s
[(-0.01)] .01131 .45719 1 0 Mshowa
.125 Mabswid
.02381 .04801 m
.02756 .04801 L
s
.02381 .07724 m
.02756 .07724 L
s
.02381 .10647 m
.02756 .10647 L
s
.02381 .13569 m
.02756 .13569 L
s
.02381 .19415 m
.02756 .19415 L
s
.02381 .22337 m
.02756 .22337 L
s
.02381 .2526 m
.02756 .2526 L
s
.02381 .28183 m
.02756 .28183 L
s
.02381 .34028 m
.02756 .34028 L
s
.02381 .36951 m
.02756 .36951 L
s
.02381 .39873 m
.02756 .39873 L
s
.02381 .42796 m
.02756 .42796 L
s
.02381 .48641 m
.02756 .48641 L
s
.02381 .51564 m
.02756 .51564 L
s
.02381 .54487 m
.02756 .54487 L
s
.02381 .57409 m
.02756 .57409 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04262 .48159 L
.06244 .37264 L
.08426 .27463 L
.10458 .20211 L
.12414 .1468 L
.14264 .10499 L
.16305 .07038 L
.18163 .0469 L
.19132 .03755 L
.2016 .02972 L
.21038 .0246 L
.22004 .02017 L
.22524 .01828 L
.23018 .01688 L
.23461 .01592 L
.23712 .01551 L
.23945 .0152 L
.24076 .01506 L
.24218 .01494 L
.24352 .01485 L
.24475 .01479 L
.24587 .01475 L
.24709 .01472 L
.24837 .01472 L
.24956 .01473 L
.25023 .01474 L
.25095 .01477 L
.25228 .01483 L
.25357 .0149 L
.25476 .01499 L
.25746 .01526 L
.26033 .01563 L
.2649 .01628 L
.2697 .01714 L
.27497 .01835 L
.2798 .01971 L
.29808 .02681 L
.31782 .03721 L
.33619 .04883 L
.37523 .07877 L
.41673 .11548 L
.45671 .15323 L
.49518 .19008 L
.5361 .22869 L
.5755 .26452 L
.61339 .29722 L
.65373 .32983 L
.69255 .35887 L
.73383 .38714 L
Mistroke
.77359 .41189 L
.81184 .43346 L
.85253 .45414 L
.89172 .47197 L
.93335 .48885 L
.97347 .50324 L
.97619 .50415 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00Oogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo
@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00
ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo0012Ool00`00Oomoo`3oOool
Ool0049oo`03001oogoo0?moooaoo`00@Woo00<007ooOol0ogooo7oo0012Ool00`00Oomoo`3oOool
Ool0049oo`03001oogoo0?moooaoo`00@Woo00<007ooOol0ogooo7oo000@Ool40008Ool30009Ool4
000:Ool50007Ool00`00Oomoo`3oOoolOol000moo`03001oogoo009oo`03001oogoo00Eoo`<000Qo
o`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo0?moooaoo`003goo00<0
07ooOol00Woo00<007ooOol01Goo0`0027oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0
1goo00<007ooOol0JWoo4@00ogooPGoo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool90007Ool00`00Oomoo`1XOol2000AOol5003oOomlOol0009oo`T000=o
o`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00Moo`@006Aoo`<001Qoo`@00?moogQoo`000Woo2@000goo00<007ooOol017oo00<0
07ooOol03Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01goo00<0
07ooOol0HWoo0`007goo0`00ogooMGoo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool01@00Oomoogoo00002Goo00<007ooOol0Ggoo0`009Goo0P00ogooLgoo
000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000Oomo
o`002Goo00<007ooOol0GGoo0P00:Woo0`00ogooL7oo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000Oomoo`002Goo00<007ooOol0G7oo00<007ooOol0
;Goo0P00ogooKWoo000?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Ool00009Ool00`00Oomoo`1KOol00`00Oomoo`0`Ool2003oOom/Ool000moo`03001o
ogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo00Qoo`8000Uoo`03001oogoo05Uo
o`8003Eoo`800?moofYoo`0047oo100057oo10002goo0P002Goo00<007ooOol0F7oo00<007ooOol0
=goo0P00ogooJ7oo0012Ool00`00Oomoo`1FOol2000lOol2003oOomVOol0049oo`03001oogoo05Eo
o`03001oogoo03ioo`800?moofAoo`00@Woo00<007ooOol0E7oo00<007ooOol0@Goo00<007ooOol0
ogooHGoo0012Ool00`00Oomoo`1COol00`00Oomoo`13Ool2003oOomQOol0049oo`03001oogoo059o
o`03001oogoo04Ioo`03001oogoo0?mooeioo`00@Woo00<007ooOol0DGoo00<007ooOol0B7oo00<0
07ooOol0ogooGGoo0012Ool00`00Oomoo`1@Ool00`00Oomoo`1:Ool2003oOomMOol0049oo`<004mo
o`03001oogoo04eoo`03001oogoo0?mooeYoo`00@Woo00<007ooOol0Cgoo00<007ooOol0CWoo0P00
ogooFWoo0012Ool00`00Oomoo`1>Ool00`00Oomoo`1AOol00`00Oomoo`3oOomGOol0049oo`03001o
ogoo04eoo`03001oogoo05=oo`03001oogoo0?mooeIoo`00@Woo00<007ooOol0C7oo00<007ooOol0
EGoo0P00ogooEWoo0012Ool00`00Oomoo`1<Ool00`00Oomoo`1GOol00`00Oomoo`3oOomCOol0049o
o`03001oogoo04]oo`03001oogoo05Uoo`03001oogoo0?mooe9oo`00@Woo00<007ooOol0BWoo00<0
07ooOol0Fgoo0P00ogooDWoo0012Ool00`00Oomoo`19Ool00`00Oomoo`1NOol00`00Oomoo`3oOom?
Ool0049oo`03001oogoo04Uoo`03001oogoo05moo`03001oogoo0?moodioo`00@Woo00<007ooOol0
B7oo00<007ooOol0HGoo0P00ogooCWoo0012Ool00`00Oomoo`17Ool00`00Oomoo`1TOol00`00Oomo
o`3oOom;Ool0049oo`03001oogoo04Ioo`03001oogoo06Ioo`03001oogoo0?moodYoo`00@Woo00<0
07ooOol0AWoo00<007ooOol0Igoo0P00ogooBWoo0012Ool00`00Oomoo`15Ool00`00Oomoo`1ZOol0
0`00Oomoo`3oOom7Ool0049oo`<004Aoo`03001oogoo06aoo`03001oogoo0?moodIoo`00@Woo00<0
07ooOol0A7oo00<007ooOol0KGoo0P00ogooAWoo0012Ool00`00Oomoo`13Ool00`00Oomoo`1`Ool0
0`00Oomoo`3oOom3Ool0049oo`03001oogoo04=oo`03001oogoo075oo`03001oogoo0?mood9oo`00
@Woo00<007ooOol0@Woo00<007ooOol0Lgoo00<007ooOol0ogoo@Goo0012Ool00`00Oomoo`11Ool0
0`00Oomoo`1eOol00`00Oomoo`3oOom0Ool0049oo`03001oogoo045oo`03001oogoo07Ioo`03001o
ogoo0?moocmoo`00@Woo00<007ooOol0@7oo00<007ooOol0N7oo0P00ogoo?goo0012Ool00`00Oomo
o`10Ool00`00Oomoo`1jOol00`00Oomoo`3oOollOol0049oo`03001oogoo03moo`03001oogoo07ao
o`03001oogoo0?mooc]oo`00@Woo00<007ooOol0?Woo00<007ooOol0OWoo00<007ooOol0ogoo>Woo
0012Ool00`00Oomoo`0nOol00`00Oomoo`1oOol00`00Oomoo`3oOoliOol0049oo`03001oogoo03eo
o`03001oogoo085oo`03001oogoo0?moocQoo`00@Woo00<007ooOol0?Goo00<007ooOol0PWoo00<0
07ooOol0ogoo=goo0012Ool00`00Oomoo`0lOol00`00Oomoo`24Ool2003oOolgOol0049oo`03001o
ogoo03]oo`03001oogoo08Moo`03001oogoo0?moocAoo`00@Woo0`00>goo00<007ooOol0R7oo00<0
07ooOol0ogoo<goo0012Ool00`00Oomoo`0jOol00`00Oomoo`2:Ool00`00Oomoo`3oOolbOol0049o
o`03001oogoo03Yoo`03001oogoo08]oo`03001oogoo0?mooc5oo`00@Woo00<007ooOol0>Goo00<0
07ooOol0SGoo00<007ooOol0ogoo<7oo0012Ool00`00Oomoo`0iOol00`00Oomoo`2>Ool2003oOol`
Ool0049oo`03001oogoo03Qoo`03001oogoo095oo`03001oogoo0?moobeoo`00@Woo00<007ooOol0
>7oo00<007ooOol0TWoo00<007ooOol0ogoo;7oo0012Ool00`00Oomoo`0hOol00`00Oomoo`2COol0
0`00Oomoo`3oOol[Ool0049oo`03001oogoo03Moo`03001oogoo09Eoo`03001oogoo0?moobYoo`00
@Woo00<007ooOol0=goo00<007ooOol0UWoo00<007ooOol0ogoo:Goo0012Ool00`00Oomoo`0fOol0
0`00Oomoo`2HOol00`00Oomoo`3oOolXOol0049oo`03001oogoo03Ioo`03001oogoo09Uoo`03001o
ogoo0?moobMoo`00@Woo00<007ooOol0=Goo00<007ooOol0Vgoo00<007ooOol0ogoo9Woo0012Ool0
0`00Oomoo`0eOol00`00Oomoo`2LOol00`00Oomoo`3oOolUOol0049oo`03001oogoo03Aoo`03001o
ogoo09ioo`03001oogoo0?moobAoo`00@Woo0`00=7oo00<007ooOol0Wgoo00<007ooOol0ogoo8goo
0012Ool00`00Oomoo`0cOol00`00Oomoo`2QOol00`00Oomoo`3oOolROol0049oo`03001oogoo03=o
o`03001oogoo0:9oo`03001oogoo0?moob5oo`00@Woo00<007ooOol0<goo00<007ooOol0Xgoo00<0
07ooOol0ogoo87oo0012Ool00`00Oomoo`0bOol00`00Oomoo`2UOol00`00Oomoo`3oOolOOol0049o
o`03001oogoo039oo`03001oogoo0:Ioo`03001oogoo0?mooaioo`00@Woo00<007ooOol0<Goo00<0
07ooOol0Z7oo00<007ooOol0ogoo7Goo0012Ool00`00Oomoo`0aOol00`00Oomoo`2YOol00`00Oomo
o`3oOolLOol0049oo`03001oogoo031oo`03001oogoo0:]oo`03001oogoo0?mooa]oo`00@Woo00<0
07ooOol0<7oo00<007ooOol0[7oo0P00ogoo6goo0012Ool00`00Oomoo`0`Ool00`00Oomoo`2^Ool0
0`00Oomoo`3oOolHOol0011oo`@000Qoo`<000Uoo`@000Qoo`@000Yoo`03001oogoo02moo`03001o
ogoo0;1oo`03001oogoo0?mooaMoo`003goo00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0;goo00<0
07ooOol0/Goo00<007ooOol0ogoo5Woo000?Ool00`00Oomoo`02Ool00`00Oomoo`05Ool30008Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0_Ool0
0`00Oomoo`2bOol00`00Oomoo`3oOolEOol000ioo`03001oogoo00Aoo`03001oogoo00ioo`03001o
ogoo00Aoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo02ioo`03001oogoo0;Aoo`03001o
ogoo0?mooaAoo`000Woo2@000goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<0
07ooOol02Goo00<007ooOol01Woo1000;Goo00<007ooOol0]Goo00<007ooOol0ogoo4goo0002Ool9
0003Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`0^Ool00`00Oomoo`2fOol00`00Oomoo`3oOolBOol000ioo`03001oogoo00Ao
o`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Eoo`<000Yoo`03001oogoo02eoo`03001o
ogoo0;Qoo`03001oogoo0?mooa5oo`003Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol0
17oo00<007ooOol027oo00<007ooOol01goo00<007ooOol0;Goo00<007ooOol0^Goo00<007ooOol0
ogoo47oo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`09Ool0
0`00Oomoo`06Ool00`00Oomoo`0]Ool00`00Oomoo`2jOol00`00Oomoo`3oOol?Ool000moo`03001o
ogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Ioo`03001o
ogoo02aoo`03001oogoo0;aoo`03001oogoo0?moo`ioo`003goo00<007ooOol00Woo00<007ooOol0
47oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0
;7oo00<007ooOol0_Goo00<007ooOol0ogoo3Goo000@Ool4000DOol40008Ool4000:Ool00`00Oomo
o`0[Ool00`00Oomoo`2oOol00`00Oomoo`3oOol<Ool0049oo`03001oogoo02]oo`03001oogoo0<1o
o`03001oogoo0?moo`]oo`00@Woo00<007ooOol0:goo00<007ooOol0`Goo00<007ooOol0ogoo2Woo
0012Ool00`00Oomoo`0ZOol00`00Oomoo`33Ool00`00Oomoo`3oOol9Ool0049oo`03001oogoo02Yo
o`03001oogoo0<Aoo`03001oogoo0?moo`Qoo`00@Woo00<007ooOol0:Woo00<007ooOol0aGoo00<0
07ooOol0ogoo1goo0012Ool00`00Oomoo`0YOol00`00Oomoo`37Ool2003oOol7Ool0049oo`03001o
ogoo02Uoo`03001oogoo0<Uoo`03001oogoo0?moo`Aoo`00@Woo0`00:Goo00<007ooOol0bWoo00<0
07ooOol0ogoo0goo0012Ool00`00Oomoo`0XOol00`00Oomoo`3<Ool00`00Oomoo`3oOol2Ool0049o
o`03001oogoo02Qoo`03001oogoo0<eoo`03001oogoo0?moo`5oo`00@Woo00<007ooOol0:7oo00<0
07ooOol0cWoo00<007ooOol0ogoo0012Ool00`00Oomoo`0WOol00`00Oomoo`3@Ool00`00Oomoo`3n
Ool0049oo`03001oogoo02Moo`03001oogoo0=5oo`03001oogoo0?eoo`00@Woo00<007ooOol09goo
00<007ooOol0dWoo00<007ooOol0o7oo0012Ool00`00Oomoo`0VOol00`00Oomoo`3DOol00`00Oomo
o`3kOol0049oo`03001oogoo02Ioo`03001oogoo0=Eoo`03001oogoo0?Yoo`00@Woo00<007ooOol0
9Woo00<007ooOol0eWoo00<007ooOol0nGoo0012Ool00`00Oomoo`0VOol00`00Oomoo`3GOol00`00
Oomoo`3hOol0049oo`03001oogoo02Eoo`03001oogoo0=Uoo`03001oogoo0?Moo`00@Woo00<007oo
Ool09Goo00<007ooOol0fWoo00<007ooOol0mWoo0012Ool00`00Oomoo`0UOol00`00Oomoo`3KOol0
0`00Oomoo`3eOol0049oo`03001oogoo02Aoo`03001oogoo0=eoo`03001oogoo0?Aoo`00@Woo0`00
97oo00<007ooOol0gWoo00<007ooOol0lgoo0012Ool00`00Oomoo`0TOol00`00Oomoo`3OOol00`00
Oomoo`3bOol0049oo`03001oogoo02Aoo`03001oogoo0>1oo`03001oogoo0?5oo`00@Woo00<007oo
Ool08goo00<007ooOol0hWoo0P00lGoo0012Ool00`00Oomoo`0SOol00`00Oomoo`3TOol00`00Oomo
o`3^Ool0049oo`03001oogoo02=oo`03001oogoo0>Eoo`03001oogoo0>eoo`00@Woo00<007ooOol0
8goo00<007ooOol0iWoo00<007ooOol0k7oo0012Ool00`00Oomoo`0ROol00`00Oomoo`3XOol00`00
Oomoo`3[Ool0049oo`03001oogoo029oo`03001oogoo0>Uoo`03001oogoo0>Yoo`00@Woo00<007oo
Ool08Woo00<007ooOol0jWoo00<007ooOol0jGoo0012Ool00`00Oomoo`0ROol00`00Oomoo`3[Ool0
0`00Oomoo`3XOol0049oo`03001oogoo025oo`03001oogoo0>eoo`03001oogoo0>Moo`00@Woo00<0
07ooOol08Goo00<007ooOol0kWoo00<007ooOol0iWoo0012Ool00`00Oomoo`0QOol00`00Oomoo`3_
Ool00`00Oomoo`3UOol0049oo`03001oogoo025oo`03001oogoo0?1oo`03001oogoo0>Aoo`00@Woo
00<007ooOol087oo00<007ooOol0lWoo00<007ooOol0hgoo0012Ool3000POol00`00Oomoo`3cOol0
0`00Oomoo`3ROol0049oo`03001oogoo021oo`03001oogoo0?Aoo`03001oogoo0>5oo`00@Woo00<0
07ooOol07goo00<007ooOol0mWoo00<007ooOol0h7oo0012Ool00`00Oomoo`0OOol00`00Oomoo`3g
Ool00`00Oomoo`3OOol0049oo`03001oogoo01moo`03001oogoo0?Qoo`03001oogoo0=ioo`00@Woo
00<007ooOol07goo00<007ooOol0nGoo00<007ooOol0gGoo0012Ool00`00Oomoo`0NOol00`00Oomo
o`3kOol2003MOol0049oo`03001oogoo01ioo`03001oogoo0?eoo`03001oogoo0=Yoo`00@Woo00<0
07ooOol07Woo00<007ooOol0oWoo00<007ooOol0fGoo0012Ool00`00Oomoo`0NOol00`00Oomoo`3o
Ool00`00Oomoo`3HOol0049oo`03001oogoo01eoo`03001oogoo0?moo`9oo`03001oogoo0=Moo`00
@Woo00<007ooOol07Goo00<007ooOol0ogoo0goo00<007ooOol0eWoo0012Ool00`00Oomoo`0MOol0
0`00Oomoo`3oOol4Ool2003FOol0049oo`03001oogoo01eoo`03001oogoo0?moo`Ioo`03001oogoo
0==oo`00@Woo00<007ooOol077oo00<007ooOol0ogoo27oo00<007ooOol0dWoo0012Ool3000LOol0
0`00Oomoo`3oOol9Ool00`00Oomoo`3AOol0049oo`03001oogoo01aoo`03001oogoo0?moo`Yoo`03
001oogoo0=1oo`00@Woo00<007ooOol077oo00<007ooOol0ogoo2goo0P00d7oo0012Ool00`00Oomo
o`0KOol00`00Oomoo`3oOol>Ool00`00Oomoo`3=Ool0049oo`03001oogoo01]oo`03001oogoo0?mo
o`moo`03001oogoo0<aoo`00@Woo00<007ooOol06goo00<007ooOol0ogoo47oo00<007ooOol0bgoo
0012Ool00`00Oomoo`0KOol00`00Oomoo`3oOolAOol00`00Oomoo`3:Ool0049oo`03001oogoo01]o
o`03001oogoo0?mooa9oo`03001oogoo0<Uoo`00@Woo00<007ooOol06Woo00<007ooOol0ogoo57oo
0P00bGoo0012Ool00`00Oomoo`0JOol00`00Oomoo`3oOolFOol00`00Oomoo`36Ool0049oo`03001o
ogoo01Yoo`03001oogoo0?mooaMoo`03001oogoo0<Eoo`0047oo100027oo0`002Goo10001Woo2000
27oo00<007ooOol06Woo00<007ooOol0ogoo67oo00<007ooOol0a7oo000?Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`0IOol00`00Oomoo`3oOolJOol20034Ool000moo`03001oogoo009oo`03001o
ogoo00Eoo`<000Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo01Uo
o`03001oogoo0?mooaaoo`03001oogoo0<5oo`003Woo00<007ooOol017oo00<007ooOol03Woo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol0ogoo7Goo
00<007ooOol0`7oo0002Ool90003Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`09Ool4000HOol00`00Oomoo`3oOolNOol00`00Oomoo`2oOol0009o
o`T000=oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo01Qoo`03001oogoo0?moob1oo`800;moo`003Woo00<007ooOol017oo00<0
07ooOol03Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol01goo00<007ooOol067oo00<0
07ooOol0ogoo8Woo00<007ooOol0_7oo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomo
o`04Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0HOol00`00Oomoo`3oOolSOol00`00
Oomoo`2kOol000ioo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Uo
o`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo0?moobAoo`03001oogoo0;Yoo`003goo00<0
07ooOol00Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol05goo00<007ooOol0ogoo9Woo00<007ooOol0^Goo000?Ool00`00Oomo
o`02Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20003Ool00`00Oomoo`07Ool0
0`00Oomoo`0GOol00`00Oomoo`3oOolWOol2002iOol0011oo`@001Aoo`@000Uoo`<000Yoo`03001o
ogoo01Moo`03001oogoo0?moobUoo`03001oogoo0;Ioo`00@Woo00<007ooOol05goo00<007ooOol0
ogoo:Woo00<007ooOol0]Goo0012Ool00`00Oomoo`0GOol00`00Oomoo`3oOol[Ool00`00Oomoo`2d
Ool0049oo`03001oogoo01Ioo`03001oogoo0?moobeoo`800;Aoo`00@Woo00<007ooOol05Woo00<0
07ooOol0ogoo;goo00<007ooOol0/Goo0012Ool00`00Oomoo`0FOol00`00Oomoo`3oOol`Ool00`00
Oomoo`2`Ool0049oo`03001oogoo01Ioo`03001oogoo0?mooc5oo`800;1oo`00@Woo00<007ooOol0
5Goo00<007ooOol0ogoo=7oo00<007ooOol0[Goo0012Ool3000EOol00`00Oomoo`3oOoleOol00`00
Oomoo`2/Ool0049oo`03001oogoo01Eoo`03001oogoo0?moocIoo`800:aoo`00@Woo00<007ooOol0
5Goo00<007ooOol0ogoo>7oo00<007ooOol0ZGoo0012Ool00`00Oomoo`0DOol00`00Oomoo`3oOolj
Ool00`00Oomoo`2XOol0049oo`03001oogoo01Aoo`03001oogoo0?mooc]oo`800:Qoo`00@Woo00<0
07ooOol057oo00<007ooOol0ogoo?Goo00<007ooOol0YGoo0012Ool00`00Oomoo`0DOol00`00Oomo
o`3oOolnOol00`00Oomoo`2TOol0049oo`03001oogoo01=oo`03001oogoo0?mood1oo`800:Aoo`00
@Woo00<007ooOol04goo00<007ooOol0ogoo@Woo00<007ooOol0XGoo0012Ool00`00Oomoo`0COol0
0`00Oomoo`3oOom3Ool00`00Oomoo`2POol0049oo`03001oogoo01=oo`03001oogoo0?moodAoo`80
0:1oo`00@Woo00<007ooOol04goo00<007ooOol0ogooAWoo00<007ooOol0WGoo0012Ool00`00Oomo
o`0BOol00`00Oomoo`3oOom8Ool2002MOol0049oo`03001oogoo019oo`03001oogoo0?moodYoo`03
001oogoo09Yoo`00@Woo00<007ooOol04Woo00<007ooOol0ogooBgoo0P00VWoo0012Ool00`00Oomo
o`0BOol00`00Oomoo`3oOom=Ool00`00Oomoo`2GOol0049oo`<0015oo`03001oogoo0?moodmoo`80
09Moo`00@Woo00<007ooOol04Goo00<007ooOol0ogooDGoo00<007ooOol0U7oo0012Ool00`00Oomo
o`0AOol00`00Oomoo`3oOomBOol00`00Oomoo`2COol0049oo`03001oogoo015oo`03001oogoo0?mo
oe=oo`8009=oo`00@Woo00<007ooOol04Goo00<007ooOol0ogooEGoo00<007ooOol0T7oo0012Ool0
0`00Oomoo`0@Ool00`00Oomoo`3oOomGOol2002@Ool0049oo`03001oogoo011oo`03001oogoo0?mo
oeUoo`03001oogoo08eoo`00@Woo00<007ooOol047oo00<007ooOol0ogooFWoo0P00SGoo0012Ool0
0`00Oomoo`0@Ool00`00Oomoo`3oOomLOol00`00Oomoo`2:Ool0049oo`03001oogoo011oo`03001o
ogoo0?mooeeoo`8008Yoo`00@Woo00<007ooOol047oo00<007ooOol0ogooGgoo00<007ooOol0Qgoo
0012Ool00`00Oomoo`0?Ool00`00Oomoo`3oOomQOol20027Ool0049oo`03001oogoo00moo`03001o
ogoo0?moof=oo`8008Eoo`00@Woo00<007ooOol03goo00<007ooOol0ogooIGoo00<007ooOol0PWoo
0012Ool00`00Oomoo`0?Ool00`00Oomoo`3oOomVOol20022Ool0049oo`<000moo`03001oogoo0?mo
ofQoo`80081oo`00@Woo00<007ooOol03Woo00<007ooOol0ogooJgoo00<007ooOol0OGoo0012Ool0
0`00Oomoo`0>Ool00`00Oomoo`3oOom/Ool2001mOol0049oo`03001oogoo00ioo`03001oogoo0?mo
ofioo`03001oogoo07Yoo`00@Woo00<007ooOol03Woo00<007ooOol0ogooKgoo0P00NWoo0012Ool0
0`00Oomoo`0>Ool00`00Oomoo`3oOomaOol2001hOol0049oo`03001oogoo00ioo`03001oogoo0?mo
og=oo`03001oogoo07Eoo`00@Woo00<007ooOol03Goo00<007ooOol0ogooMGoo0P00MGoo0012Ool0
0`00Oomoo`0=Ool00`00Oomoo`3oOomgOol2001cOol0049oo`03001oogoo00eoo`03001oogoo0?mo
ogUoo`03001oogoo071oo`00@Woo00<007ooOol03Goo00<007ooOol0ogooNWoo0P00L7oo0012Ool0
0`00Oomoo`0=Ool00`00Oomoo`3oOomlOol2001^Ool0049oo`03001oogoo00eoo`03001oogoo0?mo
ogioo`8006aoo`00@Woo00<007ooOol037oo00<007ooOol0ogooPGoo00<007ooOol0JGoo0012Ool0
0`00Oomoo`0<Ool00`00Oomoo`3oOon2Ool2001YOol0049oo`<000aoo`03001oogoo0?moohAoo`80
06Moo`00@Woo00<007ooOol037oo00<007ooOol0ogooQWoo00<007ooOol0I7oo0012Ool00`00Oomo
o`0<Ool00`00Oomoo`3oOon7Ool2001TOol0049oo`03001oogoo00]oo`03001oogoo0?moohYoo`80
069oo`00@Woo00<007ooOol02goo00<007ooOol0ogooS7oo0P00H7oo0012Ool00`00Oomoo`0;Ool0
0`00Oomoo`3oOon>Ool2001NOol0049oo`03001oogoo00]oo`03001oogoo0?mooi1oo`8005aoo`00
@Woo00<007ooOol02goo00<007ooOol0ogooTWoo0P00FWoo0012Ool00`00Oomoo`0;Ool00`00Oomo
o`3oOonDOol2001HOol0049oo`03001oogoo00Yoo`03001oogoo0?mooiMoo`8005Ioo`00@Woo00<0
07ooOol02Woo00<007ooOol0ogooVGoo0P00E7oo000@Ool40008Ool30009Ool40007Ool70008Ool0
0`00Oomoo`0:Ool00`00Oomoo`3oOonKOol2001BOol000moo`03001oogoo009oo`03001oogoo00Eo
o`<000Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo0?mooieoo`80051oo`003goo00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0ogooWgoo0P00CWoo
000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`3oOonQOol2001<Ool0009oo`T000=oo`03001oogoo00Ao
o`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Uoo`@000Qoo`03001o
ogoo0?moojAoo`8004Yoo`000Woo2@000goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0ogooYWoo0`00Agoo
000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`3oOonYOol20015Ool000ioo`03001oogoo00Aoo`03001o
ogoo00ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo0?mooj]oo`8004=oo`003Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0ogoo[Goo0P00@Goo000?Ool0
0`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`3oOon`Ool2000oOol000moo`03001oogoo009oo`03001oogoo011o
o`03001oogoo009oo`03001oogoo00Aoo`@000]oo`03001oogoo00Qoo`03001oogoo0?mook9oo`<0
03aoo`0047oo100057oo10002Goo0P002goo00<007ooOol027oo00<007ooOol0ogoo]Goo0P00>Woo
0012Ool00`00Oomoo`08Ool00`00Oomoo`3oOongOol2000hOol0049oo`03001oogoo00Qoo`03001o
ogoo0?mookUoo`<003Eoo`00@Woo00<007ooOol027oo00<007ooOol0ogoo_7oo0P00<goo0012Ool0
0`00Oomoo`07Ool00`00Oomoo`3oOonoOol3000`Ool0049oo`03001oogoo00Moo`03001oogoo0?mo
ol9oo`8002ioo`00@Woo00<007ooOol01goo00<007ooOol0ogooa7oo0P00;7oo0012Ool00`00Oomo
o`07Ool00`00Oomoo`3oOoo6Ool3000YOol0049oo`<000Moo`03001oogoo0?moolUoo`8002Moo`00
@Woo00<007ooOol01goo00<007ooOol0ogoobgoo0`0097oo0012Ool00`00Oomoo`06Ool00`00Oomo
o`3oOoo?Ool3000QOol0049oo`03001oogoo00Ioo`03001oogoo0?moom9oo`<001ioo`00@Woo00<0
07ooOol01Woo00<007ooOol0ogooeGoo0`006goo0012Ool00`00Oomoo`06Ool00`00Oomoo`3oOooH
Ool3000HOol0049oo`03001oogoo00Ioo`03001oogoo0?moom]oo`<001Eoo`00@Woo00<007ooOol0
1Woo00<007ooOol0ogoogWoo0`004Woo0012Ool00`00Oomoo`05Ool00`00Oomoo`3oOooROol3000?
Ool0049oo`03001oogoo00Eoo`03001oogoo0?moonEoo`03001oogoo00aoo`00@Woo00<007ooOol0
1Goo00<007ooOol0ogooiWoo00<007ooOol02goo0012Ool00`00Oomoo`05Ool00`00Oomoo`3oOood
Ool0049oo`03001oogoo00Eoo`03001oogoo0?moooAoo`00@Woo00<007ooOol01Goo00<007ooOol0
ogoom7oo0012Ool00`00Oomoo`05Ool00`00Oomoo`3oOoodOol0049oo`03001oogoo00Aoo`03001o
ogoo0?moooEoo`00@Woo0`0017oo00<007ooOol0ogoomGoo0012Ool00`00Oomoo`04Ool00`00Oomo
o`3oOooeOol0049oo`03001oogoo00Aoo`03001oogoo0?moooEoo`00@Woo00<007ooOol017oo00<0
07ooOol0ogoomGoo0012Ool00`00Oomoo`04Ool00`00Oomoo`3oOooeOol0049oo`03001oogoo00=o
o`03001oogoo0?moooIoo`00@Woo00<007ooOol00goo00<007ooOol0ogoomWoo0012Ool00`00Oomo
o`03Ool00`00Oomoo`3oOoofOol0049oo`03001oogoo00=oo`03001oogoo0?moooIoo`00@Woo00<0
07ooOol00goo00<007ooOol0ogoomWoo0012Ool00`00Oomoo`03Ool00`00Oomoo`3oOoofOol0049o
o`03001oogoo009oo`03001oogoo0?moooMoo`00@Woo00<007ooOol00Woo00<007ooOol0ogoomgoo
0012Ool00`00Oomoo`02Ool00`00Oomoo`3oOoogOol0049oo`03001oogoo009oo`03001oogoo0?mo
ooMoo`00@Woo0`000Woo00<007ooOol0ogoomgoo0012Ool00`00Oomoo`02Ool00`00Oomoo`3oOoog
Ool0049oo`03001oogoo009oo`03001oogoo0?moooMoo`00@Woo00D007ooOomoo`000?moooYoo`00
@Woo00D007ooOomoo`000?moooYoo`00@Woo00D007ooOomoo`000?moooYoo`00@Woo00D007ooOomo
o`000?moooYoo`00@Woo00D007ooOomoo`000?moooYoo`00@Woo00D007ooOomoo`000?moooYoo`00
@Woo00@007ooOol00?mooo]oo`00@Woo00@007ooOol007Eoo`L007Aoo`P007Ioo`@007Yoo`D000Uo
o`00@Woo00@007ooOol007Qoo`03001oogoo07Ioo`03001oogoo00=oo`03001oogoo07=oo`03001o
ogoo009oo`03001oogoo07Uoo`03001oogoo00Uoo`00@Woo00@007ooOol007Qoo`03001oogoo07Mo
o`03001oogoo07Moo`03001oogoo00Aoo`03001oogoo07Qoo`03001oogoo00Uoo`00@Woo00@007oo
Ool007Qoo`03001oogoo07Qoo`03001oogoo07eoo`03001oogoo079oo`T000Uoo`00@Woo00@007oo
Ool007Qoo`03001oogoo07Uoo`03001oogoo07aoo`03001oogoo07=oo`03001oogoo009oo`03001o
ogoo00Uoo`00@Woo0`00NGoo00<007ooOol0NWoo00<007ooOol0NWoo00<007ooOol0M7oo00<007oo
Ool00Woo00<007ooOol02Goo0012Ool00`00Ool0001iOol00`00Oomoo`1kOol00`00Oomoo`1fOol3
001hOol01@00Oomoogoo00002goo0012Ool00`00Ool0001iOol00`00Oomoo`1lOol00`00Oomoo`1h
Ool00`00Oomoo`1fOol01000Oomoo`002goo0012Ool00`00Ool0001iOol00`00Oomoo`1lOol00`00
Oomoo`1iOol00`00Oomoo`1eOol01000Oomoo`002goo0012Ool00`00Ool0001iOol00`00Oomoo`1f
Ool00`00Oomoo`03Ool00`00Oomoo`1iOol00`00Oomoo`1fOol00`00Ool0000;Ool0049oo`03001o
o`0007Ioo`@007Qoo`8000=oo`03001oogoo07Aoo`03001oogoo009oo`03001oogoo07Qoo`8000]o
o`00@Woo00<007oo0000N7oo0P00NWoo0`00N7oo1000Ngoo0P002goo0012Ool2003oOoomOol0049o
o`800?moooeoo`00@Woo0P00ogoooGoo0012Ool2003oOoomOol0049oo`800?moooeoo`00@Woo0P00
ogoooGoo0012Ool00`00Oomoo`3oOoolOol0049oo`03001oogoo0?moooaoo`00=Wooo`00o`002`00
0Goo0012Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00
Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00
Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00
Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00
Oomoo`0FOol00`00Oomoo`0;Ool0049oo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Eo
o`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Eo
o`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Eo
o`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Eo
o`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo00]oo`00@Woo00<007ooOol0NGoo00<007oo
Ool0NGoo00<007ooOol0NGoo00<007ooOol0NGoo00<007ooOol02goo0012Ool00`00Oomoo`1iOol0
0`00Oomoo`1iOol00`00Oomoo`1iOol00`00Oomoo`1iOol00`00Oomoo`0;Ool0049oo`03001oogoo
0?moooaoo`00@Woo00<007ooOol0ogooo7oo0012Ool00`00Oomoo`3oOoolOol0049oo`03001oogoo
0?moooaoo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2
Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo
@Woo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "\tThe error can be reduced by reducing the step size. To do this, we must \
go back and run the ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command again after setting the step size to a smaller value, and after \
applying the ",
  StyleBox["Clear[v]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command.  ",
  StyleBox["We must",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["Clear[v]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["before running the ",
    FontSlant->"Italic"],
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" command again; otherwise the values of ",
    FontSlant->"Italic"],
  StyleBox["v[1],v[2],",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["\[Ellipsis] stored in the kernel's memory as a result of our \
using two equal signs in ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Eq. (1.4.10)",
    ButtonData:>"(1.4.10)",
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[",  will supersede the new evaluations.",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  " After clearing ",
  StyleBox["v",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", we must then reevaluate the definition of ",
  StyleBox["v",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in Cell ",
  ButtonBox["1.33",
    ButtonData:>"Cell 1.33",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tAll of these reevaluations are starting to seem like work. There is a \
way to avoid having to reevaluate groups of cells over and over again. We can \
create a ",
  StyleBox["Module",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is a method of grouping a number of commands together to create a  \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function. Modules are the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " version of C+ modules or Fortran subroutines, and have the following \
syntax:"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  StyleBox["Module[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["internal variables",
    FontSlant->"Italic"],
  StyleBox["},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["statements",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "        creates a module in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
The list of internal variables defines variables that are used only \
within the module. The definitions of these variables will not be remembered \
outside of the module.\
\>", "Text",
  CellTags->"i:142"],

Cell[TextData[{
  "\tHere is a version of the Euler solution  that is written as a module, \
and assigned to a function ",
  StyleBox["Eulersol[v0,time, \[CapitalDelta]t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This function finds the approximate solution ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["vEuler",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["t",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          StyleBox["time",
            FontSlant->"Italic"]}], TraditionalForm]]],
  ", with step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ".  To use the module , all we need to do is specify the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t, v)\)]],
  " that enters the differential equation:"
}], "Text"],

Cell[BoxData[
    \(Eulersol[v0_, time_, \[CapitalDelta]t_] := \ 
      Module[{t, v, solution}, \[IndentingNewLine]t[n_]\  := \ 
          n\ \[CapitalDelta]t; \[IndentingNewLine]v[
            n_]\  := \((v[
                  n]\  = \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ v[
                    n - 1]\  + \ \[CapitalDelta]t\ \ f[t[n - 1], \ 
                      v[n - 1]])\) /; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \
\ n > 0\  && \ n \[Element] Integers; \[IndentingNewLine]v[
            0]\  := \ \ \ v0; \[IndentingNewLine]solution\  = \ 
          Table[{t[n], v[n]}, {n, 0, 
              time/\[CapitalDelta]t}]; \[IndentingNewLine]vEuler[
            t_]\  = \ \(Interpolation[solution]\)[t];]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.39"],

Cell[TextData[{
  "\t Note that we did not have to add a ",
  StyleBox["Clear[v]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement to the list of commands, because ",
  StyleBox["v",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an internal variable that is not remembered outside the module, and is \
also not remembered from one application of the ",
  StyleBox["Module",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the next. "
}], "Text"],

Cell[TextData[{
  "\tAlso, note that we don\[CloseCurlyQuote]t really need the condition \
statements in the definition of ",
  StyleBox["v[n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " anymore, since we only evaluate ",
  StyleBox["v[n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "at positive integers, and the definition does not exist outside the ",
  StyleBox["Module",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\tIn Cell ",
  ButtonBox["1.40",
    ButtonData:>"Cell 1.40",
    ButtonStyle->"Hyperlink"],
  ", we show a plot of the error vs. time as ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is reduced to 0.1 and then to 0.05. The plot was made simply by running \
the ",
  StyleBox["Eulersol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function at these two values of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and plotting the resulting error, then superimposing the results along \
with the original error plot at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.2"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Eulersol[0, 4, 0.1];\)\), "\n", 
    \(\(p2\  = \ 
        Plot[vEuler[t] - vExact[t], {t, 0, 4}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Eulersol[0, 4, 0.05];\)\), "\n", 
    \(\(p3 = \ 
        Plot[vEuler[t] - vExact[t], {t, 0, 4}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[p1, p2, p3, DisplayFunction \[Rule] $DisplayFunction, 
        PlotLabel \[Rule] "\<Error for \[CapitalDelta]t = 0.2,0.1,0.05\>"];\)\
\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.40"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.603319 14.6133 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -3 -9 ]
[.5 .59082 3 0 ]
[.7381 .59082 -3 -9 ]
[.7381 .59082 3 0 ]
[.97619 .59082 -3 -9 ]
[.97619 .59082 3 0 ]
[.01131 .01879 -30 -4.5 ]
[.01131 .01879 0 4.5 ]
[.01131 .16492 -30 -4.5 ]
[.01131 .16492 0 4.5 ]
[.01131 .31105 -30 -4.5 ]
[.01131 .31105 0 4.5 ]
[.01131 .45719 -30 -4.5 ]
[.01131 .45719 0 4.5 ]
[.5 .63053 -83 0 ]
[.5 .63053 83 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(1)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(2)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(3)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(4)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01879 m
.03006 .01879 L
s
[(-0.04)] .01131 .01879 1 0 Mshowa
.02381 .16492 m
.03006 .16492 L
s
[(-0.03)] .01131 .16492 1 0 Mshowa
.02381 .31105 m
.03006 .31105 L
s
[(-0.02)] .01131 .31105 1 0 Mshowa
.02381 .45719 m
.03006 .45719 L
s
[(-0.01)] .01131 .45719 1 0 Mshowa
.125 Mabswid
.02381 .04801 m
.02756 .04801 L
s
.02381 .07724 m
.02756 .07724 L
s
.02381 .10647 m
.02756 .10647 L
s
.02381 .13569 m
.02756 .13569 L
s
.02381 .19415 m
.02756 .19415 L
s
.02381 .22337 m
.02756 .22337 L
s
.02381 .2526 m
.02756 .2526 L
s
.02381 .28183 m
.02756 .28183 L
s
.02381 .34028 m
.02756 .34028 L
s
.02381 .36951 m
.02756 .36951 L
s
.02381 .39873 m
.02756 .39873 L
s
.02381 .42796 m
.02756 .42796 L
s
.02381 .48641 m
.02756 .48641 L
s
.02381 .51564 m
.02756 .51564 L
s
.02381 .54487 m
.02756 .54487 L
s
.02381 .57409 m
.02756 .57409 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Error) show
99.000 13.000 moveto
(for) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
141.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
195.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
225.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04262 .48159 L
.06244 .37264 L
.08426 .27463 L
.10458 .20211 L
.12414 .1468 L
.14264 .10499 L
.16305 .07038 L
.18163 .0469 L
.19132 .03755 L
.2016 .02972 L
.21038 .0246 L
.22004 .02017 L
.22524 .01828 L
.23018 .01688 L
.23461 .01592 L
.23712 .01551 L
.23945 .0152 L
.24076 .01506 L
.24218 .01494 L
.24352 .01485 L
.24475 .01479 L
.24587 .01475 L
.24709 .01472 L
.24837 .01472 L
.24956 .01473 L
.25023 .01474 L
.25095 .01477 L
.25228 .01483 L
.25357 .0149 L
.25476 .01499 L
.25746 .01526 L
.26033 .01563 L
.2649 .01628 L
.2697 .01714 L
.27497 .01835 L
.2798 .01971 L
.29808 .02681 L
.31782 .03721 L
.33619 .04883 L
.37523 .07877 L
.41673 .11548 L
.45671 .15323 L
.49518 .19008 L
.5361 .22869 L
.5755 .26452 L
.61339 .29722 L
.65373 .32983 L
.69255 .35887 L
.73383 .38714 L
Mistroke
.77359 .41189 L
.81184 .43346 L
.85253 .45414 L
.89172 .47197 L
.93335 .48885 L
.97347 .50324 L
.97619 .50415 L
Mfstroke
.02381 .60332 m
.04262 .54629 L
.06244 .49568 L
.08426 .45004 L
.10458 .41571 L
.12414 .38914 L
.14264 .36912 L
.16305 .352 L
.18163 .34039 L
.19132 .33568 L
.2016 .33156 L
.21123 .3285 L
.22004 .3263 L
.22945 .32456 L
.23464 .32386 L
.23958 .32334 L
.24177 .32315 L
.24412 .32298 L
.24614 .32286 L
.24833 .32276 L
.24967 .32271 L
.25091 .32268 L
.25209 .32265 L
.25334 .32263 L
.25446 .32262 L
.2555 .32262 L
.25665 .32262 L
.25788 .32263 L
.2591 .32265 L
.26044 .32268 L
.26316 .32277 L
.26568 .32287 L
.26805 .323 L
.27338 .32339 L
.27912 .32395 L
.28961 .32534 L
.29924 .32698 L
.31816 .33113 L
.33886 .33687 L
.37942 .35082 L
.41847 .3665 L
.45997 .38447 L
.49995 .40224 L
.53842 .41919 L
.57933 .43669 L
.61874 .45275 L
.65662 .46729 L
.69696 .48171 L
.73579 .49451 L
.77707 .50696 L
Mistroke
.81683 .51785 L
.85507 .52734 L
.89577 .53644 L
.93495 .54429 L
.97619 .55166 L
Mfstroke
.02381 .60332 m
.04262 .57575 L
.06244 .55128 L
.08426 .52911 L
.10458 .51238 L
.12414 .49937 L
.14264 .48953 L
.16305 .48107 L
.18163 .47529 L
.19132 .47292 L
.2016 .47084 L
.21123 .46927 L
.22004 .46813 L
.22945 .46721 L
.23464 .46682 L
.23958 .46653 L
.24412 .46632 L
.24833 .46618 L
.25075 .46612 L
.25295 .46608 L
.25417 .46606 L
.25549 .46605 L
.25673 .46604 L
.25788 .46604 L
.25914 .46604 L
.26034 .46604 L
.26141 .46604 L
.26258 .46605 L
.26385 .46607 L
.26519 .46609 L
.26761 .46613 L
.26984 .46618 L
.27193 .46624 L
.2767 .46641 L
.28189 .46665 L
.28665 .46692 L
.29737 .46769 L
.31629 .46952 L
.33699 .47213 L
.37755 .47862 L
.4166 .48605 L
.45809 .49464 L
.49808 .5032 L
.53654 .51141 L
.57746 .51993 L
.61686 .52778 L
.65475 .53492 L
.69509 .54202 L
.73391 .54835 L
.77519 .55452 L
Mistroke
.81495 .55993 L
.8532 .56466 L
.8939 .56921 L
.93308 .57315 L
.97471 .57689 L
.97619 .57701 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00Oogooogoo@Woo0012
Ool00`00Oomoo`3oOoolOol0049oo`03001oogoo0?moooaoo`00@Woo00<007ooOol0ogooo7oo0012
Ool00`00Oomoo`3oOoolOol0049oo`03001oogoo0?moooaoo`00@Woo00<007ooOol0ogooo7oo000@
Ool40008Ool30009Ool4000:Ool50007Ool00`00Oomoo`3oOoolOol000moo`03001oogoo009oo`03
001oogoo00Eoo`<000Qoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo
0?moooaoo`003goo00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<007ooOol00Woo00<007oo
Ool02Goo00<007ooOol01goo00<007ooOol0JWoo4`00ogooOgoo000>Ool00`00Oomoo`04Ool00`00
Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`02Ool90007Ool00`00Oomoo`1UOol5000COol5003o
OomjOol0009oo`T000=oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00Moo`@0065oo`<001eoo`800?moogQoo`000Woo2@000goo
00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol01goo00<007ooOol0H7oo0P008Woo0`00ogooMGoo000>Ool00`00Oomoo`04Ool00`00
Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo00002Goo00<007ooOol0Ggoo
00<007ooOol09Goo0P00ogooLgoo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool01000Oomoo`002Goo00<007ooOol0GGoo0P00:Woo0`00ogooL7oo000>Ool0
0`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000Oomoo`002Goo
00<007ooOol0Fgoo0P00;goo0P00ogooKWoo000?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Ool00009Ool00`00Oomoo`1IOol2000cOol2003oOom/Ool0
00moo`03001oogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo00Qoo`8000Uoo`03
001oogoo05Qoo`03001oogoo03Eoo`800?moofYoo`0047oo100057oo10002goo0P002Goo00<007oo
Ool0EWoo0P00>Woo0P00ogooJ7oo0012Ool00`00Oomoo`1EOol00`00Oomoo`0lOol2003oOomVOol0
049oo`03001oogoo05Aoo`03001oogoo03moo`800?moofAoo`00@Woo00<007ooOol0Dgoo00<007oo
Ool0@Woo0P00ogooHWoo0012Ool00`00Oomoo`1BOol00`00Oomoo`15Ool00`00Oomoo`3oOomOOol0
049oo`03001oogoo055oo`03001oogoo04Moo`800?mooemoo`00@Woo00<007ooOol0D7oo00<007oo
Ool0BWoo0P00ogooGGoo0012Ool00`00Oomoo`1?Ool00`00Oomoo`1=Ool00`00Oomoo`3oOomJOol0
049oo`<004moo`03001oogoo04ioo`800?mooeYoo`00@Woo00<007ooOol0CWoo00<007ooOol0DGoo
00<007ooOol0ogooEgoo0012Ool00`00Oomoo`1=Ool00`00Oomoo`1COol00`00Oomoo`3oOomFOol0
049oo`03001oogoo04eoo`03001oogoo05Aoo`03001oogoo0?mooeEoo`00@Woo00<007ooOol0C7oo
00<007ooOol0EWoo0P00ogooEGoo0012Ool00`00Oomoo`1;Ool00`00Oomoo`1IOol00`00Oomoo`3o
OomBOol0049oo`03001oogoo04Yoo`03001oogoo05]oo`03001oogoo0?mooe5oo`00@Woo00<007oo
Ool0BWoo00<007ooOol0G7oo00<007ooOol0ogooD7oo0012Ool00`00Oomoo`19Ool00`00Oomoo`1N
Ool2003oOom@Ool0049oo`03001oogoo04Qoo`03001oogoo065oo`03001oogoo0?moodeoo`00@Woo
00<007ooOol0B7oo00<007ooOol0HWoo00<007ooOol0ogooC7oo0012Ool00`00Oomoo`17Ool00`00
Oomoo`1TOol00`00Oomoo`3oOom;Ool0049oo`03001oogoo04Ioo`03001oogoo06Ioo`800?mood]o
o`00@Woo00<007ooOol0AWoo00<007ooOol0J7oo00<007ooOol0ogooB7oo0012Ool00`00Oomoo`15
Ool00`00Oomoo`1ZOol00`00Oomoo`3oOom7Ool0049oo`<004Aoo`03001oogoo06aoo`03001oogoo
0?moodIoo`00@Woo00<007ooOol0A7oo00<007ooOol0KGoo0P00ogooAWoo0012Ool00`00Oomoo`13
Ool00`00Oomoo`1`Ool00`00Oomoo`3oOom3Ool0049oo`03001oogoo04=oo`03001oogoo075oo`03
001oogoo0?mood9oo`00@Woo00<007ooOol0@Woo00<007ooOol0Lgoo00<007ooOol0ogoo@Goo0012
Ool00`00Oomoo`11Ool00`00Oomoo`1eOol00`00Oomoo`3oOom0Ool0049oo`03001oogoo045oo`03
001oogoo07Ioo`03001oogoo0?moocmoo`00@Woo00<007ooOol0@7oo00<007ooOol0N7oo0P00ogoo
?goo0012Ool00`00Oomoo`10Ool00`00Oomoo`1jOol00`00Oomoo`3oOollOol0049oo`03001oogoo
03moo`03001oogoo07aoo`03001oogoo0?mooc]oo`00@Woo00<007ooOol0?Woo00<007ooOol0OWoo
00<007ooOol0ogoo>Woo0012Ool00`00Oomoo`0nOol00`00Oomoo`1oOol00`00Oomoo`3oOoliOol0
049oo`03001oogoo03eoo`03001oogoo085oo`03001oogoo0?moocQoo`00@Woo00<007ooOol0?Goo
00<007ooOol0PWoo00<007ooOol0ogoo=goo0012Ool00`00Oomoo`0lOol00`00Oomoo`24Ool2003o
OolgOol0049oo`<003]oo`03001oogoo08Moo`03001oogoo0?moocAoo`00@Woo00<007ooOol0>goo
00<007ooOol0R7oo00<007ooOol0ogoo<goo0012Ool00`00Oomoo`0jOol00`00Oomoo`2:Ool00`00
Oomoo`3oOolbOol0049oo`03001oogoo03Yoo`03001oogoo08]oo`03001oogoo0?mooc5oo`00@Woo
00<007ooOol0>Goo00<007ooOol0SGoo00<007ooOol0ogoo<7oo0012Ool00`00Oomoo`0iOol00`00
Oomoo`2>Ool2003oOol`Ool0049oo`03001oogoo03Qoo`03001oogoo095oo`03001oogoo0?moobeo
o`00@Woo00<007ooOol0>7oo00<007ooOol0TWoo00<007ooOol0ogoo;7oo0012Ool00`00Oomoo`0g
Ool00`00Oomoo`2DOol00`00Oomoo`3oOol[Ool0049oo`03001oogoo03Moo`03001oogoo09Eoo`03
001oogoo0?moobYoo`00@Woo00<007ooOol0=Woo00<007ooOol0Ugoo00<007ooOol0ogoo:Goo0012
Ool00`00Oomoo`0fOol00`00Oomoo`2HOol00`00Oomoo`3oOolXOol0049oo`03001oogoo03Ioo`03
001oogoo09Uoo`03001oogoo0?moobMoo`00@Woo00<007ooOol0=Goo00<007ooOol0Vgoo00<007oo
Ool0ogoo9Woo0012Ool00`00Oomoo`0eOol00`00Oomoo`2LOol00`00Oomoo`3oOolUOol0049oo`03
001oogoo03Aoo`03001oogoo09ioo`03001oogoo0?moobAoo`00@Woo0`00=7oo00<007ooOol0Wgoo
00<007ooOol0ogoo8goo0012Ool00`00Oomoo`0cOol00`00Oomoo`2QOol00`00Oomoo`3oOolROol0
049oo`03001oogoo03=oo`03001oogoo0:9oo`03001oogoo0?moob5oo`00@Woo00<007ooOol0<Woo
00<007ooOol0Y7oo00<007ooOol0ogoo87oo0012Ool00`00Oomoo`0bOol00`00Oomoo`2UOol00`00
Oomoo`3oOolOOol0049oo`03001oogoo035oo`03001oogoo0:Moo`03001oogoo0?mooaioo`00@Woo
00<007ooOol0<Goo00<007ooOol0Z7oo00<007ooOol0ogoo7Goo0012Ool00`00Oomoo`0`Ool00`00
Oomoo`2ZOol00`00Oomoo`3oOolLOol0049oo`03001oogoo031oo`03001oogoo0:]oo`03001oogoo
0?mooa]oo`00@Woo00<007ooOol0<7oo00<007ooOol0[7oo0P00ogoo6goo0012Ool00`00Oomoo`0_
Ool00`00Oomoo`2_Ool00`00Oomoo`3oOolHOol0011oo`@000Qoo`<000Uoo`@000Qoo`@000Yoo`03
001oogoo02moo`03001oogoo0;1oo`03001oogoo0?mooaMoo`003goo00<007ooOol00Woo00<007oo
Ool01Goo0`0027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0;goo00<007ooOol0/Goo00<007ooOol0ogoo5Woo000?Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`0^Ool00`00Oomoo`2cOol00`00Oomoo`3oOolEOol000ioo`03001oogoo00Aoo`03
001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo02ioo`03
001oogoo0;Aoo`03001oogoo0?mooaAoo`000Woo2@000goo00<007ooOol017oo00<007ooOol03Woo
00<007ooOol017oo00<007ooOol02Goo00<007ooOol01Woo1000;Goo00<007ooOol0]Goo00<007oo
Ool0ogoo4goo0002Ool90003Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00
Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0]Ool00`00Oomoo`2gOol00`00Oomoo`3oOolBOol0
00ioo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Eoo`<000Yoo`03
001oogoo02eoo`03001oogoo0;Qoo`03001oogoo0?mooa5oo`003Woo00<007ooOol017oo00<007oo
Ool03Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol01goo00<007ooOol0;Goo00<007oo
Ool0^Goo00<007ooOol0ogoo47oo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool00`00Oomoo`2kOol00`00Oomoo`3o
Ool?Ool000moo`03001oogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo00Yoo`03
001oogoo00Ioo`03001oogoo02aoo`03001oogoo0;aoo`03001oogoo0?moo`ioo`003goo00<007oo
Ool00Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol0;7oo00<007ooOol0_Goo00<007ooOol0ogoo3Goo000@Ool4000DOol40008
Ool4000:Ool00`00Oomoo`0[Ool00`00Oomoo`2oOol00`00Oomoo`3oOol<Ool0049oo`03001oogoo
02]oo`03001oogoo0<1oo`03001oogoo0?moo`]oo`00@Woo00<007ooOol0:goo00<007ooOol0`Goo
00<007ooOol0ogoo2Woo0012Ool00`00Oomoo`0ZOol00`00Oomoo`33Ool00`00Oomoo`3oOol9Ool0
049oo`03001oogoo02Yoo`03001oogoo0<Aoo`03001oogoo0?moo`Qoo`00@Woo00<007ooOol0:Woo
00<007ooOol0aGoo00<007ooOol0ogoo1goo0012Ool00`00Oomoo`0YOol00`00Oomoo`37Ool2003o
Ool7Ool0049oo`03001oogoo02Uoo`03001oogoo0<Uoo`03001oogoo0?moo`Aoo`00@Woo0`00:Goo
00<007ooOol0bWoo00<007ooOol0ogoo0goo0012Ool00`00Oomoo`0XOol00`00Oomoo`3<Ool00`00
Oomoo`3oOol2Ool0049oo`03001oogoo02Qoo`03001oogoo0<eoo`03001oogoo0?moo`5oo`00@Woo
00<007ooOol0:7oo00<007ooOol0cWoo00<007ooOol0ogoo0012Ool00`00Oomoo`0WOol00`00Oomo
o`3@Ool00`00Oomoo`3nOol0049oo`03001oogoo02Moo`03001oogoo0=5oo`03001oogoo0?eoo`00
@Woo00<007ooOol09goo00<007ooOol0dWoo00<007ooOol0o7oo0012Ool00`00Oomoo`0VOol00`00
Oomoo`3DOol00`00Oomoo`3kOol0049oo`03001oogoo02Ioo`03001oogoo0=Eoo`03001oogoo0?Yo
o`00@Woo00<007ooOol09Woo00<007ooOol0eWoo00<007ooOol0nGoo0012Ool00`00Oomoo`0VOol0
0`00Oomoo`3GOol00`00Oomoo`3hOol0049oo`03001oogoo02Eoo`03001oogoo0=Uoo`03001oogoo
0?Moo`00@Woo00<007ooOol09Goo00<007ooOol0fWoo00<007ooOol0mWoo0012Ool00`00Oomoo`0U
Ool00`00Oomoo`3KOol00`00Oomoo`3eOol0049oo`03001oogoo02Aoo`03001oogoo0=eoo`03001o
ogoo0?Aoo`00@Woo0`0097oo00<007ooOol0gWoo00<007ooOol0lgoo0012Ool00`00Oomoo`0TOol0
0`00Oomoo`3OOol00`00Oomoo`3bOol0049oo`03001oogoo02Aoo`03001oogoo0>1oo`03001oogoo
0?5oo`00@Woo00<007ooOol08goo00<007ooOol0hWoo0P00lGoo0012Ool00`00Oomoo`0SOol00`00
Oomoo`3TOol00`00Oomoo`3^Ool0049oo`03001oogoo02=oo`03001oogoo0>Eoo`03001oogoo0>eo
o`00@Woo00<007ooOol08goo00<007ooOol0iWoo00<007ooOol0k7oo0012Ool00`00Oomoo`0ROol0
0`00Oomoo`3XOol00`00Oomoo`3[Ool0049oo`03001oogoo029oo`03001oogoo0>Uoo`03001oogoo
0>Yoo`00@Woo00<007ooOol08Woo00<007ooOol0jWoo00<007ooOol0jGoo0012Ool00`00Oomoo`0R
Ool00`00Oomoo`3[Ool00`00Oomoo`3XOol0049oo`03001oogoo025oo`03001oogoo0>eoo`03001o
ogoo0>Moo`00@Woo00<007ooOol08Goo00<007ooOol0kWoo00<007ooOol0iWoo0012Ool00`00Oomo
o`0QOol00`00Oomoo`3_Ool00`00Oomoo`3UOol0049oo`03001oogoo025oo`03001oogoo0?1oo`03
001oogoo0>Aoo`00@Woo0`0087oo00<007ooOol0lWoo00<007ooOol0hgoo0012Ool00`00Oomoo`0P
Ool00`00Oomoo`3cOol00`00Oomoo`3ROol0049oo`03001oogoo021oo`03001oogoo0?Aoo`03001o
ogoo0>5oo`00@Woo00<007ooOol07goo00<007ooOol0mWoo00<007ooOol0h7oo0012Ool00`00Oomo
o`0OOol00`00Oomoo`3gOol00`00Oomoo`3OOol0049oo`03001oogoo01moo`03001oogoo0?Qoo`03
001oogoo0=ioo`00@Woo00<007ooOol07goo00<007ooOol0nGoo00<007ooOol0gGoo0012Ool00`00
Oomoo`0NOol00`00Oomoo`3kOol2003MOol0049oo`03001oogoo01ioo`03001oogoo0?eoo`03001o
ogoo0=Yoo`00@Woo00<007ooOol07Woo00<007ooOol0oWoo00<007ooOol0fGoo0012Ool00`00Oomo
o`0NOol00`00Oomoo`3oOol00`00Oomoo`3HOol0049oo`03001oogoo01eoo`03001oogoo0?moo`9o
o`03001oogoo0=Moo`00@Woo00<007ooOol07Goo00<007ooOol0ogoo0goo00<007ooOol0eWoo0012
Ool00`00Oomoo`0MOol00`00Oomoo`3oOol4Ool2003FOol0049oo`03001oogoo01eoo`03001oogoo
0?moo`Ioo`03001oogoo0==oo`00@Woo00<007ooOol077oo00<007ooOol0ogoo27oo00<007ooOol0
dWoo0012Ool3000LOol00`00Oomoo`3oOol9Ool00`00Oomoo`3AOol0049oo`03001oogoo01aoo`03
001oogoo0?moo`Yoo`03001oogoo0=1oo`00@Woo00<007ooOol077oo00<007ooOol0ogoo2goo0P00
d7oo0012Ool00`00Oomoo`0KOol00`00Oomoo`3oOol>Ool00`00Oomoo`3=Ool0049oo`03001oogoo
01]oo`03001oogoo0?moo`moo`03001oogoo0<aoo`00@Woo00<007ooOol06goo00<007ooOol0ogoo
47oo00<007ooOol0bgoo0012Ool00`00Oomoo`0KOol00`00Oomoo`3oOolAOol00`00Oomoo`3:Ool0
049oo`03001oogoo01]oo`03001oogoo0?mooa9oo`03001oogoo0<Uoo`00@Woo00<007ooOol06Woo
00<007ooOol0ogoo57oo0P00bGoo0012Ool00`00Oomoo`0JOol00`00Oomoo`3oOolFOol00`00Oomo
o`36Ool0049oo`03001oogoo01Yoo`03001oogoo0?mooaMoo`03001oogoo0<Eoo`0047oo100027oo
0`002Goo10001Woo200027oo00<007ooOol06Woo00<007ooOol0ogoo67oo00<007ooOol0a7oo000?
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0IOol00`00Oomoo`3oOolJOol20034Ool000moo`03
001oogoo009oo`03001oogoo00Eoo`<000Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
00]oo`03001oogoo01Uoo`03001oogoo0?mooaaoo`03001oogoo0<5oo`003Woo00<007ooOol017oo
00<007ooOol03Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol06Goo
00<007ooOol0ogoo7Goo00<007ooOol0`7oo0002Ool90003Ool00`00Oomoo`04Ool00`00Oomoo`0>
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool4000HOol00`00Oomoo`3oOolNOol0
0`00Oomoo`2oOol0009oo`T000=oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo01Qoo`03001oogoo0?moob1oo`800;moo`003Woo
00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol01goo
00<007ooOol067oo00<007ooOol0ogoo8Woo00<007ooOol0_7oo000>Ool00`00Oomoo`04Ool00`00
Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0HOol00`00
Oomoo`3oOolSOol00`00Oomoo`2kOol000ioo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo
00Aoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo0?moobAoo`03001o
ogoo0;Yoo`003goo00<007ooOol00Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol05goo00<007ooOol0ogoo9Woo00<007ooOol0
^Goo000?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20003
Ool00`00Oomoo`07Ool00`00Oomoo`0GOol00`00Oomoo`1BOolF002nOol2002iOol0011oo`@001Ao
o`@000Uoo`<000Yoo`03001oogoo01Moo`03001oogoo04aoo`H001Ioo`T00;Moo`03001oogoo0;Io
o`00@Woo00<007ooOol05goo00<007ooOol0Agoo1@009Goo1@00/goo00<007ooOol0]Goo0012Ool0
0`00Oomoo`0GOol00`00Oomoo`14Ool3000_Ool5002_Ool00`00Oomoo`2dOol0049oo`03001oogoo
01Ioo`03001oogoo049oo`<003Moo`@00:aoo`800;Aoo`00@Woo00<007ooOol05Woo00<007ooOol0
@7oo0P00?Woo1000ZWoo00<007ooOol0/Goo0012Ool00`00Oomoo`0FOol00`00Oomoo`0mOol30014
Ool3002XOol00`00Oomoo`2`Ool0049oo`03001oogoo01Ioo`03001oogoo03Yoo`<004Yoo`<00:Io
o`800;1oo`00@Woo00<007ooOol05Goo00<007ooOol0>7oo0`00D7oo0`00YGoo00<007ooOol0[Goo
0012Ool3000EOol00`00Oomoo`0fOol2001FOol3002SOol00`00Oomoo`2/Ool0049oo`03001oogoo
01Eoo`03001oogoo03Eoo`03001oogoo05Uoo`800:9oo`800:aoo`00@Woo00<007ooOol05Goo00<0
07ooOol0<goo0P00GWoo0`00XGoo00<007ooOol0ZGoo0012Ool00`00Oomoo`0DOol00`00Oomoo`0c
Ool00`00Oomoo`1QOol2002POol00`00Oomoo`2XOol0049oo`03001oogoo01Aoo`03001oogoo035o
o`8006Ioo`<009ioo`800:Qoo`00@Woo00<007ooOol057oo00<007ooOol0<7oo00<007ooOol0JGoo
0`00WGoo00<007ooOol0YGoo0012Ool00`00Oomoo`0DOol00`00Oomoo`0^Ool2001_Ool2002LOol0
0`00Oomoo`2TOol0049oo`03001oogoo01=oo`03001oogoo02ioo`03001oogoo075oo`<009Yoo`80
0:Aoo`00@Woo00<007ooOol04goo00<007ooOol0;Goo00<007ooOol0MGoo0`00VGoo00<007ooOol0
XGoo0012Ool00`00Oomoo`0COol00`00Oomoo`0/Ool00`00Oomoo`1iOol2002HOol00`00Oomoo`2P
Ool0049oo`03001oogoo01=oo`03001oogoo02Yoo`8007ioo`<009Ioo`800:1oo`00@Woo00<007oo
Ool04goo00<007ooOol0:Goo00<007ooOol0PGoo0P00UWoo00<007ooOol0WGoo0012Ool00`00Oomo
o`0BOol00`00Oomoo`0YOol00`00Oomoo`24Ool3002DOol2002MOol0049oo`03001oogoo019oo`03
001oogoo02Qoo`03001oogoo08Qoo`<009=oo`8009]oo`00@Woo00<007ooOol04Woo00<007ooOol0
9goo00<007ooOol0S7oo0P00Tgoo00<007ooOol0V7oo0012Ool3000BOol00`00Oomoo`0VOol00`00
Oomoo`2?Ool3002AOol2002HOol0049oo`03001oogoo015oo`03001oogoo02Moo`03001oogoo099o
o`80095oo`03001oogoo09Eoo`00@Woo00<007ooOol04Goo00<007ooOol09Woo00<007ooOol0UGoo
0P00T7oo0P00UGoo0012Ool00`00Oomoo`0AOol00`00Oomoo`0UOol00`00Oomoo`2HOol3002?Ool0
0`00Oomoo`2BOol0049oo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo09aoo`8008ioo`80
099oo`00@Woo00<007ooOol04Goo00<007ooOol08goo00<007ooOol0Wgoo0P00SWoo0P00T7oo0012
Ool00`00Oomoo`0@Ool00`00Oomoo`0SOol00`00Oomoo`2ROol3002=Ool00`00Oomoo`2=Ool0049o
o`03001oogoo011oo`03001oogoo029oo`03001oogoo0:Ioo`8008aoo`8008eoo`00@Woo00<007oo
Ool047oo00<007ooOol08Goo00<007ooOol0ZGoo0P00S7oo00<007ooOol0RWoo0012Ool00`00Oomo
o`0@Ool00`00Oomoo`0POol00`00Oomoo`2/Ool3002:Ool2002:Ool0049oo`03001oogoo011oo`03
001oogoo01moo`03001oogoo0;1oo`8008Yoo`03001oogoo08Moo`00@Woo00<007ooOol047oo00<0
07ooOol07Woo00<007ooOol0/goo0P00RGoo0P00Qgoo0012Ool00`00Oomoo`0?Ool00`00Oomoo`0O
Ool00`00Oomoo`2eOol30028Ool20025Ool0049oo`03001oogoo00moo`03001oogoo01ioo`03001o
ogoo0;Uoo`8008Qoo`03001oogoo089oo`00@Woo00<007ooOol03goo00<007ooOol07Goo00<007oo
Ool0_7oo0P00Qgoo0P00PWoo0012Ool00`00Oomoo`0?Ool00`00Oomoo`0LOol00`00Oomoo`2oOol3
0026Ool20020Ool0049oo`<000moo`03001oogoo01aoo`03001oogoo0<9oo`8008Ioo`03001oogoo
07eoo`00@Woo00<007ooOol03Woo00<007ooOol077oo00<007ooOol0aGoo0P00QGoo0P00OGoo0012
Ool00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`38Ool20025Ool00`00Oomoo`1jOol0049o
o`03001oogoo00ioo`03001oogoo01Yoo`03001oogoo0<]oo`<008=oo`8007Yoo`00@Woo00<007oo
Ool03Woo00<007ooOol06Goo00<007ooOol0cgoo0P00Pgoo0P00N7oo0012Ool00`00Oomoo`0>Ool0
0`00Oomoo`0IOol00`00Oomoo`3AOol20023Ool00`00Oomoo`1eOol0049oo`03001oogoo00ioo`03
001oogoo01Qoo`03001oogoo0=Aoo`80089oo`8007Eoo`00@Woo00<007ooOol03Goo00<007ooOol0
67oo00<007ooOol0egoo0P00PWoo00<007ooOol0LWoo0012Ool00`00Oomoo`0=Ool00`00Oomoo`0G
Ool00`00Oomoo`3JOol30020Ool2001bOol0049oo`03001oogoo00eoo`03001oogoo01Moo`03001o
ogoo0=eoo`80081oo`80071oo`00@Woo00<007ooOol03Goo00<007ooOol05Woo00<007ooOol0h7oo
0P00P7oo00<007ooOol0KGoo0012Ool00`00Oomoo`0=Ool00`00Oomoo`0FOol00`00Oomoo`3ROol3
001nOol2001]Ool0049oo`03001oogoo00eoo`03001oogoo01Eoo`03001oogoo0>Ioo`8007ioo`03
001oogoo06Yoo`00@Woo00<007ooOol037oo00<007ooOol05Goo00<007ooOol0jGoo0P00OGoo0P00
JWoo0012Ool00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`3[Ool3001lOol00`00Oomoo`1W
Ool0049oo`<000aoo`03001oogoo01Aoo`03001oogoo0>moo`8007]oo`8006Moo`00@Woo00<007oo
Ool037oo00<007ooOol057oo00<007ooOol0lGoo0P00Ngoo0P00IGoo0012Ool00`00Oomoo`0<Ool0
0`00Oomoo`0COol00`00Oomoo`3dOol3001jOol00`00Oomoo`1ROol0049oo`03001oogoo00]oo`03
001oogoo01Aoo`03001oogoo0?Moo`8007Uoo`80069oo`00@Woo00<007ooOol02goo00<007ooOol0
4goo00<007ooOol0nWoo0P00NGoo0P00H7oo0012Ool00`00Oomoo`0;Ool00`00Oomoo`0COol00`00
Oomoo`3lOol3001hOol3001MOol0049oo`03001oogoo00]oo`03001oogoo019oo`03001oogoo0?mo
o`5oo`8007Uoo`8005]oo`00@Woo00<007ooOol02goo00<007ooOol04Goo00<007ooOol0ogoo17oo
0P00NGoo0P00FGoo0012Ool00`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`3oOol6Ool3001h
Ool2001GOol0049oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo0?moo`Yoo`8007Qoo`80
05Eoo`00@Woo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol0ogoo37oo0P00N7oo0`00DWoo
000@Ool40008Ool30009Ool40007Ool70008Ool00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomo
o`3oOol?Ool3001hOol2001@Ool000moo`03001oogoo009oo`03001oogoo00Eoo`<000Qoo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo011oo`03001o
ogoo0?mooa9oo`8007Qoo`8004ioo`003goo00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol03goo00<0
07ooOol0ogoo5Goo0P00N7oo0P00C7oo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomo
o`3oOolGOol3001gOol2001:Ool0009oo`T000=oo`03001oogoo00Aoo`03001oogoo00ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Uoo`@000Qoo`03001oogoo00moo`03001oogoo0?mo
oa]oo`<007Ioo`8004Qoo`000Woo2@000goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol03goo00<007ooOol0
ogoo7Woo0`00MGoo0P00AWoo000>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`3oOolR
Ool3001dOol20014Ool000ioo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo0?moobEoo`<0
07=oo`80049oo`003Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol0ogoo:Goo0`00LWoo
0P00@7oo000?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`1:Ool/002eOol2001bOol2
000nOol000moo`03001oogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo00Aoo`@0
00]oo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo049oo`T002aoo`L00;1oo`<0075oo`80
03aoo`0047oo100057oo10002Goo0P002goo00<007ooOol027oo00<007ooOol03Goo00<007ooOol0
?7oo1P00?7oo1@00[Woo0`00L7oo0P00>Woo0012Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00
Oomoo`0hOol50017Ool7002ZOol2001`Ool2000hOol0049oo`03001oogoo00Qoo`03001oogoo00ao
o`03001oogoo03Aoo`@005=oo`L00:Eoo`<006moo`<003Eoo`00@Woo00<007ooOol027oo00<007oo
Ool02goo00<007ooOol0<Woo0`00GWoo1`00XGoo0P00L7oo0`00<Woo0012Ool00`00Oomoo`07Ool0
0`00Oomoo`0<Ool00`00Oomoo`0_Ool3001XOol6002MOol3001`Ool3000_Ool0049oo`03001oogoo
00Moo`03001oogoo00]oo`03001oogoo02eoo`<0075oo`D009]oo`<0071oo`8002eoo`00@Woo00<0
07ooOol01goo00<007ooOol02goo00<007ooOol0:goo0P00NGoo1@00VGoo0`00Kgoo0`00:Woo0012
Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0YOol30020Ool5002GOol3001_Ool3000W
Ool0049oo`<000Moo`03001oogoo00Yoo`03001oogoo02Moo`8008Qoo`H009Aoo`<006moo`<002Ao
o`00@Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol09Woo0P00T7oo1@00TWoo1000KWoo
0P008Woo0012Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0TOol2002GOol5002AOol3
001]Ool3000OOol0049oo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo02=oo`8009ioo`D0
08moo`<006eoo`<001aoo`00@Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol08Goo0P00
YGoo1@00SGoo1000K7oo0P006Woo0012Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0P
Ool2002/Ool4002=Ool3001[Ool3000GOol0049oo`03001oogoo00Ioo`03001oogoo00Qoo`03001o
ogoo01ioo`800;9oo`D008]oo`<006]oo`8001Eoo`00@Woo00<007ooOol01Woo00<007ooOol01goo
00<007ooOol07Goo0P00^Goo1000RWoo0`00JWoo0`004Woo0012Ool00`00Oomoo`05Ool00`00Oomo
o`08Ool00`00Oomoo`0LOol00`00Oomoo`2mOol40029Ool3001ZOol3000?Ool0049oo`03001oogoo
00Eoo`03001oogoo00Qoo`03001oogoo01Yoo`800<Aoo`D008Moo`<006Yoo`8000eoo`00@Woo00<0
07ooOol01Goo00<007ooOol01goo00<007ooOol06Woo00<007ooOol0bGoo1@00QGoo0`00MWoo0012
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`3?Ool50023Ool3001c
Ool0049oo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo01Qoo`800=Moo`D0085oo`<0071o
o`00@Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol05goo00<007ooOol0g7oo1000P7oo
1000K7oo0012Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0EOol2003SOol40020Ool3
001YOol0049oo`<000Aoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo0>Moo`D007ioo`@0
06Eoo`00@Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol057oo00<007ooOol0kGoo1000
OWoo0`00HWoo0012Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0COol00`00Oomoo`3b
Ool4001mOol4001NOol0049oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo019oo`800?Uo
o`D007aoo`@005Yoo`00@Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol04Goo00<007oo
Ool0oWoo1@00Ngoo1000EWoo0012Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0AOol0
0`00Oomoo`3oOol5Ool5001jOol4001BOol0049oo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo011oo`03001oogoo0?moo`]oo`D007Uoo`@004ioo`00@Woo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol03goo00<007ooOol0ogoo4Goo1P00Mgoo1@00BGoo0012Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`3oOolHOol7001eOol50014Ool0049oo`03001o
ogoo00=oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo0?moob1oo`L007=oo`D003moo`00
@Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0ogoo:7oo1P00LWoo
1@00>Woo0012Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`3oOol_
Ool5001bOol6000dOol0049oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00aoo`03001o
ogoo0?moocEoo`D007=oo`D002moo`00@Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
37oo00<007ooOol0ogoo>goo1@00Lgoo1@00:Woo0012Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`0;Ool00`00Oomoo`3oOom1Ool6001bOol5000UOol0049oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00Yoo`03001oogoo0?moodQoo`L0071oo`H001moo`00@Woo0`000Woo00<0
07ooOol00Woo00<007ooOol02Woo00<007ooOol0ogooD7oo1`00Kgoo1@006Woo0012Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`3oOomHOol6001^Ool5000EOol0049o
o`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`3oOomOOol5001^Ool5000@Ool0049o
o`05001oogooOol00004Ool00`00Oomoo`08Ool00`00Oomoo`3oOomUOol5001^Ool3000=Ool0049o
o`05001oogooOol00004Ool00`00Oomoo`08Ool00`00Oomoo`3oOomZOol5001iOol0049oo`05001o
ogooOol00003Ool00`00Oomoo`08Ool00`00Oomoo`3oOom`Ool7001bOol0049oo`05001oogooOol0
0003Ool00`00Oomoo`07Ool00`00Oomoo`3oOomhOol7001[Ool0049oo`05001oogooOol00003Ool0
0`00Oomoo`06Ool00`00Oomoo`3oOon0Ool7001TOol0049oo`05001oogooOol00002Ool00`00Oomo
o`07Ool00`00Oomoo`3oOon7Ool8001LOol0049oo`04001oogoo0003Ool00`00Oomoo`06Ool00`00
Oomoo`3oOon@Ool:001BOol0049oo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`1WOol7
001dOol8001fOol4000fOol:000jOol50009Ool0049oo`04001oogoo0002Ool00`00Oomoo`05Ool0
0`00Oomoo`1[Ool00`00Oomoo`1fOol00`00Oomoo`03Ool00`00Oomoo`1cOol00`00Oomoo`02Ool0
0`00Oomoo`0mOol;000aOol00`00Oomoo`09Ool0049oo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`1/Ool00`00Oomoo`1gOol00`00Oomoo`1gOol00`00Oomoo`04Ool00`00Oomoo`17Ool:
000WOol00`00Oomoo`09Ool0049oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`1/Ool0
0`00Oomoo`1hOol00`00Oomoo`1mOol00`00Oomoo`1AOol;000FOol90009Ool0049oo`06001oogoo
001oo`001Woo00<007ooOol0KGoo00<007ooOol0NGoo00<007ooOol0O7oo00<007ooOol0G7oo2P00
3Goo00<007ooOol00Woo00<007ooOol02Goo0012Ool30002Ool00`00Oomoo`03Ool00`00Oomoo`1^
Ool00`00Oomoo`1jOol00`00Oomoo`1jOol00`00Oomoo`1WOol;0002Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool0049oo`03001oo`00009oo`03001oogoo009oo`03001oogoo06moo`03001oogoo07]o
o`03001oogoo07Ioo`<007Eoo`H00003Ool007oo00Yoo`00@Woo00D007oo001oo`0000Eoo`03001o
ogoo06moo`03001oogoo07aoo`03001oogoo07Qoo`03001oogoo07Ioo`04001oogoo000;Ool0049o
o`05001oo`00Ool00004Ool00`00Oomoo`1`Ool00`00Oomoo`1lOol00`00Oomoo`1iOol00`00Oomo
o`1eOol01000Oomoo`002goo0012Ool01@00Ool007oo00000goo00<007ooOol0LGoo00<007ooOol0
MWoo00<007ooOol00goo00<007ooOol0NGoo00<007ooOol0MWoo00<007oo00002goo0012Ool01000
Ool000000goo00<007ooOol0Kgoo1000N7oo0P000goo00<007ooOol0M7oo00<007ooOol00Woo00<0
07ooOol0N7oo0P002goo0012Ool01000Ool000000goo00<007ooOol0LGoo0P00NWoo0`00N7oo1000
Ngoo0P002goo0012Ool200001Goo001oogoo0000ogoon7oo0012Ool30002Ool00`00Oomoo`3oOoog
Ool0049oo`<0009oo`03001oogoo0?moooMoo`00@Woo0`0000=oo`00Ool0ogoonGoo0012Ool20000
0goo001oo`3oOoojOol0049oo`<00?moooaoo`00@Woo0`00ogooo7oo0012Ool2003oOoomOol003Io
ool00?l000/0005oo`00@Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Goo00<007oo
Ool05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Goo00<007oo
Ool05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Goo00<007oo
Ool05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Goo00<007oo
Ool05Woo00<007ooOol05Woo00<007ooOol02goo0012Ool00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol0
0`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0;Ool0049oo`03001oogoo
07Uoo`03001oogoo07Uoo`03001oogoo07Uoo`03001oogoo07Uoo`03001oogoo00]oo`00@Woo00<0
07ooOol0ogooo7oo0012Ool00`00Oomoo`3oOoolOol0049oo`03001oogoo0?moooaoo`00@Woo00<0
07ooOol0ogooo7oo0012Ool00`00Oomoo`3oOoolOol00?mooomood9oo`00ogooogoo@Woo003oOooo
Oom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo
003oOoooOom2Ool00?moogEoo`8002ioo`8009Yoo`00ogooMGoo0P00;Woo0P00VWoo003oOomeOol2
000^Ool2002JOol009Qoo`X000=oo`P000Aoo`P000Moo`@000Eoo`P0015oo`L000Moo`@000Eoo`P0
00moo`/000Eoo`D002]oo`@000Qoo`<000Moo`P000Moo`8000Uoo`@000Qoo`<000Qoo`L000Moo`80
00Uoo`@000Qoo`<000Uoo`@000Ioo`H006Qoo`00VWoo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol02Goo00<007ooOol01goo0P0017oo0P001Woo00<007ooOol05Goo00<007ooOol01goo0P00
17oo0P001Woo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo0P00
:7oo00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<007ooOol00goo00<007ooOol01Goo0P00
27oo00<007ooOol00Woo00<007ooOol01Goo0`002goo00<007ooOol027oo0P0027oo00<007ooOol0
0Woo00<007ooOol01Goo0`0027oo00<007ooOol00Woo00<007ooOol00Woo0P001Goo00<007ooOol0
IGoo002JOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomoo`07Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0DOol8000A
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool30009Ool00`00Oomoo`0:Ool30007Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool3000;Ool00`00Oomoo`08Ool30007Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`1TOol009Yoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00=o
o`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo01=o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo015o
o`03001oogoo019oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo00Ao
o`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo06Aoo`00VWoo00<007oo
Ool02goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00goo00<007oo
Ool05Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol04goo00<007oo
Ool00goo00<007ooOol017oo00<007ooOol0;7oo00<007ooOol017oo00<007ooOol04Woo00<007oo
Ool04Goo00<007ooOol017oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol017oo00<007oo
Ool03Woo00<007ooOol017oo00<007ooOol02Goo00<007ooOol0I7oo002JOol01@00Oomoogoo0000
2Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
5Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol04goo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol0;7oo00<007ooOol017oo00<007ooOol04goo00<007ooOol0
47oo00<007ooOol017oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol017oo00<007ooOol0
3Woo00<007ooOol017oo00<007ooOol02Goo00<007ooOol0I7oo002JOol50009Ool2000:Ool20008
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool2000FOol00`00Oomoo`07Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool2000EOol01@00Oomoogoo00001goo00<007ooOol057oo200047oo00<007ooOol017oo
00<007ooOol057oo00<007ooOol03goo00<007ooOol017oo00<007ooOol04Woo00<007ooOol04Goo
00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol00Woo0P0017oo00<007oo
Ool0IGoo002JOol01@00Oomoogoo00002Goo00<007oo00000goo0P0017oo00<007oo00000goo0P00
0Woo0P0017oo0P001Woo00<007oo00000goo0P0047oo00<007ooOol01goo0P0017oo0P001Woo00<0
07oo00000goo0P003goo00D007ooOomoo`0000Eoo`P002Uoo`03001oogoo00Aoo`03001oogoo01Eo
o`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo00Ao
o`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo009oo`H006Qoo`00VWoo00<007ooOol017oo
00<007ooOol00Woo0`000Woo10000goo0`000Woo10001Goo10001Woo0`000Woo10003goo1`001goo
10001Woo0`000Woo10004Goo00<007oo000027oo00<007ooOol0;7oo00<007ooOol017oo00<007oo
Ool05Goo00<007ooOol03Woo00<007ooOol017oo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0Jgoo002JOol0
0`00Oomoo`04Ool00`00Oomoo`10Ool00`00Oomoo`0]Ool00`00Ool00008Ool00`00Oomoo`0]Ool0
0`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`1[Ool009Yoo`03001oogoo00Aoo`03001oogoo041oo`03001oogoo
02ioo`03001oogoo00Moo`03001oogoo02eoo`03001oogoo009oo`03001oogoo011oo`8000=oo`03
001oogoo011oo`03001oogoo009oo`03001oogoo011oo`@001Aoo`03001oogoo009oo`03001oogoo
011oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo06]oo`00V7oo2P00@Woo0P00;goo00<0
07ooOol0>7oo10005Goo0`0057oo10005Goo0P005Goo100057oo10001Woo1`00Igoo003UOol5003o
OomGOol00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo
003oOoooOom2Ool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "As ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " decreases by factors of 2, the error can be seen to decrease roughly by \
factors of 2 as well. The error in the solution scales linearly with ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  ": Error ",
  StyleBox["\[Proportional]",
    FontFamily->"Symbol"],
  " ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  ". In other words, the error is first-order in ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t ",
    FontSlant->"Italic"],
  ".  (The same  language is used in the discussion of power series \
expansions; see Sec. ",
  ButtonBox["9.9.2",
    ButtonData:>{"Chapter9.nb", "c:50"},
    ButtonStyle->"Hyperlink"],
  ".)  Euler's method is called a ",
  StyleBox["first-order method.",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "\tOne can see why the error in this method is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"O", "(", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], ")"}], TraditionalForm]]],
  "  from Eq. ",
  ButtonBox["(1.4.7)",
    ButtonData:>"(1.4.7)",
    ButtonStyle->"Hyperlink"],
  ":  the error in a single step is of order \[CapitalDelta]",
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)]],
  ". To integrate the solution over a fixed time interval  ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " steps must be taken, with ",
  Cell[BoxData[
      FormBox[
        RowBox[{"N", "=", 
          RowBox[{"T", "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " increasing as ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " decreases. The total error is the sum of all individual errors, and \
therefore scales as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"N", " ", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "2"]}], "=", 
          RowBox[{"T", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " "}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tEuler's method is too crude to be of much practical use today. Clearly \
it would be a great improvement in efficiency if we could somehow modify \
Euler's method so that it is ",
  StyleBox["second-order",
    FontSlant->"Italic"],
  " , or even ",
  StyleBox["nth-order",
    FontSlant->"Italic"],
  ", with error scaling like ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "n"], TraditionalForm]]],
  " .  Then by reducing the step size by only a factor of 2, the error would \
be reduced by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  ".  In the next section we will see how to easily modify Euler's method to \
make it second",
  "-order",
  ". "
}], "Text"],

Cell[TextData[{
  "The error of a numerical solution to an ODE is controlled by the step size \
",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". Reducing the step size increases the accuracy of the solution, but also \
increases the number of steps required to find the solution over a fixed \
interval ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". For a method with error that is of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", the error in the solution, found over a fixed time interval ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", scales like ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], ")"}], "n"], TraditionalForm]]],
  "."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:48"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4.4 The Predictor-Corrector Method of Order 2",
  FontFamily->"Helvetica"]], "Subsubtitle",
  CellTags->{"i:49", "c:25"}],

Cell[TextData[{
  "The error in Euler's method arose from the crude approximation to the \
integral in ",
  ButtonBox["Eq. (1.4.6)",
    ButtonData:>"(1.4.6)",
    ButtonStyle->"Hyperlink"],
  ". To improve the approximation, we need a more accurate value for this \
integral. Now, the required integral is just the area under the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "),",
  StyleBox["t",
    FontSlant->"Italic"],
  "), shown schematically in Fig. ",
  ButtonBox["1.11 (a)",
    ButtonData:>"Fig. 1.11",
    ButtonStyle->"Hyperlink"],
  ". ",
  ButtonBox["Equation (1.4.6)",
    ButtonData:>"(1.4.6)",
    ButtonStyle->"Hyperlink"],
  " approximates this area by the gray rectangle in Fig. ",
  ButtonBox["1.11.a)",
    ButtonData:>"Fig. 1.11",
    ButtonStyle->"Hyperlink"],
  " which is clearly a rather poor approximation to the area under the curve, \
if the function varies much over the step size \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ".  A better approximation would be to use the average value of the \
function  at the initial and final points in determining the area: "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Integral]\_\(t\_\(n - 1\)\)\%\(t\_n\)\(f(t, 
              v(t))\) \[DifferentialD]t\), "\[TildeTilde]", 
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], 
            " ", \(\(f(t\_\(n - 1\), v(t\_\(n - 1\))) + 
                  f(t\_n, v(t\_n))\)\/2\)}], "+", 
          RowBox[{"O", "(", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "3"], ")"}]}]}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(1.4.10)"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0001HR000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooon<0?ooo`030?knoP3oool0oooo07D0oooo00<0o_kn
0?ooo`3oool0o`3ooomK0?ooo`00H`3oool02030`<00@410000000000000@4100<30`03oool0P820
0P0000000`10@400P8200?ooo`0;0?ooo`050820P0010@400@4100000020P800o`3oool50?ooo`07
0820P0000000000000000020P800oooo0820P003000000030820P03oool0oooo07<0oooo00L0P820
000000000000@4100820P03oool0P82000<0000000<0P8200?ooo`3oool02@3oool01P30`<00@410
000000000000@4100<30`?l0oooo103oool02030`<00@410000000000000@4100<30`03oool0P820
0P0000000`10@400P8200?ooo`0`0?ooo`00I@3oool2000000@0oooo00<0P8200000003oool03P3o
ool00`20P80000000?ooo`3o0?ooo`L0oooo00<0P8200000003oool0103oool00`000000P8200?oo
o`1f0?ooo`030820P0000000oooo00<0oooo00<0P82000000020P8003P3oool200000?l0oooo203o
ool2000000@0oooo00<0P8200000003oool0<P3oool006D0oooo0P0000040?ooo`030820P0000000
oooo00h0oooo00<0P8200000003oool0o`3oool70?ooo`030820P0000000oooo00@0oooo00<00000
0820P03oool0MP3oool00`20P80000000?ooo`030?ooo`030820P0000000P82000h0oooo0P00003o
0?ooo`P0oooo0P0000040?ooo`030820P0000000oooo0380oooo001U0?ooo`800000103oool00`20
P80000000?ooo`0>0?ooo`030820P0000000oooo0?l0oooo1`3oool00`20P80000000?ooo`040?oo
o`0300000020P800oooo07H0oooo00<0P8200000003oool00`3oool00`20P80000000820P00>0?oo
o`800000o`3oool80?ooo`800000103oool00`20P80000000?ooo`0b0?ooo`00I@3oool2000000@0
oooo00<0P8200000003oool00P3oool00`2o_kl0P8200820P0030820P0H0oooo00<0P8200000003o
ool0o`3oool70?ooo`030820P0000000oooo00@0oooo00<000000820P03oool0MP3oool00`20P800
00000?ooo`030?ooo`030820P0000000P82000<0oooo1@20P8000`2o_kl0oooo0?ooo`030?ooo`80
0000o`3oool80?ooo`800000103oool00`20P80000000?ooo`0b0?ooo`00I@3oool2000000@0oooo
00<0P8200000003oool00P3oool01020P8000000000000010@42000000H0oooo00<0P8200000003o
ool0o`3oool70?ooo`030820P0000000oooo00@0oooo00<000000820P03oool0MP3oool00`20P800
00000?ooo`030?ooo`030820P0000000P82000<0oooo0P00000010010@40000000000020P8050?oo
o`800000o`3oool80?ooo`800000103oool00`20P80000000?ooo`0b0?ooo`00I@3oool2000000@0
oooo00<0P8200000003oool03P3oool00`20P80000000?ooo`3o0?ooo`L0oooo00<0P8200000003o
ool0103oool00`000000P8200?ooo`1f0?ooo`030820P0000000oooo00<0oooo00<0P82000000020
P8003P3oool200000?l0oooo203oool2000000@0oooo00<0P8200000003oool0<P3oool006D0oooo
0P0000040?ooo`030820P0000000oooo00h0oooo00<0P8200000003oool0o`3oool70?ooo`030820
P0000000o_kn00@0oooo00<000000820P03oool0MP3oool00`20P8000@410?ooo`030?ooo`030820
P0000000Ogmo00h0oooo0P00003o0?ooo`@0oooo00@0o_kn0?ooo`3oool0oooo0P0000040?ooo`03
0820P0000000oooo0380oooo001O0?ooo`040410@00000000@410820P080oooo0P0000001P30`<00
oooo0?ooo`3oool0@D51000000l0oooo00<0P8200000003oool0o`3oool01@30`<000@4100410@10
@400`<300080oooo00<0P82000000020P8000`3oool00`20P8000@410820P01`0?ooo`050<30`000
000000000410@030`<000P3oool00`20P80000000<30`0030?ooo`030451@@000000P82000h0oooo
0P00003o0?ooo`40oooo00D0`<30000000000000P8200<30`0020?ooo`80000000H0`<300?ooo`3o
ool0oooo0410@0010@4c0?ooo`00GP3oool00`20P800000000410@020820P0060410@00000000000
00000030`<00@4100P20P8000`000000P8200?ooo`0>0?ooo`030820P0000000oooo0?l0oooo00L0
0@41000000000000P8200451@@3oool0@4100080000000@0oooo0410@020P800P8200P00001a0?oo
o`<0000000@0P8200410@03oool0@4100P0000001030`<0000000820P020P802000000l0oooo0P00
003o0?ooo`40oooo0P0000001010@400P8200410@030`<03000000060<30`010@400P8200820P000
0000P820<`3oool005h0oooo00<0P82000000020P8000P3oool01030`<00oooo0?ooo`20P8020?oo
o`80P82000<0`<300?ooo`3oool03P3oool00`20P80000000?ooo`3o0?ooo`80000000@0P8200?oo
o`3oool0P8200P3oool01020P800oooo0?ooo`30`<020820P780oooo0P0000001020P800oooo0?oo
o`20P8020?ooo`060820P03oool0oooo0<30`020P800_kno403oool200000?l0oooo0@3oool20000
00<0oooo00@0`<300?ooo`3oool0P8200P3oool20820P0030<30`03oool0oooo0380oooo001N0?oo
o`030820P0000000P82001/0oooo00<0P8200000003oool0o`3oool2000000030820P03oool0oooo
07/0oooo0P0000000`20P800oooo0?ooo`0I0?ooo`800000o`3oool10?ooo`800000@03oool005h0
oooo00<0P82000000020P8006`3oool00`20P80000000?ooo`3o0?ooo`80000000<0P8200?ooo`3o
ool0N`3oool2000000030820P03oool0oooo01T0oooo0P00003o0?ooo`40oooo0P0000100?ooo`00
GP3oool00`20P80000000820P00K0?ooo`030820P0000000oooo0?l0oooo0P0000000`20P800oooo
0?ooo`1k0?ooo`80000000<0P8200?ooo`3oool06@3oool200000?l0oooo0@3oool200000400oooo
001N0?ooo`030820P0000000P82001T0oooo0P20P80200000?l0oooo0@3oool2000000030820P03o
ool0oooo07/0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`040820P010@400000000000?l0oooo
0@3oool200000400oooo001N0?ooo`030820P0000000P82001`0oooo00<000000?ooo`3oool0oP3o
ool2000000030820P03oool0oooo07/0oooo0P0000000`20P800oooo0?ooo`0J0?ooo`030000003o
ool0oooo0?h0oooo0P0000100?ooo`00GP3oool00`20P80000000820P03o0?oooah0oooo0P000000
0`20P800oooo0?ooo`1k0?ooo`80000000<0P8200?ooo`3oool0o`3ooolL0?ooo`800000@03oool0
05h0oooo00<0P82000000020P800o`3ooolN0?ooo`80000000<0P8200?ooo`3oool0N`3oool20000
00030820P03oool0oooo0?l0oooo703oool00`0000000@410?ooo`0o0?ooo`00GP3oool00`20P800
00000820P03o0?oooah0oooo0P0000000`20P800oooo0?ooo`1k0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooolL0?ooo`800000@03oool005h0oooo00<0P82000000020P800o`3ooolN0?ooo`800000
00<0P8200?ooo`3oool0N`3oool2000000030820P03oool0oooo0?l0oooo6`3oool00`3no_h00000
000000100?ooo`00G03oool00`10@400000000000004000000030820P03oool0oooo0?l0oooo5`3o
ool00`10@400000000000004000007T0oooo00<0@4100000000000001000003o0?oooaT0oooo00<0
`<30000000000000100000000`010@40oooo0?ooo`0k0?ooo`00GP3oool00`10@40000000820P03o
0?oooad0oooo00@0`<30000000000000P820O03oool01030`<00000000000020P83o0?oooad0oooo
00<0P820000000000000@03oool005l0oooo00<000000820P03oool0o`3ooolM0?ooo`030820P000
0000P82007d0oooo00<0P82000000020P800o`3ooolN0?ooo`030820P0000000oooo03l0oooo001O
0?ooo`80P820o`3ooolO0?ooo`0300000020P800oooo07d0oooo00<000000820P03oool0o`3ooolN
0?ooo`030000003oool0oooo03h0oooo001O0?ooo`030<30`020P800oooo0?l0oooo7P3oool20820
P7h0oooo0P20P83o0?oooal0oooo00<0@4100?ooo`3oool0?P3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooon?0?ooo`040<30`000000000000820
P?l0ooooW@3oool01020P80000000410@030`<0^0?ooo`00o`3ooon?0?ooo`080820P00000000@41
00410@000000@41007moO`2o_koo0?oooiT0oooo1@0000000`10@400P8200?ooo`0Z0?ooo`00o`3o
oon?0?ooo`T00000o`3ooonG0?ooo`030820P0000000000000L00000:@3oool00?l0ooooS`3oool0
0`010@4000000000000700000080P820o`3ooonD0?ooo`030820P0010@40000000H0000000@00@41
00000020P800_kno9P3oool00?l0ooooS`3oool=000000030410@020P800oooo0?l0ooooT03oool0
1020P800000000410@010@4:000000030410@030`<00oooo0280oooo003o0?ooohh0oooo00<0P820
0000000000003P0000000`10@400P8200820P03o0?ooohd0oooo00@00@410000000000000@413@00
00020820P0030<30`03oool0oooo01d0oooo003o0?ooohh0oooo00<0P8200000000000004@000000
0`010@40P8200?ooo`3o0?ooohX0oooo4`0000000`010@4000000?ooo`0M0?ooo`00o`3ooon>0?oo
o`030820P0000000000001<0000000<0@4100820P03oool0o`3ooon80?ooo`<0000000<00@410000
00000000400000000`10@400P8200?ooo`0J0?ooo`007P3ooooo00000800000000@00@4100000001
0@400@411000000010010@40P8200820P020P80E0?ooo`030820P000000000000?l00000K`000000
0`010@400000000000080000000600410@000000000000410@0000000@411P0000020820P0030<30
`03oool0oooo01D0oooo000M0?oood40000000<00@41000000000000o`00000P0000000300410@00
0000000002@0000000<0@4100820P02o_kl04P3oool01020P8000000000000010@7o000008<00000
00<00@410000000000000P0000000`10@400P8200?ooo`0F0?ooo`007@3ooom2000000800@41o`00
000N0000000300410@000000000001l000000P010@44000001H0oooo00<0P820000000000000o`00
0027000000030820P03oool0oooo01P0oooo000M0?ooo`800000?P3oool2000000030820P03oool0
oooo0?l0oooo;03oool00`10@40000000000000=0000000300410@00000000000080000000<00@41
0820P03oool05`3oool01020P800000000000020P80l0?ooo`030>CTi039bLT0b<S80?l0b<S87P38
b<P00`39bLT0b<S80>CTi00>0?oooaH0000000<0P8200?ooo`3oool06P3oool001d0oooo0P00000n
0?ooo`03000000010@40I6AT0?l0b<S88038b<P>0?ooo`030820P0000000000000l0000000<0@410
0820P030`<006P3oool01020P800000000000020P80l0?ooo`040>CTi038b<P0b<S80<W9bOl0b<S8
7038b<P01039bLT0b<S80<S8b03Ti>@>0?oooa80000000<0@4100820P03oool07P3oool001d0oooo
0P00000n0?ooo`80000000<0I6AT0<W9b@38b<P0o`38b<PN0<S8b0h0oooo00<0`<30000000000000
2@0000000`010@400000000000020820P1h0oooo00@0P820000000000000P820?03oool00`3Ti>@0
b<S80<S8b03o0<S8b200b<S800<0i>CT0?ooo`3oool0303oool00`10@40000000000000200410@<0
000000<00@41000000010@40100000000`20P800`<300?ooo`0Q0?ooo`007@3oool2000003h0oooo
0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S83`3oool<000000030820P03oool0oooo01l0oooo
00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT0?ooo`3o
ool0303oool00`20P8000000000000090000000300410@3oool0oooo02@0oooo000M0?ooo`800000
?P3oool00`20P800LW9b09NGU`3o0<S8b200b<S83`3oool80000000300410@20P800P82002<0oooo
00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT0?ooo`3o
ool0303oool00`20P800000000410@050000000400410@000000P8200;no_bL0oooo000M0?ooo`80
0000?`3oool00`3Ti>@0b<S80<S8b03o0<S8b1l0b<S80P20P8000`30`<00oooo0?ooo`0:0?ooo`03
0820P0000000000000<000000P20P80V0?ooo`040820P000000000000820P3`0oooo00<0i>CT0<S8
b038b<P0o`38b<PP0<S8b0040>CTi020P800P8200820P0`0oooo1P0000000`20P800`<300?ooo`0Y
0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b039bLT0o`38b<PO0<S8b080000000<0P8200?oo
o`3oool02P3oool01@20P800000000000020P800`<3002T0oooo00@0P820000000000000P820?03o
ool00`3Ti>@0I6AT06ATI03o0<S8b200b<S800@0i>CT000000010@4000003@3oool00`000000@410
0820P00^0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080000000<0
P8200?ooo`3oool0>03oool01020P800000000000020P80l0?ooo`030>CTi000000000000?l0b<S8
8038b<P0103Ti>@0000000000000000n0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0
o`38b<PO0<S8b080000000<0P8200?ooo`3oool0>03oool01020P800000000000020P80l0?ooo`03
0>CTi000000000000?l0b<S88038b<P0103Ti>@0000000000000000n0?ooo`007@3oool2000003l0
oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080000000<0P8200?ooo`3oool0>03oool01020P800
000000000020P80l0?ooo`030>CTi000000000000?l0b<S88038b<P0103Ti>@0000000000000000n
0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080000000<0P8200?oo
o`3oool07@3oool00`30`<00P8200<30`00H0?ooo`040820P000000000000820P3`0oooo00<0i>CT
000000000000o`38b<PP0<S8b0040>CTi00000000000000001l0oooo00<0`<300820P020P800703o
ool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P2000000030820P03oool0
o_kn01d0oooo1000000G0?ooo`040820P000000000000820P3`0oooo00<0i>CT000000000000o`38
b<PP0<S8b0040>CTi00000000@41000001l0oooo0`0000000`010@40oooo0?ooo`0I0?ooo`007@3o
ool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080P82000<0`<300?ooo`3oool0703o
ool3000000<0P8205P3oool01020P800000000000020P80l0?ooo`030>CTi000000000000?l0b<S8
8038b<P0103Ti>@0P8200820P020P80N0?ooo`040820P000000000000410@080P8206P3oool001d0
oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<PQ0?ooo`80000000@0P8200?ooo`3o
ool0`<305P3oool01020P800000000000020P80l0?ooo`030>CTi000000000000?l0b<S88038b<P0
0`3Ti>@0oooo0?ooo`0O0?ooo`030820P000000000000080oooo00<0`<300?ooo`3oool0603oool0
01d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<PQ0?ooo`80000000<0P8200?oo
o`3oool05`3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P0
0`3Ti>@0oooo0?ooo`0O0?ooo`030820P0000000000001d0oooo000M0?ooo`800000?`3oool00`3T
i>@0b<S80<S8b03o0<S8b1l0b<S88@3oool00`010@4000000820P00I0?ooo`040820P00000000000
0820P3`0oooo00<0i>CT0<S8b038b<P0o`38b<PP0<S8b0030>CTi03oool0oooo01l0oooo00<0P820
0000000000007@3oool001d0oooo0P00000n0?ooo`030820P01cLg<0UYJF0?l0b<S88038b<PQ0?oo
o`80000000<0P8200?ooo`3oool05`3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0
b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0O0?ooo`030820P0000000000001d0oooo000M0?oo
o`800000?P3oool20000000406ATI038b<P0b<S80<W9bOl0b<S87@38b<PQ0?ooo`80000000<0P820
0?ooo`3oool05`3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038
b<P00`3Ti>@0oooo0?ooo`0O0?ooo`030820P0000000000001d0oooo000M0?ooo`800000?P3oool2
0000000306EUI@38b<P0b<S80?l0b<S87P38b<PQ0?ooo`80000000<0P8200?ooo`3oool05`3oool0
1020P800000000000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?oo
o`0O0?ooo`030820P0000000000001d0oooo000M0?ooo`800000?P3oool20000000306ATI038b<P0
alO70?l0b<S87P38b<PQ0?ooo`80000000<0P8200?ooo`3oool05`3oool01020P800000000000020
P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0O0?ooo`030820P000
0000000001d0oooo000M0?ooo`800000?P3oool010010@40000006ATI039bLWo0<S8b1l0b<S88@3o
ool2000000030820P03oool0oooo01L0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S8
0<S8b03o0<S8b200b<S800<0i>CT0?ooo`3oool07`3oool00`20P80000000000000M0?ooo`007@3o
ool2000003h0oooo00<0000000410@1TI6@00P38b<P00`39bLT0b<S80<S8b03o0<S8b1P0b<S80`39
bLTQ0?ooo`0300410@000000P82001T0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S8
0<S8b03o0<S8b200b<S800<0i>CT0?ooo`3oool07`3oool00`20P80000000000000M0?ooo`007@3o
ool2000003h0oooo00<0000000410@1UIFD00P38b<P00`39bLT0b<S80<S8b03o0<S8b1T0b<S80P39
bLTO0?ooo`80P8200P0000001010@400P8200820P030`<0F0?ooo`040820P000000000000820P3`0
oooo00<0i>CT0<S8b038b<P0o`38b<PP0<S8b0030>CTi03oool0oooo01d0oooo0P20P8000`10@400
0000000000020820P0030<30`03oool0oooo01P0oooo000M0?ooo`800000?`3oool0103Ti>@0b<S8
0<S8b039bLWo0<S8b1h0b<S87`3oool00`20P8000000000000020000000300410@000000P82001H0
oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT0?oo
o`3oool07P3oool6000000030820P03oool0oooo01P0oooo000M0?ooo`800000?`3oool00`3Ti>@0
b<S80<W9b@3o0<S8b1l0b<S80P20P8000`30`<00oooo0?ooo`0K0?ooo`040<30`000000000000820
P1T0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800@0i>CT
0820P020P800P8207P3oool00`10@40000000000000M0?ooo`007@3oool2000003l0oooo00<0i>CT
0<S8b038b<P0o`38b<PO0<S8b080000000<0P8200?ooo`3oool07@3oool00`000000P8200?ooo`0H
0?ooo`040820P000000000000820P3`0oooo00<0i>CT06ATI01TI6@0o`38b<PP0<S8b0040>CTi000
00000000000001l0oooo0P00000M0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38
b<PO0<S8b080000000<0P8200?ooo`3oool07@3oool20820P1T0oooo00@0P820000000000000P820
?03oool00`3Ti>@000000000003o0<S8b200b<S800@0i>CT00000000000000007`3oool00`20P800
00000?ooo`0L0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b0800000
00<0P8200?ooo`3oool07P3oool00`30`<00oooo0?ooo`0G0?ooo`040820P000000000000820P3`0
oooo00<0i>CT000000000000o`38b<PP0<S8b0040>CTi0000000000000000200oooo00<0P8200?oo
o`3oool06`3oool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P200000003
0820P03oool0oooo03P0oooo00@0P820000000000000P820?03oool00`3Ti>@000000000003o0<S8
b200b<S800@0i>CT0000000000000000?P3oool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S8
0?l0b<S87`38b<P2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820?03oool0
0`3Ti>@000000000003o0<S8b200b<S800@0i>CT0000000000000000?P3oool001d0oooo0P00000o
0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P2000000030820P03oool0oooo03P0oooo00@0P820
000000000000P820?03oool00`3Ti>@000000000003o0<S8b200b<S800@0i>CT0000000000000000
?P3oool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P20820P0030<30`03o
ool0oooo03P0oooo00@0P820000000000000P820?03oool00`3Ti>@000000000003o0<S8b200b<S8
00@0i>CT0820P020P800P820?P3oool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S8
7`38b<Pm0?ooo`040820P000000000000820P3`0oooo00<0i>CT000000000000o`38b<PP0<S8b003
0>CTi03oool0oooo03l0oooo000M0?ooo`800000?`3oool00`3Ti>@0b<S80<S8b03o0<S8b1l0b<S8
?@3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0
oooo0?ooo`0o0?ooo`007@3oool2000003l0oooo00@0i>CT0<S8b038b<P0bLW9o`38b<PN0<S8b3d0
oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT0?oo
o`3oool0?`3oool001d0oooo0P00000n0?ooo`80000000<0I6AT0<S8b038b<P0o`38b<PN0<S8b3d0
oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT0?oo
o`3oool0?`3oool001d0oooo0P00000n0?ooo`80000000<0I6AT0<S8b039bLT0o`38b<PN0<S8b3d0
oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT0?oo
o`3oool0?`3oool001d0oooo0P00000n0?ooo`80000000@0IFEU0<S8b038b<P0bLW9o`38b<PM0<S8
b3d0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT
0?ooo`3oool0?`3oool001d0oooo0P00000n0?ooo`0300410@000000I6AT0?l0b<S88038b<Pm0?oo
o`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0o`38b<PP0<S8b0030>CTi03oool0
oooo03l0oooo000M0?ooo`800000?P3oool20000000306ATI038b<P0b<S80?l0b<S87P38b<Pm0?oo
o`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0o`38b<PP0<S8b0030>CTi03oool0
oooo03l0oooo000M0?ooo`800000?P3oool20000000306EUI@38b<P0b<S80?l0b<S87P38b<Pm0?oo
o`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0o`38b<PP0<S8b0030>CTi03oool0
oooo03l0oooo000M0?ooo`800000?P3oool20000000406ATI038b<P0b<S80<W9bOl0b<S87@38b<Pm
0?ooo`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0o`38b<PP0<S8b0030>CTi03o
ool0oooo03l0oooo000M0?ooo`800000?P3oool00`20P800Lg=c09JFUP3o0<S8b200b<S8?@3oool0
1020P800000000000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?oo
o`0o0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080P82000<0`<30
0?ooo`3oool0>03oool01020P800000000000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038
b<P0103Ti>@0P8200820P01oOgln0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38
b<PM0<S8b0050<W9b@38b<P0000000000020P800>P3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P0103Ti>@0000000000000000n0?ooo`007@3oool2000003l0
oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b003000000010@40P82003X0oooo00@0P82000000000
0000P820?03oool00`3Ti>@000000000003o0<S8b200b<S800@0i>CT000000010@400000?P3oool0
01d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P00`0000000@410820P00j0?oo
o`040820P000000000000820P3`0oooo00<0i>CT000000000000o`38b<PP0<S8b0040>CTi0000000
0000000003h0oooo000M0?ooo`800000?`3oool00`3Ti>@0b<S80<S8b03o0<S8b1d0b<S800D0bLW9
0<S8b000000000000820P00j0?ooo`040820P000000000000820P3`0oooo00<0i>CT000000000000
o`38b<PP0<S8b0040>CTi00000000000000003h0oooo000M0?ooo`800000?`3oool00`3Ti>@0b<S8
0<S8b03o0<S8b1l0b<S80P0000000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P3`0
oooo00<0i>CT000000000000o`38b<PP0<S8b0040>CTi00000000000000003h0oooo000M0?ooo`80
0000?`3oool00`3Ti>@0b<S80<S8b03o0<S8b1l0b<S800<0000000410@20P800>P3oool01020P800
000000000020P80l0?ooo`030>CTi000000000000?l0b<S88038b<P0103Ti>@0000000000000000n
0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080P82000<0`<300?oo
o`3oool0>03oool01020P800000000000020P80l0?ooo`030>CTi000000000000?l0b<S88038b<P0
103Ti>@0P8200820P020P80n0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PM
0<S8b0030<W9b@38b<P0oooo03`0oooo00@0P820000000000000P820?03oool00`3Ti>@0I6AT06AT
I03o0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00000o0?ooo`040>CTi038b<P0
b<S80<O7aol0b<S87P38b<Pm0?ooo`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0
o`38b<PP0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000?`3oool0103Ti>@0b<S80<W9
b@39bLWo0<S8b1h0b<S8?@3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0b<S80?l0
b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo00<0000000410@1UIFD0
0P38b<P00`39bLT0b<S80<S8b03o0<S8b1/0b<S8?@3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo
00<0000000410@1TI6@00P38b<P00`39bLT0b<S80<S8b03o0<S8b1/0b<S8?@3oool01020P8000000
00000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`00
7@3oool2000003h0oooo0P0000000`1TI6@0bLW90<S8b03o0<S8b1h0b<S8?@3oool01020P8000000
00000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`00
7@3oool2000003h0oooo0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P8000000
00000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`00
7@3oool2000003h0oooo0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P8000000
00000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`00
7@3oool2000003h0oooo0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P8000000
00000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`00
7@3oool2000003h0oooo0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P8000000
00000020P80l0?ooo`030>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`00
7@3oool2000003h0oooo00<0P820079bLP2FUYH0o`38b<PP0<S8b3d0oooo00@0P820000000000000
P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo
0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P20820P0030<30`03oool0oooo03P0oooo
00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o0<S8b200b<S800@0i>CT0820P020
P800P820?P3oool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P200000003
0820P03oool0oooo03P0oooo00@0P820000000000000P820?03oool00`3Ti>@0I6AT06ATI03o0<S8
b200b<S800@0i>CT00410@0000000000?P3oool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S8
0?l0b<S87`38b<P2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820?03oool0
0`3Ti>@000000000003o0<S8b200b<S800@0i>CT0000000000000000?P3oool001d0oooo0P00000o
0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P2000000030820P03oool0oooo03P0oooo00@0P820
000000000000P820?03oool00`3Ti>@000000000003o0<S8b200b<S800@0i>CT0000000000000000
?P3oool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<P2000000030820P03o
ool0oooo03P0oooo00@0P820000000000000P820?03oool00`3Ti>@000000000003o0<S8b200b<S8
00@0i>CT0000000000000000?P3oool001d0oooo0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S8
7`38b<P2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820?03oool00`3Ti>@0
00000000003o0<S8b200b<S800@0i>CT00410@0000000000?P3oool001d0oooo0P00000o0?ooo`03
0>CTi038b<P0b<S80?l0b<S87`38b<P00`0000000@410820P00j0?ooo`040820P000000000000820
P3`0oooo00<0i>CT000000000000o`38b<PP0<S8b0040>CTi0000000000000410Ch0oooo000M0?oo
o`800000?`3oool00`3Ti>@0b<S80<S8b03o0<S8b1l0b<S8?@3oool01020P800000000000020P80l
0?ooo`030>CTi000000000000?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool20000
03l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b3d0oooo00@0P820000000000000P820?03oool0
0`3Ti>@000000000003o0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00000o0?oo
o`030>CTi038b<P0b<S80?l0b<S87`38b<Pm0?ooo`040820P000000000000820P3`0oooo00<0i>CT
0<S8b038b<P0o`38b<PP0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000?`3oool00`3T
i>@0b<S80<W9b@3o0<S8b1l0b<S8?@3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0
b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo0P0000000`1U
IFD0b<S80<O7a`3o0<S8b1h0b<S8?@3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0
b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo00<000000041
0@1TI6@0o`38b<PP0<S8b3d0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o
0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00000n0?ooo`80000000<0I6AT0<S8
b038b<P0o`38b<PN0<S8b3d0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o
0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00000n0?ooo`80000000<0I6AT0<S8
b038b<P0o`38b<PN0<S8b3d0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o
0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00000n0?ooo`80000000<0I6AT0<S8
b038b<P0o`38b<PN0<S8b3d0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o
0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00000n0?ooo`80000000<0I6AT0<S8
b038b<P0o`38b<PN0<S8b3d0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b03o
0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00000n0?ooo`80000000<0I6AT0<S8
b038b<P0o`38b<PL0<S8b0030<W9b@38b<P0oooo03`0oooo00@0P820000000000000P820?03oool0
0`3Ti>@0b<S80<S8b03o0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00000o0?oo
o`030>CTi038b<P0b<S80?l0b<S87`38b<Pm0?ooo`040820P000000000000820P3`0oooo00<0i>CT
0<S8b038b<P0o`38b<PP0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000?`3oool00`3T
i>@0b<S80<S8b03o0<S8b1l0b<S80P0000000`20P800oooo0?ooo`0h0?ooo`040820P00000000000
0820P3`0oooo00<0i>CT0<S8b038b<P0o`38b<PP0<S8b0040>CTi00000000000000003h0oooo000M
0?ooo`800000?`3oool00`3Ti>@0bLW90<W9b@3o0<S8b1l0b<S800<0000000410@20P800>P3oool0
1020P800000000000020P80l0?ooo`030>CTi01TI6@0I6AT0?l0b<S88038b<P0103Ti>@000000000
0000000n0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080000000<0
P8200?ooo`3oool0>03oool01020P800000000000020P80l0?ooo`030>CTi000000000000?l0b<S8
8038b<P0103Ti>@0000000000000000n0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0
o`38b<PO0<S8b080000000<0P8200?ooo`3oool0>03oool01020P800000000000020P80l0?ooo`03
0>CTi000000000000?l0b<S88038b<P0103Ti>@0000000000000000n0?ooo`007@3oool2000003l0
oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080000000<0P8200?ooo`3oool0>03oool01020P800
000000000020P80l0?ooo`030>CTi000000000000?l0b<S88038b<P0103Ti>@0000000000000000n
0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b080000000<0P8200?oo
o`3oool0>03oool01020P800000000000020P80l0?ooo`030>CTi000000000000?l0b<S88038b<P0
103Ti>@0000000000000000n0?ooo`007@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO
0<S8b080000000<0P8200?ooo`3oool0>03oool01020P800000000000020P80l0?ooo`030>CTi000
000000000?l0b<S88038b<P0103Ti>@0000000000000000n0?ooo`007@3oool2000003l0oooo00<0
i>CT0<S8b038b<P0o`38b<PO0<S8b080P82000<0`<300?ooo`3oool0>03oool01020P80000000000
0020P80l0?ooo`030>CTi000000000000?l0b<S88038b<P0103Ti>@0P8200820P020P80n0?ooo`00
7@3oool2000003l0oooo00<0i>CT0<S8b038b<P0o`38b<PO0<S8b3d0oooo00@0P820000000000000
P820?03oool00`3Ti>@000000000003o0<S8b200b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo
0P00000o0?ooo`030>CTi038b<P0b<S80?l0b<S87`38b<Pm0?ooo`040820P000000000000820P3`0
oooo00<0i>CT0<S8b038b<P0o`38b<PP0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000
?`3oool00`3Ti>@0bLW90<S8b03o0<S8b1l0b<S8?@3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo
0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo
0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo
0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo
0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo
0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo
0P0000000`1TI6@0b<S80<S8b03o0<S8b1h0b<S8?@3oool01020P800000000000020P80l0?ooo`03
0>CTi038b<P0b<S80?l0b<S88038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000003h0oooo
00@0000000410@000000UYJF0P38b<P20<W9bOl0b<S86P38b<P00`39bLT0oooo0?ooo`0k0?ooo`04
0820P000000000000820P3`0oooo00D0i>CT0<S8b00c<c<0000009JFUP3o0<S8b1h0b<S800<0i>CT
0?ooo`3oool0?`3oool001d0oooo0P00000<0?ooo`L0P82000<0`<300?ooo`3oool02@3oool00`30
`<00P8200820P0040820P0030<30`03oool0oooo00T0oooo1`20P8050?ooo`80000000D00@410000
001TI6@0I6AT06EUI@3o06ATI1X0I6AT00D0IFEU06ATI020P800P8200<30`00j0?ooo`040820P000
000000000820P0/0oooo1`20P80<0?ooo`L0P820303oool70820P0060<30`03oool0oooo0?ooo`3T
i>@0I6AT0`0000000`2GUiL0bLW90<S8b03o0<S8b1/0b<S800<0i>CT0?ooo`3oool0?`3oool001d0
oooo0P00000<0?ooo`L0000000<0P8200?ooo`3oool02@3oool00`20P80000000000000400000003
0820P03oool0oooo00T0oooo0`00000010010@4000000000000000040?ooo`030410@00000000000
00D0000000<00@41000000000000o`00000K000000030820P03oool0oooo03P0oooo00@0P8200000
00000000P8202`3oool20000000300410@000000000000800000303oool7000000`0oooo1`000000
1@20P800oooo0?ooo`3oool0/[:b00D0000000<0UYJF0<W9b@38b<P0o`38b<PJ0<S8b0040>CTi020
P800P8200820P3h0oooo000M0?ooo`800000303oool70820P0030<30`03oool0oooo00T0oooo00<0
`<300820P020P8001020P8000`2o_kl0oooo0?ooo`090?ooo`L0P8200`3oool01@10@40000000041
0@0000000@410080000000<00@4100000020P800o`20P80K0820P080000000<0P8200?ooo`3oool0
>03oool01020P800000000000020P80;0?ooo`L0P820303oool70820P0`0oooo1`20P8001030`<00
oooo0?ooo`20P8060000000300410@1TI6@0b<S80?l0b<S86P38b<P0103Ti>@0000000410@00000n
0?ooo`007@3oool2000003/0oooo00<0P8200000000000001`0000000`20P800oooo0?ooo`3o0?oo
oaT0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P3X0oooo00<0P820
0000000000000`0000001@010@400000000000010@40IFEU0?l0b<S86P38b<P0103Ti>@000000000
0000000n0?ooo`007@3oool2000003`0oooo00<0@41000410@0000001`0000000`20P800oooo0?oo
o`3o0?oooaP0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P3/0oooo
00@0P8200000000000000@411@0000000`010@40UYJF0<W9b@3o0<S8b1P0b<S800@0i>CT00000000
00000000?P3oool001d0oooo0P00000m0?ooo`030410@0000000000000D0000000<00@4100000010
@400o`3ooolI0?ooo`80000000<0P8200?ooo`3oool0>03oool01020P800000000000020P80l0?oo
o`030;:b/P000000000000H0000000<00@4109JFUP39bLT0o`38b<PG0<S8b0040>CTi00000000000
000003h0oooo000M0?ooo`800000?P3oool00`20P800000000000007000000030410@03oool0oooo
0?l0oooo5P3oool2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820?03oool0
0`3Ti>@0000000410@080000000309NGU`38b<P0b<S80?l0b<S85@38b<P0103Ti>@0000000000000
000n0?ooo`007@3oool2000003l0oooo00<0P8200000000000001`0000000`20P800oooo0?ooo`3o
0?oooaD0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P3`0oooo00<0
i>CT0000000000002@00003o0<S8b1L0b<S800@0i>CT0000000000000000?P3oool001d0oooo0P00
00100?ooo`060<30`0000000000000410@0000000@41100000000`20P800oooo0?ooo`3o0?oooa@0
oooo0P20P8000`30`<00oooo0?ooo`0h0?ooo`040820P000000000000820P3`0oooo00D0i>CT0000
00000000I6AT00410@060000000300410@000000UiNG0080bLW9o`38b<PC0<S8b0040>CTi020P800
P8200820P3h0oooo000M0?ooo`800000@@3oool01030`<000000000000010@420000000600410@00
0000000000410@10@400`<30o`3ooomA0?ooo`040820P000000000000820P3`0oooo00D0i>CT06AT
I01TI6@0b<S809JFUP080000000300410@1TI6@0b<S80?l0b<S84`38b<P00`3Ti>@0oooo0?ooo`0o
0?ooo`007@3oool2000004<0oooo00<0@4100000000000000P0000000`010@400000000000020000
00030<30`03oool0oooo0?l0ooooCP3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0
b<S80080b<S800<0UYJF0000000000001@0000000`010@400000038b<P3o0<S8b1<0b<S800<0i>CT
0?ooo`3oool0?`3oool001d0oooo0P0000140?ooo`@000000P010@4400000?l0ooooD03oool01020
P800000000000020P80l0?ooo`030>CTi038b<P0b<S800<0b<S800<0I6AT0000000000002000003o
0<S8b180b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P0000140?ooo`040<30`00000000000
00410@@0000000<00@4100000010@400o`3ooom?0?ooo`040820P000000000000820P3`0oooo00D0
i>CT0<S8b039bLT0b<S80<W9b@020<S8b00506ATI0010@400000000000010@401@0000000`0b<S80
b<S80<S8b03o0<S8b0l0b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P0000150?ooo`050<30
`0010@400000000000010@401P0000000`20P800oooo0?ooo`3o0?oood/0oooo00@0P82000000000
0000P820?03oool01@3Ti>@0b<S80<S8b038b<P0bLW900<0b<S800<0UYJF0000000000001`000000
100c<c<0UYJF0<S8b039bLWo0<S8b0d0b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P000017
0?ooo`030410@0010@400@4100L0000000<0@4100?ooo`3oool0o`3ooom:0?ooo`040820P0000000
00000820P3`0oooo00<0i>CT0<S8b038b<P01P38b<P00`2FUYH0<c<c000000080000000306EUI@38
b<P0b<S80?l0b<S83038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000004P0oooo2P000000
0`20P800oooo0?ooo`3o0?ooodT0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8
b0070<S8b0030<W9b@000000000000P0000000<0I6AT0<S8b038b<P0o`38b<P;0<S8b0030>CTi03o
ool0oooo03l0oooo000M0?ooo`800000B03oool00`30`<00@41000000008000000030820P03oool0
oooo0?l0ooooB03oool01020P800000000000020P80l0?ooo`030>CTi038b<P0b<S800@0b<S800D0
bLW90<S8b038b<P0b<S809JFUP090000000300410@2FUYH0b<S80?l0b<S82`38b<P00`3Ti>@0oooo
0?ooo`0o0?ooo`007@3oool2000004X0oooo00<0P8200000000000001`0000000`10@400`<300?oo
o`3o0?ooodL0oooo00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b00:0<S8b003038b
<P000000000000L0000000<0I6AT0<S8b038b<P0o`38b<P90<S8b0030>CTi03oool0oooo03l0oooo
000M0?ooo`800000B`3oool00`30`<000000000000040000000500410@000000000000000030`<00
o`3ooom70?ooo`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P02`38b<P00`1TI6@0
0000000000080000000309JFUP38b<P0b<S80?l0b<S81`38b<P00`3Ti>@0oooo0?ooo`0o0?ooo`00
7@3oool2000004`0oooo00<0P8200000000000001P0000000`010@4000000?ooo`3o0?ooodH0oooo
00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b0060<S8b080bLW91038b<P00`1UIFD0
00000000000800000?l0b<S82@38b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000004d0oooo
00<0@4100000000000001P0000000`010@4000000<30`03o0?ooo`P0oooo0P20P8000`30`<00oooo
0?ooo`0h0?ooo`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P01P38b<P20<W9b@D0
b<S800<0I6AT00410@0000001`0000000`0b<S80b<S80<S8b03o0<S8b0H0b<S800@0i>CT0820P020
P800P820?P3oool001d0oooo0P00001>0?ooo`030<30`0000000000000<000000P010@4300000003
0410@03oool0oooo0?l0oooo1@3oool2000000030820P03oool0oooo03P0oooo00@0P82000000000
0000P820?03oool00`3Ti>@0I6AT06ATI0070<S8b0030<W9b@38b<P0b<S800@0b<S800@0UYJF0000
000000000@411P0000000`010@40I6AT0<S8b0020<W9bOl0b<S80`38b<P0103Ti>@0000000410@00
000n0?ooo`007@3oool200000500oooo00<0@4100000000000001`0000000`10@400oooo0?ooo`3o
0?ooo`@0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P3`0oooo00<0
i>CT0000000000003`38b<P00`2FUYH000000000000800000003038b<P38b<P0b<S80080b<S800<0
bLW90<S8b038b<P0o@38b<P0103Ti>@0000000000000000n0?ooo`007@3oool200000540oooo2`00
003o0?ooo`D0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P3`0oooo
00<0i>CT0000000000004038b<P00`1TI6@00000000000080000000306ATI038b<P0bLW90?l0b<S8
0P38b<P0103Ti>@0000000000000000n0?ooo`007@3oool200000540oooo00<0`<300410@0010@40
200000000`10@400oooo0?ooo`3o0?ooo`80oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820
P000000000000820P3`0oooo00<0i>CT0000000000003`38b<P01@39bLT0b<S806ATI00c<c<00@41
00P0000000<0UYJF0<S8b039bLT0o`38b<P10<S8b0040>CTi00000000000000003h0oooo000M0?oo
o`800000D`3oool00`20P8000000000000040000000500410@000000000000000030`<00o`3oool2
0?ooo`80000000<0P8200?ooo`3oool0>03oool01020P800000000000020P80l0?ooo`030>CTi000
0000000001<0b<S800<0<c<c0000000000001P0000000`010@40000009NGU`3o0<S8b040b<S800@0
i>CT0000000000000000?P3oool001d0oooo0P00001D0?ooo`030<30`0000000000000P0000000<0
P8200?ooo`3oool0oP3oool2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820
?03oool00`3Ti>@000000000000C0<S8b0050<W9b@0b<S800000000000010@401`0000000`2GUiL0
b<S80<S8b03m0<S8b0040>CTi00000000@41000003h0oooo000M0?ooo`800000E@3oool00`20P800
000000000008000000030820P03oool0oooo0?l0oooo>`3oool01020P800000000000020P80l0?oo
o`030>CTi0000000000001D0b<S82`00003o0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`80
0000EP3oool01010@4000@41000000010@47000000030820P03oool0oooo0?l0oooo>P3oool01020
P800000000000020P80l0?ooo`030>CTi0000000000001H0b<S800<0<c<c00410@0000001`000000
100c<c<0IFEU0<S8b039bLWk0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000E`3oool0
0`20P800@41000000008000000030410@03oool0oooo0?l0oooo>@3oool01020P800000000000020
P80l0?ooo`030>CTi038b<P0b<S801@0b<S800D0bLW90<S8b038b<P0I6AT00410@090000000303<c
<`38b<P0b<S80?X0b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00001I0?ooo`030451@@00
0000000000D0000000@00@41000000010@40`<30o`3oooli0?ooo`040820P000000000000820P3`0
oooo00<0i>CT0<S8b038b<P05@38b<P01039bLT0b<S80<S8b02GUiL200410@P0000000D0<c<c0<S8
b038b<P0b<S80<W9b@3g0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000FP3oool;0000
0?l0oooo>@3oool01020P800000000000020P80l0?ooo`030>CTi038b<P0b<S801T0b<S800<0bLW9
000000000000200000000`1TI6@0b<S80<S8b03h0<S8b0030>CTi03oool0oooo03l0oooo000M0?oo
o`800000F`3oool00`1oOgl00@41000000070000000300410@30`<00oooo0?l0oooo=P3oool01020
P800000000000020P80l0?ooo`030>CTi038b<P0b<S801/0b<S800@0<S8b0000000000000@411P00
00000`0b<S80b<S80<W9b@3g0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000G03oool0
0`30`<000000000000050000000400410@00000000000820P?l0oooo=P3oool01020P80000000000
0020P80l0?ooo`030>CTi038b<P0b<S801X0b<S800<0bLW90<S8b00c<c<01P0000001@010@400000
000000000000UYJF0080bLW9m@38b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000005h0oooo
00<0@4100000000000001`0000000`10@400oooo0?ooo`3o0?oooc<0oooo00@0P820000000000000
P820?03oool00`3Ti>@0b<S80<S8b00N0<S8b003038b<P000000000000L0000000<0UYJF0<S8b038
b<P0m038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000005l0oooo2`00003o0?oooc@0oooo
00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b00O0<S8b0D0000000H00@4100000000
0000000000410@1UIFGe0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000G`3oool00`20
P800000000000008000000030410@03oool0oooo0?l0oooo<@3oool01020P800000000000020P80l
0?ooo`030>CTi038b<P0b<S801h0b<S800<0bLW9038b<P0000000`0000000`010@40000000000002
0000000300410@1TI6@0b<S80?<0b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00001Q0?oo
o`030410@0000000000000@0000000H00@41000000010@4000000820P030`<3o0?oooc00oooo00@0
P820000000000000P820?03oool00`3Ti>@0b<S80<S8b00L0<S8b0050<W9b@38b<P0b<S80<S8b02F
UYH02`0000000`1UIFD0b<S80<S8b03`0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000
HP3oool00`10@400000000000003000000800@41100000000`30`<00oooo0?ooo`3o0?ooobd0oooo
00@0P820000000000000P820?03oool00`3Ti>@0b<S80<S8b00R0<S8b003038b<P010@40000000H0
000000<00@410000000b<S80l@38b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000006@0oooo
1`00000010010@40000000000000003a0?ooo`80000000<0P8200?ooo`3oool0>03oool01020P800
000000000020P80l0?ooo`030>CTi038b<P0b<S802<0b<S800<0I6AT0000000000001P0000000`01
0@4000000000003`0<S8b0040>CTi00000000000000003h0oooo000M0?ooo`800000I03oool00`30
`<00000000000009000000030820P03oool0oooo0>d0oooo0P0000000`20P800oooo0?ooo`0h0?oo
o`040820P000000000000820P3`0oooo00<0i>CT06ATI01TI6@09038b<P00`0b<S80000000410@09
0000000309JFUP38b<P0b<S80>`0b<S800@0i>CT0000000000000000?P3oool001d0oooo0P00001U
0?ooo`030<30`010@400000000T0000000<0@4100?ooo`3oool0k03oool2000000030820P03oool0
oooo03P0oooo00@0P820000000000000P820?03oool00`3Ti>@000000000000S0<S8b080bLW900<0
I6AT0000000000002@0000000`2GUiL0b<S80<S8b03[0<S8b0040>CTi00000000000000003h0oooo
000M0?ooo`800000I`3oool00`20P800000000000009000000030<30`03oool0oooo0>X0oooo0P00
00000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P3`0oooo00<0i>CT000000000000
9`38b<P00`1TI6@00000000000090000000309JFUP38b<P0b<S80>T0b<S800@0i>CT000000000000
0000?P3oool001d0oooo0P00001Y0?ooo`030410@0000000000000P0000000<0P8200<30`03oool0
j@3oool2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820?03oool00`3Ti>@0
00000000000V0<S8b0040<W9b@38b<P0UYJF038b<PH0000000H00@41000000000000000006EUI@39
bLWY0<S8b0040>CTi00000000000000003h0oooo000M0?ooo`800000JP3oool<000000H0oooo00<0
o_kn0?ooo`3oool0h@3oool2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820
?03oool00`3Ti>@000000000000Z0<S8b080000000<00@410000000000001P0000000`1TI6@0bLW9
0<S8b03W0<S8b0040>CTi00000000000000003h0oooo000M0?ooo`800000JP3oool01030`<00@410
000000010@48000000030410@030`<00oooo0>L0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`04
0820P000000000000820P3`0oooo00<0i>CT000000000000:`38b<P00`0b<S800000000000070000
000400410@1TI6@0UYJF0<W9bNH0b<S800@0i>CT0000000000000000?P3oool001d0oooo0P00001/
0?ooo`030820P0000000000000T0000000<0P8200?ooo`3oool0i@3oool20820P0030<30`03oool0
oooo03P0oooo00@0P820000000000000P820?03oool00`3Ti>@000000000000Z0<S8b0030<W9b@38
b<P0<S8b00/0000000D0UYJF0<S8b038b<P0b<S80<W9b@3R0<S8b0040>CTi020P800P8200820P3h0
oooo000M0?ooo`800000K@3oool00`30`<00@410000000050000000600410@000000000000000010
@400`<30o`3ooolS0?ooo`040820P000000000000820P3`0oooo00<0i>CT06ATI01TI6@0;@38b<P0
0`2GUiL00@41000000090000000306ATI038b<P0b<S80><0b<S800<0i>CT0?ooo`3oool0?`3oool0
01d0oooo0P00001_0?ooo`L0000000<00@410000000000000P00003o0?ooob<0oooo00@0P8200000
00000000P820?03oool00`3Ti>@0b<S80<S8b00^0<S8b0030<W9b@000000000000@0000000<00@41
0000000000000`00003T0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000K`3oool00`30
`<00P82000000009000000030410@020P800oooo0?l0oooo803oool01020P800000000000020P80l
0?ooo`030>CTi038b<P0b<S80300b<S800<0IFEU000000000000100000001P010@40000000000000
0000<S8b09JFUPH0b<S80P39bLWJ0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000L@3o
ool00`30`<00@410000000060000000500410@00000000000410@030`<00o`3ooolO0?ooo`040820
P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0<@38b<P00`2FUYH000000000000900000003
06ATI038b<P0b<S800<0b<S80`39bLWI0<S8b0030>CTi03oool0oooo03l0oooo000M0?ooo`800000
L`3oool00`11@D400000000000080000000300410@20P800oooo0?l0oooo7@3oool01020P8000000
00000020P80l0?ooo`030>CTi038b<P0b<S80300b<S800@0bLW90<S8b038b<P0UYJF0`0000000`01
0@400000000000050000000306ATI039bLT0b<S80=d0b<S800<0i>CT0?ooo`3oool0?`3oool001d0
oooo0P00001e0?ooo`X0000000<00@410000003oool0o`3ooolL0?ooo`040820P000000000000820
P3`0oooo00<0i>CT0<S8b038b<P0=038b<P00`1TI6@00000000000090000000306ATI038b<P0b<S8
0=`0b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00001e0?ooo`030<30`010@400000000X0
000000<0`<300?ooo`3oool0o`3ooolI0?ooo`040820P000000000000820P3`0oooo00<0i>CT0<S8
b038b<P0=@38b<P00`1TI6@000000000000900000003038b<P38b<P0b<S80=/0b<S800<0i>CT0?oo
o`3oool0?`3oool001d0oooo0P00001g0?ooo`030410@0000000000000T0000000<0P8200?ooo`3o
ool0o`3ooolH0?ooo`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0=@38b<P01039
bLT0b<S8038b<P010@480000000300410@0b<S80I6AT0=/0b<S800<0i>CT0?ooo`3oool0?`3oool0
01d0oooo0P00001i0?ooo`030410@0010@40000000T0000000<0`<300?ooo`3oool0o`3ooolF0?oo
o`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0=@38b<P20<W9b@030<S8b02FUYH0
000000L0000000D00@41000000000000<S8b0<S8b0020<W9bML0b<S800<0i>CT0?ooo`3oool0?`3o
ool001d0oooo0P00001j0?ooo`030820P0000000000000T0000000<0P8200?ooo`3oool0o`3ooolE
0?ooo`040820P000000000000820P3`0oooo00<0i>CT0<S8b038b<P0>P38b<P<000000030<S8b039
bLT0b<S80=H0b<S800<0i>CT0?ooo`3oool0?`3oool001d0oooo0P00001k0?ooo`030820P0000000
000000L0000000<00@4100000030`<00o`3ooolF0?ooo`040820P000000000000820P3`0oooo00<0
i>CT0<S8b038b<P0>038b<P01039bLT0b<S80<S8b01TI6@60000000500410@00000000000000000b
<S80f038b<P00`3Ti>@0oooo0?ooo`0o0?ooo`007@3oool2000007d0oooo00<0P82000410@000000
200000000`10@400oooo0?ooo`3E0?ooo`80P82000<0`<300?ooo`3oool0>03oool01020P8000000
00000020P80l0?ooo`030>CTi038b<P0b<S803`0b<S800<0UiNG038b<P0000000P010@4700000003
038b<P38b<P0b<S80=@0b<S800@0i>CT0820P020P800Ogmo?P3oool001d0oooo0P00001n0?ooo`03
0820P0010@40000000T0000000<0@4100?ooo`3oool0d`3oool00`0000000@410820P00j0?ooo`04
0820P000000000000820P3`0oooo00<0i>CT06ATI01TI6@0?P38b<P<0000000409NGU`38b<P0b<S8
0<W9bM40b<S800@0i>CT000000010@400000?P3oool001d0oooo0P00001o0?ooo`030820P0000000
000000T0000000<00@410?ooo`3oool0dP3oool2000000030820P03oool0oooo03P0oooo00@0P820
000000000000P820?03oool00`3Ti>@000000000000o0<S8b00306ATI0000000000000H0000000@0
0@410000000000000000d`38b<P0103Ti>@0000000000000000n0?ooo`007@3oool200000800oooo
00<0P8200410@00000002000000010010@4000000820P030`<3A0?ooo`03000000010@40P82003X0
oooo00@0P820000000000000P820?03oool00`3Ti>@000000000000m0<S8b0050<W9b@38b<P0b<S8
06EUI@010@402`0000000`1TI6@0b<S80<S8b03?0<S8b0040>CTi00000000000000003h0oooo000M
0?ooo`800000PP3oool00`20P8000000000000050000000300410@00000000000080000000<0P820
0?ooo`3oool0cP3oool2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820?03o
ool00`3Ti>@000000000000n0<S8b0050<W9b@38b<P0b<S809NGU`0c<c<02`0000000`0b<S80I6AT
0<S8b03>0<S8b0040>CTi00000000000000003h0oooo000M0?ooo`800000P`3oool01@30`<00P820
0000000000000@4100T0000000<0P8200?ooo`3oool0c03oool00`0000000@410820P00j0?ooo`04
0820P000000000000820P3`0oooo00<0i>CT000000000000@`38b<P00`1TI6@0<S8b0000000;0000
000309JFUP38b<P0b<S80080b<S800<0bLW90<S8b038b<P0aP38b<P0103Ti>@0000000410@00000n
0?ooo`007@3oool2000008D0oooo00@0P8200000000000000@410P0000000`010@40000000000005
00000080oooo00<0o_kn0?ooo`3oool0b03oool00`0000000@410820P00j0?ooo`040820P0000000
00000820P3`0oooo00D0hn?S000000000000b<S80<W9b@0o0<S8b0040<W9b@38b<P0b<S80<S8b0d0
000000<0I6AT0<S8b038b<P0bP38b<P0103Shn<0000000000000000n0?ooo`007@3oool2000008H0
oooo00<0`<300000000000002P0000000`10@400`<300?ooo`3:0?ooo`80P82000<0`<300?ooo`3o
ool0>03oool01020P800000000000020P80l0?ooo`030>CTi00000000@4104@0b<S800<0bLW90<S8
b00b<S8030000000101TI6@0UYJF0<S8b039bLW80<S8b0040>CTi020P800P8200820P3h0oooo000M
0?ooo`800000R03oool01010@4000000000000010@49000000030820P030`<00oooo0?l0oooo1P3o
ool01020P8000@4100410@10@40l0820P00307=cL`000000000004H0I6AT0P1UIFD00`0000000@41
00000004000000800@41100000000`1TI6@0IFEU06ATI03706ATI00307=cL`30`<00oooo03l0oooo
000M0?ooo`800000RP3oool00`10@4000@4100410@0:000000030820P03oool0oooo0?l0oooo103o
ool01@20P8000@410000000000000@4108P0000000<00@410000000000003@0000000`010@400000
00000033000000030820P03oool0oooo03h0oooo000M0?ooo`800000R`3oool00`20P80000000000
000:000000030820P03oool0oooo0?l0oooo0`3oool00`20P80000000000002=0000000300410@00
000000000=00000000<0P8200?ooo`3oool0?P3oool001d0oooo0P00002<0?ooo`030820P0000000
000000H0000000H00@41000000000000000000410@30`<3o0?ooo`<0oooo00@0P820000000000000
P820R`3oool00`20P80000000000000:000000030410@03oool0oooo0?l0oooo1P3oool001d0oooo
0P00002>0?ooo`030820P0000000000000T0000000<00@410410@03oool0o`3oool10?ooo`040820
P000000000000820P8X0oooo00@0o_kn0?ooo`30`<00@410300000000`20P800oooo0?ooo`3o0?oo
o`@0oooo000M0?ooo`800000S`3oool01030`<00@410000000010@4:000000030820P03oool0oooo
0?d0oooo00@0P820000000000000P820SP3oool00`20P800@410000000030000000300410@000000
000000D0000000<0`<300?ooo`3oool0o`3oool20?ooo`007@3oool200000940oooo3P00003n0?oo
o`040820P000000000000820P900oooo3@0000000`20P800oooo0?ooo`3o0?ooo`40oooo000M0?oo
o`800000TP3oool01@30`<00@4100000000000000@4100T0000000<0`<300?ooo`3oool0nP3oool0
1020P800000000000020P82A0?ooo`030820P0000000000000X0000000<0@4100?ooo`3oool0o`3o
ool001d0oooo0P00002D0?ooo`030820P0010@40000000/0000000<0P8200?ooo`3oool0n03oool0
1020P800000000000020P82C0?ooo`030820P0000000000000X0000000<0@4100<30`03oool0o@3o
ool001d0oooo0P00002F0?ooo`030820P0000000000000H0000000<00@41000000010@400P000000
0`30`<00oooo0?ooo`3f0?ooo`040820P000000000000820P9@0oooo00<0`<300410@00000001000
00000`010@400000000000030000000300410@10@400oooo0?`0oooo000M0?ooo`800000U`3oool0
0`20P800000000000004000000800@411@0000000`20P800oooo0?ooo`3e0?ooo`040820P0000000
00000820P9H0oooo3P0000000`20P800oooo0?ooo`2k0?ooo`030?knoP3oool0oooo03/0oooo000M
0?ooo`800000V03oool00`30`<00P8200000000<000000030820P03oool0oooo0;H0oooo0P20P800
0`30`<00oooo0?ooo`0h0?ooo`040820P000000000000820P9L0oooo00<0`<300410@00000000P00
00000`010@40000000000006000000030451@@2o_kl0oooo0;L0oooo0`20P80n0?ooo`007@3oool2
000009/0oooo00@0P8200000000000000@410P0000001P010@4000000000000000000@4100000080
0@4100<0`<300?ooo`3oool0]03oool2000000030820P03oool0oooo03P0oooo00@0P82000000000
0000P820V@3oool00`30`<00P820000000090000000400410@00000000000<30`;H0oooo00<00@41
000000000000?P3oool001d0oooo0P00002M0?ooo`030820P010@400000000D0000000<00@410000
000000000P0000000`010@40P8200?ooo`2c0?ooo`80000000<0P8200?ooo`3oool0>03oool01020
P800000000000020P82L0?ooo`040820P0000000000000410@T0000000<0@4100<30`03oool0/`3o
ool3000003h0oooo000M0?ooo`800000G@3oool00`30`<00oooo0?ooo`0D0?ooo`030820P03oool0
oooo00L0oooo00<0`<300?ooo`3oool05@3oool00`30`<00oooo0?ooo`060?ooo`030<30`0000000
000000D0000000<00@410000000000000`0000000`20P800oooo0?ooo`2`0?ooo`80000000<0P820
0?ooo`3oool0>03oool01020P800000000000020P82N0?ooo`030410@0000000000000/0000000<0
P8200?ooo`3oool0/03oool3000003h0oooo000M0?ooo`800000G03oool00`000000oooo0?ooo`0A
0?ooo`050?knoP3oool0oooo0000003no_h02@3oool20820P1L0oooo00<000000?ooo`3oool01`3o
ool>000000030820P03oool0oooo0:h0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820P000
000000000820P:00oooo3P00002a0?ooo`<00000?P3oool001d0oooo0P00001J0?ooo`030<30`000
0000`<3001D0oooo00<0@D510<30`03oool02P3oool00`10@400P8200<30`0050?ooo`030<30`020
P800oooo00d0oooo00<0`<300410@020P800203oool00`20P80000000000000;000000030410@03o
ool0oooo0:d0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P:00oooo
00<0`<300410@0000000300000000`20P800`<300?ooo`2]0?ooo`0300410@000000000003h0oooo
000M0?ooo`800000F@3oool00`30`<00@4100?ooo`0E0?ooo`030410@030`<00oooo00`0oooo00<0
P82000000030`<001P3oool00`20P800@4100?ooo`0<0?ooo`030<30`0000000@41000P0oooo00<0
`<300410@0000000300000000`20P800`<300?ooo`2[0?ooo`03000000010@40P82003X0oooo00@0
P820000000000000P820XP3oool00`20P80000000000000<000000030410@030`<00oooo0:/0oooo
0P0000000`010@40oooo0?ooo`0l0?ooo`007@3oool2000005P0oooo00<0`<3000410@30`<00503o
ool00`30`<0000000410@00?0?ooo`030820P010@400oooo00H0oooo00<0@4100<30`03oool03@3o
ool00`010@40`<300?ooo`080?ooo`030<30`0000000000000P0000000H00@410000000000000000
0410@030`<3W0?ooo`040820P000000000000820P:@0oooo00<0`<300000000000003@0000000`20
P800oooo0?ooo`3Y0?ooo`007@3oool2000004h0oooo00<0o_kn0?ooo`3oool01`3oool00`000000
P8200?ooo`0D0?ooo`8000002`3oool00`3no_h0oooo0?ooo`030?ooo`0300000020P800oooo00D0
oooo0P20P80>0?ooo`030820P0000000oooo00X0oooo00@0P8200000000000000@41300000070?oo
o`030?knoP3oool0oooo0=`0oooo00@0P820000000000000P820YP3oool@00000>X0oooo000M0?oo
o`800000E`3oool00`20P80000000820P00:0?ooo`030<30`03oool0oooo00L0oooo00<0`<300000
00000000203oool20820P0L0oooo00<00@410410@03oool00`3oool40820P0D0oooo00<0Ogmo0820
P030`<001P3oool00`20P80000000<30`00;0?ooo`030<30`010@400000000X0000000@00@410000
00000000P820i03oool01020P800000000000020P81d0?ooo`030<30`03oool0oooo01D0oooo00<0
`<300?ooo`3oool01P3oool00`30`<00oooo0?ooo`0?0?ooo`030820P010@400000000d0000000<0
P8200<30`03oool0iP3oool001d0oooo0P00001;0?ooo`030<30`010@400000000<0000000<0P820
0<30`03oool00P3oool00`2o_kl000000000000;0?ooo`0300000020P800oooo00L0oooo00<0@410
00410@3oool01P3oool00`30`<00000000000002000000030820P03oool0oooo00<0oooo00<0P820
00000020P8000P3oool01@20P8000000000000000000`<3000@0oooo00D0@410000000010@400000
0410@0060?ooo`0300000010@400oooo00d0oooo00<0P820000000000000300000000`20P800_kno
0?ooo`3P0?ooo`040820P000000000000820P7<0oooo00<0@4100<30`03oool0503oool00`20P800
@4100?ooo`090?ooo`030820P011@D40oooo00H0oooo00<0P8200?ooo`3oool01`3oool00`30`<00
@4100000000=000000030410@030`<00oooo0>@0oooo000M0?ooo`800000C@3oool01010@4000000
00000030`<050?ooo`030410@0000000000000X0oooo0P0000000`10@400oooo0?ooo`040?ooo`04
0?knoP30`<00000000410@L0oooo00L0P820000000000000`<300?ooo`20P800`<3000@0oooo00@0
P82000410@000000`<300P3oool20820P0030<30`03oool0oooo00<0oooo0P0000001010@400oooo
0<30`020P8050?ooo`80000000<0P8200?ooo`3oool03@3oool00`20P80000000000000800000080
0@410P0000000`10@400P8200?ooo`3N0?ooo`040820P000000000000820P780oooo00<0@D510<30
`03oool0503oool00`10@400P8200?ooo`0;0?ooo`030<30`0000000`<3000H0oooo0P20P80:0?oo
o`030820P0000000000000`000000P20P83S0?ooo`007@3oool2000004d0oooo00<0P82000000000
00001P3oool3000000X0oooo0`0000070?ooo`030820P00000000@4100L0oooo00<0P82000000000
0000203oool01020P800000000000020P80:0?ooo`0300410@000000P82000P0oooo0`00000A0?oo
o`030820P0000000000000d0000000<0P8200?ooo`3oool0f`3oool01020P800000000000020P81a
0?ooo`0300000020P800oooo01@0oooo0P20P80>0?ooo`030820P0000000oooo00H0oooo0P20P80;
0?oooa000000hP3oool001d0oooo0P00001=0?ooo`030820P0000000000000H0oooo00<00@410000
0020P8002@3oool00`20P800000000410@020820P0H0oooo00<0P82000000020P8001`3oool00`20
P8000000000000090?ooo`03000000010@40P82000X0oooo0P0000000`20P800oooo0?ooo`060?oo
o`030820P0010@4000000180oooo00@0`<300410@00000000@41300000000`10@400P8200?ooo`3J
0?ooo`040820P000000000000820P700oooo00<0@41000000030`<00503oool00`30`<0000000<30
`00?0?ooo`0300000020P800oooo00D0oooo00<0_kno0410@03oool02`3oool01@20P800@4100000
000000000@4100/000000P20P8070?ooo`030?knoP3oool0oooo0=D0oooo000M0?ooo`800000C@3o
ool00`20P8000000000000050?ooo`040820P000000000000820P0T0oooo0P0000000`20P800oooo
000000060?ooo`80000000<0P8200?ooo`3oool01@3oool00`20P8000000000000090?ooo`800000
00<00@410?ooo`3oool0203oool2000000030820P03oool0oooo00H0oooo00@0P820000000000000
P820503oool00`20P8000000000000090000000600410@000000000000000020P800`<30f03oool0
1020P800000000000020P81_0?ooo`030820P0000000oooo01D0oooo00<000000820P03oool03`3o
ool00`20P80000000820P0060?ooo`030000003oool0oooo00`0oooo00<0`<300000000000003P00
00000`20P800oooo0?ooo`3K0?ooo`007@3oool2000004d0oooo00<0P8200000000000001@3oool0
1020P800000000410@20P8080?ooo`070820P0010@4000000<30`03oool0@D510820P0050?ooo`80
000000<0P8200?ooo`3oool01@3oool00`20P8000000000000090?ooo`0300410@000000000000X0
oooo0P0000000`20P800oooo0?ooo`060?ooo`040820P0010@4000000820P1H0oooo00<0P8200000
000000002P00000200410@80000000<0P8200?ooo`3oool0e03oool01020P800000000000020P81S
0?ooo`L0P82000<0`<300?ooo`3oool00P3oool00`000000@4100?ooo`090?ooo`030;no_`10@400
oooo00P0oooo0P0000000`30`<00oooo0?ooo`050?ooo`040410@00000000@410820P0D0oooo00<0
`<3000410@0000000`3oool01020P80000000410@0010@450?ooo`050<30`000000000000820P030
`<001@3oool00`10@40000000410@00:000000800@41100000000`20P800oooo0?ooo`3H0?ooo`00
7@3oool2000004d0oooo00<0P8200000000000001@3oool01020P800000000000020P8080?ooo`<0
00000P3oool00`20P80000000?ooo`040?ooo`80000000<0P8200?ooo`3oool01@3oool00`20P800
0000000000090?ooo`<000002P3oool2000000030820P03oool0oooo00H0oooo00@0P82000000000
0000P820603oool00`20P80000000000000=0000000300410@20P800oooo0=<0oooo00@0P8200000
00000000P820I03oool4000000030820P03oool0oooo00<0oooo00<0P82000410@20P8002P3oool0
0`20P80000000?ooo`070?ooo`0307moO`000000000000L0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`030?ooo`80000000<0P8200?ooo`3oool00`0000000`20P800oooo0?ooo`03
0?ooo`<0000000<00@410000003oool0103oool01020P80000000000003oool=0000000400410@00
0000000000000=T0oooo000M0?ooo`800000C@3oool00`20P8000000000000050?ooo`040820P000
00000@410820P0P0oooo0P0000040?ooo`0300000020P800oooo00<0oooo0P0000000`20P800oooo
0?ooo`050?ooo`030820P0000000000000T0oooo00<0000000410@0000002P3oool2000000030820
P03oool0oooo00H0oooo00@0P82000410@000000P8206@3oool01@30`<00@4100000000000000@41
00d0000000<0P8200?ooo`3oool0d03oool01020P800000000000020P81T0?ooo`040<30`0010@40
00000410@0H0oooo00<0@41000000020P8002P3oool2000000030820P03oool0oooo00D0oooo00<0
@41000410@010@401`3oool00`20P80000000410@0020?ooo`030820P03oool0oooo00<0oooo0P00
00001010@400oooo0?ooo`3oool20820P0H0oooo0P0000001030`<00oooo0<30`030`<040?ooo`07
0820P0010@4000000<30`03oool0P8200410@0060000000300410@0000000@4100L0000000<0P820
0?ooo`3oool0e03oool001d0oooo0P00001=0?ooo`030820P0000000000000D0oooo00@0P8200000
00000000P8201`3oool00`20P80000000820P0050?ooo`030451@@3oool0oooo0080oooo0P000000
0`20P800oooo0?ooo`050?ooo`030820P0000000000000T0oooo0`00000:0?ooo`800@4100<0P820
0?ooo`3oool01P3oool01020P800000000000020P80L0?ooo`030820P0000000000000h0000000<0
@4100820P03oool0cP3oool01020P800000000000020P81U0?ooo`80000000<0P8200?ooo`3oool0
103oool2000000030<30`03oool0oooo00L0oooo00D0`<3000000010@40000000<30`0060?ooo`80
000000<0@4100?ooo`3oool01@3oool00`20P80000000820P0080?ooo`030820P0000000000000/0
oooo0P0000080?ooo`040;no_`00000000000820P0<0oooo00D0`<300410@0000000000000410@0=
00000080P820d`3oool001d0oooo0P00001=0?ooo`030820P0000000000000D0oooo00@0`<300000
00010@40P8201`3oool2000000H0oooo00<0@4100<30`03oool00P3oool00`10@40000000820P007
0?ooo`030820P0000000000000T0oooo0P0000000`10@400oooo0?ooo`080?ooo`80000000<0P820
0?ooo`3oool01P3oool01020P8000@4100000030`<0N0?ooo`80P82000<00@410000000000002P00
00001@010@40000000000020P800`<3008l0oooo00<0000000410@20P800>P3oool01020P8000000
00000020P81U0?ooo`80000000<0P8200?ooo`3oool00`3oool00`20P80000000000000:0?ooo`05
0410@0010@40`<300820P010@4001@3oool01030`<00000000410@20P8070?ooo`030820P0000000
P82000T0oooo0P0000000`30`<00oooo0?ooo`080?ooo`8000002@3oool2000000030410@03oool0
oooo00<0oooo00D0`<300820P010@400000000410@020000000300410@000000000000T0000000<0
P8200?ooo`3oool0SP3oool3000003h0oooo000M0?ooo`800000C@3oool00`20P800000000000006
0?ooo`80000000<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo00@0oooo0P20P803
0?ooo`0307moO`000000Ogmo00L0oooo00<0P8200000000000002@3oool2000000030820P03oool0
oooo00P0oooo00<00@4100000020P800203oool00`20P80000000000000R0?oooa80000000<0oooo
0?knoP3oool0R`3oool00`0000000@410820P00j0?ooo`040820P000000000000820P6D0oooo0P00
00000`20P800oooo0?ooo`030?ooo`<000002P3oool01@0000000@410?ooo`3oool0000000D0oooo
00@0P820000000000000P8201`3oool00`20P80000000820P0090?ooo`80000000<0P8200?ooo`3o
ool0203oool2000000T0oooo0`0000080?ooo`030820P0010@40000000d0000000<00@4100000000
0000SP3oool3000003h0oooo000M0?ooo`800000B`3oool00`30`<00P8200410@002000000<0P820
0`3oool20000000300410@3oool0oooo00<0oooo00@0P820000000010@40@4101P3oool00`30`<00
00000<30`0020?ooo`030820P00000000@4100D0oooo00<0`<300820P010@4000P0000030820P0D0
oooo00@0P820000000000000P820203oool20820P080000000<0@4100820P020P8001P3oool00`01
0@4000000000000S0?ooo`030820P0000000000000`000000P010@400`000000P8200820P02;0?oo
o`80000000<0P8200?ooo`3oool0>03oool01020P800000000000020P81U0?ooo`80000000<0P820
0?ooo`3oool00`3oool3000000T0oooo0P0000001@10@400oooo0?ooo`10@400`<3000@0oooo00@0
P820000000010@40P8201`3oool00`20P80000000820P0090?ooo`80000000<0P8200?ooo`3oool0
203oool00`0000000@410?ooo`080?ooo`<000002@3oool00`30`<00P82000000007000000030041
0@0000000@4100<0000000D00@41000000000000P8200<30`02;0?ooo`<00000?P3oool001d0oooo
0P00001;0?ooo`030<30`020P800@410008000000`20P8030?ooo`030820P0000000000000@0oooo
00<0`<300820P020P8000`20P8040?ooo`@0P8200`3oool2000000H0oooo00@0P820000000000000
00000`20P8050?ooo`030820P0010@40000000T0oooo00D0`<300451@@00000000000451@@020820
P0H0oooo00<0000000410@3oool09@3oool00`20P800@4100000000@000000030410@020P800`<30
08L0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040820P000000000000820P6D0oooo0P000000
0`20P800oooo0?ooo`030?ooo`<00000203oool01020P800000000000030`<020?ooo`030<30`010
@400oooo00<0oooo00@0P820000000000000P8201`3oool00`20P80000000820P0090?ooo`800000
00<0P8200?ooo`3oool0203oool2000000T0oooo0`00000<0?ooo`040820P0000000000000410@l0
000000<0@4100820P03oool0Q`3oool3000003h0oooo000M0?ooo`800000C@3oool00`1oOgl00000
00410@070?ooo`80000000<0`<300?ooo`3oool04P3oool00`20P80000000820P0060?ooo`030<30
`0000000000000P0oooo00<0@41000410@3oool02`3oool00`10@4000@410820P0070?ooo`030<30
`0000000P82002T0oooo00<0P8200000000000000`0000000`010@4000000000000;00000080P820
Q03oool2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820I@3oool200000003
0820P03oool0oooo00<0oooo0`0000080?ooo`030410@0000000@41000@0oooo00<0@4100?ooo`3o
ool00P3oool01020P800000000410@20P8070?ooo`030820P0000000P82000T0oooo0P0000000`20
P800oooo0?ooo`080?ooo`8000002@3oool00`010@4000000000000?0?ooo`070820P00000000000
000000010@40000000410@070000000300410@000000000000<0000000<0P8200<30`03oool0P`3o
ool3000003h0oooo000M0?ooo`800000C@3oool00`20P8000@41000000080?ooo`0300000020P800
oooo01@0oooo0P0000070?ooo`800000203oool00`000000P8200?ooo`0;0?ooo`030820P0000000
P82000L0oooo00<0P8200000003oool09P3oool00`3no_h0oooo0?ooo`030?ooo`<0000000<00@41
0000000000003@0000000`010@40P8200?ooo`210?ooo`80000000<0P8200?ooo`3oool0>03oool0
1020P800000000000020P81U0?ooo`80000000<0P8200?ooo`3oool00`3oool3000000P0oooo00<0
0@4100000020P800103oool00`1oOgl0P8200?ooo`020?ooo`040820P000000000000820P0L0oooo
00<0P82000000020P8002@3oool2000000030820P03oool0oooo00P0oooo0P0000090?ooo`<00000
4@3oool00`20P80000000000000<0000000300410@000000000000<00000P`3oool3000003h0oooo
000M0?ooo`800000C@3oool00`20P8000@41000000080?ooo`80@4105@3oool00`10@40000000<30
`0070?ooo`030000003oool0oooo00D0oooo00<0`<3000000030`<003@3oool00`000000P8200?oo
o`060?ooo`80@410;P3oool00`30`<00P8200000000B00000080P820O`3oool2000000030820P03o
ool0oooo03P0oooo00@0P820000000000000P820I@3oool2000000030820P03oool0oooo00<0oooo
00<0P8200000000000001`3oool00`20P800000000410@050?ooo`030<30`010@400oooo0080oooo
00@0`<30000000000000P8201`3oool00`20P80000000820P0090?ooo`80000000<0`<300?ooo`3o
ool0203oool2000000T0oooo0P0000000`10@400oooo0?ooo`0A0?ooo`030<30`010@40000000100
000000@00@4100000020P800`<30O`3oool3000003h0oooo000M0?ooo`800000CP3oool2000000@0
oooo00<0`<3000000030`<000P3oool00`000000`<300?ooo`0D0?ooo`0300000010@400oooo00H0
oooo00<0`<300?ooo`3oool01@3oool00`000000`<300?ooo`0>0?ooo`030<30`03oool0oooo00@0
oooo00<00@410410@03oool0<@3oool00`30`<00@410000000090000000300410@000000000000@0
000000@00@4100000010@400P820O03oool20820P0030<30`03oool0oooo03P0oooo00@0P8200000
00000000P820I@3oool2000000030820P03oool0oooo00@0oooo0P0000000`30`<00oooo0?ooo`04
0?ooo`8000001`3oool00`10@400`<300?ooo`020?ooo`0300410@000000@41000L0oooo00<0P820
00000020P800203oool00`20P80000000000000;0?ooo`800000203oool01030`<000@4100000020
P80F0?ooo`030820P010@400000000H000000P010@4:00000080P820O03oool30820P3h0oooo000M
0?ooo`800000CP3oool00`20P80000000<30`0020?ooo`040820P00000000@410820P080oooo00<0
`<3000000020P8005@3oool20410@0`0oooo00<0`<3000410@20P8005P3oool00`10@400P8200<30
`00e0?ooo`040<30`020P800000000410@D0000000<00@410000000000002P0000000`10@400P820
0?ooo`2d0?ooo`040820P000000000000820P6<0oooo00<00@41000000000000100000001`010@40
oooo0?ooo`3oool0@41000000020P800103oool00`20P800000000000002000000030820P03oool0
oooo0080oooo00@0P820000000000000Ogmo0P3oool00`10@4000000000000050?ooo`030451@@00
0000000000@0000000<0P8200?ooo`3oool00`3oool200410@030410@03oool0oooo00H0oooo00@0
`<3000410@0000000@41100000050?ooo`040820P0010@4000000<30`1T0oooo0P20P8000`10@400
0000000000020000000300410@000000000000/0000000<00@410820P020P800^@3oool001d0oooo
0P00001?0?ooo`80000000D0oooo0820P0000000000000410@050?ooo`0300000020P800oooo01@0
oooo0P20P8000`3no_h0oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo0P20P80k0?ooo`80
000000<00@410000000000004@00002c0?ooo`040820P000000000000820P6D0oooo0P0000000`20
P800oooo0?ooo`040?ooo`030820P0000000P82001@0oooo00<0P8200000000000001`3oool20000
00030820P03oool0oooo00H0oooo0P010@400`20P800oooo0?ooo`080?ooo`<00000203oool00`1o
Ogl000000000000M0?ooo`030820P0010@40000000/0000000<00@410000000000001@0000000`20
P800oooo0?ooo`2e0?ooo`007@3oool200000500oooo00H0`<300410@000000000000410@030`<06
0?ooo`030820P030`<00oooo01@0oooo0P20P8090?ooo`030820P030`<00oooo01D0oooo00<0`<30
0820P03oool0?03oool01@20P800@4100000000000000@410140000000<0@4100820P030`<00[`3o
ool01020P800000000000020P81U0?ooo`80000000<0P8200?ooo`3oool01@3oool00`010@40@D51
0?ooo`0D0?ooo`80000000<0`<300?ooo`3oool0103oool00`30`<0000000820P0070?ooo`030<30
`0000000000000`0oooo00<0@4100000003oool01`3oool00`11@D4000000820P00O0?ooo`80P820
0`0000000`010@400000000000070000000400410@000000000000410@<0000000<0@4100820P03o
ool0/`3oool001d0oooo0P00003H0?ooo`030<30`020P80000000180000000@00@4100000020P800
P820[03oool01020P800000000000020P81U0?ooo`80000000<0P8200?ooo`3oool01@3oool00`20
P80000000?ooo`0E0?ooo`0300000020P800oooo00H0oooo00<0@4100820P03oool01P3oool00`20
P80000000820P00<0?ooo`030<30`0000000oooo00L0oooo0P00000S0?ooo`80P8202@0000030041
0@<0000000<00@410000000000000`0000000`20P800`<300?ooo`2_0?ooo`007@3oool200000=/0
oooo0P20P8000`010@400000000000060000000300410@000000000000X000000P20P82X0?ooo`04
0820P000000000000820P6D0oooo00<0P82000000020P800103oool01P30`<00P8200?ooo`3oool0
@410000001D0oooo00<0`<3000410@3oool01P3oool00`30`<00P8200?ooo`050?ooo`030<30`000
0000P82000h0oooo00<0@4100?ooo`3oool01@3oool20410@2L0oooo00@0P8200410@0010@400@41
1000000200410@h0000000<0P8200<30`03oool0Z`3oool001d0oooo0P00003N0?ooo`0307moO`00
0000000001D0000000<0P8200?ooo`3oool0Y03oool01020P800000000000020P81V0?ooo`030000
0020P800oooo00<0oooo0P0000001@20P800oooo0820P0000000P82001D0oooo00<000000820P03o
ool03@3oool20820P1L0oooo00<000000?ooo`3oool0:@3oool00`010@4000000000000400000003
00410@000000000000h00000Z`3oool001d0oooo0P00003P0?ooo`050;no_`20P800000000000001
0@403`00000010010@4000000000000000020820P:<0oooo00@0P820000000000000P820IP3oool0
0`20P800@4100?ooo`020?ooo`040410@000000000000820P080oooo00<0P82000000030`<00503o
ool00`30`<0000000820P00<0?ooo`030<30`010@400`<3001H0oooo00<0@4100820P03oool0;03o
ool01@20P800@4100000000000000@4100<0000000<00@410000000000003@0000020820P:L0oooo
000M0?ooo`800000i03oool00`1oOgl0P82000410@0=0000000400410@000000000000410@800000
00<00@410000000000000P20P82N0?ooo`040820P000000000000820P6L0oooo00@0P8200451@@20
P800@4100P0000000`20P800oooo0?ooo`030?ooo`030410@030`<00oooo01@0oooo00<0P8200410
@03oool02@3oool00`20P800@4100?ooo`0E0?ooo`030<30`0000000`<300380oooo00<0P8200410
@0000000300000000`010@4000000000000700000080P820XP3oool001d0oooo0P00003W0?ooo`03
0<30`020P800@41000/000000P010@470000000400410@000000000000000080P820V@3oool01020
P800000000000020P81Y0?ooo`<0P820203oool00`30`<00oooo0?ooo`0E0?ooo`030<30`03oool0
oooo00H0oooo00<0`<300?ooo`3oool05P3oool00`30`<00oooo0?ooo`0e0?ooo`030<30`020P800
000000d0000000<00@41000000000000200000020820P0030<30`03oool0oooo09X0oooo000M0?oo
o`800000j`3oool40000000300410@000000000001@0000000<0Ogmo0?ooo`3oool0U03oool01020
P800000000000020P83Z0?ooo`04000000010@40000000410AL00000V`3oool001d0oooo0P00003]
0?ooo`030820P010@400000000D0000000<00@410000000000004@0000020820P0030<30`03oool0
oooo08l0oooo00@0P820000000000000P820j`3oool01030`<00P820000000010@4H000000030041
0@20P800P82009H0oooo000M0?ooo`800000l@3oool00`20P800@410000000030000000300410@00
0000000001@0000000<0@4100820P030`<00C`3oool20820P0030<30`03oool0oooo03P0oooo00@0
P820000000000000P820k`3oool00`30`<00P8200000000B0000000300410@000000000000H00000
0P20P8000`30`<00oooo0?ooo`1=0?ooo`<0P820?P3oool001d0oooo0P00003d0?ooo`80P8207@00
00001010@400P8200820P020P8190?ooo`03000000010@40P82003X0oooo00@0P820000000000000
P820l`3oool00`20P800@4100000000E0000000300410@000000000000@000000`20P8000`30`<00
oooo0?ooo`170?ooo`03000000010@40000003h0oooo000M0?ooo`800000n03oool30820P1l00000
0P20P8000`30`<00oooo0?ooo`110?ooo`80000000<0P8200?ooo`3oool0>03oool01020P8000000
00000020P83g0?ooo`030<30`020P800@41000<000000`010@4H000000030410@020P800P82004@0
oooo0`00000n0?ooo`007@3oool200000?d0oooo00<0P8200000000000007`0000000`20P800oooo
0?ooo`0n0?ooo`80000000<0P8200?ooo`3oool0>03oool01020P800000000000020P83l0?ooo`03
0820P0000000000001d0000000<00@410000003oool0@03oool3000003h0oooo000M0?ooo`800000
o`3oool10?ooo`80P82000<0@4100000000000007@0000030820P3/0oooo0P0000000`20P800oooo
0?ooo`0h0?ooo`040820P000000000000820P?l0oooo0P20P8030000000300410@000000000001X0
00000`20P80k0?ooo`<00000?P3oool001d0oooo0P00003o0?ooo`D0oooo00@0`<300820P020P800
@4104@0000000`010@4000000000000200410@X000001020P80d0?ooo`80000000<0P8200?ooo`3o
ool0>03oool01020P800000000000020P83o0?ooo`D0oooo0P20P80E0000000300410@0000000000
00P0000000D0@4100820P020P800P8200<30`00d0?ooo`<00000?P3oool001d0oooo0P00003o0?oo
o`/0oooo0P20P8001010@400000000000000000200410@X000000P010@400`0000000@410000000>
000000050410@020P800P8200820P030`<00;03oool2000000030820P03oool0oooo03P0oooo00@0
P820000000000000P820o`3oool:0?ooo`80P82000<0@4100000000000004`00000200410@/00000
1020P80]0?ooo`<00000?P3oool001d0oooo0P00003o0?oooa00oooo:P00001T0?ooo`040820P000
000000000820P?l0oooo3P3oool00`20P80000000000000W000000030820P03oool0oooo06H0oooo
000M0?ooo`800000o`3ooolB0?ooo`80P82000<0@410000000010@401`0000000`010@4000000000
000A0000000300410@000000000000X000001@20P81J0?ooo`040820P000000000000820P?l0oooo
4@3oool30820P2X000001@20P81N0?ooo`007@3oool200000?l0oooo5`3oool01030`<00P8200410
@000000200410@@0000000<00@410000000000004@0000000`010@40000000000008000000030041
0@000000000000H000002@20P8000`30`<00oooo0?ooo`190?ooo`040820P000000000000820P?l0
oooo5P3oool30820P1T0000000<00@410000000000001000000200410@P0000000<00@4100000000
00000P0000090820P500oooo000M0?ooo`800000o`3ooolL0?ooo`@0P8205000000200410Ad00000
00@00@41000000000000@4102`20P8000`30`<00oooo0?ooo`0i0?ooo`040820P000000000000820
P?l0oooo6`3oool40820P1H000000P010@4=0000000300410@000000000000P0000000<00@410000
000000000`0000000`10@400P8200820P0090820P400oooo000M0?ooo`800000o`3ooolT0?ooo`@0
000000<00@410000000000003@0000000`010@4000000000000W000000030820P03oool0oooo03T0
oooo00@0P820000000000000P820o`3ooolR0?ooo`040820P0000000000000410AD000000P010@4T
00000400oooo000M0?ooo`800000o`3ooolX0?ooo`@0P8200P00000010010@40000000410@010@46
0000000300410@000000000000<0000000<00@410000000000008@0000000`20P800oooo0?ooo`0i
0?ooo`040820P000000000000820P?l0oooo9P3oool01`30`<00P8200820P020P800@41000000001
0@40=00000100?ooo`007@3oool2000000030?ooo`30`<00P82000H0P8202`3oool00`30`<00P820
0820P0040820P0030<30`03oool0oooo00T0oooo00<0`<300820P020P8001@20P80;0?ooo`L0P820
00<0`<300?ooo`3oool02@3oool00`30`<00P8200820P0040820P0030<30`03oool0oooo00T0oooo
00<0`<300820P020P8001@20P80;0?ooo`L0P82000<0`<300?ooo`3oool02@3oool00`30`<00P820
0820P0040820P0`0oooo1`20P8000`30`<00oooo0?ooo`090?ooo`L0P82000<0`<300?ooo`3oool0
2@3oool00`30`<00P8200820P0040820P0`0oooo1`20P8000`30`<00oooo0?ooo`090?ooo`L0P820
303oool70820P0`0oooo1`20P8000`30`<00oooo0?ooo`080?ooo`030<30`020P800P82000D0P820
2@3oool30820P0/0000000<00@410000000000008P0000000`20P800oooo0?ooo`0i0?ooo`050820
P000000000000820P030`<001P20P8000`30`<00oooo0?ooo`090?ooo`030<30`020P800P82000D0
P8202`3oool70820P0030<30`03oool0oooo00T0oooo00<0`<300820P020P8001020P8000`30`<00
oooo0?ooo`090?ooo`L0P82000<0`<300?ooo`3oool02@3oool70820P0030<30`03oool0oooo00T0
oooo00<0`<300820P020P8001020P80<0?ooo`L0P82000<0`<300?ooo`3oool02@3oool70820P0`0
oooo1`20P80<0?ooo`L0P82000<0`<300?ooo`3oool02@3oool70820P0`0oooo1`20P80<0?ooo`L0
P8202`3oool00`30`<00P8200820P0050820P0`0oooo1`20P8090?ooo`<0P8202@00000200410@80
000000<00@41000000000000800000100?ooo`007@3oool2000000030?ooo`20P800000000H00000
2`3oool00`20P800000000000004000000030820P03oool0oooo00T0oooo00<0P820000000000000
1@00000;0?ooo`L0000000<0P8200?ooo`3oool02@3oool00`20P800000000000004000000030820
P03oool0oooo00T0oooo00<0P8200000000000001@00000;0?ooo`L0000000<0P8200?ooo`3oool0
2@3oool00`20P800000000000004000000`0oooo1`0000000`20P800oooo0?ooo`090?ooo`L00000
00<0P8200?ooo`3oool02@3oool00`20P800000000000004000000`0oooo1`0000000`20P800oooo
0?ooo`090?ooo`L00000303oool7000000`0oooo1`0000000`20P800oooo0?ooo`080?ooo`030820
P0000000000000D0000000<0oooo0?knoP3oool02@3oool40000000700410@00000000000820P010
@400000000410@0U000000030820P03oool0oooo03T0oooo00<0P8200000000000000P20P8060000
00030820P03oool0oooo00T0oooo00<0P8200000000000001@00000;0?ooo`L0000000<0P8200?oo
o`3oool02@3oool00`20P800000000000004000000030820P03oool0oooo00T0oooo1`0000000`20
P800oooo0?ooo`090?ooo`L0000000<0P8200?ooo`3oool02@3oool00`20P8000000000000040000
00`0oooo1`0000000`20P800oooo0?ooo`090?ooo`L00000303oool7000000`0oooo1`0000000`20
P800oooo0?ooo`090?ooo`L00000303oool7000000`0oooo1`00000;0?ooo`030820P00000000000
00D00000303oool7000000`0oooo1`0000000`20P80000000000000V00000400oooo000M0?ooo`80
000000<0oooo0820P00000001P00000;0?ooo`030820P0000000000000@0000000<0P8200?ooo`3o
ool02@3oool00`20P800000000000005000000/0oooo1`0000000`20P800oooo0?ooo`090?ooo`03
0820P0000000000000@0000000<0P8200?ooo`3oool02@3oool00`20P800000000000005000000/0
oooo1`0000000`20P800oooo0?ooo`090?ooo`030820P0000000000000@00000303oool700000003
0820P03oool0oooo00T0oooo1`0000000`20P800oooo0?ooo`090?ooo`030820P0000000000000@0
0000303oool7000000030820P03oool0oooo00T0oooo1`00000<0?ooo`L00000303oool700000003
0820P03oool0oooo00P0oooo00<0P8200000000000001@00000<0?ooo`L000001@3ooolT00000003
0820P03oool0oooo03T0oooo00<0P8200000000000000P20P806000000030820P03oool0oooo00T0
oooo00<0P8200000000000001@00000;0?ooo`L0000000<0P8200?ooo`3oool02@3oool00`20P800
000000000004000000030820P03oool0oooo00T0oooo1`0000000`20P800oooo0?ooo`090?ooo`L0
000000<0P8200?ooo`3oool02@3oool00`20P800000000000004000000`0oooo1`0000000`20P800
oooo0?ooo`090?ooo`L00000303oool7000000`0oooo1`0000000`20P800oooo0?ooo`090?ooo`L0
0000303oool7000000`0oooo1`00000;0?ooo`030820P0000000000000D00000303oool7000000`0
oooo1`0000040?ooo`030820P0000000000002800000@03oool001d0oooo0P00003o0?oood<0oooo
1@20P8000`010@400000000000080000000300410@000000000000P0000000D00@41000000000000
00000820P00k0?ooo`040820P000000000000820P?l0oooo@P3oool50820P0P0000000<00@410000
000000003`0000100?ooo`007@3oool200000?l0ooooDP3oool80820P0030410@0000000000000D0
000000<0P8200?ooo`3oool0>@3oool01020P800000000000020P83o0?oooe00oooo00<0`<300820
P020P8001P20P8000`10@4000@410000000500000400oooo000M0?ooo`800000o`3ooonN0?ooo`04
0820P000000000000820P?l0ooooX@3oool001d0oooo0P00003o0?oooih0oooo00@0P82000000000
0000P820o`3ooonQ0?ooo`007@3oool200000?l0ooooWP3oool01020P800000000000020P83o0?oo
oj40oooo000M0?ooo`800000o`3ooonN0?ooo`040820P000000000000820P?l0ooooX@3oool001d0
oooo0P00003o0?oooih0oooo00@0P820000000000000P820o`3ooonQ0?ooo`007@3oool200000?l0
ooooWP3oool01020P800000000000020P83o0?oooj40oooo000M0?ooo`800000o`3ooonN0?ooo`04
0820P000000000000820P?l0ooooX@3oool001d0oooo0P00003o0?oooih0oooo00@0P82000000000
0000P820o`3ooonQ0?ooo`007@3oool200000?l0ooooWP3oool01020P800000000000020P83o0?oo
oj40oooo000M0?ooo`800000o`3ooonN0?ooo`040820P000000000000820P?l0ooooX@3oool001d0
oooo0P00003o0?oooih0oooo00@0P820000000000000P820o`3ooonQ0?ooo`00603oool00`30`<00
P8200820P0020820P08000001@20P8000`30`<00oooo0?ooo`3o0?oooi80oooo1020P8001010@400
000000000010@4040820P?l0ooooW@3oool001D0oooo00<0P8200410@00000003P0000000`20P800
oooo0?ooo`3o0?oooh`0oooo00<0`<300820P010@4003`0000000`20P800oooo0?ooo`3o0?oooiP0
oooo000E0?ooo`@0000000<00@410000000000002P0000000`010@4000000?ooo`3o0?oooh`0oooo
00<0P8200000000000002`0000000`010@40000000000002000000030820P03oool0oooo0?l0oooo
U`3oool001D0oooo00<0P8200000000000003`00003o0?ooohl0oooo3`00000200410@030000003o
ool0oooo0?l0ooooV03oool001H0oooo3P00000200410@030410@03oool0oooo0?l0ooooSP3oool=
000000<00@4100<0@4100?ooo`3oool0o`3ooonH0?ooo`005P3oool00`10@400000000410@090000
00800@4100<0000000410@20P800o`3ooon@0?ooo`030410@0000000000000d0000000<0P8200?oo
o`3oool0o`3ooonH0?ooo`005P3oool00`20P80000000000000=00000?l0ooooT@3oool00`20P800
00000000000=00000?l0ooooV`3oool001H0oooo00<0P8200000000000002`0000000`010@400000
0?ooo`3o0?oooi00oooo00<0P8200000000000003@00003o0?oooi/0oooo000G0?ooo`0300000001
0@40000000/0000000<0P8200?ooo`3oool0o`3ooon@0?ooo`h00000o`3ooonL0?ooo`005`3oool0
0`20P8000000000000090000000300410@000000`<300:40oooo00<0`<300820P03oool0k@3oool0
1@10@40000000000000000000@4100D0000000@00@41000000000000@410_`3oool20820P=X0oooo
000H0?ooo`030410@0010@40000000X00000X`3oool00`30`<00P8200820P03/0?ooo`050<30`000
00000000000000010@40200000000`20P800oooo0?ooo`2n0?ooo`030<30`020P800`<300=P0oooo
000H0?ooo`030820P0000000000000T0000000<0P8200?ooo`3oool0X`3oool20820P>`0oooo3000
00330?ooo`030000003oool0oooo0=H0oooo000I0?ooo`0300410@000000000000P0000000<0P820
0?ooo`3oool0X`3oool00`30`<0000000<30`03[0?ooo`040820P0000000000000410@P00000``3o
ool00`10@40000000<30`03F0?ooo`006@3oool00`10@40000000000000800000:L0oooo00<0P820
0410@03oool0jP3oool00`30`<000000000000050000000400410@00000000000820P<@0oooo00<0
00000410@03oool0e@3oool001T0oooo00<0P8200000000000001`0000000`20P800oooo0?ooo`2V
0?ooo`80000000<0`<300?ooo`3oool0j03oool00`20P800000000000007000000030<30`03oool0
oooo0<<0oooo00<000000410@03oool0e03oool001T0oooo00<0P820000000000000100000000`01
0@4000000000002Y0?ooo`030820P0000000P8200>X0oooo00<0o_kn0000000000001`0000360?oo
o`030820P0000000oooo0=@0oooo000J0?ooo`P0000000<0@4100?ooo`3oool0U@3oool01P30`<00
@410000000000000@4100<30`080oooo00@0@41000000010@400P8201P3oool00`20P80000000041
0@3[0?ooo`030410@0000000000000D0000000<0@D510?ooo`3oool0/P3oool20820P0@0000000<0
P8200?ooo`3oool02@3oool00`20P80000000820P03D0?ooo`006P3oool40000000500410@000000
000000000030`<00U`3oool3000000050410@020P800@41000000030`<000P0000000`10@400P820
0410@0060?ooo`80000000<0P8200?ooo`3oool0j03oool00`20P800000000000005000000030<30
`03oool0oooo0;00oooo00H0`<3000000000000000000451@@30`<020?ooo`030410@0000000`<30
00X0oooo0P00003D0?ooo`006P3oool02020P80000000000000000000@41000000010@400000U`3o
ool01020P80000000000000000040?ooo`060410@000000000000820P03oool0`<301P3oool20000
00030410@03oool0oooo0>T0oooo1P0000000`010@40oooo0?ooo`2a0?ooo`040820P00000000000
0410@0D0oooo00<0@41000410@20P8002@3oool00`010@40000007moO`3C0?ooo`006`3oool60000
00030820P03oool0oooo09D0oooo00<0P8200000000000001P3oool2000000030820P03oool0oooo
00H0oooo0`00003[0?ooo`H00000]03oool01020P800000000000020P8060?ooo`80000000<0P820
0?ooo`3oool01P3oool00`010@4000000000003C0?ooo`006`3oool6000000030820P03oool0oooo
09D0oooo00<0P8200000000000001P3oool2000000030820P03oool0oooo00L0oooo0P00003[0?oo
o`030410@0000000000000<00000]03oool01020P800000000000020P8060?ooo`03000000010@40
@41000P0oooo00<0P82000410@000000d`3oool001`0oooo00<00@410000000000000P00002I0?oo
o`0300410@000000P82000D0oooo0P0000000`20P800oooo0?ooo`070?ooo`80000000<0P8200?oo
o`3oool0j03oool00`20P800000000000002000000030820P03oool0oooo0;80oooo00@0P8200000
00000000P8201P3oool00`20P8000000000000080?ooo`040820P000000000000820P=80oooo000L
0?ooo`050410@0000000000000000010@400V@3oool01030`<00000000000010@4040?ooo`800000
00<0P8200?ooo`3oool01`3oool2000000030820P03oool0oooo0>T0oooo100000000`30`<00oooo
0?ooo`2b0?ooo`040820P000000000000820P0H0oooo00@0P820000000000000P8201`3oool01020
P8000@4100000020P83B0?ooo`00703oool01@20P8000000000000000000P82009/0oooo0P000000
1020P800oooo0?ooo`3oool2000000030820P03oool0oooo00L0oooo0P0000000`20P800oooo0?oo
o`3Y0?ooo`040820P0000000000000000;D0oooo00@0P820000000000000P8201P3oool01020P800
000000410@20P8070?ooo`040820P000000000000820P=80oooo000L0?ooo`050<30`0010@400@41
00000030`<00W03oool01@20P800@4100410@020P800_kno0080000000<0P8200?ooo`3oool01`3o
ool2000000030820P03oool0oooo0>T0oooo00@0`<30000000000000@410]@3oool01020P8000000
00000020P8060?ooo`040820P000000000000820P0L0oooo00@0P820000000000000P820dP3oool0
01d0oooo00<0@D51000000000000W`3oool00`30`<00P8200410@002000000030820P03oool0oooo
00L0oooo0P0000000`20P800oooo0?ooo`3Z0?ooo`80000000<0P8200?ooo`3oool0/`3oool01020
P800000000000020P8060?ooo`040820P000000000000820P0L0oooo00@0P820000000000000P820
dP3oool001d0oooo00<0`<300000003oool0VP3oool00`30`<00P8200?ooo`050?ooo`80000000<0
P8200?ooo`3oool01`3oool2000000030820P03oool0oooo0>/0oooo00<000000?ooo`3oool0]03o
ool01020P800000000000020P8060?ooo`80000000<00@410<30`03oool01P3oool01020P8000000
00000020P83B0?ooo`007P3oool00`000000oooo0?ooo`2I0?ooo`<000001@3oool2000000030820
P03oool0oooo00L0oooo0P0000000`20P800oooo0?ooo`3[0?ooo`030000003oool0oooo0;@0oooo
00@0P820000000000000P8200`3oool00`3no_h0oooo0?ooo`03000000P0oooo00@0P82000000000
0000P820dP3oool00;X0oooo00<00@410000000000001@3oool2000000030820P03oool0oooo00H0
oooo00<0P820000000010@40o`3ooonV0?ooo`040820P00000000@410410@0D0oooo00@0@D510000
00000000@D51203oool00`10@40000000000003C0?ooo`00^P3oool00`10@4000000000000040?oo
o`040820P000000000000<30`0P0oooo00<00@41000000010@40o`3ooonV0?ooo`030820P0000000
00000080@41000@0`<300?ooo`3oool0P8200`0000000`30`<00oooo0?ooo`060?ooo`0300000001
0@4000000=<0oooo002k0?ooo`030410@0010@4000000080P8200P010@400`000000`<300?ooo`08
0?ooo`80000000<0P8200?ooo`3oool0o`3ooonT0?ooo`050820P000000000000820P02o_kl01@00
00000`10@400oooo0?ooo`080?ooo`03000000010@40oooo0=<0oooo002m0?ooo`030820P0000000
0000008000002`3oool200000?l0ooooY`3oool01020P800000000000020P8020?ooo`<0000000<0
P8200?ooo`3oool02@3oool00`010@40P8200?ooo`3C0?ooo`00c03oool00`20P800000000410@3o
0?ooojL0oooo00@0P820000000000000P820403oool00`20P80000000820P03D0?ooo`00c03oool0
0`10@40000000<30`03o0?ooojL0oooo00@0P820000000000000P820403oool20410@=D0oooo003;
0?ooo`030<30`0000000P8200?l0ooooZ03oool01020P800000000000020P80?0?ooo`030820P000
0000`<300=D0oooo003;0?ooo`80P820o`3ooonY0?ooo`040820P000000000000820P0l0oooo00<0
00000820P03oool0e@3oool00<X0oooo00<0`<3000000030`<00o`3ooonY0?ooo`040820P0000000
00000820P0h0oooo00<0@D5100000030`<00eP3oool00<T0oooo00<0P82000410@30`<00o`3ooonX
0?ooo`80P82000@0@410000000000000P8203@3oool20410@=P0oooo00380?ooo`030410@020P800
oooo0?l0ooooZP3oool01@20P800@41000410@000000P82000`0oooo00<0@4100<30`03oool0f03o
ool00<L0oooo00<0P8200?ooo`3oool0o`3ooon]0?ooo`030820P0000000P82000/0oooo00<00000
0?ooo`3oool0f@3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{288, 118.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 1.11 different numerical approximations to the area under ",
  StyleBox["f\n(",
    FontSlant->"Italic"],
  "a) Euler's method ",
  ButtonBox["Eq. (1.4.6)",
    ButtonData:>"(1.4.6)",
    ButtonStyle->"Hyperlink"],
  "; (b) modified Euler's method,  Eq. ",
  ButtonBox["(1.4.10)",
    ButtonData:>"(1.4.10)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Caption",
  CellTags->{"i:125", "Fig. 1.11"}],

Cell[TextData[{
  "This approximation would be exactly right if the shaded area above the \
curve  in Fig. ",
  ButtonBox["1.11",
    ButtonData:>"Fig. 1.11",
    ButtonStyle->"Hyperlink"],
  " (b) equaled the unshaded area below the curve.  If ",
  Cell[BoxData[
      \(TraditionalForm\`f(v(t), t)\)]],
  " were a linear function of ",
  StyleBox["t",
    FontSlant->"Italic"],
  " over this range, that would be true, and there would be no error. For ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " sufficiently small, ",
  Cell[BoxData[
      \(TraditionalForm\`f(v(t), t)\)]],
  StyleBox["will",
    FontSlant->"Italic"],
  " be nearly linear in ",
  StyleBox["t",
    FontSlant->"Italic"],
  " if it is a smooth function of ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", so for small ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " the error is small. In fact, one can easily show that the error in this \
approximation to the integral is of order ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "3"], TraditionalForm]]],
  " (see the exercises at the end of this section), as opposed to the \
order-",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "2"], " "}], TraditionalForm]]],
  "error made in a single step of the Euler's method [see Eq. ",
  ButtonBox["(1.4.6)]",
    ButtonData:>"(1.4.6)",
    ButtonStyle->"Hyperlink"],
  ".  Therefore, this modification to Euler's method should improve the \
accuracy of the code to order ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "3"], TraditionalForm]]],
  "in a single step."
}], "Text"],

Cell[TextData[{
  "\tIf we now use Eq. ",
  ButtonBox["(1.4.10)",
    ButtonData:>"(1.4.10)",
    ButtonStyle->"Hyperlink"],
  " in ",
  ButtonBox["Eq. (1.4.5)",
    ButtonData:>"(1.4.5)",
    ButtonStyle->"Hyperlink"],
  ", we obtain  the following result:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(v(t\_n)\), "=", 
        RowBox[{\(v(t\_\(n - 1\))\), "+", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], 
            " ", \(\(f(t\_\(n - 1\), v(t\_\(n - 1\))) + 
                  f(t\_n, v(t\_n))\)\/2\)}], 
          "+", \(O(\[CapitalDelta]t\^3)\)}]}], TraditionalForm]]]], "NE4",
  CellTags->"(1.4.11)"],

Cell[TextData[{
  "Since the error of the method is order ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "3"], TraditionalForm]]],
  "in a single step, Eq. ",
  ButtonBox["(1.4.11)",
    ButtonData:>"(1.4.11)",
    ButtonStyle->"Hyperlink"],
  " is a distinct improvement over Euler's method, ",
  ButtonBox["Eq. (1.4.7)",
    ButtonData:>"(1.4.7)",
    ButtonStyle->"Hyperlink"],
  ". However, there is a catch.  Now ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["t",
              FontSize->12], "n"],
          FontSize->10], TraditionalForm]]],
  ") appears on the ",
  "right-hand",
  " side of the recursion relation, so we can't use this equation as it \
stands to solve for ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["t",
              FontSize->12], "n"],
          FontSize->10], TraditionalForm]]],
  "). [We might try to solve this equation for ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["t",
              FontSize->12], "n"],
          FontSize->10], TraditionalForm]]],
  "), but for general ",
  StyleBox["f",
    FontSlant->"Italic"],
  " that is nontrivial. Such methods are called ",
  StyleBox["implicit methods",
    FontSlant->"Italic"],
  ", and will be discussed in Chapter ",
  ButtonBox["6",
    ButtonData:>"Chapter6.nb",
    ButtonStyle->"Hyperlink"],
  ".] "
}], "Text",
  CellTags->"i:143"],

Cell[TextData[{
  "\tWhat we need is some way to replace ",
  Cell[BoxData[
      \(TraditionalForm\`v(t\_n)\)]],
  " on the right-hand side: we need a ",
  StyleBox["prediction",
    FontSlant->"Italic"],
  " for the value of ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["t",
              FontSize->12], "n"],
          FontSize->10], TraditionalForm]]],
  "), which we will then use in Eq. ",
  ButtonBox["(1.4.11)",
    ButtonData:>"(1.4.11)",
    ButtonStyle->"Hyperlink"],
  " to get a better value. Fortunately, we have such a prediction available: \
Euler's method, ",
  ButtonBox["Eq. (1.4.7)",
    ButtonData:>"(1.4.7)",
    ButtonStyle->"Hyperlink"],
  ", provides an approximation to ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["t",
              FontSize->12], "n"],
          FontSize->10], TraditionalForm]]],
  "), good to order ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)]],
  ". This is sufficient for Eq. ",
  ButtonBox["(1.4.11)",
    ButtonData:>"(1.4.11)",
    ButtonStyle->"Hyperlink"],
  ", since the ",
  StyleBox["O",
    FontSlant->"Italic"],
  "(",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)]],
  ") error in ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["t",
              FontSize->12], "n"],
          FontSize->10], TraditionalForm]]],
  ") is multiplied in Eq. ",
  ButtonBox["(1.4.11)",
    ButtonData:>"(1.4.11)",
    ButtonStyle->"Hyperlink"],
  " by another factor of ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  ", making this error ",
  StyleBox["O",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t\^3\)]],
  "); but  the ",
  "right-hand",
  " side  of Eq. ",
  ButtonBox["(1.4.11)",
    ButtonData:>"(1.4.11)",
    ButtonStyle->"Hyperlink"],
  " is already accurate only to ",
  StyleBox["O",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "3"], TraditionalForm]]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tThe resulting recursion relation is called a",
  StyleBox[" predictor-corrector method of order 2",
    FontSlant->"Italic"],
  ".  The method is second-order accurate, because over a fixed time interval \
",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " the number of steps taken is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "/", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " and the total error scales as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"T", "/", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], ")"}], " ", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "3"]}], "=", 
          RowBox[{"T", " ", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "2"]}]}], TraditionalForm]]],
  ".  The method consists of the following two lines: an initial prediction \
for ",
  StyleBox["v",
    FontSlant->"Italic"],
  " at the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "th step, which we assign to a variable ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  " , and the improved correction step, given by Eq. ",
  ButtonBox["(1.4.11)",
    ButtonData:>"(1.4.11)",
    ButtonStyle->"Hyperlink"],
  ", making use of the prediction:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v\_1 = 
        v(t\_\(n - 1\)) + \[CapitalDelta]t\ \(f(t\_\(n - 1\), 
              v(t\_\(n - 1\)))\), \[IndentingNewLine]v(t\_n) = 
        v(t\_\(n - 1\)) + \[CapitalDelta]t\ \(\(\(f(t\_\(n - 1\), 
                      v(t\_\(n - 1\))) + f(t\_n, v\_1)\)\/2\)\(.\)\)\)]],
  "\t\t\t\t"
}], "NE4",
  CellTags->"(1.4.12)"],

Cell[TextData[{
  "\tThe following module, named ",
  StyleBox["PCsol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", implements the predictor-corrector method in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(PCsol[v0_, time_, \[CapitalDelta]t_] := 
      Module[{t, v, f0, v1, solution}, 
        t[n_] = n\ \[CapitalDelta]t; \[IndentingNewLine]v[0] = 
          v0; \[IndentingNewLine]f0 := 
          f[t[n - 1], v[n - 1]]; \[IndentingNewLine]v1 := 
          v[n - 1] + \[CapitalDelta]t\ f0; \[IndentingNewLine]v[
            n_] := \(v[n] = 
            v[n - 1] + \[CapitalDelta]t \((f0 + f[t[n], v1])\)/
                  2\); \[IndentingNewLine]solution = 
          Table[{t[n], v[n]}, {n, 0, 
              time/\[CapitalDelta]t}]; \[IndentingNewLine]vPC[
            t_] = \(Interpolation[solution]\)[t];]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.41"],

Cell[TextData[{
  "There is one extra trick that we have implemented in this module. We have \
assigned the value of ",
  StyleBox["f",
    FontSlant->"Italic"],
  " at the ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  "st step to the variable ",
  StyleBox["f0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", (using delayed evaluation so that it is evaluated only when needed). The \
reason for doing so is that we used this value for ",
  StyleBox["f",
    FontSlant->"Italic"],
  "  twice in Eq. ",
  ButtonBox["(1.4.12)",
    ButtonData:>"(1.4.12)",
    ButtonStyle->"Hyperlink"],
  ". Rather than evaluating the function twice at the same point, we instead \
save its value in the variable ",
  StyleBox["f0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This does not save much time for simple functions, but can be a real \
time-saver if  ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "is very complicated "
}], "Text"],

Cell["\<\
\tAlso, note that we have paid a price in going to a second-order \
method. The code is more complicated, and we now need to evaluate the \
function at two points, instead of only one as we did in Euler's method. \
\
\>", "Text"],

Cell[TextData[{
  "\tBut we have also gained something -- accuracy. This relatively simple \
predictor corrector method is much more accurate than Euler's method, as we \
can see by again evaluating the solution for three step sizes ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  "={0.2,0.1,0.05},  and plotting the error. We again choose our previous \
example:"
}], "Text"],

Cell[BoxData[{
    \(\(f[t_, v_] = t - v;\)\), "\n", 
    \(\(vExact[t_]\  = \ E^\(-t\)\  + \ t\  - \ 1;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.42"],

Cell[TextData[{
  "The resulting error is shown in Cell ",
  ButtonBox["1.43",
    ButtonData:>"Cell 1.43",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(PCsol[0, 4, 0.2];\)\), "\n", 
    \(\(p1\  = \ 
        Plot[vPC[t] - vExact[t], {t, 0, 4}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(PCsol[0, 4, 0.1];\)\), "\n", 
    \(\(p2\  = \ 
        Plot[vPC[t] - vExact[t], {t, 0, 4}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(PCsol[0, 4, 0.05];\)\), "\n", 
    \(\(p3\  = \ 
        Plot[vPC[t] - vExact[t], {t, 0, 4}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[p1, p2, p3, DisplayFunction \[Rule] $DisplayFunction, 
        PlotLabel \[Rule] "\<Error for \[CapitalDelta]t = 0.2,0.1,0.05\>"];\)\
\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.43"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 205.781 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11761 -36 -4.5 ]
[.01131 .11761 0 4.5 ]
[.01131 .2205 -30 -4.5 ]
[.01131 .2205 0 4.5 ]
[.01131 .32339 -36 -4.5 ]
[.01131 .32339 0 4.5 ]
[.01131 .42628 -30 -4.5 ]
[.01131 .42628 0 4.5 ]
[.01131 .52917 -36 -4.5 ]
[.01131 .52917 0 4.5 ]
[.5 .63053 -83 0 ]
[.5 .63053 83 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(1)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(2)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(3)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11761 m
.03006 .11761 L
s
[(0.0005)] .01131 .11761 1 0 Mshowa
.02381 .2205 m
.03006 .2205 L
s
[(0.001)] .01131 .2205 1 0 Mshowa
.02381 .32339 m
.03006 .32339 L
s
[(0.0015)] .01131 .32339 1 0 Mshowa
.02381 .42628 m
.03006 .42628 L
s
[(0.002)] .01131 .42628 1 0 Mshowa
.02381 .52917 m
.03006 .52917 L
s
[(0.0025)] .01131 .52917 1 0 Mshowa
.125 Mabswid
.02381 .03529 m
.02756 .03529 L
s
.02381 .05587 m
.02756 .05587 L
s
.02381 .07645 m
.02756 .07645 L
s
.02381 .09703 m
.02756 .09703 L
s
.02381 .13818 m
.02756 .13818 L
s
.02381 .15876 m
.02756 .15876 L
s
.02381 .17934 m
.02756 .17934 L
s
.02381 .19992 m
.02756 .19992 L
s
.02381 .24107 m
.02756 .24107 L
s
.02381 .26165 m
.02756 .26165 L
s
.02381 .28223 m
.02756 .28223 L
s
.02381 .30281 m
.02756 .30281 L
s
.02381 .34397 m
.02756 .34397 L
s
.02381 .36454 m
.02756 .36454 L
s
.02381 .38512 m
.02756 .38512 L
s
.02381 .4057 m
.02756 .4057 L
s
.02381 .44686 m
.02756 .44686 L
s
.02381 .46743 m
.02756 .46743 L
s
.02381 .48801 m
.02756 .48801 L
s
.02381 .50859 m
.02756 .50859 L
s
.02381 .54975 m
.02756 .54975 L
s
.02381 .57032 m
.02756 .57032 L
s
.02381 .5909 m
.02756 .5909 L
s
.02381 .61148 m
.02756 .61148 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Error) show
99.000 13.000 moveto
(for) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
141.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
153.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
171.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
177.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
195.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
201.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
225.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04262 .14144 L
.06244 .2388 L
.08426 .32462 L
.10458 .39576 L
.14264 .49399 L
.15313 .51506 L
.16305 .53411 L
.17196 .54691 L
.18163 .5574 L
.20108 .57704 L
.2064 .58217 L
.20934 .58493 L
.21214 .58749 L
.21339 .58862 L
.21407 .58923 L
.21472 .58958 L
.21549 .58987 L
.21619 .59012 L
.21755 .59061 L
.2225 .59226 L
.24299 .59828 L
.25198 .60078 L
.25674 .60205 L
.25936 .60272 L
.26065 .60303 L
.26185 .60332 L
.26302 .60312 L
.26428 .60288 L
.26692 .60235 L
.27154 .60137 L
.28059 .59939 L
.29012 .59736 L
.3004 .59531 L
.30535 .59433 L
.30665 .59406 L
.30804 .59378 L
.30936 .5935 L
.31055 .5929 L
.315 .5904 L
.31987 .58765 L
.33815 .57762 L
.37813 .55169 L
.4166 .52206 L
.45751 .4873 L
.49692 .45202 L
.53481 .41733 L
.57514 .38155 L
.61397 .34859 L
.65525 .31544 L
Mistroke
.69501 .2856 L
.73325 .25868 L
.77395 .23217 L
.81313 .20888 L
.85477 .18646 L
.89488 .16698 L
.93349 .15022 L
.97454 .13399 L
.97619 .13331 L
Mfstroke
.02381 .01472 m
.04262 .04203 L
.06244 .06535 L
.08426 .08718 L
.10458 .10376 L
.12414 .11678 L
.14264 .12677 L
.16305 .13512 L
.18163 .14086 L
.19132 .14348 L
.19622 .14441 L
.2016 .14541 L
.21106 .14714 L
.22004 .14831 L
.23018 .14933 L
.23467 .14978 L
.23585 .14989 L
.23713 .15002 L
.23834 .15012 L
.23945 .15016 L
.24217 .15024 L
.24463 .15032 L
.24943 .15046 L
.25469 .15063 L
.25759 .15072 L
.25901 .15076 L
.26033 .1508 L
.26151 .15084 L
.26277 .15083 L
.26403 .15079 L
.26542 .15076 L
.27007 .15062 L
.27916 .15039 L
.28165 .15033 L
.28428 .15026 L
.28495 .15024 L
.28566 .15023 L
.28644 .15017 L
.28717 .15011 L
.28981 .14991 L
.29982 .14917 L
.32116 .14716 L
.34132 .1447 L
.37978 .13881 L
.4207 .13118 L
.4601 .12324 L
.49799 .11537 L
.53833 .10689 L
.57716 .09896 L
.61843 .09087 L
Mistroke
.65819 .08345 L
.69644 .0768 L
.73714 .07023 L
.77632 .06438 L
.81795 .05873 L
.85807 .0538 L
.89667 .04949 L
.93773 .04536 L
.97619 .0419 L
Mfstroke
.02381 .01472 m
.04262 .02119 L
.06244 .02698 L
.08426 .03224 L
.10458 .03621 L
.12414 .03931 L
.14264 .04169 L
.16305 .04371 L
.18163 .04512 L
.19132 .04571 L
.2016 .04622 L
.22004 .04689 L
.22945 .04713 L
.23464 .04723 L
.2372 .04728 L
.23958 .04731 L
.24415 .04736 L
.24676 .04739 L
.2479 .04741 L
.24913 .04742 L
.25027 .04743 L
.25131 .04743 L
.25337 .04744 L
.25788 .04746 L
.25903 .04746 L
.26029 .04747 L
.26148 .04747 L
.26258 .04747 L
.26385 .04746 L
.26521 .04746 L
.26761 .04745 L
.26969 .04744 L
.27193 .04744 L
.27322 .04743 L
.27439 .04743 L
.27552 .04742 L
.2767 .0474 L
.28184 .04735 L
.28437 .04733 L
.28669 .0473 L
.28938 .04726 L
.29228 .04722 L
.29737 .04714 L
.30695 .04695 L
.31711 .04671 L
.33547 .04619 L
.37336 .04482 L
.4137 .04307 L
.45253 .04121 L
.4938 .03913 L
Mistroke
.53356 .03713 L
.57181 .03523 L
.61251 .03329 L
.65169 .03152 L
.69332 .02976 L
.73344 .02819 L
.77204 .0268 L
.8131 .02544 L
.85264 .02426 L
.89066 .02322 L
.93114 .02223 L
.9701 .02137 L
.97619 .02124 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00O?ooool4o`000003oa0@4?oooooooooo04;ooooo1Ol00015ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0Aoooool2o`000003oa0@4?oooooooooo00Sooooo001nooooo`03
o`000?oooooooooo04Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80B?ooool00ol0003oooooooooo`09ooooo`00O_ooool00ol0003oooooooooo`15oooo
o`03oiRHV?lQ8B7ok^k^04[ooooo00?o0000ooooooooool0@oooool5o`0000[ooooo001nooooo`03
o`000?oooooooooo04Kooooo00?oV9RHob4Q8Oo^k^h0B?ooool00onYZJWo410@ooooo`14ooooo`04
odA4A?oMgMgoooooo`0000_ooooo001nooooo`03o`000?oooooooooo04Oooooo00?oMgMgofIVI_oo
ool0A_ooool00ol@413o0000okZj^P15ooooo`04omgMgOmEEEGoooooo`0000_ooooo001nooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0A_ooool00onj^[[o8B4Qooooo`15ooooo`03
ogMgMoo<c<co000000_ooooo001nooooo`03o`000?oooooooooo04Cooooo00Go0000okZj^_oooooo
V9RHoa0@4015ooooo`05oa0@4?nHV9SooooookZj^_l00000A_ooool00oo^k^koA4A4o`00000;oooo
o`00O?ooool00omEEEGoIVIVo`000016ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01OnY
ZJWo410@o`000?l@413oZJVY04Oooooo00?oMgMgo`000?ooool02_ooool00?ooooooJOooool003Co
oooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo
000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolb
ooooo`00;?ooooooo`0003Wo00001?ooool003Cooooo00?o0000ooooooooool00ol00009ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool003Cooooo0_l00004ooooo`?o0000
@Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
?oooool9o`0000_ooooo000dooooo`03o`000?oooooo000000Kooooo0ol0003_ooooobGo00005?oo
ool003Cooooo0ol00009ooooo`?o0000aooooolUo`0003Wooooo000dooooo`;o000000?oooooo`00
0?ooool02_ooool3o`000:_ooooo6Ol0001Nooooo`00=?ooool2o`0000;ooooo00?o0000oooooooo
ool02oooool5o`0009[ooooo3?l0001gooooo`00=?ooool2o`0000;ooooo00?o0000ooooooooool0
4?ooool6o`0007_ooooo6Ol00023ooooo`00=?ooool2o`0000?ooooo00?o0000ooooooooool05Ooo
ool6o`0005cooooo6Ol0002Looooo`00=?ooool2o`0000Cooooo00?o0000ooooooooool06_ooool<
o`0004Cooooo3?l0002Sooooo`Oo00002oooool003Cooooo0_l00004ooooo`03o`000?oooooooooo
02KoooooA?l0002Sooooo`co00004_ooool003Cooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`3oooooo`go00007_ooool003Cooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`3eooooo`Wo0000:oooool003Cooooo0ol00006ooooo`03o`000?oooooooooo0>gooooo1ol0
000dooooo`00=?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo0>Kooooo1_l0000k
ooooo`00=?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0=oooooo1_l00011oooo
o`00=?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0=Gooooo2Ol00017ooooo`00
=?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0<_ooooo2Ol0001@ooooo`00=?oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo0<Kooooo1?l0001Iooooo`00=?oo
ool2o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool0`Oooool4o`0005gooooo000d
ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool0^oooool5o`00067ooooo000d
ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0]?ooool6o`0006Kooooo000d
ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0[Oooool6o`0006cooooo000d
ooooo`04o`000?ooooooooooo`0000oooooo0_l0002Wooooo`Ko0000L_ooool003Cooooo00Go0000
ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo09kooooo1_l0001hooooo`00=?ooool0
1Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0U_ooool7o`0007kooooo000d
ooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo093ooooo1Ol00025
ooooo`00=?ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool0Roooool4
o`0008[ooooo000dooooo`05o`000?ooooooooooooooool000005?ooool2o`0008Oooooo1?l0002>
ooooo`00=?ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool0P?ooool4
o`0009;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01Ol0003ooooooooooooo
oooo000001Oooooo0_l0001kooooo`Go0000U_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0M?ooool4
o`0009_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000ooooooooool0
5oooool2o`0006oooooo1Ol0002Oooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`;o0000Ioooool6o`000:Cooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6oooool2o`0005oooooo1_l0002Zooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Mooooo`;o0000Eoooool6o`000;3ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo0_l0001@ooooo`Go
0000]_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool4o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`;o0000
BOooool5o`000:gooooo0ol0000;ooooo`00=?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02;ooooo1?l00011ooooo`Co0000[oooool3o`0000kooooo000dooooo`;o00001?ooool0
0ol0003oooooooooo`0Vooooo`Go0000=oooool5o`000;3ooooo0ol0000Aooooo`00=?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;_ooool6o`00
0;?ooooo0_l0000Dooooo`00=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02co
oooo2?l0000Looooo`co0000]_ooool3o`0001Kooooo000dooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0=?ooool<o`0000?ooooo3Ol00030ooooo`;o00006Oooool003Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`?o0000boooool2o`0001_ooooo000d
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool<ooooo`;o00007Oooool0
03Cooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo2_ooool2o`0001oooooo000dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool8ooooo`;o00008Oooool003Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Kooooo0_l0000Sooooo`00=?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo0oooool2o`0002Gooooo000d
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool1ooooo`;o00009oooool0
03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3nooooo`;o0000:Oooool003Co
oooo0_l00006ooooo`03o`000?oooooooooo0?cooooo0_l0000[ooooo`00=?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?[ooooo0_l0000]ooooo`00=?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?Oooooo0_l0000_ooooo`00=?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?Gooooo0_l0000aooooo`00=?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0??ooooo0_l0000cooooo`00=?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?7ooooo0_l0000eooooo`00=?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0>oooooo0_l0000gooooo`00=?ooool2o`0000Sooooo00?o0000ooooooooool0kOoo
ool00ol0003oooooooooo`0gooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0>_ooooo0_l0000jooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0>Wooooo0_l0000looooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>Oo
oooo0_l0000nooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0iOooool2
o`00043ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0hoooool00ol0003ooooo
ooooo`10ooooo`002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`05oooo
o`?o00002?ooool00ol0003oooooooooo`3Qooooo`;o0000@oooool000Wooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0=oooooo0_l00015ooooo`002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0g_ooool00ol0003o
ooooooooo`15ooooo`002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0g?ooool2o`0004Sooooo0009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`3Iooooo`;o0000B_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
0=Sooooo00?o0000ooooooooool0B_ooool003Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`3Fooooo`;o0000COooool003Cooooo0_l0000:ooooo`03o`000?oooooooooo0=Cooooo
0_l0001?ooooo`00=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0=?ooooo00?o
0000ooooooooool0Coooool003Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3@
ooooo`;o0000D_ooool003Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3>oooo
o`;o0000E?ooool003Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3=ooooo`03
o`000?oooooooooo05Cooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
boooool2o`0005Oooooo000dooooo`;o00003?ooool00ol0003oooooooooo`39ooooo`03o`000?oo
oooooooo05Oooooo000dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0aoooool2
o`0005[ooooo000dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0a_ooool00ol0
003oooooooooo`1Jooooo`00=?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<?o
oooo0_l0001Mooooo`00=?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<;ooooo
00?o0000ooooooooool0GOooool003Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`30ooooo`;o0000H?ooool003Cooooo0_l0000=ooooo`03o`000?oooooooooo0;oooooo00?o0000
ooooooooool0H?ooool003Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2loooo
o`;o0000Hoooool003Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2kooooo`03
o`000?oooooooooo06?ooooo000dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`1Tooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo0;Wooooo00?o0000ooooooooool0IOooool003Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2gooooo`03o`000?oooooooooo06Kooooo000dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0]Oooool2o`0006Wooooo000dooooo`;o00003oooool00ol0003o
ooooooooo`2dooooo`03o`000?oooooooooo06Wooooo000dooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`1Zooooo`00=?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0Joooool003Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo06cooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l000001Ol@413oooooooooooooooooA4A4
00;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:kooooo0_l0001_ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo0:cooooo00?o0000ooooooooool0Koooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`00013o
oooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1`ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0ZOooool2o`0007?ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Sooooo00?o
0000ooooooooool0Loooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo0:Kooooo00?o0000ooooooooool0M?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0MOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0Xoooool2o`0007Sooooo000dooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0X_ooool00ol0003oooooooooo`1hooooo`00=?ooool2o`0001?ooooo00?o
0000ooooooooool0X?ooool00ol0003oooooooooo`1iooooo`00=?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo09kooooo0_l0001looooo`00=?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool0O?ooool003Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo07gooooo000dooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`1nooooo`00=?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0Oooo
ool003Cooooo0_l0000Dooooo`03o`000?oooooooooo09Oooooo0_l00022ooooo`00=?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0P_ooool003Co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo08?o
oooo000dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Toooool00ol0003ooooo
ooooo`24ooooo`00=?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09;ooooo00?o
0000ooooooooool0QOooool003Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2?
ooooo`;o0000R?ooool003Cooooo0_l0000Fooooo`03o`000?oooooooooo08kooooo00?o0000oooo
ooooool0R?ooool003Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2=ooooo`03
o`000?oooooooooo08Wooooo000dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
S?ooool00ol0003oooooooooo`2:ooooo`00=?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo08[ooooo00?o0000ooooooooool0Roooool003Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo08cooooo000dooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`2=ooooo`00=?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0S_ooool003Cooooo
0_l0000Hooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0Soooool003Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo093ooooo000d
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`2A
ooooo`00=?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo083ooooo0_l0002Doooo
o`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00006ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`2Dooooo`002Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`2Eoooo
o`002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001?ooool00onHV9So8B4Qonk^kP07ooooo`?o00006Ooo
ool00ol0003oooooooooo`1looooo`03o`000?oooooooooo09Kooooo0009ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo09Oooooo0009ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo09Sooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo09Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool0V_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`2Kooooo`00=?ooool2o`0001gooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`2Looooo`00=?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0WOooool003Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1_
ooooo`;o0000X?ooool003Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo0:3ooooo000dooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`2Qooooo`00=?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool0X_ooool003Cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo0:?ooooo000dooooo`;o00008?ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo0:Cooooo000dooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2Uooooo`00=?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0Y_ooool003Cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo0:Oooooo
000dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`2Xooooo`00=?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0ZOooool003Cooooo0_l0000Rooooo`03o`000?oooooooooo05oooooo0_l0002/oooo
o`00=?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool0[?ooool003Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo0:gooooo000dooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`2^ooooo`00=?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool0[oooool003Cooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Gooooo`;o0000/_ooool003Cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo0;;ooooo000dooooo`;o00009Oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo0;?ooooo000dooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`2dooooo`00=?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0]Oooool003Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo0;Kooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04gooooo0_l0002iooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`2iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00009oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo0;[ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`18ooooo`;o0000_Oooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`2mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`2nooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`12ooooo`;o0000`Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<7ooooo000dooooo`;o0000;?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo0<;ooooo000dooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0>oooool2o`000<Gooooo000dooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`35ooooo`00=?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo03Kooooo0_l00038ooooo`00=?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo03?ooooo0_l0003:ooooo`00=?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0b_ooool003Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0^ooooo`;o0000cOooool003Cooooo0_l0000cooooo`03o`00
0?oooooooooo02_ooooo0_l0003?ooooo`00=?ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0coooool003Cooooo00?o0000ooooooooool0=?ooool2
o`0002Oooooo0_l0003Booooo`00=?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
02;ooooo0_l0003Dooooo`00=?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0e?ooool003Cooooo00?o0000ooooooooool0=oooool2o`0001oooooo
0_l0003Gooooo`00=?ooool2o`0003Wooooo0ol0000Looooo`03o`000?oooooooooo0=Oooooo000d
ooooo`03o`000?oooooooooo03_ooooo1?l0000Eooooo`?o0000f_ooool003Cooooo00?o0000oooo
ooooool0?oooool5o`0000_ooooo1Ol0003Mooooo`00=?ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo00;ooooo1_l0003Rooooo`00=?ooool00ol0003oooooooooo`15ooooo`Co0000
j?ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3o
oooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;o
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00>_ooooo00?o0000okZj^_ooool06ooo
ool00ol0003o^[Zjooooo`1Looooo`00joooool2oc8b<Qcooooo0_lb<S9Mooooo`00H_ooool6o`00
00;ooooo00?o410@o`000?l000000ol00002ooooo`03oa0@4?l0003o000000?o00000oooool02?o^
k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00008ooooo`03oa0@4?l0003o000000;o0000
00Go410@ooooooooooook^k^oeEEE@02o`000004oeEEEOo^k^kooooooa0@40Go00002?ooool00olb
<S;o0000o`000003o`000005oc8b<_oooooooooooooooonHV9P00_l000000om4A4Co^[Zjooooo`0G
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00002ooooo`03ohN7Qol0
003o^[Zj00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@
4?ooooooQhN7o`000?nj^[X01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM03[ooooo001S
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000
ooooooooool02Oooool00onHV9SoA4A4ooooo`02ooooo`03odA4A?nHV9Sooooo00;ooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool00oo<c<co0000oa0@4004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00Oo0000ooooooooooooooooolc<c?l0
003o410@00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool0>Oooool006?ooooo00Go0000oooooooooooo
oooooa0@4004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000<ooooo`05oa0@4?oMgMgo
ooooomgMgOl@41001?ooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP0:ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo
410@00Sooooo00?o0000ooooooooool0>?ooool006?ooooo00?o0000ooooool@41001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000003?ooool01On7QhOoMgMgoooooomVIVKoQhN700Cooooo
00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001ooo
ool00omgMgOo<S8booooo`0iooooo`00Hoooool3o`0000Kooooo00?o0000oc8b<_oMgMd01Oooool0
0ol0003o<S8bomgMg@04ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003o<S8b
omgMg@0;ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3oooo
o`03o`000?lb<S;ogMgM00[ooooo00Gok^k^oa0@4?o^k^ko410@onk^kP04ooooo`03o`000?oooooo
oooo01[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Sooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<03[ooooo001Sooooo`05o`000?oooooo410@ooooool@41000oooool2o`000004ojVYZOlQ8B7o
0000ob4Q8@;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000o`000?mE
EEGok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Oooooo00?o410@o`000?l000000ol00002
ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Wo
oooo00?oMgMgob4Q8OmEEED00oooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00Oooooo00Go410@oooooooooooooooooa0@400>
ooooo`03o`000?oooooooooo00Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oo
ooooooooooooool@41001?ooool00ol0003oooooooooo`0looooo`00Hoooool01Ol0003ooooooooo
oooooooo000002[ooooo00?o0000ooooooooool06_ooool00ooMgMgo0000omgMg@05ooooo`03o`00
0?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool02?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooooooo03cooooo001Rooooo`Ko0000:_ooool00ol@413o^[Zjooooo`0Kooooo`03ojVYZOoo
oooooooo00Cooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omE
EEGoIVIVo`00000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Cooooo1?l0000kooooo`00T_ooool01?nj^[[o410@o`000?l@413Booooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "Not only is the error much smaller than in Euler's method for the same \
step size, but the error also decreases much more rapidly as ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " is decreased. The maximum error goes from roughly 0.0029 to 0.0007 to \
0.00017 as ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " goes from 0.2 to 0.1 to 0.05.  In other words, the maximum error is \
reduced by roughly a factor of 4 every time ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " is reduced by a factor of 2. This is exactly what we expect for error \
that is ",
  StyleBox["O",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "2"], TraditionalForm]]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tThere are many higher-order methods that are even more accurate than \
this.  Two the more popular methods are the fourth",
  "-order",
  " Runge-Kutta method, and the  Bulirsch-Stoer method. These methods will \
not be discussed here, but  the codes can be found in many other textbooks. \
See, for instance,  ",
  ButtonBox["Press et al",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "., (1986). "
}], "Text",
  CellTags->"i:53"],

Cell["\<\
\tAlso, there are several second-order (and higher-order) methods \
that require only one force evaluation per timestep. These algorithms can be \
more efficient when the force evaluation is time-consuming. Three such \
methods are considered in the exercises: the leapfrog method and a \
centered-difference method for problems in Newtonian mechanics, and the \
Adams-Bashforth method for more general problems.. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4.5 Euler's Method for Systems of ODEs",
  FontFamily->"Helvetica"]], "Subsubtitle",
  CellTags->{"i:52", "c:26"}],

Cell["Consider the general second-order ODE", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{"f", "(", 
            RowBox[{"t", ",", "x", ",", 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], ")"}]}], TraditionalForm]]],
  ",     ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x(0) = x\_o\), ",", 
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None], \((0)\)}], "=", \(v\_o\)}]}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(1.4.13)"],

Cell[TextData[{
  "Since the ODE is second-order, Euler's method cannot be used to solve it \
numerically. However, we can modify the equation so that Euler's method can \
be used. By introducing a new variable ",
  Cell[BoxData[
      \(TraditionalForm\`v(t)\  = \[DifferentialD]x/\[DifferentialD]t\)]],
  ", Eq. ",
  ButtonBox["(1.4.13)",
    ButtonData:>"(1.4.13)",
    ButtonStyle->"Hyperlink"],
  " can be written as the following system of first",
  "-order",
  " differential equations:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
            MultilineFunction->None], "=", \(v(t)\)}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]v\), \(\[DifferentialD]t\),
            MultilineFunction->None], "=", \(f(t, x, v)\)}], 
        TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = x\_o, v(0) = v\_o\)]],
  "."
}], "NE4",
  CellTags->"(1.4.14)"],

Cell[TextData[{
  "Euler's method still does not apply, because it was written originally for \
a single first-order ODE. However, let us define a vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], " ", "=", 
          " ", \({x(t), v(t)}\)}], TraditionalForm]]],
  ". Then Eqs. ",
  ButtonBox["(1.4.14)",
    ButtonData:>"(1.4.14)",
    ButtonStyle->"Hyperlink"],
  " can be written as a ",
  StyleBox["vector ODE",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{"\[DifferentialD]", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], \(\[DifferentialD]t\),
            MultilineFunction->None], "=", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", 
            RowBox[{"t", ",", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "0", ")"}], "=", 
          SubscriptBox[
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(1.4.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], "=", \({x\_o, v\_o}\)}], 
        TraditionalForm]]],
  " , and the vector function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          RowBox[{"t", ",", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  " is defined as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", 
            RowBox[{"t", ",", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], "=", \({v(t), f(t, x, v)}\)}], 
        TraditionalForm]]],
  " ."
}], "NE4",
  CellTags->"(1.4.16)"],

Cell[TextData[{
  "  We can now apply Euler's method to this vector ODE, simply by \
reinterpreting the scalar quantities that appeared in ",
  ButtonBox["Eq. (1.4.7)",
    ButtonData:>"(1.4.7)",
    ButtonStyle->"Hyperlink"],
  " as vectors:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", \(t\_n\), ")"}], "=", 
          RowBox[{
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", \(t\_\(n - 1\)\), ")"}], "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "(", 
                RowBox[{\(t\_\(n - 1\)\), ",", 
                  RowBox[{
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "(", \(t\_\(n - 1\)\), ")"}]}], 
                ")"}]}]}]}], TraditionalForm]]],
  " ."
}], "NE4",
  CellTags->"(1.4.17)"],

Cell[TextData[{
  " In fact, there is nothing about Eqs. ",
  ButtonBox["(1.4.15)",
    ButtonData:>"(1.4.15)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(1.4.17)",
    ButtonData:>"(1.4.17)",
    ButtonStyle->"Hyperlink"],
  " that limits them to two-dimensional vectors. An ",
  StyleBox["N",
    FontSlant->"Italic"],
  "th-order ODE of the general form given by ",
  ButtonBox["Eq. (1.2.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  " can also be written in the form of Eq. ",
  ButtonBox["(1.4.15)",
    ButtonData:>"(1.4.15)",
    ButtonStyle->"Hyperlink"],
  " by defining a series of new variables"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(v(t)\), "=", 
          FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
            MultilineFunction->None]}], ",", 
        RowBox[{\(a(t)\), "=", 
          FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None]}], ",", "...", ",", 
        RowBox[{\(u(t)\), "=", 
          
          FractionBox[\(\[DifferentialD]\^\(N - 1\)x\), \(\[DifferentialD]t\^\
\(N - 1\)\),
            MultilineFunction->None]}], ","}], TraditionalForm]]]], "NE4",
  CellTags->"(1.4.18)"],

Cell["a vector", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], 
          "=", \({x(t), v(t), a(t),  ... , u(t)}\)}], ","}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(1.4.19)"],

Cell[" and a \"force\" ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", 
            RowBox[{"t", ",", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], 
          "=", \({v, a,  ... , u, f(t, x, v, a,  ... , u)}\)}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(1.4.20)"],

Cell[TextData[{
  "Thus, Euler's method in vector form, Eq. ",
  ButtonBox["(1.4.17)",
    ButtonData:>"(1.4.17)",
    ButtonStyle->"Hyperlink"],
  ", can be applied to a general ",
  StyleBox["N",
    FontSlant->"Italic"],
  "th-order ODE. Below, we provide the simple changes to the previous module \
",
  StyleBox["Eulersol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that ",
  "allow",
  " it to work for a general ODE of order ",
  StyleBox["N",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.44"],

Cell[BoxData[
    \(Eulersol[z0_, time_, \[CapitalDelta]t_] := \ 
      Module[{t, z, sol}, \[IndentingNewLine]t[n_]\  := \ 
          n\ \[CapitalDelta]t; \[IndentingNewLine]z[n_]\  := \(z[n] = 
            z[n - 1]\  + \ \[CapitalDelta]t\ \ f[t[n - 1], \ 
                  z[n - 1]]\); \[IndentingNewLine]z[
            0]\  := \ \ \ z0; \[IndentingNewLine]sol\  = \ 
          Table[Table[{t[n], \(z[n]\)[\([m]\)]}, {n, 0, 
                time/\[CapitalDelta]t}], {m, 1, 
              Length[z0]}]; \[IndentingNewLine]zEuler\  = \ 
          Table[Interpolation[sol[\([m]\)]], {m, 1, Length[z0]}];]\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 1.45"],

Cell[TextData[{
  StyleBox[" ",
    FontWeight->"Bold"],
  "Thanks to the ease with which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " handles vector arithmetic, the module is nearly identical to the previous \
scalar version of the Euler method.  In fact, except for renaming some \
variables, the first four lines are identical.  Only the lines involving \
creation of the interpolating functions differ. This is because the solution \
list ",
  StyleBox["sol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  " is created as a table of lists, each of which is a dataset of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{t[n], z\_m[n]}\)]],
  ".  Each element of ",
  StyleBox["zEuler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an interpolation of a component of ",
  StyleBox["z",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tTo use this module, we must first define a force vector ",
  StyleBox["f",
    FontWeight->"Bold"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ",",
  StyleBox["z",
    FontWeight->"Bold"],
  "). Let's take the case of the 1-D harmonic oscillator problem as an \
example. In this case",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((x, v)\)}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", "=", " ", \((v, \(-x\))\)}], 
        TraditionalForm]]],
  " (i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ 
        v, \ \[DifferentialD]v/\[DifferentialD]t\  = \ \(-x\)\)]],
  "):"
}], "Text"],

Cell[BoxData[
    \(f[t_, 
        z_]\  := \ {v, \(-x\)} /. {x \[Rule] z[\([1]\)], 
          v -> z[\([2]\)]}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.46"],

Cell[TextData[{
  "A delayed equality must be used in defining ",
  StyleBox["f",
    FontWeight->"Bold"],
  "; otherwise ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will attempt to find the two elements of ",
  StyleBox["z",
    FontWeight->"Bold"],
  " when making the substitution,  and this will lead to an error, since ",
  StyleBox["z",
    FontWeight->"Bold"],
  " has not been defined as a list yet."
}], "Text"],

Cell[TextData[{
  "Taking the initial condition ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["z",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " = (1,0) (i.e., ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " = 1, ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  " = 0),  in Cell ",
  ButtonBox["1.47",
    ButtonData:>"Cell 1.47",
    ButtonStyle->"Hyperlink"],
  " we run the Euler code and in Cell ",
  ButtonBox["1.48",
    ButtonData:>"Cell 1.48",
    ButtonStyle->"Hyperlink"],
  " plot the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ", which is the first element of ",
  StyleBox["zEuler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(Eulersol[{1, 0}, 10,  .02]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.47"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\(zEuler[\([1]\)]\)[t], {t, 0, 10}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.48"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.31364 0.272027 [
[.21429 .30114 -3 -9 ]
[.21429 .30114 3 0 ]
[.40476 .30114 -3 -9 ]
[.40476 .30114 3 0 ]
[.59524 .30114 -3 -9 ]
[.59524 .30114 3 0 ]
[.78571 .30114 -3 -9 ]
[.78571 .30114 3 0 ]
[.97619 .30114 -6 -9 ]
[.97619 .30114 6 0 ]
[.01131 .04161 -12 -4.5 ]
[.01131 .04161 0 4.5 ]
[.01131 .17763 -24 -4.5 ]
[.01131 .17763 0 4.5 ]
[.01131 .44965 -18 -4.5 ]
[.01131 .44965 0 4.5 ]
[.01131 .58567 -6 -4.5 ]
[.01131 .58567 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .31364 m
.21429 .31989 L
s
[(2)] .21429 .30114 0 1 Mshowa
.40476 .31364 m
.40476 .31989 L
s
[(4)] .40476 .30114 0 1 Mshowa
.59524 .31364 m
.59524 .31989 L
s
[(6)] .59524 .30114 0 1 Mshowa
.78571 .31364 m
.78571 .31989 L
s
[(8)] .78571 .30114 0 1 Mshowa
.97619 .31364 m
.97619 .31989 L
s
[(10)] .97619 .30114 0 1 Mshowa
.125 Mabswid
.07143 .31364 m
.07143 .31739 L
s
.11905 .31364 m
.11905 .31739 L
s
.16667 .31364 m
.16667 .31739 L
s
.2619 .31364 m
.2619 .31739 L
s
.30952 .31364 m
.30952 .31739 L
s
.35714 .31364 m
.35714 .31739 L
s
.45238 .31364 m
.45238 .31739 L
s
.5 .31364 m
.5 .31739 L
s
.54762 .31364 m
.54762 .31739 L
s
.64286 .31364 m
.64286 .31739 L
s
.69048 .31364 m
.69048 .31739 L
s
.7381 .31364 m
.7381 .31739 L
s
.83333 .31364 m
.83333 .31739 L
s
.88095 .31364 m
.88095 .31739 L
s
.92857 .31364 m
.92857 .31739 L
s
.25 Mabswid
0 .31364 m
1 .31364 L
s
.02381 .04161 m
.03006 .04161 L
s
[(-1)] .01131 .04161 1 0 Mshowa
.02381 .17763 m
.03006 .17763 L
s
[(-0.5)] .01131 .17763 1 0 Mshowa
.02381 .44965 m
.03006 .44965 L
s
[(0.5)] .01131 .44965 1 0 Mshowa
.02381 .58567 m
.03006 .58567 L
s
[(1)] .01131 .58567 1 0 Mshowa
.125 Mabswid
.02381 .06882 m
.02756 .06882 L
s
.02381 .09602 m
.02756 .09602 L
s
.02381 .12322 m
.02756 .12322 L
s
.02381 .15042 m
.02756 .15042 L
s
.02381 .20483 m
.02756 .20483 L
s
.02381 .23203 m
.02756 .23203 L
s
.02381 .25923 m
.02756 .25923 L
s
.02381 .28644 m
.02756 .28644 L
s
.02381 .34084 m
.02756 .34084 L
s
.02381 .36805 m
.02756 .36805 L
s
.02381 .39525 m
.02756 .39525 L
s
.02381 .42245 m
.02756 .42245 L
s
.02381 .47686 m
.02756 .47686 L
s
.02381 .50406 m
.02756 .50406 L
s
.02381 .53126 m
.02756 .53126 L
s
.02381 .55846 m
.02756 .55846 L
s
.02381 .01441 m
.02756 .01441 L
s
.02381 .61287 m
.02756 .61287 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58567 m
.02499 .58568 L
.02605 .58566 L
.02729 .58558 L
.02846 .58548 L
.02954 .58534 L
.03053 .58518 L
.03279 .58472 L
.03506 .58409 L
.03756 .58323 L
.04262 .58091 L
.04755 .57792 L
.05285 .57391 L
.06244 .56461 L
.07373 .5504 L
.08445 .53378 L
.10458 .49512 L
.14277 .40077 L
.18342 .28468 L
.22255 .17667 L
.24252 .12898 L
.26413 .08635 L
.27428 .07018 L
.285 .05607 L
.29415 .04656 L
.29896 .04255 L
.3042 .03896 L
.30944 .03619 L
.31184 .0352 L
.3144 .03434 L
.3167 .03374 L
.31792 .03349 L
.31923 .03327 L
.32044 .03311 L
.32154 .03301 L
.3226 .03295 L
.32371 .03292 L
.32502 .03293 L
.32621 .03299 L
.32687 .03304 L
.32758 .03312 L
.32888 .03329 L
.3301 .03349 L
.33139 .03376 L
.33369 .03437 L
.33638 .03529 L
.3389 .03635 L
.34462 .03948 L
.3496 .04301 L
.35503 .04771 L
Mistroke
.36491 .05849 L
.38344 .08606 L
.40316 .12491 L
.42414 .17528 L
.46578 .29304 L
.5059 .41145 L
.5445 .51035 L
.56448 .55013 L
.57466 .56657 L
.58555 .581 L
.59585 .59145 L
.60073 .59528 L
.60523 .59816 L
.60975 .60042 L
.61213 .60135 L
.61466 .60215 L
.61685 .60267 L
.61785 .60286 L
.6189 .60302 L
.62008 .60316 L
.62115 .60325 L
.62231 .60331 L
.62358 .60332 L
.62422 .60331 L
.6249 .60328 L
.62612 .60319 L
.62744 .60304 L
.62888 .60281 L
.63146 .60224 L
.63388 .60151 L
.63839 .59966 L
.64323 .59696 L
.64885 .59289 L
.65419 .58813 L
.66419 .57688 L
.68408 .54597 L
.70249 .50818 L
.74172 .40505 L
.77944 .29037 L
.81961 .17165 L
.85827 .07982 L
.87828 .04623 L
.88835 .03365 L
.89402 .02793 L
.89937 .02345 L
.90429 .02014 L
.90689 .01871 L
.90963 .01743 L
.91194 .01654 L
.91448 .01577 L
Mistroke
.9156 .01549 L
.9168 .01525 L
.91784 .01507 L
.91896 .01492 L
.91969 .01484 L
.92035 .01479 L
.92164 .01473 L
.92237 .01472 L
.92315 .01472 L
.92389 .01475 L
.92457 .01479 L
.92581 .0149 L
.92651 .01498 L
.92716 .01508 L
.92857 .01533 L
.9299 .01562 L
.93243 .01634 L
.93473 .01719 L
.9399 .01971 L
.94425 .0225 L
.94905 .02629 L
.95876 .03619 L
.97619 .06117 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo
000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom4
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0
ooooA03oool00280oooo0P00003o0?ooobH0oooo2000000G0?ooo`008P3oool00`000000oooo0?oo
o`3o0?ooob@0oooo00<000000?ooo`3oool01P3oool2000001D0oooo000R0?ooo`030000003oool0
oooo0?l0oooo8P3oool2000000/0oooo0P00000C0?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
ob00oooo0P00000?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo0?l0
oooo7`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo000R0?ooo`030000
003oool0oooo0?l0oooo7P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo
000H0?ooo`@0000000<04A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`1M0?ooo`P00000]`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo000J0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0F`3oool3000000L0oooo0P00002e0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0303oool000l0oooo1P0000050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0F@3oool2000000`0oooo0P00002b0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool01@3oool3000005P0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool02`3oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00X0oooo000J0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2Y
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02@3oool001P0oooo0P1EEED00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool00280
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo000R0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02X0oooo000R
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2R
0?ooo`030000003oool0oooo02/0oooo000R0?ooo`800000D@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00280oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3o
ool0;03oool00280oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00280oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3o
ool00280oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0;P3oool00280oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;P3oool00280
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0;`3oool00280oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0;`3oool00280oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo09P0oooo00<0
00000?ooo`3oool0<03oool00280oooo0P00001=0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0V03oool00`000000oooo0?ooo`0`0?ooo`008P3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?oo
o`008P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`0a0?ooo`008P3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0a0?ooo`008P3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0b0?ooo`008P3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0b0?ooo`008P3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`0c0?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0c0?ooo`008P3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`0c0?ooo`008P3oool2000004L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo03@0oooo000R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03@0oooo000R0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03D0oooo000R0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03D0oooo000R0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo03H0oooo000R0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03H0oooo000R0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo03H0oooo000R0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo03L0oooo000R0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03L0
oooo000R0?ooo`800000A03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo08L0oooo
00<000000?ooo`3oool0>03oool00280oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0>03oool00280oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0>@3oool00280oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo08@0oooo00<000000?ooo`3oool0>@3oool00280oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0>@3oool00280oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo08<0oooo00<000000?ooo`3oool0>P3oool00280oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0>P3o
ool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000
000c<c<0gMgM00D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool0>`3oool000L0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo03/0oooo
000500000080oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo00<0oooo
0`00000o0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`0k0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0
103oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`0l0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000`0oooo
00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo03`0oooo00070?ooo`05014A
4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo03`0
oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo03d0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000000H0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool0?@3oool00280oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0?@3oool00280oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0?P3oool00280oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0?P3oool00280oooo0P00000m0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0n0?oo
o`008P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0o0?ooo`008P3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0o0?ooo`008P3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`0o0?ooo`008P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`100?ooo`008P3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`100?ooo`008P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`100?ooo`008P3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`110?ooo`008P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`110?ooo`008P3oool2000003X0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0440oooo000R0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo0480oooo000R0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0480oooo000R0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0480oooo000R0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo04<0oooo000R0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0
oooo04<0oooo000R0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo04<0oooo000R0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo04@0
oooo000R0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo04@0oooo000R0?ooo`800000=P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0A03oool00280oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0A@3oool00280oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0A@3oool00280oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool0A@3oool00280oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool0AP3oool00280oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`020?ooo`D00000?03oool200000003014A4@3oool0oooo00l0oooo00<0
00000?ooo`3oool09`3oool01@3^k^h0<c<c0000000A4A40c<c<03X0oooo00D0c<c<028R8P000000
00000<c<c00h0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kP<0oooo000R
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool00`3oool01@2IVIT08R8R0>k^kP3o
ool0A4A403d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0W0?ooo`0505EEE@1g
MgL0oooo09VIV@0R8R80>P3oool01@0R8R80VIVI0?ooo`0000008R8R03X0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0oooo000R0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0103oool00`2IVIT08R8R0>k^kP0k0?ooo`D000004@3oool00`000000
oooo0?ooo`0W0?ooo`050000003oool0oooo0?ooo`000000>P3oool01@000000oooo0000003oool0
000003X0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A00<0oooo000R
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01@3oool00`2IVIT08R8R0>k^kP0j
0?ooo`0404A4A03MgMd0oooo000001<0oooo00<000000?ooo`3oool09P3oool01@000000VIVI0?oo
o`2IVIT08R8R03X0oooo00D0<c<c09VIV@000000VIVI03<c<`0j0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000030?ooo`008P3oool2000003<0oooo00<000000?ooo`3o
ool01`3oool00`1gMgL0IVIV0?ooo`0i0?ooo`040=gMg@1EEED0oooo000001<0oooo00<000000?oo
o`3oool09P3oool01@000000EEEE0000000A4A40c<c<03X0oooo00D0c<c<00000000000000000<c<
c00j0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`008P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0>@3o
ool00`1gMgL0c<c<0000000C0?ooo`030000003oool0oooo02H0oooo00<0EEEE08R8R03oool0?03o
ool01@0A4A4000000?ooo`2k^k/04A4A03X0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo
0?ooo`3oool04A4A00<0oooo000R0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
1@3oool01@000000^k^k0?ooo`2IVIT04A4A03/0oooo00<0k^k^04A4A0000000503oool00`000000
oooo0?ooo`0U0?ooo`030=gMg@0A4A40VIVI03`0oooo0P0000000`3oool0^k^k0000000j0?ooo`03
0000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`008P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00D0oooo00D0VIVI014A4@0000008R8R0<c<c00l0?oo
o`0307MgM`000000oooo01<0oooo00<000000?ooo`3oool09P3oool0103<c<`0A4A40000000A4A4j
0?ooo`050:ZZZP0000000000014A4@2ZZZX0>03oool205EEE@030000003oool0oooo0080oooo00D0
k^k^03<c<`000000<c<c0>k^kP030?ooo`008P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`180?ooo`008P3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`190?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`190?ooo`008P3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`190?ooo`008P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1:0?ooo`006P3ooooo000004l00000000R
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01P3oool00280oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000003@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`060?ooo`008P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1;0?ooo`008P3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`1;0?ooo`008P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1<0?ooo`008P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`1<0?ooo`008P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`1<0?ooo`008P3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1=0?oo
o`008P3oool2000002d0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo04d0oooo000R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo04d0oooo000R0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo04h0oooo000R0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo04h0oooo000R0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
04h0oooo000R0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo04h0oooo000R0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo04l0oooo
000R0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo04l0oooo000R0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo04l0oooo000R0?oo
o`800000:@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0D03oool00280oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0D03oool00280oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
D03oool00280oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0D@3oool00280oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0D@3oool0
0280oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0D@3oool00280oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0DP3oool00280oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0DP3oool00280oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0DP3oool00280oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0D`3oool00280oooo0P00000V0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`1C0?ooo`008P3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1C0?ooo`00
8P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`1D0?ooo`008P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1D0?ooo`008P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`1D0?ooo`008P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1E0?ooo`008P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1E0?ooo`008P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1E0?ooo`008P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`1F0?ooo`008P3oool200000280oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo05H0oooo000R0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0N`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05H0oooo000R0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo05L0oooo000R0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo05L0oooo000R0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo05P0oooo000R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo05P0oooo00070?ooo`050>k^kP0c<c<00000
03<c<`3^k^h01@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo05P0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0
MgMg03<c<`3oool0103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`1I0?ooo`001`3oool01@0A4A40oooo0?ooo`3o
ool04A4A0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1I0?ooo`001`3oool0
1@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0103oool3000001h0oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo05X0oooo0007
0?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<00D0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0FP3oool000L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0FP3oool000L0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0F`3oool000L0oooo00D0
k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@000001P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1K0?ooo`008P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`1K0?ooo`008P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1L0?ooo`008P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`1L0?ooo`008P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1M0?ooo`008P3oool2000001/0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05d0oooo
000R0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo05d0oooo000R0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo05h0oooo000R0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo05h0oooo000R0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo05l0oooo000R0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo05l0oooo000R0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05l0oooo000R0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0600oooo000R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0600oooo000R0?ooo`800000603oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0H03oool00280oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0H@3oool00280oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0H@3oool00280oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0HP3oool00280oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2D0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0HP3oool00280oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0H`3oool00280oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0H`3oool00280oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0I03o
ool00280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0I@3oool00280oooo0P00000C0?ooo`030000003oool0oooo
09T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1U0?ooo`008P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`1V0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo09/0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1V0?ooo`008P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`1W0?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`1W0?ooo`008P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1X0?oo
o`008P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`1X0?ooo`008P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0:40oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1Y0?ooo`008P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`1Z0?ooo`008P3oool2000000`0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06X0oooo000R0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
06/0oooo000R0?ooo`030000003oool0oooo00T0oooo0P00002X0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0J`3oool00280oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`2Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0K03oool00280oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0K@3oool00280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0K@3oool001P0oooo100000000`0A
4A40oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P00002a0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0KP3oool001X0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`800000]03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06l0
oooo000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P00002f0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0L03oool001X0oooo00<000000?ooo`3oool01@3o
ool400000;P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1a0?ooo`006P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1b0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0;/0oooo0P00000@0?ooo`030000003oool0oooo07<0oooo000J0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07@0
oooo000H0?ooo`80EEEE00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2n0?ooo`800000
2P3oool2000007L0oooo000R0?ooo`030000003oool0oooo0<00oooo0P0000050?ooo`<00000N@3o
ool00280oooo00<000000?ooo`3oool0`P3oool5000007`0oooo000R0?ooo`030000003oool0oooo
0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool200000?l0oooo
A@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o
0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}]
}, Open  ]],

Cell["\<\
The code clearly works, but a keen eye can see that the expected \
cosine oscillations are actually growing slowly with time, even at the \
relatively small step size of 0.02.\
\>", "Text"],

Cell["\<\
\t As already discussed, the Euler method is only first-order \
accurate. Nevertheless, the general methods discussed in this section also \
work for higher-order methods, such as the predictor-corrector code of the \
previous section.  Examples may be found in the exercises at the end of the \
section.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.4.6 The Numerical N-Body Problem: An Introduction \
to Molecular Dynamics",
  FontFamily->"Helvetica"]], "Subsubtitle",
  CellTags->{"i:54", "c:27"}],

Cell[TextData[{
  "One way that systems of ODEs arise in the physical sciences is in the \
description of the motion of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " interacting classical particles.  Newton  solved this problem for the \
case of two particles (the two-body problem) interacting via a central force. \
However, for three or more particles there is no general analytic solution, \
and numerical techniques are of great importance in understanding the \
motion."
}], "Text"],

Cell[TextData[{
  "\tIn the numerical method known as ",
  StyleBox["molecular dynamics",
    FontSlant->"Italic"],
  ", the coupled equations of motion for the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles are simply integrated forward in time using Newton's second law \
for each particle. There is nothing subtle about this - the numerical \
techniques learned in the previous sections are simply applied on a larger \
scale. The subtleties only arise when details such as  error accumulation, \
code efficiency, and the like must be considered."
}], "Text"],

Cell[TextData[{
  "\tBelow, we show how to use ",
  StyleBox["Mathematica's",
    FontSlant->"Italic"],
  " intrinsic function ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to numerically solve the following ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " body problem: For particles at positions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "1"], "(", "t", ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "2"], "(", "t", ")"}], TraditionalForm]]],
  ",\[Ellipsis],",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "N"], "(", "t", ")"}], TraditionalForm]]],
  ", the equations of motion are"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(m\_i\), " ", 
            FractionBox[
              RowBox[{\(\[DifferentialD]\^2\), 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}], \(\[DifferentialD]t\^2\),
              MultilineFunction->None]}], "=", 
          RowBox[{\(\[Sum]\+\(j = 1\[IndentingNewLine]
                j \[NotEqual] i\)\%N\), 
            RowBox[{
              SubscriptBox[
                StyleBox["F",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], \(i\ j\)], "(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"], "-", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "j"]}], ")"}]}]}], 
        TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(1.4.21)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["F",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(i\ j\)], TraditionalForm]]],
  " is the force between particles ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  ", ",
  StyleBox[" ",
    FontWeight->"Bold"],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`m\_i\)]],
  " is the mass of particle ",
  StyleBox["i",
    FontSlant->"Italic"],
  ".  To complete the problem, we must also specify initial conditions on \
position and velocity :"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "i"], "(", "0", ")"}], "=", 
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "io"]}], " ", ",", 
        FormBox[
          RowBox[{
            FractionBox[
              RowBox[{"\[DifferentialD]", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}], \(\[DifferentialD]t\),
              MultilineFunction->None], "=", 
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "io"]}],
          "TraditionalForm"], ",", 
        FormBox[\(i = 1,  ... , n\),
          "TraditionalForm"]}], TraditionalForm]]]], "NE4",
  CellTags->"(1.4.22)"],

Cell[TextData[{
  "The following module ",
  StyleBox["MDsol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solves this problem numerically:"
}], "Text"],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.49"],

Cell[BoxData[
    \(MDsol[z0_, time_]\  := \ 
      Module[{}, \[IndentingNewLine]npart\  = \ 
          Length[z0]/6; \[IndentingNewLine]r[i_, 
            t_]\  = \ {\(x[i]\)[t], \(y[i]\)[t], \(z[i]\)[
              t]}; \[IndentingNewLine]v[i_, 
            t_]\  = \ {\(vx[i]\)[t], \(vy[i]\)[t], \(vz[i]\)[
              t]}; \[IndentingNewLine]Z[t_] = 
          Flatten[Table[{r[i, t], v[i, t]}, {i, 1, 
                npart}]]; \[IndentingNewLine]f[t_]\  = \ 
          Flatten[Table[{v[i, 
                  t], \[IndentingNewLine]\((Sum[
                        F[i, j, r[i, t] - r[j, t]], {j, 1, 
                          i - 1}] + \[IndentingNewLine]Sum[
                        F[i, j, r[i, t] - r[j, t]], {j, i + 1, npart}])\)/
                  mass[\([i]\)]}, {i, 1, 
                npart}]]; \[IndentingNewLine]ODEs\  = \ 
          Flatten[Table[\(\(Z'\)[t]\)\ [\([n]\)] \[Equal] \(f[
                    t]\)[\([n]\)], {n, 1, 
                6*npart}]]; \[IndentingNewLine]ics\  = \ 
          Table[\(Z[0]\)[\([n]\)] \[Equal] z0[\([n]\)], {n, 1, 
              6*npart}]; \[IndentingNewLine]eqns\  = \ 
          Join[ODEs, ics]; \[IndentingNewLine]NDSolve[eqns, 
          Z[t], {t, 0, time}, MaxSteps \[Rule] 10^5]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.50"],

Cell[TextData[{
  "To understand what this module does, look at the last line. Here we see \
that ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to integrate a list of equations called eqns, that the equations \
involve a vector of unknown functions ",
  StyleBox["Z[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and that the equations are integrated from ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["t",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["0",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["t",
            FontSlant->"Plain"], "=", "time"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  The definition of ",
  StyleBox["Z[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be found a few lines higher in the module: it is a list of \
variables,",
  StyleBox["{r[i,t],v[i,t]}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["i",
    FontSlant->"Italic"],
  "th particle position vector  ",
  StyleBox["r[i,t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is defined in the second line as  having components ",
  StyleBox["{x[i][t],y[i][t],z[i][t]}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and  the velocity vector ",
  StyleBox["v[i,t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "has components ",
  StyleBox["{vx[i][t],vy[i][t],vz[i][t]}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  These functions use a notation we haven't seen before: the notation ",
  StyleBox["x[i][t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "means the same thing as",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["x[i,t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The reason we use the former and not the latter notation is due to a \
vagary of ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ": ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " likes to work on functions of one variable; otherwise it gets confused \
and thinks it is solving a PDE. The notation ",
  StyleBox["x[i][t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " fools ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " into thinking of ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as a function of a single argument, the time ",
  StyleBox["t",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe ",
  StyleBox["Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used in the definition of ",
  StyleBox["Z[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " because ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " works only on a simple list of unknown functions, without sublists. "
}], "Text"],

Cell[TextData[{
  "\tThe list ",
  StyleBox["eqns",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be seen to be a concatenation of a list of ODEs called ",
  StyleBox["ODEs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and a list of initial conditions called ",
  StyleBox["ics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The initial conditions are given as an argument to the module, in terms \
of a list ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  " of positions and velocities for each particle of the form"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["Flatten",
              FontFamily->"Courier"], 
            StyleBox["[",
              FontFamily->"Courier"], 
            RowBox[{
              StyleBox["{",
                FontWeight->"Plain"], 
              RowBox[{
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[\(1  o\),
                    FontWeight->"Plain"]], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                SubscriptBox[
                  StyleBox["v",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[\(1  o\),
                    FontWeight->"Plain"]], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[\(2  o\),
                    FontWeight->"Plain"]], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                SubscriptBox[
                  StyleBox["v",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[\(2  o\),
                    FontWeight->"Plain"]], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["...",
                  FontWeight->"Plain"]}], 
              StyleBox["}",
                FontWeight->"Plain"]}], 
            StyleBox["]",
              FontFamily->"Courier"]}]}], TraditionalForm]],
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is included explicitly here to ensure that ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  " is a simple list, not an array."
}], "Text"],

Cell[TextData[{
  "\tThe acceleration function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", "t", ")"}], TraditionalForm]]],
  " is defined as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], "=", " ", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox[
                StyleBox["v",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "1"], ",", 
              RowBox[{\(1\/m\_1\), 
                RowBox[{\(\[Sum]\+\(j = 2\)\%N\), 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["F",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], \(1  j\)], "(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "1"], "-", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "j"]}], ")"}]}]}], ",", 
              SubscriptBox[
                StyleBox["v",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "2"], ",", 
              RowBox[{\(1\/m\_2\), 
                RowBox[{\(\[Sum]\+\(j = 1\[IndentingNewLine]
                      j \[NotEqual] 2\)\%N\), 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["F",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], \(2  j\)], "(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "2"], "-", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "j"]}], ")"}]}]}], ",", 
              "..."}], "}"}], " "}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(1.4.23)"],

Cell[TextData[{
  "and the result is flattened in order for each element to correspond to the \
proper element in ",
  StyleBox["Z",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".   The fact that the sum over individual forces must neglect the self\
\[Dash]force term  ",
  Cell[BoxData[
      \(TraditionalForm\`j = i\)]],
  " requires us to write the sum as two pieces, one from ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`i - 1\)]],
  ", and the other from ",
  Cell[BoxData[
      \(TraditionalForm\`j = i + 1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t The value of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ", called ",
  StyleBox["npart",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the module (because ",
  StyleBox["N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a reserved function name),  is determined in terms of the length of \
the initial condition vector",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["z0",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", in the first line of the code."
}], "Text"],

Cell["\<\
\tFinally, the module itself is given no internal variables (the \
internal-variable list is the null set {}), so that we can examine each \
variable if we wish. \
\>", "Text"],

Cell[TextData[{
  "\tIn order to use this code, we must first define a force function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["F",
                FontSlant->"Plain"], 
              StyleBox[\(i\ j\),
                FontWeight->"Plain"]],
            FontWeight->"Bold"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  ". Let's consider the gravitational ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " body problem, where the force obeys Newton's law of gravitation:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["F",
                  FontSlant->"Plain"], 
                StyleBox[\(i\ j\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "=", 
          RowBox[{\(-G\), " ", \(m\_i\), " ", \(m\_j\), " ", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["/",
                FontWeight->"Plain"], 
              StyleBox[\(r\^3\),
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(1.4.24)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"G", "=", 
          RowBox[{\(6.67\ \[Cross]10\^\(-11\)\), " ", \(m\^3/kg\), " ", 
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], "2"]}]}], TraditionalForm]]],
  ".  We can define this force using the command"
}], "Text"],

Cell[BoxData[
    \(F[i_, j_, r_]\  := \ \(-mass[\([i]\)]\)\ mass[\([j]\)] 
        r/\(\(\((r . r)\)^\((3/2)\)\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.51"],

Cell[TextData[{
  "Here mass is a length-",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " list of the masses of all particles, and we have set the gravitational \
force constant ",
  Cell[BoxData[
      \(TraditionalForm\`G = 1\)]],
  " for simplicity. "
}], "Text"],

Cell[TextData[{
  "\tLet's apply this molecular dynamics code to the simple problem of two \
gravitating bodies orbiting around one another. For initial conditions we \
will choose ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "1"], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["v",
            FontWeight->"Bold",
            FontSlant->"Plain"], "1"], TraditionalForm]]],
  " = 0, and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  "=(1,0,0), ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["v",
            FontWeight->"Bold",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  " = (0,0.5,0). Thus, the list of initial conditions is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z0\  = \ Flatten[{{0, 0, 0, 0, 0, 0}, {1, 0, 0, 0, 0.5, 0}}]\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 1.52"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5`, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
\t Also, we must not forget to assign masses to the two particles. \
Let's take one mass 3 times that of the other:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mass\  = \ {3, 1}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.53"],

Cell[BoxData[
    \({3, 1}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we run the code for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 4\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s = MDsol[z0, 4]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.54"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{\(\(x[1]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(y[1]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(z[1]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(vx[1]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(vy[1]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(vz[1]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(x[2]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(y[2]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(z[2]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(vx[2]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(vy[2]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}], ",", 
          RowBox[{\(\(vz[2]\)[t]\), "\[Rule]", 
            RowBox[{
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a list of interpolating functions for each component of \
position and velocity of the two particles.  We can do whatever we wish with \
these - perform more analysis, make plots, etc.  One thing that is fun to do \
(but is difficult to show in a textbook)  is to make an animation of the \
motion. An example is displayed in the electronic version of the book, \
plotting the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " positions of the two masses at a series of separate times. (As discussed \
in Chapter ",
  ButtonBox["9",
    ButtonData:>"Chapter9.nb",
    ButtonStyle->"Hyperlink"],
  ", the animation can be viewed by selecting the plot cells and choosing ",
  StyleBox["Animate Selected Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " from the ",
  StyleBox["Format",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " menu.) Only the command that creates the animation is given in the hard \
copy, in Cell ",
  ButtonBox["1.55",
    ButtonData:>"Cell 1.55",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[
          Table[{\(x[n]\)[t], \(y[n]\)[t]} /. %[\([1]\)], {n, 1, npart}], 
          PlotStyle \[Rule] PointSize[0.015], AspectRatio \[Rule] 1, 
          PlotRange \[Rule] {{\(- .1\), 1.2}, {\(- .1\), 1.2}}], {t, 0, 
          4,  .1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.55"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.07692 .07692 Mdot
.84615 .07692 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006_ooool3o`000?oooooo4_ooool3
o`0003Oooooo000Iooooo`Go0000ooooool@ooooo`Go0000=_ooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02Oooool5o`0000_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool5o`0000_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
000Jooooo`?o0000=Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0cooooo`?o0000=oooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo0000
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?ooooooBoooool00005o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo
Boooool00005o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0oooooom;ooooo`00
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood_o
oooo00001Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0
003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000001oooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?oo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`?o0000oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`3ooooood_ooooo
00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0
003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Aooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`?o0000oooooom;ooooo`00
4oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooBoooool0017ooooo00?oEEEEofIVI_l000001oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2
o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.08079 .07699 Mdot
.83454 .11519 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool3o`000?ooooooBoooool0
01[ooooo1Ol0003ooooood[ooooo003oo`0006Wo0000000=ooooo`03o`000?oooooooooo00[ooooo
1Ol0000:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool001_ooooo0ol0
000dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
ool=ooooo`?o0000>oooool001_ooooo00?o0000ooooooooool0ooooool<ooooo`Go0000>_ooool0
01_ooooo0_l0003oooooo`gooooo1Ol0000jooooo`006oooool00ol0003oooooooooo`3oooooo`co
oooo1Ol0000jooooo`006oooool00ol0003oooooooooo`3oooooo`gooooo0ol0000kooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_o
oooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo0000
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool0017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.0927 .07747 Mdot
.79882 .15221 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`02
ooooo`?o0000oooooom6ooooo`006oooool01?l0003oooooooooooooool5o`000?ooooooAOooool0
0?oo0000JOl0000000gooooo00?o0000ooooooooool02oooool01?l0003oooooooooooooool5o`00
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`006oooool00ol0003o
ooooooooo`02ooooo`?o0000;oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
ooooo`?o0000B?ooool001_ooooo00?o0000ooooooooool0o_ooool5o`0004Oooooo000Kooooo`03
o`000?oooooooooo0?kooooo1Ol00017ooooo`006oooool2o`000?oooooo1Ol00017ooooo`006ooo
ool00ol0003oooooooooo`3oooooo`?o0000B?ooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`0000Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooo
od_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;oooo
o`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003ooooood_o
oooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?ooooooBoooool00005
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool0017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
Boooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000C
ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom;ooooo`004Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o
0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.11369 .07893 Mdot
.73586 .18627 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo00Wooooo0ol0003oooooocoooooo003oo`0006Wo
0000000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool5o`0000cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool02?ooool5o`0002Oooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`09
ooooo`?o0000ooooooloooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3Xooooo`?o0000Goooool001_ooooo00?o0000oooo
ooooool0ioooool5o`0005kooooo000Kooooo`03o`000?oooooooooo0>Oooooo1Ol0001Nooooo`00
6oooool00ol0003oooooooooo`3Wooooo`Go0000G_ooool001_ooooo0_l0003Yooooo`?o0000Gooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood_ooooo
00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom;oooo
o`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?ooooooBoooool00005o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?oo
ooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3o
oooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2
o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`004Oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000oooooooo
ool01Oooool3o`000?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool0
01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Aooooo`03
oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.14619 .08246 Mdot
.63836 .21416 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
1_l0000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`006oooool00ol0003oooooooooo`0Dooooo`Go00006oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo01Cooooo1Ol0003o
oooooc;ooooo000Kooooo`03o`000?oooooooooo01Gooooo0ol0003ooooooc?ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0aOooool3o`0008;ooooo000Koooo
o`03o`000?oooooooooo0<Cooooo1Ol00021ooooo`006oooool00ol0003oooooooooo`34ooooo`Go
0000POooool001_ooooo00?o0000ooooooooool0a?ooool5o`00087ooooo000Kooooo`03o`000?oo
oooooooo0<Gooooo0ol00022ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood_ooooo
00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom;oooo
o`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?ooooooBoooool00005o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?oo
ooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3o
oooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2
o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`004Oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000oooooooo
ool01Oooool3o`000?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool0
01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Aooooo`03
oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.19677 .09121 Mdot
.4866 .22636 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Oooooo0ol0003o
ooooob7ooooo000Kooooo`03o`000?oooooooooo02Kooooo1Ol0003oooooob3ooooo000Kooooo`03
o`000?oooooooooo02Kooooo1Ol0003oooooob3ooooo000Kooooo`03o`000?oooooooooo02Kooooo
1Ol0003oooooob3ooooo000Kooooo`03o`000?oooooooooo02Oooooo0ol0003oooooob7ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`2?ooooo`?o0000^?ooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08kooooo1Ol0002gooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0S_ooool5o`000;Oooooo00001Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0008kooooo1Ol0002gooooo`0000Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Soooool3o`000;Sooooo
00001Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.2524 .15674 Mdot
.31973 .06825 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`1Cooooo`?o0000m?ooool001_ooooo00?o0000ooooooooool0
D_ooool5o`000??ooooo000Kooooo`03o`000?oooooooooo05;ooooo1Ol0003cooooo`006oooool0
0ol0003oooooooooo`1Booooo`Go0000loooool001_ooooo00?o0000ooooooooool0Doooool3o`00
0?Cooooo003oo`0006Wo0000000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo000Kooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0fooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003ooooo
odcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo03_ooooo0ol0
003oooooo`gooooo000Kooooo`;o0000>oooool5o`000?oooooo3?ooool001_ooooo00?o0000oooo
ooooool0>_ooool5o`000?oooooo3?ooool001_ooooo00?o0000ooooooooool0>_ooool5o`000?oo
oooo3?ooool001_ooooo00?o0000ooooooooool0>oooool3o`000?oooooo3Oooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.1761 .17877 Mdot
.54862 .04063 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0:Gooooo0ol0002Rooooo`006oooool2o`000:Gooooo1Ol0002Qooooo`006oooool0
0ol0003oooooooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`0Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go000000Co<S8bo`000?l@
413oc<c<8_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`0:oooool4o`000003oa0@4?oooooooooo03Cooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A402?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`0Qooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Go000000CoMgMgoooo
oonHV9So8B4Q8_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@4008oooo
o`Co00000oooool00ol0003oooooooooo`0Pooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000002gooooo00?o0000ooooooooool0=_ooool001_ooooo00?o0000
ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h08ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00008oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Rooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b02gooooo00?o0000ooooooooool0
=_ooool001_ooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool08_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00008oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c00Rooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<02go
oooo00?o0000ooooooooool0=_ooool001_ooooo00?o0000ooooooooool0:Oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool08Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000008oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEE
ohN7Qoooool09?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@400]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41008oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000008oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P09?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_oooooo^[Zjo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool08_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@8_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0[ooooo`03oeEEEOmVIVKo000003So
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00ool0001Yo`0000003Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`006oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0=_ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`0Pooooo`?o0000oooooolXooooo`006ooo
ool00ol0003oooooooooo`0Oooooo`Go0000oooooolWooooo`006oooool00ol0003oooooooooo`0O
ooooo`Go0000oooooolWooooo`006oooool00ol0003oooooooooo`0Oooooo`Go0000oooooolWoooo
o`006oooool00ol0003oooooooooo`0Pooooo`?o0000oooooolXooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`?o0000oooooom;ooooo`0000Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood_ooooo0000
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`Go00001_oo
ool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03
o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003ooooood_ooooo00001Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodco
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooBoooool001?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`00
4Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.13321 .18498 Mdot
.67731 .06046 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Co410@oooooooooooooooo0ol00009ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00?oMgMgoiRHV?ooool01Ol00008ooooo`05o`000?nj
^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00?ok^k^oc8b<_l000001Ol0
0008ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hooooo`006ooo
ool00ol0003oooooooooo`3Booooo`Go0000Loooool001_ooooo00?o0000ooooooooool0doooool3
o`0007Cooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo003oo`0006Wo0000000=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo000Kooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodco
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`0@ooooo`?o0000oooooolhoooo
o`006oooool00ol0003oooooooooo`0?ooooo`Go0000oooooolgooooo`006oooool00ol0003ooooo
ooooo`0?ooooo`Go0000oooooolgooooo`006oooool00ol0003oooooooooo`0?ooooo`Go0000oooo
oolgooooo`006oooool00ol0003oooooooooo`0@ooooo`?o0000oooooolhooooo`006oooool2o`00
0?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
oooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo1Ol00006
ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?ooooooBoooool00005
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodco
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?oooooo
C?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom;ooooo`00
4oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o
0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003ooooo
odcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.10517 .18759 Mdot
.7614 .09107 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?;ooooo0ol0001E
ooooo`006oooool00ol0003oooooooooo`3aooooo`Go0000E?ooool001_ooooo00?o0000oooooooo
ool0lOooool5o`0005Cooooo000Kooooo`03o`000?oooooooooo0?7ooooo1Ol0001Dooooo`006ooo
ool00ol0003oooooooooo`3booooo`?o0000EOooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003ooooo
odcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo00Kooooo0ol0003ooooood;ooooo000Koooo
o`03o`000?oooooooooo00Gooooo1Ol0003ooooood7ooooo000Kooooo`03o`000?oooooooooo00Go
oooo1Ol0003ooooood7ooooo000Kooooo`03o`000?oooooooooo00Gooooo1Ol0003ooooood7ooooo
000Kooooo`;o00001oooool3o`000?oooooo@_ooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.08756 .18863 Mdot
.81426 .12643 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3oooooo`Kooooo0ol00012ooooo`006ooo
ool00ol0003oooooooooo`3oooooo`Gooooo1Ol00011ooooo`006oooool00ol0003oooooooooo`3o
ooooo`Gooooo1Ol00011ooooo`006oooool00ol0003oooooooooo`3oooooo`Gooooo1Ol00011oooo
o`006oooool00ol0003oooooooooo`3oooooo`Kooooo0ol00012ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`03
o`000?ooooooB?ooool001_ooooo00?o0000ooooool000001?l0003oooooodOooooo000Kooooo`03
o`000?oooooo000000Co0000oooooom7ooooo`006oooool00ol0003oooooo`000004o`000?oooooo
Aoooool001_ooooo0_l000001?oooooo0000o`000?l0003oooooodSooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooo
od_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`00
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_o
oooo00001Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`00
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooo
od_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0017ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`00
4oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.07854 .18891 Mdot
.8413 .16404 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3oooooo`oo
oooo0ol0000iooooo`006oooool00ol0003oooooooooo`3oooooo`kooooo1Ol0000hooooo`006ooo
ool00ol0003oooooooooo`3oooooo`kooooo1Ol0000hooooo`006oooool00ol0003oooooooooo`3o
ooooo`kooooo1Ol0000hooooo`006oooool00ol0003oooooooooo`3oooooo`oooooo0ol0000ioooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`?o0000oooooom;ooooo`006_ooool5o`000?ooooooB_ooool001[ooooo
1Ol0003ooooood[ooooo000Jooooo`Go0000oooooom:ooooo`006oooool3o`000?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_o
oooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo0000
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool0017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.07739 .18893 Mdot
.84475 .20244 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006_ooool3o`000?ooooooC?ooool001Wooooo1Ol0003ooooood_o
oooo000Iooooo`Go0000oooooom;ooooo`006Oooool5o`000?ooooooBoooool001[ooooo0ol0003o
oooooa;ooooo0ol0000gooooo`006oooool00ol0003oooooooooo`3ooooooa3ooooo1Ol0000foooo
o`006oooool00ol0003oooooooooo`3ooooooa3ooooo1Ol0000fooooo`006oooool00ol0003ooooo
ooooo`3ooooooa3ooooo1Ol0000fooooo`006oooool00ol0003oooooooooo`3ooooooa7ooooo0ol0
000gooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_o
oooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo0000
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool0017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.08402 .18909 Mdot
.82487 .24042 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool001_ooooo1Ol0003oooooodWo
oooo000Kooooo`Go0000oooooom9ooooo`006oooool5o`000?ooooooBOooool001_ooooo1?l0003o
oooood[ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo0000
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?ooooooBoooool00005o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo
Boooool00005o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo0?oooooo2Oooool3o`0003oooooo00001Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Sooooo1Ol0000nooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`3oooooo`Sooooo1Ol0000nooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooo`Sooooo1Ol0000noooo
o`006oooool00ol0003oooooooooo`3oooooo`Wooooo0ol0000oooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_o
oooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo0000
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool0017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.09894 .18984 Mdot
.7801 .27664 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`04ooooo`?o0000oooooom4oooo
o`006oooool00ol0003oooooooooo`03ooooo`Go0000oooooom3ooooo`006oooool00ol0003ooooo
ooooo`03ooooo`Go0000oooooom3ooooo`006oooool2o`0000Cooooo1Ol0003ooooood?ooooo000K
ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodCooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0n?ooool3o`00
04oooooo000Kooooo`03o`000?oooooooooo0?Oooooo1Ol0001>ooooo`006oooool00ol0003ooooo
ooooo`3gooooo`Go0000C_ooool001_ooooo00?o0000ooooooooool0moooool5o`0004kooooo000K
ooooo`03o`000?oooooooooo0?Sooooo0ol0001?ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.12358 .19186 Mdot
.70619 .30904 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo00gooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00cooooo
1Ol0003ooooooc[ooooo000Kooooo`;o00003Oooool5o`000?oooooo>_ooool001_ooooo00?o0000
ooooooooool03?ooool5o`000?oooooo>_ooool001_ooooo00?o0000ooooooooool03Oooool3o`00
0?oooooo>oooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0g_ooool3o`0006Wooooo000Kooooo`;o0000g_ooool5o`0006Sooooo000K
ooooo`03o`000?oooooooooo0=gooooo1Ol0001Xooooo`006oooool00ol0003oooooooooo`3Moooo
o`Go0000J?ooool001_ooooo00?o0000ooooooooool0g_ooool3o`0006Wooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.16125 .19662 Mdot
.59317 .33322 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool06_ooool3o`000?oooooo
;_ooool001_ooooo0_l0000Jooooo`Go0000ooooool]ooooo`006oooool00ol0003oooooooooo`0I
ooooo`Go0000ooooool]ooooo`006oooool00ol0003oooooooooo`0Iooooo`Go0000ooooool]oooo
o`006oooool00ol0003oooooooooo`0Jooooo`?o0000ooooool^ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0]Oooool3o`0009;ooooo000Kooooo`03o`000?oooooooooo0;Co
oooo1Ol0002Aooooo`006oooool00ol0003oooooooooo`2dooooo`Go0000TOooool001_ooooo00?o
0000ooooooooool0]?ooool5o`00097ooooo000Kooooo`03o`000?oooooooooo0;Gooooo0ol0002B
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.22259 .20985 Mdot
.40916 .33198 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0<?ooool3o`000?oooooo6?ooool001_ooooo00?o0000ooooooooool0;ooo
ool5o`000?oooooo5oooool001_ooooo00?o0000ooooooooool0;oooool5o`000?oooooo5oooool0
01_ooooo00?o0000ooooooooool0;oooool5o`000?oooooo5oooool001_ooooo00?o0000oooooooo
ool0<?ooool3o`000?oooooo6?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0Loooool3o`000=Cooooo000Kooooo`03o`000?oooooooooo07;o
oooo1Ol0003Cooooo`006oooool00ol0003oooooooooo`1booooo`Go0000doooool001_ooooo00?o
0000ooooooooool0L_ooool5o`000=?ooooo000Kooooo`03o`000?oooooooooo07?ooooo0ol0003D
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.21827 .28127 Mdot
.42213 .15618 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0N?ooool3o`000<oooooo000Kooooo`;o0000N?ooool5
o`000<kooooo000Kooooo`03o`000?oooooooooo07Oooooo1Ol0003>ooooo`006oooool00ol0003o
ooooooooo`1gooooo`Go0000c_ooool001_ooooo00?o0000ooooooooool0N?ooool3o`000<oooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood_o
oooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0;oooool3o`000?oooooo6Oooool001_ooooo00?o
0000ooooooooool0;_ooool5o`000?oooooo6?ooool001_ooooo00?o0000ooooooooool0;_ooool5
o`000?oooooo6?ooool001_ooooo00?o0000ooooooooool0;_ooool5o`000?oooooo6?ooool001_o
oooo00?o0000ooooooooool0;oooool3o`000?oooooo6Oooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.15884 .29361 Mdot
.60039 .15762 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0^?ooool3o`0008oooooo000Kooooo`;o0000^?ooool5
o`0008kooooo000Kooooo`03o`000?oooooooooo0;Oooooo1Ol0002>ooooo`006oooool00ol0003o
ooooooooo`2gooooo`Go0000S_ooool001_ooooo00?o0000ooooooooool0^?ooool3o`0008oooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood_o
oooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`0Iooooo`?o0000ooooool_ooooo`00
6oooool00ol0003oooooooooo`0Hooooo`Go0000ooooool^ooooo`006oooool00ol0003ooooooooo
o`0Hooooo`Go0000ooooool^ooooo`006oooool00ol0003oooooooooo`0Hooooo`Go0000ooooool^
ooooo`006oooool00ol0003oooooooooo`0Iooooo`?o0000ooooool_ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.122 .29816 Mdot
.71091 .18245 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3Pooooo`?o0000Ioooool001_ooooo00?o0000ooooooooool0goooool5o`0006Kooooo000K
ooooo`03o`000?oooooooooo0=oooooo1Ol0001Vooooo`006oooool00ol0003oooooooooo`3Ooooo
o`Go0000I_ooool001_ooooo00?o0000ooooooooool0h?ooool3o`0006Oooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood_o
oooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool03?ooool3o`000?oooooo??oo
ool001_ooooo00?o0000ooooooooool02oooool5o`000?oooooo>oooool001_ooooo00?o0000oooo
ooooool02oooool5o`000?oooooo>oooool001_ooooo00?o0000ooooooooool02oooool5o`000?oo
oooo>oooool001_ooooo00?o0000ooooooooool03?ooool3o`000?oooooo??ooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.09794 .30008 Mdot
.78311 .21513 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?Wooooo0ol0001>ooooo`006oooool00ol0003oooooooooo`3hoooo
o`Go0000COooool001_ooooo00?o0000ooooooooool0n?ooool5o`0004gooooo000Kooooo`03o`00
0?oooooooooo0?Sooooo1Ol0001=ooooo`006oooool00ol0003oooooooooo`3iooooo`?o0000C_oo
ool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood_o
oooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool00oooool3o`000?ooooooAOoo
ool001_ooooo00?o0000ooooooooool00_ooool5o`000?ooooooA?ooool001_ooooo00?o0000oooo
ooooool00_ooool5o`000?ooooooA?ooool001_ooooo00?o0000ooooooooool00_ooool5o`000?oo
ooooA?ooool001_ooooo00?o0000ooooooooool00oooool3o`000?ooooooAOooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.08348 .30078 Mdot
.82649 .25149 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000nooooo`006oooool00ol0003ooooo
ooooo`3oooooo`Wooooo1Ol0000mooooo`006oooool00ol0003oooooooooo`3oooooo`Wooooo1Ol0
000mooooo`006oooool00ol0003oooooooooo`3oooooo`Wooooo1Ol0000mooooo`006oooool00ol0
003oooooooooo`3oooooo`[ooooo0ol0000nooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo000Kooooo`Go0000oooooom9oooo
o`006oooool5o`000?ooooooBOooool001_ooooo1Ol0003oooooodWooooo000Kooooo`Co0000oooo
oom:ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_o
oooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo0000
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool0017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.07727 .30093 Mdot
.8451 .28953 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooooa7ooooo0ol0000goooo
o`006oooool00ol0003oooooooooo`3ooooooa3ooooo1Ol0000fooooo`006oooool00ol0003ooooo
ooooo`3ooooooa3ooooo1Ol0000fooooo`006oooool00ol0003oooooooooo`3ooooooa3ooooo1Ol0
000fooooo`006_ooool3o`000?oooooo4_ooool3o`0003Oooooo000Iooooo`Go0000oooooom;oooo
o`006Oooool5o`000?ooooooBoooool001Wooooo1Ol0003ooooood_ooooo000Jooooo`?o0000oooo
oom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_o
oooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo0000
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool0017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.07884 .30095 Mdot
.84041 .32792 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`?o0000oooooom;ooooo`006_ooool5o`00
0?ooooooB_ooool001[ooooo1Ol0003ooooood[ooooo000Jooooo`Go0000oooooom:ooooo`006ooo
ool3o`000?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3oooooo`oooooo0ol0
000iooooo`006oooool00ol0003oooooooooo`3oooooo`kooooo1Ol0000hooooo`006oooool00ol0
003oooooooooo`3oooooo`kooooo1Ol0000hooooo`006oooool00ol0003oooooooooo`3oooooo`ko
oooo1Ol0000hooooo`006oooool00ol0003oooooooooo`3oooooo`oooooo0ol0000iooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooood_o
oooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo
Boooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooood_ooooo00001Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood_ooooo0000
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool0017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood_ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.08828 .30126 Mdot
.81207 .36545 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo00?o0000oooooom8
ooooo`006oooool00ol0003oooooo`000004o`000?ooooooAoooool001_ooooo00?o0000ooooool0
00001?l0003oooooodOooooo000Kooooo`03o`000?oooooo000000Co0000oooooom7ooooo`006ooo
ool2o`000004ooooool0003o0000o`000?ooooooB?ooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3oooooo`Gooooo0ol00013ooooo`006oooool00ol0003ooooo
ooooo`3oooooo`Cooooo1Ol00012ooooo`006oooool00ol0003oooooooooo`3oooooo`Cooooo1Ol0
0012ooooo`006oooool00ol0003oooooooooo`3oooooo`Cooooo1Ol00012ooooo`006oooool00ol0
003oooooooooo`3oooooo`Gooooo0ol00013ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`00
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_o
oooo00001Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`00
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000
oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooo
od_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0017ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`00
4oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004Oooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.1064 .30236 Mdot
.75772 .40063 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo00Oooooo0ol0003o
oooood7ooooo000Kooooo`03o`000?oooooooooo00Kooooo1Ol0003ooooood3ooooo000Kooooo`03
o`000?oooooooooo00Kooooo1Ol0003ooooood3ooooo000Kooooo`03o`000?oooooooooo00Kooooo
1Ol0003ooooood3ooooo000Kooooo`;o00002?ooool3o`000?oooooo@Oooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?oooooo
C?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooo
od_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`3`ooooo`?o0000Eoooool001_ooooo00?o0000oooooooo
ool0koooool5o`0005Kooooo000Kooooo`03o`000?oooooooooo0>oooooo1Ol0001Fooooo`006ooo
ool00ol0003oooooooooo`3_ooooo`Go0000E_ooool001_ooooo00?o0000ooooooooool0l?ooool3
o`0005Oooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.13508 .3051 Mdot
.67169 .43087 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool04Oooool3o`000?oooooo=oooool001_ooooo00?o0000oooooooo
ool04?ooool5o`000?oooooo=_ooool001_ooooo00?o0000ooooooooool04?ooool5o`000?oooooo
=_ooool001_ooooo0_l0000Aooooo`Go0000oooooolfooooo`006oooool00ol0003oooooooooo`0A
ooooo`?o0000oooooolgooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?oooooo
C?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooo
od_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2
o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0dOooool3o`0007Kooooo000Kooooo`03
o`000?oooooooooo0=3ooooo1Ol0001eooooo`006oooool00ol0003oooooooooo`3@ooooo`Go0000
MOooool001_ooooo00?o0000ooooooooool0d?ooool5o`0007Gooooo000Kooooo`03o`000?oooooo
oooo0=7ooooo0ol0001fooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.17902 .31163 Mdot
.53986 .44973 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0000Rooooo`?o0000oooo
oolWooooo`006oooool00ol0003oooooooooo`0Pooooo`Go0000oooooolVooooo`006oooool00ol0
003oooooooooo`0Pooooo`Go0000oooooolVooooo`006oooool00ol0003oooooooooo`0Pooooo`Go
0000oooooolVooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000oooooolWooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?oooooo
C?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooo
od_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2
o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`2Rooooo`?o0000YOooool001_ooooo00?o0000ooooooooool0XOoo
ool5o`000:Cooooo000Kooooo`03o`000?oooooooooo0:7ooooo1Ol0002Tooooo`006oooool00ol0
003oooooooooo`2Qooooo`Go0000Y?ooool001_ooooo00?o0000ooooooooool0X_ooool3o`000:Go
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.25934 .33692 Mdot
.29889 .41233 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`0mooooo`?o0000ooooool;ooooo`006ooo
ool00ol0003oooooooooo`0looooo`Go0000ooooool:ooooo`006oooool00ol0003oooooooooo`0l
ooooo`Go0000ooooool:ooooo`006oooool00ol0003oooooooooo`0looooo`Go0000ooooool:oooo
o`006oooool00ol0003oooooooooo`0mooooo`?o0000ooooool;ooooo`006oooool2o`000?oooooo
C?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooo
od_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo04cooooo0ol0003kooooo`006oooool00ol0
003oooooooooo`1;ooooo`Go0000n_ooool001_ooooo00?o0000ooooooooool0Boooool5o`000?[o
oooo000Kooooo`03o`000?oooooooooo04_ooooo1Ol0003jooooo`006oooool00ol0003ooooooooo
o`1<ooooo`?o0000noooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.19333 .39939 Mdot
.49695 .26337 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo09?ooooo0ol0002dooooo`006oooool00ol0003o
ooooooooo`2Booooo`Go0000/oooool001_ooooo00?o0000ooooooooool0T_ooool5o`000;?ooooo
000Kooooo`03o`000?oooooooooo09;ooooo1Ol0002cooooo`006oooool2o`0009Cooooo0ol0002d
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?oo
ooooBoooool00005o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo02Kooooo0ol0003ooooo
ob;ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`0Uooooo`Go0000oooooolQooooo`006oooool00ol0003oooooooooo`0Uooooo`Go
0000oooooolQooooo`006oooool00ol0003oooooooooo`0Uooooo`Go0000oooooolQooooo`006ooo
ool00ol0003oooooooooo`0Vooooo`?o0000oooooolRooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.14407 .40766 Mdot
.64471 .27702 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0<Sooooo0ol0001oooooo`006oooool00ol0003oooooooooo`37ooooo`Go0000O_ooool001_ooooo
00?o0000ooooooooool0aoooool5o`0007kooooo000Kooooo`03o`000?oooooooooo0<Oooooo1Ol0
001nooooo`006oooool00ol0003oooooooooo`38ooooo`?o0000Ooooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?oo
ooooBoooool00005o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`0Dooooo`?o0000ooooooldooooo`006oooool00ol0003oooooooooo`0Cooooo`Go0000oooo
oolcooooo`006oooool00ol0003oooooooooo`0Cooooo`Go0000oooooolcooooo`006oooool00ol0
003oooooooooo`0Cooooo`Go0000oooooolcooooo`006oooool00ol0003oooooooooo`0Dooooo`?o
0000ooooooldooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.1123 .41102 Mdot
.74002 .3054 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0j_ooool3o`0005gooooo000Kooooo`03o`000?oooooooooo0>Wo
oooo1Ol0001Looooo`006oooool00ol0003oooooooooo`3Yooooo`Go0000G?ooool001_ooooo0_l0
003Zooooo`Go0000G?ooool001_ooooo00?o0000ooooooooool0j_ooool3o`0005gooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?oo
ooooBoooool00005o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooBoooool00005
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo00Wooooo0ol0003oooooocoooooo000K
ooooo`03o`000?oooooooooo00Sooooo1Ol0003oooooockooooo000Kooooo`03o`000?oooooooooo
00Sooooo1Ol0003oooooockooooo000Kooooo`03o`000?oooooooooo00Sooooo1Ol0003oooooocko
oooo000Kooooo`03o`000?oooooooooo00Wooooo0ol0003oooooocoooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooBoooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.09186 .41241 Mdot
.80136 .33969 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?oooooo0Oooool3o`0004Oooooo000Kooooo`03o`000?oooooooooo0?oooooo1Ol00016
ooooo`006oooool00ol0003oooooooooo`3oooooo`Go0000A_ooool001_ooooo00?o0000oooooooo
ool0ooooool5o`0004Kooooo000Kooooo`;o0000ooooool2ooooo`?o0000Aoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
Boooool00005oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`04o`000?ooooooooooooooo`?o0000oooooom7ooooo`006oooool00ol0003oooooooooo`05
o`000?ooooooA_ooool001_ooooo00?o0000ooooooooool01Ol0003oooooodKooooo000Kooooo`03
o`000?oooooooooo00Go0000oooooom6ooooo`006oooool01?l0003oooooooooooooool3o`000?oo
ooooAoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003ooooo
odcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool0
0005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?oo
ooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom;oooo
o`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`00
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo
00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBooo
ool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.08041 .41285 Mdot
.8357 .37682 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3oooooo`go
oooo0ol0000kooooo`006oooool00ol0003oooooooooo`3oooooo`cooooo1Ol0000jooooo`0000Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0ooooool<ooooo`Go0000>_ooool00005ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`cooooo
1Ol0000jooooo`0000Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003ooooo
ooooo`3oooooo`gooooo0ol0000kooooo`0000Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooo
od_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`?o0000oooooom;ooooo`006_ooool5o`000?ooooooB_ooool001[o
oooo1Ol0003ooooood[ooooo000Jooooo`Go0000oooooom:ooooo`006oooool3o`000?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?ooooooBooo
ool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`00
0?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom;
ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?o
oooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.07697 .41291 Mdot
.84601 .41512 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006_ooool3o`000?ooooooC?ooool001Wooooo1Ol0003ooooo
oa7ooooo0ol0000gooooo`006Oooool5o`000?oooooo4?ooool5o`0003Kooooo000Iooooo`Go0000
ooooool@ooooo`Go0000=_ooool001[ooooo0ol0003ooooooa7ooooo1Ol0000fooooo`006oooool2
o`000?oooooo4_ooool3o`0003Oooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?ooooooBooo
ool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`00
0?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom;
ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?o
oooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.08127 .41298 Mdot
.8331 .45335 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool3o`000?ooooooBoooool001[ooooo1Ol0003ooooo
od[ooooo000Jooooo`Go0000oooooom:ooooo`006_ooool5o`000?ooooooB_ooool001_ooooo0ol0
003ooooood_ooooo000Kooooo`;o0000oooooom<ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0ooooool<ooooo`?o0000??ooool001_ooooo00?o0000ooooooooool0ooooool;
ooooo`Go0000>oooool001_ooooo00?o0000ooooooooool0ooooool;ooooo`Go0000>oooool001_o
oooo00?o0000ooooooooool0ooooool;ooooo`Go0000>oooool001_ooooo00?o0000ooooooooool0
ooooool<ooooo`?o0000??ooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?ooooooBooo
ool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`00
0?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom;
ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?o
oooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0
003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.09365 .4135 Mdot
.79596 .49026 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`02ooooo`?o0000oooooom6
ooooo`006oooool01?l0003oooooooooooooool5o`000?ooooooAOooool001_ooooo00Co0000oooo
oooooooooooo1Ol0003oooooodGooooo000Kooooo`04o`000?ooooooooooooooo`Go0000oooooom5
ooooo`006oooool00ol0003oooooooooo`02ooooo`?o0000oooooom6ooooo`006oooool2o`000?oo
ooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?kooooo0ol00019ooooo`006oooool00ol0003oooooooooo`3mooooo`Go0000B?ooool001_o
oooo00?o0000ooooooooool0oOooool5o`0004Sooooo000Kooooo`03o`000?oooooooooo0?gooooo
1Ol00018ooooo`006oooool00ol0003oooooooooo`3nooooo`?o0000BOooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;ooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00
0?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom;
ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0
oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
Boooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodco
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.11521 .41505 Mdot
.7313 .52408 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo00[ooooo0ol0003oooooockooooo000Kooooo`03o`000?oooooooooo00Wo
oooo1Ol0003oooooocgooooo000Kooooo`03o`000?oooooooooo00Wooooo1Ol0003oooooocgooooo
000Kooooo`03o`000?oooooooooo00Wooooo1Ol0003oooooocgooooo000Kooooo`;o00002oooool3
o`000?oooooo?_ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0ioooool3o`00063ooooo000Kooooo`03o`000?oooooooooo
0>Kooooo1Ol0001Oooooo`006oooool00ol0003oooooooooo`3Vooooo`Go0000Goooool001_ooooo
00?o0000ooooooooool0i_ooool5o`0005oooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3Wooooo`?o
0000H?ooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooBoooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom;
ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?ooooooBoooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom;ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.14849 .41875 Mdot
.63147 .55144 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool05_ooool3o`000?oo
oooo<_ooool001_ooooo00?o0000ooooooooool05Oooool5o`000?oooooo<Oooool001_ooooo00?o
0000ooooooooool05Oooool5o`000?oooooo<Oooool001_ooooo0_l0000Fooooo`Go0000oooooola
ooooo`006oooool00ol0003oooooooooo`0Fooooo`?o0000oooooolbooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooooooooooo
000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000oooooom;ooooo`0000Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`33ooooo`?o0000Q?ooool00005onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0<;o
oooo1Ol00023ooooo`006oooool00ol0003oooooooooo`32ooooo`Go0000Poooool001_ooooo00?o
0000ooooooooool0`_ooool5o`0008?ooooo000Kooooo`03o`000?oooooooooo0<?ooooo0ol00024
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.769231 0.0769231 0.769231 [
[.23077 .06442 -9 -9 ]
[.23077 .06442 9 0 ]
[.38462 .06442 -9 -9 ]
[.38462 .06442 9 0 ]
[.53846 .06442 -9 -9 ]
[.53846 .06442 9 0 ]
[.69231 .06442 -9 -9 ]
[.69231 .06442 9 0 ]
[.84615 .06442 -3 -9 ]
[.84615 .06442 3 0 ]
[.06442 .23077 -18 -4.5 ]
[.06442 .23077 0 4.5 ]
[.06442 .38462 -18 -4.5 ]
[.06442 .38462 0 4.5 ]
[.06442 .53846 -18 -4.5 ]
[.06442 .53846 0 4.5 ]
[.06442 .69231 -18 -4.5 ]
[.06442 .69231 0 4.5 ]
[.06442 .84615 -6 -4.5 ]
[.06442 .84615 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23077 .07692 m
.23077 .08317 L
s
[(0.2)] .23077 .06442 0 1 Mshowa
.38462 .07692 m
.38462 .08317 L
s
[(0.4)] .38462 .06442 0 1 Mshowa
.53846 .07692 m
.53846 .08317 L
s
[(0.6)] .53846 .06442 0 1 Mshowa
.69231 .07692 m
.69231 .08317 L
s
[(0.8)] .69231 .06442 0 1 Mshowa
.84615 .07692 m
.84615 .08317 L
s
[(1)] .84615 .06442 0 1 Mshowa
.125 Mabswid
.11538 .07692 m
.11538 .08067 L
s
.15385 .07692 m
.15385 .08067 L
s
.19231 .07692 m
.19231 .08067 L
s
.26923 .07692 m
.26923 .08067 L
s
.30769 .07692 m
.30769 .08067 L
s
.34615 .07692 m
.34615 .08067 L
s
.42308 .07692 m
.42308 .08067 L
s
.46154 .07692 m
.46154 .08067 L
s
.5 .07692 m
.5 .08067 L
s
.57692 .07692 m
.57692 .08067 L
s
.61538 .07692 m
.61538 .08067 L
s
.65385 .07692 m
.65385 .08067 L
s
.73077 .07692 m
.73077 .08067 L
s
.76923 .07692 m
.76923 .08067 L
s
.80769 .07692 m
.80769 .08067 L
s
.88462 .07692 m
.88462 .08067 L
s
.92308 .07692 m
.92308 .08067 L
s
.96154 .07692 m
.96154 .08067 L
s
.03846 .07692 m
.03846 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .23077 m
.08317 .23077 L
s
[(0.2)] .06442 .23077 1 0 Mshowa
.07692 .38462 m
.08317 .38462 L
s
[(0.4)] .06442 .38462 1 0 Mshowa
.07692 .53846 m
.08317 .53846 L
s
[(0.6)] .06442 .53846 1 0 Mshowa
.07692 .69231 m
.08317 .69231 L
s
[(0.8)] .06442 .69231 1 0 Mshowa
.07692 .84615 m
.08317 .84615 L
s
[(1)] .06442 .84615 1 0 Mshowa
.125 Mabswid
.07692 .11538 m
.08067 .11538 L
s
.07692 .15385 m
.08067 .15385 L
s
.07692 .19231 m
.08067 .19231 L
s
.07692 .26923 m
.08067 .26923 L
s
.07692 .30769 m
.08067 .30769 L
s
.07692 .34615 m
.08067 .34615 L
s
.07692 .42308 m
.08067 .42308 L
s
.07692 .46154 m
.08067 .46154 L
s
.07692 .5 m
.08067 .5 L
s
.07692 .57692 m
.08067 .57692 L
s
.07692 .61538 m
.08067 .61538 L
s
.07692 .65385 m
.08067 .65385 L
s
.07692 .73077 m
.08067 .73077 L
s
.07692 .76923 m
.08067 .76923 L
s
.07692 .80769 m
.08067 .80769 L
s
.07692 .88462 m
.08067 .88462 L
s
.07692 .92308 m
.08067 .92308 L
s
.07692 .96154 m
.08067 .96154 L
s
.07692 .03846 m
.08067 .03846 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.015 w
.20054 .42805 Mdot
.47529 .56199 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o6oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo023ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<02_ooooo1?l000000ol@413oooooooooo`0dooooo`006oooool00ol0003oooooooooo`0Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooooooo
o`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Tooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0002;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000008_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0]ooooo`03o`000?oooooooooo03Ko
oooo000Kooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo02;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00]oooo
o`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo02Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003oooooooooo`0Yooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000;Oooool00ol0003oooooooooo`0fooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:oooool00omEEEGoIVIVo`00000hoooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00?oo0000JOl0000000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Kooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0003ooooood_ooooo00001Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood_ooooo
00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
Boooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooBoooool00005o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom;ooooo`0000Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom;oooo
o`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0oooooom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0000Yooooo`?o0000oooooolPooooo`006oooool00ol0003oooooooooo`0Woooo
o`Go0000oooooolOooooo`006oooool00ol0003oooooooooo`0Wooooo`Go0000oooooolOooooo`00
6oooool00ol0003oooooooooo`0Wooooo`Go0000oooooolOooooo`006oooool00ol0003ooooooooo
o`0Xooooo`?o0000oooooolPooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol0003ooooooooooooooooo
000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000oooooom;ooooo`0000Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`3ooooood_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`3ooooood_ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0Rooo
ool3o`000;cooooo000Kooooo`03o`000?oooooooooo08[ooooo1Ol0002kooooo`006oooool00ol0
003oooooooooo`2:ooooo`Go0000^oooool001_ooooo00?o0000ooooooooool0R_ooool5o`000;_o
oooo000Kooooo`03o`000?oooooooooo08_ooooo0ol0002looooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooooooo
o`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom;ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom;ooooo`0000Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooBoooool00005o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0oooooom;ooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood_ooooo00001Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooBooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooom;ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`00
6oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`006oooool2o`000?ooooooC?ooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`00
0?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo
000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oo
ooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBooo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0
oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooo
oooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003o
ooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o
0000ooooooooool0oooooom;ooooo`004Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool3o`000?ooooooBoooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom;ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood_ooooo000Aooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003oooooodcooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006ooo
ool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo0_l0003o
ooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooooooo
ool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oo
oooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo
00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?oooooo
Boooool001_ooooo0_l0003oooooodcooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_o
oooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooo
oom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03
o`000?oooooooooo0?ooooooBoooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tAnother thing one can do (that can be shown in a textbook!) is plot the \
orbits of the particles in the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-",
  StyleBox["y",
    FontSlant->"Italic"],
  " plane.  The parametric plots in Cell ",
  ButtonBox["1.56",
    ButtonData:>"Cell 1.56",
    ButtonStyle->"Hyperlink"],
  " do this, using the usual trick of turning off intermediate plot displays \
in order to save space:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p1 = 
        ParametricPlot[{\(x[1]\)[t], \(y[1]\)[t]} /. s[\([1]\)], {t, 0, 4}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(p2 = 
        ParametricPlot[{\(x[2]\)[t], \(y[2]\)[t]} /. s[\([1]\)], {t, 0, 4}, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] Dashing[{0.015, 0.015}]];\)\), "\n", 
    \(\(Show[p1, p2, DisplayFunction \[Rule] $DisplayFunction, 
        PlotRange -> {{0, 1}, {0, 1}}, AspectRatio \[Rule] 1];\)\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 1.56"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
0 0 m
1e-05 0 L
4e-05 0 L
.00011 0 L
.00019 0 L
.0004 0 L
.00071 0 L
.00116 1e-05 L
.00175 2e-05 L
.00313 4e-05 L
.00498 8e-05 L
.0071 .00014 L
.01338 .00037 L
.02197 .00079 L
.03187 .00139 L
.04614 .00248 L
.06231 .00397 L
.10026 .0086 L
.12632 .01275 L
.16098 .01975 L
.18085 .02476 L
.20599 .03261 L
.22186 .03891 L
.23148 .04357 L
.23727 .04685 L
.24316 .05075 L
.24883 .05538 L
.25499 .0627 L
.25526 .08245 L
.25001 .0891 L
.2443 .09402 L
.23484 .10019 L
.21913 .10788 L
.20469 .11346 L
.18256 .12038 L
.14308 .12971 L
.11514 .13474 L
.09007 .1384 L
.06826 .14101 L
.05178 .14264 L
.02713 .14452 L
.01725 .14506 L
.01007 .14536 L
.00505 .14552 L
.00318 .14556 L
.0023 .14558 L
.00162 .14559 L
.00114 .1456 L
.00071 .1456 L
.00036 .1456 L
Mistroke
.00023 .1456 L
.00014 .14561 L
2e-05 .14561 L
Mfstroke
2e-05 .14561 m
0 .14561 L
s
0 .14561 m
2e-05 .14561 L
6e-05 .14561 L
.0002 .14561 L
.00033 .14561 L
.00047 .14561 L
.0008 .14561 L
.00127 .14562 L
.00189 .14563 L
.00331 .14565 L
.00499 .14569 L
.01017 .14585 L
.01777 .14618 L
.02637 .14665 L
.03777 .14742 L
.06476 .14983 L
.10637 .15511 L
.13395 .15974 L
.1523 .16343 L
.17221 .16809 L
.1938 .17416 L
.20697 .17858 L
.22294 .18502 L
.23029 .18857 L
.23895 .19351 L
.24955 .20168 L
.25796 .21656 L
.25165 .23298 L
.24226 .24112 L
.23453 .24598 L
.22685 .24999 L
.19713 .26162 L
.1723 .26872 L
.13691 .27653 L
.11064 .28106 L
.08716 .28439 L
.05402 .28804 L
.02825 .29005 L
.01872 .29059 L
.01065 .29095 L
.00762 .29105 L
.00523 .29112 L
.00346 .29116 L
.00198 .29119 L
.00138 .29119 L
.00084 .2912 L
.00047 .2912 L
.00034 .29121 L
.00022 .29121 L
.00016 .29121 L
Mistroke
.00012 .29121 L
8e-05 .29121 L
5e-05 .29121 L
2e-05 .29121 L
1e-05 .29121 L
2e-05 .29121 L
4e-05 .29121 L
7e-05 .29121 L
.00011 .29121 L
.0002 .29121 L
.00033 .29121 L
.00066 .29121 L
.00114 .29122 L
.00235 .29123 L
.00395 .29127 L
.00581 .29131 L
.01141 .2915 L
.01952 .29187 L
.02851 .29238 L
.04037 .29322 L
.06835 .29581 L
.11145 .30149 L
.14018 .30653 L
.15943 .31061 L
.18054 .31589 L
.20377 .32305 L
.2194 .32906 L
.22782 .33292 L
.23651 .33761 L
.24458 .34302 L
.25385 .35221 L
.25672 .37071 L
.24777 .38241 L
.23838 .38929 L
.2292 .39443 L
.21461 .40095 L
.18778 .41009 L
.16459 .41621 L
.13092 .42323 L
.10333 .42775 L
.07898 .43098 L
.06147 .43291 L
.04539 .43438 L
.02243 .43597 L
.01352 .43641 L
.00732 .43663 L
.00497 .4367 L
.00295 .43674 L
.0022 .43676 L
.00153 .43677 L
Mistroke
.00105 .43677 L
.00064 .43678 L
.00047 .43678 L
.00034 .43678 L
.00024 .43678 L
.00016 .43678 L
.00011 .43678 L
7e-05 .43678 L
5e-05 .43678 L
5e-05 .43678 L
8e-05 .43678 L
.00013 .43678 L
.00021 .43678 L
.00033 .43678 L
.0006 .43678 L
.001 .43679 L
.00151 .43679 L
.0022 .4368 L
.0038 .43683 L
.008 .43695 L
.01496 .43722 L
.02348 .43765 L
.04508 .43917 L
.06121 .44064 L
.07936 .44264 L
.11562 .44772 L
.16071 .45647 L
Mfstroke
[ .015 .015 ] 0 setdash
1 0 m
.99996 .00247 L
.99987 .00471 L
.99968 .00731 L
.99943 .00976 L
.9988 .01411 L
.99787 .01884 L
.99652 .02403 L
.99474 .02953 L
.9906 .03937 L
.98507 .04948 L
.97871 .05888 L
.95985 .08002 L
.9341 .10103 L
.90438 .11958 L
.86212 .13989 L
.81307 .1577 L
.76033 .17199 L
.72674 .179 L
.69336 .18456 L
.65927 .18892 L
.6387 .19094 L
.61881 .19246 L
.60054 .19349 L
.58979 .19394 L
.57951 .19425 L
.56836 .19446 L
.55793 .19455 L
.54556 .1945 L
.53348 .19429 L
.5212 .19392 L
.50752 .19331 L
.49417 .19251 L
.48152 .19157 L
.45045 .18842 L
.4338 .18623 L
.41466 .18322 L
.37524 .1752 L
.35085 .16877 L
.32679 .16104 L
.30222 .1513 L
.27258 .13583 L
.24169 .11049 L
.22676 .06349 L
.24921 .02735 L
.2771 .00706 L
s
.2771 .00706 m
.29093 0 L
s
.84689 0 m
.85576 .00313 L
.89191 .01944 L
.92486 .03832 L
.95292 .0593 L
.97345 .08005 L
.98238 .09193 L
.98896 .10296 L
.99346 .11268 L
.99704 .1234 L
.99832 .12882 L
.99887 .1318 L
.99929 .13463 L
.9996 .13726 L
.99973 .13865 L
.99984 .14012 L
.99997 .14273 L
s
.99997 .14273 m
1 .14426 L
s
1 .14731 m
1 .14752 L
.9999 .15013 L
.99971 .15285 L
.99945 .15538 L
.99879 .15992 L
.99782 .16477 L
.99631 .17046 L
.99452 .17583 L
.99022 .18584 L
.98498 .19529 L
.97914 .20396 L
.96227 .22333 L
.9397 .2426 L
.91334 .2601 L
.87815 .27848 L
.83224 .29697 L
.78003 .31279 L
.74613 .32076 L
.71145 .32734 L
.67481 .33272 L
.63839 .33659 L
.61668 .33822 L
.60393 .33895 L
.59185 .33949 L
.58095 .33984 L
.56865 .34008 L
.56231 .34015 L
.55541 .34017 L
.54265 .34009 L
.52978 .33982 L
.52226 .33958 L
.51508 .3393 L
.50022 .33852 L
.48357 .33736 L
.46831 .336 L
.45156 .33418 L
.4196 .32967 L
.40013 .32618 L
.37801 .32147 L
.33375 .30906 L
.30279 .29717 L
.28611 .28916 L
.26968 .27962 L
.23703 .25022 L
.22592 .22166 L
.23488 .18978 L
.26566 .15991 L
.29209 .14466 L
.31951 .13286 L
Mistroke
.34314 .12478 L
.38087 .11474 L
.41748 .10755 L
.45368 .10244 L
.47247 .10047 L
.48872 .09912 L
.50336 .09817 L
.51085 .09777 L
.5186 .09743 L
.53248 .09699 L
.54482 .09677 L
.55731 .09671 L
.5642 .09675 L
.57046 .09682 L
.58172 .09707 L
.59334 .09746 L
.60345 .09791 L
.6127 .09842 L
.63304 .09985 L
.65388 .10177 L
.67205 .10383 L
.71012 .10933 L
.7696 .12149 L
.81774 .13506 L
.86157 .15116 L
.90059 .16964 L
.93083 .18799 L
.95318 .20521 L
.9732 .22545 L
.9866 .24442 L
.99175 .25444 L
.99596 .2655 L
.99751 .27108 L
.9982 .27416 L
.99875 .27708 L
.99917 .27979 L
.99953 .28275 L
.99976 .28543 L
.99989 .28792 L
.99996 .29039 L
.99994 .29299 L
.99987 .29521 L
.99972 .29764 L
.99947 .30027 L
.99912 .30307 L
.99825 .30811 L
.99706 .31321 L
.99564 .31802 L
.99223 .327 L
.98684 .33769 L
Mistroke
.9806 .34748 L
.96184 .36932 L
.93913 .3886 L
.91264 .40609 L
.87729 .42447 L
.83121 .44293 L
.77874 .45872 L
.74468 .46667 L
.70986 .47321 L
.67303 .47855 L
.65437 .48067 L
.63643 .48236 L
.61461 .48395 L
.60265 .48461 L
.59642 .4849 L
.58965 .48517 L
.57798 .48551 L
.56679 .48571 L
.55981 .48576 L
.55309 .48577 L
.54019 .48565 L
.52807 .48537 L
.51459 .48487 L
.50144 .4842 L
.489 .48337 L
.45849 .48057 L
.44218 .4786 L
.42349 .47589 L
.38506 .46866 L
.36143 .46293 L
.33826 .45613 L
.31473 .44775 L
.28661 .43501 L
.25688 .41607 L
.2297 .38284 L
.23454 .33592 L
.26267 .30761 L
.288 .29232 L
.30909 .2826 L
.35455 .26703 L
.39201 .25793 L
.42664 .2517 L
.45597 .2478 L
.48573 .24497 L
.49994 .24399 L
.50733 .24358 L
.51508 .2432 L
.52833 .24272 L
.5403 .24246 L
.54745 .24237 L
Mistroke
.55409 .24234 L
.56625 .2424 L
.57871 .24262 L
.58988 .24296 L
.60181 .24346 L
.6141 .24413 L
.63349 .24552 L
.65086 .2471 L
.68782 .25155 L
.72422 .25745 L
.75464 .26364 L
.81443 .27966 L
.8599 .29614 L
.89542 .31258 L
.92773 .33157 L
.95512 .35263 L
.97507 .37346 L
.98367 .38538 L
.98994 .39643 L
.99417 .40618 L
.99607 .41179 L
.99747 .41691 L
.99859 .42234 L
.99906 .42533 L
.99941 .42816 L
.99964 .43077 L
.99978 .43319 L
.99986 .43584 L
.99986 .43718 L
.99985 .43866 L
.99975 .44122 L
.9996 .44359 L
.99934 .4462 L
.99899 .44899 L
.99796 .45468 L
.99669 .45984 L
.99332 .46979 L
.98902 .47915 L
.98266 .48993 L
.97547 .4998 L
.95441 .52176 L
.92968 .54086 L
.90117 .55812 L
.8634 .57615 L
.81439 .59408 L
.76066 .60871 L
.72592 .61595 L
.69048 .62178 L
.67163 .62429 L
.65303 .62638 L
Mistroke
.63535 .62802 L
.61584 .62945 L
.60528 .63006 L
.59338 .6306 L
.58227 .63097 L
.57163 .63121 L
.55869 .63134 L
.54654 .6313 L
.53966 .63121 L
.53206 .63105 L
.51788 .63059 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@1000`40O003h00Oogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo
@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00
QGoo100027oo0`001goo2000C7oo100027oo0`002goo1@00BWoo100027oo0`002Goo1000CGoo1000
27oo0`002Goo1000F7oo1`0017oo0024Ool00`00Oomoo`02Ool00`00Oomoo`05Ool30008Ool00`00
Oomoo`03Ool00`00Oomoo`19Ool00`00Oomoo`02Ool00`00Oomoo`05Ool3000=Ool00`00Oomoo`19
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`19Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`1HOol00`00Oomoo`05
Ool008Aoo`03001oogoo009oo`03001oogoo00Eoo`<000Uoo`03001oogoo04ioo`03001oogoo009o
o`03001oogoo00Eoo`<000eoo`03001oogoo04Uoo`03001oogoo009oo`03001oogoo00Eoo`<000Mo
o`03001oogoo00Aoo`03001oogoo04Qoo`03001oogoo009oo`03001oogoo00Eoo`<000Moo`03001o
ogoo00Aoo`03001oogoo05Moo`03001oogoo00Eoo`00Pgoo00<007ooOol017oo00<007ooOol04Goo
00<007ooOol0C7oo00<007ooOol017oo00<007ooOol03Woo2@00B7oo00<007ooOol017oo00<007oo
Ool03Woo00<007ooOol017oo00<007ooOol0Agoo00<007ooOol017oo00<007ooOol03Woo00<007oo
Ool017oo00<007ooOol0Egoo00<007ooOol01Goo0023Ool00`00Oomoo`04Ool00`00Oomoo`0BOol0
0`00Oomoo`1;Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`18Ool0
0`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`17Ool00`00Oomoo`04Ool0
0`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`1GOol00`00Oomoo`05Ool008=oo`03001oogoo
00Aoo`03001oogoo01=oo`03001oogoo04Yoo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo
009oo`03001oogoo04Qoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo
04Moo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo009oo`03001oogoo05Qoo`03001oogoo
00Eoo`00Pgoo00<007ooOol017oo00<007ooOol057oo00<007ooOol0BGoo00<007ooOol017oo00<0
07ooOol047oo00D007ooOomoo`0004Yoo`03001oogoo00Aoo`03001oogoo00ioo`8000Aoo`03001o
ogoo04Qoo`03001oogoo00Aoo`03001oogoo00moo`H005Yoo`03001oogoo00Eoo`00Pgoo00<007oo
Ool017oo00<007ooOol05Goo00<007ooOol0B7oo00<007ooOol017oo00<007ooOol04Goo00@007oo
Ool004Yoo`03001oogoo00Aoo`03001oogoo00ioo`03001oo`0000<004]oo`03001oogoo00Aoo`03
001oogoo00moo`03001oogoo009oo`03001oogoo05Qoo`03001oogoo00Eoo`00Pgoo00<007ooOol0
17oo00<007ooOol05Goo00<007ooOol0B7oo00<007ooOol017oo00<007ooOol04Goo00@007ooOol0
04Yoo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo04eoo`03001oogoo00Aoo`03001oogoo
00ioo`03001oogoo00Aoo`03001oogoo05Moo`03001oogoo00Eoo`00Q7oo00<007ooOol00Woo00<0
07ooOol047oo00<007ooOol00goo00<007ooOol0BGoo00<007ooOol00Woo00<007ooOol04goo00<0
07oo0000Bgoo00<007ooOol00Woo00<007ooOol047oo00<007ooOol0CWoo00<007ooOol00Woo00<0
07ooOol03goo00<007ooOol017oo00<007ooOol0Egoo00<007ooOol01Goo0024Ool00`00Oomoo`02
Ool00`00Oomoo`0@Ool20003Ool00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`0DOol2001;
Ool00`00Oomoo`02Ool00`00Oomoo`0AOol2001>Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00
Oomoo`02Ool00`00Oomoo`1EOol40007Ool008Eoo`@001Eoo`<004ioo`@001Moo`8004aoo`@001Io
o`@004]oo`@001Aoo`@005Yoo`8000Moo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00
ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomo
od9oo`00:Wooo`00o`004@001goo000ZOol00`00Oomoo`0COol8000GOol00`00Oomoo`0GOol00`00
Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`0>Ool30006Ool00`00Oomoo`0GOol00`00Oomoo`0H
Ool00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0G
Ool00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Ool00002
000EOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`05Ool002Yoo`03001oogoo01Moo`04
001oogooOol9000>Ool00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`0<
Ool20009Ool00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00
Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`0GOol00`00
Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0GOol00`00
Oomoo`0GOol00`00Oomoo`05Ool002Yoo`03001oogoo02Aoo`X003Qoo`03001oogoo02Ioo`03001o
ogoo03ioo`03001oogoo06Ioo`03001oogoo06Ioo`03001oogoo06Ioo`03001oogoo00Eoo`00:Woo
00<007ooOol0;Woo2@00EGoo0P00ogooOWoo00<007ooOol01Goo000ZOol00`00Oomoo`0gOol7001=
Ool00`00Oomoo`3oOomnOol00`00Oomoo`05Ool002Yoo`03001oogoo03ioo`D004Moo`03001oogoo
0?mooceoo`80041oo`03001oogoo00Eoo`00:Woo00<007ooOol0@goo1@00@Goo00<007ooOol0ogoo
@7oo0`00?Goo00<007ooOol01Goo000ZOol00`00Oomoo`18Ool4000lOol00`00Oomoo`3oOom4Ool3
0012Ool002Yoo`03001oogoo04aoo`D003Ioo`03001oogoo0?moodQoo`03001oogoo03moo`00:Woo
00<007ooOol0DGoo1000ogoo_goo000ZOol00`00Oomoo`1EOol3003oOonlOol002Yoo`03001oogoo
05Qoo`<00?mookUoo`00:Woo00<007ooOol0Fgoo1000ogooNWoo0P00>Goo000ZOol00`00Oomoo`1O
Ool3000NOol2003oOomIOol00`00Oomoo`0fOol002Yoo`03001oogoo069oo`@001Yoo`03001oogoo
0?mooeUoo`8002aoo`03001oogoo00Moo`00:Woo00<007ooOol0IWoo0`005Woo00<007ooOol0ogoo
G7oo00<007ooOol0:Goo00<007ooOol01goo000ZOol00`00Oomoo`1YOol3000BOol00`00Oomoo`3o
OomNOol00`00Oomoo`0WOol00`00Oomoo`08Ool002Yoo`03001oogoo06aoo`<000moo`03001oogoo
0?moohQoo`03001oogoo00Qoo`00:Woo00<007ooOol0Kgoo0`002goo00<007ooOol0ogooRGoo00<0
07ooOol027oo000ZOol00`00Oomoo`1bOol20008Ool00`00Oomoo`3oOon9Ool00`00Oomoo`09Ool0
02Yoo`03001oogoo07Aoo`800?moog1oo`8001moo`03001oogoo00Yoo`00:Woo00<007ooOol0MWoo
00<007ooOol0ogooKgoo00<007ooOol06goo00<007ooOol02goo000ZOol00`00Oomoo`1gOol3003o
Oom_Ool2000YOol002Yoo`03001oogoo07Yoo`800?moofmoo`03001oogoo02Ioo`00:Woo00<007oo
Ool0O7oo00<007ooOol0ogooKGoo00<007ooOol09Goo000ZOol3001mOol00`00Oomoo`3oOonDOol0
02Yoo`03001oogoo07Qoo`03001oogoo00=oo`03001oogoo0?mooi=oo`00:Woo00<007ooOol0N7oo
00<007ooOol017oo00<007ooOol0ogooTWoo000ZOol00`00Oomoo`1gOol00`00Oomoo`06Ool00`00
Oomoo`3oOomoOol00`00Oomoo`0?Ool002Yoo`03001oogoo07Ioo`03001oogoo00Moo`03001oogoo
0?moog1oo`03001oogoo00aoo`03001oogoo00moo`00:Woo00<007ooOol0MWoo00<007ooOol027oo
00<007ooOol0ogooL7oo00<007ooOol02Woo00<007ooOol047oo000ZOol00`00Oomoo`1eOol00`00
Oomoo`0:Ool00`00Oomoo`3oOom_Ool00`00Oomoo`09Ool00`00Oomoo`0AOol002Yoo`03001oogoo
07Aoo`03001oogoo00aoo`03001oogoo0?moofmoo`03001oogoo00Moo`03001oogoo019oo`00:Woo
00<007ooOol0MGoo00<007ooOol02goo00<007ooOol0ogooL7oo00<007ooOol01Goo00<007ooOol0
4goo000ZOol00`00Oomoo`23Ool00`00Oomoo`3oOomaOol00`00Oomoo`03Ool00`00Oomoo`0DOol0
02Yoo`03001oogoo08=oo`03001oogoo0?moog9oo`03001oogoo01Uoo`00:Woo00<007ooOol0Pgoo
00<007ooOol0ogooSWoo000ZOol00`00Oomoo`23Ool00`00Oomoo`3oOon>Ool002Yoo`03001oogoo
08=oo`03001oogoo0?moohioo`00:Woo00<007ooOol0Pgoo00<007ooOol0ogooSWoo000ZOol00`00
Oomoo`1gOol00`00Oomoo`09Ool00`00Oomoo`3oOombOol00`00Oomoo`03Ool00`00Oomoo`0COol0
02Yoo`03001oogoo07Moo`03001oogoo00Uoo`03001oogoo0?moog1oo`8000Moo`03001oogoo019o
o`00:Woo00<007ooOol0N7oo00<007ooOol027oo00<007ooOol0ogooKgoo00<007ooOol01goo00<0
07ooOol04Woo000ZOol00`00Oomoo`1hOol00`00Oomoo`08Ool00`00Oomoo`3oOom^Ool00`00Oomo
o`09Ool00`00Oomoo`0AOol002Yoo`03001oogoo07Qoo`03001oogoo00Moo`03001oogoo0?moofio
o`03001oogoo00]oo`03001oogoo011oo`00:Woo00<007ooOol0NGoo00<007ooOol01Goo00<007oo
Ool0ogooKWoo00<007ooOol037oo00<007ooOol047oo000ZOol00`00Oomoo`1iOol00`00Oomoo`04
Ool00`00Oomoo`3oOomoOol00`00Oomoo`0?Ool002Yoo`03001oogoo07Uoo`03001oogoo00=oo`03
001oogoo0?mooh5oo`03001oogoo00ioo`00:Woo00<007ooOol0NWoo00<007ooOol00P00ogooUGoo
000ZOol00`00Oomoo`1kOol2002TOol4003^Ool002Yoo`03001oogoo07Yoo`03001oogoo08Ioo`H0
00Ioo`T000Moo`8000Aoo`<000Moo`T000Moo`H00:Ioo`03001oogoo02Eoo`00:Woo0`00N7oo0P00
NGoo1P001goo0`00@Woo0`00XWoo00<007ooOol09Woo000ZOol00`00Oomoo`1fOol2001hOol3001L
Ool8002AOol2000YOol002Yoo`03001oogoo07=oo`<006ioo`D007Eoo`H0089oo`8001ioo`03001o
ogoo00Yoo`00:Woo00<007ooOol0LGoo0P00KGoo1000P7oo0`00OWoo00<007ooOol07Woo00<007oo
Ool02Woo000ZOol00`00Oomoo`1_Ool2000;Ool00`00Oomoo`1GOol3002EOol4001bOol00`00Oomo
o`0POol00`00Oomoo`09Ool002Yoo`03001oogoo06aoo`<000eoo`03001oogoo05Aoo`<009aoo`@0
095oo`03001oogoo00Uoo`00:Woo00<007ooOol0JWoo0P0047oo0P00Dgoo0P00Xgoo00<007ooOol0
SWoo00<007ooOol02Goo000ZOol00`00Oomoo`1XOol2000DOol00`00Oomoo`17Ool2002cOol30028
Ool00`00Oomoo`08Ool002Yoo`03001oogoo06Eoo`<001Moo`03001oogoo049oo`@00;Qoo`@005Uo
o`8002Uoo`03001oogoo00Qoo`00:Woo00<007ooOol0HWoo0`006goo00<007ooOol0?Woo0`00`7oo
0P00EGoo0P00;7oo00<007ooOol01goo000ZOol00`00Oomoo`1OOol3000OOol00`00Oomoo`3oOol:
Ool2001;Ool00`00Oomoo`0/Ool00`00Oomoo`07Ool002Yoo`03001oogoo05]oo`@005Uoo`<00=Ao
o`<004Ioo`8003Uoo`00:Woo00<007ooOol0Egoo1000FGoo1000fWoo1000@Goo00<007ooOol0>Goo
000ZOol00`00Oomoo`1BOol5001KOol2003oOomPOol002Yoo`03001oogoo04ioo`@00?mood]oo`80
07Eoo`00:Woo00<007ooOol0BWoo1000>Goo0P00ogoo5Woo0`00;Woo0P00@Woo000ZOol00`00Oomo
o`16Ool4000oOol00`00Oomoo`0NOol2003eOol3000XOol30014Ool002Yoo`03001oogoo045oo`D0
04Aoo`8001]oo`<00?Yoo`03001oogoo02=oo`8003moo`03001oogoo00Eoo`00:Woo00<007ooOol0
?7oo1@00Bgoo00<007ooOol05Goo0`00ogoo8goo00<007ooOol0?goo00<007ooOol01Goo000ZOol0
0`00Oomoo`0cOol9001AOol00`00Oomoo`0AOol3003oOol8Ool4001LOol00`00Oomoo`05Ool002Yo
o`03001oogoo02Uoo`X005]oo`03001oogoo00moo`03001oogoo0?moo`eoo`<005Uoo`03001oogoo
00Eoo`00:Woo00<007ooOol097oo1@00ogooRWoo0P00Egoo00<007ooOol01Goo000ZOol00`00Oomo
o`0MOol7003oOonLOol30019Ool00`00Oomoo`05Ool002Yoo`03001oogoo019oo`/007Qoo`800003
Ool000000?moob=oo`<004aoo`03001oogoo00Eoo`00:Woo5@00Q7oo0`00ogoo8Woo0P00Cgoo00<0
07ooOol01Goo000ZOol00`00Oomoo`05OolD001kOol20003Ool00`00Oomoo`3oOolQOol3001<Ool0
0`00Oomoo`05Ool002Yoo`03001oogoo01Uoo`/006moo`03001oogoo00Aoo`800?moobAoo`<004Uo
o`03001oogoo00Eoo`00:Woo0`0097oo1`00Igoo00<007ooOol01goo00<007ooOol0ogoo57oo0P00
3Woo00<007ooOol0AWoo00<007ooOol01Goo000ZOol00`00Oomoo`0[Ool7003oOomnOol3001IOol0
0`00Oomoo`05Ool002Yoo`03001oogoo039oo`L00?moogAoo`<005aoo`03001oogoo00Eoo`00:Woo
00<007ooOol0>Goo1@00IGoo0`00ogoo1Woo00<007ooOol06goo0P00@7oo00<007ooOol01Goo000Z
Ool00`00Oomoo`0nOol50017Ool2000JOol3003oOolSOol30015Ool002Yoo`03001oogoo04=oo`@0
045oo`8001moo`03001oogoo0?Ioo`<002Uoo`8004=oo`00:Woo00<007ooOol0Agoo1@00>goo00<0
07ooOol087oo00<007ooOol0lGoo1000;Woo00<007ooOol0@7oo000ZOol00`00Oomoo`1<Ool5000e
Ool00`00Oomoo`3oOolDOol2001eOol002Yoo`03001oogoo055oo`D002moo`03001oogoo02Yoo`<0
0?mooemoo`00:Woo00<007ooOol0EWoo1@00FWoo1000fGoo0`00OWoo000ZOol00`00Oomoo`1KOol4
001JOol2003DOol30015Ool2000jOol002Yoo`03001oogoo05moo`<00?moobaoo`8004Yoo`8002io
o`03001oogoo00Moo`00:Woo00<007ooOol0HWoo0`00G7oo0P00ogoo6Goo00<007ooOol0:goo00<0
07ooOol01goo000ZOol00`00Oomoo`1UOol3001KOol4002jOol5001FOol2000[Ool00`00Oomoo`07
Ool002Yoo`03001oogoo06Qoo`8001Eoo`03001oogoo04Eoo`<00;=oo`@005eoo`03001oogoo02Qo
o`03001oogoo00Moo`00:Woo00<007ooOol0JWoo0P004Woo00<007ooOol0ogooR7oo00<007ooOol0
27oo000ZOol00`00Oomoo`1/Ool3000>Ool00`00Oomoo`1AOol4002MOol5002@Ool00`00Oomoo`09
Ool002Yoo`03001oogoo06moo`<000Yoo`03001oogoo05Ioo`@009Eoo`@009Eoo`03001oogoo00Uo
o`00:Woo00<007ooOol0LWoo0P001goo00<007ooOol0HWoo00<007ooOol0Ogoo1@00OWoo00<007oo
Ool07Woo00<007ooOol02Woo000ZOol00`00Oomoo`1dOol20004Ool00`00Oomoo`1TOol5001hOol4
0024Ool00`00Oomoo`0ZOol002Yoo`03001oogoo07Ioo`8006ioo`<000Moo`D005eoo`D0091oo`80
02Yoo`00:Woo00<007ooOol0N7oo0`00NWoo1000EGoo1000Ugoo00<007ooOol09goo0004Ool40008
Ool30007Ool80008Ool00`00Oomoo`1kOol00`00Oomoo`22Ool8000gOol9002ROol00`00Oomoo`0V
Ool000=oo`03001oogoo009oo`03001oogoo00Eoo`<000Qoo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo07aoo`03001oogoo091oo`T000Moo`T000Moo`T00;=oo`03001oogoo02Eoo`000goo
00<007ooOol00Woo00<007ooOol01Goo0`002Goo00<007ooOol02goo00<007ooOol0OGoo00<007oo
Ool0ogooU7oo0002Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`1n
Ool00`00Oomoo`3oOon2Ool00`00Oomoo`0>Ool0009oo`03001oogoo00Aoo`03001oogoo019oo`03
001oogoo00Uoo`@007ioo`03001oogoo0?mooh5oo`03001oogoo00ioo`000Woo00<007ooOol017oo
00<007ooOol04goo00<007ooOol027oo00<007ooOol0Mgoo00<007ooOol01Woo00<007ooOol0ogoo
Kgoo00<007ooOol03Goo00<007ooOol03goo0002Ool00`00Oomoo`04Ool00`00Oomoo`0DOol00`00
Oomoo`07Ool00`00Oomoo`1gOol00`00Oomoo`06Ool00`00Oomoo`3oOom`Ool00`00Oomoo`0<Ool0
0`00Oomoo`0?Ool0009oo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo
07Moo`03001oogoo00Moo`03001oogoo0?moog1oo`03001oogoo00Yoo`03001oogoo011oo`000Woo
00<007ooOol017oo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol0MWoo00<007ooOol02Goo
00<007ooOol0ogooL7oo00<007ooOol027oo00<007ooOol04Goo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1fOol00`00Oomoo`09Ool00`00
Oomoo`3oOomaOol00`00Oomoo`06Ool00`00Oomoo`0BOol000=oo`03001oogoo009oo`03001oogoo
011oo`8000=oo`03001oogoo00Moo`03001oogoo07Ioo`03001oogoo00Yoo`03001oogoo0?moog5o
o`03001oogoo01Yoo`0017oo10005Goo0`002Woo00<007ooOol0MGoo00<007ooOol02goo00<007oo
Ool0ogooLWoo00<007ooOol06Goo000ZOol00`00Oomoo`1eOol00`00Oomoo`0<Ool00`00Oomoo`3o
Oon=Ool002Yoo`03001oogoo08Eoo`03001oogoo0?moohaoo`00:Woo00<007ooOol0QGoo00<007oo
Ool0ogooS7oo000ZOol00`00Oomoo`24Ool00`00Oomoo`3oOombOol00`00Oomoo`0HOol002Yoo`03
001oogoo08Aoo`03001oogoo0?moog5oo`8000Aoo`03001oogoo01=oo`00:Woo00<007ooOol0Q7oo
00<007ooOol0ogooL7oo00<007ooOol017oo00<007ooOol04goo000ZOol00`00Oomoo`23Ool00`00
Oomoo`3oOom`Ool00`00Oomoo`05Ool00`00Oomoo`0COol002Yoo`03001oogoo08=oo`03001oogoo
0?moofmoo`03001oogoo00Moo`03001oogoo019oo`00:Woo00<007ooOol0MWoo00<007ooOol02Woo
00<007ooOol0ogooKWoo00<007ooOol02Goo00<007ooOol04Goo000ZOol00`00Oomoo`1fOol00`00
Oomoo`09Ool00`00Oomoo`3oOom^Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol002Yoo`03001oogoo
07Moo`03001oogoo00Moo`03001oogoo0?moogeoo`03001oogoo011oo`00:Woo00<007ooOol0Mgoo
00<007ooOol01Woo00<007ooOol0ogooOgoo00<007ooOol03goo000ZOol00`00Oomoo`1hOol00`00
Oomoo`04Ool00`00Oomoo`3oOonBOol002Yoo`03001oogoo07Qoo`03001oogoo00=oo`03001oogoo
0?mooi=oo`00:Woo00<007ooOol0N7oo00@007ooOomoo`8009Aoo`T0009oo`L000Moo`T00;Moo`80
02Ioo`00:Woo00<007ooOol0NGoo0`00QWoo2@00<7oo2@00YWoo00<007ooOol09Woo000ZOol00`00
Oomoo`1hOol2001lOol5001?Ool6002HOol2000YOol002Yoo`03001oogoo07Ioo`8006moo`@000Mo
o`@005Yoo`<000Moo`D008Qoo`03001oogoo01aoo`03001oogoo00Yoo`00:Woo0`00M7oo0P00KGoo
1000N7oo1000Pgoo00<007ooOol07Goo00<007ooOol02Woo000ZOol00`00Oomoo`1aOol3003fOol3
002IOol00`00Oomoo`0:Ool002Yoo`03001oogoo06ioo`<006Ioo`D0095oo`@009Ioo`03001oogoo
00Uoo`00:Woo00<007ooOol0K7oo0P003goo00<007ooOol0Dgoo1000VWoo0P00U7oo00<007ooOol0
2Goo000ZOol00`00Oomoo`1YOol3000BOol00`00Oomoo`18Ool3002]Ool4002:Ool00`00Oomoo`09
Ool002Yoo`03001oogoo06Ioo`<001Ioo`03001oogoo04Aoo`<00;Aoo`<005moo`03001oogoo02Io
o`03001oogoo00Qoo`00:Woo00<007ooOol0Hgoo0`006Woo00<007ooOol0@Goo0P00^Woo0P00Fgoo
0P00:Goo00<007ooOol027oo000ZOol00`00Oomoo`1POol3000NOol00`00Oomoo`3oOol6Ool4001=
Ool3000/Ool00`00Oomoo`07Ool002Yoo`03001oogoo05eoo`<0029oo`03001oogoo03Eoo`<00=1o
o`<004Uoo`03001oogoo03Moo`00:Woo00<007ooOol0FWoo0`009Woo00<007ooOol0<7oo1000eWoo
00<007ooOol0P7oo000ZOol00`00Oomoo`1FOol4001JOol2003oOomNOol002Yoo`03001oogoo055o
o`D00?mood=oo`<007Qoo`00:Woo00<007ooOol0C7oo1@00ogooBgoo1000<Goo0P00@Goo000ZOol0
0`00Oomoo`17Ool5001OOol3003aOol2000]Ool20013Ool002Yoo`03001oogoo04=oo`@0049oo`03
001oogoo01]oo`@00?moob9oo`8003eoo`03001oogoo00Eoo`00:Woo00<007ooOol0?Woo1@00Agoo
00<007ooOol067oo0P00ogoo0Goo0`008Goo00<007ooOol0?Goo00<007ooOol01Goo000ZOol00`00
Oomoo`0iOol5001=Ool2003oOolNOol2000NOol00`00Oomoo`0nOol00`00Oomoo`05Ool002Yoo`03
001oogoo035oo`P005Aoo`800?mooaioo`<005aoo`03001oogoo00Eoo`00:Woo00<007ooOol09goo
2P00GWoo00<007ooOol02goo0P00ogoo4Goo00<007ooOol047oo0P00Agoo00<007ooOol01Goo000Z
Ool00`00Oomoo`0NOol9001dOol2003oOolSOol30019Ool00`00Oomoo`05Ool002Yoo`03001oogoo
01=oo`/007aoo`03001oogoo0?mooaYoo`8000Eoo`8004aoo`03001oogoo00Eoo`00:Woo00<007oo
Ool02Woo2@00QGoo0P00ogoo7goo0`0000=oo`00Ool0CGoo00<007ooOol01Goo000ZOolC0026Ool2
003oOolTOol3001=Ool00`00Oomoo`05Ool002Yoo`03001oogoo011oo`/007eoo`800?moobEoo`03
001oogoo059oo`00:Woo00<007ooOol06goo2`00M7oo0P00ogoo6Goo00<007ooOol0G7oo000ZOol0
0`00Oomoo`0VOol8001QOol2000;Ool2003oOolEOol2001OOol002Yoo`03001oogoo02ioo`L005Qo
o`800?moob5oo`<001=oo`8004aoo`00:Woo0`00=Goo1`00D7oo00<007ooOol0ogoo7goo0P0067oo
0`00BGoo000ZOol00`00Oomoo`0lOol50019Ool2000IOol2003oOolTOol20017Ool002Yoo`03001o
ogoo045oo`D004=oo`03001oogoo01]oo`<00?Uoo`<002Ioo`03001oogoo04Aoo`00:Woo00<007oo
Ool0AWoo1@00Ggoo0P00m7oo0`00J7oo00<007ooOol01Goo000ZOol00`00Oomoo`1;Ool5001LOol0
0`00Oomoo`3_Ool2001[Ool00`00Oomoo`05Ool002Yoo`03001oogoo051oo`@00?mookQoo`03001o
ogoo00Eoo`00:Woo00<007ooOol0E7oo1000G7oo0`00ogoo7Goo0`00=7oo00<007ooOol01Woo000Z
Ool00`00Oomoo`1HOol3001LOol3003IOol4000oOol00`00Oomoo`0aOol00`00Oomoo`06Ool002Yo
o`03001oogoo05]oo`@002Aoo`03001oogoo03Aoo`800==oo`@004Aoo`80031oo`03001oogoo00Mo
o`00:Woo00<007ooOol0Ggoo0`0087oo00<007ooOol0ogooEGoo00<007ooOol0;Goo00<007ooOol0
1goo000ZOol00`00Oomoo`1ROol3000LOol00`00Oomoo`3oOol1Ool4001BOol00`00Oomoo`0/Ool0
0`00Oomoo`07Ool002Yoo`03001oogoo06Eoo`<001Qoo`03001oogoo041oo`H00;Qoo`<008moo`00
:Woo00<007ooOol0J7oo0`0057oo00<007ooOol0Agoo0`00/goo0P00TWoo000ZOol00`00Oomoo`1[
Ool3000@Ool00`00Oomoo`3eOol2002KOol002Yoo`03001oogoo06ioo`<0065oo`D009]oo`@006]o
o`80031oo`00:Woo00<007ooOol0LGoo0P00I7oo1000UGoo0P00LGoo0P00;Woo000ZOol00`00Oomo
o`1cOol2001]Ool5001mOol5001lOol2000/Ool002Yoo`03001oogoo07Eoo`80071oo`@007Eoo`@0
08=oo`03001oogoo02Uoo`00:Woo00<007ooOol0Mgoo0`00N7oo1P00F7oo2@00Sgoo00<007ooOol0
6Woo00<007ooOol02goo000ZOol00`00Oomoo`1hOol01000Ool00000O7oo0`00BWoo1000_7oo00<0
07ooOol02goo000ZOol00`00Oomoo`1hOol01@00Oomoogoo0000Q7oo2@001goo1`006Goo2@001goo
1000_goo00<007ooOol037oo000ZOol00`00Oomoo`1hOol00`00Oomoo`02Ool00`00Oomoo`2HOol2
0007Ool9003YOol002Yoo`03001oogoo07Qoo`03001oogoo00=oo`03001oogoo0?mooi=oo`00:Woo
00<007ooOol0N7oo00<007ooOol017oo00<007ooOol0ogooKGoo0P008goo000ZOol00`00Oomoo`1h
Ool00`00Oomoo`05Ool00`00Oomoo`3oOom^Ool00`00Oomoo`0POol002Yoo`03001oogoo07Qoo`03
001oogoo00Ioo`03001oogoo0?moofioo`80021oo`00:Woo0`00N7oo00<007ooOol01goo00<007oo
Ool0ogooKgoo00<007ooOol07Goo000ZOol00`00Oomoo`1hOol00`00Oomoo`08Ool00`00Oomoo`3o
Oom_Ool00`00Oomoo`08Ool00`00Oomoo`0AOol002Yoo`03001oogoo08=oo`03001oogoo0?moofmo
o`03001oogoo00Qoo`03001oogoo015oo`00:Woo00<007ooOol0Pgoo00<007ooOol0ogooNGoo00<0
07ooOol04Woo000ZOol00`00Oomoo`23Ool00`00Oomoo`3oOomhOol00`00Oomoo`0COol002Yoo`03
001oogoo08=oo`03001oogoo0?moogMoo`03001oogoo01Aoo`00:Woo00<007ooOol0Pgoo00<007oo
Ool0ogooMWoo00<007ooOol05Goo000ZOol00`00Oomoo`24Ool00`00Oomoo`3oOomdOol00`00Oomo
o`0FOol002Yoo`03001oogoo08Aoo`03001oogoo0?moogAoo`03001oogoo01Ioo`00:Woo00<007oo
Ool0Mgoo00<007ooOol02Woo00<007ooOol0ogooMGoo00<007ooOol05Goo000ZOol00`00Oomoo`1g
Ool00`00Oomoo`0:Ool00`00Oomoo`3oOomfOol00`00Oomoo`0DOol002Yoo`03001oogoo07Moo`03
001oogoo00Yoo`03001oogoo0?moogMoo`03001oogoo01=oo`00:Woo00<007ooOol0Mgoo00<007oo
Ool02Woo00<007ooOol0ogooKWoo0P0027oo00<007ooOol04Woo000ZOol00`00Oomoo`1gOol00`00
Oomoo`09Ool00`00Oomoo`3oOom^Ool00`00Oomoo`09Ool00`00Oomoo`0AOol002Yoo`03001oogoo
07Ioo`03001oogoo00Uoo`03001oogoo0?moofioo`03001oogoo01ioo`00:Woo00<007ooOol0MWoo
00<007ooOol02Goo00<007ooOol0ogooKGoo00<007ooOol07goo000ZOol00`00Oomoo`1fOol00`00
Oomoo`08Ool00`00Oomoo`3oOom]Ool00`00Oomoo`0POol002Yoo`03001oogoo07Ioo`03001oogoo
00Ioo`800?moofmoo`03001oogoo025oo`00:Woo00<007ooOol0OWoo00<007ooOol0ogooTgoo000Z
Ool00`00Oomoo`1mOol00`00Oomoo`3oOon4Ool00`00Oomoo`0=Ool002Yoo`03001oogoo07aoo`03
001oogoo0?moohEoo`03001oogoo00eoo`00:Woo00<007ooOol0NWoo0P00ogooRGoo00<007ooOol0
37oo0004Ool40008Ool3000;Ool50007Ool00`00Oomoo`1gOol3003oOom^Ool2000LOol00`00Oomo
o`0;Ool000=oo`03001oogoo009oo`03001oogoo00Eoo`<000eoo`03001oogoo00Moo`03001oogoo
07Eoo`8000Aoo`03001oogoo0?moofUoo`03001oogoo01aoo`03001oogoo00]oo`000goo00<007oo
Ool00Woo00<007ooOol01Goo0`003Goo00<007ooOol01goo00<007ooOol0Lgoo0P001Woo00<007oo
Ool0ogooIgoo0P0087oo00<007ooOol02Woo0002Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool90007
Ool00`00Oomoo`1aOol20009Ool00`00Oomoo`3oOomUOol00`00Oomoo`0POol00`00Oomoo`0:Ool0
009oo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo009oo`03001oogoo00Moo`@006ioo`80
00aoo`03001oogoo0?moof=oo`03001oogoo029oo`03001oogoo00Uoo`000Woo00<007ooOol017oo
00<007ooOol03goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0K7oo0`003goo00<007oo
Ool0ogooTgoo0002Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool01@00Oomoogoo00002Goo00<007oo
Ool0JGoo0`004goo00<007ooOol0ogooTWoo0002Ool00`00Oomoo`04Ool00`00Oomoo`0AOol01000
Oomoo`002Goo00<007ooOol0IGoo10005goo00<007ooOol0ogooTGoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`0AOol01000Oomoo`002Goo00<007ooOol0HWoo0`00ogoo[goo0003Ool00`00Oomoo`02
Ool00`00Oomoo`0COol00`00Ool00009Ool00`00Oomoo`1OOol3003oOomiOol2000gOol000=oo`03
001oogoo009oo`03001oogoo01Aoo`8000Uoo`03001oogoo05aoo`<00?moogUoo`<003Uoo`0017oo
10005goo0P002Goo00<007ooOol0FGoo0`00ogooNWoo0P00?7oo000ZOol00`00Oomoo`1FOol3003o
OomlOol00`00Oomoo`0cOol00`00Oomoo`06Ool002Yoo`03001oogoo055oo`D002moo`800?moohAo
o`03001oogoo00Ioo`00:Woo00<007ooOol0Bgoo1P00=Woo00<007ooOol0ogooPGoo00<007ooOol0
1Woo000ZOol00`00Oomoo`15Ool6000mOol2003oOon2Ool00`00Oomoo`05Ool002Yoo`03001oogoo
041oo`D004Eoo`03001oogoo0?mood1oo`8003eoo`03001oogoo00Eoo`00:Woo00<007ooOol0>goo
1@00Bgoo00<007ooOol0ogoo?Goo0P00?goo00<007ooOol01Goo000ZOol00`00Oomoo`0fOol5003o
Oon=Ool30011Ool00`00Oomoo`05Ool002Yoo`03001oogoo02eoo`T00?mooi5oo`03001oogoo049o
o`03001oogoo00Eoo`00:Woo00<007ooOol08Woo2`00ogooggoo00<007ooOol01Goo000ZOol00`00
Oomoo`0IOol9001`Ool00`00Oomoo`3oOomoOol002Yoo`03001oogoo00moo`X007Yoo`03001oogoo
0?moobUoo`8005=oo`00:Woo4P00QGoo0P00ogoo9Woo0`00EGoo000ZOolC0026Ool3003oOolPOol3
001HOol002Yoo`03001oogoo011oo`X007moo`03001oogoo0?mooaaoo`03001oogoo05Uoo`00:Woo
00<007ooOol06Woo2@00ogoolGoo000ZOol00`00Oomoo`0SOol:003oOooOOol00`00Oomoo`05Ool0
02Yoo`03001oogoo02eoo`T006Yoo`<00?moo`aoo`<005Yoo`03001oogoo00Eoo`00:Woo00<007oo
Ool0=Woo1`00IWoo0P00ogoo1Woo1000GGoo00<007ooOol01Goo000ZOol3000mOol5001SOol3003o
Ool1Ool2001QOol00`00Oomoo`05Ool002Yoo`03001oogoo049oo`D0065oo`03001oogoo0?moof5o
o`03001oogoo00Eoo`00:Woo00<007ooOol0Agoo1@00ogooE7oo0`00J7oo00<007ooOol01Woo000Z
Ool00`00Oomoo`1<Ool5003oOom;Ool4001[Ool00`00Oomoo`06Ool002Yoo`03001oogoo055oo`80
05aoo`<00>Moo`8006moo`03001oogoo00Ioo`00:Woo00<007ooOol0/Woo1000ogooEGoo00<007oo
Ool01Woo000ZOol00`00Oomoo`2fOol2003HOol30020Ool002Yoo`03001oogoo0?mooheoo`@008=o
o`00:Woo00<007ooOol0_Woo0`00bGoo0P00Qgoo000ZOol00`00Oomoo`31Ool4003oOom?Ool002Yo
o`03001oogoo0<Eoo`800;Moo`D0091oo`00:Woo00<007ooOol0cWoo0`00ZGoo1000UGoo000ZOol0
0`00Oomoo`3AOol3003oOom0Ool002Yoo`03001oogoo0=Aoo`8009Uoo`D009=oo`03001oogoo00Uo
o`00:Woo00<007ooOol0gGoo1@00RGoo1000V7oo00<007ooOol02Goo000ZOol00`00Oomoo`3ROol4
001gOol7002ROol00`00Oomoo`0:Ool002Yoo`03001oogoo0>eoo`03001oogoo06]oo`800:Uoo`03
001oogoo00Yoo`00:Woo00<007ooOol0kWoo2000FWoo1000/Woo00<007ooOol02Woo000ZOol00`00
Oomoo`3mOol8000jOol60006Ool5002eOol00`00Oomoo`0;Ool002Yoo`03001oogoo0?moo`eoo`T0
00Moo`T000Moo`T000Moo`<00<Eoo`03001oogoo00aoo`00:Woo00<007ooOol0ogooogoo1Goo00<0
07ooOol03Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo
00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomo
oaEoo`00:Woo00<007ooOol0ogooogoo0Goo00<007ooOol04Goo000ZOol3003oOoooOol1Ool00`00
Oomoo`0AOol002Yoo`03001oogoo0?mooomoo`03001oogoo019oo`00:Woo00<007ooOol0ogoooWoo
00<007ooOol04goo000ZOol00`00Oomoo`3oOoomOol00`00Oomoo`0DOol002Yoo`03001oogoo0?mo
ooaoo`03001oogoo01Eoo`00:Woo00<007ooOol0ogoongoo00<007ooOol05Woo000ZOol00`00Oomo
o`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000Z
Ool00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogoo
m7oo0P007Woo000ZOol00`00Oomoo`3oOoocOol00`00Oomoo`0NOol002Yoo`03001oogoo0?mooo9o
o`03001oogoo01moo`00:Woo00<007ooOol0ogoolGoo00<007ooOol087oo000ZOol00`00Oomoo`3o
Ooo`Ool00`00Oomoo`0QOol002Yoo`03001oogoo0?moonmoo`03001oogoo029oo`00:Woo00<007oo
Ool0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00
:Woo00<007ooOol0ogooj7oo0P00:Woo000ZOol00`00Oomoo`3oOooVOol2000/Ool002Yoo`03001o
ogoo0?moonEoo`03001oogoo02aoo`00:Woo00<007ooOol0ogooi7oo00<007ooOol0;Goo000ZOol0
0`00Oomoo`3oOooSOol00`00Oomoo`0^Ool002Yoo`03001oogoo0?moon9oo`03001oogoo02moo`00
:Woo0`00ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEo
o`00:Woo00<007ooOol0ogoofWoo0P00>7oo000ZOol00`00Oomoo`3oOooGOol3000jOol002Yoo`03
001oogoo0?moomEoo`8003eoo`00:Woo00<007ooOol0ogooe7oo00<007ooOol0?Goo000ZOol00`00
Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo
000ZOol00`00Oomoo`3oOoo<Ool20016Ool002Yoo`03001oogoo0?moolUoo`<004Qoo`00:Woo00<0
07ooOol0ogooagoo0P00Bgoo000ZOol00`00Oomoo`3oOoo6Ool00`00Oomoo`1;Ool002Yoo`03001o
ogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOonnOol2001D
Ool002Yoo`03001oogoo0?mook]oo`<005Ioo`00:Woo00<007ooOol0ogoo^7oo0`00FGoo000ZOol0
0`00Oomoo`3oOongOol00`00Oomoo`1JOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007oo
Ool0ogoo[goo0P00Hgoo0004Ool40008Ool30009Ool4000:Ool00`00Oomoo`3oOon/Ool3001UOol0
00=oo`03001oogoo009oo`03001oogoo00Eoo`<000Qoo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo0?moojYoo`8006Qoo`000goo00<007ooOol00Woo00<007ooOol01Goo0`001goo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol0ogooZ7oo0P00JWoo0002Ool00`00Oomoo`04Ool00`00
Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`3oOoooOolEOol0009oo`03001o
ogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Ioo`@00?mooiioo`<0079oo`00
0Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
ogooVgoo1000MGoo0002Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool20004Ool00`00Oomoo`07Ool0
0`00Oomoo`3oOonIOol2001iOol0009oo`03001oogoo00Aoo`03001oogoo00ioo`03001oo`0000<0
00Yoo`03001oogoo0?mooomooaEoo`000Woo00<007ooOol017oo00<007ooOol03goo00<007ooOol0
37oo00<007ooOol0ogooTGoo0P00PGoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomo
o`0<Ool00`00Oomoo`3oOon=Ool40023Ool000=oo`03001oogoo009oo`03001oogoo015oo`8000ao
o`03001oogoo0?moohYoo`<008Moo`0017oo10005Woo100027oo00<007ooOol0ogooogoo5Goo000Z
Ool00`00Oomoo`3oOomoOol4002AOol002Yoo`03001oogoo0?moogYoo`D009Eoo`00:Woo00<007oo
Ool0ogooLGoo0`00X7oo000ZOol00`00Oomoo`3oOom]Ool4002SOol002Yoo`03001oogoo0?moof]o
o`800:Moo`00:Woo00<007ooOol0ogooGWoo1P00/7oo000ZOol00`00Oomoo`3oOomCOol40004Ool3
002fOol002Yoo`03001oogoo0?moodEoo`@000Moo`<00<5oo`00:Woo00<007ooOol0ogoo=goo0P00
1goo1@00cgoo000ZOol00`00Oomoo`3oOolAOol90007Ool90007Ool6003MOol002Yoo`03001oogoo
0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yo
o`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOooo
OolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00
Oomoo`3oOoooOolEOol002Yoo`<00?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol0
0`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo
5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007oo
Ool0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00
:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mo
oomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03
001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolE
Ool002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomo
o`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000Z
Ool00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogoo
ogoo5Goo000ZOol3003oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0
ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo
00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomo
oaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001o
ogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol0
02Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3o
OoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol0
0`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo
5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007oo
Ool0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00
:Woo0`00ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEo
o`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo
0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yo
o`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOooo
OolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00
Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo
000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0
ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo
00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol000Aoo`@000Qoo`<000Uoo`@0
00Yoo`03001oogoo0?mooomooaEoo`000goo00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol0ogooogoo5Goo0003Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool30007Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`3oOoooOolEOol0009o
o`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo0?mo
oomooaEoo`000Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol01Woo
1000ogooogoo57oo0002Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`3oOoooOolEOol0009oo`03001oogoo00Aoo`03001oogoo00moo`H000Uoo`03
001oogoo0?mooomooaEoo`000Woo00<007ooOol017oo00<007ooOol03goo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol0ogooogoo5Goo0002Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`3oOoooOolEOol000=oo`03001oogoo009oo`03001o
ogoo00moo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo0?mooomooaEoo`000goo00<007oo
Ool00Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogooogoo5Goo
0004Ool4000DOol4000:Ool00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00
:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mo
oomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03
001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolE
Ool002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomo
o`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000Z
Ool00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogoo
ogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`<00?mooomooaEoo`00:Woo00<007ooOol0
ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo
00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomo
oaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001o
ogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol0
02Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3o
OoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol0
0`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo
5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007oo
Ool0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00
:Woo00<007ooOol0ogooogoo5Goo000ZOol3003oOoooOolEOol002Yoo`03001oogoo0?mooomooaEo
o`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo
0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yo
o`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOooo
OolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00
Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo
000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0
ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo
00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomo
oaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001o
ogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol3003oOoooOolEOol002Yoo`03
001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolE
Ool002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomo
o`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000Z
Ool00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<007ooOol0ogoo
ogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEoo`00:Woo00<0
07ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo0?mooomooaEo
o`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol002Yoo`03001oogoo
0?mooomooaEoo`00:Woo00<007ooOol0ogooogoo5Goo000ZOol00`00Oomoo`3oOoooOolEOol001]o
o`L000Qoo`03001oogoo0?mooomooaEoo`007Woo00<007ooOol02Goo00<007ooOol0ogooogoo5Goo
000NOol00`00Oomoo`09Ool00`00Oomoo`3oOoooOolEOol001ioo`03001oogoo00Uoo`03001oogoo
0?mooomooaEoo`007Woo00<007ooOol02Goo1000ogooogoo57oo000NOol00`00Oomoo`3oOoooOolQ
Ool001ioo`03001oogoo0?mooomoob5oo`007Woo00<007ooOol0ogooogoo8Goo000NOol00`00Oomo
o`3oOoooOolQOol001ioo`03001oogoo0?mooomoob5oo`006goo1000ogooogoo8goo000MOol2003o
OoooOolSOol00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo
@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The mass-1 particle can be seen to move considerably farther in the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-direction than the mass-3 particle, as expected from conservation of \
momentum. Both particles drift in the ",
  StyleBox["y",
    FontSlant->"Italic"],
  "-direction, because  the mass-1 particle had an initial ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-velocity, which imparts momentum to the center of mass.  "
}], "Text"],

Cell["\<\
\tThese orbits look a bit more complicated than one might have \
expected - aren't these two bodies simply supposed to perform elliptical \
orbits around the center of mass? The answer is yes, but the orbits look \
different depending on one's frame of reference.  In a frame moving with the \
center of mass, the orbits do look like closed ellipses (see the \
exercises).\
\>", "Text"],

Cell["\<\
\tOf course, the orbits of two gravitating particles can be \
determined analytically, so there is really no need for molecular dynamics. \
However, for three or more bodies, no general analytic solution is available, \
and molecular dynamics is crucial for understanding the motion.  \
\>", "Text"],

Cell[TextData[{
  "\tTake, for example, the solar system.  Table ",
  ButtonBox["1.2",
    ButtonData:>"Table 1.2",
    ButtonStyle->"Hyperlink"],
  " provides the positions and velocities of the major bodies in the solar \
system, with respect to the solar system center of mass, on January 1, 2001.  \
We can use the information in this table as initial conditions to determine \
the subsequent motion of these planetary bodies. "
}], "Text"],

Cell[TextData[{
  "Table 1.2 : Positions and Velocities of Sun and ",
  Cell[BoxData[
      \(TraditionalForm\`Planets\^a\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\^a\)]],
  "On",
  StyleBox["  January 1, 2001, 12 noon GMT, with respect to the solar system \
center of mass\n",
    FontSize->11],
  StyleBox[" Data adapted from the Horizon system at JPL",
    FontSize->8]
}], "Text",
  TextAlignment->Center,
  TextJustification->0,
  CellTags->"Table 1.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(\*"\<\"\"\>" Body\), "\<\"Mass (kg)\"\>", "\<\"\!\(\*
StyleBox[\\\"x\\\",\\nFontSlant->\\\"Italic\\\"]\) (m)\"\>", "\<\"\!\(\*
StyleBox[\\\"y\\\",\\nFontSlant->\\\"Italic\\\"]\) (m)\"\>", "\<\"\!\(\*
StyleBox[\\\"z\\\",\\nFontSlant->\\\"Italic\\\"]\) (m)\"\>", "\<\"\!\(\*
StyleBox[\(v\_x\),\\nFontSlant->\\\"Italic\\\"]\) (m/s)\"\>", "\<\"\!\(\*
StyleBox[\(v\_y\),\\nFontSlant->\\\"Italic\\\"]\) (m/s)\"\>", "\<\"\!\(\*
StyleBox[\(v\_z\),\\nFontSlant->\\\"Italic\\\"]\) (m/s)\"\>"},
          {"\<\"Sun\"\>", "1.9891`*^30", \(-7.0299`*^8\), \(-7.5415`*^8\), 
            "2.38988`*^7", "14.1931`", \(-6.9255`\), \(-0.31676`\)},
          {"\<\"Mercury\"\>", "3.302`*^23", 
            "2.60517`*^10", \(-6.1102`*^10\), \(-7.3616`*^9\), "34796.`", 
            "22185.2`", \(-1379.78`\)},
          {"\<\"Venus\"\>", "4.8685`*^24", "7.2129`*^10", 
            "7.9106`*^10", \(-3.0885`*^9\), \(-25968.7`\), "23441.6`", 
            "1819.92`"},
          {"\<\"Earth\"\>", "5.9736`*^24", \(-2.91204`*^10\), "1.43576`*^11", 
            "2.39614`*^7", \(-29699.8`\), \(-5883.3`\), "0.050215`"},
          {"\<\"Mars\"\>", 
            "6.4185`*^23", \(-2.47064`*^11\), \(-1.03161`*^10\), "5.8788`*^9",
             "1862.73`", \(-22150.6`\), \(-509.6`\)},
          {"\<\"Jupiter\"\>", "1.8986`*^27", "2.67553`*^11", 
            "7.0482`*^11", \(-8.911`*^9\), \(-12376.3`\), "5259.2`", 
            "255.192`"},
          {"\<\"Saturn\"\>", "5.9846`*^26", "6.999`*^11", 
            "1.16781`*^12", \(-4.817`*^10\), \(-8792.6`\), "4944.9`", 
            "263.754`"},
          {"\<\"Uranus\"\>", "1.0243`*^26", "2.65363`*^12", \(-3.6396`*^12\), 
            "1.37957`*^10", "4356.6`", "3233.3`", \(-166.986`\)},
          {"\<\"Neptune\"\>", "8.6832`*^25", 
            "2.2993`*^12", \(-1.90411`*^12\), \(-3.6864`*^10\), "4293.6`", 
            "4928.1`", \(-37.32`\)},
          {"\<\"Pluto\"\>", 
            "1.2700000000000001`*^22", \(-1.31126`*^12\), \(-4.2646`*^12\), 
            "8.3563`*^11", "5316.6`", \(-2484.6`\), \(-1271.99`\)}
          },
        RowSpacings->0.55,
        ColumnSpacings->0.55,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableHeadings -> {{"sun", "mercury", "venus", "earth", 
        "mars", "jupiter", "saturn", "uranus", "neptune", "pluto"}, {
        "mass (kg)", "x (m)", "y (m)", "z (m)", "\!\(v\_x\) (m/sec)", 
        "\!\(v\_y\) (m/sec)", "\!\(v\_z\) (m/sec)"}}, TableSpacing -> 
        0.55000000000000004]&)]], "Text",
  PageWidth->Infinity,
  FontSize->9],

Cell["\<\
This data is also summarized in the following list, which makes it \
easy to use. Each element in the list corresponds to a column entry in the \
Table:\
\>", "Text"],

Cell[BoxData[{
    \(\(sun = {1.9891*^30, \(-7.0299*^8\), \(-7.5415*^8\), 2.38988*^7, 
          14.1931, \(-6.9255\), \(-0.31676\)};\)\), "\n", 
    \(\(mercury = {3.302*^23, 2.60517*^10, \(-6.1102*^10\), \(-7.3616*^9\), 
          34796. , 22185.2, \(-1379.78\)};\)\), "\n", 
    \(\(venus = {4.8685*^24, 7.2129*^10, 
          7.9106*^10, \(-3.0885*^9\), \(-25968.7\), 23441.6, 
          1819.92};\)\), "\n", 
    \(\(earth = {5.9736*^24, \(-2.91204*^10\), 1.43576*^11, 
          2.39614*^7, \(-29699.8\), \(-5883.3\), 0.050215};\)\), "\n", 
    \(\(mars = {6.4185*^23, \(-2.47064*^11\), \(-1.03161*^10\), 5.8788*^9, 
          1862.73, \(-22150.6\), \(-509.6\)};\)\), "\n", 
    \(\(jupiter = {1.8986*^27, 2.67553*^11, 
          7.0482*^11, \(-8.911*^9\), \(-12376.3\), 5259.2, 
          255.192};\)\), "\n", 
    \(\(saturn = {5.9846*^26, 6.999*^11, 
          1.16781*^12, \(-4.817*^10\), \(-8792.6\), 4944.9, 
          263.754};\)\), "\n", 
    \(\(neptune = {8.6832*^25, 2.2993*^12, \(-1.90411*^12\), \(-3.6864*^10\), 
          4293.6, 4928.1, \(-37.32\)};\)\), "\n", 
    \(\(uranus = {1.0243*^26, 2.65363*^12, \(-3.6396*^12\), 1.37957*^10, 
          4356.6, 3233.3, \(-166.986\)};\)\), "\n", 
    \(\(pluto = {1.27*^22, \(-1.31126*^12\), \(-4.2646*^12\), 8.3563*^11, 
          5316.6, \(-2484.6\), \(-1271.99\)};\)\)}], "Input",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ShowCellTags->True,
  CellTags->"Cell 1.57"],

Cell[BoxData[
    \(\(solarsys\  = \ {sun, mercury, venus, earth, mars, jupiter, saturn, 
          uranus, neptune, pluto};\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.58"],

Cell["\<\
Let's use this data to try to answer the following important \
question: is the solar system stable? How do we know that planetary orbits do \
not have a nonzero Lyapunov exponent, so that they may eventually fly off \
their present courses, possibly colliding with one another or with the sun?\
\
\>", "Text",
  CellTags->"i:145"],

Cell[TextData[{
  "\tThere has naturally been a considerable amount of very advanced work on \
this fundamental problem of celestial mechanics. Here, we will simply use our \
molecular dynamics algorithm to solve for the orbits of the planets, proving \
the system is stable over the next three hundred years. This is not very long \
compared to the age of the solar system, but it is about the best we can do \
using ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "unless we are willing to wait for long times for the code to complete.  \
More advanced numerical integrators, run on mainframe computers, have \
evaluated  the orbits over much longer time periods.  "
}], "Text"],

Cell["\<\
\tBecause the inner planets are small and rotate rapidly about the \
sun , we will ignore Mercury, Venus, and Earth  in order to speed up the \
numerical integration.\
\>", "Text"],

Cell["\<\
\tFirst we input the data for the sun and the outer planets into \
the mass list:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mass\  = \ 
      Join[{sun[\([1]\)]}, 
        Table[\(solarsys[\([n]\)]\)[\([1]\)], {n, 5, 
            Length[solarsys]}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.59"],

Cell[BoxData[
    \({1.9891`*^30, 6.4185`*^23, 1.8986`*^27, 5.9846`*^26, 1.0243`*^26, 
      8.6832`*^25, 1.2700000000000001`*^22}\)], "Output"]
}, Open  ]],

Cell["Next,  we create a list of initial conditions:", "Text"],

Cell[BoxData[
    \(\(z0\  = \ 
        Flatten[Join[Table[sun[\([j]\)], {j, 2, 7}], 
            Table[Table[\(solarsys[\([n]\)]\)[\([j]\)], {j, 2, 7}], {n, 5, 
                Length[solarsys]}]]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.60"],

Cell[TextData[{
  "Finally, we define the force , this time keeping the correct magnitude for \
",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(G = \ 6.67\ 10^\(-11\);\)\), "\n", 
    \(F[i_, j_, r_]\  := \ \(-G\)\ mass[\([i]\)]\ mass[\([j]\)] 
        r/\(\(\((r . r)\)^\((3/2)\)\)\(\ \)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.61"],

Cell["\<\
We now run the molecular dynamics code for the planet positions \
forward in time  for 300 years. \
\>", "Text"],

Cell[BoxData[
    \(\(solution1\  = \ MDsol[z0, 300*365*24*3600];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.62"],

Cell[TextData[{
  "This takes quite some time to run, even on a fast machine. In Cell ",
  ButtonBox["1.65",
    ButtonData:>"Cell 1.65",
    ButtonStyle->"Hyperlink"],
  " we plot the orbits in 3D with a parametric plot."
}], "Text"],

Cell[BoxData[
    \(\(Table[{\(x[n]\)[t], \(y[n]\)[t], \(z[n]\)[t]} /. 
          solution1[\([1]\)], {n, 1, 7}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.63"],

Cell[BoxData[
    \(\(orbits\  = 
        Table[ParametricPlot3D[%[\([n]\)], {t, 0, 3\ 10^2\ 365\ 24\ 3600}, 
            PlotPoints \[Rule] 5000, DisplayFunction \[Rule] Identity], {n, 
            1, 7}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.64"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[orbits, DisplayFunction \[Rule] $DisplayFunction, 
        PlotLabel \[Rule] "\<Orbits of the outer planets for 300 years\>", 
        PlotRange \[Rule] All];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.65"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.05125 -0.088886 1.05125 [
[.5 .78309 -125 0 ]
[.5 .78309 125 12 ]
[.13891 .19759 -50.9489 -12.5 ]
[.13891 .19759 .05115 0 ]
[.2723 .1458 -5.73039 -9 ]
[.2723 .1458 .26961 0 ]
[.4126 .09135 -41.0009 -12.5 ]
[.4126 .09135 3.99908 0 ]
[.56036 .03403 -28.6176 -12.5 ]
[.56036 .03403 4.38244 0 ]
[.69787 -0.00176 0 -8.66105 ]
[.69787 -0.00176 39 3.83895 ]
[.76922 .10507 0 -8.51906 ]
[.76922 .10507 51 3.98094 ]
[.83411 .20223 0 -6.04286 ]
[.83411 .20223 6 2.95714 ]
[.89338 .29099 0 -8.27996 ]
[.89338 .29099 45 4.22004 ]
[.94773 .37237 0 -8.17837 ]
[.94773 .37237 33 4.32163 ]
[.01433 .26824 -39 -3.8466 ]
[.01433 .26824 0 8.6534 ]
[.0068 .31629 -39 -3.90138 ]
[.0068 .31629 0 8.59862 ]
[-0.00095 .36579 -6 -2.84976 ]
[-0.00095 .36579 0 6.15024 ]
[-0.00894 .41683 -33 -4.01654 ]
[-0.00894 .41683 0 8.48346 ]
[ 0 0 0 0 ]
[ 1 .77059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .78309 -186 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Orbits) show
105.000 13.000 moveto
(of) show
123.000 13.000 moveto
(the) show
147.000 13.000 moveto
(outer) show
183.000 13.000 moveto
(planets) show
231.000 13.000 moveto
(for) show
255.000 13.000 moveto
(300) show
279.000 13.000 moveto
(years) show
309.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.02819 .25327 m
.68363 0 L
s
.14819 .2069 m
.15283 .21155 L
s
gsave
.13891 .19759 -50.9489 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.28114 .15552 m
.28557 .16038 L
s
[(0)] .2723 .1458 .91013 1 Mshowa
.42095 .1015 m
.42512 .10658 L
s
gsave
.4126 .09135 -41.0009 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.56814 .04462 m
.57203 .04992 L
s
gsave
.56036 .03403 -28.6176 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.125 Mabswid
.17426 .19682 m
.17702 .19964 L
s
.20058 .18665 m
.20332 .18949 L
s
.22717 .17638 m
.22988 .17924 L
s
.25402 .166 m
.2567 .16889 L
s
.30854 .14494 m
.31116 .14788 L
s
.33621 .13424 m
.33881 .13721 L
s
.36417 .12344 m
.36673 .12643 L
s
.39241 .11253 m
.39495 .11555 L
s
.44977 .09036 m
.45225 .09343 L
s
.4789 .07911 m
.48134 .0822 L
s
.50834 .06773 m
.51074 .07086 L
s
.53808 .05624 m
.54045 .05939 L
s
.12238 .21687 m
.12519 .21964 L
s
.09682 .22675 m
.09965 .22949 L
s
.0715 .23653 m
.07436 .23925 L
s
.04643 .24622 m
.04931 .24891 L
s
.59852 .03289 m
.60082 .03609 L
s
.62922 .02102 m
.63148 .02425 L
s
.66026 .00903 m
.66248 .01229 L
s
.25 Mabswid
.68363 0 m
.97692 .43869 L
s
.68561 .00297 m
.67948 .00533 L
s
gsave
.69787 -0.00176 0 -6.66105 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.75687 .10955 m
.75069 .1118 L
s
gsave
.76922 .10507 0 -6.51906 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.82168 .2065 m
.81547 .20863 L
s
[(0)] .83411 .20223 -1 .34286 Mshowa
.88088 .29504 m
.87463 .29707 L
s
gsave
.89338 .29099 0 -6.27996 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.93517 .37625 m
.92889 .37818 L
s
gsave
.94773 .37237 0 -6.17837 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.125 Mabswid
.70042 .02512 m
.69674 .02653 L
s
.71495 .04685 m
.71126 .04824 L
s
.72919 .06815 m
.7255 .06953 L
s
.74316 .08905 m
.73946 .09041 L
s
.77032 .12967 m
.76661 .131 L
s
.78352 .14941 m
.7798 .15073 L
s
.79647 .16879 m
.79275 .17009 L
s
.80919 .18781 m
.80547 .18911 L
s
.83395 .22484 m
.83021 .22611 L
s
.84599 .24286 m
.84226 .24411 L
s
.85783 .26056 m
.85409 .2618 L
s
.86946 .27795 m
.86571 .27918 L
s
.89211 .31184 m
.88836 .31305 L
s
.90315 .32835 m
.8994 .32955 L
s
.91401 .34459 m
.91025 .34577 L
s
.92468 .36055 m
.92091 .36172 L
s
.94549 .39168 m
.94172 .39284 L
s
.95565 .40687 m
.95187 .40801 L
s
.96564 .42181 m
.96186 .42294 L
s
.97546 .43651 m
.97168 .43763 L
s
.25 Mabswid
.02819 .25327 m
0 .43447 L
s
.02659 .26352 m
.03272 .26117 L
s
gsave
.01433 .26824 -39 -1.8466 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.0191 .31166 m
.02525 .30935 L
s
gsave
.0068 .31629 -39 -1.90138 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.01139 .36127 m
.01756 .35901 L
s
[(0)] -0.00095 .36579 1 -0.36672 Mshowa
.00343 .41241 m
.00962 .4102 L
s
gsave
-0.00894 .41683 -33 -2.01654 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.125 Mabswid
.02511 .27304 m
.02879 .27163 L
s
.02362 .28261 m
.02731 .2812 L
s
.02213 .29224 m
.02581 .29084 L
s
.02062 .30192 m
.02431 .30053 L
s
.01758 .32147 m
.02127 .32008 L
s
.01604 .33133 m
.01974 .32995 L
s
.0145 .34125 m
.0182 .33988 L
s
.01295 .35123 m
.01665 .34986 L
s
.00982 .37137 m
.01352 .37002 L
s
.00823 .38154 m
.01194 .38019 L
s
.00664 .39176 m
.01035 .39043 L
s
.00504 .40206 m
.00875 .40072 L
s
.02806 .25407 m
.03174 .25265 L
s
.00181 .42283 m
.00553 .42151 L
s
.00018 .43331 m
.0039 .432 L
s
.25 Mabswid
.02819 .25327 m
0 .43447 L
s
0 .43447 m
.40485 .77059 L
s
.40485 .77059 m
.41018 .60658 L
s
.41018 .60658 m
.02819 .25327 L
s
.68363 0 m
.97692 .43869 L
s
.97692 .43869 m
1 .61171 L
s
1 .61171 m
.69379 .18935 L
s
.69379 .18935 m
.68363 0 L
s
.02819 .25327 m
0 .43447 L
s
0 .43447 m
.69379 .18935 L
s
.69379 .18935 m
.68363 0 L
s
.68363 0 m
.02819 .25327 L
s
.41018 .60658 m
.97692 .43869 L
s
.97692 .43869 m
1 .61171 L
s
1 .61171 m
.40485 .77059 L
s
.40485 .77059 m
.41018 .60658 L
s
0 0 m
1 0 L
1 .77059 L
0 .77059 L
closepath
clip
newpath
.5 Mabswid
.60172 .60787 m
.60132 .60803 L
s
.60212 .60771 m
.60172 .60787 L
s
.60252 .60756 m
.60212 .60771 L
s
.60132 .60803 m
.60092 .60818 L
s
.60292 .6074 m
.60252 .60756 L
s
.60092 .60818 m
.60052 .60834 L
s
.60332 .60724 m
.60292 .6074 L
s
.60052 .60834 m
.60012 .60849 L
s
.60372 .60708 m
.60332 .60724 L
s
.60012 .60849 m
.59972 .60865 L
s
.60412 .60693 m
.60372 .60708 L
s
.59972 .60865 m
.59931 .60881 L
s
.60452 .60677 m
.60412 .60693 L
s
.59931 .60881 m
.59891 .60896 L
s
.60492 .60661 m
.60452 .60677 L
s
.59891 .60896 m
.59851 .60912 L
s
.60532 .60645 m
.60492 .60661 L
s
.59851 .60912 m
.59811 .60927 L
s
.60572 .60629 m
.60532 .60645 L
s
.59811 .60927 m
.5977 .60943 L
s
.60612 .60613 m
.60572 .60629 L
s
.5977 .60943 m
.5973 .60958 L
s
.60652 .60597 m
.60612 .60613 L
s
.5973 .60958 m
.5969 .60973 L
s
.60691 .60581 m
.60652 .60597 L
s
.5969 .60973 m
.59649 .60989 L
s
.60731 .60565 m
.60691 .60581 L
s
.59649 .60989 m
.59609 .61004 L
s
.60771 .60549 m
.60731 .60565 L
s
.59609 .61004 m
.59568 .61019 L
s
.60811 .60533 m
.60771 .60549 L
s
.59568 .61019 m
.59528 .61035 L
s
.6085 .60517 m
.60811 .60533 L
s
.59528 .61035 m
.59488 .6105 L
s
.6089 .60501 m
.6085 .60517 L
s
.59488 .6105 m
.59447 .61065 L
s
.6093 .60485 m
.6089 .60501 L
s
.59447 .61065 m
.59407 .6108 L
s
.60969 .60469 m
.6093 .60485 L
s
.59407 .6108 m
.59366 .61096 L
s
.61009 .60453 m
.60969 .60469 L
s
.59366 .61096 m
.59325 .61111 L
s
.61049 .60436 m
.61009 .60453 L
s
.59325 .61111 m
.59285 .61126 L
s
.61088 .6042 m
.61049 .60436 L
s
.59285 .61126 m
.59244 .61141 L
s
.61128 .60404 m
.61088 .6042 L
s
.59244 .61141 m
.59204 .61156 L
s
.61167 .60388 m
.61128 .60404 L
s
.59204 .61156 m
.59163 .61171 L
s
.61207 .60371 m
.61167 .60388 L
s
.59163 .61171 m
.59122 .61186 L
s
.61246 .60355 m
.61207 .60371 L
s
.59122 .61186 m
.59082 .61201 L
s
.61286 .60339 m
.61246 .60355 L
s
.59082 .61201 m
.59041 .61216 L
s
.61325 .60322 m
.61286 .60339 L
s
.59041 .61216 m
.59 .61231 L
s
.61364 .60306 m
.61325 .60322 L
s
.59 .61231 m
.58959 .61246 L
s
.61404 .6029 m
.61364 .60306 L
s
.58959 .61246 m
.58919 .61261 L
s
.61443 .60273 m
.61404 .6029 L
s
.58919 .61261 m
.58878 .61276 L
s
.61482 .60257 m
.61443 .60273 L
s
.58878 .61276 m
.58837 .61291 L
s
.61522 .6024 m
.61482 .60257 L
s
.58837 .61291 m
.58796 .61306 L
s
.61561 .60224 m
.61522 .6024 L
s
.58796 .61306 m
.58755 .61321 L
s
.616 .60207 m
.61561 .60224 L
s
.58755 .61321 m
.58714 .61335 L
s
.6164 .60191 m
.616 .60207 L
s
.58714 .61335 m
.58674 .6135 L
s
.61679 .60174 m
.6164 .60191 L
s
.58674 .6135 m
.58633 .61365 L
s
.61718 .60158 m
.61679 .60174 L
s
.58633 .61365 m
.58592 .6138 L
s
.61757 .60141 m
.61718 .60158 L
s
.58592 .6138 m
.58551 .61394 L
s
.61796 .60125 m
.61757 .60141 L
s
.58551 .61394 m
.5851 .61409 L
s
.61835 .60108 m
.61796 .60125 L
s
.5851 .61409 m
.58469 .61424 L
s
.61874 .60091 m
.61835 .60108 L
s
.58469 .61424 m
.58428 .61438 L
s
.61913 .60075 m
.61874 .60091 L
s
.58428 .61438 m
.58387 .61453 L
s
.61952 .60058 m
.61913 .60075 L
s
.58387 .61453 m
.58345 .61467 L
s
.61992 .60041 m
.61952 .60058 L
s
.58345 .61467 m
.58304 .61482 L
s
.6203 .60024 m
.61992 .60041 L
s
.58304 .61482 m
.58263 .61496 L
s
.62069 .60008 m
.6203 .60024 L
s
.58263 .61496 m
.58222 .61511 L
s
.62108 .59991 m
.62069 .60008 L
s
.58222 .61511 m
.58181 .61525 L
s
.62147 .59974 m
.62108 .59991 L
s
.58181 .61525 m
.5814 .6154 L
s
.62186 .59957 m
.62147 .59974 L
s
.5814 .6154 m
.58099 .61554 L
s
.62225 .5994 m
.62186 .59957 L
s
.58099 .61554 m
.58057 .61569 L
s
.62264 .59923 m
.62225 .5994 L
s
.58057 .61569 m
.58016 .61583 L
s
.62303 .59906 m
.62264 .59923 L
s
.58016 .61583 m
.57975 .61597 L
s
.62342 .5989 m
.62303 .59906 L
s
.57975 .61597 m
.57933 .61612 L
s
.6238 .59873 m
.62342 .5989 L
s
.57933 .61612 m
.57892 .61626 L
s
.62419 .59856 m
.6238 .59873 L
s
.57892 .61626 m
.57851 .6164 L
s
.62458 .59839 m
.62419 .59856 L
s
.57851 .6164 m
.57809 .61654 L
s
.62496 .59822 m
.62458 .59839 L
s
.62535 .59805 m
.62496 .59822 L
s
.57809 .61654 m
.57768 .61669 L
s
.62574 .59787 m
.62535 .59805 L
s
.57768 .61669 m
.57727 .61683 L
s
.62612 .5977 m
.62574 .59787 L
s
.57727 .61683 m
.57685 .61697 L
s
.62651 .59753 m
.62612 .5977 L
s
.57685 .61697 m
.57644 .61711 L
s
.6269 .59736 m
.62651 .59753 L
s
.57644 .61711 m
.57602 .61725 L
s
.62728 .59719 m
.6269 .59736 L
s
.57602 .61725 m
.57561 .61739 L
s
.62767 .59702 m
.62728 .59719 L
s
.57561 .61739 m
.57519 .61753 L
s
.62805 .59685 m
.62767 .59702 L
s
.57519 .61753 m
.57478 .61767 L
s
.62844 .59667 m
.62805 .59685 L
s
.57478 .61767 m
.57436 .61781 L
s
.62882 .5965 m
.62844 .59667 L
s
.57436 .61781 m
.57395 .61795 L
s
.6292 .59633 m
.62882 .5965 L
s
.57395 .61795 m
.57353 .61809 L
s
.62959 .59616 m
.6292 .59633 L
s
.57353 .61809 m
.57311 .61823 L
s
.62997 .59598 m
.62959 .59616 L
s
.57311 .61823 m
.5727 .61837 L
s
.63036 .59581 m
.62997 .59598 L
s
.5727 .61837 m
.57228 .61851 L
s
.63074 .59564 m
.63036 .59581 L
s
.57228 .61851 m
.57186 .61865 L
s
.63112 .59546 m
.63074 .59564 L
s
.57186 .61865 m
.57145 .61878 L
s
.63151 .59529 m
.63112 .59546 L
s
.57145 .61878 m
.57103 .61892 L
s
.63189 .59511 m
.63151 .59529 L
s
.57103 .61892 m
.57061 .61906 L
s
.63227 .59494 m
.63189 .59511 L
s
.57061 .61906 m
.57019 .6192 L
s
.63265 .59477 m
.63227 .59494 L
s
.57019 .6192 m
.56978 .61933 L
s
.63303 .59459 m
.63265 .59477 L
s
.56978 .61933 m
.56936 .61947 L
s
.63342 .59442 m
.63303 .59459 L
s
.56936 .61947 m
.56894 .61961 L
s
.6338 .59424 m
.63342 .59442 L
s
.56894 .61961 m
.56852 .61974 L
s
.63418 .59407 m
.6338 .59424 L
s
.56852 .61974 m
.5681 .61988 L
s
.63456 .59389 m
.63418 .59407 L
s
.5681 .61988 m
.56768 .62001 L
s
.63494 .59371 m
.63456 .59389 L
s
.56768 .62001 m
.56726 .62015 L
s
.63532 .59354 m
.63494 .59371 L
s
.6357 .59336 m
.63532 .59354 L
s
.56726 .62015 m
.56684 .62028 L
s
.63608 .59318 m
.6357 .59336 L
s
.56684 .62028 m
.56642 .62042 L
s
.63646 .59301 m
.63608 .59318 L
s
.56642 .62042 m
.566 .62055 L
s
.63684 .59283 m
.63646 .59301 L
s
.566 .62055 m
.56558 .62069 L
s
.63722 .59265 m
.63684 .59283 L
s
.56558 .62069 m
.56516 .62082 L
s
.6376 .59248 m
.63722 .59265 L
s
.56516 .62082 m
.56474 .62096 L
s
.63797 .5923 m
.6376 .59248 L
s
.56474 .62096 m
.56432 .62109 L
s
.63835 .59212 m
.63797 .5923 L
s
.56432 .62109 m
.5639 .62122 L
s
.63873 .59194 m
.63835 .59212 L
s
.5639 .62122 m
.56348 .62136 L
s
.63911 .59177 m
.63873 .59194 L
s
.56348 .62136 m
.56306 .62149 L
s
.63949 .59159 m
.63911 .59177 L
s
.56306 .62149 m
.56264 .62162 L
s
.63986 .59141 m
.63949 .59159 L
s
.56264 .62162 m
.56222 .62175 L
s
.64024 .59123 m
.63986 .59141 L
s
.56222 .62175 m
.5618 .62188 L
s
.64062 .59105 m
.64024 .59123 L
s
.5618 .62188 m
.56137 .62202 L
s
.64099 .59087 m
.64062 .59105 L
s
.56137 .62202 m
.56095 .62215 L
s
.64137 .59069 m
.64099 .59087 L
s
.56095 .62215 m
.56053 .62228 L
s
.64175 .59051 m
.64137 .59069 L
s
.56053 .62228 m
.56011 .62241 L
s
.64212 .59033 m
.64175 .59051 L
s
.56011 .62241 m
.55968 .62254 L
s
.6425 .59015 m
.64212 .59033 L
s
.55968 .62254 m
.55926 .62267 L
s
.64287 .58997 m
.6425 .59015 L
s
.55926 .62267 m
.55884 .6228 L
s
.64325 .58979 m
.64287 .58997 L
s
.64362 .58961 m
.64325 .58979 L
s
.55884 .6228 m
.55841 .62293 L
s
.644 .58943 m
.64362 .58961 L
s
.55841 .62293 m
.55799 .62306 L
s
.64437 .58925 m
.644 .58943 L
s
.55799 .62306 m
.55757 .62319 L
s
.64474 .58907 m
.64437 .58925 L
s
.55757 .62319 m
.55714 .62331 L
s
.64512 .58889 m
.64474 .58907 L
s
.55714 .62331 m
.55672 .62344 L
s
.64549 .58871 m
.64512 .58889 L
s
.55672 .62344 m
.55629 .62357 L
s
.64586 .58852 m
.64549 .58871 L
s
.55629 .62357 m
.55587 .6237 L
s
.64624 .58834 m
.64586 .58852 L
s
.55587 .6237 m
.55544 .62383 L
s
.64661 .58816 m
.64624 .58834 L
s
.55544 .62383 m
.55502 .62395 L
s
.64698 .58798 m
.64661 .58816 L
s
.55502 .62395 m
.55459 .62408 L
s
.64735 .58779 m
.64698 .58798 L
s
.55459 .62408 m
.55417 .62421 L
s
.64773 .58761 m
.64735 .58779 L
s
.55417 .62421 m
.55374 .62433 L
s
.6481 .58743 m
.64773 .58761 L
s
.55374 .62433 m
.55332 .62446 L
s
.64847 .58724 m
.6481 .58743 L
s
.55332 .62446 m
.55289 .62459 L
s
.64884 .58706 m
.64847 .58724 L
s
.55289 .62459 m
.55246 .62471 L
s
.64921 .58688 m
.64884 .58706 L
s
.55246 .62471 m
.55204 .62484 L
s
.64958 .58669 m
.64921 .58688 L
s
.64995 .58651 m
.64958 .58669 L
s
.55204 .62484 m
.55161 .62496 L
s
.65032 .58633 m
.64995 .58651 L
s
.55161 .62496 m
.55118 .62509 L
s
.65069 .58614 m
.65032 .58633 L
s
.55118 .62509 m
.55076 .62521 L
s
.65106 .58596 m
.65069 .58614 L
s
.55076 .62521 m
.55033 .62533 L
s
.65143 .58577 m
.65106 .58596 L
s
.55033 .62533 m
.5499 .62546 L
s
.6518 .58559 m
.65143 .58577 L
s
.5499 .62546 m
.54947 .62558 L
s
.65217 .5854 m
.6518 .58559 L
s
.54947 .62558 m
.54905 .62571 L
s
.65254 .58522 m
.65217 .5854 L
s
.54905 .62571 m
.54862 .62583 L
s
.65291 .58503 m
.65254 .58522 L
s
.54862 .62583 m
.54819 .62595 L
s
.65327 .58484 m
.65291 .58503 L
s
.54819 .62595 m
.54776 .62607 L
s
.65364 .58466 m
.65327 .58484 L
s
.54776 .62607 m
.54733 .62619 L
s
.65401 .58447 m
.65364 .58466 L
s
.54733 .62619 m
.5469 .62632 L
s
.65438 .58428 m
.65401 .58447 L
s
.5469 .62632 m
.54648 .62644 L
s
.65474 .5841 m
.65438 .58428 L
s
.54648 .62644 m
.54605 .62656 L
s
.65511 .58391 m
.65474 .5841 L
s
.65548 .58372 m
.65511 .58391 L
s
.54605 .62656 m
.54562 .62668 L
s
.65584 .58354 m
.65548 .58372 L
s
.54562 .62668 m
.54519 .6268 L
s
.65621 .58335 m
.65584 .58354 L
s
.54519 .6268 m
.54476 .62692 L
s
.65658 .58316 m
.65621 .58335 L
s
.54476 .62692 m
.54433 .62704 L
s
.65694 .58297 m
.65658 .58316 L
s
.54433 .62704 m
.5439 .62716 L
s
.65731 .58279 m
.65694 .58297 L
s
.5439 .62716 m
.54347 .62728 L
s
.65767 .5826 m
.65731 .58279 L
s
.54347 .62728 m
.54304 .6274 L
s
.65804 .58241 m
.65767 .5826 L
s
.54304 .6274 m
.54261 .62752 L
s
.6584 .58222 m
.65804 .58241 L
s
.54261 .62752 m
.54217 .62764 L
s
.65876 .58203 m
.6584 .58222 L
s
.54217 .62764 m
.54174 .62775 L
s
.65913 .58184 m
.65876 .58203 L
s
.54174 .62775 m
.54131 .62787 L
s
.65949 .58165 m
.65913 .58184 L
s
.54131 .62787 m
.54088 .62799 L
s
.65985 .58146 m
.65949 .58165 L
s
.54088 .62799 m
.54045 .62811 L
s
.66022 .58127 m
.65985 .58146 L
s
.66058 .58109 m
.66022 .58127 L
s
.54045 .62811 m
.54002 .62822 L
s
.66094 .5809 m
.66058 .58109 L
s
.54002 .62822 m
.53959 .62834 L
s
.6613 .5807 m
.66094 .5809 L
s
.53959 .62834 m
.53915 .62846 L
s
.66167 .58051 m
.6613 .5807 L
s
.53915 .62846 m
.53872 .62857 L
s
.66203 .58032 m
.66167 .58051 L
s
.53872 .62857 m
.53829 .62869 L
s
.66239 .58013 m
.66203 .58032 L
s
.53829 .62869 m
.53786 .6288 L
s
.66275 .57994 m
.66239 .58013 L
s
.53786 .6288 m
.53742 .62892 L
s
.66311 .57975 m
.66275 .57994 L
s
.53742 .62892 m
.53699 .62904 L
s
.66347 .57956 m
.66311 .57975 L
s
.53699 .62904 m
.53656 .62915 L
s
.66383 .57937 m
.66347 .57956 L
s
.53656 .62915 m
.53612 .62926 L
s
.66419 .57918 m
.66383 .57937 L
s
.53612 .62926 m
.53569 .62938 L
s
.66455 .57899 m
.66419 .57918 L
s
.53569 .62938 m
.53526 .62949 L
s
.66491 .57879 m
.66455 .57899 L
s
.66527 .5786 m
.66491 .57879 L
s
.53526 .62949 m
.53482 .6296 L
s
.66563 .57841 m
.66527 .5786 L
s
.53482 .6296 m
.53439 .62972 L
s
.66599 .57822 m
.66563 .57841 L
s
.53439 .62972 m
.53395 .62983 L
s
.66635 .57802 m
.66599 .57822 L
s
.53395 .62983 m
.53352 .62994 L
s
.66671 .57783 m
.66635 .57802 L
s
.53352 .62994 m
.53308 .63006 L
s
.66706 .57764 m
.66671 .57783 L
s
.53308 .63006 m
.53265 .63017 L
s
.66742 .57744 m
.66706 .57764 L
s
.53265 .63017 m
.53221 .63028 L
s
.66778 .57725 m
.66742 .57744 L
s
.53221 .63028 m
.53178 .63039 L
s
.66814 .57706 m
.66778 .57725 L
s
.53178 .63039 m
.53134 .6305 L
s
.66849 .57686 m
.66814 .57706 L
s
.53134 .6305 m
.53091 .63061 L
s
.66885 .57667 m
.66849 .57686 L
s
.53091 .63061 m
.53047 .63072 L
s
.66921 .57647 m
.66885 .57667 L
s
.66956 .57628 m
.66921 .57647 L
s
.53047 .63072 m
.53004 .63083 L
s
.66992 .57608 m
.66956 .57628 L
s
.53004 .63083 m
.5296 .63094 L
s
.67027 .57589 m
.66992 .57608 L
s
.5296 .63094 m
.52916 .63105 L
s
.67063 .57569 m
.67027 .57589 L
s
.52916 .63105 m
.52873 .63116 L
s
.67099 .5755 m
.67063 .57569 L
s
.52873 .63116 m
.52829 .63127 L
s
.67134 .5753 m
.67099 .5755 L
s
.52829 .63127 m
.52785 .63138 L
s
.67169 .57511 m
.67134 .5753 L
s
.52785 .63138 m
.52742 .63148 L
s
.67205 .57491 m
.67169 .57511 L
s
.52742 .63148 m
.52698 .63159 L
s
.6724 .57472 m
.67205 .57491 L
s
.52698 .63159 m
.52654 .6317 L
s
.67276 .57452 m
.6724 .57472 L
s
.52654 .6317 m
.5261 .63181 L
s
.67311 .57432 m
.67276 .57452 L
s
.67346 .57413 m
.67311 .57432 L
s
.5261 .63181 m
.52567 .63191 L
s
.67382 .57393 m
.67346 .57413 L
s
.52567 .63191 m
.52523 .63202 L
s
.67417 .57373 m
.67382 .57393 L
s
.52523 .63202 m
.52479 .63213 L
s
.67452 .57354 m
.67417 .57373 L
s
.52479 .63213 m
.52435 .63223 L
s
.67487 .57334 m
.67452 .57354 L
s
.52435 .63223 m
.52391 .63234 L
s
.67522 .57314 m
.67487 .57334 L
s
.52391 .63234 m
.52347 .63244 L
s
.67558 .57295 m
.67522 .57314 L
s
.52347 .63244 m
.52304 .63255 L
s
.67593 .57275 m
.67558 .57295 L
s
.52304 .63255 m
.5226 .63265 L
s
.67628 .57255 m
.67593 .57275 L
s
.5226 .63265 m
.52216 .63276 L
s
.67663 .57235 m
.67628 .57255 L
s
.52216 .63276 m
.52172 .63286 L
s
.67698 .57215 m
.67663 .57235 L
s
.67733 .57195 m
.67698 .57215 L
s
.52172 .63286 m
.52128 .63296 L
s
.67768 .57176 m
.67733 .57195 L
s
.52128 .63296 m
.52084 .63307 L
s
.67803 .57156 m
.67768 .57176 L
s
.52084 .63307 m
.5204 .63317 L
s
.67838 .57136 m
.67803 .57156 L
s
.5204 .63317 m
.51996 .63327 L
s
.67873 .57116 m
.67838 .57136 L
s
.51996 .63327 m
.51952 .63338 L
s
.67908 .57096 m
.67873 .57116 L
s
.51952 .63338 m
.51908 .63348 L
s
.67942 .57076 m
.67908 .57096 L
s
.51908 .63348 m
.51864 .63358 L
s
.67977 .57056 m
.67942 .57076 L
s
.51864 .63358 m
.5182 .63368 L
s
.68012 .57036 m
.67977 .57056 L
s
.5182 .63368 m
.51776 .63378 L
s
.68047 .57016 m
.68012 .57036 L
s
.68082 .56996 m
.68047 .57016 L
s
.51776 .63378 m
.51732 .63388 L
s
.68116 .56976 m
.68082 .56996 L
s
.51732 .63388 m
.51688 .63398 L
s
.68151 .56956 m
.68116 .56976 L
s
.51688 .63398 m
.51643 .63408 L
s
.68186 .56936 m
.68151 .56956 L
s
.51643 .63408 m
.51599 .63418 L
s
.6822 .56916 m
.68186 .56936 L
s
.51599 .63418 m
.51555 .63428 L
s
.68255 .56896 m
.6822 .56916 L
s
.51555 .63428 m
.51511 .63438 L
s
.68289 .56876 m
.68255 .56896 L
s
.51511 .63438 m
.51467 .63448 L
s
.68324 .56855 m
.68289 .56876 L
s
.51467 .63448 m
.51423 .63458 L
s
.68359 .56835 m
.68324 .56855 L
s
.51423 .63458 m
.51378 .63468 L
s
.68393 .56815 m
.68359 .56835 L
s
.68428 .56795 m
.68393 .56815 L
s
.51378 .63468 m
.51334 .63477 L
s
.68462 .56775 m
.68428 .56795 L
s
.51334 .63477 m
.5129 .63487 L
s
.68496 .56754 m
.68462 .56775 L
s
.5129 .63487 m
.51246 .63497 L
s
.68531 .56734 m
.68496 .56754 L
s
.51246 .63497 m
.51201 .63507 L
s
.68565 .56714 m
.68531 .56734 L
s
.51201 .63507 m
.51157 .63516 L
s
.68599 .56694 m
.68565 .56714 L
s
.51157 .63516 m
.51113 .63526 L
s
.68634 .56673 m
.68599 .56694 L
s
.51113 .63526 m
.51068 .63535 L
s
.68668 .56653 m
.68634 .56673 L
s
.51068 .63535 m
.51024 .63545 L
s
.68702 .56633 m
.68668 .56653 L
s
.68736 .56612 m
.68702 .56633 L
s
.51024 .63545 m
.5098 .63555 L
s
.68771 .56592 m
.68736 .56612 L
s
.5098 .63555 m
.50935 .63564 L
s
.68805 .56572 m
.68771 .56592 L
s
.50935 .63564 m
.50891 .63573 L
s
.68839 .56551 m
.68805 .56572 L
s
.50891 .63573 m
.50846 .63583 L
s
.68873 .56531 m
.68839 .56551 L
s
.50846 .63583 m
.50802 .63592 L
s
.68907 .5651 m
.68873 .56531 L
s
.50802 .63592 m
.50757 .63602 L
s
.68941 .5649 m
.68907 .5651 L
s
.50757 .63602 m
.50713 .63611 L
s
.68975 .56469 m
.68941 .5649 L
s
.50713 .63611 m
.50668 .6362 L
s
.69009 .56449 m
.68975 .56469 L
s
.69043 .56428 m
.69009 .56449 L
s
.50668 .6362 m
.50624 .63629 L
s
.69077 .56408 m
.69043 .56428 L
s
.50624 .63629 m
.50579 .63639 L
s
.69111 .56387 m
.69077 .56408 L
s
.50579 .63639 m
.50535 .63648 L
s
.69145 .56367 m
.69111 .56387 L
s
.50535 .63648 m
.5049 .63657 L
s
.69179 .56346 m
.69145 .56367 L
s
.5049 .63657 m
.50446 .63666 L
s
.69213 .56326 m
.69179 .56346 L
s
.50446 .63666 m
.50401 .63675 L
s
.69246 .56305 m
.69213 .56326 L
s
.50401 .63675 m
.50357 .63684 L
s
.6928 .56284 m
.69246 .56305 L
s
.50357 .63684 m
.50312 .63693 L
s
.69314 .56264 m
.6928 .56284 L
s
.69348 .56243 m
.69314 .56264 L
s
.50312 .63693 m
.50267 .63702 L
s
.69381 .56222 m
.69348 .56243 L
s
.50267 .63702 m
.50223 .63711 L
s
.69415 .56202 m
.69381 .56222 L
s
.50223 .63711 m
.50178 .6372 L
s
.69449 .56181 m
.69415 .56202 L
s
.50178 .6372 m
.50134 .63729 L
s
.69482 .5616 m
.69449 .56181 L
s
.50134 .63729 m
.50089 .63738 L
s
.69516 .56139 m
.69482 .5616 L
s
.50089 .63738 m
.50044 .63746 L
s
.69549 .56119 m
.69516 .56139 L
s
.50044 .63746 m
.49999 .63755 L
s
.69583 .56098 m
.69549 .56119 L
s
.69616 .56077 m
.69583 .56098 L
s
.49999 .63755 m
.49955 .63764 L
s
.6965 .56056 m
.69616 .56077 L
s
.49955 .63764 m
.4991 .63773 L
s
.69683 .56036 m
.6965 .56056 L
s
.4991 .63773 m
.49865 .63781 L
s
.69717 .56015 m
.69683 .56036 L
s
.49865 .63781 m
.4982 .6379 L
s
.6975 .55994 m
.69717 .56015 L
s
.4982 .6379 m
.49776 .63799 L
s
.69783 .55973 m
.6975 .55994 L
s
.49776 .63799 m
.49731 .63807 L
s
.69817 .55952 m
.69783 .55973 L
s
.49731 .63807 m
.49686 .63816 L
s
.6985 .55931 m
.69817 .55952 L
s
.69883 .5591 m
.6985 .55931 L
s
.49686 .63816 m
.49641 .63824 L
s
.69916 .55889 m
.69883 .5591 L
s
.49641 .63824 m
.49596 .63833 L
s
.6995 .55868 m
.69916 .55889 L
s
.49596 .63833 m
.49552 .63841 L
s
.69983 .55847 m
.6995 .55868 L
s
.49552 .63841 m
.49507 .63849 L
s
.70016 .55826 m
.69983 .55847 L
s
.49507 .63849 m
.49462 .63858 L
s
.70049 .55805 m
.70016 .55826 L
s
.49462 .63858 m
.49417 .63866 L
s
.70082 .55784 m
.70049 .55805 L
s
.49417 .63866 m
.49372 .63874 L
s
.70115 .55763 m
.70082 .55784 L
s
.70148 .55742 m
.70115 .55763 L
s
.49372 .63874 m
.49327 .63883 L
s
.70181 .55721 m
.70148 .55742 L
s
.49327 .63883 m
.49282 .63891 L
s
.70214 .557 m
.70181 .55721 L
s
.49282 .63891 m
.49237 .63899 L
s
.70247 .55679 m
.70214 .557 L
s
.49237 .63899 m
.49192 .63907 L
s
.7028 .55658 m
.70247 .55679 L
s
.49192 .63907 m
.49147 .63915 L
s
.70313 .55637 m
.7028 .55658 L
s
.49147 .63915 m
.49102 .63923 L
s
.70346 .55616 m
.70313 .55637 L
s
.49102 .63923 m
.49057 .63931 L
s
.70379 .55594 m
.70346 .55616 L
s
.70411 .55573 m
.70379 .55594 L
s
.49057 .63931 m
.49012 .63939 L
s
.70444 .55552 m
.70411 .55573 L
s
.49012 .63939 m
.48967 .63947 L
s
.70477 .55531 m
.70444 .55552 L
s
.48967 .63947 m
.48922 .63955 L
s
.7051 .5551 m
.70477 .55531 L
s
.48922 .63955 m
.48877 .63963 L
s
.70542 .55488 m
.7051 .5551 L
s
.48877 .63963 m
.48832 .63971 L
s
.70575 .55467 m
.70542 .55488 L
s
.48832 .63971 m
.48787 .63979 L
s
.70608 .55446 m
.70575 .55467 L
s
.48787 .63979 m
.48742 .63986 L
s
.7064 .55425 m
.70608 .55446 L
s
.70673 .55403 m
.7064 .55425 L
s
.48742 .63986 m
.48697 .63994 L
s
.70705 .55382 m
.70673 .55403 L
s
.48697 .63994 m
.48652 .64002 L
s
.70738 .55361 m
.70705 .55382 L
s
.48652 .64002 m
.48606 .6401 L
s
.7077 .55339 m
.70738 .55361 L
s
.48606 .6401 m
.48561 .64017 L
s
.70803 .55318 m
.7077 .55339 L
s
.48561 .64017 m
.48516 .64025 L
s
.70835 .55297 m
.70803 .55318 L
s
.48516 .64025 m
.48471 .64032 L
s
.70868 .55275 m
.70835 .55297 L
s
.709 .55254 m
.70868 .55275 L
s
.48471 .64032 m
.48426 .6404 L
s
.70932 .55232 m
.709 .55254 L
s
.48426 .6404 m
.48381 .64047 L
s
.70965 .55211 m
.70932 .55232 L
s
.48381 .64047 m
.48335 .64055 L
s
.70997 .55189 m
.70965 .55211 L
s
.48335 .64055 m
.4829 .64062 L
s
.71029 .55168 m
.70997 .55189 L
s
.4829 .64062 m
.48245 .6407 L
s
.71061 .55146 m
.71029 .55168 L
s
.48245 .6407 m
.482 .64077 L
s
.71094 .55125 m
.71061 .55146 L
s
.71126 .55103 m
.71094 .55125 L
s
.482 .64077 m
.48154 .64084 L
s
.71158 .55082 m
.71126 .55103 L
s
.48154 .64084 m
.48109 .64091 L
s
.7119 .5506 m
.71158 .55082 L
s
.48109 .64091 m
.48064 .64099 L
s
.71222 .55039 m
.7119 .5506 L
s
.48064 .64099 m
.48018 .64106 L
s
.71254 .55017 m
.71222 .55039 L
s
.48018 .64106 m
.47973 .64113 L
s
.71286 .54996 m
.71254 .55017 L
s
.47973 .64113 m
.47928 .6412 L
s
.71318 .54974 m
.71286 .54996 L
s
.7135 .54952 m
.71318 .54974 L
s
.47928 .6412 m
.47882 .64127 L
s
.71382 .54931 m
.7135 .54952 L
s
.47882 .64127 m
.47837 .64134 L
s
.71414 .54909 m
.71382 .54931 L
s
.47837 .64134 m
.47792 .64141 L
s
.71446 .54887 m
.71414 .54909 L
s
.47792 .64141 m
.47746 .64148 L
s
.71478 .54866 m
.71446 .54887 L
s
.47746 .64148 m
.47701 .64155 L
s
.71509 .54844 m
.71478 .54866 L
s
.47701 .64155 m
.47655 .64162 L
s
.71541 .54822 m
.71509 .54844 L
s
.71573 .54801 m
.71541 .54822 L
s
.47655 .64162 m
.4761 .64169 L
s
.71605 .54779 m
.71573 .54801 L
s
.4761 .64169 m
.47565 .64176 L
s
.71636 .54757 m
.71605 .54779 L
s
.47565 .64176 m
.47519 .64183 L
s
.71668 .54735 m
.71636 .54757 L
s
.47519 .64183 m
.47474 .64189 L
s
.717 .54713 m
.71668 .54735 L
s
.47474 .64189 m
.47428 .64196 L
s
.71731 .54692 m
.717 .54713 L
s
.47428 .64196 m
.47383 .64203 L
s
.71763 .5467 m
.71731 .54692 L
s
.71794 .54648 m
.71763 .5467 L
s
.47383 .64203 m
.47337 .64209 L
s
.71826 .54626 m
.71794 .54648 L
s
.47337 .64209 m
.47292 .64216 L
s
.71857 .54604 m
.71826 .54626 L
s
.47292 .64216 m
.47246 .64222 L
s
.71889 .54582 m
.71857 .54604 L
s
.47246 .64222 m
.47201 .64229 L
s
.7192 .54561 m
.71889 .54582 L
s
.47201 .64229 m
.47155 .64235 L
s
.71952 .54539 m
.7192 .54561 L
s
.47155 .64235 m
.4711 .64242 L
s
.71983 .54517 m
.71952 .54539 L
s
.72014 .54495 m
.71983 .54517 L
s
.4711 .64242 m
.47064 .64248 L
s
.72046 .54473 m
.72014 .54495 L
s
.47064 .64248 m
.47019 .64255 L
s
.72077 .54451 m
.72046 .54473 L
s
.47019 .64255 m
.46973 .64261 L
s
.72108 .54429 m
.72077 .54451 L
s
.46973 .64261 m
.46927 .64267 L
s
.72139 .54407 m
.72108 .54429 L
s
.46927 .64267 m
.46882 .64273 L
s
.72171 .54385 m
.72139 .54407 L
s
.72202 .54363 m
.72171 .54385 L
s
.46882 .64273 m
.46836 .6428 L
s
.72233 .54341 m
.72202 .54363 L
s
.46836 .6428 m
.46791 .64286 L
s
.72264 .54319 m
.72233 .54341 L
s
.46791 .64286 m
.46745 .64292 L
s
.72295 .54297 m
.72264 .54319 L
s
.46745 .64292 m
.46699 .64298 L
s
.72326 .54275 m
.72295 .54297 L
s
.46699 .64298 m
.46654 .64304 L
s
.72357 .54252 m
.72326 .54275 L
s
.46654 .64304 m
.46608 .6431 L
s
.72388 .5423 m
.72357 .54252 L
s
.72419 .54208 m
.72388 .5423 L
s
.46608 .6431 m
.46562 .64316 L
s
.7245 .54186 m
.72419 .54208 L
s
.46562 .64316 m
.46517 .64322 L
s
.72481 .54164 m
.7245 .54186 L
s
.46517 .64322 m
.46471 .64328 L
s
.72512 .54142 m
.72481 .54164 L
s
.46471 .64328 m
.46425 .64334 L
s
.72543 .5412 m
.72512 .54142 L
s
.46425 .64334 m
.46379 .6434 L
s
.72573 .54097 m
.72543 .5412 L
s
.72604 .54075 m
.72573 .54097 L
s
.46379 .6434 m
.46334 .64345 L
s
.72635 .54053 m
.72604 .54075 L
s
.46334 .64345 m
.46288 .64351 L
s
.72666 .54031 m
.72635 .54053 L
s
.46288 .64351 m
.46242 .64357 L
s
.72696 .54008 m
.72666 .54031 L
s
.46242 .64357 m
.46196 .64363 L
s
.72727 .53986 m
.72696 .54008 L
s
.46196 .64363 m
.46151 .64368 L
s
.72758 .53964 m
.72727 .53986 L
s
.46151 .64368 m
.46105 .64374 L
s
.72788 .53942 m
.72758 .53964 L
s
.72819 .53919 m
.72788 .53942 L
s
.46105 .64374 m
.46059 .64379 L
s
.72849 .53897 m
.72819 .53919 L
s
.46059 .64379 m
.46013 .64385 L
s
.7288 .53875 m
.72849 .53897 L
s
.46013 .64385 m
.45967 .6439 L
s
.7291 .53852 m
.7288 .53875 L
s
.45967 .6439 m
.45922 .64396 L
s
.72941 .5383 m
.7291 .53852 L
s
.45922 .64396 m
.45876 .64401 L
s
.72971 .53807 m
.72941 .5383 L
s
.73002 .53785 m
.72971 .53807 L
s
.45876 .64401 m
.4583 .64406 L
s
.73032 .53763 m
.73002 .53785 L
s
.4583 .64406 m
.45784 .64412 L
s
.73062 .5374 m
.73032 .53763 L
s
.45784 .64412 m
.45738 .64417 L
s
.73093 .53718 m
.73062 .5374 L
s
.45738 .64417 m
.45692 .64422 L
s
.73123 .53695 m
.73093 .53718 L
s
.45692 .64422 m
.45647 .64427 L
s
.73153 .53673 m
.73123 .53695 L
s
.73183 .5365 m
.73153 .53673 L
s
.45647 .64427 m
.45601 .64433 L
s
.73213 .53628 m
.73183 .5365 L
s
.45601 .64433 m
.45555 .64438 L
s
.73244 .53605 m
.73213 .53628 L
s
.45555 .64438 m
.45509 .64443 L
s
.73274 .53583 m
.73244 .53605 L
s
.45509 .64443 m
.45463 .64448 L
s
.73304 .5356 m
.73274 .53583 L
s
.45463 .64448 m
.45417 .64453 L
s
.73334 .53538 m
.73304 .5356 L
s
.73364 .53515 m
.73334 .53538 L
s
.45417 .64453 m
.45371 .64458 L
s
.73394 .53493 m
.73364 .53515 L
s
.45371 .64458 m
.45325 .64463 L
s
.73424 .5347 m
.73394 .53493 L
s
.45325 .64463 m
.45279 .64467 L
s
.73454 .53447 m
.73424 .5347 L
s
.45279 .64467 m
.45233 .64472 L
s
.73484 .53425 m
.73454 .53447 L
s
.45233 .64472 m
.45187 .64477 L
s
.73513 .53402 m
.73484 .53425 L
s
.73543 .5338 m
.73513 .53402 L
s
.45187 .64477 m
.45141 .64482 L
s
.73573 .53357 m
.73543 .5338 L
s
.45141 .64482 m
.45095 .64487 L
s
.73603 .53334 m
.73573 .53357 L
s
.45095 .64487 m
.45049 .64491 L
s
.73633 .53312 m
.73603 .53334 L
s
.45049 .64491 m
.45003 .64496 L
s
.73662 .53289 m
.73633 .53312 L
s
.45003 .64496 m
.44957 .645 L
s
.73692 .53266 m
.73662 .53289 L
s
.73722 .53243 m
.73692 .53266 L
s
.44957 .645 m
.44911 .64505 L
s
.73751 .53221 m
.73722 .53243 L
s
.44911 .64505 m
.44865 .64509 L
s
.73781 .53198 m
.73751 .53221 L
s
.44865 .64509 m
.44819 .64514 L
s
.7381 .53175 m
.73781 .53198 L
s
.44819 .64514 m
.44773 .64518 L
s
.7384 .53152 m
.7381 .53175 L
s
.73869 .5313 m
.7384 .53152 L
s
.44773 .64518 m
.44727 .64523 L
s
.73899 .53107 m
.73869 .5313 L
s
.44727 .64523 m
.44681 .64527 L
s
.73928 .53084 m
.73899 .53107 L
s
.44681 .64527 m
.44635 .64531 L
s
.73958 .53061 m
.73928 .53084 L
s
.44635 .64531 m
.44589 .64536 L
s
.73987 .53038 m
.73958 .53061 L
s
.44589 .64536 m
.44543 .6454 L
s
.74016 .53015 m
.73987 .53038 L
s
.74046 .52993 m
.74016 .53015 L
s
.44543 .6454 m
.44497 .64544 L
s
.74075 .5297 m
.74046 .52993 L
s
.44497 .64544 m
.44451 .64548 L
s
.74104 .52947 m
.74075 .5297 L
s
.44451 .64548 m
.44404 .64552 L
s
.74134 .52924 m
.74104 .52947 L
s
.44404 .64552 m
.44358 .64556 L
s
.74163 .52901 m
.74134 .52924 L
s
.44358 .64556 m
.44312 .6456 L
s
.74192 .52878 m
.74163 .52901 L
s
.74221 .52855 m
.74192 .52878 L
s
.44312 .6456 m
.44266 .64564 L
s
.7425 .52832 m
.74221 .52855 L
s
.44266 .64564 m
.4422 .64568 L
s
.74279 .52809 m
.7425 .52832 L
s
.4422 .64568 m
.44174 .64572 L
s
.74308 .52786 m
.74279 .52809 L
s
.44174 .64572 m
.44128 .64576 L
s
.74337 .52763 m
.74308 .52786 L
s
.74366 .5274 m
.74337 .52763 L
s
.44128 .64576 m
.44082 .64579 L
s
.74395 .52717 m
.74366 .5274 L
s
.44082 .64579 m
.44035 .64583 L
s
.74424 .52694 m
.74395 .52717 L
s
.44035 .64583 m
.43989 .64587 L
s
.74453 .52671 m
.74424 .52694 L
s
.43989 .64587 m
.43943 .64591 L
s
.74482 .52648 m
.74453 .52671 L
s
.43943 .64591 m
.43897 .64594 L
s
.74511 .52625 m
.74482 .52648 L
s
.74539 .52602 m
.74511 .52625 L
s
.43897 .64594 m
.43851 .64598 L
s
.74568 .52579 m
.74539 .52602 L
s
.43851 .64598 m
.43804 .64601 L
s
.74597 .52556 m
.74568 .52579 L
s
.43804 .64601 m
.43758 .64605 L
s
.74626 .52532 m
.74597 .52556 L
s
.43758 .64605 m
.43712 .64608 L
s
.74654 .52509 m
.74626 .52532 L
s
.74683 .52486 m
.74654 .52509 L
s
.43712 .64608 m
.43666 .64612 L
s
.74711 .52463 m
.74683 .52486 L
s
.43666 .64612 m
.4362 .64615 L
s
.7474 .5244 m
.74711 .52463 L
s
.4362 .64615 m
.43573 .64618 L
s
.74769 .52417 m
.7474 .5244 L
s
.43573 .64618 m
.43527 .64622 L
s
.74797 .52393 m
.74769 .52417 L
s
.43527 .64622 m
.43481 .64625 L
s
.74826 .5237 m
.74797 .52393 L
s
.74854 .52347 m
.74826 .5237 L
s
.43481 .64625 m
.43435 .64628 L
s
.74882 .52324 m
.74854 .52347 L
s
.43435 .64628 m
.43388 .64631 L
s
.74911 .523 m
.74882 .52324 L
s
.43388 .64631 m
.43342 .64634 L
s
.74939 .52277 m
.74911 .523 L
s
.43342 .64634 m
.43296 .64637 L
s
.74967 .52254 m
.74939 .52277 L
s
.74996 .52231 m
.74967 .52254 L
s
.43296 .64637 m
.4325 .6464 L
s
.75024 .52207 m
.74996 .52231 L
s
.4325 .6464 m
.43203 .64643 L
s
.75052 .52184 m
.75024 .52207 L
s
.43203 .64643 m
.43157 .64646 L
s
.7508 .52161 m
.75052 .52184 L
s
.43157 .64646 m
.43111 .64649 L
s
.75109 .52137 m
.7508 .52161 L
s
.75137 .52114 m
.75109 .52137 L
s
.43111 .64649 m
.43064 .64652 L
s
.75165 .52091 m
.75137 .52114 L
s
.43064 .64652 m
.43018 .64655 L
s
.75193 .52067 m
.75165 .52091 L
s
.43018 .64655 m
.42972 .64658 L
s
.75221 .52044 m
.75193 .52067 L
s
.42972 .64658 m
.42926 .6466 L
s
.75249 .5202 m
.75221 .52044 L
s
.42926 .6466 m
.42879 .64663 L
s
.75277 .51997 m
.75249 .5202 L
s
.75305 .51974 m
.75277 .51997 L
s
.42879 .64663 m
.42833 .64666 L
s
.75333 .5195 m
.75305 .51974 L
s
.42833 .64666 m
.42787 .64668 L
s
.75361 .51927 m
.75333 .5195 L
s
.42787 .64668 m
.4274 .64671 L
s
.75388 .51903 m
.75361 .51927 L
s
.4274 .64671 m
.42694 .64673 L
s
.75416 .5188 m
.75388 .51903 L
s
.75444 .51856 m
.75416 .5188 L
s
.42694 .64673 m
.42648 .64676 L
s
.75472 .51833 m
.75444 .51856 L
s
.42648 .64676 m
.42601 .64678 L
s
.75499 .51809 m
.75472 .51833 L
s
.42601 .64678 m
.42555 .6468 L
s
.75527 .51786 m
.75499 .51809 L
s
.42555 .6468 m
.42509 .64683 L
s
.75555 .51762 m
.75527 .51786 L
s
.75582 .51739 m
.75555 .51762 L
s
.42509 .64683 m
.42462 .64685 L
s
.7561 .51715 m
.75582 .51739 L
s
.42462 .64685 m
.42416 .64687 L
s
.75638 .51692 m
.7561 .51715 L
s
.42416 .64687 m
.42369 .64689 L
s
.75665 .51668 m
.75638 .51692 L
s
.42369 .64689 m
.42323 .64691 L
s
.75693 .51644 m
.75665 .51668 L
s
.7572 .51621 m
.75693 .51644 L
s
.42323 .64691 m
.42277 .64694 L
s
.75747 .51597 m
.7572 .51621 L
s
.42277 .64694 m
.4223 .64696 L
s
.75775 .51573 m
.75747 .51597 L
s
.4223 .64696 m
.42184 .64698 L
s
.75802 .5155 m
.75775 .51573 L
s
.42184 .64698 m
.42138 .647 L
s
.7583 .51526 m
.75802 .5155 L
s
.75857 .51503 m
.7583 .51526 L
s
.42138 .647 m
.42091 .64701 L
s
.75884 .51479 m
.75857 .51503 L
s
.42091 .64701 m
.42045 .64703 L
s
.75911 .51455 m
.75884 .51479 L
s
.42045 .64703 m
.41998 .64705 L
s
.75939 .51431 m
.75911 .51455 L
s
.41998 .64705 m
.41952 .64707 L
s
.75966 .51408 m
.75939 .51431 L
s
.75993 .51384 m
.75966 .51408 L
s
.41952 .64707 m
.41906 .64709 L
s
.7602 .5136 m
.75993 .51384 L
s
.41906 .64709 m
.41859 .6471 L
s
.76047 .51337 m
.7602 .5136 L
s
.41859 .6471 m
.41813 .64712 L
s
.76074 .51313 m
.76047 .51337 L
s
.41813 .64712 m
.41766 .64714 L
s
.76101 .51289 m
.76074 .51313 L
s
.76128 .51265 m
.76101 .51289 L
s
.41766 .64714 m
.4172 .64715 L
s
.76155 .51241 m
.76128 .51265 L
s
.4172 .64715 m
.41674 .64717 L
s
.76182 .51218 m
.76155 .51241 L
s
.41674 .64717 m
.41627 .64718 L
s
.76209 .51194 m
.76182 .51218 L
s
.41627 .64718 m
.41581 .64719 L
s
.76236 .5117 m
.76209 .51194 L
s
.76263 .51146 m
.76236 .5117 L
s
.41581 .64719 m
.41534 .64721 L
s
.76289 .51122 m
.76263 .51146 L
s
.41534 .64721 m
.41488 .64722 L
s
.76316 .51098 m
.76289 .51122 L
s
.41488 .64722 m
.41441 .64723 L
s
.76343 .51075 m
.76316 .51098 L
s
.41441 .64723 m
.41395 .64725 L
s
.7637 .51051 m
.76343 .51075 L
s
.76396 .51027 m
.7637 .51051 L
s
.41395 .64725 m
.41349 .64726 L
s
.76423 .51003 m
.76396 .51027 L
s
.41349 .64726 m
.41302 .64727 L
s
.76449 .50979 m
.76423 .51003 L
s
.41302 .64727 m
.41256 .64728 L
s
.76476 .50955 m
.76449 .50979 L
s
.41256 .64728 m
.41209 .64729 L
s
.76502 .50931 m
.76476 .50955 L
s
.76529 .50907 m
.76502 .50931 L
s
.41209 .64729 m
.41163 .6473 L
s
.76555 .50883 m
.76529 .50907 L
s
.41163 .6473 m
.41116 .64731 L
s
.76582 .50859 m
.76555 .50883 L
s
.41116 .64731 m
.4107 .64732 L
s
.76608 .50835 m
.76582 .50859 L
s
.76635 .50811 m
.76608 .50835 L
s
.4107 .64732 m
.41024 .64733 L
s
.76661 .50787 m
.76635 .50811 L
s
.41024 .64733 m
.40977 .64734 L
s
.76687 .50763 m
.76661 .50787 L
s
.40977 .64734 m
.40931 .64734 L
s
.76713 .50739 m
.76687 .50763 L
s
.40931 .64734 m
.40884 .64735 L
s
.7674 .50715 m
.76713 .50739 L
s
.76766 .50691 m
.7674 .50715 L
s
.40884 .64735 m
.40838 .64736 L
s
.76792 .50667 m
.76766 .50691 L
s
.40838 .64736 m
.40791 .64736 L
s
.76818 .50643 m
.76792 .50667 L
s
.40791 .64736 m
.40745 .64737 L
s
.76844 .50619 m
.76818 .50643 L
s
.40745 .64737 m
.40698 .64737 L
s
.7687 .50595 m
.76844 .50619 L
s
.76896 .50571 m
.7687 .50595 L
s
.40698 .64737 m
.40652 .64738 L
s
.76922 .50546 m
.76896 .50571 L
s
.40652 .64738 m
.40605 .64738 L
s
.76948 .50522 m
.76922 .50546 L
s
.40605 .64738 m
.40559 .64739 L
s
.76974 .50498 m
.76948 .50522 L
s
.40559 .64739 m
.40513 .64739 L
s
.77 .50474 m
.76974 .50498 L
s
.77026 .5045 m
.77 .50474 L
s
.40513 .64739 m
.40466 .64739 L
s
.77052 .50426 m
.77026 .5045 L
s
.40466 .64739 m
.4042 .64739 L
s
.77078 .50402 m
.77052 .50426 L
s
.4042 .64739 m
.40373 .6474 L
s
.77104 .50377 m
.77078 .50402 L
s
.77129 .50353 m
.77104 .50377 L
s
.40373 .6474 m
.40327 .6474 L
s
.77155 .50329 m
.77129 .50353 L
s
.40327 .6474 m
.4028 .6474 L
s
.77181 .50305 m
.77155 .50329 L
s
.4028 .6474 m
.40234 .6474 L
s
.77206 .5028 m
.77181 .50305 L
s
.40234 .6474 m
.40187 .6474 L
s
.77232 .50256 m
.77206 .5028 L
s
.77258 .50232 m
.77232 .50256 L
s
.40187 .6474 m
.40141 .6474 L
s
.77283 .50208 m
.77258 .50232 L
s
.40141 .6474 m
.40094 .6474 L
s
.77309 .50183 m
.77283 .50208 L
s
.40094 .6474 m
.40048 .6474 L
s
.77334 .50159 m
.77309 .50183 L
s
.40048 .6474 m
.40002 .64739 L
s
.77359 .50135 m
.77334 .50159 L
s
.77385 .50111 m
.77359 .50135 L
s
.40002 .64739 m
.39955 .64739 L
s
.7741 .50086 m
.77385 .50111 L
s
.39955 .64739 m
.39909 .64739 L
s
.77436 .50062 m
.7741 .50086 L
s
.39909 .64739 m
.39862 .64739 L
s
.77461 .50038 m
.77436 .50062 L
s
.77486 .50013 m
.77461 .50038 L
s
.39862 .64739 m
.39816 .64738 L
s
.77511 .49989 m
.77486 .50013 L
s
.39816 .64738 m
.39769 .64738 L
s
.77537 .49964 m
.77511 .49989 L
s
.39769 .64738 m
.39723 .64737 L
s
.77562 .4994 m
.77537 .49964 L
s
.39723 .64737 m
.39676 .64737 L
s
.77587 .49916 m
.77562 .4994 L
s
.77612 .49891 m
.77587 .49916 L
s
.39676 .64737 m
.3963 .64736 L
s
.77637 .49867 m
.77612 .49891 L
s
.3963 .64736 m
.39584 .64735 L
s
.77662 .49842 m
.77637 .49867 L
s
.39584 .64735 m
.39537 .64735 L
s
.77687 .49818 m
.77662 .49842 L
s
.77712 .49794 m
.77687 .49818 L
s
.39537 .64735 m
.39491 .64734 L
s
.77737 .49769 m
.77712 .49794 L
s
.39491 .64734 m
.39444 .64733 L
s
.77762 .49745 m
.77737 .49769 L
s
.39444 .64733 m
.39398 .64732 L
s
.77787 .4972 m
.77762 .49745 L
s
.39398 .64732 m
.39351 .64732 L
s
.77812 .49696 m
.77787 .4972 L
s
.77837 .49671 m
.77812 .49696 L
s
.39351 .64732 m
.39305 .64731 L
s
.77861 .49647 m
.77837 .49671 L
s
.39305 .64731 m
.39258 .6473 L
s
.77886 .49622 m
.77861 .49647 L
s
.39258 .6473 m
.39212 .64729 L
s
.77911 .49598 m
.77886 .49622 L
s
.77935 .49573 m
.77911 .49598 L
s
.39212 .64729 m
.39166 .64728 L
s
.7796 .49548 m
.77935 .49573 L
s
.39166 .64728 m
.39119 .64726 L
s
.77985 .49524 m
.7796 .49548 L
s
.39119 .64726 m
.39073 .64725 L
s
.78009 .49499 m
.77985 .49524 L
s
.39073 .64725 m
.39026 .64724 L
s
.78034 .49475 m
.78009 .49499 L
s
.78058 .4945 m
.78034 .49475 L
s
.39026 .64724 m
.3898 .64723 L
s
.78083 .49426 m
.78058 .4945 L
s
.3898 .64723 m
.38933 .64721 L
s
.78107 .49401 m
.78083 .49426 L
s
.38933 .64721 m
.38887 .6472 L
s
.78132 .49376 m
.78107 .49401 L
s
.78156 .49352 m
.78132 .49376 L
s
.38887 .6472 m
.38841 .64719 L
s
.7818 .49327 m
.78156 .49352 L
s
.38841 .64719 m
.38794 .64717 L
s
.78205 .49302 m
.7818 .49327 L
s
.38794 .64717 m
.38748 .64716 L
s
.78229 .49278 m
.78205 .49302 L
s
.78253 .49253 m
.78229 .49278 L
s
.38748 .64716 m
.38701 .64714 L
s
.78277 .49228 m
.78253 .49253 L
s
.38701 .64714 m
.38655 .64712 L
s
.78302 .49204 m
.78277 .49228 L
s
.38655 .64712 m
.38609 .64711 L
s
.78326 .49179 m
.78302 .49204 L
s
.38609 .64711 m
.38562 .64709 L
s
.7835 .49154 m
.78326 .49179 L
s
.78374 .4913 m
.7835 .49154 L
s
.38562 .64709 m
.38516 .64707 L
s
.78398 .49105 m
.78374 .4913 L
s
.38516 .64707 m
.3847 .64705 L
s
.78422 .4908 m
.78398 .49105 L
s
.3847 .64705 m
.38423 .64704 L
s
.78446 .49055 m
.78422 .4908 L
s
.7847 .49031 m
.78446 .49055 L
s
.38423 .64704 m
.38377 .64702 L
s
.78494 .49006 m
.7847 .49031 L
s
.38377 .64702 m
.3833 .647 L
s
.78518 .48981 m
.78494 .49006 L
s
.3833 .647 m
.38284 .64698 L
s
.78541 .48956 m
.78518 .48981 L
s
.78565 .48932 m
.78541 .48956 L
s
.38284 .64698 m
.38238 .64695 L
s
.78589 .48907 m
.78565 .48932 L
s
.38238 .64695 m
.38191 .64693 L
s
.78613 .48882 m
.78589 .48907 L
s
.38191 .64693 m
.38145 .64691 L
s
.78636 .48857 m
.78613 .48882 L
s
.38145 .64691 m
.38099 .64689 L
s
.7866 .48832 m
.78636 .48857 L
s
.78684 .48807 m
.7866 .48832 L
s
.38099 .64689 m
.38052 .64687 L
s
.78707 .48783 m
.78684 .48807 L
s
.38052 .64687 m
.38006 .64684 L
s
.78731 .48758 m
.78707 .48783 L
s
.38006 .64684 m
.3796 .64682 L
s
.78754 .48733 m
.78731 .48758 L
s
.78778 .48708 m
.78754 .48733 L
s
.3796 .64682 m
.37913 .64679 L
s
.78801 .48683 m
.78778 .48708 L
s
.37913 .64679 m
.37867 .64677 L
s
.78825 .48658 m
.78801 .48683 L
s
.37867 .64677 m
.37821 .64674 L
s
.78848 .48633 m
.78825 .48658 L
s
.78871 .48608 m
.78848 .48633 L
s
.37821 .64674 m
.37774 .64672 L
s
.78895 .48584 m
.78871 .48608 L
s
.37774 .64672 m
.37728 .64669 L
s
.78918 .48559 m
.78895 .48584 L
s
.37728 .64669 m
.37682 .64666 L
s
.78941 .48534 m
.78918 .48559 L
s
.78964 .48509 m
.78941 .48534 L
s
.37682 .64666 m
.37635 .64664 L
s
.78988 .48484 m
.78964 .48509 L
s
.37635 .64664 m
.37589 .64661 L
s
.79011 .48459 m
.78988 .48484 L
s
.37589 .64661 m
.37543 .64658 L
s
.79034 .48434 m
.79011 .48459 L
s
.79057 .48409 m
.79034 .48434 L
s
.37543 .64658 m
.37497 .64655 L
s
.7908 .48384 m
.79057 .48409 L
s
.37497 .64655 m
.3745 .64652 L
s
.79103 .48359 m
.7908 .48384 L
s
.3745 .64652 m
.37404 .64649 L
s
.79126 .48334 m
.79103 .48359 L
s
.37404 .64649 m
.37358 .64646 L
s
.79149 .48309 m
.79126 .48334 L
s
.79172 .48284 m
.79149 .48309 L
s
.37358 .64646 m
.37312 .64643 L
s
.79195 .48259 m
.79172 .48284 L
s
.37312 .64643 m
.37265 .6464 L
s
.79218 .48234 m
.79195 .48259 L
s
.37265 .6464 m
.37219 .64636 L
s
.7924 .48209 m
.79218 .48234 L
s
.79263 .48184 m
.7924 .48209 L
s
.37219 .64636 m
.37173 .64633 L
s
.79286 .48158 m
.79263 .48184 L
s
.37173 .64633 m
.37127 .6463 L
s
.79308 .48133 m
.79286 .48158 L
s
.37127 .6463 m
.37081 .64626 L
s
.79331 .48108 m
.79308 .48133 L
s
.79354 .48083 m
.79331 .48108 L
s
.37081 .64626 m
.37034 .64623 L
s
.79376 .48058 m
.79354 .48083 L
s
.37034 .64623 m
.36988 .6462 L
s
.79399 .48033 m
.79376 .48058 L
s
.36988 .6462 m
.36942 .64616 L
s
.79421 .48008 m
.79399 .48033 L
s
.79444 .47983 m
.79421 .48008 L
s
.36942 .64616 m
.36896 .64612 L
s
.79466 .47958 m
.79444 .47983 L
s
.36896 .64612 m
.3685 .64609 L
s
.79489 .47932 m
.79466 .47958 L
s
.3685 .64609 m
.36803 .64605 L
s
.79511 .47907 m
.79489 .47932 L
s
.79533 .47882 m
.79511 .47907 L
s
.36803 .64605 m
.36757 .64601 L
s
.79556 .47857 m
.79533 .47882 L
s
.36757 .64601 m
.36711 .64597 L
s
.79578 .47832 m
.79556 .47857 L
s
.36711 .64597 m
.36665 .64594 L
s
.796 .47806 m
.79578 .47832 L
s
.79623 .47781 m
.796 .47806 L
s
.36665 .64594 m
.36619 .6459 L
s
.79645 .47756 m
.79623 .47781 L
s
.36619 .6459 m
.36573 .64586 L
s
.79667 .47731 m
.79645 .47756 L
s
.36573 .64586 m
.36527 .64582 L
s
.79689 .47706 m
.79667 .47731 L
s
.79711 .4768 m
.79689 .47706 L
s
.36527 .64582 m
.36481 .64578 L
s
.79733 .47655 m
.79711 .4768 L
s
.36481 .64578 m
.36434 .64573 L
s
.79755 .4763 m
.79733 .47655 L
s
.36434 .64573 m
.36388 .64569 L
s
.79777 .47605 m
.79755 .4763 L
s
.79799 .47579 m
.79777 .47605 L
s
.36388 .64569 m
.36342 .64565 L
s
.79821 .47554 m
.79799 .47579 L
s
.36342 .64565 m
.36296 .64561 L
s
.79843 .47529 m
.79821 .47554 L
s
.36296 .64561 m
.3625 .64556 L
s
.79864 .47503 m
.79843 .47529 L
s
.79886 .47478 m
.79864 .47503 L
s
.3625 .64556 m
.36204 .64552 L
s
.79908 .47453 m
.79886 .47478 L
s
.36204 .64552 m
.36158 .64547 L
s
.7993 .47427 m
.79908 .47453 L
s
.36158 .64547 m
.36112 .64543 L
s
.79951 .47402 m
.7993 .47427 L
s
.79973 .47377 m
.79951 .47402 L
s
.36112 .64543 m
.36066 .64538 L
s
.79995 .47351 m
.79973 .47377 L
s
.36066 .64538 m
.3602 .64534 L
s
.80016 .47326 m
.79995 .47351 L
s
.3602 .64534 m
.35974 .64529 L
s
.80038 .47301 m
.80016 .47326 L
s
.80059 .47275 m
.80038 .47301 L
s
.35974 .64529 m
.35928 .64524 L
s
.80081 .4725 m
.80059 .47275 L
s
.35928 .64524 m
.35882 .64519 L
s
.80102 .47225 m
.80081 .4725 L
s
.35882 .64519 m
.35836 .64515 L
s
.80123 .47199 m
.80102 .47225 L
s
.80145 .47174 m
.80123 .47199 L
s
.35836 .64515 m
.3579 .6451 L
s
.80166 .47148 m
.80145 .47174 L
s
.3579 .6451 m
.35744 .64505 L
s
.80187 .47123 m
.80166 .47148 L
s
.35744 .64505 m
.35698 .645 L
s
.80209 .47098 m
.80187 .47123 L
s
.8023 .47072 m
.80209 .47098 L
s
.35698 .645 m
.35652 .64495 L
s
.80251 .47047 m
.8023 .47072 L
s
.35652 .64495 m
.35607 .64489 L
s
.80272 .47021 m
.80251 .47047 L
s
.35607 .64489 m
.35561 .64484 L
s
.80293 .46996 m
.80272 .47021 L
s
.80314 .4697 m
.80293 .46996 L
s
.35561 .64484 m
.35515 .64479 L
s
.80335 .46945 m
.80314 .4697 L
s
.35515 .64479 m
.35469 .64474 L
s
.80356 .46919 m
.80335 .46945 L
s
.35469 .64474 m
.35423 .64468 L
s
.80377 .46894 m
.80356 .46919 L
s
.80398 .46868 m
.80377 .46894 L
s
.35423 .64468 m
.35377 .64463 L
s
.80419 .46843 m
.80398 .46868 L
s
.35377 .64463 m
.35331 .64458 L
s
.8044 .46817 m
.80419 .46843 L
s
.35331 .64458 m
.35286 .64452 L
s
.80461 .46792 m
.8044 .46817 L
s
.80482 .46766 m
.80461 .46792 L
s
.35286 .64452 m
.3524 .64446 L
s
.80502 .46741 m
.80482 .46766 L
s
.3524 .64446 m
.35194 .64441 L
s
.80523 .46715 m
.80502 .46741 L
s
.35194 .64441 m
.35148 .64435 L
s
.80544 .4669 m
.80523 .46715 L
s
.80564 .46664 m
.80544 .4669 L
s
.35148 .64435 m
.35102 .64429 L
s
.80585 .46638 m
.80564 .46664 L
s
.35102 .64429 m
.35057 .64424 L
s
.80606 .46613 m
.80585 .46638 L
s
.80626 .46587 m
.80606 .46613 L
s
.35057 .64424 m
.35011 .64418 L
s
.80647 .46562 m
.80626 .46587 L
s
.35011 .64418 m
.34965 .64412 L
s
.80667 .46536 m
.80647 .46562 L
s
.45254 .58861 m
.45196 .58863 L
s
.45312 .58859 m
.45254 .58861 L
s
.45369 .58857 m
.45312 .58859 L
s
.45196 .58863 m
.45138 .58865 L
s
.45427 .58855 m
.45369 .58857 L
s
.45138 .58865 m
.4508 .58867 L
s
.45485 .58852 m
.45427 .58855 L
s
.34965 .64412 m
.34919 .64406 L
s
.4508 .58867 m
.45023 .58869 L
s
.45543 .5885 m
.45485 .58852 L
s
.4529 .58859 m
.45232 .58862 L
s
.45348 .58857 m
.4529 .58859 L
s
.45232 .58862 m
.45175 .58864 L
s
.45406 .58855 m
.45348 .58857 L
s
.45175 .58864 m
.45117 .58866 L
s
.45023 .58869 m
.44965 .58871 L
s
.45464 .58853 m
.45406 .58855 L
s
.45117 .58866 m
.45059 .58868 L
s
.456 .58847 m
.45543 .5885 L
s
.45521 .5885 m
.45464 .58853 L
s
.45059 .58868 m
.45001 .58869 L
s
.44965 .58871 m
.44907 .58873 L
s
.45658 .58845 m
.456 .58847 L
s
.45579 .58848 m
.45521 .5885 L
s
.45001 .58869 m
.44943 .58871 L
s
.44907 .58873 m
.44849 .58874 L
s
.45637 .58845 m
.45579 .58848 L
s
.45716 .58842 m
.45658 .58845 L
s
.44943 .58871 m
.44886 .58873 L
s
.44849 .58874 m
.44791 .58876 L
s
.45694 .58843 m
.45637 .58845 L
s
.44886 .58873 m
.44828 .58875 L
s
.45774 .58839 m
.45716 .58842 L
s
.44791 .58876 m
.44734 .58878 L
s
.45752 .5884 m
.45694 .58843 L
s
.44828 .58875 m
.4477 .58876 L
s
.45831 .58837 m
.45774 .58839 L
s
.4581 .58837 m
.45752 .5884 L
s
.44734 .58878 m
.44676 .58879 L
s
.4477 .58876 m
.44712 .58878 L
s
.45889 .58834 m
.45831 .58837 L
s
.45868 .58834 m
.4581 .58837 L
s
.44676 .58879 m
.44618 .5888 L
s
.44712 .58878 m
.44654 .58879 L
s
.45947 .58831 m
.45889 .58834 L
s
.45925 .58831 m
.45868 .58834 L
s
.44654 .58879 m
.44597 .5888 L
s
.44618 .5888 m
.4456 .58882 L
s
.80687 .46511 m
.80667 .46536 L
s
.46004 .58828 m
.45947 .58831 L
s
.45983 .58828 m
.45925 .58831 L
s
.44597 .5888 m
.44539 .58882 L
s
.4456 .58882 m
.44502 .58883 L
s
.46062 .58825 m
.46004 .58828 L
s
.46041 .58825 m
.45983 .58828 L
s
.44539 .58882 m
.44481 .58883 L
s
.44502 .58883 m
.44444 .58884 L
s
.4612 .58822 m
.46062 .58825 L
s
.46098 .58822 m
.46041 .58825 L
s
.44481 .58883 m
.44423 .58884 L
s
.44444 .58884 m
.44387 .58885 L
s
.46177 .58818 m
.4612 .58822 L
s
.46156 .58819 m
.46098 .58822 L
s
.44423 .58884 m
.44365 .58885 L
s
.44387 .58885 m
.44329 .58886 L
s
.46235 .58815 m
.46177 .58818 L
s
.46214 .58816 m
.46156 .58819 L
s
.44365 .58885 m
.44308 .58886 L
s
.44329 .58886 m
.44271 .58887 L
s
.46293 .58812 m
.46235 .58815 L
s
.46271 .58812 m
.46214 .58816 L
s
.44308 .58886 m
.4425 .58887 L
s
.44271 .58887 m
.44213 .58888 L
s
.4635 .58808 m
.46293 .58812 L
s
.46329 .58809 m
.46271 .58812 L
s
.4425 .58887 m
.44192 .58888 L
s
.44213 .58888 m
.44155 .58889 L
s
.46408 .58805 m
.4635 .58808 L
s
.46387 .58805 m
.46329 .58809 L
s
.44192 .58888 m
.44134 .58889 L
s
.44155 .58889 m
.44098 .5889 L
s
.46466 .58801 m
.46408 .58805 L
s
.46444 .58802 m
.46387 .58805 L
s
.44134 .58889 m
.44076 .58889 L
s
.44098 .5889 m
.4404 .5889 L
s
.46502 .58798 m
.46444 .58802 L
s
.46523 .58797 m
.46466 .58801 L
s
.44076 .58889 m
.44018 .5889 L
s
.4404 .5889 m
.43982 .58891 L
s
.4656 .58795 m
.46502 .58798 L
s
.46581 .58794 m
.46523 .58797 L
s
.44018 .5889 m
.43961 .58891 L
s
.43982 .58891 m
.43924 .58891 L
s
.46617 .58791 m
.4656 .58795 L
s
.46639 .5879 m
.46581 .58794 L
s
.43961 .58891 m
.43903 .58891 L
s
.43924 .58891 m
.43866 .58892 L
s
.46675 .58787 m
.46617 .58791 L
s
.46696 .58786 m
.46639 .5879 L
s
.80708 .46485 m
.80687 .46511 L
s
.43903 .58891 m
.43845 .58892 L
s
.43866 .58892 m
.43808 .58892 L
s
.34919 .64406 m
.34874 .644 L
s
.46732 .58783 m
.46675 .58787 L
s
.46754 .58782 m
.46696 .58786 L
s
.43845 .58892 m
.43787 .58892 L
s
.43808 .58892 m
.43751 .58893 L
s
.4679 .58779 m
.46732 .58783 L
s
.46811 .58778 m
.46754 .58782 L
s
.43787 .58892 m
.43729 .58892 L
s
.43751 .58893 m
.43693 .58893 L
s
.46848 .58775 m
.4679 .58779 L
s
.46869 .58774 m
.46811 .58778 L
s
.43729 .58892 m
.43671 .58892 L
s
.43693 .58893 m
.43635 .58893 L
s
.46905 .58771 m
.46848 .58775 L
s
.46926 .5877 m
.46869 .58774 L
s
.43671 .58892 m
.43614 .58893 L
s
.43635 .58893 m
.43577 .58893 L
s
.46963 .58767 m
.46905 .58771 L
s
.46984 .58766 m
.46926 .5877 L
s
.43614 .58893 m
.43556 .58893 L
s
.43577 .58893 m
.43519 .58893 L
s
.4702 .58762 m
.46963 .58767 L
s
.47041 .58761 m
.46984 .58766 L
s
.43556 .58893 m
.43498 .58893 L
s
.43519 .58893 m
.43461 .58893 L
s
.47078 .58758 m
.4702 .58762 L
s
.47099 .58757 m
.47041 .58761 L
s
.43498 .58893 m
.4344 .58893 L
s
.43461 .58893 m
.43404 .58893 L
s
.47135 .58754 m
.47078 .58758 L
s
.47156 .58753 m
.47099 .58757 L
s
.80728 .46459 m
.80708 .46485 L
s
.4344 .58893 m
.43382 .58893 L
s
.43404 .58893 m
.43346 .58893 L
s
.47193 .58749 m
.47135 .58754 L
s
.47214 .58748 m
.47156 .58753 L
s
.43382 .58893 m
.43325 .58892 L
s
.43346 .58893 m
.43288 .58893 L
s
.4725 .58745 m
.47193 .58749 L
s
.47271 .58744 m
.47214 .58748 L
s
.43325 .58892 m
.43267 .58892 L
s
.43288 .58893 m
.4323 .58892 L
s
.47308 .5874 m
.4725 .58745 L
s
.34874 .644 m
.34828 .64394 L
s
.47329 .58739 m
.47271 .58744 L
s
.43267 .58892 m
.43209 .58892 L
s
.4323 .58892 m
.43172 .58892 L
s
.47365 .58735 m
.47308 .5874 L
s
.47386 .58734 m
.47329 .58739 L
s
.43209 .58892 m
.43151 .58891 L
s
.43172 .58892 m
.43115 .58891 L
s
.47422 .58731 m
.47365 .58735 L
s
.47444 .5873 m
.47386 .58734 L
s
.43151 .58891 m
.43093 .58891 L
s
.43115 .58891 m
.43057 .58891 L
s
.4748 .58726 m
.47422 .58731 L
s
.47501 .58725 m
.47444 .5873 L
s
.43093 .58891 m
.43035 .5889 L
s
.80748 .46434 m
.80728 .46459 L
s
.43057 .58891 m
.42999 .5889 L
s
.47537 .58721 m
.4748 .58726 L
s
.47559 .5872 m
.47501 .58725 L
s
.43035 .5889 m
.42978 .5889 L
s
.42999 .5889 m
.42941 .5889 L
s
.47595 .58716 m
.47537 .58721 L
s
.47616 .58715 m
.47559 .5872 L
s
.42978 .5889 m
.4292 .58889 L
s
.42941 .5889 m
.42883 .58889 L
s
.47652 .58711 m
.47595 .58716 L
s
.47673 .5871 m
.47616 .58715 L
s
.4292 .58889 m
.42862 .58888 L
s
.42883 .58889 m
.42826 .58888 L
s
.47709 .58706 m
.47652 .58711 L
s
.42862 .58888 m
.42804 .58887 L
s
.47731 .58705 m
.47673 .5871 L
s
.42826 .58888 m
.42768 .58887 L
s
.34828 .64394 m
.34782 .64388 L
s
.47767 .58701 m
.47709 .58706 L
s
.42804 .58887 m
.42747 .58886 L
s
.47788 .58699 m
.47731 .58705 L
s
.42768 .58887 m
.4271 .58886 L
s
.80769 .46408 m
.80748 .46434 L
s
.47824 .58695 m
.47767 .58701 L
s
.42747 .58886 m
.42689 .58885 L
s
.47845 .58694 m
.47788 .58699 L
s
.4271 .58886 m
.42652 .58885 L
s
.47881 .5869 m
.47824 .58695 L
s
.42689 .58885 m
.42631 .58884 L
s
.47903 .58689 m
.47845 .58694 L
s
.42652 .58885 m
.42594 .58884 L
s
.47939 .58685 m
.47881 .5869 L
s
.42631 .58884 m
.42573 .58883 L
s
.4796 .58683 m
.47903 .58689 L
s
.42594 .58884 m
.42537 .58883 L
s
.47996 .58679 m
.47939 .58685 L
s
.42573 .58883 m
.42516 .58882 L
s
.48017 .58678 m
.4796 .58683 L
s
.42537 .58883 m
.42479 .58882 L
s
.48053 .58674 m
.47996 .58679 L
s
.42516 .58882 m
.42458 .58881 L
s
.48075 .58672 m
.48017 .58678 L
s
.42479 .58882 m
.42421 .5888 L
s
.80789 .46382 m
.80769 .46408 L
s
.48111 .58668 m
.48053 .58674 L
s
.42458 .58881 m
.424 .58879 L
s
.48132 .58667 m
.48075 .58672 L
s
.34782 .64388 m
.34737 .64381 L
s
.42421 .5888 m
.42363 .58879 L
s
.48168 .58662 m
.48111 .58668 L
s
.424 .58879 m
.42342 .58878 L
s
.48189 .58661 m
.48132 .58667 L
s
.42363 .58879 m
.42306 .58877 L
s
.48225 .58657 m
.48168 .58662 L
s
.42342 .58878 m
.42285 .58877 L
s
.48246 .58655 m
.48189 .58661 L
s
.42306 .58877 m
.42248 .58876 L
s
.48282 .58651 m
.48225 .58657 L
s
.42285 .58877 m
.42227 .58875 L
s
.48304 .58649 m
.48246 .58655 L
s
.42248 .58876 m
.4219 .58874 L
s
.4834 .58645 m
.48282 .58651 L
s
.80809 .46357 m
.80789 .46382 L
s
.42227 .58875 m
.42169 .58873 L
s
.48361 .58643 m
.48304 .58649 L
s
.4219 .58874 m
.42133 .58873 L
s
.48397 .58639 m
.4834 .58645 L
s
.42169 .58873 m
.42111 .58872 L
s
.48418 .58638 m
.48361 .58643 L
s
.42133 .58873 m
.42075 .58871 L
s
.48454 .58633 m
.48397 .58639 L
s
.42111 .58872 m
.42054 .5887 L
s
.48475 .58631 m
.48418 .58638 L
s
.34737 .64381 m
.34691 .64375 L
s
.42075 .58871 m
.42017 .58869 L
s
.48511 .58627 m
.48454 .58633 L
s
.42054 .5887 m
.41996 .58868 L
s
.48532 .58625 m
.48475 .58631 L
s
.42017 .58869 m
.41959 .58867 L
s
.48568 .58621 m
.48511 .58627 L
s
.41996 .58868 m
.41938 .58866 L
s
.80829 .46331 m
.80809 .46357 L
s
.48589 .58619 m
.48532 .58625 L
s
.41959 .58867 m
.41902 .58865 L
s
.48625 .58615 m
.48568 .58621 L
s
.41938 .58866 m
.41881 .58864 L
s
.48646 .58613 m
.48589 .58619 L
s
.41902 .58865 m
.41844 .58863 L
s
.48682 .58608 m
.48625 .58615 L
s
.41881 .58864 m
.41823 .58862 L
s
.48704 .58607 m
.48646 .58613 L
s
.41844 .58863 m
.41786 .58861 L
s
.48739 .58602 m
.48682 .58608 L
s
.41823 .58862 m
.41765 .5886 L
s
.48761 .586 m
.48704 .58607 L
s
.34691 .64375 m
.34645 .64369 L
s
.41786 .58861 m
.41729 .58859 L
s
.8085 .46305 m
.80829 .46331 L
s
.48796 .58595 m
.48739 .58602 L
s
.41765 .5886 m
.41708 .58858 L
s
.48818 .58594 m
.48761 .586 L
s
.41729 .58859 m
.41671 .58857 L
s
.48853 .58589 m
.48796 .58595 L
s
.41708 .58858 m
.4165 .58856 L
s
.48875 .58587 m
.48818 .58594 L
s
.41671 .58857 m
.41614 .58854 L
s
.4891 .58582 m
.48853 .58589 L
s
.4165 .58856 m
.41592 .58853 L
s
.48932 .58581 m
.48875 .58587 L
s
.41614 .58854 m
.41556 .58852 L
s
.48967 .58576 m
.4891 .58582 L
s
.41592 .58853 m
.41535 .58851 L
s
.48989 .58574 m
.48932 .58581 L
s
.8087 .4628 m
.8085 .46305 L
s
.41556 .58852 m
.41498 .5885 L
s
.49024 .58569 m
.48967 .58576 L
s
.41535 .58851 m
.41477 .58848 L
s
.49046 .58567 m
.48989 .58574 L
s
.34645 .64369 m
.346 .64362 L
s
.41498 .5885 m
.41441 .58847 L
s
.49081 .58562 m
.49024 .58569 L
s
.41477 .58848 m
.4142 .58846 L
s
.49103 .5856 m
.49046 .58567 L
s
.41441 .58847 m
.41383 .58845 L
s
.49138 .58555 m
.49081 .58562 L
s
.4142 .58846 m
.41362 .58843 L
s
.4916 .58553 m
.49103 .5856 L
s
.41383 .58845 m
.41325 .58842 L
s
.8089 .46254 m
.8087 .4628 L
s
.49195 .58548 m
.49138 .58555 L
s
.41362 .58843 m
.41304 .58841 L
s
.49216 .58546 m
.4916 .58553 L
s
.41325 .58842 m
.41268 .58839 L
s
.49252 .58541 m
.49195 .58548 L
s
.41304 .58841 m
.41247 .58838 L
s
.49273 .58539 m
.49216 .58546 L
s
.41268 .58839 m
.4121 .58836 L
s
.346 .64362 m
.34554 .64356 L
s
.49309 .58534 m
.49252 .58541 L
s
.41247 .58838 m
.41189 .58835 L
s
.4933 .58532 m
.49273 .58539 L
s
.4121 .58836 m
.41153 .58833 L
s
.49366 .58527 m
.49309 .58534 L
s
.41189 .58835 m
.41132 .58832 L
s
.8091 .46228 m
.8089 .46254 L
s
.49387 .58525 m
.4933 .58532 L
s
.41153 .58833 m
.41095 .58831 L
s
.49423 .5852 m
.49366 .58527 L
s
.41132 .58832 m
.41074 .58829 L
s
.49444 .58518 m
.49387 .58525 L
s
.41095 .58831 m
.41038 .58827 L
s
.4948 .58513 m
.49423 .5852 L
s
.41074 .58829 m
.41017 .58826 L
s
.49501 .58511 m
.49444 .58518 L
s
.41038 .58827 m
.4098 .58824 L
s
.49536 .58505 m
.4948 .58513 L
s
.34554 .64356 m
.34509 .6435 L
s
.41017 .58826 m
.40959 .58823 L
s
.49557 .58503 m
.49501 .58511 L
s
.8093 .46203 m
.8091 .46228 L
s
.4098 .58824 m
.40923 .58821 L
s
.49593 .58498 m
.49536 .58505 L
s
.40959 .58823 m
.40902 .5882 L
s
.49614 .58496 m
.49557 .58503 L
s
.40923 .58821 m
.40865 .58818 L
s
.4965 .5849 m
.49593 .58498 L
s
.40902 .5882 m
.40844 .58817 L
s
.49671 .58488 m
.49614 .58496 L
s
.40865 .58818 m
.40808 .58815 L
s
.49707 .58483 m
.4965 .5849 L
s
.40844 .58817 m
.40787 .58813 L
s
.8095 .46177 m
.8093 .46203 L
s
.49728 .58481 m
.49671 .58488 L
s
.40808 .58815 m
.4075 .58811 L
s
.49763 .58475 m
.49707 .58483 L
s
.40787 .58813 m
.40729 .5881 L
s
.34509 .6435 m
.34463 .64343 L
s
.49784 .58473 m
.49728 .58481 L
s
.4075 .58811 m
.40693 .58808 L
s
.4982 .58467 m
.49763 .58475 L
s
.40729 .5881 m
.40672 .58806 L
s
.49841 .58465 m
.49784 .58473 L
s
.40693 .58808 m
.40635 .58804 L
s
.49877 .5846 m
.4982 .58467 L
s
.40672 .58806 m
.40614 .58803 L
s
.8097 .46151 m
.8095 .46177 L
s
.49898 .58458 m
.49841 .58465 L
s
.40635 .58804 m
.40578 .58801 L
s
.49933 .58452 m
.49877 .5846 L
s
.40614 .58803 m
.40557 .58799 L
s
.49954 .5845 m
.49898 .58458 L
s
.40578 .58801 m
.4052 .58797 L
s
.34463 .64343 m
.34417 .64336 L
s
.4999 .58444 m
.49933 .58452 L
s
.40557 .58799 m
.405 .58796 L
s
.50011 .58442 m
.49954 .5845 L
s
.4052 .58797 m
.40463 .58793 L
s
.80989 .46126 m
.8097 .46151 L
s
.50046 .58436 m
.4999 .58444 L
s
.405 .58796 m
.40442 .58792 L
s
.50067 .58434 m
.50011 .58442 L
s
.40463 .58793 m
.40406 .5879 L
s
.50103 .58428 m
.50046 .58436 L
s
.40442 .58792 m
.40385 .58788 L
s
.50124 .58426 m
.50067 .58434 L
s
.40406 .5879 m
.40348 .58786 L
s
.50159 .5842 m
.50103 .58428 L
s
.40385 .58788 m
.40327 .58784 L
s
.50181 .58417 m
.50124 .58426 L
s
.81009 .461 m
.80989 .46126 L
s
.34417 .64336 m
.34372 .6433 L
s
.40348 .58786 m
.40291 .58782 L
s
.50216 .58412 m
.50159 .5842 L
s
.40327 .58784 m
.4027 .5878 L
s
.50237 .58409 m
.50181 .58417 L
s
.40291 .58782 m
.40234 .58778 L
s
.50272 .58403 m
.50216 .58412 L
s
.4027 .5878 m
.40213 .58776 L
s
.50294 .58401 m
.50237 .58409 L
s
.40234 .58778 m
.40176 .58774 L
s
.50329 .58395 m
.50272 .58403 L
s
.40213 .58776 m
.40155 .58772 L
s
.81029 .46074 m
.81009 .461 L
s
.5035 .58393 m
.50294 .58401 L
s
.40176 .58774 m
.40119 .5877 L
s
.50385 .58387 m
.50329 .58395 L
s
.40155 .58772 m
.40098 .58768 L
s
.34372 .6433 m
.34326 .64323 L
s
.50406 .58384 m
.5035 .58393 L
s
.40119 .5877 m
.40062 .58765 L
s
.50442 .58378 m
.50385 .58387 L
s
.40098 .58768 m
.40041 .58764 L
s
.50463 .58376 m
.50406 .58384 L
s
.40062 .58765 m
.40004 .58761 L
s
.81049 .46048 m
.81029 .46074 L
s
.50498 .5837 m
.50442 .58378 L
s
.40041 .58764 m
.39984 .58759 L
s
.50519 .58367 m
.50463 .58376 L
s
.40004 .58761 m
.39947 .58757 L
s
.50554 .58361 m
.50498 .5837 L
s
.39984 .58759 m
.39926 .58755 L
s
.50576 .58358 m
.50519 .58367 L
s
.34326 .64323 m
.34281 .64316 L
s
.39947 .58757 m
.3989 .58752 L
s
.50611 .58352 m
.50554 .58361 L
s
.39926 .58755 m
.39869 .58751 L
s
.81069 .46023 m
.81049 .46048 L
s
.50632 .5835 m
.50576 .58358 L
s
.3989 .58752 m
.39833 .58748 L
s
.50667 .58344 m
.50611 .58352 L
s
.39869 .58751 m
.39812 .58746 L
s
.50688 .58341 m
.50632 .5835 L
s
.39833 .58748 m
.39775 .58743 L
s
.50723 .58335 m
.50667 .58344 L
s
.39812 .58746 m
.39755 .58741 L
s
.50744 .58332 m
.50688 .58341 L
s
.81088 .45997 m
.81069 .46023 L
s
.39775 .58743 m
.39718 .58739 L
s
.34281 .64316 m
.34235 .64309 L
s
.5078 .58326 m
.50723 .58335 L
s
.39755 .58741 m
.39697 .58737 L
s
.50801 .58323 m
.50744 .58332 L
s
.39718 .58739 m
.39661 .58734 L
s
.50836 .58317 m
.5078 .58326 L
s
.39697 .58737 m
.3964 .58732 L
s
.50857 .58314 m
.50801 .58323 L
s
.39661 .58734 m
.39604 .58729 L
s
.81108 .45971 m
.81088 .45997 L
s
.50892 .58308 m
.50836 .58317 L
s
.3964 .58732 m
.39583 .58727 L
s
.50913 .58305 m
.50857 .58314 L
s
.39604 .58729 m
.39547 .58724 L
s
.34235 .64309 m
.3419 .64303 L
s
.50948 .58299 m
.50892 .58308 L
s
.39583 .58727 m
.39526 .58722 L
s
.50969 .58296 m
.50913 .58305 L
s
.39547 .58724 m
.3949 .58719 L
s
.51004 .5829 m
.50948 .58299 L
s
.39526 .58722 m
.39469 .58717 L
s
.81128 .45945 m
.81108 .45971 L
s
.51025 .58287 m
.50969 .58296 L
s
.3949 .58719 m
.39432 .58714 L
s
.5106 .5828 m
.51004 .5829 L
s
.39469 .58717 m
.39412 .58712 L
s
.51081 .58278 m
.51025 .58287 L
s
.39432 .58714 m
.39375 .58709 L
s
.51117 .58271 m
.5106 .5828 L
s
.39412 .58712 m
.39355 .58707 L
s
.3419 .64303 m
.34144 .64296 L
s
.51138 .58268 m
.51081 .58278 L
s
.81147 .4592 m
.81128 .45945 L
s
.39375 .58709 m
.39318 .58704 L
s
.51173 .58262 m
.51117 .58271 L
s
.39355 .58707 m
.39298 .58702 L
s
.51194 .58259 m
.51138 .58268 L
s
.39318 .58704 m
.39261 .58699 L
s
.39298 .58702 m
.3924 .58697 L
s
.51229 .58252 m
.51173 .58262 L
s
.5125 .58249 m
.51194 .58259 L
s
.39261 .58699 m
.39204 .58694 L
s
.81167 .45894 m
.81147 .4592 L
s
.3924 .58697 m
.39183 .58692 L
s
.51285 .58243 m
.51229 .58252 L
s
.34144 .64296 m
.34099 .64289 L
s
.51306 .5824 m
.5125 .58249 L
s
.39204 .58694 m
.39147 .58688 L
s
.39183 .58692 m
.39126 .58686 L
s
.51341 .58233 m
.51285 .58243 L
s
.51362 .5823 m
.51306 .5824 L
s
.39147 .58688 m
.3909 .58683 L
s
.81186 .45868 m
.81167 .45894 L
s
.39126 .58686 m
.39069 .58681 L
s
.51397 .58223 m
.51341 .58233 L
s
.51417 .58221 m
.51362 .5823 L
s
.3909 .58683 m
.39033 .58678 L
s
.39069 .58681 m
.39012 .58675 L
s
.34099 .64289 m
.34054 .64282 L
s
.51452 .58214 m
.51397 .58223 L
s
.51473 .58211 m
.51417 .58221 L
s
.39033 .58678 m
.38976 .58672 L
s
.81206 .45842 m
.81186 .45868 L
s
.39012 .58675 m
.38956 .5867 L
s
.51508 .58204 m
.51452 .58214 L
s
.51529 .58201 m
.51473 .58211 L
s
.38976 .58672 m
.38919 .58666 L
s
.38956 .5867 m
.38899 .58664 L
s
.51564 .58194 m
.51508 .58204 L
s
.51585 .58191 m
.51529 .58201 L
s
.38919 .58666 m
.38862 .58661 L
s
.34054 .64282 m
.34008 .64274 L
s
.38899 .58664 m
.38842 .58658 L
s
.81225 .45816 m
.81206 .45842 L
s
.5162 .58184 m
.51564 .58194 L
s
.51641 .58181 m
.51585 .58191 L
s
.38862 .58661 m
.38805 .58655 L
s
.38842 .58658 m
.38785 .58653 L
s
.51676 .58174 m
.5162 .58184 L
s
.51697 .58171 m
.51641 .58181 L
s
.38805 .58655 m
.38749 .58649 L
s
.38785 .58653 m
.38728 .58647 L
s
.51732 .58164 m
.51676 .58174 L
s
.81244 .45791 m
.81225 .45816 L
s
.51752 .58161 m
.51697 .58171 L
s
.38749 .58649 m
.38692 .58643 L
s
.34008 .64274 m
.33963 .64267 L
s
.38728 .58647 m
.38671 .58641 L
s
.51787 .58154 m
.51732 .58164 L
s
.51808 .58151 m
.51752 .58161 L
s
.38692 .58643 m
.38635 .58637 L
s
.38671 .58641 m
.38614 .58635 L
s
.51843 .58144 m
.51787 .58154 L
s
.81264 .45765 m
.81244 .45791 L
s
.51864 .58141 m
.51808 .58151 L
s
.38635 .58637 m
.38578 .58631 L
s
.38614 .58635 m
.38557 .58629 L
s
.51899 .58133 m
.51843 .58144 L
s
.51919 .5813 m
.51864 .58141 L
s
.33963 .64267 m
.33917 .6426 L
s
.38578 .58631 m
.38521 .58625 L
s
.38557 .58629 m
.38501 .58623 L
s
.51954 .58123 m
.51899 .58133 L
s
.81283 .45739 m
.81264 .45765 L
s
.51975 .5812 m
.51919 .5813 L
s
.38521 .58625 m
.38464 .58619 L
s
.38501 .58623 m
.38444 .58617 L
s
.5201 .58113 m
.51954 .58123 L
s
.52031 .5811 m
.51975 .5812 L
s
.38464 .58619 m
.38408 .58613 L
s
.38444 .58617 m
.38387 .5861 L
s
.81302 .45713 m
.81283 .45739 L
s
.52065 .58102 m
.5201 .58113 L
s
.33917 .6426 m
.33872 .64253 L
s
.52086 .58099 m
.52031 .5811 L
s
.38408 .58613 m
.38351 .58606 L
s
.38387 .5861 m
.3833 .58604 L
s
.52121 .58092 m
.52065 .58102 L
s
.52142 .58088 m
.52086 .58099 L
s
.38351 .58606 m
.38294 .586 L
s
.81322 .45687 m
.81302 .45713 L
s
.3833 .58604 m
.38274 .58597 L
s
.52177 .58081 m
.52121 .58092 L
s
.52197 .58078 m
.52142 .58088 L
s
.38294 .586 m
.38238 .58593 L
s
.33872 .64253 m
.33827 .64245 L
s
.38274 .58597 m
.38217 .58591 L
s
.52232 .5807 m
.52177 .58081 L
s
.52253 .58067 m
.52197 .58078 L
s
.38238 .58593 m
.38181 .58587 L
s
.81341 .45661 m
.81322 .45687 L
s
.38217 .58591 m
.3816 .58584 L
s
.52287 .5806 m
.52232 .5807 L
s
.52308 .58056 m
.52253 .58067 L
s
.38181 .58587 m
.38124 .5858 L
s
.3816 .58584 m
.38104 .58578 L
s
.52343 .58049 m
.52287 .5806 L
s
.33827 .64245 m
.33781 .64238 L
s
.52364 .58045 m
.52308 .58056 L
s
.38124 .5858 m
.38068 .58574 L
s
.8136 .45636 m
.81341 .45661 L
s
.38104 .58578 m
.38047 .58571 L
s
.52398 .58038 m
.52343 .58049 L
s
.52419 .58035 m
.52364 .58045 L
s
.38068 .58574 m
.38011 .58567 L
s
.38047 .58571 m
.37991 .58564 L
s
.52454 .58027 m
.52398 .58038 L
s
.52474 .58024 m
.52419 .58035 L
s
.81379 .4561 m
.8136 .45636 L
s
.38011 .58567 m
.37954 .5856 L
s
.33781 .64238 m
.33736 .6423 L
s
.37991 .58564 m
.37934 .58558 L
s
.52509 .58016 m
.52454 .58027 L
s
.5253 .58013 m
.52474 .58024 L
s
.37954 .5856 m
.37898 .58553 L
s
.37934 .58558 m
.37878 .58551 L
s
.52564 .58005 m
.52509 .58016 L
s
.52585 .58001 m
.5253 .58013 L
s
.81398 .45584 m
.81379 .4561 L
s
.37898 .58553 m
.37841 .58546 L
s
.37878 .58551 m
.37821 .58544 L
s
.52619 .57994 m
.52564 .58005 L
s
.33736 .6423 m
.33691 .64223 L
s
.5264 .5799 m
.52585 .58001 L
s
.37841 .58546 m
.37785 .58539 L
s
.37821 .58544 m
.37765 .58537 L
s
.52675 .57982 m
.52619 .57994 L
s
.81417 .45558 m
.81398 .45584 L
s
.52695 .57979 m
.5264 .5799 L
s
.37785 .58539 m
.37728 .58532 L
s
.37765 .58537 m
.37708 .5853 L
s
.5273 .57971 m
.52675 .57982 L
s
.5275 .57968 m
.52695 .57979 L
s
.37728 .58532 m
.37672 .58525 L
s
.33691 .64223 m
.33645 .64215 L
s
.81436 .45532 m
.81417 .45558 L
s
.37708 .5853 m
.37652 .58522 L
s
.52785 .5796 m
.5273 .57971 L
s
.52805 .57956 m
.5275 .57968 L
s
.37672 .58525 m
.37616 .58518 L
s
.37652 .58522 m
.37595 .58515 L
s
.5284 .57948 m
.52785 .5796 L
s
.52861 .57945 m
.52805 .57956 L
s
.37616 .58518 m
.37559 .5851 L
s
.81455 .45506 m
.81436 .45532 L
s
.37595 .58515 m
.37539 .58508 L
s
.52895 .57937 m
.5284 .57948 L
s
.33645 .64215 m
.336 .64208 L
s
.52916 .57933 m
.52861 .57945 L
s
.37559 .5851 m
.37503 .58503 L
s
.37539 .58508 m
.37482 .585 L
s
.5295 .57925 m
.52895 .57937 L
s
.52971 .57922 m
.52916 .57933 L
s
.81474 .4548 m
.81455 .45506 L
s
.37503 .58503 m
.37446 .58496 L
s
.37482 .585 m
.37426 .58493 L
s
.53005 .57913 m
.5295 .57925 L
s
.53026 .5791 m
.52971 .57922 L
s
.336 .64208 m
.33555 .642 L
s
.37446 .58496 m
.3739 .58488 L
s
.37426 .58493 m
.3737 .58485 L
s
.5306 .57902 m
.53005 .57913 L
s
.81493 .45454 m
.81474 .4548 L
s
.53081 .57898 m
.53026 .5791 L
s
.3739 .58488 m
.37334 .58481 L
s
.3737 .58485 m
.37314 .58478 L
s
.53115 .5789 m
.5306 .57902 L
s
.53135 .57886 m
.53081 .57898 L
s
.37334 .58481 m
.37278 .58473 L
s
.81512 .45429 m
.81493 .45454 L
s
.33555 .642 m
.3351 .64192 L
s
.37314 .58478 m
.37257 .5847 L
s
.5317 .57878 m
.53115 .5789 L
s
.5319 .57874 m
.53135 .57886 L
s
.37278 .58473 m
.37221 .58465 L
s
.37257 .5847 m
.37201 .58462 L
s
.53225 .57866 m
.5317 .57878 L
s
.53245 .57863 m
.5319 .57874 L
s
.81531 .45403 m
.81512 .45429 L
s
.37221 .58465 m
.37165 .58457 L
s
.37201 .58462 m
.37145 .58455 L
s
.53279 .57854 m
.53225 .57866 L
s
.3351 .64192 m
.33464 .64184 L
s
.533 .57851 m
.53245 .57863 L
s
.37165 .58457 m
.37109 .5845 L
s
.37145 .58455 m
.37089 .58447 L
s
.53334 .57842 m
.53279 .57854 L
s
.8155 .45377 m
.81531 .45403 L
s
.53355 .57838 m
.533 .57851 L
s
.37109 .5845 m
.37053 .58442 L
s
.37089 .58447 m
.37033 .58439 L
s
.53389 .5783 m
.53334 .57842 L
s
.33464 .64184 m
.33419 .64176 L
s
.53409 .57826 m
.53355 .57838 L
s
.37053 .58442 m
.36997 .58434 L
s
.81569 .45351 m
.8155 .45377 L
s
.37033 .58439 m
.36976 .58431 L
s
.53444 .57818 m
.53389 .5783 L
s
.53464 .57814 m
.53409 .57826 L
s
.36997 .58434 m
.36941 .58426 L
s
.36976 .58431 m
.3692 .58423 L
s
.53498 .57805 m
.53444 .57818 L
s
.53519 .57802 m
.53464 .57814 L
s
.81587 .45325 m
.81569 .45351 L
s
.36941 .58426 m
.36884 .58417 L
s
.33419 .64176 m
.33374 .64168 L
s
.3692 .58423 m
.36864 .58414 L
s
.53553 .57793 m
.53498 .57805 L
s
.53573 .57789 m
.53519 .57802 L
s
.36884 .58417 m
.36828 .58409 L
s
.36864 .58414 m
.36808 .58406 L
s
.81606 .45299 m
.81587 .45325 L
s
.53607 .57781 m
.53553 .57793 L
s
.53628 .57777 m
.53573 .57789 L
s
.36828 .58409 m
.36772 .58401 L
s
.33374 .64168 m
.33329 .6416 L
s
.36808 .58406 m
.36752 .58398 L
s
.53662 .57768 m
.53607 .57781 L
s
.53682 .57764 m
.53628 .57777 L
s
.36772 .58401 m
.36716 .58393 L
s
.81625 .45273 m
.81606 .45299 L
s
.36752 .58398 m
.36696 .5839 L
s
.53717 .57756 m
.53662 .57768 L
s
.53737 .57752 m
.53682 .57764 L
s
.36716 .58393 m
.3666 .58384 L
s
.36696 .5839 m
.3664 .58381 L
s
.33329 .6416 m
.33284 .64152 L
s
.53771 .57743 m
.53717 .57756 L
s
.81643 .45247 m
.81625 .45273 L
s
.53791 .57739 m
.53737 .57752 L
s
.3666 .58384 m
.36605 .58376 L
s
.3664 .58381 m
.36584 .58373 L
s
.53825 .5773 m
.53771 .57743 L
s
.53846 .57727 m
.53791 .57739 L
s
.36605 .58376 m
.36549 .58367 L
s
.81662 .45221 m
.81643 .45247 L
s
.36584 .58373 m
.36529 .58364 L
s
.5388 .57718 m
.53825 .5773 L
s
.33284 .64152 m
.33239 .64144 L
s
.539 .57714 m
.53846 .57727 L
s
.36549 .58367 m
.36493 .58359 L
s
.36529 .58364 m
.36473 .58355 L
s
.53934 .57705 m
.5388 .57718 L
s
.8168 .45195 m
.81662 .45221 L
s
.53954 .57701 m
.539 .57714 L
s
.36493 .58359 m
.36437 .5835 L
s
.36473 .58355 m
.36417 .58347 L
s
.53988 .57692 m
.53934 .57705 L
s
.33239 .64144 m
.33194 .64136 L
s
.54009 .57688 m
.53954 .57701 L
s
.36437 .5835 m
.36381 .58341 L
s
.81699 .45169 m
.8168 .45195 L
s
.36417 .58347 m
.36361 .58338 L
s
.54043 .57679 m
.53988 .57692 L
s
.54063 .57675 m
.54009 .57688 L
s
.36381 .58341 m
.36325 .58332 L
s
.36361 .58338 m
.36305 .58329 L
s
.54097 .57666 m
.54043 .57679 L
s
.81717 .45143 m
.81699 .45169 L
s
.33194 .64136 m
.33149 .64128 L
s
.54117 .57662 m
.54063 .57675 L
s
.36325 .58332 m
.3627 .58323 L
s
.36305 .58329 m
.3625 .5832 L
s
.54151 .57653 m
.54097 .57666 L
s
.54171 .57649 m
.54117 .57662 L
s
.3627 .58323 m
.36214 .58314 L
s
.3625 .5832 m
.36194 .58311 L
s
.81736 .45117 m
.81717 .45143 L
s
.54205 .5764 m
.54151 .57653 L
s
.54225 .57636 m
.54171 .57649 L
s
.33149 .64128 m
.33104 .6412 L
s
.36214 .58314 m
.36158 .58305 L
s
.36194 .58311 m
.36138 .58302 L
s
.54259 .57627 m
.54205 .5764 L
s
.81754 .45091 m
.81736 .45117 L
s
.5428 .57623 m
.54225 .57636 L
s
.36158 .58305 m
.36103 .58296 L
s
.36138 .58302 m
.36083 .58293 L
s
.54313 .57613 m
.54259 .57627 L
s
.54334 .57609 m
.5428 .57623 L
s
.36103 .58296 m
.36047 .58287 L
s
.33104 .6412 m
.33058 .64111 L
s
.36083 .58293 m
.36027 .58284 L
s
.81773 .45065 m
.81754 .45091 L
s
.54367 .576 m
.54313 .57613 L
s
.54388 .57596 m
.54334 .57609 L
s
.36047 .58287 m
.35991 .58278 L
s
.36027 .58284 m
.35971 .58275 L
s
.54421 .57587 m
.54367 .576 L
s
.81791 .45039 m
.81773 .45065 L
s
.54442 .57582 m
.54388 .57596 L
s
.35991 .58278 m
.35936 .58268 L
s
.33058 .64111 m
.33013 .64103 L
s
.35971 .58275 m
.35916 .58265 L
s
.54475 .57573 m
.54421 .57587 L
s
.54495 .57569 m
.54442 .57582 L
s
.35936 .58268 m
.3588 .58259 L
s
.81809 .45013 m
.81791 .45039 L
s
.35916 .58265 m
.3586 .58256 L
s
.54529 .57559 m
.54475 .57573 L
s
.54549 .57555 m
.54495 .57569 L
s
.3588 .58259 m
.35825 .5825 L
s
.33013 .64103 m
.32968 .64094 L
s
.3586 .58256 m
.35805 .58246 L
s
.54583 .57546 m
.54529 .57559 L
s
.81827 .44987 m
.81809 .45013 L
s
.54603 .57542 m
.54549 .57555 L
s
.35825 .5825 m
.35769 .5824 L
s
.35805 .58246 m
.35749 .58237 L
s
.54637 .57532 m
.54583 .57546 L
s
.54657 .57528 m
.54603 .57542 L
s
.35769 .5824 m
.35714 .58231 L
s
.32968 .64094 m
.32923 .64086 L
s
.81846 .44961 m
.81827 .44987 L
s
.35749 .58237 m
.35694 .58227 L
s
.54691 .57518 m
.54637 .57532 L
s
.54711 .57514 m
.54657 .57528 L
s
.35714 .58231 m
.35658 .58221 L
s
.35694 .58227 m
.35639 .58217 L
s
.81864 .44935 m
.81846 .44961 L
s
.54744 .57505 m
.54691 .57518 L
s
.35658 .58221 m
.35603 .58211 L
s
.54764 .575 m
.54711 .57514 L
s
.32923 .64086 m
.32879 .64077 L
s
.35639 .58217 m
.35583 .58208 L
s
.54798 .57491 m
.54744 .57505 L
s
.35603 .58211 m
.35548 .58201 L
s
.54818 .57486 m
.54764 .575 L
s
.81882 .44909 m
.81864 .44935 L
s
.35583 .58208 m
.35528 .58198 L
s
.54852 .57477 m
.54798 .57491 L
s
.35548 .58201 m
.35492 .58191 L
s
.54872 .57472 m
.54818 .57486 L
s
.32879 .64077 m
.32834 .64068 L
s
.35528 .58198 m
.35473 .58188 L
s
.819 .44883 m
.81882 .44909 L
s
.54905 .57463 m
.54852 .57477 L
s
.35492 .58191 m
.35437 .58182 L
s
.54925 .57458 m
.54872 .57472 L
s
.35473 .58188 m
.35417 .58178 L
s
.54959 .57449 m
.54905 .57463 L
s
.81918 .44857 m
.819 .44883 L
s
.32834 .64068 m
.32789 .6406 L
s
.35437 .58182 m
.35382 .58172 L
s
.54979 .57444 m
.54925 .57458 L
s
.35417 .58178 m
.35362 .58168 L
s
.55012 .57434 m
.54959 .57449 L
s
.35382 .58172 m
.35327 .58161 L
s
.55032 .5743 m
.54979 .57444 L
s
.81936 .44831 m
.81918 .44857 L
s
.35362 .58168 m
.35307 .58158 L
s
.55066 .5742 m
.55012 .57434 L
s
.32789 .6406 m
.32744 .64051 L
s
.35327 .58161 m
.35272 .58151 L
s
.55086 .57416 m
.55032 .5743 L
s
.35307 .58158 m
.35252 .58148 L
s
.81954 .44805 m
.81936 .44831 L
s
.55119 .57406 m
.55066 .5742 L
s
.35272 .58151 m
.35216 .58141 L
s
.55139 .57402 m
.55086 .57416 L
s
.35252 .58148 m
.35197 .58138 L
s
.55172 .57392 m
.55119 .57406 L
s
.32744 .64051 m
.32699 .64042 L
s
.35216 .58141 m
.35161 .58131 L
s
.55192 .57387 m
.55139 .57402 L
s
.81972 .44779 m
.81954 .44805 L
s
.35197 .58138 m
.35142 .58127 L
s
.55226 .57377 m
.55172 .57392 L
s
.35161 .58131 m
.35106 .58121 L
s
.55246 .57373 m
.55192 .57387 L
s
.35142 .58127 m
.35087 .58117 L
s
.8199 .44753 m
.81972 .44779 L
s
.32699 .64042 m
.32654 .64033 L
s
.55279 .57363 m
.55226 .57377 L
s
.35106 .58121 m
.35051 .5811 L
s
.55299 .57358 m
.55246 .57373 L
s
.35087 .58117 m
.35032 .58106 L
s
.55332 .57348 m
.55279 .57363 L
s
.82008 .44727 m
.8199 .44753 L
s
.35051 .5811 m
.34996 .581 L
s
.55352 .57344 m
.55299 .57358 L
s
.35032 .58106 m
.34977 .58096 L
s
.32654 .64033 m
.32609 .64024 L
s
.55385 .57333 m
.55332 .57348 L
s
.34996 .581 m
.34941 .58089 L
s
.55405 .57329 m
.55352 .57344 L
s
.82026 .44701 m
.82008 .44727 L
s
.34977 .58096 m
.34922 .58085 L
s
.55439 .57319 m
.55385 .57333 L
s
.34941 .58089 m
.34887 .58078 L
s
.55458 .57314 m
.55405 .57329 L
s
.34922 .58085 m
.34867 .58075 L
s
.32609 .64024 m
.32564 .64015 L
s
.82043 .44675 m
.82026 .44701 L
s
.55492 .57304 m
.55439 .57319 L
s
.34887 .58078 m
.34832 .58068 L
s
.55511 .57299 m
.55458 .57314 L
s
.34867 .58075 m
.34812 .58064 L
s
.55545 .57289 m
.55492 .57304 L
s
.82061 .44649 m
.82043 .44675 L
s
.34832 .58068 m
.34777 .58057 L
s
.55564 .57285 m
.55511 .57299 L
s
.32564 .64015 m
.3252 .64006 L
s
.34812 .58064 m
.34757 .58053 L
s
.55598 .57274 m
.55545 .57289 L
s
.34777 .58057 m
.34722 .58046 L
s
.55617 .5727 m
.55564 .57285 L
s
.82079 .44622 m
.82061 .44649 L
s
.34757 .58053 m
.34703 .58042 L
s
.55651 .57259 m
.55598 .57274 L
s
.34722 .58046 m
.34667 .58035 L
s
.5567 .57255 m
.55617 .5727 L
s
.3252 .64006 m
.32475 .63997 L
s
.34703 .58042 m
.34648 .58032 L
s
.82097 .44596 m
.82079 .44622 L
s
.55703 .57244 m
.55651 .57259 L
s
.34667 .58035 m
.34613 .58024 L
s
.55723 .5724 m
.5567 .57255 L
s
.34648 .58032 m
.34593 .58021 L
s
.82114 .4457 m
.82097 .44596 L
s
.55756 .57229 m
.55703 .57244 L
s
.32475 .63997 m
.3243 .63988 L
s
.34613 .58024 m
.34558 .58013 L
s
.55776 .57225 m
.55723 .5724 L
s
.34593 .58021 m
.34538 .5801 L
s
.55809 .57214 m
.55756 .57229 L
s
.34558 .58013 m
.34503 .58002 L
s
.82132 .44544 m
.82114 .4457 L
s
.55829 .57209 m
.55776 .57225 L
s
.34538 .5801 m
.34484 .57998 L
s
.3243 .63988 m
.32385 .63978 L
s
.55862 .57199 m
.55809 .57214 L
s
.34503 .58002 m
.34449 .57991 L
s
.55882 .57194 m
.55829 .57209 L
s
.34484 .57998 m
.34429 .57987 L
s
.82149 .44518 m
.82132 .44544 L
s
.55915 .57183 m
.55862 .57199 L
s
.34449 .57991 m
.34394 .5798 L
s
.55934 .57179 m
.55882 .57194 L
s
.34429 .57987 m
.34375 .57976 L
s
.32385 .63978 m
.32341 .63969 L
s
.82167 .44492 m
.82149 .44518 L
s
.55967 .57168 m
.55915 .57183 L
s
.34394 .5798 m
.34339 .57968 L
s
.55987 .57163 m
.55934 .57179 L
s
.34375 .57976 m
.3432 .57965 L
s
.5602 .57153 m
.55967 .57168 L
s
.82184 .44466 m
.82167 .44492 L
s
.34339 .57968 m
.34285 .57957 L
s
.56039 .57148 m
.55987 .57163 L
s
.3432 .57965 m
.34266 .57953 L
s
.32341 .63969 m
.32296 .6396 L
s
.56072 .57137 m
.5602 .57153 L
s
.34285 .57957 m
.34231 .57946 L
s
.56092 .57132 m
.56039 .57148 L
s
.82202 .4444 m
.82184 .44466 L
s
.34266 .57953 m
.34211 .57942 L
s
.56125 .57122 m
.56072 .57137 L
s
.34231 .57946 m
.34176 .57934 L
s
.32296 .6396 m
.32251 .6395 L
s
.56144 .57117 m
.56092 .57132 L
s
.34211 .57942 m
.34157 .5793 L
s
.82219 .44414 m
.82202 .4444 L
s
.56177 .57106 m
.56125 .57122 L
s
.34176 .57934 m
.34122 .57923 L
s
.56197 .57101 m
.56144 .57117 L
s
.34157 .5793 m
.34102 .57919 L
s
.82237 .44387 m
.82219 .44414 L
s
.5623 .5709 m
.56177 .57106 L
s
.32251 .6395 m
.32207 .63941 L
s
.34122 .57923 m
.34067 .57911 L
s
.56249 .57085 m
.56197 .57101 L
s
.34102 .57919 m
.34048 .57907 L
s
.56282 .57075 m
.5623 .5709 L
s
.34067 .57911 m
.34013 .57899 L
s
.82254 .44361 m
.82237 .44387 L
s
.56302 .5707 m
.56249 .57085 L
s
.34048 .57907 m
.33994 .57895 L
s
.32207 .63941 m
.32162 .63931 L
s
.56334 .57059 m
.56282 .57075 L
s
.34013 .57899 m
.33959 .57887 L
s
.56354 .57054 m
.56302 .5707 L
s
.82271 .44335 m
.82254 .44361 L
s
.33994 .57895 m
.3394 .57883 L
s
.56387 .57043 m
.56334 .57059 L
s
.33959 .57887 m
.33905 .57876 L
s
.56406 .57038 m
.56354 .57054 L
s
.3394 .57883 m
.33885 .57872 L
s
.32162 .63931 m
.32118 .63922 L
s
.82289 .44309 m
.82271 .44335 L
s
.56439 .57027 m
.56387 .57043 L
s
.33905 .57876 m
.3385 .57864 L
s
.56458 .57022 m
.56406 .57038 L
s
.33885 .57872 m
.33831 .5786 L
s
.82306 .44283 m
.82289 .44309 L
s
.56491 .57011 m
.56439 .57027 L
s
.3385 .57864 m
.33796 .57852 L
s
.32118 .63922 m
.32073 .63912 L
s
.5651 .57006 m
.56458 .57022 L
s
.33831 .5786 m
.33777 .57848 L
s
.56543 .56995 m
.56491 .57011 L
s
.82323 .44257 m
.82306 .44283 L
s
.33796 .57852 m
.33742 .5784 L
s
.56563 .5699 m
.5651 .57006 L
s
.33777 .57848 m
.33723 .57836 L
s
.32073 .63912 m
.32028 .63902 L
s
.56595 .56979 m
.56543 .56995 L
s
.33742 .5784 m
.33688 .57827 L
s
.8234 .4423 m
.82323 .44257 L
s
.56615 .56974 m
.56563 .5699 L
s
.33723 .57836 m
.33669 .57823 L
s
.56647 .56962 m
.56595 .56979 L
s
.33688 .57827 m
.33634 .57815 L
s
.56667 .56957 m
.56615 .56974 L
s
.33669 .57823 m
.33615 .57811 L
s
.82357 .44204 m
.8234 .4423 L
s
.32028 .63902 m
.31984 .63892 L
s
.56699 .56946 m
.56647 .56962 L
s
.33634 .57815 m
.3358 .57803 L
s
.56718 .56941 m
.56667 .56957 L
s
.33615 .57811 m
.33561 .57799 L
s
.82374 .44178 m
.82357 .44204 L
s
.56751 .5693 m
.56699 .56946 L
s
.3358 .57803 m
.33526 .57791 L
s
.31984 .63892 m
.31939 .63882 L
s
.5677 .56925 m
.56718 .56941 L
s
.33561 .57799 m
.33507 .57787 L
s
.82391 .44152 m
.82374 .44178 L
s
.56803 .56913 m
.56751 .5693 L
s
.33526 .57791 m
.33472 .57778 L
s
.56822 .56908 m
.5677 .56925 L
s
.33507 .57787 m
.33453 .57774 L
s
.31939 .63882 m
.31895 .63872 L
s
.56855 .56897 m
.56803 .56913 L
s
.33472 .57778 m
.33419 .57766 L
s
.82408 .44126 m
.82391 .44152 L
s
.56874 .56892 m
.56822 .56908 L
s
.33453 .57774 m
.334 .57762 L
s
.56906 .5688 m
.56855 .56897 L
s
.33419 .57766 m
.33365 .57753 L
s
.82425 .44099 m
.82408 .44126 L
s
.56926 .56875 m
.56874 .56892 L
s
.334 .57762 m
.33346 .57749 L
s
.31895 .63872 m
.3185 .63862 L
s
.56958 .56864 m
.56906 .5688 L
s
.33365 .57753 m
.33311 .57741 L
s
.56977 .56859 m
.56926 .56875 L
s
.33346 .57749 m
.33292 .57737 L
s
.82442 .44073 m
.82425 .44099 L
s
.5701 .56847 m
.56958 .56864 L
s
.33311 .57741 m
.33257 .57728 L
s
.3185 .63862 m
.31806 .63852 L
s
.57029 .56842 m
.56977 .56859 L
s
.33292 .57737 m
.33238 .57724 L
s
.82459 .44047 m
.82442 .44073 L
s
.57061 .5683 m
.5701 .56847 L
s
.33257 .57728 m
.33204 .57715 L
s
.5708 .56825 m
.57029 .56842 L
s
.33238 .57724 m
.33185 .57711 L
s
.82476 .44021 m
.82459 .44047 L
s
.31806 .63852 m
.31762 .63842 L
s
.33204 .57715 m
.3315 .57703 L
s
.57113 .56813 m
.57061 .5683 L
s
.57132 .56808 m
.5708 .56825 L
s
.33185 .57711 m
.33131 .57698 L
s
.82493 .43994 m
.82476 .44021 L
s
.3315 .57703 m
.33096 .5769 L
s
.57164 .56797 m
.57113 .56813 L
s
.57183 .56791 m
.57132 .56808 L
s
.33131 .57698 m
.33077 .57685 L
s
.31762 .63842 m
.31717 .63832 L
s
.33096 .5769 m
.33043 .57677 L
s
.57216 .5678 m
.57164 .56797 L
s
.82509 .43968 m
.82493 .43994 L
s
.57235 .56774 m
.57183 .56791 L
s
.33077 .57685 m
.33024 .57673 L
s
.33043 .57677 m
.32989 .57664 L
s
.57267 .56763 m
.57216 .5678 L
s
.31717 .63832 m
.31673 .63822 L
s
.82526 .43942 m
.82509 .43968 L
s
.33024 .57673 m
.3297 .57659 L
s
.57286 .56757 m
.57235 .56774 L
s
.32989 .57664 m
.32936 .57651 L
s
.57318 .56746 m
.57267 .56763 L
s
.3297 .57659 m
.32917 .57646 L
s
.57337 .5674 m
.57286 .56757 L
s
.82543 .43916 m
.82526 .43942 L
s
.31673 .63822 m
.31629 .63811 L
s
.32936 .57651 m
.32882 .57638 L
s
.5737 .56728 m
.57318 .56746 L
s
.32917 .57646 m
.32864 .57633 L
s
.57389 .56723 m
.57337 .5674 L
s
.8256 .4389 m
.82543 .43916 L
s
.32882 .57638 m
.32829 .57624 L
s
.57421 .56711 m
.5737 .56728 L
s
.32864 .57633 m
.3281 .5762 L
s
.5744 .56706 m
.57389 .56723 L
s
.31629 .63811 m
.31584 .63801 L
s
.82576 .43863 m
.8256 .4389 L
s
.32829 .57624 m
.32776 .57611 L
s
.57472 .56694 m
.57421 .56711 L
s
.3281 .5762 m
.32757 .57607 L
s
.57491 .56689 m
.5744 .56706 L
s
.82593 .43837 m
.82576 .43863 L
s
.32776 .57611 m
.32723 .57598 L
s
.31584 .63801 m
.3154 .63791 L
s
.57523 .56677 m
.57472 .56694 L
s
.32757 .57607 m
.32704 .57593 L
s
.57542 .56671 m
.57491 .56689 L
s
.32723 .57598 m
.32669 .57584 L
s
.57574 .56659 m
.57523 .56677 L
s
.82609 .43811 m
.82593 .43837 L
s
.32704 .57593 m
.32651 .5758 L
s
.57593 .56654 m
.57542 .56671 L
s
.3154 .63791 m
.31496 .6378 L
s
.32669 .57584 m
.32616 .57571 L
s
.57625 .56642 m
.57574 .56659 L
s
.82626 .43784 m
.82609 .43811 L
s
.32651 .5758 m
.32597 .57566 L
s
.57644 .56636 m
.57593 .56654 L
s
.32616 .57571 m
.32563 .57557 L
s
.57676 .56624 m
.57625 .56642 L
s
.31496 .6378 m
.31452 .63769 L
s
.32597 .57566 m
.32544 .57553 L
s
.82642 .43758 m
.82626 .43784 L
s
.57695 .56619 m
.57644 .56636 L
s
.32563 .57557 m
.3251 .57544 L
s
.57727 .56607 m
.57676 .56624 L
s
.32544 .57553 m
.32491 .57539 L
s
.57746 .56601 m
.57695 .56619 L
s
.82659 .43732 m
.82642 .43758 L
s
.31452 .63769 m
.31407 .63759 L
s
.3251 .57544 m
.32457 .5753 L
s
.57777 .56589 m
.57727 .56607 L
s
.32491 .57539 m
.32438 .57526 L
s
.57796 .56583 m
.57746 .56601 L
s
.82675 .43706 m
.82659 .43732 L
s
.32457 .5753 m
.32404 .57516 L
s
.57828 .56571 m
.57777 .56589 L
s
.32438 .57526 m
.32385 .57512 L
s
.57847 .56566 m
.57796 .56583 L
s
.31407 .63759 m
.31363 .63748 L
s
.82691 .43679 m
.82675 .43706 L
s
.32404 .57516 m
.32351 .57503 L
s
.57879 .56553 m
.57828 .56571 L
s
.32385 .57512 m
.32332 .57498 L
s
.57898 .56548 m
.57847 .56566 L
s
.82708 .43653 m
.82691 .43679 L
s
.32351 .57503 m
.32298 .57489 L
s
.31363 .63748 m
.31319 .63737 L
s
.5793 .56536 m
.57879 .56553 L
s
.32332 .57498 m
.32279 .57484 L
s
.57948 .5653 m
.57898 .56548 L
s
.32298 .57489 m
.32245 .57475 L
s
.82724 .43627 m
.82708 .43653 L
s
.5798 .56518 m
.5793 .56536 L
s
.32279 .57484 m
.32227 .5747 L
s
.57999 .56512 m
.57948 .5653 L
s
.31319 .63737 m
.31275 .63727 L
s
.32245 .57475 m
.32192 .57461 L
s
.8274 .436 m
.82724 .43627 L
s
.58031 .565 m
.5798 .56518 L
s
.32227 .5747 m
.32174 .57456 L
s
.58049 .56494 m
.57999 .56512 L
s
.32192 .57461 m
.3214 .57447 L
s
.31275 .63727 m
.31231 .63716 L
s
.58081 .56482 m
.58031 .565 L
s
.82756 .43574 m
.8274 .436 L
s
.32174 .57456 m
.32121 .57442 L
s
.581 .56476 m
.58049 .56494 L
s
.3214 .57447 m
.32087 .57433 L
s
.58131 .56464 m
.58081 .56482 L
s
.82772 .43548 m
.82756 .43574 L
s
.32121 .57442 m
.32068 .57428 L
s
.5815 .56458 m
.581 .56476 L
s
.31231 .63716 m
.31187 .63705 L
s
.32087 .57433 m
.32034 .57418 L
s
.58182 .56445 m
.58131 .56464 L
s
.32068 .57428 m
.32016 .57414 L
s
.82789 .43521 m
.82772 .43548 L
s
.58201 .5644 m
.5815 .56458 L
s
.32034 .57418 m
.31982 .57404 L
s
.58232 .56427 m
.58182 .56445 L
s
.31187 .63705 m
.31143 .63694 L
s
.32016 .57414 m
.31963 .57399 L
s
.58251 .56421 m
.58201 .5644 L
s
.82805 .43495 m
.82789 .43521 L
s
.31982 .57404 m
.31929 .5739 L
s
.58282 .56409 m
.58232 .56427 L
s
.31963 .57399 m
.31911 .57385 L
s
.58301 .56403 m
.58251 .56421 L
s
.82821 .43469 m
.82805 .43495 L
s
.31143 .63694 m
.31099 .63683 L
s
.31929 .5739 m
.31877 .57375 L
s
.58332 .5639 m
.58282 .56409 L
s
.31911 .57385 m
.31858 .57371 L
s
.58351 .56385 m
.58301 .56403 L
s
.82837 .43442 m
.82821 .43469 L
s
.31877 .57375 m
.31824 .57361 L
s
.58383 .56372 m
.58332 .5639 L
s
.31099 .63683 m
.31055 .63671 L
s
.31858 .57371 m
.31806 .57356 L
s
.58401 .56366 m
.58351 .56385 L
s
.82853 .43416 m
.82837 .43442 L
s
.31824 .57361 m
.31772 .57346 L
s
.58433 .56354 m
.58383 .56372 L
s
.31806 .57356 m
.31753 .57342 L
s
.58451 .56348 m
.58401 .56366 L
s
.31055 .63671 m
.31011 .6366 L
s
.82869 .4339 m
.82853 .43416 L
s
.31772 .57346 m
.31719 .57332 L
s
.58483 .56335 m
.58433 .56354 L
s
.31753 .57342 m
.31701 .57327 L
s
.58501 .56329 m
.58451 .56348 L
s
.82884 .43363 m
.82869 .4339 L
s
.31719 .57332 m
.31667 .57317 L
s
.58533 .56316 m
.58483 .56335 L
s
.31701 .57327 m
.31649 .57312 L
s
.31011 .6366 m
.30967 .63649 L
s
.58551 .56311 m
.58501 .56329 L
s
.31667 .57317 m
.31615 .57302 L
s
.829 .43337 m
.82884 .43363 L
s
.58582 .56298 m
.58533 .56316 L
s
.31649 .57312 m
.31596 .57298 L
s
.58601 .56292 m
.58551 .56311 L
s
.30967 .63649 m
.30923 .63638 L
s
.31615 .57302 m
.31563 .57288 L
s
.82916 .43311 m
.829 .43337 L
s
.58632 .56279 m
.58582 .56298 L
s
.31596 .57298 m
.31544 .57283 L
s
.58651 .56273 m
.58601 .56292 L
s
.31563 .57288 m
.3151 .57273 L
s
.82932 .43284 m
.82916 .43311 L
s
.58682 .5626 m
.58632 .56279 L
s
.31544 .57283 m
.31492 .57268 L
s
.30923 .63638 m
.30879 .63626 L
s
.587 .56254 m
.58651 .56273 L
s
.3151 .57273 m
.31458 .57258 L
s
.82947 .43258 m
.82932 .43284 L
s
.58732 .56241 m
.58682 .5626 L
s
.31492 .57268 m
.3144 .57253 L
s
.5875 .56235 m
.587 .56254 L
s
.30879 .63626 m
.30835 .63615 L
s
.31458 .57258 m
.31406 .57243 L
s
.58781 .56222 m
.58732 .56241 L
s
.82963 .43232 m
.82947 .43258 L
s
.3144 .57253 m
.31388 .57238 L
s
.588 .56216 m
.5875 .56235 L
s
.31406 .57243 m
.31354 .57228 L
s
.58831 .56203 m
.58781 .56222 L
s
.31388 .57238 m
.31336 .57223 L
s
.82979 .43205 m
.82963 .43232 L
s
.30835 .63615 m
.30791 .63603 L
s
.58849 .56197 m
.588 .56216 L
s
.31354 .57228 m
.31302 .57213 L
s
.5888 .56184 m
.58831 .56203 L
s
.31336 .57223 m
.31284 .57208 L
s
.82994 .43179 m
.82979 .43205 L
s
.58899 .56178 m
.58849 .56197 L
s
.30791 .63603 m
.30748 .63592 L
s
.31302 .57213 m
.3125 .57197 L
s
.5893 .56165 m
.5888 .56184 L
s
.31284 .57208 m
.31232 .57192 L
s
.8301 .43152 m
.82994 .43179 L
s
.58948 .56159 m
.58899 .56178 L
s
.3125 .57197 m
.31198 .57182 L
s
.58979 .56146 m
.5893 .56165 L
s
.31232 .57192 m
.3118 .57177 L
s
.30748 .63592 m
.30704 .6358 L
s
.83025 .43126 m
.8301 .43152 L
s
.58997 .5614 m
.58948 .56159 L
s
.31198 .57182 m
.31147 .57167 L
s
.59028 .56127 m
.58979 .56146 L
s
.3118 .57177 m
.31129 .57162 L
s
.83041 .431 m
.83025 .43126 L
s
.59047 .56121 m
.58997 .5614 L
s
.30704 .6358 m
.3066 .63568 L
s
.31147 .57167 m
.31095 .57151 L
s
.31129 .57162 m
.31077 .57146 L
s
.59078 .56107 m
.59028 .56127 L
s
.83056 .43073 m
.83041 .431 L
s
.59096 .56101 m
.59047 .56121 L
s
.31095 .57151 m
.31043 .57136 L
s
.3066 .63568 m
.30616 .63556 L
s
.31077 .57146 m
.31025 .57131 L
s
.59127 .56088 m
.59078 .56107 L
s
.83072 .43047 m
.83056 .43073 L
s
.59145 .56082 m
.59096 .56101 L
s
.31043 .57136 m
.30992 .5712 L
s
.31025 .57131 m
.30974 .57115 L
s
.59176 .56068 m
.59127 .56088 L
s
.59194 .56062 m
.59145 .56082 L
s
.83087 .4302 m
.83072 .43047 L
s
.30616 .63556 m
.30573 .63545 L
s
.30992 .5712 m
.3094 .57105 L
s
.30974 .57115 m
.30922 .571 L
s
.59225 .56049 m
.59176 .56068 L
s
.59243 .56043 m
.59194 .56062 L
s
.83102 .42994 m
.83087 .4302 L
s
.3094 .57105 m
.30888 .57089 L
s
.30573 .63545 m
.30529 .63533 L
s
.30922 .571 m
.3087 .57084 L
s
.59274 .56029 m
.59225 .56049 L
s
.59292 .56023 m
.59243 .56043 L
s
.83118 .42968 m
.83102 .42994 L
s
.30888 .57089 m
.30837 .57073 L
s
.3087 .57084 m
.30819 .57068 L
s
.59323 .5601 m
.59274 .56029 L
s
.59341 .56004 m
.59292 .56023 L
s
.30529 .63533 m
.30486 .63521 L
s
.83133 .42941 m
.83118 .42968 L
s
.30837 .57073 m
.30785 .57058 L
s
.30819 .57068 m
.30768 .57053 L
s
.59372 .5599 m
.59323 .5601 L
s
.5939 .55984 m
.59341 .56004 L
s
.83148 .42915 m
.83133 .42941 L
s
.30785 .57058 m
.30734 .57042 L
s
.30486 .63521 m
.30442 .63509 L
s
.30768 .57053 m
.30716 .57037 L
s
.59421 .5597 m
.59372 .5599 L
s
.59439 .55964 m
.5939 .55984 L
s
.83163 .42888 m
.83148 .42915 L
s
.30734 .57042 m
.30683 .57026 L
s
.30716 .57037 m
.30665 .57021 L
s
.59469 .5595 m
.59421 .5597 L
s
.30442 .63509 m
.30398 .63497 L
s
.59487 .55944 m
.59439 .55964 L
s
.83178 .42862 m
.83163 .42888 L
s
.30683 .57026 m
.30632 .5701 L
s
.30665 .57021 m
.30614 .57005 L
s
.59518 .55931 m
.59469 .5595 L
s
.59536 .55924 m
.59487 .55944 L
s
.83194 .42835 m
.83178 .42862 L
s
.30632 .5701 m
.3058 .56994 L
s
.30398 .63497 m
.30355 .63484 L
s
.30614 .57005 m
.30563 .56989 L
s
.59566 .55911 m
.59518 .55931 L
s
.59585 .55904 m
.59536 .55924 L
s
.83209 .42809 m
.83194 .42835 L
s
.3058 .56994 m
.30529 .56978 L
s
.30563 .56989 m
.30511 .56973 L
s
.59615 .55891 m
.59566 .55911 L
s
.30355 .63484 m
.30311 .63472 L
s
.59633 .55884 m
.59585 .55904 L
s
.83224 .42783 m
.83209 .42809 L
s
.30529 .56978 m
.30478 .56961 L
s
.30511 .56973 m
.3046 .56956 L
s
.59664 .55871 m
.59615 .55891 L
s
.59681 .55864 m
.59633 .55884 L
s
.83239 .42756 m
.83224 .42783 L
s
.30311 .63472 m
.30268 .6346 L
s
.30478 .56961 m
.30427 .56945 L
s
.3046 .56956 m
.30409 .5694 L
s
.59712 .5585 m
.59664 .55871 L
s
.5973 .55844 m
.59681 .55864 L
s
.83254 .4273 m
.83239 .42756 L
s
.30427 .56945 m
.30376 .56929 L
s
.30409 .5694 m
.30358 .56924 L
s
.30268 .6346 m
.30225 .63447 L
s
.5976 .5583 m
.59712 .5585 L
s
.59778 .55824 m
.5973 .55844 L
s
.83268 .42703 m
.83254 .4273 L
s
.30376 .56929 m
.30325 .56913 L
s
.30358 .56924 m
.30307 .56907 L
s
.59809 .5581 m
.5976 .5583 L
s
.59826 .55804 m
.59778 .55824 L
s
.30225 .63447 m
.30181 .63435 L
s
.83283 .42677 m
.83268 .42703 L
s
.30325 .56913 m
.30274 .56896 L
s
.30307 .56907 m
.30257 .56891 L
s
.59857 .5579 m
.59809 .5581 L
s
.59875 .55783 m
.59826 .55804 L
s
.83298 .4265 m
.83283 .42677 L
s
.30274 .56896 m
.30223 .5688 L
s
.30181 .63435 m
.30138 .63423 L
s
.30257 .56891 m
.30206 .56874 L
s
.59905 .55769 m
.59857 .5579 L
s
.59923 .55763 m
.59875 .55783 L
s
.83313 .42624 m
.83298 .4265 L
s
.30223 .5688 m
.30173 .56863 L
s
.30206 .56874 m
.30155 .56858 L
s
.59953 .55749 m
.59905 .55769 L
s
.30138 .63423 m
.30094 .6341 L
s
.59971 .55742 m
.59923 .55763 L
s
.83328 .42597 m
.83313 .42624 L
s
.30173 .56863 m
.30122 .56846 L
s
.30155 .56858 m
.30104 .56841 L
s
.60001 .55728 m
.59953 .55749 L
s
.60019 .55722 m
.59971 .55742 L
s
.83342 .42571 m
.83328 .42597 L
s
.30122 .56846 m
.30071 .5683 L
s
.30094 .6341 m
.30051 .63397 L
s
.30104 .56841 m
.30054 .56824 L
s
.60049 .55708 m
.60001 .55728 L
s
.60067 .55701 m
.60019 .55722 L
s
.83357 .42544 m
.83342 .42571 L
s
.30071 .5683 m
.30021 .56813 L
s
.30054 .56824 m
.30003 .56808 L
s
.30051 .63397 m
.30008 .63385 L
s
.60097 .55687 m
.60049 .55708 L
s
.60114 .55681 m
.60067 .55701 L
s
.83371 .42518 m
.83357 .42544 L
s
.30021 .56813 m
.2997 .56796 L
s
.30003 .56808 m
.29953 .56791 L
s
.60145 .55666 m
.60097 .55687 L
s
.60162 .5566 m
.60114 .55681 L
s
.83386 .42491 m
.83371 .42518 L
s
.30008 .63385 m
.29965 .63372 L
s
.2997 .56796 m
.2992 .56779 L
s
.29953 .56791 m
.29902 .56774 L
s
.60192 .55646 m
.60145 .55666 L
s
.83401 .42465 m
.83386 .42491 L
s
.6021 .55639 m
.60162 .5566 L
s
.2992 .56779 m
.29869 .56762 L
s
.29965 .63372 m
.29921 .63359 L
s
.29902 .56774 m
.29852 .56757 L
s
.6024 .55625 m
.60192 .55646 L
s
.83415 .42438 m
.83401 .42465 L
s
.60258 .55618 m
.6021 .55639 L
s
.29869 .56762 m
.29819 .56745 L
s
.29852 .56757 m
.29801 .5674 L
s
.60288 .55604 m
.6024 .55625 L
s
.29921 .63359 m
.29878 .63346 L
s
.8343 .42412 m
.83415 .42438 L
s
.60305 .55597 m
.60258 .55618 L
s
.29819 .56745 m
.29768 .56728 L
s
.29801 .5674 m
.29751 .56723 L
s
.60335 .55583 m
.60288 .55604 L
s
.83444 .42385 m
.8343 .42412 L
s
.60353 .55576 m
.60305 .55597 L
s
.29768 .56728 m
.29718 .56711 L
s
.29878 .63346 m
.29835 .63333 L
s
.29751 .56723 m
.29701 .56706 L
s
.60383 .55562 m
.60335 .55583 L
s
.83458 .42359 m
.83444 .42385 L
s
.604 .55555 m
.60353 .55576 L
s
.29718 .56711 m
.29668 .56694 L
s
.29701 .56706 m
.29651 .56688 L
s
.29835 .63333 m
.29792 .6332 L
s
.6043 .55541 m
.60383 .55562 L
s
.83473 .42332 m
.83458 .42359 L
s
.60447 .55534 m
.604 .55555 L
s
.29668 .56694 m
.29618 .56676 L
s
.29651 .56688 m
.29601 .56671 L
s
.60477 .5552 m
.6043 .55541 L
s
.83487 .42306 m
.83473 .42332 L
s
.29792 .6332 m
.29749 .63307 L
s
.60495 .55513 m
.60447 .55534 L
s
.29618 .56676 m
.29568 .56659 L
s
.29601 .56671 m
.2955 .56654 L
s
.60524 .55499 m
.60477 .5552 L
s
.83501 .42279 m
.83487 .42306 L
s
.60542 .55492 m
.60495 .55513 L
s
.29568 .56659 m
.29518 .56642 L
s
.29749 .63307 m
.29706 .63294 L
s
.2955 .56654 m
.295 .56636 L
s
.60572 .55477 m
.60524 .55499 L
s
.83515 .42253 m
.83501 .42279 L
s
.60589 .55471 m
.60542 .55492 L
s
.29518 .56642 m
.29468 .56624 L
s
.295 .56636 m
.29451 .56619 L
s
.29706 .63294 m
.29663 .63281 L
s
.8353 .42226 m
.83515 .42253 L
s
.60619 .55456 m
.60572 .55477 L
s
.60636 .55449 m
.60589 .55471 L
s
.29468 .56624 m
.29418 .56607 L
s
.29451 .56619 m
.29401 .56601 L
s
.83544 .422 m
.8353 .42226 L
s
.60666 .55435 m
.60619 .55456 L
s
.60683 .55428 m
.60636 .55449 L
s
.29663 .63281 m
.2962 .63267 L
s
.29418 .56607 m
.29368 .56589 L
s
.29401 .56601 m
.29351 .56584 L
s
.83558 .42173 m
.83544 .422 L
s
.60713 .55413 m
.60666 .55435 L
s
.6073 .55407 m
.60683 .55428 L
s
.29368 .56589 m
.29318 .56571 L
s
.29351 .56584 m
.29301 .56566 L
s
.2962 .63267 m
.29577 .63254 L
s
.83572 .42146 m
.83558 .42173 L
s
.6076 .55392 m
.60713 .55413 L
s
.60777 .55385 m
.6073 .55407 L
s
.29318 .56571 m
.29269 .56554 L
s
.29301 .56566 m
.29251 .56548 L
s
.83586 .4212 m
.83572 .42146 L
s
.60807 .5537 m
.6076 .55392 L
s
.29577 .63254 m
.29534 .63241 L
s
.29269 .56554 m
.29219 .56536 L
s
.60824 .55363 m
.60777 .55385 L
s
.29251 .56548 m
.29202 .5653 L
s
.836 .42093 m
.83586 .4212 L
s
.60853 .55349 m
.60807 .5537 L
s
.29219 .56536 m
.29169 .56518 L
s
.60871 .55342 m
.60824 .55363 L
s
.29534 .63241 m
.29491 .63227 L
s
.29202 .5653 m
.29152 .56513 L
s
.83614 .42067 m
.836 .42093 L
s
.609 .55327 m
.60853 .55349 L
s
.29169 .56518 m
.2912 .565 L
s
.60917 .5532 m
.60871 .55342 L
s
.83628 .4204 m
.83614 .42067 L
s
.29152 .56513 m
.29103 .56495 L
s
.29491 .63227 m
.29448 .63214 L
s
.60947 .55305 m
.609 .55327 L
s
.2912 .565 m
.2907 .56482 L
s
.60964 .55298 m
.60917 .5532 L
s
.83641 .42014 m
.83628 .4204 L
s
.29103 .56495 m
.29053 .56477 L
s
.60993 .55283 m
.60947 .55305 L
s
.29448 .63214 m
.29405 .632 L
s
.2907 .56482 m
.29021 .56464 L
s
.6101 .55277 m
.60964 .55298 L
s
.83655 .41987 m
.83641 .42014 L
s
.29053 .56477 m
.29004 .56459 L
s
.6104 .55261 m
.60993 .55283 L
s
.29021 .56464 m
.28972 .56446 L
s
.61057 .55255 m
.6101 .55277 L
s
.83669 .41961 m
.83655 .41987 L
s
.29405 .632 m
.29363 .63186 L
s
.29004 .56459 m
.28955 .5644 L
s
.61086 .55239 m
.6104 .55261 L
s
.28972 .56446 m
.28922 .56428 L
s
.61103 .55233 m
.61057 .55255 L
s
.83683 .41934 m
.83669 .41961 L
s
.28955 .5644 m
.28905 .56422 L
s
.29363 .63186 m
.2932 .63173 L
s
.61132 .55218 m
.61086 .55239 L
s
.28922 .56428 m
.28873 .5641 L
s
.83696 .41907 m
.83683 .41934 L
s
.61149 .55211 m
.61103 .55233 L
s
.28905 .56422 m
.28856 .56404 L
s
.61179 .55195 m
.61132 .55218 L
s
.2932 .63173 m
.29277 .63159 L
s
.8371 .41881 m
.83696 .41907 L
s
.28873 .5641 m
.28824 .56391 L
s
.61196 .55189 m
.61149 .55211 L
s
.28856 .56404 m
.28807 .56386 L
s
.61225 .55173 m
.61179 .55195 L
s
.83724 .41854 m
.8371 .41881 L
s
.28824 .56391 m
.28775 .56373 L
s
.61242 .55166 m
.61196 .55189 L
s
.29277 .63159 m
.29235 .63145 L
s
.28807 .56386 m
.28758 .56367 L
s
.61271 .55151 m
.61225 .55173 L
s
.83737 .41828 m
.83724 .41854 L
s
.28775 .56373 m
.28726 .56354 L
s
.61288 .55144 m
.61242 .55166 L
s
.28758 .56367 m
.28709 .56349 L
s
.29235 .63145 m
.29192 .63131 L
s
.83751 .41801 m
.83737 .41828 L
s
.61317 .55129 m
.61271 .55151 L
s
.28726 .56354 m
.28677 .56336 L
s
.61334 .55122 m
.61288 .55144 L
s
.28709 .56349 m
.2866 .5633 L
s
.83764 .41774 m
.83751 .41801 L
s
.61363 .55107 m
.61317 .55129 L
s
.29192 .63131 m
.29149 .63117 L
s
.28677 .56336 m
.28628 .56317 L
s
.6138 .551 m
.61334 .55122 L
s
.2866 .5633 m
.28611 .56312 L
s
.83778 .41748 m
.83764 .41774 L
s
.61409 .55084 m
.61363 .55107 L
s
.28628 .56317 m
.28579 .56299 L
s
.61426 .55077 m
.6138 .551 L
s
.29149 .63117 m
.29107 .63103 L
s
.28611 .56312 m
.28562 .56293 L
s
.83791 .41721 m
.83778 .41748 L
s
.61454 .55062 m
.61409 .55084 L
s
.28579 .56299 m
.2853 .5628 L
s
.61471 .55055 m
.61426 .55077 L
s
.28562 .56293 m
.28513 .56274 L
s
.83804 .41695 m
.83791 .41721 L
s
.29107 .63103 m
.29064 .63089 L
s
.615 .55039 m
.61454 .55062 L
s
.2853 .5628 m
.28481 .56261 L
s
.61517 .55032 m
.61471 .55055 L
s
.28513 .56274 m
.28465 .56256 L
s
.83818 .41668 m
.83804 .41695 L
s
.61546 .55017 m
.615 .55039 L
s
.29064 .63089 m
.29022 .63075 L
s
.28481 .56261 m
.28433 .56242 L
s
.61563 .5501 m
.61517 .55032 L
s
.83831 .41641 m
.83818 .41668 L
s
.28465 .56256 m
.28416 .56237 L
s
.61591 .54994 m
.61546 .55017 L
s
.28433 .56242 m
.28384 .56224 L
s
.61608 .54987 m
.61563 .5501 L
s
.29022 .63075 m
.28979 .6306 L
s
.83844 .41615 m
.83831 .41641 L
s
.28416 .56237 m
.28368 .56218 L
s
.61637 .54972 m
.61591 .54994 L
s
.28384 .56224 m
.28336 .56205 L
s
.83857 .41588 m
.83844 .41615 L
s
.61654 .54965 m
.61608 .54987 L
s
.28368 .56218 m
.28319 .56199 L
s
.28979 .6306 m
.28937 .63046 L
s
.61682 .54949 m
.61637 .54972 L
s
.28336 .56205 m
.28287 .56186 L
s
.83871 .41562 m
.83857 .41588 L
s
.61699 .54942 m
.61654 .54965 L
s
.28319 .56199 m
.28271 .5618 L
s
.28937 .63046 m
.28894 .63032 L
s
.61728 .54926 m
.61682 .54949 L
s
.83884 .41535 m
.83871 .41562 L
s
.28287 .56186 m
.28239 .56167 L
s
.61744 .54919 m
.61699 .54942 L
s
.28271 .5618 m
.28222 .56161 L
s
.83897 .41508 m
.83884 .41535 L
s
.61773 .54903 m
.61728 .54926 L
s
.28239 .56167 m
.28191 .56147 L
s
.28894 .63032 m
.28852 .63017 L
s
.6179 .54896 m
.61744 .54919 L
s
.28222 .56161 m
.28174 .56142 L
s
.8391 .41482 m
.83897 .41508 L
s
.61818 .54881 m
.61773 .54903 L
s
.28191 .56147 m
.28142 .56128 L
s
.61835 .54873 m
.6179 .54896 L
s
.28174 .56142 m
.28126 .56123 L
s
.28852 .63017 m
.2881 .63002 L
s
.83923 .41455 m
.8391 .41482 L
s
.61863 .54858 m
.61818 .54881 L
s
.28142 .56128 m
.28094 .56109 L
s
.6188 .5485 m
.61835 .54873 L
s
.28126 .56123 m
.28078 .56103 L
s
.83936 .41428 m
.83923 .41455 L
s
.2881 .63002 m
.28767 .62988 L
s
.61908 .54835 m
.61863 .54858 L
s
.28094 .56109 m
.28046 .5609 L
s
.61925 .54827 m
.6188 .5485 L
s
.28078 .56103 m
.28029 .56084 L
s
.83949 .41402 m
.83936 .41428 L
s
.61953 .54812 m
.61908 .54835 L
s
.28046 .5609 m
.27998 .5607 L
s
.28767 .62988 m
.28725 .62973 L
s
.6197 .54804 m
.61925 .54827 L
s
.28029 .56084 m
.27981 .56065 L
s
.83962 .41375 m
.83949 .41402 L
s
.61998 .54788 m
.61953 .54812 L
s
.27998 .5607 m
.2795 .56051 L
s
.62015 .54781 m
.6197 .54804 L
s
.27981 .56065 m
.27933 .56045 L
s
.83974 .41348 m
.83962 .41375 L
s
.28725 .62973 m
.28683 .62958 L
s
.62043 .54765 m
.61998 .54788 L
s
.2795 .56051 m
.27902 .56031 L
s
.83987 .41322 m
.83974 .41348 L
s
.6206 .54758 m
.62015 .54781 L
s
.27933 .56045 m
.27885 .56026 L
s
.28683 .62958 m
.28641 .62944 L
s
.62088 .54742 m
.62043 .54765 L
s
.27902 .56031 m
.27854 .56012 L
s
.84 .41295 m
.83987 .41322 L
s
.62104 .54735 m
.6206 .54758 L
s
.27885 .56026 m
.27838 .56006 L
s
.62133 .54719 m
.62088 .54742 L
s
.28641 .62944 m
.28599 .62929 L
s
.27854 .56012 m
.27806 .55992 L
s
.84013 .41269 m
.84 .41295 L
s
.27838 .56006 m
.2779 .55986 L
s
.62149 .54711 m
.62104 .54735 L
s
.84025 .41242 m
.84013 .41269 L
s
.27806 .55992 m
.27759 .55973 L
s
.62177 .54695 m
.62133 .54719 L
s
.28599 .62929 m
.28557 .62914 L
s
.2779 .55986 m
.27742 .55967 L
s
.62194 .54688 m
.62149 .54711 L
s
.84038 .41215 m
.84025 .41242 L
s
.27759 .55973 m
.27711 .55953 L
s
.62222 .54672 m
.62177 .54695 L
s
.27742 .55967 m
.27695 .55947 L
s
.62238 .54665 m
.62194 .54688 L
s
.28557 .62914 m
.28515 .62899 L
s
.8405 .41189 m
.84038 .41215 L
s
.27711 .55953 m
.27663 .55933 L
s
.62266 .54648 m
.62222 .54672 L
s
.27695 .55947 m
.27647 .55927 L
s
.62282 .54641 m
.62238 .54665 L
s
.84063 .41162 m
.8405 .41189 L
s
.28515 .62899 m
.28473 .62884 L
s
.27663 .55933 m
.27616 .55913 L
s
.6231 .54625 m
.62266 .54648 L
s
.27647 .55927 m
.27599 .55907 L
s
.62327 .54618 m
.62282 .54641 L
s
.84076 .41135 m
.84063 .41162 L
s
.27616 .55913 m
.27568 .55893 L
s
.62355 .54601 m
.6231 .54625 L
s
.28473 .62884 m
.28431 .62868 L
s
.27599 .55907 m
.27552 .55887 L
s
.62371 .54594 m
.62327 .54618 L
s
.84088 .41108 m
.84076 .41135 L
s
.27568 .55893 m
.27521 .55873 L
s
.62399 .54578 m
.62355 .54601 L
s
.27552 .55887 m
.27505 .55867 L
s
.841 .41082 m
.84088 .41108 L
s
.62415 .5457 m
.62371 .54594 L
s
.28431 .62868 m
.28389 .62853 L
s
.27521 .55873 m
.27474 .55853 L
s
.62443 .54554 m
.62399 .54578 L
s
.84113 .41055 m
.841 .41082 L
s
.27505 .55867 m
.27457 .55847 L
s
.62459 .54547 m
.62415 .5457 L
s
.28389 .62853 m
.28347 .62838 L
s
.27474 .55853 m
.27426 .55833 L
s
.62487 .5453 m
.62443 .54554 L
s
.84125 .41028 m
.84113 .41055 L
s
.27457 .55847 m
.2741 .55827 L
s
.62503 .54523 m
.62459 .54547 L
s
.84137 .41002 m
.84125 .41028 L
s
.27426 .55833 m
.27379 .55813 L
s
.28347 .62838 m
.28305 .62823 L
s
.62531 .54506 m
.62487 .5453 L
s
.2741 .55827 m
.27363 .55807 L
s
.62547 .54499 m
.62503 .54523 L
s
.8415 .40975 m
.84137 .41002 L
s
.27379 .55813 m
.27332 .55793 L
s
.62575 .54483 m
.62531 .54506 L
s
.27363 .55807 m
.27316 .55787 L
s
.28305 .62823 m
.28263 .62807 L
s
.62591 .54475 m
.62547 .54499 L
s
.84162 .40948 m
.8415 .40975 L
s
.27332 .55793 m
.27285 .55772 L
s
.62619 .54459 m
.62575 .54483 L
s
.27316 .55787 m
.27269 .55766 L
s
.62635 .54451 m
.62591 .54475 L
s
.28263 .62807 m
.28221 .62792 L
s
.84174 .40922 m
.84162 .40948 L
s
.27285 .55772 m
.27238 .55752 L
s
.62662 .54435 m
.62619 .54459 L
s
.27269 .55766 m
.27222 .55746 L
s
.62678 .54427 m
.62635 .54451 L
s
.84186 .40895 m
.84174 .40922 L
s
.28221 .62792 m
.2818 .62776 L
s
.27238 .55752 m
.27191 .55731 L
s
.62706 .54411 m
.62662 .54435 L
s
.27222 .55746 m
.27175 .55725 L
s
.84198 .40868 m
.84186 .40895 L
s
.62722 .54403 m
.62678 .54427 L
s
.27191 .55731 m
.27144 .55711 L
s
.2818 .62776 m
.28138 .6276 L
s
.6275 .54386 m
.62706 .54411 L
s
.8421 .40842 m
.84198 .40868 L
s
.27175 .55725 m
.27128 .55705 L
s
.62766 .54379 m
.62722 .54403 L
s
.27144 .55711 m
.27097 .5569 L
s
.84222 .40815 m
.8421 .40842 L
s
.62793 .54362 m
.6275 .54386 L
s
.27128 .55705 m
.27081 .55684 L
s
.28138 .6276 m
.28096 .62745 L
s
.62809 .54355 m
.62766 .54379 L
s
.27097 .5569 m
.27051 .5567 L
s
.84234 .40788 m
.84222 .40815 L
s
.62836 .54338 m
.62793 .54362 L
s
.27081 .55684 m
.27035 .55664 L
s
.62852 .54331 m
.62809 .54355 L
s
.28096 .62745 m
.28055 .62729 L
s
.84246 .40761 m
.84234 .40788 L
s
.27051 .5567 m
.27004 .55649 L
s
.6288 .54314 m
.62836 .54338 L
s
.27035 .55664 m
.26988 .55643 L
s
.62896 .54306 m
.62852 .54331 L
s
.84258 .40735 m
.84246 .40761 L
s
.28055 .62729 m
.28013 .62713 L
s
.27004 .55649 m
.26958 .55628 L
s
.62923 .54289 m
.6288 .54314 L
s
.26988 .55643 m
.26942 .55622 L
s
.62939 .54282 m
.62896 .54306 L
s
.8427 .40708 m
.84258 .40735 L
s
.26958 .55628 m
.26911 .55608 L
s
.62966 .54265 m
.62923 .54289 L
s
.28013 .62713 m
.27972 .62697 L
s
.26942 .55622 m
.26895 .55601 L
s
.84282 .40681 m
.8427 .40708 L
s
.62982 .54257 m
.62939 .54282 L
s
.26911 .55608 m
.26865 .55587 L
s
.63009 .54241 m
.62966 .54265 L
s
.26895 .55601 m
.26849 .55581 L
s
.84293 .40655 m
.84282 .40681 L
s
.27972 .62697 m
.2793 .62681 L
s
.63025 .54233 m
.62982 .54257 L
s
.26865 .55587 m
.26818 .55566 L
s
.63052 .54216 m
.63009 .54241 L
s
.84305 .40628 m
.84293 .40655 L
s
.26849 .55581 m
.26802 .5556 L
s
.63068 .54208 m
.63025 .54233 L
s
.2793 .62681 m
.27889 .62665 L
s
.26818 .55566 m
.26772 .55545 L
s
.84317 .40601 m
.84305 .40628 L
s
.63095 .54191 m
.63052 .54216 L
s
.26802 .5556 m
.26756 .55539 L
s
.63111 .54184 m
.63068 .54208 L
s
.84328 .40574 m
.84317 .40601 L
s
.26772 .55545 m
.26726 .55524 L
s
.27889 .62665 m
.27847 .62649 L
s
.63138 .54167 m
.63095 .54191 L
s
.26756 .55539 m
.2671 .55518 L
s
.63154 .54159 m
.63111 .54184 L
s
.8434 .40548 m
.84328 .40574 L
s
.26726 .55524 m
.2668 .55503 L
s
.63181 .54142 m
.63138 .54167 L
s
.27847 .62649 m
.27806 .62633 L
s
.2671 .55518 m
.26664 .55496 L
s
.63196 .54135 m
.63154 .54159 L
s
.84352 .40521 m
.8434 .40548 L
s
.2668 .55503 m
.26634 .55481 L
s
.63223 .54117 m
.63181 .54142 L
s
.26664 .55496 m
.26618 .55475 L
s
.27806 .62633 m
.27765 .62617 L
s
.84363 .40494 m
.84352 .40521 L
s
.63239 .5411 m
.63196 .54135 L
s
.26634 .55481 m
.26588 .5546 L
s
.63266 .54093 m
.63223 .54117 L
s
.26618 .55475 m
.26572 .55454 L
s
.84375 .40468 m
.84363 .40494 L
s
.63281 .54085 m
.63239 .5411 L
s
.27765 .62617 m
.27723 .626 L
s
.26588 .5546 m
.26542 .55439 L
s
.84386 .40441 m
.84375 .40468 L
s
.26572 .55454 m
.26526 .55433 L
s
.63308 .54068 m
.63266 .54093 L
s
.63324 .5406 m
.63281 .54085 L
s
.26542 .55439 m
.26496 .55418 L
s
.27723 .626 m
.27682 .62584 L
s
.84397 .40414 m
.84386 .40441 L
s
.26526 .55433 m
.2648 .55411 L
s
.63351 .54043 m
.63308 .54068 L
s
.63366 .54035 m
.63324 .5406 L
s
.84409 .40387 m
.84397 .40414 L
s
.26496 .55418 m
.2645 .55396 L
s
.27682 .62584 m
.27641 .62567 L
s
.2648 .55411 m
.26435 .5539 L
s
.63393 .54018 m
.63351 .54043 L
s
.63409 .5401 m
.63366 .54035 L
s
.8442 .40361 m
.84409 .40387 L
s
.2645 .55396 m
.26404 .55375 L
s
.26435 .5539 m
.26389 .55369 L
s
.63435 .53993 m
.63393 .54018 L
s
.27641 .62567 m
.276 .62551 L
s
.63451 .53985 m
.63409 .5401 L
s
.84431 .40334 m
.8442 .40361 L
s
.26404 .55375 m
.26359 .55353 L
s
.26389 .55369 m
.26343 .55347 L
s
.63477 .53968 m
.63435 .53993 L
s
.84442 .40307 m
.84431 .40334 L
s
.63493 .5396 m
.63451 .53985 L
s
.276 .62551 m
.27559 .62534 L
s
.26359 .55353 m
.26313 .55332 L
s
.26343 .55347 m
.26298 .55325 L
s
.63519 .53943 m
.63477 .53968 L
s
.84454 .4028 m
.84442 .40307 L
s
.63535 .53935 m
.63493 .5396 L
s
.26313 .55332 m
.26268 .5531 L
s
.27559 .62534 m
.27518 .62518 L
s
.84465 .40254 m
.84454 .4028 L
s
.26298 .55325 m
.26252 .55304 L
s
.63561 .53917 m
.63519 .53943 L
s
.63577 .5391 m
.63535 .53935 L
s
.26268 .5531 m
.26222 .55288 L
s
.84476 .40227 m
.84465 .40254 L
s
.27518 .62518 m
.27477 .62501 L
s
.26252 .55304 m
.26207 .55282 L
s
.63603 .53892 m
.63561 .53917 L
s
.63619 .53884 m
.63577 .5391 L
s
.84487 .402 m
.84476 .40227 L
s
.26222 .55288 m
.26177 .55267 L
s
.26207 .55282 m
.26162 .5526 L
s
.63645 .53867 m
.63603 .53892 L
s
.27477 .62501 m
.27436 .62484 L
s
.6366 .53859 m
.63619 .53884 L
s
.84498 .40173 m
.84487 .402 L
s
.26177 .55267 m
.26132 .55245 L
s
.26162 .5526 m
.26117 .55238 L
s
.63687 .53842 m
.63645 .53867 L
s
.84509 .40147 m
.84498 .40173 L
s
.63702 .53834 m
.6366 .53859 L
s
.27436 .62484 m
.27395 .62467 L
s
.26132 .55245 m
.26087 .55223 L
s
.26117 .55238 m
.26071 .55216 L
s
.63729 .53816 m
.63687 .53842 L
s
.8452 .4012 m
.84509 .40147 L
s
.63744 .53808 m
.63702 .53834 L
s
.27395 .62467 m
.27354 .6245 L
s
.26087 .55223 m
.26042 .55201 L
s
.26071 .55216 m
.26026 .55195 L
s
.8453 .40093 m
.8452 .4012 L
s
.6377 .53791 m
.63729 .53816 L
s
.63785 .53783 m
.63744 .53808 L
s
.26042 .55201 m
.25997 .55179 L
s
.84541 .40066 m
.8453 .40093 L
s
.27354 .6245 m
.27313 .62433 L
s
.26026 .55195 m
.25981 .55173 L
s
.63812 .53765 m
.6377 .53791 L
s
.63827 .53757 m
.63785 .53783 L
s
.25997 .55179 m
.25952 .55157 L
s
.84552 .4004 m
.84541 .40066 L
s
.25981 .55173 m
.25936 .5515 L
s
.27313 .62433 m
.27272 .62416 L
s
.63853 .5374 m
.63812 .53765 L
s
.63868 .53732 m
.63827 .53757 L
s
.84563 .40013 m
.84552 .4004 L
s
.25952 .55157 m
.25907 .55135 L
s
.25936 .5515 m
.25892 .55128 L
s
.63894 .53714 m
.63853 .5374 L
s
.27272 .62416 m
.27232 .62399 L
s
.84574 .39986 m
.84563 .40013 L
s
.63909 .53706 m
.63868 .53732 L
s
.25907 .55135 m
.25862 .55112 L
s
.25892 .55128 m
.25847 .55106 L
s
.63935 .53688 m
.63894 .53714 L
s
.84584 .39959 m
.84574 .39986 L
s
.6395 .5368 m
.63909 .53706 L
s
.27232 .62399 m
.27191 .62382 L
s
.25862 .55112 m
.25817 .5509 L
s
.25847 .55106 m
.25802 .55084 L
s
.84595 .39932 m
.84584 .39959 L
s
.63976 .53662 m
.63935 .53688 L
s
.63991 .53654 m
.6395 .5368 L
s
.25817 .5509 m
.25773 .55068 L
s
.27191 .62382 m
.2715 .62364 L
s
.84605 .39906 m
.84595 .39932 L
s
.25802 .55084 m
.25758 .55062 L
s
.64018 .53637 m
.63976 .53662 L
s
.64032 .53629 m
.63991 .53654 L
s
.25773 .55068 m
.25728 .55046 L
s
.84616 .39879 m
.84605 .39906 L
s
.25758 .55062 m
.25713 .55039 L
s
.2715 .62364 m
.2711 .62347 L
s
.64058 .53611 m
.64018 .53637 L
s
.64073 .53603 m
.64032 .53629 L
s
.84626 .39852 m
.84616 .39879 L
s
.25728 .55046 m
.25684 .55023 L
s
.25713 .55039 m
.25669 .55017 L
s
.64099 .53585 m
.64058 .53611 L
s
.2711 .62347 m
.27069 .6233 L
s
.84637 .39825 m
.84626 .39852 L
s
.64114 .53577 m
.64073 .53603 L
s
.25684 .55023 m
.25639 .55001 L
s
.25669 .55017 m
.25624 .54994 L
s
.6414 .53559 m
.64099 .53585 L
s
.84647 .39799 m
.84637 .39825 L
s
.27069 .6233 m
.27029 .62312 L
s
.64155 .53551 m
.64114 .53577 L
s
.25639 .55001 m
.25595 .54978 L
s
.25624 .54994 m
.2558 .54972 L
s
.84658 .39772 m
.84647 .39799 L
s
.64181 .53533 m
.6414 .53559 L
s
.64196 .53525 m
.64155 .53551 L
s
.25595 .54978 m
.25551 .54956 L
s
.27029 .62312 m
.26988 .62294 L
s
.84668 .39745 m
.84658 .39772 L
s
.2558 .54972 m
.25536 .54949 L
s
.64221 .53507 m
.64181 .53533 L
s
.64236 .53499 m
.64196 .53525 L
s
.25551 .54956 m
.25507 .54933 L
s
.84678 .39718 m
.84668 .39745 L
s
.26988 .62294 m
.26948 .62277 L
s
.25536 .54949 m
.25492 .54926 L
s
.64262 .53481 m
.64221 .53507 L
s
.64277 .53473 m
.64236 .53499 L
s
.84688 .39691 m
.84678 .39718 L
s
.25507 .54933 m
.25462 .5491 L
s
.25492 .54926 m
.25447 .54904 L
s
.26948 .62277 m
.26907 .62259 L
s
.64302 .53454 m
.64262 .53481 L
s
.84699 .39665 m
.84688 .39691 L
s
.64317 .53446 m
.64277 .53473 L
s
.25462 .5491 m
.25418 .54887 L
s
.25447 .54904 m
.25404 .54881 L
s
.84709 .39638 m
.84699 .39665 L
s
.64343 .53428 m
.64302 .53454 L
s
.26907 .62259 m
.26867 .62241 L
s
.64357 .5342 m
.64317 .53446 L
s
.25418 .54887 m
.25375 .54865 L
s
.25404 .54881 m
.2536 .54858 L
s
.84719 .39611 m
.84709 .39638 L
s
.64383 .53402 m
.64343 .53428 L
s
.26867 .62241 m
.26827 .62223 L
s
.64397 .53394 m
.64357 .5342 L
s
.25375 .54865 m
.25331 .54842 L
s
.84729 .39584 m
.84719 .39611 L
s
.2536 .54858 m
.25316 .54835 L
s
.64423 .53376 m
.64383 .53402 L
s
.64437 .53367 m
.64397 .53394 L
s
.25331 .54842 m
.25287 .54819 L
s
.84739 .39557 m
.84729 .39584 L
s
.26827 .62223 m
.26787 .62205 L
s
.25316 .54835 m
.25272 .54812 L
s
.64463 .53349 m
.64423 .53376 L
s
.84749 .39531 m
.84739 .39557 L
s
.64478 .53341 m
.64437 .53367 L
s
.25287 .54819 m
.25243 .54796 L
s
.25272 .54812 m
.25228 .54789 L
s
.26787 .62205 m
.26746 .62187 L
s
.64503 .53323 m
.64463 .53349 L
s
.84759 .39504 m
.84749 .39531 L
s
.64517 .53314 m
.64478 .53341 L
s
.25243 .54796 m
.252 .54773 L
s
.25228 .54789 m
.25185 .54766 L
s
.84769 .39477 m
.84759 .39504 L
s
.26746 .62187 m
.26706 .62169 L
s
.64543 .53296 m
.64503 .53323 L
s
.64557 .53288 m
.64517 .53314 L
s
.252 .54773 m
.25156 .54749 L
s
.25185 .54766 m
.25141 .54743 L
s
.84779 .3945 m
.84769 .39477 L
s
.64583 .5327 m
.64543 .53296 L
s
.26706 .62169 m
.26666 .62151 L
s
.25156 .54749 m
.25113 .54726 L
s
.64597 .53261 m
.64557 .53288 L
s
.84788 .39424 m
.84779 .3945 L
s
.25141 .54743 m
.25098 .5472 L
s
.64622 .53243 m
.64583 .5327 L
s
.26666 .62151 m
.26626 .62133 L
s
.84798 .39397 m
.84788 .39424 L
s
.25113 .54726 m
.25069 .54703 L
s
.64637 .53235 m
.64597 .53261 L
s
.25098 .5472 m
.25055 .54697 L
s
.64662 .53216 m
.64622 .53243 L
s
.84808 .3937 m
.84798 .39397 L
s
.25069 .54703 m
.25026 .5468 L
s
.64676 .53208 m
.64637 .53235 L
s
.26626 .62133 m
.26586 .62115 L
s
.25055 .54697 m
.25011 .54673 L
s
.84817 .39343 m
.84808 .3937 L
s
.64701 .5319 m
.64662 .53216 L
s
.25026 .5468 m
.24983 .54656 L
s
.64716 .53181 m
.64676 .53208 L
s
.25011 .54673 m
.24968 .5465 L
s
.26586 .62115 m
.26546 .62096 L
s
.84827 .39316 m
.84817 .39343 L
s
.64741 .53163 m
.64701 .5319 L
s
.24983 .54656 m
.2494 .54633 L
s
.64755 .53154 m
.64716 .53181 L
s
.84837 .39289 m
.84827 .39316 L
s
.24968 .5465 m
.24925 .54626 L
s
.26546 .62096 m
.26506 .62078 L
s
.6478 .53136 m
.64741 .53163 L
s
.2494 .54633 m
.24897 .54609 L
s
.64794 .53128 m
.64755 .53154 L
s
.84846 .39263 m
.84837 .39289 L
s
.24925 .54626 m
.24882 .54603 L
s
.64819 .53109 m
.6478 .53136 L
s
.26506 .62078 m
.26466 .62059 L
s
.84856 .39236 m
.84846 .39263 L
s
.24897 .54609 m
.24854 .54586 L
s
.64834 .53101 m
.64794 .53128 L
s
.24882 .54603 m
.24839 .54579 L
s
.84865 .39209 m
.84856 .39236 L
s
.64858 .53082 m
.64819 .53109 L
s
.24854 .54586 m
.24811 .54562 L
s
.26466 .62059 m
.26427 .62041 L
s
.64873 .53074 m
.64834 .53101 L
s
.24839 .54579 m
.24796 .54556 L
s
.84875 .39182 m
.84865 .39209 L
s
.64897 .53055 m
.64858 .53082 L
s
.24811 .54562 m
.24768 .54539 L
s
.64912 .53047 m
.64873 .53074 L
s
.26427 .62041 m
.26387 .62022 L
s
.24796 .54556 m
.24753 .54532 L
s
.84884 .39155 m
.84875 .39182 L
s
.64936 .53028 m
.64897 .53055 L
s
.24768 .54539 m
.24725 .54515 L
s
.64951 .5302 m
.64912 .53047 L
s
.84893 .39129 m
.84884 .39155 L
s
.24753 .54532 m
.24711 .54508 L
s
.26387 .62022 m
.26347 .62003 L
s
.64975 .53001 m
.64936 .53028 L
s
.84903 .39102 m
.84893 .39129 L
s
.24725 .54515 m
.24683 .54491 L
s
.64989 .52993 m
.64951 .5302 L
s
.24711 .54508 m
.24668 .54485 L
s
.26347 .62003 m
.26308 .61985 L
s
.84912 .39075 m
.84903 .39102 L
s
.65014 .52974 m
.64975 .53001 L
s
.24683 .54491 m
.2464 .54467 L
s
.65028 .52965 m
.64989 .52993 L
s
.24668 .54485 m
.24626 .54461 L
s
.84921 .39048 m
.84912 .39075 L
s
.26308 .61985 m
.26268 .61966 L
s
.65053 .52947 m
.65014 .52974 L
s
.2464 .54467 m
.24597 .54444 L
s
.65067 .52938 m
.65028 .52965 L
s
.24626 .54461 m
.24583 .54437 L
s
.8493 .39021 m
.84921 .39048 L
s
.65091 .52919 m
.65053 .52947 L
s
.24597 .54444 m
.24555 .5442 L
s
.26268 .61966 m
.26229 .61947 L
s
.65105 .52911 m
.65067 .52938 L
s
.84939 .38995 m
.8493 .39021 L
s
.24583 .54437 m
.24541 .54413 L
s
.6513 .52892 m
.65091 .52919 L
s
.24555 .5442 m
.24513 .54396 L
s
.84948 .38968 m
.84939 .38995 L
s
.65144 .52883 m
.65105 .52911 L
s
.26229 .61947 m
.26189 .61928 L
s
.24541 .54413 m
.24498 .54389 L
s
.84957 .38941 m
.84948 .38968 L
s
.65168 .52865 m
.6513 .52892 L
s
.24513 .54396 m
.24471 .54372 L
s
.65182 .52856 m
.65144 .52883 L
s
.24498 .54389 m
.24456 .54365 L
s
.26189 .61928 m
.2615 .61909 L
s
.84966 .38914 m
.84957 .38941 L
s
.65206 .52837 m
.65168 .52865 L
s
.24471 .54372 m
.24428 .54347 L
s
.6522 .52829 m
.65182 .52856 L
s
.24456 .54365 m
.24414 .54341 L
s
.84975 .38887 m
.84966 .38914 L
s
.2615 .61909 m
.2611 .6189 L
s
.65245 .5281 m
.65206 .52837 L
s
.24428 .54347 m
.24386 .54323 L
s
.65258 .52801 m
.6522 .52829 L
s
.84984 .38861 m
.84975 .38887 L
s
.24414 .54341 m
.24372 .54317 L
s
.2611 .6189 m
.26071 .6187 L
s
.65283 .52782 m
.65245 .5281 L
s
.24386 .54323 m
.24344 .54299 L
s
.84993 .38834 m
.84984 .38861 L
s
.65297 .52774 m
.65258 .52801 L
s
.24372 .54317 m
.2433 .54292 L
s
.85002 .38807 m
.84993 .38834 L
s
.65321 .52755 m
.65283 .52782 L
s
.26071 .6187 m
.26032 .61851 L
s
.24344 .54299 m
.24302 .54275 L
s
.65335 .52746 m
.65297 .52774 L
s
.2433 .54292 m
.24288 .54268 L
s
.85011 .3878 m
.85002 .38807 L
s
.65359 .52727 m
.65321 .52755 L
s
.24302 .54275 m
.24261 .5425 L
s
.26032 .61851 m
.25992 .61832 L
s
.65372 .52718 m
.65335 .52746 L
s
.24288 .54268 m
.24247 .54244 L
s
.85019 .38753 m
.85011 .3878 L
s
.65396 .52699 m
.65359 .52727 L
s
.24261 .5425 m
.24219 .54226 L
s
.85028 .38726 m
.85019 .38753 L
s
.45439 .53807 m
.45362 .53808 L
s
.45515 .53806 m
.45439 .53807 L
s
.45362 .53808 m
.45285 .53808 L
s
.6541 .52691 m
.65372 .52718 L
s
.45592 .53804 m
.45515 .53806 L
s
.24247 .54244 m
.24205 .54219 L
s
.45285 .53808 m
.45208 .53809 L
s
.45669 .53803 m
.45592 .53804 L
s
.45208 .53809 m
.45132 .53809 L
s
.45745 .53801 m
.45669 .53803 L
s
.45391 .53806 m
.45314 .53807 L
s
.45468 .53805 m
.45391 .53806 L
s
.45545 .53804 m
.45468 .53805 L
s
.45132 .53809 m
.45055 .53809 L
s
.45314 .53807 m
.45238 .53807 L
s
.45621 .53802 m
.45545 .53804 L
s
.45238 .53807 m
.45161 .53808 L
s
.45822 .53799 m
.45745 .53801 L
s
.45698 .53801 m
.45621 .53802 L
s
.25992 .61832 m
.25953 .61812 L
s
.45055 .53809 m
.44978 .53809 L
s
.45161 .53808 m
.45084 .53808 L
s
.45774 .53799 m
.45698 .53801 L
s
.45899 .53797 m
.45822 .53799 L
s
.45084 .53808 m
.45007 .53808 L
s
.44978 .53809 m
.44901 .53809 L
s
.45851 .53797 m
.45774 .53799 L
s
.45007 .53808 m
.4493 .53807 L
s
.45975 .53795 m
.45899 .53797 L
s
.44901 .53809 m
.44824 .53808 L
s
.45928 .53795 m
.45851 .53797 L
s
.45434 .53801 m
.45358 .53802 L
s
.45511 .538 m
.45434 .53801 L
s
.45358 .53802 m
.45281 .53803 L
s
.4493 .53807 m
.44854 .53807 L
s
.45588 .53799 m
.45511 .538 L
s
.45281 .53803 m
.45204 .53803 L
s
.46052 .53792 m
.45975 .53795 L
s
.45664 .53797 m
.45588 .53799 L
s
.45204 .53803 m
.45127 .53804 L
s
.46004 .53792 m
.45928 .53795 L
s
.44824 .53808 m
.44747 .53808 L
s
.45741 .53796 m
.45664 .53797 L
s
.45127 .53804 m
.4505 .53804 L
s
.44854 .53807 m
.44777 .53806 L
s
.45396 .53799 m
.45319 .538 L
s
.45473 .53798 m
.45396 .53799 L
s
.45549 .53797 m
.45473 .53798 L
s
.45818 .53794 m
.45741 .53796 L
s
.45319 .538 m
.45242 .53801 L
s
.45626 .53796 m
.45549 .53797 L
s
.46128 .5379 m
.46052 .53792 L
s
.4505 .53804 m
.44974 .53803 L
s
.46081 .5379 m
.46004 .53792 L
s
.45242 .53801 m
.45166 .53801 L
s
.44747 .53808 m
.44671 .53807 L
s
.45703 .53794 m
.45626 .53796 L
s
.45894 .53792 m
.45818 .53794 L
s
.45166 .53801 m
.45089 .53801 L
s
.44777 .53806 m
.447 .53806 L
s
.4578 .53793 m
.45703 .53794 L
s
.44974 .53803 m
.44897 .53803 L
s
.45089 .53801 m
.45012 .53801 L
s
.46204 .53787 m
.46128 .5379 L
s
.46157 .53787 m
.46081 .5379 L
s
.45856 .53791 m
.4578 .53793 L
s
.45971 .53789 m
.45894 .53792 L
s
.44671 .53807 m
.44594 .53806 L
s
.44897 .53803 m
.4482 .53803 L
s
.45012 .53801 m
.44935 .53801 L
s
.447 .53806 m
.44623 .53805 L
s
.45933 .53788 m
.45856 .53791 L
s
.46047 .53787 m
.45971 .53789 L
s
.46233 .53784 m
.46157 .53787 L
s
.44935 .53801 m
.44858 .538 L
s
.46281 .53784 m
.46204 .53787 L
s
.4482 .53803 m
.44743 .53802 L
s
.46009 .53786 m
.45933 .53788 L
s
.44594 .53806 m
.44517 .53804 L
s
.44623 .53805 m
.44546 .53803 L
s
.46124 .53784 m
.46047 .53787 L
s
.44858 .538 m
.44781 .538 L
s
.44743 .53802 m
.44666 .53801 L
s
.46086 .53784 m
.46009 .53786 L
s
.4631 .53781 m
.46233 .53784 L
s
.46357 .5378 m
.46281 .53784 L
s
.44517 .53804 m
.4444 .53803 L
s
.462 .53781 m
.46124 .53784 L
s
.44781 .538 m
.44704 .53799 L
s
.44546 .53803 m
.44469 .53802 L
s
.46162 .53781 m
.46086 .53784 L
s
.44666 .53801 m
.44589 .538 L
s
.46386 .53778 m
.4631 .53781 L
s
.46434 .53777 m
.46357 .5378 L
s
.44704 .53799 m
.44627 .53798 L
s
.46277 .53778 m
.462 .53781 L
s
.4444 .53803 m
.44363 .53801 L
s
.46239 .53778 m
.46162 .53781 L
s
.44469 .53802 m
.44392 .538 L
s
.44589 .538 m
.44512 .53798 L
s
.44627 .53798 m
.4455 .53797 L
s
.46462 .53774 m
.46386 .53778 L
s
.46353 .53775 m
.46277 .53778 L
s
.4651 .53773 m
.46434 .53777 L
s
.46315 .53775 m
.46239 .53778 L
s
.44363 .53801 m
.44286 .53799 L
s
.65434 .52672 m
.65396 .52699 L
s
.44392 .538 m
.44315 .53798 L
s
.44512 .53798 m
.44435 .53797 L
s
.24219 .54226 m
.24177 .54202 L
s
.4455 .53797 m
.44473 .53795 L
s
.46429 .53772 m
.46353 .53775 L
s
.46539 .5377 m
.46462 .53774 L
s
.46392 .53771 m
.46315 .53775 L
s
.46586 .53769 m
.4651 .53773 L
s
.85037 .387 m
.85028 .38726 L
s
.44435 .53797 m
.44358 .53795 L
s
.44286 .53799 m
.44209 .53797 L
s
.44315 .53798 m
.44238 .53796 L
s
.44473 .53795 m
.44396 .53793 L
s
.46506 .53768 m
.46429 .53772 L
s
.46468 .53768 m
.46392 .53771 L
s
.46615 .53766 m
.46539 .5377 L
s
.46662 .53765 m
.46586 .53769 L
s
.44358 .53795 m
.44281 .53793 L
s
.44238 .53796 m
.44161 .53794 L
s
.44209 .53797 m
.44132 .53795 L
s
.44396 .53793 m
.44319 .53792 L
s
.46582 .53764 m
.46506 .53768 L
s
.46544 .53764 m
.46468 .53768 L
s
.46691 .53762 m
.46615 .53766 L
s
.44281 .53793 m
.44204 .53791 L
s
.46738 .53761 m
.46662 .53765 L
s
.24205 .54219 m
.24163 .54195 L
s
.65448 .52663 m
.6541 .52691 L
s
.44319 .53792 m
.44242 .5379 L
s
.44161 .53794 m
.44084 .53792 L
s
.44132 .53795 m
.44055 .53792 L
s
.4662 .5376 m
.46544 .53764 L
s
.46658 .5376 m
.46582 .53764 L
s
.46767 .53758 m
.46691 .53762 L
s
.44204 .53791 m
.44127 .53789 L
s
.46814 .53756 m
.46738 .53761 L
s
.44242 .5379 m
.44166 .53787 L
s
.44084 .53792 m
.44007 .53789 L
s
.44055 .53792 m
.43978 .5379 L
s
.46697 .53756 m
.4662 .5376 L
s
.46734 .53756 m
.46658 .5376 L
s
.46843 .53753 m
.46767 .53758 L
s
.44127 .53789 m
.4405 .53786 L
s
.44166 .53787 m
.44089 .53785 L
s
.4689 .53752 m
.46814 .53756 L
s
.25953 .61812 m
.25914 .61793 L
s
.46773 .53752 m
.46697 .53756 L
s
.44007 .53789 m
.43931 .53786 L
s
.43978 .5379 m
.43901 .53787 L
s
.4681 .53751 m
.46734 .53756 L
s
.46919 .53748 m
.46843 .53753 L
s
.4405 .53786 m
.43973 .53784 L
s
.44089 .53785 m
.44012 .53782 L
s
.46966 .53747 m
.4689 .53752 L
s
.46849 .53747 m
.46773 .53752 L
s
.43931 .53786 m
.43854 .53783 L
s
.46887 .53747 m
.4681 .53751 L
s
.43901 .53787 m
.43824 .53784 L
s
.43973 .53784 m
.43896 .53781 L
s
.46995 .53743 m
.46919 .53748 L
s
.44012 .53782 m
.43935 .53779 L
s
.47042 .53742 m
.46966 .53747 L
s
.46925 .53742 m
.46849 .53747 L
s
.46963 .53742 m
.46887 .53747 L
s
.43854 .53783 m
.43777 .5378 L
s
.85045 .38673 m
.85037 .387 L
s
.43824 .53784 m
.43747 .5378 L
s
.43896 .53781 m
.43819 .53777 L
s
.47071 .53738 m
.46995 .53743 L
s
.43935 .53779 m
.43858 .53776 L
s
.47001 .53737 m
.46925 .53742 L
s
.47118 .53737 m
.47042 .53742 L
s
.65472 .52644 m
.65434 .52672 L
s
.47038 .53737 m
.46963 .53742 L
s
.24177 .54202 m
.24136 .54177 L
s
.43777 .5378 m
.437 .53776 L
s
.43747 .5378 m
.4367 .53777 L
s
.43819 .53777 m
.43743 .53774 L
s
.43858 .53776 m
.43781 .53773 L
s
.47147 .53733 m
.47071 .53738 L
s
.47077 .53732 m
.47001 .53737 L
s
.47194 .53731 m
.47118 .53737 L
s
.47114 .53732 m
.47038 .53737 L
s
.437 .53776 m
.43623 .53773 L
s
.4367 .53777 m
.43594 .53773 L
s
.43743 .53774 m
.43666 .53771 L
s
.43781 .53773 m
.43704 .53769 L
s
.47223 .53727 m
.47147 .53733 L
s
.47153 .53727 m
.47077 .53732 L
s
.24163 .54195 m
.24122 .5417 L
s
.65485 .52635 m
.65448 .52663 L
s
.4719 .53726 m
.47114 .53732 L
s
.4727 .53725 m
.47194 .53731 L
s
.43623 .53773 m
.43546 .53769 L
s
.43594 .53773 m
.43517 .53769 L
s
.43666 .53771 m
.43589 .53767 L
s
.43704 .53769 m
.43627 .53766 L
s
.47298 .53722 m
.47223 .53727 L
s
.47228 .53721 m
.47153 .53727 L
s
.47266 .5372 m
.4719 .53726 L
s
.47345 .5372 m
.4727 .53725 L
s
.43546 .53769 m
.43469 .53765 L
s
.43517 .53769 m
.4344 .53765 L
s
.43627 .53766 m
.4355 .53762 L
s
.43589 .53767 m
.43512 .53763 L
s
.47374 .53716 m
.47298 .53722 L
s
.47304 .53716 m
.47228 .53721 L
s
.47342 .53715 m
.47266 .5372 L
s
.85054 .38646 m
.85045 .38673 L
s
.47421 .53714 m
.47345 .5372 L
s
.43469 .53765 m
.43392 .53761 L
s
.25914 .61793 m
.25875 .61773 L
s
.4344 .53765 m
.43363 .53761 L
s
.4355 .53762 m
.43473 .53758 L
s
.43512 .53763 m
.43435 .53759 L
s
.4745 .5371 m
.47374 .53716 L
s
.4738 .5371 m
.47304 .53716 L
s
.47417 .53709 m
.47342 .53715 L
s
.47497 .53707 m
.47421 .53714 L
s
.43392 .53761 m
.43315 .53756 L
s
.43363 .53761 m
.43286 .53756 L
s
.43473 .53758 m
.43396 .53754 L
s
.43435 .53759 m
.43358 .53754 L
s
.47456 .53704 m
.4738 .5371 L
s
.47525 .53703 m
.4745 .5371 L
s
.24136 .54177 m
.24094 .54153 L
s
.65509 .52616 m
.65472 .52644 L
s
.47493 .53702 m
.47417 .53709 L
s
.47572 .53701 m
.47497 .53707 L
s
.43315 .53756 m
.43238 .53751 L
s
.43396 .53754 m
.43319 .53749 L
s
.43286 .53756 m
.43209 .53751 L
s
.43358 .53754 m
.43281 .5375 L
s
.47531 .53697 m
.47456 .53704 L
s
.47601 .53697 m
.47525 .53703 L
s
.47569 .53696 m
.47493 .53702 L
s
.47648 .53694 m
.47572 .53701 L
s
.24122 .5417 m
.2408 .54146 L
s
.43238 .53751 m
.43162 .53747 L
s
.65523 .52607 m
.65485 .52635 L
s
.43319 .53749 m
.43242 .53744 L
s
.43281 .5375 m
.43204 .53745 L
s
.43209 .53751 m
.43132 .53746 L
s
.47607 .53691 m
.47531 .53697 L
s
.47676 .5369 m
.47601 .53697 L
s
.47644 .53689 m
.47569 .53696 L
s
.85062 .38619 m
.85054 .38646 L
s
.47723 .53687 m
.47648 .53694 L
s
.43162 .53747 m
.43085 .53742 L
s
.43242 .53744 m
.43165 .53739 L
s
.43204 .53745 m
.43127 .5374 L
s
.43132 .53746 m
.43056 .53741 L
s
.47682 .53684 m
.47607 .53691 L
s
.47752 .53683 m
.47676 .5369 L
s
.47719 .53683 m
.47644 .53689 L
s
.47798 .5368 m
.47723 .53687 L
s
.43085 .53742 m
.43008 .53736 L
s
.43165 .53739 m
.43088 .53734 L
s
.43127 .5374 m
.4305 .53735 L
s
.43056 .53741 m
.42979 .53736 L
s
.47758 .53677 m
.47682 .53684 L
s
.47827 .53676 m
.47752 .53683 L
s
.47795 .53676 m
.47719 .53683 L
s
.25875 .61773 m
.25836 .61754 L
s
.47874 .53673 m
.47798 .5368 L
s
.43008 .53736 m
.42931 .53731 L
s
.43088 .53734 m
.43012 .53729 L
s
.4305 .53735 m
.42974 .53729 L
s
.24094 .54153 m
.24053 .54128 L
s
.47833 .5367 m
.47758 .53677 L
s
.42979 .53736 m
.42902 .5373 L
s
.65547 .52588 m
.65509 .52616 L
s
.47902 .53669 m
.47827 .53676 L
s
.4787 .53668 m
.47795 .53676 L
s
.47949 .53666 m
.47874 .53673 L
s
.43012 .53729 m
.42935 .53724 L
s
.42931 .53731 m
.42855 .53725 L
s
.42974 .53729 m
.42897 .53724 L
s
.47908 .53663 m
.47833 .5367 L
s
.42902 .5373 m
.42825 .53725 L
s
.85071 .38592 m
.85062 .38619 L
s
.2408 .54146 m
.24039 .54121 L
s
.47977 .53661 m
.47902 .53669 L
s
.47945 .53661 m
.4787 .53668 L
s
.6556 .52579 m
.65523 .52607 L
s
.48024 .53658 m
.47949 .53666 L
s
.42935 .53724 m
.42858 .53718 L
s
.42855 .53725 m
.42778 .53719 L
s
.42897 .53724 m
.4282 .53718 L
s
.47983 .53656 m
.47908 .53663 L
s
.42825 .53725 m
.42749 .53719 L
s
.48052 .53654 m
.47977 .53661 L
s
.4802 .53653 m
.47945 .53661 L
s
.48099 .5365 m
.48024 .53658 L
s
.42858 .53718 m
.42781 .53712 L
s
.42778 .53719 m
.42701 .53713 L
s
.4282 .53718 m
.42743 .53712 L
s
.48059 .53648 m
.47983 .53656 L
s
.42749 .53719 m
.42672 .53712 L
s
.48127 .53646 m
.48052 .53654 L
s
.48096 .53646 m
.4802 .53653 L
s
.48174 .53642 m
.48099 .5365 L
s
.42781 .53712 m
.42704 .53706 L
s
.42701 .53713 m
.42624 .53707 L
s
.48134 .5364 m
.48059 .53648 L
s
.42743 .53712 m
.42667 .53706 L
s
.24053 .54128 m
.24012 .54103 L
s
.42672 .53712 m
.42595 .53706 L
s
.65584 .5256 m
.65547 .52588 L
s
.48202 .53638 m
.48127 .53646 L
s
.85079 .38565 m
.85071 .38592 L
s
.48171 .53638 m
.48096 .53646 L
s
.25836 .61754 m
.25797 .61734 L
s
.48249 .53634 m
.48174 .53642 L
s
.42704 .53706 m
.42628 .537 L
s
.42624 .53707 m
.42548 .537 L
s
.48209 .53632 m
.48134 .5364 L
s
.42667 .53706 m
.4259 .537 L
s
.42595 .53706 m
.42518 .537 L
s
.24039 .54121 m
.23998 .54097 L
s
.48277 .53629 m
.48202 .53638 L
s
.48245 .53629 m
.48171 .53638 L
s
.65598 .52551 m
.6556 .52579 L
s
.48324 .53626 m
.48249 .53634 L
s
.42628 .537 m
.42551 .53693 L
s
.48283 .53624 m
.48209 .53632 L
s
.42548 .537 m
.42471 .53694 L
s
.4259 .537 m
.42513 .53693 L
s
.42518 .537 m
.42442 .53693 L
s
.48352 .53621 m
.48277 .53629 L
s
.4832 .53621 m
.48245 .53629 L
s
.48398 .53617 m
.48324 .53626 L
s
.42551 .53693 m
.42474 .53686 L
s
.48358 .53615 m
.48283 .53624 L
s
.42513 .53693 m
.42437 .53686 L
s
.42471 .53694 m
.42395 .53687 L
s
.42442 .53693 m
.42365 .53686 L
s
.85087 .38539 m
.85079 .38565 L
s
.48427 .53612 m
.48352 .53621 L
s
.48395 .53612 m
.4832 .53621 L
s
.48473 .53608 m
.48398 .53617 L
s
.24012 .54103 m
.2397 .54079 L
s
.42474 .53686 m
.42398 .53679 L
s
.48433 .53607 m
.48358 .53615 L
s
.65621 .52532 m
.65584 .5256 L
s
.42437 .53686 m
.4236 .53679 L
s
.42395 .53687 m
.42318 .5368 L
s
.42365 .53686 m
.42289 .53679 L
s
.4847 .53604 m
.48395 .53612 L
s
.48501 .53603 m
.48427 .53612 L
s
.25797 .61734 m
.25758 .61714 L
s
.48548 .53599 m
.48473 .53608 L
s
.23998 .54097 m
.23956 .54072 L
s
.42398 .53679 m
.42321 .53672 L
s
.48508 .53598 m
.48433 .53607 L
s
.4236 .53679 m
.42284 .53672 L
s
.42318 .5368 m
.42241 .53672 L
s
.65635 .52523 m
.65598 .52551 L
s
.42289 .53679 m
.42212 .53671 L
s
.48544 .53595 m
.4847 .53604 L
s
.48576 .53594 m
.48501 .53603 L
s
.48622 .5359 m
.48548 .53599 L
s
.42321 .53672 m
.42245 .53665 L
s
.48582 .53589 m
.48508 .53598 L
s
.85096 .38512 m
.85087 .38539 L
s
.42284 .53672 m
.42207 .53665 L
s
.42241 .53672 m
.42165 .53665 L
s
.48619 .53586 m
.48544 .53595 L
s
.42212 .53671 m
.42136 .53664 L
s
.4865 .53585 m
.48576 .53594 L
s
.48697 .53581 m
.48622 .5359 L
s
.42245 .53665 m
.42168 .53657 L
s
.48657 .5358 m
.48582 .53589 L
s
.42207 .53665 m
.4213 .53657 L
s
.42165 .53665 m
.42089 .53657 L
s
.2397 .54079 m
.23929 .54054 L
s
.48693 .53576 m
.48619 .53586 L
s
.42136 .53664 m
.42059 .53656 L
s
.48725 .53576 m
.4865 .53585 L
s
.65659 .52504 m
.65621 .52532 L
s
.48771 .53571 m
.48697 .53581 L
s
.42168 .53657 m
.42092 .5365 L
s
.48731 .5357 m
.48657 .5358 L
s
.4213 .53657 m
.42054 .53649 L
s
.23956 .54072 m
.23915 .54047 L
s
.42089 .53657 m
.42012 .53649 L
s
.48768 .53567 m
.48693 .53576 L
s
.48799 .53566 m
.48725 .53576 L
s
.42059 .53656 m
.41983 .53648 L
s
.65672 .52495 m
.65635 .52523 L
s
.85104 .38485 m
.85096 .38512 L
s
.25758 .61714 m
.25719 .61694 L
s
.48845 .53562 m
.48771 .53571 L
s
.48806 .53561 m
.48731 .5357 L
s
.42092 .5365 m
.42015 .53642 L
s
.42054 .53649 m
.41978 .53641 L
s
.42012 .53649 m
.41936 .53641 L
s
.48842 .53557 m
.48768 .53567 L
s
.48873 .53556 m
.48799 .53566 L
s
.41983 .53648 m
.41907 .5364 L
s
.48919 .53552 m
.48845 .53562 L
s
.4888 .53551 m
.48806 .53561 L
s
.42015 .53642 m
.41939 .53634 L
s
.41978 .53641 m
.41901 .53633 L
s
.41936 .53641 m
.41859 .53633 L
s
.48916 .53547 m
.48842 .53557 L
s
.23929 .54054 m
.23888 .54029 L
s
.48947 .53546 m
.48873 .53556 L
s
.41907 .5364 m
.4183 .53631 L
s
.65696 .52476 m
.65659 .52504 L
s
.48993 .53542 m
.48919 .53552 L
s
.48954 .53541 m
.4888 .53551 L
s
.41939 .53634 m
.41862 .53625 L
s
.85112 .38458 m
.85104 .38485 L
s
.41901 .53633 m
.41825 .53625 L
s
.41859 .53633 m
.41783 .53624 L
s
.23915 .54047 m
.23874 .54022 L
s
.4899 .53537 m
.48916 .53547 L
s
.49021 .53536 m
.48947 .53546 L
s
.4183 .53631 m
.41754 .53623 L
s
.65709 .52467 m
.65672 .52495 L
s
.49067 .53531 m
.48993 .53542 L
s
.49028 .53531 m
.48954 .53541 L
s
.41862 .53625 m
.41786 .53617 L
s
.41825 .53625 m
.41749 .53616 L
s
.41783 .53624 m
.41707 .53616 L
s
.25719 .61694 m
.25681 .61674 L
s
.49064 .53527 m
.4899 .53537 L
s
.49095 .53526 m
.49021 .53536 L
s
.41754 .53623 m
.41678 .53614 L
s
.49141 .53521 m
.49067 .53531 L
s
.49102 .5352 m
.49028 .53531 L
s
.41786 .53617 m
.4171 .53608 L
s
.41749 .53616 m
.41672 .53607 L
s
.41707 .53616 m
.41631 .53607 L
s
.23888 .54029 m
.23847 .54004 L
s
.49138 .53516 m
.49064 .53527 L
s
.8512 .38431 m
.85112 .38458 L
s
.49169 .53515 m
.49095 .53526 L
s
.41678 .53614 m
.41601 .53605 L
s
.65733 .52448 m
.65696 .52476 L
s
.49176 .5351 m
.49102 .5352 L
s
.49215 .5351 m
.49141 .53521 L
s
.4171 .53608 m
.41634 .53599 L
s
.23874 .54022 m
.23833 .53997 L
s
.41672 .53607 m
.41596 .53598 L
s
.41631 .53607 m
.41554 .53598 L
s
.49212 .53506 m
.49138 .53516 L
s
.49243 .53504 m
.49169 .53515 L
s
.65746 .52439 m
.65709 .52467 L
s
.41601 .53605 m
.41525 .53596 L
s
.4925 .53499 m
.49176 .5351 L
s
.49289 .53499 m
.49215 .5351 L
s
.41634 .53599 m
.41557 .5359 L
s
.41596 .53598 m
.4152 .53589 L
s
.41554 .53598 m
.41478 .53588 L
s
.49286 .53495 m
.49212 .53506 L
s
.49317 .53493 m
.49243 .53504 L
s
.41525 .53596 m
.41449 .53586 L
s
.25681 .61674 m
.25642 .61654 L
s
.85129 .38405 m
.8512 .38431 L
s
.49324 .53488 m
.4925 .53499 L
s
.49362 .53488 m
.49289 .53499 L
s
.41557 .5359 m
.41481 .53581 L
s
.23847 .54004 m
.23806 .53979 L
s
.4152 .53589 m
.41444 .53579 L
s
.4936 .53484 m
.49286 .53495 L
s
.41478 .53588 m
.41402 .53579 L
s
.65769 .5242 m
.65733 .52448 L
s
.4939 .53482 m
.49317 .53493 L
s
.41449 .53586 m
.41373 .53577 L
s
.49397 .53477 m
.49324 .53488 L
s
.23833 .53997 m
.23793 .53972 L
s
.49436 .53477 m
.49362 .53488 L
s
.41481 .53581 m
.41405 .53571 L
s
.41444 .53579 m
.41368 .5357 L
s
.65783 .52411 m
.65746 .52439 L
s
.49433 .53473 m
.4936 .53484 L
s
.41402 .53579 m
.41326 .53569 L
s
.49464 .53471 m
.4939 .53482 L
s
.41373 .53577 m
.41297 .53567 L
s
.85137 .38378 m
.85129 .38405 L
s
.49471 .53466 m
.49397 .53477 L
s
.49509 .53466 m
.49436 .53477 L
s
.41405 .53571 m
.41329 .53561 L
s
.41368 .5357 m
.41292 .5356 L
s
.49507 .53461 m
.49433 .53473 L
s
.41326 .53569 m
.4125 .53559 L
s
.49537 .53459 m
.49464 .53471 L
s
.41297 .53567 m
.41221 .53557 L
s
.25642 .61654 m
.25603 .61634 L
s
.23806 .53979 m
.23766 .53954 L
s
.49544 .53454 m
.49471 .53466 L
s
.49583 .53454 m
.49509 .53466 L
s
.41329 .53561 m
.41253 .53551 L
s
.65806 .52391 m
.65769 .5242 L
s
.41292 .5356 m
.41216 .5355 L
s
.4958 .53449 m
.49507 .53461 L
s
.4125 .53559 m
.41174 .53549 L
s
.49611 .53448 m
.49537 .53459 L
s
.23793 .53972 m
.23752 .53947 L
s
.41221 .53557 m
.41145 .53547 L
s
.85145 .38351 m
.85137 .38378 L
s
.49618 .53442 m
.49544 .53454 L
s
.65819 .52383 m
.65783 .52411 L
s
.49656 .53442 m
.49583 .53454 L
s
.41253 .53551 m
.41177 .53541 L
s
.41216 .5355 m
.4114 .5354 L
s
.49653 .53438 m
.4958 .53449 L
s
.41174 .53549 m
.41099 .53539 L
s
.49684 .53436 m
.49611 .53448 L
s
.41145 .53547 m
.4107 .53536 L
s
.49691 .53431 m
.49618 .53442 L
s
.49729 .5343 m
.49656 .53442 L
s
.41177 .53541 m
.41101 .53531 L
s
.4114 .5354 m
.41064 .53529 L
s
.49727 .53426 m
.49653 .53438 L
s
.23766 .53954 m
.23725 .53929 L
s
.41099 .53539 m
.41023 .53528 L
s
.49757 .53424 m
.49684 .53436 L
s
.65843 .52363 m
.65806 .52391 L
s
.4107 .53536 m
.40994 .53526 L
s
.25603 .61634 m
.25565 .61614 L
s
.85153 .38324 m
.85145 .38351 L
s
.49764 .53418 m
.49691 .53431 L
s
.49802 .53418 m
.49729 .5343 L
s
.23752 .53947 m
.23711 .53922 L
s
.41101 .53531 m
.41025 .5352 L
s
.498 .53413 m
.49727 .53426 L
s
.41064 .53529 m
.40988 .53519 L
s
.65856 .52354 m
.65819 .52383 L
s
.4983 .53411 m
.49757 .53424 L
s
.41023 .53528 m
.40947 .53517 L
s
.40994 .53526 m
.40918 .53515 L
s
.49837 .53406 m
.49764 .53418 L
s
.49875 .53405 m
.49802 .53418 L
s
.41025 .5352 m
.4095 .5351 L
s
.49873 .53401 m
.498 .53413 L
s
.40988 .53519 m
.40913 .53508 L
s
.49903 .53399 m
.4983 .53411 L
s
.40947 .53517 m
.40871 .53507 L
s
.85161 .38297 m
.85153 .38324 L
s
.23725 .53929 m
.23684 .53904 L
s
.40918 .53515 m
.40842 .53504 L
s
.4991 .53394 m
.49837 .53406 L
s
.49948 .53393 m
.49875 .53405 L
s
.65879 .52335 m
.65843 .52363 L
s
.4095 .5351 m
.40874 .53499 L
s
.49945 .53389 m
.49873 .53401 L
s
.40913 .53508 m
.40837 .53497 L
s
.23711 .53922 m
.23671 .53897 L
s
.49976 .53386 m
.49903 .53399 L
s
.40871 .53507 m
.40796 .53495 L
s
.25565 .61614 m
.25526 .61594 L
s
.40842 .53504 m
.40767 .53493 L
s
.65893 .52326 m
.65856 .52354 L
s
.49983 .53381 m
.4991 .53394 L
s
.50021 .5338 m
.49948 .53393 L
s
.40874 .53499 m
.40798 .53487 L
s
.50018 .53376 m
.49945 .53389 L
s
.40837 .53497 m
.40761 .53486 L
s
.50048 .53373 m
.49976 .53386 L
s
.40796 .53495 m
.4072 .53484 L
s
.85169 .3827 m
.85161 .38297 L
s
.40767 .53493 m
.40691 .53481 L
s
.50056 .53368 m
.49983 .53381 L
s
.50093 .53367 m
.50021 .5338 L
s
.23684 .53904 m
.23644 .53879 L
s
.40798 .53487 m
.40723 .53476 L
s
.50091 .53363 m
.50018 .53376 L
s
.40761 .53486 m
.40686 .53474 L
s
.65916 .52306 m
.65879 .52335 L
s
.50121 .5336 m
.50048 .53373 L
s
.4072 .53484 m
.40645 .53473 L
s
.23671 .53897 m
.2363 .53872 L
s
.50128 .53355 m
.50056 .53368 L
s
.40691 .53481 m
.40616 .5347 L
s
.50166 .53354 m
.50093 .53367 L
s
.65929 .52298 m
.65893 .52326 L
s
.40723 .53476 m
.40647 .53464 L
s
.25526 .61594 m
.25487 .61574 L
s
.50163 .5335 m
.50091 .53363 L
s
.85177 .38244 m
.85169 .3827 L
s
.40686 .53474 m
.4061 .53463 L
s
.50194 .53347 m
.50121 .5336 L
s
.40645 .53473 m
.40569 .53461 L
s
.50201 .53342 m
.50128 .53355 L
s
.40616 .5347 m
.40541 .53458 L
s
.50238 .53341 m
.50166 .53354 L
s
.40647 .53464 m
.40572 .53453 L
s
.50236 .53336 m
.50163 .5335 L
s
.23644 .53879 m
.23603 .53853 L
s
.4061 .53463 m
.40535 .53451 L
s
.50266 .53334 m
.50194 .53347 L
s
.40569 .53461 m
.40494 .53449 L
s
.65952 .52278 m
.65916 .52306 L
s
.50273 .53329 m
.50201 .53342 L
s
.40541 .53458 m
.40465 .53446 L
s
.50311 .53327 m
.50238 .53341 L
s
.2363 .53872 m
.2359 .53847 L
s
.85184 .38217 m
.85177 .38244 L
s
.40572 .53453 m
.40496 .53441 L
s
.50308 .53323 m
.50236 .53336 L
s
.65965 .52269 m
.65929 .52298 L
s
.40535 .53451 m
.4046 .53439 L
s
.50338 .5332 m
.50266 .53334 L
s
.40494 .53449 m
.40419 .53437 L
s
.50345 .53315 m
.50273 .53329 L
s
.25487 .61574 m
.25449 .61553 L
s
.40465 .53446 m
.4039 .53434 L
s
.50383 .53314 m
.50311 .53327 L
s
.40496 .53441 m
.40421 .53429 L
s
.5038 .53309 m
.50308 .53323 L
s
.4046 .53439 m
.40384 .53426 L
s
.5041 .53306 m
.50338 .5332 L
s
.23603 .53853 m
.23563 .53828 L
s
.40419 .53437 m
.40344 .53424 L
s
.50418 .53301 m
.50345 .53315 L
s
.85192 .3819 m
.85184 .38217 L
s
.65988 .52249 m
.65952 .52278 L
s
.4039 .53434 m
.40315 .53421 L
s
.50455 .533 m
.50383 .53314 L
s
.2359 .53847 m
.23549 .53821 L
s
.40421 .53429 m
.40346 .53416 L
s
.50453 .53295 m
.5038 .53309 L
s
.50482 .53293 m
.5041 .53306 L
s
.40384 .53426 m
.40309 .53414 L
s
.66002 .52241 m
.65965 .52269 L
s
.40344 .53424 m
.40269 .53412 L
s
.5049 .53288 m
.50418 .53301 L
s
.40315 .53421 m
.4024 .53409 L
s
.50527 .53286 m
.50455 .533 L
s
.40346 .53416 m
.40271 .53404 L
s
.50525 .53281 m
.50453 .53295 L
s
.25449 .61553 m
.25411 .61533 L
s
.50554 .53278 m
.50482 .53293 L
s
.40309 .53414 m
.40234 .53401 L
s
.852 .38163 m
.85192 .3819 L
s
.23563 .53828 m
.23523 .53803 L
s
.40269 .53412 m
.40193 .53399 L
s
.50562 .53273 m
.5049 .53288 L
s
.50599 .53271 m
.50527 .53286 L
s
.4024 .53409 m
.40165 .53396 L
s
.66025 .52221 m
.65988 .52249 L
s
.50596 .53267 m
.50525 .53281 L
s
.23549 .53821 m
.23509 .53796 L
s
.40271 .53404 m
.40196 .53391 L
s
.50626 .53264 m
.50554 .53278 L
s
.40234 .53401 m
.40159 .53388 L
s
.66038 .52212 m
.66002 .52241 L
s
.40193 .53399 m
.40118 .53386 L
s
.50633 .53259 m
.50562 .53273 L
s
.50671 .53257 m
.50599 .53271 L
s
.40165 .53396 m
.4009 .53383 L
s
.85208 .38136 m
.852 .38163 L
s
.50668 .53253 m
.50596 .53267 L
s
.40196 .53391 m
.40121 .53378 L
s
.50698 .5325 m
.50626 .53264 L
s
.40159 .53388 m
.40084 .53375 L
s
.23523 .53803 m
.23483 .53777 L
s
.40118 .53386 m
.40044 .53373 L
s
.50705 .53245 m
.50633 .53259 L
s
.25411 .61533 m
.25372 .61512 L
s
.50742 .53242 m
.50671 .53257 L
s
.4009 .53383 m
.40015 .5337 L
s
.66061 .52192 m
.66025 .52221 L
s
.5074 .53238 m
.50668 .53253 L
s
.40121 .53378 m
.40046 .53365 L
s
.23509 .53796 m
.23469 .53771 L
s
.50769 .53235 m
.50698 .5325 L
s
.40084 .53375 m
.40009 .53362 L
s
.85215 .38109 m
.85208 .38136 L
s
.50777 .5323 m
.50705 .53245 L
s
.40044 .53373 m
.39969 .5336 L
s
.66074 .52183 m
.66038 .52212 L
s
.50814 .53228 m
.50742 .53242 L
s
.40015 .5337 m
.3994 .53356 L
s
.50811 .53223 m
.5074 .53238 L
s
.40046 .53365 m
.39971 .53351 L
s
.50841 .5322 m
.50769 .53235 L
s
.40009 .53362 m
.39934 .53349 L
s
.23483 .53777 m
.23443 .53752 L
s
.50848 .53215 m
.50777 .5323 L
s
.39969 .5336 m
.39894 .53346 L
s
.50885 .53213 m
.50814 .53228 L
s
.3994 .53356 m
.39865 .53343 L
s
.25372 .61512 m
.25334 .61492 L
s
.66097 .52163 m
.66061 .52192 L
s
.50883 .53208 m
.50811 .53223 L
s
.23469 .53771 m
.23429 .53745 L
s
.85223 .38083 m
.85215 .38109 L
s
.39971 .53351 m
.39896 .53338 L
s
.50912 .53205 m
.50841 .5322 L
s
.39934 .53349 m
.3986 .53335 L
s
.5092 .532 m
.50848 .53215 L
s
.6611 .52155 m
.66074 .52183 L
s
.39894 .53346 m
.39819 .53332 L
s
.50956 .53197 m
.50885 .53213 L
s
.39865 .53343 m
.39791 .53329 L
s
.50954 .53193 m
.50883 .53208 L
s
.39896 .53338 m
.39821 .53324 L
s
.50983 .5319 m
.50912 .53205 L
s
.3986 .53335 m
.39785 .53321 L
s
.23443 .53752 m
.23403 .53727 L
s
.50991 .53185 m
.5092 .532 L
s
.39819 .53332 m
.39745 .53318 L
s
.8523 .38056 m
.85223 .38083 L
s
.51027 .53182 m
.50956 .53197 L
s
.39791 .53329 m
.39716 .53315 L
s
.66133 .52135 m
.66097 .52163 L
s
.51025 .53178 m
.50954 .53193 L
s
.23429 .53745 m
.23389 .5372 L
s
.39821 .53324 m
.39747 .5331 L
s
.25334 .61492 m
.25296 .61471 L
s
.51055 .53174 m
.50983 .5319 L
s
.39785 .53321 m
.39711 .53307 L
s
.51062 .53169 m
.50991 .53185 L
s
.66145 .52126 m
.6611 .52155 L
s
.39745 .53318 m
.3967 .53304 L
s
.51098 .53167 m
.51027 .53182 L
s
.39716 .53315 m
.39642 .53301 L
s
.51096 .53162 m
.51025 .53178 L
s
.85238 .38029 m
.8523 .38056 L
s
.39747 .5331 m
.39672 .53296 L
s
.51125 .53159 m
.51055 .53174 L
s
.23403 .53727 m
.23363 .53701 L
s
.39711 .53307 m
.39636 .53293 L
s
.51133 .53154 m
.51062 .53169 L
s
.3967 .53304 m
.39596 .5329 L
s
.51169 .53151 m
.51098 .53167 L
s
.66168 .52106 m
.66133 .52135 L
s
.23389 .5372 m
.23349 .53694 L
s
.39642 .53301 m
.39567 .53286 L
s
.51167 .53147 m
.51096 .53162 L
s
.39672 .53296 m
.39598 .53281 L
s
.51196 .53143 m
.51125 .53159 L
s
.25296 .61471 m
.25258 .6145 L
s
.39636 .53293 m
.39562 .53278 L
s
.66181 .52097 m
.66145 .52126 L
s
.51204 .53138 m
.51133 .53154 L
s
.85245 .38002 m
.85238 .38029 L
s
.39596 .5329 m
.39522 .53275 L
s
.5124 .53135 m
.51169 .53151 L
s
.51238 .53131 m
.51167 .53147 L
s
.39567 .53286 m
.39493 .53272 L
s
.39598 .53281 m
.39523 .53267 L
s
.51267 .53127 m
.51196 .53143 L
s
.23363 .53701 m
.23323 .53675 L
s
.39562 .53278 m
.39487 .53264 L
s
.51275 .53122 m
.51204 .53138 L
s
.39522 .53275 m
.39447 .53261 L
s
.51311 .53119 m
.5124 .53135 L
s
.66204 .52077 m
.66168 .52106 L
s
.23349 .53694 m
.23309 .53668 L
s
.51309 .53115 m
.51238 .53131 L
s
.39493 .53272 m
.39419 .53257 L
s
.85253 .37975 m
.85245 .38002 L
s
.51338 .53111 m
.51267 .53127 L
s
.39523 .53267 m
.39449 .53252 L
s
.66217 .52068 m
.66181 .52097 L
s
.51345 .53106 m
.51275 .53122 L
s
.39487 .53264 m
.39413 .53249 L
s
.25258 .6145 m
.25219 .61429 L
s
.51381 .53103 m
.51311 .53119 L
s
.39447 .53261 m
.39373 .53246 L
s
.51379 .53099 m
.51309 .53115 L
s
.39419 .53257 m
.39345 .53242 L
s
.23323 .53675 m
.23283 .5365 L
s
.51408 .53094 m
.51338 .53111 L
s
.39449 .53252 m
.39375 .53237 L
s
.51416 .5309 m
.51345 .53106 L
s
.8526 .37949 m
.85253 .37975 L
s
.39413 .53249 m
.39339 .53234 L
s
.6624 .52048 m
.66204 .52077 L
s
.23309 .53668 m
.2327 .53643 L
s
.51452 .53086 m
.51381 .53103 L
s
.39373 .53246 m
.39299 .53231 L
s
.5145 .53082 m
.51379 .53099 L
s
.39345 .53242 m
.39271 .53227 L
s
.66252 .5204 m
.66217 .52068 L
s
.51478 .53078 m
.51408 .53094 L
s
.39375 .53237 m
.39301 .53222 L
s
.51486 .53073 m
.51416 .5309 L
s
.39339 .53234 m
.39265 .53219 L
s
.25219 .61429 m
.25181 .61408 L
s
.51522 .5307 m
.51452 .53086 L
s
.39299 .53231 m
.39225 .53215 L
s
.85268 .37922 m
.8526 .37949 L
s
.23283 .5365 m
.23244 .53624 L
s
.5152 .53066 m
.5145 .53082 L
s
.39271 .53227 m
.39197 .53211 L
s
.51549 .53061 m
.51478 .53078 L
s
.39301 .53222 m
.39227 .53207 L
s
.2327 .53643 m
.2323 .53617 L
s
.66275 .52019 m
.6624 .52048 L
s
.51556 .53057 m
.51486 .53073 L
s
.39265 .53219 m
.39191 .53203 L
s
.51592 .53053 m
.51522 .5307 L
s
.39225 .53215 m
.39151 .532 L
s
.5159 .53049 m
.5152 .53066 L
s
.66288 .52011 m
.66252 .5204 L
s
.39197 .53211 m
.39123 .53196 L
s
.51619 .53044 m
.51549 .53061 L
s
.85275 .37895 m
.85268 .37922 L
s
.39227 .53207 m
.39153 .53191 L
s
.51626 .5304 m
.51556 .53057 L
s
.39191 .53203 m
.39117 .53188 L
s
.23244 .53624 m
.23204 .53598 L
s
.51662 .53036 m
.51592 .53053 L
s
.25181 .61408 m
.25143 .61388 L
s
.39151 .532 m
.39078 .53184 L
s
.5166 .53032 m
.5159 .53049 L
s
.39123 .53196 m
.39049 .5318 L
s
.2323 .53617 m
.23191 .53591 L
s
.51689 .53027 m
.51619 .53044 L
s
.6631 .51991 m
.66275 .52019 L
s
.39153 .53191 m
.39079 .53175 L
s
.51696 .53023 m
.51626 .5304 L
s
.39117 .53188 m
.39044 .53172 L
s
.85282 .37868 m
.85275 .37895 L
s
.51732 .53019 m
.51662 .53036 L
s
.66323 .51982 m
.66288 .52011 L
s
.39078 .53184 m
.39004 .53168 L
s
.5173 .53015 m
.5166 .53032 L
s
.39049 .5318 m
.38975 .53164 L
s
.51759 .5301 m
.51689 .53027 L
s
.39079 .53175 m
.39006 .53159 L
s
.23204 .53598 m
.23165 .53572 L
s
.51766 .53006 m
.51696 .53023 L
s
.39044 .53172 m
.3897 .53156 L
s
.51802 .53001 m
.51732 .53019 L
s
.25143 .61388 m
.25105 .61366 L
s
.39004 .53168 m
.3893 .53152 L
s
.23191 .53591 m
.23151 .53565 L
s
.518 .52997 m
.5173 .53015 L
s
.66346 .51962 m
.6631 .51991 L
s
.85289 .37841 m
.85282 .37868 L
s
.38975 .53164 m
.38902 .53148 L
s
.51828 .52993 m
.51759 .5301 L
s
.39006 .53159 m
.38932 .53143 L
s
.51836 .52988 m
.51766 .53006 L
s
.66358 .51953 m
.66323 .51982 L
s
.3897 .53156 m
.38896 .5314 L
s
.51871 .52984 m
.51802 .53001 L
s
.3893 .53152 m
.38857 .53136 L
s
.51869 .5298 m
.518 .52997 L
s
.23165 .53572 m
.23125 .53546 L
s
.51898 .52975 m
.51828 .52993 L
s
.38902 .53148 m
.38829 .53131 L
s
.85296 .37814 m
.85289 .37841 L
s
.38932 .53143 m
.38858 .53127 L
s
.51905 .52971 m
.51836 .52988 L
s
.23151 .53565 m
.23112 .5354 L
s
.38896 .5314 m
.38823 .53123 L
s
.66381 .51932 m
.66346 .51962 L
s
.51941 .52966 m
.51871 .52984 L
s
.25105 .61366 m
.25068 .61345 L
s
.51939 .52962 m
.51869 .5298 L
s
.38857 .53136 m
.38784 .53119 L
s
.51967 .52957 m
.51898 .52975 L
s
.66393 .51924 m
.66358 .51953 L
s
.38829 .53131 m
.38755 .53115 L
s
.51975 .52953 m
.51905 .52971 L
s
.38858 .53127 m
.38785 .5311 L
s
.85304 .37788 m
.85296 .37814 L
s
.38823 .53123 m
.3875 .53106 L
s
.5201 .52948 m
.51941 .52966 L
s
.23125 .53546 m
.23086 .53521 L
s
.52008 .52944 m
.51939 .52962 L
s
.38784 .53119 m
.3871 .53102 L
s
.52036 .52939 m
.51967 .52957 L
s
.23112 .5354 m
.23073 .53514 L
s
.38755 .53115 m
.38682 .53098 L
s
.66416 .51903 m
.66381 .51932 L
s
.52044 .52935 m
.51975 .52953 L
s
.38785 .5311 m
.38712 .53093 L
s
.52079 .5293 m
.5201 .52948 L
s
.25068 .61345 m
.2503 .61324 L
s
.3875 .53106 m
.38676 .5309 L
s
.66429 .51894 m
.66393 .51924 L
s
.85311 .37761 m
.85304 .37788 L
s
.52077 .52926 m
.52008 .52944 L
s
.3871 .53102 m
.38637 .53085 L
s
.52105 .52921 m
.52036 .52939 L
s
.38682 .53098 m
.38609 .53081 L
s
.52113 .52917 m
.52044 .52935 L
s
.23086 .53521 m
.23047 .53495 L
s
.38712 .53093 m
.38639 .53076 L
s
.52148 .52912 m
.52079 .5293 L
s
.38676 .5309 m
.38603 .53073 L
s
.52146 .52908 m
.52077 .52926 L
s
.23073 .53514 m
.23033 .53488 L
s
.38637 .53085 m
.38564 .53068 L
s
.66451 .51874 m
.66416 .51903 L
s
.85318 .37734 m
.85311 .37761 L
s
.52174 .52903 m
.52105 .52921 L
s
.38609 .53081 m
.38536 .53064 L
s
.52182 .52899 m
.52113 .52917 L
s
.38639 .53076 m
.38565 .53059 L
s
.66463 .51865 m
.66429 .51894 L
s
.2503 .61324 m
.24992 .61303 L
s
.52217 .52894 m
.52148 .52912 L
s
.38603 .53073 m
.3853 .53055 L
s
.52215 .5289 m
.52146 .52908 L
s
.38564 .53068 m
.38491 .53051 L
s
.23047 .53495 m
.23008 .53468 L
s
.52243 .52885 m
.52174 .52903 L
s
.38536 .53064 m
.38463 .53046 L
s
.52251 .5288 m
.52182 .52899 L
s
.85325 .37707 m
.85318 .37734 L
s
.38565 .53059 m
.38492 .53042 L
s
.23033 .53488 m
.22994 .53462 L
s
.66486 .51845 m
.66451 .51874 L
s
.52286 .52875 m
.52217 .52894 L
s
.3853 .53055 m
.38457 .53038 L
s
.52284 .52871 m
.52215 .5289 L
s
.38491 .53051 m
.38418 .53034 L
s
.52312 .52866 m
.52243 .52885 L
s
.66498 .51836 m
.66463 .51865 L
s
.5232 .52861 m
.52251 .5288 L
s
.38463 .53046 m
.3839 .53029 L
s
.24992 .61303 m
.24954 .61282 L
s
.38492 .53042 m
.3842 .53024 L
s
.85332 .3768 m
.85325 .37707 L
s
.23008 .53468 m
.22969 .53442 L
s
.52354 .52856 m
.52286 .52875 L
s
.38457 .53038 m
.38385 .5302 L
s
.52353 .52853 m
.52284 .52871 L
s
.38418 .53034 m
.38346 .53016 L
s
.22994 .53462 m
.22955 .53435 L
s
.52381 .52847 m
.52312 .52866 L
s
.6652 .51816 m
.66486 .51845 L
s
.52388 .52843 m
.5232 .52861 L
s
.3839 .53029 m
.38317 .53011 L
s
.3842 .53024 m
.38347 .53007 L
s
.52423 .52837 m
.52354 .52856 L
s
.66533 .51807 m
.66498 .51836 L
s
.38385 .5302 m
.38312 .53002 L
s
.52421 .52834 m
.52353 .52853 L
s
.85339 .37654 m
.85332 .3768 L
s
.38346 .53016 m
.38273 .52998 L
s
.52449 .52828 m
.52381 .52847 L
s
.22969 .53442 m
.2293 .53416 L
s
.24954 .61282 m
.24917 .6126 L
s
.52457 .52824 m
.52388 .52843 L
s
.38317 .53011 m
.38245 .52993 L
s
.38347 .53007 m
.38274 .52989 L
s
.52491 .52818 m
.52423 .52837 L
s
.22955 .53435 m
.22917 .53409 L
s
.52489 .52815 m
.52421 .52834 L
s
.38312 .53002 m
.38239 .52984 L
s
.66555 .51787 m
.6652 .51816 L
s
.85345 .37627 m
.85339 .37654 L
s
.52517 .52809 m
.52449 .52828 L
s
.38273 .52998 m
.382 .5298 L
s
.52525 .52805 m
.52457 .52824 L
s
.66568 .51778 m
.66533 .51807 L
s
.38245 .52993 m
.38172 .52975 L
s
.38274 .52989 m
.38202 .52971 L
s
.52559 .52799 m
.52491 .52818 L
s
.2293 .53416 m
.22891 .5339 L
s
.52558 .52795 m
.52489 .52815 L
s
.38239 .52984 m
.38167 .52966 L
s
.24917 .6126 m
.24879 .61239 L
s
.52585 .5279 m
.52517 .52809 L
s
.382 .5298 m
.38128 .52962 L
s
.22917 .53409 m
.22878 .53383 L
s
.85352 .376 m
.85345 .37627 L
s
.52593 .52785 m
.52525 .52805 L
s
.6659 .51757 m
.66555 .51787 L
s
.38172 .52975 m
.381 .52957 L
s
.38202 .52971 m
.38129 .52952 L
s
.52627 .5278 m
.52559 .52799 L
s
.52626 .52776 m
.52558 .52795 L
s
.38167 .52966 m
.38095 .52948 L
s
.66602 .51748 m
.66568 .51778 L
s
.52653 .5277 m
.52585 .5279 L
s
.38128 .52962 m
.38056 .52943 L
s
.52661 .52766 m
.52593 .52785 L
s
.22891 .5339 m
.22852 .53364 L
s
.85359 .37573 m
.85352 .376 L
s
.381 .52957 m
.38028 .52938 L
s
.52695 .5276 m
.52627 .5278 L
s
.38129 .52952 m
.38057 .52934 L
s
.22878 .53383 m
.22839 .53357 L
s
.52694 .52756 m
.52626 .52776 L
s
.24879 .61239 m
.24841 .61217 L
s
.38095 .52948 m
.38022 .52929 L
s
.66624 .51728 m
.6659 .51757 L
s
.52721 .5275 m
.52653 .5277 L
s
.38056 .52943 m
.37984 .52924 L
s
.52729 .52746 m
.52661 .52766 L
s
.66637 .51719 m
.66602 .51748 L
s
.38028 .52938 m
.37956 .52919 L
s
.52763 .5274 m
.52695 .5276 L
s
.85366 .37546 m
.85359 .37573 L
s
.38057 .52934 m
.37985 .52915 L
s
.52761 .52737 m
.52694 .52756 L
s
.22852 .53364 m
.22814 .53337 L
s
.38022 .52929 m
.3795 .5291 L
s
.52789 .52731 m
.52721 .5275 L
s
.37984 .52924 m
.37912 .52905 L
s
.22839 .53357 m
.22801 .5333 L
s
.52797 .52726 m
.52729 .52746 L
s
.66659 .51698 m
.66624 .51728 L
s
.37956 .52919 m
.37884 .529 L
s
.24841 .61217 m
.24804 .61196 L
s
.5283 .5272 m
.52763 .5274 L
s
.37985 .52915 m
.37913 .52896 L
s
.52829 .52717 m
.52761 .52737 L
s
.85372 .37519 m
.85366 .37546 L
s
.66671 .51689 m
.66637 .51719 L
s
.3795 .5291 m
.37878 .52891 L
s
.52856 .52711 m
.52789 .52731 L
s
.37912 .52905 m
.3784 .52886 L
s
.52864 .52706 m
.52797 .52726 L
s
.22814 .53337 m
.22775 .53311 L
s
.37884 .529 m
.37812 .52881 L
s
.52898 .527 m
.5283 .5272 L
s
.37913 .52896 m
.37841 .52877 L
s
.22801 .5333 m
.22762 .53304 L
s
.52896 .52696 m
.52829 .52717 L
s
.85379 .37493 m
.85372 .37519 L
s
.37878 .52891 m
.37806 .52872 L
s
.66693 .51669 m
.66659 .51698 L
s
.52924 .5269 m
.52856 .52711 L
s
.52932 .52686 m
.52864 .52706 L
s
.3784 .52886 m
.37768 .52867 L
s
.24804 .61196 m
.24767 .61174 L
s
.66705 .5166 m
.66671 .51689 L
s
.52965 .5268 m
.52898 .527 L
s
.37812 .52881 m
.3774 .52862 L
s
.37841 .52877 m
.37769 .52858 L
s
.52964 .52676 m
.52896 .52696 L
s
.22775 .53311 m
.22737 .53285 L
s
.37806 .52872 m
.37735 .52853 L
s
.52991 .5267 m
.52924 .5269 L
s
.85386 .37466 m
.85379 .37493 L
s
.22762 .53304 m
.22724 .53278 L
s
.52999 .52666 m
.52932 .52686 L
s
.37768 .52867 m
.37696 .52848 L
s
.66727 .51639 m
.66693 .51669 L
s
.53032 .52659 m
.52965 .5268 L
s
.3774 .52862 m
.37669 .52842 L
s
.53031 .52656 m
.52964 .52676 L
s
.37769 .52858 m
.37697 .52838 L
s
.66739 .5163 m
.66705 .5166 L
s
.24767 .61174 m
.24729 .61152 L
s
.37735 .52853 m
.37663 .52833 L
s
.53058 .52649 m
.52991 .5267 L
s
.85392 .37439 m
.85386 .37466 L
s
.53066 .52645 m
.52999 .52666 L
s
.22737 .53285 m
.22698 .53258 L
s
.37696 .52848 m
.37625 .52828 L
s
.53099 .52639 m
.53032 .52659 L
s
.37669 .52842 m
.37597 .52823 L
s
.22724 .53278 m
.22685 .53251 L
s
.53098 .52635 m
.53031 .52656 L
s
.37697 .52838 m
.37626 .52818 L
s
.66761 .5161 m
.66727 .51639 L
s
.53125 .52629 m
.53058 .52649 L
s
.37663 .52833 m
.37592 .52814 L
s
.53133 .52624 m
.53066 .52645 L
s
.85399 .37412 m
.85392 .37439 L
s
.37625 .52828 m
.37553 .52808 L
s
.66773 .51601 m
.66739 .5163 L
s
.53166 .52618 m
.53099 .52639 L
s
.24729 .61152 m
.24692 .6113 L
s
.37597 .52823 m
.37526 .52803 L
s
.22698 .53258 m
.2266 .53232 L
s
.53164 .52614 m
.53098 .52635 L
s
.37626 .52818 m
.37554 .52799 L
s
.53191 .52608 m
.53125 .52629 L
s
.37592 .52814 m
.3752 .52794 L
s
.22685 .53251 m
.22647 .53225 L
s
.53199 .52604 m
.53133 .52624 L
s
.37553 .52808 m
.37482 .52788 L
s
.66795 .5158 m
.66761 .5161 L
s
.85405 .37385 m
.85399 .37412 L
s
.53232 .52597 m
.53166 .52618 L
s
.37526 .52803 m
.37455 .52783 L
s
.53231 .52593 m
.53164 .52614 L
s
.37554 .52799 m
.37483 .52778 L
s
.66807 .51571 m
.66773 .51601 L
s
.53258 .52587 m
.53191 .52608 L
s
.3752 .52794 m
.37449 .52773 L
s
.2266 .53232 m
.22622 .53205 L
s
.53266 .52583 m
.53199 .52604 L
s
.24692 .6113 m
.24655 .61108 L
s
.37482 .52788 m
.37411 .52768 L
s
.85411 .37359 m
.85405 .37385 L
s
.22647 .53225 m
.22609 .53198 L
s
.53299 .52576 m
.53232 .52597 L
s
.53298 .52572 m
.53231 .52593 L
s
.37455 .52783 m
.37383 .52762 L
s
.66829 .5155 m
.66795 .5158 L
s
.37483 .52778 m
.37412 .52758 L
s
.53324 .52566 m
.53258 .52587 L
s
.37449 .52773 m
.37378 .52753 L
s
.53332 .52561 m
.53266 .52583 L
s
.66841 .51541 m
.66807 .51571 L
s
.37411 .52768 m
.3734 .52747 L
s
.22622 .53205 m
.22584 .53178 L
s
.53365 .52554 m
.53299 .52576 L
s
.85418 .37332 m
.85411 .37359 L
s
.53364 .52551 m
.53298 .52572 L
s
.37383 .52762 m
.37313 .52742 L
s
.37412 .52758 m
.37341 .52738 L
s
.22609 .53198 m
.22571 .53171 L
s
.24655 .61108 m
.24618 .61086 L
s
.53391 .52544 m
.53324 .52566 L
s
.37378 .52753 m
.37307 .52733 L
s
.53399 .5254 m
.53332 .52561 L
s
.66862 .51521 m
.66829 .5155 L
s
.3734 .52747 m
.37269 .52727 L
s
.53431 .52533 m
.53365 .52554 L
s
.85424 .37305 m
.85418 .37332 L
s
.5343 .52529 m
.53364 .52551 L
s
.66875 .51512 m
.66841 .51541 L
s
.37313 .52742 m
.37242 .52721 L
s
.37341 .52738 m
.3727 .52717 L
s
.22584 .53178 m
.22546 .53152 L
s
.53457 .52523 m
.53391 .52544 L
s
.53465 .52518 m
.53399 .5254 L
s
.37307 .52733 m
.37236 .52712 L
s
.22571 .53171 m
.22533 .53145 L
s
.37269 .52727 m
.37198 .52706 L
s
.53497 .52511 m
.53431 .52533 L
s
.24618 .61086 m
.2458 .61064 L
s
.53496 .52508 m
.5343 .52529 L
s
.66896 .51491 m
.66862 .51521 L
s
.8543 .37278 m
.85424 .37305 L
s
.37242 .52721 m
.37171 .527 L
s
.3727 .52717 m
.37199 .52696 L
s
.53522 .52501 m
.53457 .52523 L
s
.66908 .51482 m
.66875 .51512 L
s
.53531 .52497 m
.53465 .52518 L
s
.37236 .52712 m
.37166 .52691 L
s
.22546 .53152 m
.22508 .53125 L
s
.53563 .52489 m
.53497 .52511 L
s
.37198 .52706 m
.37128 .52685 L
s
.53562 .52486 m
.53496 .52508 L
s
.22533 .53145 m
.22495 .53118 L
s
.85436 .37251 m
.8543 .37278 L
s
.37171 .527 m
.371 .52679 L
s
.37199 .52696 m
.37129 .52675 L
s
.53588 .52479 m
.53522 .52501 L
s
.6693 .51461 m
.66896 .51491 L
s
.2458 .61064 m
.24543 .61042 L
s
.53596 .52475 m
.53531 .52497 L
s
.37166 .52691 m
.37095 .5267 L
s
.53628 .52467 m
.53563 .52489 L
s
.66942 .51452 m
.66908 .51482 L
s
.37128 .52685 m
.37057 .52664 L
s
.53627 .52464 m
.53562 .52486 L
s
.22508 .53125 m
.2247 .53098 L
s
.85443 .37225 m
.85436 .37251 L
s
.371 .52679 m
.3703 .52658 L
s
.53654 .52457 m
.53588 .52479 L
s
.37129 .52675 m
.37058 .52654 L
s
.22495 .53118 m
.22457 .53091 L
s
.53662 .52453 m
.53596 .52475 L
s
.37095 .5267 m
.37025 .52648 L
s
.66963 .51431 m
.6693 .51461 L
s
.53694 .52445 m
.53628 .52467 L
s
.37057 .52664 m
.36987 .52642 L
s
.53693 .52442 m
.53627 .52464 L
s
.24543 .61042 m
.24506 .6102 L
s
.85449 .37198 m
.85443 .37225 L
s
.66975 .51422 m
.66942 .51452 L
s
.3703 .52658 m
.3696 .52636 L
s
.53719 .52435 m
.53654 .52457 L
s
.37058 .52654 m
.36988 .52632 L
s
.2247 .53098 m
.22432 .53071 L
s
.53727 .52431 m
.53662 .52453 L
s
.37025 .52648 m
.36954 .52627 L
s
.22457 .53091 m
.2242 .53064 L
s
.53759 .52423 m
.53694 .52445 L
s
.36987 .52642 m
.36917 .52621 L
s
.53758 .52419 m
.53693 .52442 L
s
.66996 .51401 m
.66963 .51431 L
s
.85455 .37171 m
.85449 .37198 L
s
.3696 .52636 m
.3689 .52615 L
s
.53784 .52412 m
.53719 .52435 L
s
.36988 .52632 m
.36918 .52611 L
s
.53793 .52408 m
.53727 .52431 L
s
.67008 .51392 m
.66975 .51422 L
s
.24506 .6102 m
.2447 .60998 L
s
.36954 .52627 m
.36884 .52605 L
s
.22432 .53071 m
.22395 .53044 L
s
.53824 .524 m
.53759 .52423 L
s
.53823 .52397 m
.53758 .52419 L
s
.36917 .52621 m
.36847 .52599 L
s
.2242 .53064 m
.22382 .53037 L
s
.53849 .5239 m
.53784 .52412 L
s
.85461 .37144 m
.85455 .37171 L
s
.3689 .52615 m
.3682 .52593 L
s
.36918 .52611 m
.36848 .52589 L
s
.53858 .52386 m
.53793 .52408 L
s
.6703 .51371 m
.66996 .51401 L
s
.36884 .52605 m
.36814 .52583 L
s
.53889 .52378 m
.53824 .524 L
s
.53888 .52374 m
.53823 .52397 L
s
.67041 .51362 m
.67008 .51392 L
s
.36847 .52599 m
.36777 .52577 L
s
.22395 .53044 m
.22357 .53017 L
s
.2447 .60998 m
.24433 .60975 L
s
.53914 .52367 m
.53849 .5239 L
s
.85467 .37117 m
.85461 .37144 L
s
.3682 .52593 m
.3675 .52571 L
s
.53923 .52363 m
.53858 .52386 L
s
.22382 .53037 m
.22345 .5301 L
s
.36848 .52589 m
.36778 .52567 L
s
.36814 .52583 m
.36745 .52561 L
s
.53954 .52355 m
.53889 .52378 L
s
.67063 .51341 m
.6703 .51371 L
s
.53953 .52351 m
.53888 .52374 L
s
.36777 .52577 m
.36707 .52555 L
s
.53979 .52344 m
.53914 .52367 L
s
.67074 .51332 m
.67041 .51362 L
s
.85473 .37091 m
.85467 .37117 L
s
.3675 .52571 m
.3668 .52549 L
s
.22357 .53017 m
.2232 .5299 L
s
.53987 .5234 m
.53923 .52363 L
s
.36778 .52567 m
.36708 .52545 L
s
.24433 .60975 m
.24396 .60953 L
s
.22345 .5301 m
.22307 .52983 L
s
.36745 .52561 m
.36675 .52539 L
s
.54018 .52332 m
.53954 .52355 L
s
.54018 .52328 m
.53953 .52351 L
s
.36707 .52555 m
.36638 .52533 L
s
.67096 .51311 m
.67063 .51341 L
s
.54044 .52321 m
.53979 .52344 L
s
.85479 .37064 m
.85473 .37091 L
s
.3668 .52549 m
.36611 .52526 L
s
.54052 .52317 m
.53987 .5234 L
s
.36708 .52545 m
.36638 .52522 L
s
.67107 .51302 m
.67074 .51332 L
s
.2232 .5299 m
.22283 .52963 L
s
.54083 .52309 m
.54018 .52332 L
s
.36675 .52539 m
.36605 .52517 L
s
.54082 .52305 m
.54018 .52328 L
s
.22307 .52983 m
.2227 .52956 L
s
.36638 .52533 m
.36568 .5251 L
s
.24396 .60953 m
.24359 .6093 L
s
.54108 .52298 m
.54044 .52321 L
s
.85485 .37037 m
.85479 .37064 L
s
.54116 .52294 m
.54052 .52317 L
s
.36611 .52526 m
.36541 .52504 L
s
.36638 .52522 m
.36569 .525 L
s
.67129 .51281 m
.67096 .51311 L
s
.54147 .52285 m
.54083 .52309 L
s
.36605 .52517 m
.36536 .52494 L
s
.54147 .52282 m
.54082 .52305 L
s
.6714 .51272 m
.67107 .51302 L
s
.22283 .52963 m
.22245 .52936 L
s
.36568 .5251 m
.36499 .52487 L
s
.54172 .52274 m
.54108 .52298 L
s
.8549 .3701 m
.85485 .37037 L
s
.2227 .52956 m
.22233 .52929 L
s
.54181 .5227 m
.54116 .52294 L
s
.36541 .52504 m
.36472 .52481 L
s
.36569 .525 m
.365 .52477 L
s
.24359 .6093 m
.24322 .60908 L
s
.54211 .52262 m
.54147 .52285 L
s
.67161 .51251 m
.67129 .51281 L
s
.36536 .52494 m
.36467 .52471 L
s
.54211 .52259 m
.54147 .52282 L
s
.36499 .52487 m
.3643 .52464 L
s
.54236 .52251 m
.54172 .52274 L
s
.67173 .51242 m
.6714 .51272 L
s
.85496 .36983 m
.8549 .3701 L
s
.22245 .52936 m
.22208 .52909 L
s
.54245 .52247 m
.54181 .5227 L
s
.36472 .52481 m
.36403 .52458 L
s
.365 .52477 m
.3643 .52454 L
s
.22233 .52929 m
.22196 .52902 L
s
.54275 .52238 m
.54211 .52262 L
s
.36467 .52471 m
.36398 .52448 L
s
.54275 .52235 m
.54211 .52259 L
s
.24322 .60908 m
.24286 .60885 L
s
.67194 .51221 m
.67161 .51251 L
s
.3643 .52464 m
.36361 .52441 L
s
.543 .52227 m
.54236 .52251 L
s
.85502 .36957 m
.85496 .36983 L
s
.54309 .52223 m
.54245 .52247 L
s
.36403 .52458 m
.36334 .52435 L
s
.67206 .51212 m
.67173 .51242 L
s
.22208 .52909 m
.22171 .52882 L
s
.3643 .52454 m
.36361 .52431 L
s
.54339 .52214 m
.54275 .52238 L
s
.54338 .52211 m
.54275 .52235 L
s
.36398 .52448 m
.36329 .52425 L
s
.22196 .52902 m
.22159 .52875 L
s
.54364 .52203 m
.543 .52227 L
s
.85508 .3693 m
.85502 .36957 L
s
.36361 .52441 m
.36292 .52418 L
s
.54372 .52199 m
.54309 .52223 L
s
.67227 .51191 m
.67194 .51221 L
s
.36334 .52435 m
.36265 .52411 L
s
.24286 .60885 m
.24249 .60863 L
s
.36361 .52431 m
.36293 .52408 L
s
.54402 .52191 m
.54339 .52214 L
s
.22171 .52882 m
.22134 .52855 L
s
.67238 .51181 m
.67206 .51212 L
s
.54402 .52187 m
.54338 .52211 L
s
.36329 .52425 m
.3626 .52402 L
s
.22159 .52875 m
.22122 .52848 L
s
.54427 .52179 m
.54364 .52203 L
s
.85513 .36903 m
.85508 .3693 L
s
.36292 .52418 m
.36223 .52395 L
s
.54436 .52175 m
.54372 .52199 L
s
.36265 .52411 m
.36196 .52388 L
s
.36293 .52408 m
.36224 .52384 L
s
.67259 .5116 m
.67227 .51191 L
s
.54466 .52166 m
.54402 .52191 L
s
.54465 .52163 m
.54402 .52187 L
s
.3626 .52402 m
.36191 .52378 L
s
.24249 .60863 m
.24213 .6084 L
s
.22134 .52855 m
.22097 .52827 L
s
.67271 .51151 m
.67238 .51181 L
s
.85519 .36876 m
.85513 .36903 L
s
.54491 .52155 m
.54427 .52179 L
s
.36223 .52395 m
.36155 .52371 L
s
.54499 .52151 m
.54436 .52175 L
s
.22122 .52848 m
.22085 .5282 L
s
.36196 .52388 m
.36128 .52364 L
s
.36224 .52384 m
.36155 .5236 L
s
.54529 .52142 m
.54466 .52166 L
s
.54529 .52139 m
.54465 .52163 L
s
.67291 .5113 m
.67259 .5116 L
s
.36191 .52378 m
.36123 .52354 L
s
.85524 .36849 m
.85519 .36876 L
s
.54554 .5213 m
.54491 .52155 L
s
.54562 .52127 m
.54499 .52151 L
s
.36155 .52371 m
.36086 .52347 L
s
.22097 .52827 m
.22061 .528 L
s
.67303 .51121 m
.67271 .51151 L
s
.24213 .6084 m
.24176 .60817 L
s
.36128 .52364 m
.3606 .5234 L
s
.22085 .5282 m
.22048 .52793 L
s
.54592 .52118 m
.54529 .52142 L
s
.36155 .5236 m
.36087 .52337 L
s
.54592 .52114 m
.54529 .52139 L
s
.36123 .52354 m
.36055 .5233 L
s
.8553 .36823 m
.85524 .36849 L
s
.54617 .52106 m
.54554 .5213 L
s
.67324 .511 m
.67291 .5113 L
s
.54625 .52102 m
.54562 .52127 L
s
.36086 .52347 m
.36018 .52323 L
s
.22061 .528 m
.22024 .52773 L
s
.67335 .5109 m
.67303 .51121 L
s
.3606 .5234 m
.35992 .52316 L
s
.54655 .52093 m
.54592 .52118 L
s
.36087 .52337 m
.36019 .52312 L
s
.54654 .5209 m
.54592 .52114 L
s
.24176 .60817 m
.2414 .60794 L
s
.22048 .52793 m
.22012 .52765 L
s
.85535 .36796 m
.8553 .36823 L
s
.36055 .5233 m
.35986 .52306 L
s
.54679 .52081 m
.54617 .52106 L
s
.54688 .52077 m
.54625 .52102 L
s
.36018 .52323 m
.3595 .52299 L
s
.67356 .51069 m
.67324 .511 L
s
.54717 .52068 m
.54655 .52093 L
s
.35992 .52316 m
.35924 .52292 L
s
.36019 .52312 m
.35951 .52288 L
s
.54717 .52065 m
.54654 .5209 L
s
.22024 .52773 m
.21988 .52745 L
s
.67367 .5106 m
.67335 .5109 L
s
.85541 .36769 m
.85535 .36796 L
s
.35986 .52306 m
.35918 .52282 L
s
.54742 .52056 m
.54679 .52081 L
s
.22012 .52765 m
.21975 .52738 L
s
.5475 .52053 m
.54688 .52077 L
s
.2414 .60794 m
.24104 .60771 L
s
.3595 .52299 m
.35882 .52274 L
s
.5478 .52043 m
.54717 .52068 L
s
.35924 .52292 m
.35856 .52267 L
s
.67388 .51039 m
.67356 .51069 L
s
.5478 .5204 m
.54717 .52065 L
s
.35951 .52288 m
.35883 .52264 L
s
.85546 .36742 m
.85541 .36769 L
s
.21988 .52745 m
.21951 .52718 L
s
.54804 .52031 m
.54742 .52056 L
s
.35918 .52282 m
.35851 .52257 L
s
.67399 .51029 m
.67367 .5106 L
s
.54813 .52028 m
.5475 .52053 L
s
.21975 .52738 m
.21939 .5271 L
s
.35882 .52274 m
.35815 .5225 L
s
.54842 .52018 m
.5478 .52043 L
s
.24104 .60771 m
.24068 .60748 L
s
.54842 .52015 m
.5478 .5204 L
s
.35856 .52267 m
.35788 .52243 L
s
.85551 .36716 m
.85546 .36742 L
s
.35883 .52264 m
.35815 .52239 L
s
.6742 .51008 m
.67388 .51039 L
s
.54867 .52006 m
.54804 .52031 L
s
.35851 .52257 m
.35783 .52232 L
s
.54875 .52002 m
.54813 .52028 L
s
.21951 .52718 m
.21915 .5269 L
s
.67431 .50999 m
.67399 .51029 L
s
.35815 .5225 m
.35747 .52225 L
s
.21939 .5271 m
.21902 .52683 L
s
.54904 .51993 m
.54842 .52018 L
s
.85556 .36689 m
.85551 .36716 L
s
.54904 .5199 m
.54842 .52015 L
s
.35788 .52243 m
.35721 .52218 L
s
.35815 .52239 m
.35747 .52214 L
s
.24068 .60748 m
.24031 .60725 L
s
.54929 .51981 m
.54867 .52006 L
s
.35783 .52232 m
.35716 .52208 L
s
.67452 .50978 m
.6742 .51008 L
s
.54937 .51977 m
.54875 .52002 L
s
.21915 .5269 m
.21878 .52662 L
s
.35747 .52225 m
.3568 .522 L
s
.67463 .50968 m
.67431 .50999 L
s
.85562 .36662 m
.85556 .36689 L
s
.54966 .51967 m
.54904 .51993 L
s
.54966 .51964 m
.54904 .5199 L
s
.21902 .52683 m
.21866 .52655 L
s
.35721 .52218 m
.35653 .52193 L
s
.35747 .52214 m
.3568 .52189 L
s
.5499 .51955 m
.54929 .51981 L
s
.54999 .51952 m
.54937 .51977 L
s
.35716 .52208 m
.35648 .52183 L
s
.67483 .50947 m
.67452 .50978 L
s
.24031 .60725 m
.23995 .60701 L
s
.85567 .36635 m
.85562 .36662 L
s
.3568 .522 m
.35612 .52175 L
s
.55028 .51942 m
.54966 .51967 L
s
.21878 .52662 m
.21842 .52635 L
s
.55028 .51939 m
.54966 .51964 L
s
.67495 .50938 m
.67463 .50968 L
s
.35653 .52193 m
.35586 .52168 L
s
.3568 .52189 m
.35613 .52164 L
s
.21866 .52655 m
.2183 .52628 L
s
.55052 .5193 m
.5499 .51955 L
s
.55061 .51926 m
.54999 .51952 L
s
.35648 .52183 m
.35581 .52157 L
s
.85572 .36609 m
.85567 .36635 L
s
.35612 .52175 m
.35545 .5215 L
s
.55089 .51916 m
.55028 .51942 L
s
.67515 .50916 m
.67483 .50947 L
s
.55089 .51913 m
.55028 .51939 L
s
.23995 .60701 m
.23959 .60678 L
s
.21842 .52635 m
.21806 .52607 L
s
.35586 .52168 m
.35519 .52142 L
s
.35613 .52164 m
.35546 .52139 L
s
.67526 .50907 m
.67495 .50938 L
s
.55113 .51904 m
.55052 .5193 L
s
.2183 .52628 m
.21794 .526 L
s
.55122 .519 m
.55061 .51926 L
s
.35581 .52157 m
.35514 .52132 L
s
.85577 .36582 m
.85572 .36609 L
s
.5515 .5189 m
.55089 .51916 L
s
.35545 .5215 m
.35478 .52124 L
s
.5515 .51887 m
.55089 .51913 L
s
.67546 .50886 m
.67515 .50916 L
s
.35519 .52142 m
.35452 .52117 L
s
.35546 .52139 m
.35479 .52113 L
s
.21806 .52607 m
.2177 .52579 L
s
.55175 .51878 m
.55113 .51904 L
s
.23959 .60678 m
.23923 .60655 L
s
.55183 .51874 m
.55122 .519 L
s
.85582 .36555 m
.85577 .36582 L
s
.67558 .50876 m
.67526 .50907 L
s
.35514 .52132 m
.35447 .52106 L
s
.21794 .526 m
.21758 .52572 L
s
.55212 .51864 m
.5515 .5189 L
s
.35478 .52124 m
.35412 .52098 L
s
.55212 .51861 m
.5515 .51887 L
s
.35452 .52117 m
.35386 .52091 L
s
.67578 .50855 m
.67546 .50886 L
s
.55236 .51852 m
.55175 .51878 L
s
.35479 .52113 m
.35412 .52087 L
s
.85587 .36528 m
.85582 .36555 L
s
.55244 .51848 m
.55183 .51874 L
s
.2177 .52579 m
.21734 .52551 L
s
.35447 .52106 m
.35381 .5208 L
s
.67589 .50846 m
.67558 .50876 L
s
.23923 .60655 m
.23888 .60631 L
s
.21758 .52572 m
.21722 .52544 L
s
.55272 .51838 m
.55212 .51864 L
s
.55273 .51835 m
.55212 .51861 L
s
.35412 .52098 m
.35345 .52072 L
s
.85592 .36501 m
.85587 .36528 L
s
.35386 .52091 m
.35319 .52065 L
s
.55297 .51825 m
.55236 .51852 L
s
.35412 .52087 m
.35346 .52061 L
s
.55305 .51822 m
.55244 .51848 L
s
.67609 .50824 m
.67578 .50855 L
s
.35381 .5208 m
.35314 .52054 L
s
.21734 .52551 m
.21699 .52523 L
s
.55333 .51812 m
.55272 .51838 L
s
.6762 .50815 m
.67589 .50846 L
s
.55333 .51808 m
.55273 .51835 L
s
.21722 .52544 m
.21686 .52516 L
s
.35345 .52072 m
.35279 .52046 L
s
.23888 .60631 m
.23852 .60608 L
s
.85597 .36475 m
.85592 .36501 L
s
.55357 .51799 m
.55297 .51825 L
s
.35319 .52065 m
.35253 .52039 L
s
.35346 .52061 m
.35279 .52035 L
s
.55366 .51796 m
.55305 .51822 L
s
.6764 .50793 m
.67609 .50824 L
s
.35314 .52054 m
.35248 .52028 L
s
.55394 .51785 m
.55333 .51812 L
s
.21699 .52523 m
.21663 .52496 L
s
.55394 .51782 m
.55333 .51808 L
s
.85602 .36448 m
.85597 .36475 L
s
.35279 .52046 m
.35213 .5202 L
s
.67651 .50784 m
.6762 .50815 L
s
.21686 .52516 m
.21651 .52488 L
s
.55418 .51772 m
.55357 .51799 L
s
.35253 .52039 m
.35187 .52012 L
s
.55426 .51769 m
.55366 .51796 L
s
.23852 .60608 m
.23816 .60584 L
s
.35279 .52035 m
.35213 .52009 L
s
.35248 .52028 m
.35182 .52002 L
s
.55454 .51758 m
.55394 .51785 L
s
.67671 .50762 m
.6764 .50793 L
s
.85606 .36421 m
.85602 .36448 L
s
.55454 .51755 m
.55394 .51782 L
s
.21663 .52496 m
.21627 .52468 L
s
.35213 .5202 m
.35147 .51994 L
s
.67682 .50753 m
.67651 .50784 L
s
.55478 .51746 m
.55418 .51772 L
s
.21651 .52488 m
.21615 .5246 L
s
.55487 .51742 m
.55426 .51769 L
s
.35187 .52012 m
.35121 .51986 L
s
.35213 .52009 m
.35147 .51983 L
s
.23816 .60584 m
.2378 .6056 L
s
.35182 .52002 m
.35116 .51975 L
s
.85611 .36394 m
.85606 .36421 L
s
.55514 .51732 m
.55454 .51758 L
s
.55514 .51728 m
.55454 .51755 L
s
.67702 .50731 m
.67671 .50762 L
s
.35147 .51994 m
.35081 .51967 L
s
.21627 .52468 m
.21592 .5244 L
s
.55538 .51719 m
.55478 .51746 L
s
.55547 .51715 m
.55487 .51742 L
s
.67713 .50722 m
.67682 .50753 L
s
.35121 .51986 m
.35055 .51959 L
s
.21615 .5246 m
.2158 .52432 L
s
.35147 .51983 m
.35081 .51956 L
s
.85616 .36368 m
.85611 .36394 L
s
.55574 .51705 m
.55514 .51732 L
s
.35116 .51975 m
.3505 .51949 L
s
.55574 .51701 m
.55514 .51728 L
s
.2378 .6056 m
.23745 .60537 L
s
.35081 .51967 m
.35015 .5194 L
s
.67733 .50701 m
.67702 .50731 L
s
.55598 .51692 m
.55538 .51719 L
s
.21592 .5244 m
.21557 .52411 L
s
.55607 .51688 m
.55547 .51715 L
s
.35055 .51959 m
.3499 .51932 L
s
.85621 .36341 m
.85616 .36368 L
s
.35081 .51956 m
.35016 .51929 L
s
.67744 .50691 m
.67713 .50722 L
s
.2158 .52432 m
.21544 .52404 L
s
.55634 .51677 m
.55574 .51705 L
s
.3505 .51949 m
.34985 .51922 L
s
.55634 .51674 m
.55574 .51701 L
s
.35015 .5194 m
.3495 .51913 L
s
.55658 .51665 m
.55598 .51692 L
s
.55666 .51661 m
.55607 .51688 L
s
.23745 .60537 m
.23709 .60513 L
s
.85625 .36314 m
.85621 .36341 L
s
.67764 .5067 m
.67733 .50701 L
s
.21557 .52411 m
.21521 .52383 L
s
.3499 .51932 m
.34924 .51905 L
s
.35016 .51929 m
.3495 .51902 L
s
.67775 .5066 m
.67744 .50691 L
s
.21544 .52404 m
.21509 .52376 L
s
.55693 .5165 m
.55634 .51677 L
s
.55694 .51647 m
.55634 .51674 L
s
.34985 .51922 m
.34919 .51895 L
s
.8563 .36287 m
.85625 .36314 L
s
.3495 .51913 m
.34885 .51886 L
s
.55717 .51637 m
.55658 .51665 L
s
.55726 .51634 m
.55666 .51661 L
s
.67794 .50638 m
.67764 .5067 L
s
.34924 .51905 m
.34859 .51878 L
s
.21521 .52383 m
.21486 .52355 L
s
.3495 .51902 m
.34885 .51875 L
s
.23709 .60513 m
.23674 .60489 L
s
.55753 .51623 m
.55693 .5165 L
s
.55753 .5162 m
.55694 .51647 L
s
.67805 .50629 m
.67775 .5066 L
s
.21509 .52376 m
.21474 .52348 L
s
.34919 .51895 m
.34854 .51867 L
s
.85634 .36261 m
.8563 .36287 L
s
.55776 .5161 m
.55717 .51637 L
s
.34885 .51886 m
.3482 .51859 L
s
.55785 .51606 m
.55726 .51634 L
s
.34859 .51878 m
.34794 .51851 L
s
.34885 .51875 m
.3482 .51847 L
s
.67825 .50607 m
.67794 .50638 L
s
.21486 .52355 m
.21451 .52327 L
s
.55812 .51595 m
.55753 .51623 L
s
.55812 .51592 m
.55753 .5162 L
s
.85639 .36234 m
.85634 .36261 L
s
.23674 .60489 m
.23638 .60465 L
s
.34854 .51867 m
.34789 .5184 L
s
.21474 .52348 m
.21439 .5232 L
s
.67836 .50598 m
.67805 .50629 L
s
.55835 .51582 m
.55776 .5161 L
s
.3482 .51859 m
.34755 .51831 L
s
.55844 .51579 m
.55785 .51606 L
s
.34794 .51851 m
.34729 .51823 L
s
.3482 .51847 m
.34755 .5182 L
s
.55871 .51567 m
.55812 .51595 L
s
.85643 .36207 m
.85639 .36234 L
s
.67855 .50576 m
.67825 .50607 L
s
.21451 .52327 m
.21416 .52299 L
s
.55871 .51564 m
.55812 .51592 L
s
.34789 .5184 m
.34725 .51812 L
s
.21439 .5232 m
.21404 .52291 L
s
.67866 .50567 m
.67836 .50598 L
s
.23638 .60465 m
.23603 .60441 L
s
.55894 .51554 m
.55835 .51582 L
s
.55903 .51551 m
.55844 .51579 L
s
.34755 .51831 m
.3469 .51804 L
s
.85647 .36181 m
.85643 .36207 L
s
.34729 .51823 m
.34665 .51795 L
s
.34755 .5182 m
.3469 .51792 L
s
.55929 .5154 m
.55871 .51567 L
s
.5593 .51536 m
.55871 .51564 L
s
.67886 .50545 m
.67855 .50576 L
s
.21416 .52299 m
.21381 .5227 L
s
.34725 .51812 m
.3466 .51784 L
s
.55953 .51526 m
.55894 .51554 L
s
.21404 .52291 m
.21369 .52263 L
s
.55962 .51523 m
.55903 .51551 L
s
.67896 .50536 m
.67866 .50567 L
s
.3469 .51804 m
.34626 .51776 L
s
.85652 .36154 m
.85647 .36181 L
s
.23603 .60441 m
.23568 .60417 L
s
.34665 .51795 m
.346 .51768 L
s
.55988 .51511 m
.55929 .5154 L
s
.3469 .51792 m
.34626 .51764 L
s
.55988 .51508 m
.5593 .51536 L
s
.21381 .5227 m
.21346 .52242 L
s
.67916 .50514 m
.67886 .50545 L
s
.3466 .51784 m
.34596 .51756 L
s
.56011 .51498 m
.55953 .51526 L
s
.85656 .36127 m
.85652 .36154 L
s
.5602 .51495 m
.55962 .51523 L
s
.21369 .52263 m
.21335 .52235 L
s
.34626 .51776 m
.34561 .51748 L
s
.67927 .50504 m
.67896 .50536 L
s
.56046 .51483 m
.55988 .51511 L
s
.23568 .60417 m
.23532 .60392 L
s
.346 .51768 m
.34536 .51739 L
s
.34626 .51764 m
.34562 .51736 L
s
.56047 .5148 m
.55988 .51508 L
s
.8566 .361 m
.85656 .36127 L
s
.34596 .51756 m
.34531 .51728 L
s
.5607 .5147 m
.56011 .51498 L
s
.21346 .52242 m
.21312 .52213 L
s
.67946 .50483 m
.67916 .50514 L
s
.56078 .51467 m
.5602 .51495 L
s
.34561 .51748 m
.34497 .51719 L
s
.21335 .52235 m
.213 .52206 L
s
.67957 .50473 m
.67927 .50504 L
s
.56104 .51455 m
.56046 .51483 L
s
.34536 .51739 m
.34472 .51711 L
s
.56105 .51452 m
.56047 .5148 L
s
.34562 .51736 m
.34497 .51708 L
s
.85664 .36074 m
.8566 .361 L
s
.23532 .60392 m
.23497 .60368 L
s
.34531 .51728 m
.34467 .517 L
s
.56128 .51442 m
.5607 .5147 L
s
.56136 .51438 m
.56078 .51467 L
s
.21312 .52213 m
.21277 .52185 L
s
.67976 .50451 m
.67946 .50483 L
s
.34497 .51719 m
.34433 .51691 L
s
.213 .52206 m
.21265 .52178 L
s
.67986 .50442 m
.67957 .50473 L
s
.56162 .51426 m
.56104 .51455 L
s
.85669 .36047 m
.85664 .36074 L
s
.56163 .51423 m
.56105 .51452 L
s
.34472 .51711 m
.34408 .51683 L
s
.34497 .51708 m
.34434 .51679 L
s
.56185 .51413 m
.56128 .51442 L
s
.34467 .517 m
.34404 .51671 L
s
.23497 .60368 m
.23462 .60344 L
s
.56194 .5141 m
.56136 .51438 L
s
.21277 .52185 m
.21243 .52156 L
s
.68006 .5042 m
.67976 .50451 L
s
.34433 .51691 m
.3437 .51662 L
s
.85673 .3602 m
.85669 .36047 L
s
.21265 .52178 m
.21231 .52149 L
s
.5622 .51398 m
.56162 .51426 L
s
.68016 .5041 m
.67986 .50442 L
s
.56221 .51395 m
.56163 .51423 L
s
.34408 .51683 m
.34344 .51654 L
s
.34434 .51679 m
.3437 .51651 L
s
.56243 .51384 m
.56185 .51413 L
s
.34404 .51671 m
.3434 .51643 L
s
.56252 .51381 m
.56194 .5141 L
s
.85677 .35993 m
.85673 .3602 L
s
.23462 .60344 m
.23427 .60319 L
s
.21243 .52156 m
.21208 .52128 L
s
.68035 .50388 m
.68006 .5042 L
s
.3437 .51662 m
.34306 .51634 L
s
.56277 .51369 m
.5622 .51398 L
s
.21231 .52149 m
.21197 .52121 L
s
.56278 .51366 m
.56221 .51395 L
s
.68046 .50379 m
.68016 .5041 L
s
.34344 .51654 m
.34281 .51625 L
s
.3437 .51651 m
.34306 .51622 L
s
.563 .51355 m
.56243 .51384 L
s
.85681 .35967 m
.85677 .35993 L
s
.56309 .51352 m
.56252 .51381 L
s
.3434 .51643 m
.34277 .51614 L
s
.21208 .52128 m
.21174 .52099 L
s
.34306 .51634 m
.34243 .51605 L
s
.68065 .50357 m
.68035 .50388 L
s
.56335 .5134 m
.56277 .51369 L
s
.23427 .60319 m
.23392 .60295 L
s
.56335 .51337 m
.56278 .51366 L
s
.21197 .52121 m
.21162 .52092 L
s
.34281 .51625 m
.34218 .51596 L
s
.68076 .50347 m
.68046 .50379 L
s
.34306 .51622 m
.34243 .51593 L
s
.85685 .3594 m
.85681 .35967 L
s
.56358 .51326 m
.563 .51355 L
s
.56367 .51323 m
.56309 .51352 L
s
.34277 .51614 m
.34213 .51585 L
s
.21174 .52099 m
.2114 .52071 L
s
.56392 .51311 m
.56335 .5134 L
s
.34243 .51605 m
.3418 .51576 L
s
.56392 .51308 m
.56335 .51337 L
s
.68095 .50325 m
.68065 .50357 L
s
.85689 .35913 m
.85685 .3594 L
s
.23392 .60295 m
.23358 .6027 L
s
.21162 .52092 m
.21128 .52063 L
s
.34218 .51596 m
.34155 .51567 L
s
.34243 .51593 m
.3418 .51564 L
s
.68105 .50316 m
.68076 .50347 L
s
.56415 .51297 m
.56358 .51326 L
s
.56424 .51294 m
.56367 .51323 L
s
.34213 .51585 m
.3415 .51556 L
s
.85692 .35887 m
.85689 .35913 L
s
.56449 .51282 m
.56392 .51311 L
s
.3418 .51576 m
.34117 .51546 L
s
.2114 .52071 m
.21106 .52042 L
s
.56449 .51279 m
.56392 .51308 L
s
.68124 .50294 m
.68095 .50325 L
s
.21128 .52063 m
.21094 .52035 L
s
.34155 .51567 m
.34092 .51538 L
s
.3418 .51564 m
.34117 .51535 L
s
.56471 .51268 m
.56415 .51297 L
s
.23358 .6027 m
.23323 .60246 L
s
.68134 .50284 m
.68105 .50316 L
s
.5648 .51265 m
.56424 .51294 L
s
.3415 .51556 m
.34087 .51526 L
s
.85696 .3586 m
.85692 .35887 L
s
.56505 .51252 m
.56449 .51282 L
s
.56506 .5125 m
.56449 .51279 L
s
.34117 .51546 m
.34054 .51517 L
s
.21106 .52042 m
.21072 .52013 L
s
.68153 .50262 m
.68124 .50294 L
s
.34092 .51538 m
.34029 .51508 L
s
.21094 .52035 m
.2106 .52006 L
s
.56528 .51239 m
.56471 .51268 L
s
.34117 .51535 m
.34054 .51505 L
s
.56537 .51235 m
.5648 .51265 L
s
.857 .35833 m
.85696 .3586 L
s
.68164 .50253 m
.68134 .50284 L
s
.23323 .60246 m
.23288 .60221 L
s
.34087 .51526 m
.34025 .51497 L
s
.56562 .51223 m
.56505 .51252 L
s
.56562 .5122 m
.56506 .5125 L
s
.34054 .51517 m
.33991 .51487 L
s
.21072 .52013 m
.21038 .51984 L
s
.85704 .35806 m
.857 .35833 L
s
.68182 .50231 m
.68153 .50262 L
s
.56584 .51209 m
.56528 .51239 L
s
.34029 .51508 m
.33967 .51479 L
s
.2106 .52006 m
.21026 .51977 L
s
.56593 .51206 m
.56537 .51235 L
s
.34054 .51505 m
.33992 .51475 L
s
.68193 .50221 m
.68164 .50253 L
s
.34025 .51497 m
.33962 .51467 L
s
.23288 .60221 m
.23253 .60196 L
s
.56618 .51193 m
.56562 .51223 L
s
.56619 .5119 m
.56562 .5122 L
s
.85707 .3578 m
.85704 .35806 L
s
.33991 .51487 m
.33929 .51458 L
s
.21038 .51984 m
.21004 .51955 L
s
.5664 .51179 m
.56584 .51209 L
s
.68211 .50199 m
.68182 .50231 L
s
.33967 .51479 m
.33905 .51449 L
s
.56649 .51176 m
.56593 .51206 L
s
.33992 .51475 m
.33929 .51445 L
s
.21026 .51977 m
.20993 .51948 L
s
.68222 .5019 m
.68193 .50221 L
s
.33962 .51467 m
.339 .51437 L
s
.56674 .51163 m
.56618 .51193 L
s
.85711 .35753 m
.85707 .3578 L
s
.56675 .51161 m
.56619 .5119 L
s
.23253 .60196 m
.23219 .60171 L
s
.33929 .51458 m
.33867 .51428 L
s
.21004 .51955 m
.20971 .51926 L
s
.56696 .51149 m
.5664 .51179 L
s
.56705 .51146 m
.56649 .51176 L
s
.6824 .50167 m
.68211 .50199 L
s
.33905 .51449 m
.33843 .51419 L
s
.33929 .51445 m
.33867 .51415 L
s
.20993 .51948 m
.20959 .51919 L
s
.85715 .35726 m
.85711 .35753 L
s
.68251 .50158 m
.68222 .5019 L
s
.339 .51437 m
.33838 .51407 L
s
.56729 .51134 m
.56674 .51163 L
s
.5673 .51131 m
.56675 .51161 L
s
.33867 .51428 m
.33805 .51397 L
s
.23219 .60171 m
.23184 .60146 L
s
.56752 .51119 m
.56696 .51149 L
s
.20971 .51926 m
.20937 .51898 L
s
.56761 .51116 m
.56705 .51146 L
s
.85718 .357 m
.85715 .35726 L
s
.33843 .51419 m
.33781 .51388 L
s
.68269 .50136 m
.6824 .50167 L
s
.33867 .51415 m
.33805 .51385 L
s
.20959 .51919 m
.20925 .5189 L
s
.56785 .51103 m
.56729 .51134 L
s
.68279 .50126 m
.68251 .50158 L
s
.33838 .51407 m
.33777 .51377 L
s
.56786 .51101 m
.5673 .51131 L
s
.33805 .51397 m
.33744 .51367 L
s
.85722 .35673 m
.85718 .357 L
s
.56807 .51089 m
.56752 .51119 L
s
.20937 .51898 m
.20904 .51869 L
s
.56816 .51086 m
.56761 .51116 L
s
.23184 .60146 m
.2315 .60121 L
s
.33781 .51388 m
.33719 .51358 L
s
.68298 .50104 m
.68269 .50136 L
s
.33805 .51385 m
.33744 .51355 L
s
.20925 .5189 m
.20892 .51861 L
s
.5684 .51073 m
.56785 .51103 L
s
.33777 .51377 m
.33715 .51346 L
s
.68308 .50094 m
.68279 .50126 L
s
.56841 .5107 m
.56786 .51101 L
s
.85725 .35646 m
.85722 .35673 L
s
.33744 .51367 m
.33682 .51337 L
s
.56863 .51059 m
.56807 .51089 L
s
.56872 .51056 m
.56816 .51086 L
s
.20904 .51869 m
.2087 .51839 L
s
.33719 .51358 m
.33658 .51328 L
s
.2315 .60121 m
.23116 .60096 L
s
.68327 .50072 m
.68298 .50104 L
s
.20892 .51861 m
.20859 .51832 L
s
.85728 .3562 m
.85725 .35646 L
s
.56895 .51043 m
.5684 .51073 L
s
.56896 .5104 m
.56841 .5107 L
s
.33715 .51346 m
.33654 .51316 L
s
.68337 .50062 m
.68308 .50094 L
s
.56918 .51029 m
.56863 .51059 L
s
.33682 .51337 m
.33621 .51306 L
s
.56927 .51026 m
.56872 .51056 L
s
.2087 .51839 m
.20837 .5181 L
s
.85732 .35593 m
.85728 .3562 L
s
.33658 .51328 m
.33597 .51297 L
s
.68355 .5004 m
.68327 .50072 L
s
.20859 .51832 m
.20826 .51803 L
s
.23116 .60096 m
.23081 .60071 L
s
.5695 .51012 m
.56895 .51043 L
s
.56951 .5101 m
.56896 .5104 L
s
.33654 .51316 m
.33592 .51285 L
s
.68365 .50031 m
.68337 .50062 L
s
.56972 .50998 m
.56918 .51029 L
s
.85735 .35566 m
.85732 .35593 L
s
.33621 .51306 m
.3356 .51275 L
s
.56981 .50995 m
.56927 .51026 L
s
.20837 .5181 m
.20804 .51781 L
s
.33597 .51297 m
.33536 .51266 L
s
.68383 .50008 m
.68355 .5004 L
s
.20826 .51803 m
.20792 .51774 L
s
.57005 .50982 m
.5695 .51012 L
s
.57006 .50979 m
.56951 .5101 L
s
.23081 .60071 m
.23047 .60046 L
s
.33592 .51285 m
.33532 .51254 L
s
.68393 .49999 m
.68365 .50031 L
s
.85738 .3554 m
.85735 .35566 L
s
.57027 .50967 m
.56972 .50998 L
s
.57036 .50964 m
.56981 .50995 L
s
.3356 .51275 m
.33499 .51244 L
s
.20804 .51781 m
.20771 .51752 L
s
.33536 .51266 m
.33475 .51235 L
s
.57059 .50951 m
.57005 .50982 L
s
.20792 .51774 m
.20759 .51745 L
s
.68412 .49976 m
.68383 .50008 L
s
.85741 .35513 m
.85738 .3554 L
s
.5706 .50948 m
.57006 .50979 L
s
.33532 .51254 m
.33471 .51223 L
s
.23047 .60046 m
.23013 .6002 L
s
.68422 .49967 m
.68393 .49999 L
s
.57081 .50936 m
.57027 .50967 L
s
.5709 .50934 m
.57036 .50964 L
s
.33499 .51244 m
.33438 .51213 L
s
.20771 .51752 m
.20738 .51723 L
s
.85745 .35486 m
.85741 .35513 L
s
.33475 .51235 m
.33414 .51204 L
s
.57113 .5092 m
.57059 .50951 L
s
.20759 .51745 m
.20727 .51715 L
s
.57115 .50917 m
.5706 .50948 L
s
.6844 .49944 m
.68412 .49976 L
s
.33471 .51223 m
.3341 .51191 L
s
.6845 .49935 m
.68422 .49967 L
s
.57135 .50905 m
.57081 .50936 L
s
.23013 .6002 m
.22979 .59995 L
s
.57145 .50903 m
.5709 .50934 L
s
.85748 .3546 m
.85745 .35486 L
s
.33438 .51213 m
.33378 .51182 L
s
.20738 .51723 m
.20705 .51693 L
s
.57167 .50889 m
.57113 .5092 L
s
.33414 .51204 m
.33354 .51172 L
s
.57169 .50886 m
.57115 .50917 L
s
.20727 .51715 m
.20694 .51686 L
s
.68468 .49912 m
.6844 .49944 L
s
.85751 .35433 m
.85748 .3546 L
s
.3341 .51191 m
.3335 .5116 L
s
.57189 .50874 m
.57135 .50905 L
s
.68478 .49903 m
.6845 .49935 L
s
.57198 .50871 m
.57145 .50903 L
s
.22979 .59995 m
.22945 .59969 L
s
.33378 .51182 m
.33318 .5115 L
s
.20705 .51693 m
.20672 .51664 L
s
.57221 .50858 m
.57167 .50889 L
s
.33354 .51172 m
.33294 .51141 L
s
.57222 .50855 m
.57169 .50886 L
s
.20694 .51686 m
.20661 .51657 L
s
.85754 .35406 m
.85751 .35433 L
s
.68496 .4988 m
.68468 .49912 L
s
.3335 .5116 m
.3329 .51128 L
s
.57243 .50843 m
.57189 .50874 L
s
.68506 .49871 m
.68478 .49903 L
s
.57252 .5084 m
.57198 .50871 L
s
.33318 .5115 m
.33258 .51118 L
s
.22945 .59969 m
.22911 .59944 L
s
.20672 .51664 m
.2064 .51635 L
s
.85757 .3538 m
.85754 .35406 L
s
.57275 .50826 m
.57221 .50858 L
s
.57276 .50824 m
.57222 .50855 L
s
.33294 .51141 m
.33234 .51109 L
s
.20661 .51657 m
.20628 .51627 L
s
.68524 .49848 m
.68496 .4988 L
s
.57296 .50812 m
.57243 .50843 L
s
.3329 .51128 m
.3323 .51097 L
s
.57306 .50809 m
.57252 .5084 L
s
.68533 .49838 m
.68506 .49871 L
s
.8576 .35353 m
.85757 .3538 L
s
.33258 .51118 m
.33198 .51087 L
s
.2064 .51635 m
.20607 .51605 L
s
.22911 .59944 m
.22877 .59918 L
s
.57328 .50795 m
.57275 .50826 L
s
.57329 .50792 m
.57276 .50824 L
s
.33234 .51109 m
.33175 .51077 L
s
.20628 .51627 m
.20596 .51598 L
s
.68551 .49816 m
.68524 .49848 L
s
.85762 .35326 m
.8576 .35353 L
s
.5735 .5078 m
.57296 .50812 L
s
.57359 .50777 m
.57306 .50809 L
s
.3323 .51097 m
.33171 .51065 L
s
.68561 .49806 m
.68533 .49838 L
s
.33198 .51087 m
.33139 .51055 L
s
.20607 .51605 m
.20575 .51576 L
s
.57381 .50763 m
.57328 .50795 L
s
.57382 .50761 m
.57329 .50792 L
s
.22877 .59918 m
.22843 .59892 L
s
.85765 .353 m
.85762 .35326 L
s
.20596 .51598 m
.20564 .51568 L
s
.33175 .51077 m
.33115 .51045 L
s
.68579 .49784 m
.68551 .49816 L
s
.57403 .50748 m
.5735 .5078 L
s
.57412 .50746 m
.57359 .50777 L
s
.33171 .51065 m
.33111 .51033 L
s
.68589 .49774 m
.68561 .49806 L
s
.85768 .35273 m
.85765 .353 L
s
.33139 .51055 m
.3308 .51022 L
s
.20575 .51576 m
.20542 .51546 L
s
.57434 .50731 m
.57381 .50763 L
s
.57435 .50729 m
.57382 .50761 L
s
.20564 .51568 m
.20531 .51539 L
s
.22843 .59892 m
.2281 .59867 L
s
.33115 .51045 m
.33056 .51013 L
s
.68606 .49751 m
.68579 .49784 L
s
.57455 .50717 m
.57403 .50748 L
s
.57465 .50714 m
.57412 .50746 L
s
.33111 .51033 m
.33052 .51 L
s
.68616 .49742 m
.68589 .49774 L
s
.85771 .35246 m
.85768 .35273 L
s
.57486 .507 m
.57434 .50731 L
s
.20542 .51546 m
.2051 .51517 L
s
.3308 .51022 m
.33021 .5099 L
s
.57488 .50697 m
.57435 .50729 L
s
.20531 .51539 m
.20499 .51509 L
s
.33056 .51013 m
.32997 .5098 L
s
.68634 .49719 m
.68606 .49751 L
s
.2281 .59867 m
.22776 .59841 L
s
.85773 .3522 m
.85771 .35246 L
s
.57508 .50685 m
.57455 .50717 L
s
.57517 .50682 m
.57465 .50714 L
s
.68643 .49709 m
.68616 .49742 L
s
.33052 .51 m
.32993 .50968 L
s
.57539 .50668 m
.57486 .507 L
s
.2051 .51517 m
.20478 .51487 L
s
.5754 .50665 m
.57488 .50697 L
s
.33021 .5099 m
.32962 .50958 L
s
.85776 .35193 m
.85773 .3522 L
s
.20499 .51509 m
.20467 .5148 L
s
.32997 .5098 m
.32938 .50948 L
s
.68661 .49687 m
.68634 .49719 L
s
.5756 .50653 m
.57508 .50685 L
s
.57569 .5065 m
.57517 .50682 L
s
.22776 .59841 m
.22743 .59815 L
s
.6867 .49677 m
.68643 .49709 L
s
.32993 .50968 m
.32935 .50935 L
s
.85779 .35167 m
.85776 .35193 L
s
.57591 .50635 m
.57539 .50668 L
s
.20478 .51487 m
.20446 .51457 L
s
.57592 .50633 m
.5754 .50665 L
s
.32962 .50958 m
.32903 .50925 L
s
.20467 .5148 m
.20435 .5145 L
s
.57612 .5062 m
.5756 .50653 L
s
.68688 .49654 m
.68661 .49687 L
s
.32938 .50948 m
.3288 .50915 L
s
.57621 .50618 m
.57569 .5065 L
s
.85781 .3514 m
.85779 .35167 L
s
.22743 .59815 m
.22709 .59789 L
s
.68698 .49645 m
.6867 .49677 L
s
.32935 .50935 m
.32876 .50902 L
s
.57643 .50603 m
.57591 .50635 L
s
.20446 .51457 m
.20414 .51428 L
s
.57644 .50601 m
.57592 .50633 L
s
.32903 .50925 m
.32845 .50892 L
s
.20435 .5145 m
.20403 .5142 L
s
.85784 .35113 m
.85781 .3514 L
s
.57664 .50588 m
.57612 .5062 L
s
.68715 .49622 m
.68688 .49654 L
s
.57673 .50585 m
.57621 .50618 L
s
.3288 .50915 m
.32822 .50882 L
s
.68725 .49612 m
.68698 .49645 L
s
.22709 .59789 m
.22676 .59763 L
s
.32876 .50902 m
.32818 .50869 L
s
.57694 .50571 m
.57643 .50603 L
s
.20414 .51428 m
.20383 .51398 L
s
.57696 .50568 m
.57644 .50601 L
s
.85786 .35087 m
.85784 .35113 L
s
.32845 .50892 m
.32787 .50859 L
s
.20403 .5142 m
.20372 .5139 L
s
.57716 .50555 m
.57664 .50588 L
s
.68742 .4959 m
.68715 .49622 L
s
.57725 .50553 m
.57673 .50585 L
s
.32822 .50882 m
.32764 .50849 L
s
.68751 .4958 m
.68725 .49612 L
s
.85788 .3506 m
.85786 .35087 L
s
.32818 .50869 m
.3276 .50836 L
s
.22676 .59763 m
.22642 .59736 L
s
.57746 .50538 m
.57694 .50571 L
s
.57747 .50536 m
.57696 .50568 L
s
.20383 .51398 m
.20351 .51368 L
s
.32787 .50859 m
.32729 .50826 L
s
.20372 .5139 m
.2034 .51361 L
s
.57767 .50523 m
.57716 .50555 L
s
.57776 .5052 m
.57725 .50553 L
s
.68769 .49557 m
.68742 .4959 L
s
.32764 .50849 m
.32706 .50816 L
s
.85791 .35033 m
.85788 .3506 L
s
.68778 .49547 m
.68751 .4958 L
s
.57797 .50505 m
.57746 .50538 L
s
.3276 .50836 m
.32702 .50803 L
s
.57799 .50503 m
.57747 .50536 L
s
.20351 .51368 m
.20319 .51338 L
s
.22642 .59736 m
.22609 .5971 L
s
.2034 .51361 m
.20308 .51331 L
s
.32729 .50826 m
.32671 .50793 L
s
.85793 .35007 m
.85791 .35033 L
s
.57818 .5049 m
.57767 .50523 L
s
.57827 .50488 m
.57776 .5052 L
s
.68795 .49525 m
.68769 .49557 L
s
.32706 .50816 m
.32648 .50783 L
s
.68805 .49515 m
.68778 .49547 L
s
.57848 .50473 m
.57797 .50505 L
s
.5785 .5047 m
.57799 .50503 L
s
.20319 .51338 m
.20288 .51308 L
s
.32702 .50803 m
.32645 .5077 L
s
.85795 .3498 m
.85793 .35007 L
s
.22609 .5971 m
.22576 .59684 L
s
.20308 .51331 m
.20277 .51301 L
s
.32671 .50793 m
.32614 .50759 L
s
.57869 .50457 m
.57818 .5049 L
s
.57878 .50455 m
.57827 .50488 L
s
.68822 .49492 m
.68795 .49525 L
s
.32648 .50783 m
.32591 .50749 L
s
.85797 .34954 m
.85795 .3498 L
s
.68831 .49482 m
.68805 .49515 L
s
.57899 .5044 m
.57848 .50473 L
s
.579 .50437 m
.5785 .5047 L
s
.20288 .51308 m
.20256 .51278 L
s
.32645 .5077 m
.32588 .50736 L
s
.20277 .51301 m
.20246 .51271 L
s
.22576 .59684 m
.22543 .59658 L
s
.5792 .50424 m
.57869 .50457 L
s
.32614 .50759 m
.32557 .50725 L
s
.57929 .50422 m
.57878 .50455 L
s
.68848 .49459 m
.68822 .49492 L
s
.858 .34927 m
.85797 .34954 L
s
.32591 .50749 m
.32534 .50715 L
s
.68858 .4945 m
.68831 .49482 L
s
.57949 .50407 m
.57899 .5044 L
s
.57951 .50404 m
.579 .50437 L
s
.20256 .51278 m
.20225 .51248 L
s
.32588 .50736 m
.32531 .50702 L
s
.85802 .34901 m
.858 .34927 L
s
.20246 .51271 m
.20214 .51241 L
s
.22543 .59658 m
.2251 .59631 L
s
.5797 .50391 m
.5792 .50424 L
s
.57979 .50389 m
.57929 .50422 L
s
.32557 .50725 m
.325 .50692 L
s
.68874 .49427 m
.68848 .49459 L
s
.32534 .50715 m
.32477 .50682 L
s
.68884 .49417 m
.68858 .4945 L
s
.57999 .50373 m
.57949 .50407 L
s
.85804 .34874 m
.85802 .34901 L
s
.20225 .51248 m
.20194 .51218 L
s
.58001 .50371 m
.57951 .50404 L
s
.32531 .50702 m
.32474 .50668 L
s
.20214 .51241 m
.20183 .51211 L
s
.5802 .50358 m
.5797 .50391 L
s
.58029 .50355 m
.57979 .50389 L
s
.2251 .59631 m
.22477 .59605 L
s
.68901 .49394 m
.68874 .49427 L
s
.325 .50692 m
.32443 .50658 L
s
.85806 .34847 m
.85804 .34874 L
s
.6891 .49384 m
.68884 .49417 L
s
.32477 .50682 m
.3242 .50647 L
s
.58049 .5034 m
.57999 .50373 L
s
.20194 .51218 m
.20163 .51188 L
s
.58051 .50338 m
.58001 .50371 L
s
.20183 .51211 m
.20152 .51181 L
s
.32474 .50668 m
.32417 .50634 L
s
.5807 .50324 m
.5802 .50358 L
s
.85808 .34821 m
.85806 .34847 L
s
.58079 .50322 m
.58029 .50355 L
s
.68927 .49361 m
.68901 .49394 L
s
.32443 .50658 m
.32387 .50624 L
s
.22477 .59605 m
.22444 .59578 L
s
.68936 .49352 m
.6891 .49384 L
s
.58099 .50307 m
.58049 .5034 L
s
.3242 .50647 m
.32364 .50613 L
s
.20163 .51188 m
.20132 .51158 L
s
.58101 .50304 m
.58051 .50338 L
s
.8581 .34794 m
.85808 .34821 L
s
.20152 .51181 m
.20121 .51151 L
s
.32417 .50634 m
.32361 .506 L
s
.5812 .50291 m
.5807 .50324 L
s
.58129 .50289 m
.58079 .50322 L
s
.68953 .49329 m
.68927 .49361 L
s
.32387 .50624 m
.32331 .50589 L
s
.22444 .59578 m
.22412 .59551 L
s
.68962 .49319 m
.68936 .49352 L
s
.85811 .34768 m
.8581 .34794 L
s
.58149 .50273 m
.58099 .50307 L
s
.20132 .51158 m
.20101 .51128 L
s
.32364 .50613 m
.32308 .50579 L
s
.5815 .50271 m
.58101 .50304 L
s
.20121 .51151 m
.20091 .5112 L
s
.32361 .506 m
.32305 .50566 L
s
.58169 .50257 m
.5812 .50291 L
s
.58178 .50255 m
.58129 .50289 L
s
.68978 .49296 m
.68953 .49329 L
s
.85813 .34741 m
.85811 .34768 L
s
.32331 .50589 m
.32275 .50555 L
s
.22412 .59551 m
.22379 .59524 L
s
.68988 .49286 m
.68962 .49319 L
s
.58198 .50239 m
.58149 .50273 L
s
.20101 .51128 m
.20071 .51098 L
s
.582 .50237 m
.5815 .50271 L
s
.32308 .50579 m
.32252 .50545 L
s
.20091 .5112 m
.2006 .5109 L
s
.85815 .34714 m
.85813 .34741 L
s
.58218 .50223 m
.58169 .50257 L
s
.32305 .50566 m
.32249 .50531 L
s
.58228 .50221 m
.58178 .50255 L
s
.69004 .49263 m
.68978 .49296 L
s
.32275 .50555 m
.32219 .5052 L
s
.69013 .49253 m
.68988 .49286 L
s
.22379 .59524 m
.22346 .59498 L
s
.20071 .51098 m
.2004 .51067 L
s
.58247 .50205 m
.58198 .50239 L
s
.58249 .50203 m
.582 .50237 L
s
.85817 .34688 m
.85815 .34714 L
s
.32252 .50545 m
.32197 .5051 L
s
.2006 .5109 m
.20029 .5106 L
s
.58267 .5019 m
.58218 .50223 L
s
.58277 .50187 m
.58228 .50221 L
s
.32249 .50531 m
.32193 .50496 L
s
.6903 .4923 m
.69004 .49263 L
s
.85818 .34661 m
.85817 .34688 L
s
.69039 .4922 m
.69013 .49253 L
s
.32219 .5052 m
.32163 .50486 L
s
.2004 .51067 m
.2001 .51037 L
s
.58296 .50171 m
.58247 .50205 L
s
.22346 .59498 m
.22314 .59471 L
s
.58298 .50169 m
.58249 .50203 L
s
.20029 .5106 m
.19999 .5103 L
s
.32197 .5051 m
.32141 .50475 L
s
.58316 .50156 m
.58267 .5019 L
s
.58325 .50153 m
.58277 .50187 L
s
.8582 .34635 m
.85818 .34661 L
s
.69055 .49197 m
.6903 .4923 L
s
.32193 .50496 m
.32138 .50462 L
s
.69064 .49187 m
.69039 .4922 L
s
.2001 .51037 m
.19979 .51007 L
s
.32163 .50486 m
.32108 .50451 L
s
.58344 .50137 m
.58296 .50171 L
s
.58346 .50135 m
.58298 .50169 L
s
.22314 .59471 m
.22281 .59444 L
s
.19999 .5103 m
.19969 .50999 L
s
.85821 .34608 m
.8582 .34635 L
s
.32141 .50475 m
.32086 .5044 L
s
.58364 .50121 m
.58316 .50156 L
s
.58374 .50119 m
.58325 .50153 L
s
.69081 .49164 m
.69055 .49197 L
s
.32138 .50462 m
.32083 .50427 L
s
.69089 .49154 m
.69064 .49187 L
s
.19979 .51007 m
.19949 .50976 L
s
.85823 .34582 m
.85821 .34608 L
s
.58393 .50103 m
.58344 .50137 L
s
.32108 .50451 m
.32053 .50416 L
s
.58394 .50101 m
.58346 .50135 L
s
.19969 .50999 m
.19938 .50969 L
s
.22281 .59444 m
.22249 .59417 L
s
.32086 .5044 m
.32031 .50405 L
s
.58413 .50087 m
.58364 .50121 L
s
.58422 .50085 m
.58374 .50119 L
s
.69106 .49131 m
.69081 .49164 L
s
.85824 .34555 m
.85823 .34582 L
s
.32083 .50427 m
.32028 .50391 L
s
.69115 .49121 m
.69089 .49154 L
s
.19949 .50976 m
.19919 .50946 L
s
.58441 .50069 m
.58393 .50103 L
s
.58442 .50066 m
.58394 .50101 L
s
.32053 .50416 m
.31999 .5038 L
s
.19938 .50969 m
.19908 .50938 L
s
.22249 .59417 m
.22217 .59389 L
s
.85826 .34529 m
.85824 .34555 L
s
.32031 .50405 m
.31977 .5037 L
s
.5846 .50053 m
.58413 .50087 L
s
.5847 .5005 m
.58422 .50085 L
s
.69131 .49098 m
.69106 .49131 L
s
.32028 .50391 m
.31974 .50356 L
s
.6914 .49088 m
.69115 .49121 L
s
.19919 .50946 m
.19889 .50915 L
s
.58488 .50034 m
.58441 .50069 L
s
.85827 .34502 m
.85826 .34529 L
s
.5849 .50032 m
.58442 .50066 L
s
.19908 .50938 m
.19878 .50908 L
s
.31999 .5038 m
.31944 .50345 L
s
.22217 .59389 m
.22184 .59362 L
s
.58508 .50018 m
.5846 .50053 L
s
.31977 .5037 m
.31922 .50334 L
s
.58518 .50016 m
.5847 .5005 L
s
.69156 .49065 m
.69131 .49098 L
s
.85828 .34476 m
.85827 .34502 L
s
.19889 .50915 m
.19859 .50885 L
s
.69165 .49055 m
.6914 .49088 L
s
.31974 .50356 m
.31919 .50321 L
s
.58536 .5 m
.58488 .50034 L
s
.19878 .50908 m
.19848 .50877 L
s
.58538 .49997 m
.5849 .50032 L
s
.31944 .50345 m
.3189 .5031 L
s
.58556 .49983 m
.58508 .50018 L
s
.8583 .34449 m
.85828 .34476 L
s
.22184 .59362 m
.22152 .59335 L
s
.69181 .49032 m
.69156 .49065 L
s
.58565 .49981 m
.58518 .50016 L
s
.31922 .50334 m
.31868 .50299 L
s
.19859 .50885 m
.19829 .50854 L
s
.69189 .49022 m
.69165 .49055 L
s
.31919 .50321 m
.31865 .50285 L
s
.58583 .49965 m
.58536 .5 L
s
.19848 .50877 m
.19818 .50847 L
s
.58585 .49963 m
.58538 .49997 L
s
.85831 .34423 m
.8583 .34449 L
s
.3189 .5031 m
.31836 .50274 L
s
.58603 .49949 m
.58556 .49983 L
s
.69205 .48999 m
.69181 .49032 L
s
.58612 .49947 m
.58565 .49981 L
s
.22152 .59335 m
.2212 .59307 L
s
.31868 .50299 m
.31814 .50263 L
s
.19829 .50854 m
.19799 .50823 L
s
.69214 .48989 m
.69189 .49022 L
s
.85832 .34396 m
.85831 .34423 L
s
.19818 .50847 m
.19789 .50816 L
s
.31865 .50285 m
.31812 .50249 L
s
.5863 .4993 m
.58583 .49965 L
s
.58632 .49928 m
.58585 .49963 L
s
.31836 .50274 m
.31782 .50238 L
s
.6923 .48966 m
.69205 .48999 L
s
.5865 .49914 m
.58603 .49949 L
s
.58659 .49912 m
.58612 .49947 L
s
.85833 .3437 m
.85832 .34396 L
s
.2212 .59307 m
.22088 .5928 L
s
.31814 .50263 m
.31761 .50227 L
s
.19799 .50823 m
.1977 .50793 L
s
.69239 .48956 m
.69214 .48989 L
s
.19789 .50816 m
.19759 .50785 L
s
.58677 .49895 m
.5863 .4993 L
s
.31812 .50249 m
.31758 .50213 L
s
.58679 .49893 m
.58632 .49928 L
s
.85834 .34343 m
.85833 .3437 L
s
.31782 .50238 m
.31729 .50202 L
s
.69255 .48932 m
.6923 .48966 L
s
.58696 .49879 m
.5865 .49914 L
s
.58706 .49877 m
.58659 .49912 L
s
.1977 .50793 m
.1974 .50762 L
s
.22088 .5928 m
.22056 .59253 L
s
.69263 .48923 m
.69239 .48956 L
s
.31761 .50227 m
.31707 .50191 L
s
.19759 .50785 m
.1973 .50755 L
s
.85835 .34317 m
.85834 .34343 L
s
.58724 .4986 m
.58677 .49895 L
s
.58726 .49858 m
.58679 .49893 L
s
.31758 .50213 m
.31705 .50177 L
s
.69279 .48899 m
.69255 .48932 L
s
.58743 .49844 m
.58696 .49879 L
s
.31729 .50202 m
.31676 .50166 L
s
.58752 .49842 m
.58706 .49877 L
s
.1974 .50762 m
.19711 .50731 L
s
.85836 .3429 m
.85835 .34317 L
s
.69288 .48889 m
.69263 .48923 L
s
.22056 .59253 m
.22025 .59225 L
s
.31707 .50191 m
.31654 .50155 L
s
.1973 .50755 m
.197 .50724 L
s
.5877 .49825 m
.58724 .4986 L
s
.58772 .49823 m
.58726 .49858 L
s
.31705 .50177 m
.31652 .50141 L
s
.85837 .34264 m
.85836 .3429 L
s
.69303 .48866 m
.69279 .48899 L
s
.58789 .49808 m
.58743 .49844 L
s
.58799 .49806 m
.58752 .49842 L
s
.31676 .50166 m
.31623 .5013 L
s
.19711 .50731 m
.19681 .507 L
s
.69312 .48856 m
.69288 .48889 L
s
.197 .50724 m
.19671 .50693 L
s
.22025 .59225 m
.21993 .59197 L
s
.31654 .50155 m
.31602 .50119 L
s
.58816 .49789 m
.5877 .49825 L
s
.85838 .34237 m
.85837 .34264 L
s
.58818 .49787 m
.58772 .49823 L
s
.31652 .50141 m
.31599 .50105 L
s
.69327 .48833 m
.69303 .48866 L
s
.58835 .49773 m
.58789 .49808 L
s
.58845 .49771 m
.58799 .49806 L
s
.19681 .507 m
.19652 .5067 L
s
.31623 .5013 m
.3157 .50093 L
s
.69336 .48823 m
.69312 .48856 L
s
.85839 .34211 m
.85838 .34237 L
s
.19671 .50693 m
.19642 .50662 L
s
.21993 .59197 m
.21961 .59169 L
s
.31602 .50119 m
.31549 .50082 L
s
.58862 .49754 m
.58816 .49789 L
s
.58864 .49752 m
.58818 .49787 L
s
.69351 .48799 m
.69327 .48833 L
s
.31599 .50105 m
.31547 .50068 L
s
.8584 .34184 m
.85839 .34211 L
s
.19652 .5067 m
.19623 .50639 L
s
.58881 .49737 m
.58835 .49773 L
s
.5889 .49736 m
.58845 .49771 L
s
.6936 .48789 m
.69336 .48823 L
s
.3157 .50093 m
.31518 .50057 L
s
.19642 .50662 m
.19613 .50631 L
s
.21961 .59169 m
.2193 .59142 L
s
.31549 .50082 m
.31497 .50046 L
s
.58907 .49718 m
.58862 .49754 L
s
.58909 .49716 m
.58864 .49752 L
s
.8584 .34158 m
.8584 .34184 L
s
.69375 .48766 m
.69351 .48799 L
s
.31547 .50068 m
.31494 .50031 L
s
.19623 .50639 m
.19594 .50608 L
s
.58926 .49702 m
.58881 .49737 L
s
.58936 .497 m
.5889 .49736 L
s
.69384 .48756 m
.6936 .48789 L
s
.19613 .50631 m
.19584 .506 L
s
.31518 .50057 m
.31466 .5002 L
s
.85841 .34131 m
.8584 .34158 L
s
.2193 .59142 m
.21898 .59114 L
s
.58952 .49683 m
.58907 .49718 L
s
.31497 .50046 m
.31445 .50009 L
s
.58955 .49681 m
.58909 .49716 L
s
.69399 .48732 m
.69375 .48766 L
s
.19594 .50608 m
.19565 .50577 L
s
.31494 .50031 m
.31442 .49995 L
s
.58971 .49666 m
.58926 .49702 L
s
.85842 .34105 m
.85841 .34131 L
s
.69407 .48722 m
.69384 .48756 L
s
.58981 .49664 m
.58936 .497 L
s
.19584 .506 m
.19555 .50569 L
s
.31466 .5002 m
.31414 .49983 L
s
.58997 .49647 m
.58952 .49683 L
s
.21898 .59114 m
.21867 .59086 L
s
.59 .49645 m
.58955 .49681 L
s
.31445 .50009 m
.31393 .49972 L
s
.85842 .34078 m
.85842 .34105 L
s
.69423 .48699 m
.69399 .48732 L
s
.19565 .50577 m
.19537 .50546 L
s
.69431 .48689 m
.69407 .48722 L
s
.59016 .4963 m
.58971 .49666 L
s
.59026 .49628 m
.58981 .49664 L
s
.31442 .49995 m
.31391 .49958 L
s
.19555 .50569 m
.19527 .50538 L
s
.85843 .34052 m
.85842 .34078 L
s
.31414 .49983 m
.31362 .49946 L
s
.59042 .49611 m
.58997 .49647 L
s
.59044 .49609 m
.59 .49645 L
s
.21867 .59086 m
.21836 .59058 L
s
.69446 .48665 m
.69423 .48699 L
s
.31393 .49972 m
.31342 .49935 L
s
.19537 .50546 m
.19508 .50515 L
s
.69455 .48655 m
.69431 .48689 L
s
.59061 .49594 m
.59016 .4963 L
s
.19527 .50538 m
.19498 .50507 L
s
.5907 .49592 m
.59026 .49628 L
s
.85843 .34025 m
.85843 .34052 L
s
.31391 .49958 m
.31339 .4992 L
s
.31362 .49946 m
.31311 .49909 L
s
.59087 .49575 m
.59042 .49611 L
s
.59089 .49573 m
.59044 .49609 L
s
.6947 .48632 m
.69446 .48665 L
s
.21836 .59058 m
.21804 .5903 L
s
.19508 .50515 m
.1948 .50484 L
s
.85844 .33999 m
.85843 .34025 L
s
.31342 .49935 m
.3129 .49898 L
s
.69478 .48622 m
.69455 .48655 L
s
.19498 .50507 m
.1947 .50476 L
s
.59105 .49558 m
.59061 .49594 L
s
.59115 .49556 m
.5907 .49592 L
s
.31339 .4992 m
.31288 .49883 L
s
.85844 .33973 m
.85844 .33999 L
s
.31311 .49909 m
.3126 .49872 L
s
.59131 .49539 m
.59087 .49575 L
s
.69493 .48598 m
.6947 .48632 L
s
.59133 .49537 m
.59089 .49573 L
s
.1948 .50484 m
.19451 .50452 L
s
.21804 .5903 m
.21773 .59001 L
s
.3129 .49898 m
.31239 .4986 L
s
.69501 .48588 m
.69478 .48622 L
s
.1947 .50476 m
.19441 .50445 L
s
.59149 .49522 m
.59105 .49558 L
s
.59159 .4952 m
.59115 .49556 L
s
.85844 .33946 m
.85844 .33973 L
s
.31288 .49883 m
.31237 .49846 L
s
.69516 .48565 m
.69493 .48598 L
s
.59175 .49503 m
.59131 .49539 L
s
.3126 .49872 m
.31209 .49834 L
s
.19451 .50452 m
.19423 .50421 L
s
.59177 .49501 m
.59133 .49537 L
s
.21773 .59001 m
.21742 .58973 L
s
.85845 .3392 m
.85844 .33946 L
s
.69524 .48555 m
.69501 .48588 L
s
.19441 .50445 m
.19413 .50414 L
s
.31239 .4986 m
.31189 .49823 L
s
.59193 .49486 m
.59149 .49522 L
s
.59203 .49484 m
.59159 .4952 L
s
.31237 .49846 m
.31187 .49808 L
s
.85845 .33893 m
.85845 .3392 L
s
.69539 .48531 m
.69516 .48565 L
s
.19423 .50421 m
.19395 .5039 L
s
.59219 .49466 m
.59175 .49503 L
s
.59221 .49464 m
.59177 .49501 L
s
.31209 .49834 m
.31159 .49797 L
s
.19413 .50414 m
.19385 .50383 L
s
.69547 .48521 m
.69524 .48555 L
s
.21742 .58973 m
.21711 .58945 L
s
.31189 .49823 m
.31138 .49785 L
s
.59237 .49449 m
.59193 .49486 L
s
.59247 .49448 m
.59203 .49484 L
s
.85845 .33867 m
.85845 .33893 L
s
.31187 .49808 m
.31136 .49771 L
s
.69562 .48497 m
.69539 .48531 L
s
.19395 .5039 m
.19367 .50359 L
s
.59262 .4943 m
.59219 .49466 L
s
.59264 .49428 m
.59221 .49464 L
s
.19385 .50383 m
.19357 .50351 L
s
.6957 .48487 m
.69547 .48521 L
s
.31159 .49797 m
.31109 .49759 L
s
.85845 .3384 m
.85845 .33867 L
s
.21711 .58945 m
.2168 .58916 L
s
.5928 .49413 m
.59237 .49449 L
s
.5929 .49411 m
.59247 .49448 L
s
.31138 .49785 m
.31088 .49747 L
s
.69585 .48464 m
.69562 .48497 L
s
.19367 .50359 m
.19339 .50327 L
s
.31136 .49771 m
.31086 .49733 L
s
.85845 .33814 m
.85845 .3384 L
s
.59305 .49393 m
.59262 .4943 L
s
.59307 .49391 m
.59264 .49428 L
s
.19357 .50351 m
.19329 .5032 L
s
.69593 .48454 m
.6957 .48487 L
s
.31109 .49759 m
.31059 .49721 L
s
.2168 .58916 m
.21649 .58888 L
s
.59323 .49376 m
.5928 .49413 L
s
.59333 .49374 m
.5929 .49411 L
s
.31088 .49747 m
.31038 .49709 L
s
.85845 .33788 m
.85845 .33814 L
s
.69608 .4843 m
.69585 .48464 L
s
.19339 .50327 m
.19311 .50296 L
s
.31086 .49733 m
.31037 .49695 L
s
.19329 .5032 m
.19301 .50289 L
s
.59348 .49356 m
.59305 .49393 L
s
.69616 .4842 m
.69593 .48454 L
s
.5935 .49354 m
.59307 .49391 L
s
.85845 .33761 m
.85845 .33788 L
s
.31059 .49721 m
.31009 .49683 L
s
.21649 .58888 m
.21619 .58859 L
s
.59366 .49339 m
.59323 .49376 L
s
.59376 .49338 m
.59333 .49374 L
s
.31038 .49709 m
.30989 .49671 L
s
.19311 .50296 m
.19283 .50265 L
s
.6963 .48396 m
.69608 .4843 L
s
.19301 .50289 m
.19273 .50257 L
s
.85845 .33735 m
.85845 .33761 L
s
.69638 .48386 m
.69616 .4842 L
s
.59391 .4932 m
.59348 .49356 L
s
.31037 .49695 m
.30987 .49657 L
s
.59393 .49318 m
.5935 .49354 L
s
.21619 .58859 m
.21588 .5883 L
s
.31009 .49683 m
.3096 .49645 L
s
.59409 .49302 m
.59366 .49339 L
s
.59418 .49301 m
.59376 .49338 L
s
.85845 .33709 m
.85845 .33735 L
s
.19283 .50265 m
.19256 .50233 L
s
.69653 .48362 m
.6963 .48396 L
s
.30989 .49671 m
.3094 .49633 L
s
.19273 .50257 m
.19246 .50226 L
s
.6966 .48352 m
.69638 .48386 L
s
.59433 .49283 m
.59391 .4932 L
s
.59436 .49281 m
.59393 .49318 L
s
.30987 .49657 m
.30938 .49618 L
s
.85845 .33682 m
.85845 .33709 L
s
.21588 .5883 m
.21558 .58802 L
s
.3096 .49645 m
.30911 .49607 L
s
.59451 .49265 m
.59409 .49302 L
s
.59461 .49264 m
.59418 .49301 L
s
.19256 .50233 m
.19228 .50202 L
s
.69675 .48328 m
.69653 .48362 L
s
.19246 .50226 m
.19218 .50194 L
s
.3094 .49633 m
.30891 .49595 L
s
.69683 .48318 m
.6966 .48352 L
s
.85845 .33656 m
.85845 .33682 L
s
.59475 .49246 m
.59433 .49283 L
s
.59478 .49244 m
.59436 .49281 L
s
.30938 .49618 m
.30889 .4958 L
s
.21558 .58802 m
.21527 .58773 L
s
.19228 .50202 m
.19201 .5017 L
s
.59493 .49228 m
.59451 .49265 L
s
.59503 .49227 m
.59461 .49264 L
s
.30911 .49607 m
.30862 .49568 L
s
.69697 .48294 m
.69675 .48328 L
s
.85845 .33629 m
.85845 .33656 L
s
.19218 .50194 m
.19191 .50163 L
s
.69705 .48284 m
.69683 .48318 L
s
.30891 .49595 m
.30842 .49556 L
s
.59517 .49208 m
.59475 .49246 L
s
.5952 .49206 m
.59478 .49244 L
s
.30889 .4958 m
.3084 .49541 L
s
.85844 .33603 m
.85845 .33629 L
s
.19201 .5017 m
.19174 .50138 L
s
.21527 .58773 m
.21497 .58744 L
s
.69719 .4826 m
.69697 .48294 L
s
.59535 .49191 m
.59493 .49228 L
s
.59545 .4919 m
.59503 .49227 L
s
.30862 .49568 m
.30813 .4953 L
s
.19191 .50163 m
.19164 .50131 L
s
.69727 .48251 m
.69705 .48284 L
s
.30842 .49556 m
.30793 .49518 L
s
.85844 .33577 m
.85844 .33603 L
s
.59559 .49171 m
.59517 .49208 L
s
.59561 .49169 m
.5952 .49206 L
s
.3084 .49541 m
.30792 .49503 L
s
.19174 .50138 m
.19146 .50107 L
s
.69741 .48227 m
.69719 .4826 L
s
.21497 .58744 m
.21467 .58715 L
s
.59576 .49154 m
.59535 .49191 L
s
.59586 .49152 m
.59545 .4919 L
s
.19164 .50131 m
.19137 .50099 L
s
.85843 .3355 m
.85844 .33577 L
s
.30813 .4953 m
.30765 .49491 L
s
.69749 .48217 m
.69727 .48251 L
s
.30793 .49518 m
.30745 .49479 L
s
.596 .49134 m
.59559 .49171 L
s
.59602 .49132 m
.59561 .49169 L
s
.19146 .50107 m
.19119 .50075 L
s
.85843 .33524 m
.85843 .3355 L
s
.69763 .48193 m
.69741 .48227 L
s
.30792 .49503 m
.30744 .49464 L
s
.19137 .50099 m
.1911 .50068 L
s
.21467 .58715 m
.21436 .58686 L
s
.59618 .49116 m
.59576 .49154 L
s
.59627 .49115 m
.59586 .49152 L
s
.6977 .48183 m
.69749 .48217 L
s
.30765 .49491 m
.30717 .49452 L
s
.85842 .33498 m
.85843 .33524 L
s
.59641 .49096 m
.596 .49134 L
s
.30745 .49479 m
.30697 .4944 L
s
.59644 .49094 m
.59602 .49132 L
s
.19119 .50075 m
.19093 .50043 L
s
.69785 .48158 m
.69763 .48193 L
s
.1911 .50068 m
.19083 .50036 L
s
.30744 .49464 m
.30696 .49425 L
s
.59658 .49079 m
.59618 .49116 L
s
.21436 .58686 m
.21406 .58657 L
s
.59668 .49077 m
.59627 .49115 L
s
.69792 .48148 m
.6977 .48183 L
s
.85842 .33471 m
.85842 .33498 L
s
.30717 .49452 m
.30669 .49413 L
s
.59682 .49059 m
.59641 .49096 L
s
.19093 .50043 m
.19066 .50012 L
s
.59684 .49057 m
.59644 .49094 L
s
.30697 .4944 m
.3065 .49401 L
s
.69806 .48124 m
.69785 .48158 L
s
.85841 .33445 m
.85842 .33471 L
s
.19083 .50036 m
.19056 .50004 L
s
.69814 .48114 m
.69792 .48148 L
s
.59699 .49041 m
.59658 .49079 L
s
.21406 .58657 m
.21376 .58628 L
s
.59709 .4904 m
.59668 .49077 L
s
.30696 .49425 m
.30648 .49386 L
s
.30669 .49413 m
.30622 .49374 L
s
.85841 .33419 m
.85841 .33445 L
s
.19066 .50012 m
.19039 .4998 L
s
.59722 .49021 m
.59682 .49059 L
s
.59725 .49019 m
.59684 .49057 L
s
.69828 .4809 m
.69806 .48124 L
s
.3065 .49401 m
.30602 .49362 L
s
.19056 .50004 m
.19029 .49973 L
s
.69835 .4808 m
.69814 .48114 L
s
.5974 .49004 m
.59699 .49041 L
s
.21376 .58628 m
.21346 .58598 L
s
.59749 .49002 m
.59709 .4904 L
s
.8584 .33392 m
.85841 .33419 L
s
.30648 .49386 m
.30601 .49347 L
s
.19039 .4998 m
.19012 .49948 L
s
.30622 .49374 m
.30575 .49335 L
s
.59763 .48983 m
.59722 .49021 L
s
.69849 .48056 m
.69828 .4809 L
s
.59765 .48981 m
.59725 .49019 L
s
.19029 .49973 m
.19003 .49941 L
s
.85839 .33366 m
.8584 .33392 L
s
.30602 .49362 m
.30555 .49323 L
s
.69856 .48046 m
.69835 .4808 L
s
.5978 .48966 m
.5974 .49004 L
s
.5979 .48964 m
.59749 .49002 L
s
.21346 .58598 m
.21316 .58569 L
s
.30601 .49347 m
.30554 .49307 L
s
.19012 .49948 m
.18986 .49916 L
s
.85838 .3334 m
.85839 .33366 L
s
.6987 .48022 m
.69849 .48056 L
s
.30575 .49335 m
.30528 .49295 L
s
.59803 .48945 m
.59763 .48983 L
s
.19003 .49941 m
.18976 .49909 L
s
.59805 .48943 m
.59765 .48981 L
s
.69877 .48012 m
.69856 .48046 L
s
.30555 .49323 m
.30509 .49283 L
s
.5982 .48928 m
.5978 .48966 L
s
.59829 .48926 m
.5979 .48964 L
s
.85837 .33313 m
.85838 .3334 L
s
.21316 .58569 m
.21287 .5854 L
s
.18986 .49916 m
.1896 .49884 L
s
.30554 .49307 m
.30508 .49268 L
s
.69891 .47988 m
.6987 .48022 L
s
.18976 .49909 m
.1895 .49877 L
s
.59842 .48907 m
.59803 .48945 L
s
.30528 .49295 m
.30481 .49256 L
s
.59845 .48905 m
.59805 .48943 L
s
.85837 .33287 m
.85837 .33313 L
s
.69898 .47978 m
.69877 .48012 L
s
.30509 .49283 m
.30462 .49244 L
s
.59859 .4889 m
.5982 .48928 L
s
.59869 .48888 m
.59829 .48926 L
s
.21287 .5854 m
.21257 .5851 L
s
.1896 .49884 m
.18933 .49852 L
s
.30508 .49268 m
.30461 .49228 L
s
.85836 .33261 m
.85837 .33287 L
s
.69912 .47954 m
.69891 .47988 L
s
.1895 .49877 m
.18924 .49845 L
s
.59882 .48869 m
.59842 .48907 L
s
.59884 .48867 m
.59845 .48905 L
s
.69919 .47944 m
.69898 .47978 L
s
.30481 .49256 m
.30435 .49216 L
s
.30462 .49244 m
.30416 .49204 L
s
.85835 .33235 m
.85836 .33261 L
s
.59899 .48851 m
.59859 .4889 L
s
.59908 .4885 m
.59869 .48888 L
s
.18933 .49852 m
.18907 .4982 L
s
.21257 .5851 m
.21227 .58481 L
s
.69933 .47919 m
.69912 .47954 L
s
.18924 .49845 m
.18898 .49813 L
s
.30461 .49228 m
.30415 .49188 L
s
.6994 .47909 m
.69919 .47944 L
s
.59921 .48831 m
.59882 .48869 L
s
.59924 .48829 m
.59884 .48867 L
s
.85833 .33208 m
.85835 .33235 L
s
.30435 .49216 m
.30389 .49176 L
s
.18907 .4982 m
.18881 .49788 L
s
.59938 .48813 m
.59899 .48851 L
s
.59947 .48812 m
.59908 .4885 L
s
.30416 .49204 m
.3037 .49164 L
s
.21227 .58481 m
.21198 .58451 L
s
.18898 .49813 m
.18872 .49781 L
s
.69953 .47885 m
.69933 .47919 L
s
.85832 .33182 m
.85833 .33208 L
s
.30415 .49188 m
.30369 .49148 L
s
.69961 .47875 m
.6994 .47909 L
s
.5996 .48793 m
.59921 .48831 L
s
.44581 .48951 m
.44466 .48957 L
s
.44695 .48944 m
.44581 .48951 L
s
.44466 .48957 m
.44352 .48962 L
s
.59962 .48791 m
.59924 .48829 L
s
.44808 .48936 m
.44695 .48944 L
s
.44352 .48962 m
.44238 .48966 L
s
.44922 .48928 m
.44808 .48936 L
s
.44529 .48952 m
.44415 .48958 L
s
.44643 .48946 m
.44529 .48952 L
s
.44238 .48966 m
.44124 .4897 L
s
.44757 .48938 m
.44643 .48946 L
s
.44415 .48958 m
.44301 .48963 L
s
.44871 .4893 m
.44757 .48938 L
s
.44301 .48963 m
.44187 .48966 L
s
.45036 .48918 m
.44922 .48928 L
s
.44491 .48953 m
.44377 .48959 L
s
.44605 .48947 m
.44491 .48953 L
s
.44719 .4894 m
.44605 .48947 L
s
.44517 .48949 m
.44403 .48954 L
s
.44631 .48942 m
.44517 .48949 L
s
.44124 .4897 m
.4401 .48972 L
s
.44745 .48935 m
.44631 .48942 L
s
.44377 .48959 m
.44262 .48963 L
s
.44833 .48932 m
.44719 .4894 L
s
.44403 .48954 m
.44289 .48959 L
s
.44579 .48949 m
.44465 .48954 L
s
.44693 .48942 m
.44579 .48949 L
s
.44985 .48921 m
.44871 .4893 L
s
.44465 .48954 m
.44351 .4896 L
s
.44807 .48934 m
.44693 .48942 L
s
.44593 .48945 m
.44478 .48951 L
s
.44707 .48938 m
.44593 .48945 L
s
.44478 .48951 m
.44364 .48956 L
s
.44859 .48927 m
.44745 .48935 L
s
.44187 .48966 m
.44073 .48969 L
s
.44351 .4896 m
.44236 .48964 L
s
.44563 .48947 m
.44448 .48953 L
s
.44677 .4894 m
.44563 .48947 L
s
.30389 .49176 m
.30344 .49136 L
s
.44262 .48963 m
.44148 .48967 L
s
.44947 .48923 m
.44833 .48932 L
s
.44289 .48959 m
.44174 .48963 L
s
.44821 .4893 m
.44707 .48938 L
s
.44448 .48953 m
.44334 .48958 L
s
.44364 .48956 m
.4425 .4896 L
s
.44791 .48933 m
.44677 .4894 L
s
.45149 .48908 m
.45036 .48918 L
s
.44921 .48925 m
.44807 .48934 L
s
.44973 .48918 m
.44859 .48927 L
s
.44334 .48958 m
.4422 .48962 L
s
.45098 .48911 m
.44985 .48921 L
s
.4401 .48972 m
.43896 .48974 L
s
.44236 .48964 m
.44122 .48967 L
s
.44934 .48921 m
.44821 .4893 L
s
.44905 .48924 m
.44791 .48933 L
s
.4425 .4896 m
.44136 .48964 L
s
.44174 .48963 m
.4406 .48966 L
s
.44073 .48969 m
.43959 .48971 L
s
.44148 .48967 m
.44034 .48969 L
s
.18881 .49788 m
.18856 .49756 L
s
.4506 .48914 m
.44947 .48923 L
s
.44578 .48946 m
.44464 .48951 L
s
.44692 .48939 m
.44578 .48946 L
s
.44464 .48951 m
.4435 .48956 L
s
.45034 .48916 m
.44921 .48925 L
s
.44806 .48931 m
.44692 .48939 L
s
.4422 .48962 m
.44106 .48965 L
s
.44552 .48945 m
.44438 .4895 L
s
.44666 .48938 m
.44552 .48945 L
s
.4435 .48956 m
.44235 .48961 L
s
.45087 .48908 m
.44973 .48918 L
s
.45018 .48915 m
.44905 .48924 L
s
.45048 .48912 m
.44934 .48921 L
s
.44438 .4895 m
.44323 .48955 L
s
.4478 .4893 m
.44666 .48938 L
s
.44122 .48967 m
.44008 .48969 L
s
.44136 .48964 m
.44022 .48966 L
s
.44603 .48943 m
.44488 .48949 L
s
.44717 .48936 m
.44603 .48943 L
s
.45263 .48896 m
.45149 .48908 L
s
.44488 .48949 m
.44374 .48954 L
s
.4492 .48922 m
.44806 .48931 L
s
.45212 .489 m
.45098 .48911 L
s
.44831 .48928 m
.44717 .48936 L
s
.85831 .33156 m
.85832 .33182 L
s
.4406 .48966 m
.43946 .48968 L
s
.44323 .48955 m
.44209 .48959 L
s
.44374 .48954 m
.4426 .48959 L
s
.44894 .48922 m
.4478 .4893 L
s
.44034 .48969 m
.4392 .48971 L
s
.44564 .48943 m
.4445 .48949 L
s
.44679 .48936 m
.44564 .48943 L
s
.44235 .48961 m
.44121 .48964 L
s
.45174 .48903 m
.4506 .48914 L
s
.43896 .48974 m
.43782 .48974 L
s
.44106 .48965 m
.43992 .48967 L
s
.4445 .48949 m
.44336 .48954 L
s
.43959 .48971 m
.43845 .48973 L
s
.45148 .48905 m
.45034 .48916 L
s
.44793 .48929 m
.44679 .48936 L
s
.44945 .4892 m
.44831 .48928 L
s
.45034 .48913 m
.4492 .48922 L
s
.45132 .48904 m
.45018 .48915 L
s
.44336 .48954 m
.44222 .48958 L
s
.4426 .48959 m
.44146 .48962 L
s
.44209 .48959 m
.44095 .48962 L
s
.45162 .48901 m
.45048 .48912 L
s
.44907 .4892 m
.44793 .48929 L
s
.452 .48897 m
.45087 .48908 L
s
.45008 .48913 m
.44894 .48922 L
s
.44022 .48966 m
.43908 .48968 L
s
.44008 .48969 m
.43894 .48971 L
s
.59976 .48775 m
.59938 .48813 L
s
.44121 .48964 m
.44007 .48966 L
s
.59986 .48774 m
.59947 .48812 L
s
.43946 .48968 m
.43832 .48969 L
s
.44222 .48958 m
.44107 .48961 L
s
.45058 .4891 m
.44945 .4892 L
s
.45376 .48884 m
.45263 .48896 L
s
.21198 .58451 m
.21169 .58421 L
s
.43992 .48967 m
.43877 .48969 L
s
.45325 .48888 m
.45212 .489 L
s
.45021 .48911 m
.44907 .4892 L
s
.4392 .48971 m
.43806 .48972 L
s
.44146 .48962 m
.44032 .48965 L
s
.45287 .48892 m
.45174 .48903 L
s
.45147 .48903 m
.45034 .48913 L
s
.18872 .49781 m
.18846 .49749 L
s
.45261 .48894 m
.45148 .48905 L
s
.44095 .48962 m
.43981 .48965 L
s
.45122 .48903 m
.45008 .48913 L
s
.43845 .48973 m
.43731 .48973 L
s
.69974 .47851 m
.69953 .47885 L
s
.45246 .48893 m
.45132 .48904 L
s
.43782 .48974 m
.43668 .48974 L
s
.45275 .4889 m
.45162 .48901 L
s
.3037 .49164 m
.30325 .49124 L
s
.44107 .48961 m
.43993 .48963 L
s
.45313 .48885 m
.452 .48897 L
s
.43908 .48968 m
.43794 .48969 L
s
.44007 .48966 m
.43893 .48968 L
s
.43894 .48971 m
.4378 .48972 L
s
.45172 .489 m
.45058 .4891 L
s
.45134 .48901 m
.45021 .48911 L
s
.44032 .48965 m
.43917 .48966 L
s
.43832 .48969 m
.43718 .48969 L
s
.45261 .48891 m
.45147 .48903 L
s
.43981 .48965 m
.43867 .48966 L
s
.43877 .48969 m
.43763 .48969 L
s
.45235 .48891 m
.45122 .48903 L
s
.43806 .48972 m
.43692 .48972 L
s
.45375 .48882 m
.45261 .48894 L
s
.454 .48879 m
.45287 .48892 L
s
.45438 .48876 m
.45325 .48888 L
s
.45489 .48871 m
.45376 .48884 L
s
.43993 .48963 m
.43879 .48965 L
s
.45359 .48881 m
.45246 .48893 L
s
.43731 .48973 m
.43617 .48972 L
s
.43893 .48968 m
.43779 .48968 L
s
.45388 .48877 m
.45275 .4889 L
s
.45285 .48888 m
.45172 .489 L
s
.45248 .4889 m
.45134 .48901 L
s
.43668 .48974 m
.43554 .48973 L
s
.43794 .48969 m
.4368 .48969 L
s
.45427 .48873 m
.45313 .48885 L
s
.4378 .48972 m
.43666 .48971 L
s
.43917 .48966 m
.43803 .48967 L
s
.43867 .48966 m
.43752 .48966 L
s
.45374 .48879 m
.45261 .48891 L
s
.45348 .48879 m
.45235 .48891 L
s
.43763 .48969 m
.43649 .48969 L
s
.43718 .48969 m
.43604 .48968 L
s
.43879 .48965 m
.43765 .48965 L
s
.43692 .48972 m
.43578 .48971 L
s
.69981 .47841 m
.69961 .47875 L
s
.45488 .48869 m
.45375 .48882 L
s
.45513 .48866 m
.454 .48879 L
s
.45551 .48862 m
.45438 .48876 L
s
.45472 .48868 m
.45359 .48881 L
s
.45361 .48877 m
.45248 .4889 L
s
.45399 .48876 m
.45285 .48888 L
s
.45602 .48857 m
.45489 .48871 L
s
.43779 .48968 m
.43665 .48968 L
s
.45502 .48864 m
.45388 .48877 L
s
.43803 .48967 m
.43689 .48967 L
s
.43617 .48972 m
.43503 .48971 L
s
.4368 .48969 m
.43566 .48968 L
s
.43666 .48971 m
.43552 .4897 L
s
.4554 .48859 m
.45427 .48873 L
s
.43554 .48973 m
.4344 .48971 L
s
.43752 .48966 m
.43638 .48966 L
s
.45487 .48866 m
.45374 .48879 L
s
.45462 .48867 m
.45348 .48879 L
s
.43649 .48969 m
.43535 .48968 L
s
.43765 .48965 m
.43651 .48965 L
s
.30369 .49148 m
.30324 .49108 L
s
.43604 .48968 m
.4349 .48967 L
s
.59998 .48754 m
.5996 .48793 L
s
.45475 .48865 m
.45361 .48877 L
s
.45601 .48855 m
.45488 .48869 L
s
.43578 .48971 m
.43464 .48969 L
s
.45512 .48863 m
.45399 .48876 L
s
.45626 .48852 m
.45513 .48866 L
s
.43665 .48968 m
.43551 .48967 L
s
.45585 .48854 m
.45472 .48868 L
s
.8583 .3313 m
.85831 .33156 L
s
.45664 .48848 m
.45551 .48862 L
s
.60001 .48752 m
.59962 .48791 L
s
.43689 .48967 m
.43575 .48966 L
s
.45714 .48842 m
.45602 .48857 L
s
.45614 .4885 m
.45502 .48864 L
s
.43566 .48968 m
.43452 .48966 L
s
.43503 .48971 m
.43389 .48968 L
s
.43638 .48966 m
.43524 .48964 L
s
.43552 .4897 m
.43438 .48968 L
s
.45652 .48845 m
.4554 .48859 L
s
.456 .48852 m
.45487 .48866 L
s
.45575 .48853 m
.45462 .48867 L
s
.4344 .48971 m
.43327 .48968 L
s
.43651 .48965 m
.43537 .48963 L
s
.43535 .48968 m
.43422 .48966 L
s
.4349 .48967 m
.43376 .48964 L
s
.45587 .48851 m
.45475 .48865 L
s
.45625 .48849 m
.45512 .48863 L
s
.18856 .49756 m
.1883 .49724 L
s
.45713 .4884 m
.45601 .48855 L
s
.43551 .48967 m
.43437 .48965 L
s
.43464 .48969 m
.43351 .48966 L
s
.45698 .4884 m
.45585 .48854 L
s
.45739 .48837 m
.45626 .48852 L
s
.43575 .48966 m
.43461 .48964 L
s
.45776 .48832 m
.45664 .48848 L
s
.45727 .48835 m
.45614 .4885 L
s
.43524 .48964 m
.43411 .48962 L
s
.43452 .48966 m
.43338 .48963 L
s
.45827 .48827 m
.45714 .48842 L
s
.30344 .49136 m
.30298 .49096 L
s
.43389 .48968 m
.43276 .48965 L
s
.43438 .48968 m
.43324 .48965 L
s
.45687 .48838 m
.45575 .48853 L
s
.45765 .4883 m
.45652 .48845 L
s
.45713 .48838 m
.456 .48852 L
s
.43537 .48963 m
.43423 .48961 L
s
.43327 .48968 m
.43213 .48964 L
s
.43422 .48966 m
.43308 .48963 L
s
.457 .48836 m
.45587 .48851 L
s
.43376 .48964 m
.43263 .48961 L
s
.45737 .48834 m
.45625 .48849 L
s
.18846 .49749 m
.1882 .49717 L
s
.43437 .48965 m
.43323 .48962 L
s
.45826 .48825 m
.45713 .4884 L
s
.43461 .48964 m
.43348 .48961 L
s
.43351 .48966 m
.43237 .48963 L
s
.60015 .48736 m
.59976 .48775 L
s
.4581 .48824 m
.45698 .4884 L
s
.69994 .47816 m
.69974 .47851 L
s
.45851 .48821 m
.45739 .48837 L
s
.60025 .48735 m
.59986 .48774 L
s
.21169 .58421 m
.21139 .58391 L
s
.45888 .48816 m
.45776 .48832 L
s
.45839 .48819 m
.45727 .48835 L
s
.43411 .48962 m
.43297 .48959 L
s
.43338 .48963 m
.43225 .48959 L
s
.458 .48823 m
.45687 .48838 L
s
.45939 .4881 m
.45827 .48827 L
s
.43324 .48965 m
.43211 .48961 L
s
.45825 .48822 m
.45713 .48838 L
s
.43423 .48961 m
.43309 .48958 L
s
.43276 .48965 m
.43162 .48961 L
s
.45877 .48814 m
.45765 .4883 L
s
.45813 .4882 m
.457 .48836 L
s
.43308 .48963 m
.43195 .48959 L
s
.43213 .48964 m
.431 .4896 L
s
.30325 .49124 m
.30279 .49084 L
s
.45849 .48818 m
.45737 .48834 L
s
.43263 .48961 m
.4315 .48957 L
s
.85829 .33103 m
.8583 .3313 L
s
.43323 .48962 m
.4321 .48958 L
s
.43348 .48961 m
.43234 .48957 L
s
.45938 .48808 m
.45826 .48825 L
s
.43237 .48963 m
.43124 .48958 L
s
.45922 .48808 m
.4581 .48824 L
s
.45963 .48804 m
.45851 .48821 L
s
.70002 .47806 m
.69981 .47841 L
s
.43297 .48959 m
.43183 .48955 L
s
.45951 .48803 m
.45839 .48819 L
s
.46 .48799 m
.45888 .48816 L
s
.43225 .48959 m
.43111 .48955 L
s
.45912 .48806 m
.458 .48823 L
s
.43309 .48958 m
.43196 .48954 L
s
.45937 .48805 m
.45825 .48822 L
s
.43211 .48961 m
.43098 .48957 L
s
.43162 .48961 m
.43049 .48956 L
s
.4605 .48793 m
.45939 .4881 L
s
.45989 .48797 m
.45877 .48814 L
s
.45925 .48804 m
.45813 .4882 L
s
.43195 .48959 m
.43081 .48954 L
s
.45961 .48801 m
.45849 .48818 L
s
.431 .4896 m
.42987 .48954 L
s
.4315 .48957 m
.43036 .48952 L
s
.4321 .48958 m
.43096 .48953 L
s
.43234 .48957 m
.43121 .48953 L
s
.46049 .48791 m
.45938 .48808 L
s
.46034 .4879 m
.45922 .48808 L
s
.43124 .48958 m
.43011 .48953 L
s
.60037 .48716 m
.59998 .48754 L
s
.46074 .48787 m
.45963 .48804 L
s
.43183 .48955 m
.4307 .4895 L
s
.30324 .49108 m
.30279 .49068 L
s
.60039 .48714 m
.60001 .48752 L
s
.46063 .48785 m
.45951 .48803 L
s
.43196 .48954 m
.43082 .48949 L
s
.46112 .48781 m
.46 .48799 L
s
.46024 .48789 m
.45912 .48806 L
s
.43111 .48955 m
.42998 .48949 L
s
.46049 .48788 m
.45937 .48805 L
s
.43098 .48957 m
.42985 .48951 L
s
.1883 .49724 m
.18804 .49692 L
s
.43049 .48956 m
.42936 .4895 L
s
.461 .48779 m
.45989 .48797 L
s
.46162 .48774 m
.4605 .48793 L
s
.46037 .48787 m
.45925 .48804 L
s
.43081 .48954 m
.42968 .48948 L
s
.46073 .48784 m
.45961 .48801 L
s
.42987 .48954 m
.42874 .48948 L
s
.43036 .48952 m
.42923 .48946 L
s
.43096 .48953 m
.42983 .48948 L
s
.46161 .48772 m
.46049 .48791 L
s
.46146 .48772 m
.46034 .4879 L
s
.43011 .48953 m
.42898 .48947 L
s
.4307 .4895 m
.42957 .48944 L
s
.46186 .48768 m
.46074 .48787 L
s
.85827 .33077 m
.85829 .33103 L
s
.1882 .49717 m
.18795 .49685 L
s
.46174 .48767 m
.46063 .48785 L
s
.43082 .48949 m
.42969 .48944 L
s
.46135 .48771 m
.46024 .48789 L
s
.30298 .49096 m
.30253 .49056 L
s
.70015 .47782 m
.69994 .47816 L
s
.42998 .48949 m
.42885 .48943 L
s
.46223 .48763 m
.46112 .48781 L
s
.4616 .4877 m
.46049 .48788 L
s
.42985 .48951 m
.42872 .48945 L
s
.46212 .4876 m
.461 .48779 L
s
.42936 .4895 m
.42824 .48943 L
s
.46148 .48769 m
.46037 .48787 L
s
.46273 .48755 m
.46162 .48774 L
s
.60053 .48698 m
.60015 .48736 L
s
.60063 .48697 m
.60025 .48735 L
s
.42968 .48948 m
.42855 .48942 L
s
.46185 .48765 m
.46073 .48784 L
s
.21139 .58391 m
.2111 .58362 L
s
.42983 .48948 m
.4287 .48941 L
s
.42923 .48946 m
.42811 .48939 L
s
.42874 .48948 m
.42762 .48941 L
s
.46272 .48753 m
.46161 .48772 L
s
.46257 .48753 m
.46146 .48772 L
s
.42898 .48947 m
.42785 .4894 L
s
.42957 .48944 m
.42844 .48938 L
s
.70022 .47772 m
.70002 .47806 L
s
.46297 .48749 m
.46186 .48768 L
s
.42969 .48944 m
.42856 .48937 L
s
.46285 .48747 m
.46174 .48767 L
s
.46247 .48752 m
.46135 .48771 L
s
.42885 .48943 m
.42773 .48936 L
s
.30279 .49084 m
.30234 .49044 L
s
.46271 .48751 m
.4616 .4877 L
s
.46334 .48743 m
.46223 .48763 L
s
.42872 .48945 m
.42759 .48938 L
s
.4626 .48749 m
.46148 .48769 L
s
.46323 .4874 m
.46212 .4876 L
s
.42824 .48943 m
.42711 .48936 L
s
.46383 .48735 m
.46273 .48755 L
s
.42855 .48942 m
.42743 .48934 L
s
.46296 .48746 m
.46185 .48765 L
s
.4287 .48941 m
.42758 .48934 L
s
.42811 .48939 m
.42698 .48931 L
s
.42762 .48941 m
.42649 .48933 L
s
.46382 .48733 m
.46272 .48753 L
s
.46368 .48733 m
.46257 .48753 L
s
.85826 .33051 m
.85827 .33077 L
s
.42844 .48938 m
.42731 .4893 L
s
.42785 .4894 m
.42673 .48932 L
s
.60075 .48677 m
.60037 .48716 L
s
.18804 .49692 m
.18779 .4966 L
s
.42856 .48937 m
.42743 .4893 L
s
.46407 .48729 m
.46297 .48749 L
s
.46357 .48732 m
.46247 .48752 L
s
.46396 .48727 m
.46285 .48747 L
s
.60078 .48675 m
.60039 .48714 L
s
.42773 .48936 m
.4266 .48928 L
s
.46382 .48731 m
.46271 .48751 L
s
.46444 .48722 m
.46334 .48743 L
s
.42759 .48938 m
.42647 .48929 L
s
.30279 .49068 m
.30234 .49028 L
s
.4637 .4873 m
.4626 .48749 L
s
.46433 .4872 m
.46323 .4874 L
s
.42711 .48936 m
.42599 .48927 L
s
.46406 .48726 m
.46296 .48746 L
s
.42743 .48934 m
.4263 .48926 L
s
.46494 .48714 m
.46383 .48735 L
s
.18795 .49685 m
.18769 .49652 L
s
.42758 .48934 m
.42645 .48926 L
s
.42698 .48931 m
.42586 .48923 L
s
.42649 .48933 m
.42537 .48924 L
s
.70035 .47747 m
.70015 .47782 L
s
.46478 .48712 m
.46368 .48733 L
s
.42731 .4893 m
.42619 .48922 L
s
.46493 .48712 m
.46382 .48733 L
s
.42673 .48932 m
.42561 .48923 L
s
.42743 .4893 m
.42631 .48921 L
s
.46518 .48708 m
.46407 .48729 L
s
.46468 .48711 m
.46357 .48732 L
s
.46506 .48706 m
.46396 .48727 L
s
.4266 .48928 m
.42548 .48919 L
s
.46492 .4871 m
.46382 .48731 L
s
.30253 .49056 m
.30208 .49016 L
s
.60091 .48659 m
.60053 .48698 L
s
.46554 .48701 m
.46444 .48722 L
s
.42647 .48929 m
.42534 .4892 L
s
.60101 .48658 m
.60063 .48697 L
s
.46481 .48709 m
.4637 .4873 L
s
.2111 .58362 m
.21081 .58332 L
s
.46543 .48699 m
.46433 .4872 L
s
.42599 .48927 m
.42487 .48918 L
s
.46517 .48705 m
.46406 .48726 L
s
.4263 .48926 m
.42518 .48917 L
s
.70042 .47737 m
.70022 .47772 L
s
.46604 .48693 m
.46494 .48714 L
s
.42645 .48926 m
.42533 .48916 L
s
.85825 .33025 m
.85826 .33051 L
s
.42586 .48923 m
.42474 .48913 L
s
.42537 .48924 m
.42425 .48914 L
s
.42619 .48922 m
.42507 .48913 L
s
.46588 .48691 m
.46478 .48712 L
s
.46603 .48691 m
.46493 .48712 L
s
.42561 .48923 m
.42449 .48913 L
s
.42631 .48921 m
.42519 .48912 L
s
.30234 .49044 m
.3019 .49003 L
s
.46627 .48686 m
.46518 .48708 L
s
.46578 .4869 m
.46468 .48711 L
s
.46616 .48684 m
.46506 .48706 L
s
.42548 .48919 m
.42436 .48909 L
s
.46602 .48688 m
.46492 .4871 L
s
.42534 .4892 m
.42423 .4891 L
s
.46591 .48687 m
.46481 .48709 L
s
.46664 .48679 m
.46554 .48701 L
s
.18779 .4966 m
.18753 .49628 L
s
.46653 .48676 m
.46543 .48699 L
s
.42487 .48918 m
.42375 .48908 L
s
.46626 .48683 m
.46517 .48705 L
s
.42518 .48917 m
.42406 .48907 L
s
.60113 .48638 m
.60075 .48677 L
s
.46713 .4867 m
.46604 .48693 L
s
.42533 .48916 m
.42421 .48907 L
s
.60115 .48637 m
.60078 .48675 L
s
.42474 .48913 m
.42362 .48903 L
s
.42425 .48914 m
.42314 .48903 L
s
.42507 .48913 m
.42395 .48903 L
s
.18769 .49652 m
.18744 .4962 L
s
.46698 .48668 m
.46588 .48691 L
s
.46712 .48668 m
.46603 .48691 L
s
.42519 .48912 m
.42407 .48902 L
s
.42449 .48913 m
.42337 .48903 L
s
.30234 .49028 m
.30189 .48988 L
s
.70055 .47713 m
.70035 .47747 L
s
.46688 .48667 m
.46578 .4869 L
s
.46737 .48663 m
.46627 .48686 L
s
.46726 .48662 m
.46616 .48684 L
s
.42436 .48909 m
.42325 .48899 L
s
.46712 .48665 m
.46602 .48688 L
s
.85823 .32998 m
.85825 .33025 L
s
.46701 .48665 m
.46591 .48687 L
s
.42423 .4891 m
.42311 .489 L
s
.46773 .48656 m
.46664 .48679 L
s
.46762 .48653 m
.46653 .48676 L
s
.42375 .48908 m
.42264 .48897 L
s
.46736 .4866 m
.46626 .48683 L
s
.42406 .48907 m
.42295 .48896 L
s
.42421 .48907 m
.4231 .48896 L
s
.46822 .48647 m
.46713 .4867 L
s
.60129 .4862 m
.60091 .48659 L
s
.70062 .47703 m
.70042 .47737 L
s
.60139 .48619 m
.60101 .48658 L
s
.42362 .48903 m
.42251 .48892 L
s
.21081 .58332 m
.21052 .58302 L
s
.30208 .49016 m
.30164 .48975 L
s
.42314 .48903 m
.42203 .48892 L
s
.42395 .48903 m
.42284 .48892 L
s
.42407 .48902 m
.42295 .48891 L
s
.46807 .48645 m
.46698 .48668 L
s
.46821 .48645 m
.46712 .48668 L
s
.42337 .48903 m
.42226 .48891 L
s
.46797 .48644 m
.46688 .48667 L
s
.46846 .48639 m
.46737 .48663 L
s
.42325 .48899 m
.42213 .48887 L
s
.46835 .48638 m
.46726 .48662 L
s
.46821 .48642 m
.46712 .48665 L
s
.4681 .48641 m
.46701 .48665 L
s
.42311 .489 m
.422 .48888 L
s
.46882 .48632 m
.46773 .48656 L
s
.18753 .49628 m
.18728 .49595 L
s
.46871 .48629 m
.46762 .48653 L
s
.42264 .48897 m
.42153 .48885 L
s
.46845 .48636 m
.46736 .4866 L
s
.42295 .48896 m
.42184 .48884 L
s
.3019 .49003 m
.30145 .48963 L
s
.4231 .48896 m
.42198 .48884 L
s
.85822 .32972 m
.85823 .32998 L
s
.46931 .48622 m
.46822 .48647 L
s
.42251 .48892 m
.4214 .4888 L
s
.42284 .48892 m
.42172 .4888 L
s
.42203 .48892 m
.42092 .48879 L
s
.6015 .486 m
.60113 .48638 L
s
.18744 .4962 m
.18719 .49588 L
s
.42295 .48891 m
.42184 .48879 L
s
.46915 .48621 m
.46807 .48645 L
s
.60153 .48598 m
.60115 .48637 L
s
.42226 .48891 m
.42115 .48879 L
s
.4693 .4862 m
.46821 .48645 L
s
.46906 .4862 m
.46797 .48644 L
s
.70075 .47678 m
.70055 .47713 L
s
.46954 .48615 m
.46846 .48639 L
s
.42213 .48887 m
.42102 .48875 L
s
.4693 .48618 m
.46821 .48642 L
s
.46943 .48614 m
.46835 .48638 L
s
.46919 .48617 m
.4681 .48641 L
s
.422 .48888 m
.42089 .48876 L
s
.4699 .48607 m
.46882 .48632 L
s
.30189 .48988 m
.30145 .48947 L
s
.46953 .48612 m
.46845 .48636 L
s
.42153 .48885 m
.42042 .48872 L
s
.46979 .48605 m
.46871 .48629 L
s
.42184 .48884 m
.42073 .48872 L
s
.42198 .48884 m
.42087 .48871 L
s
.70082 .47668 m
.70062 .47703 L
s
.47039 .48597 m
.46931 .48622 L
s
.4214 .4888 m
.42029 .48867 L
s
.60166 .48582 m
.60129 .4862 L
s
.42172 .4888 m
.42062 .48867 L
s
.21052 .58302 m
.21023 .58271 L
s
.60176 .4858 m
.60139 .48619 L
s
.42092 .48879 m
.41982 .48866 L
s
.42184 .48879 m
.42073 .48867 L
s
.47024 .48596 m
.46915 .48621 L
s
.42115 .48879 m
.42005 .48866 L
s
.47038 .48595 m
.4693 .4862 L
s
.8582 .32946 m
.85822 .32972 L
s
.30164 .48975 m
.3012 .48935 L
s
.47014 .48595 m
.46906 .4862 L
s
.47062 .4859 m
.46954 .48615 L
s
.42102 .48875 m
.41992 .48862 L
s
.47038 .48593 m
.4693 .48618 L
s
.47051 .48588 m
.46943 .48614 L
s
.47027 .48592 m
.46919 .48617 L
s
.42089 .48876 m
.41979 .48862 L
s
.18728 .49595 m
.18703 .49563 L
s
.47098 .48582 m
.4699 .48607 L
s
.47061 .48587 m
.46953 .48612 L
s
.42042 .48872 m
.41932 .48858 L
s
.42073 .48872 m
.41962 .48858 L
s
.47087 .48579 m
.46979 .48605 L
s
.42087 .48871 m
.41977 .48858 L
s
.47146 .48571 m
.47039 .48597 L
s
.42029 .48867 m
.41919 .48853 L
s
.18719 .49588 m
.18694 .49556 L
s
.30145 .48963 m
.30101 .48922 L
s
.42062 .48867 m
.41951 .48853 L
s
.42073 .48867 m
.41963 .48853 L
s
.41982 .48866 m
.41872 .48852 L
s
.60187 .48561 m
.6015 .486 L
s
.70095 .47644 m
.70075 .47678 L
s
.47131 .4857 m
.47024 .48596 L
s
.42005 .48866 m
.41894 .48852 L
s
.47145 .48569 m
.47038 .48595 L
s
.6019 .48559 m
.60153 .48598 L
s
.47122 .48569 m
.47014 .48595 L
s
.4717 .48564 m
.47062 .4859 L
s
.41992 .48862 m
.41882 .48847 L
s
.47145 .48567 m
.47038 .48593 L
s
.47159 .48562 m
.47051 .48588 L
s
.47135 .48566 m
.47027 .48592 L
s
.85818 .3292 m
.8582 .32946 L
s
.41979 .48862 m
.41868 .48848 L
s
.47205 .48555 m
.47098 .48582 L
s
.47169 .4856 m
.47061 .48587 L
s
.41962 .48858 m
.41852 .48844 L
s
.70102 .47634 m
.70082 .47668 L
s
.41932 .48858 m
.41822 .48844 L
s
.47195 .48553 m
.47087 .48579 L
s
.30145 .48947 m
.30101 .48906 L
s
.41977 .48858 m
.41867 .48844 L
s
.41919 .48853 m
.41809 .48838 L
s
.47253 .48544 m
.47146 .48571 L
s
.60203 .48543 m
.60166 .48582 L
s
.21023 .58271 m
.20994 .58241 L
s
.41951 .48853 m
.41841 .48839 L
s
.60213 .48541 m
.60176 .4858 L
s
.41963 .48853 m
.41853 .48839 L
s
.41872 .48852 m
.41762 .48837 L
s
.41894 .48852 m
.41785 .48837 L
s
.47239 .48543 m
.47131 .4857 L
s
.47252 .48542 m
.47145 .48569 L
s
.18703 .49563 m
.18678 .49531 L
s
.47229 .48543 m
.47122 .48569 L
s
.3012 .48935 m
.30076 .48894 L
s
.41882 .48847 m
.41772 .48833 L
s
.47276 .48537 m
.4717 .48564 L
s
.47252 .4854 m
.47145 .48567 L
s
.47266 .48535 m
.47159 .48562 L
s
.47242 .48539 m
.47135 .48566 L
s
.41868 .48848 m
.41759 .48833 L
s
.47312 .48528 m
.47205 .48555 L
s
.18694 .49556 m
.18669 .49523 L
s
.47276 .48533 m
.47169 .4856 L
s
.85817 .32894 m
.85818 .3292 L
s
.41852 .48844 m
.41743 .48829 L
s
.41822 .48844 m
.41713 .48828 L
s
.47302 .48525 m
.47195 .48553 L
s
.41867 .48844 m
.41757 .48829 L
s
.70114 .47609 m
.70095 .47644 L
s
.41809 .48838 m
.41699 .48823 L
s
.4736 .48517 m
.47253 .48544 L
s
.30101 .48922 m
.30058 .48882 L
s
.60224 .48522 m
.60187 .48561 L
s
.41841 .48839 m
.41732 .48824 L
s
.41853 .48839 m
.41743 .48823 L
s
.60227 .4852 m
.6019 .48559 L
s
.41762 .48837 m
.41653 .48821 L
s
.41785 .48837 m
.41675 .48821 L
s
.47345 .48515 m
.47239 .48543 L
s
.47359 .48515 m
.47252 .48542 L
s
.47336 .48515 m
.47229 .48543 L
s
.41772 .48833 m
.41663 .48817 L
s
.70121 .47599 m
.70102 .47634 L
s
.47383 .48509 m
.47276 .48537 L
s
.47359 .48512 m
.47252 .4854 L
s
.47372 .48507 m
.47266 .48535 L
s
.47349 .48512 m
.47242 .48539 L
s
.41759 .48833 m
.41649 .48817 L
s
.47418 .485 m
.47312 .48528 L
s
.47382 .48506 m
.47276 .48533 L
s
.41743 .48829 m
.41633 .48813 L
s
.30101 .48906 m
.30057 .48865 L
s
.41713 .48828 m
.41604 .48812 L
s
.47408 .48497 m
.47302 .48525 L
s
.41757 .48829 m
.41648 .48813 L
s
.20994 .58241 m
.20965 .58211 L
s
.85815 .32867 m
.85817 .32894 L
s
.6024 .48503 m
.60203 .48543 L
s
.6025 .48502 m
.60213 .48541 L
s
.18678 .49531 m
.18653 .49498 L
s
.41699 .48823 m
.4159 .48807 L
s
.47466 .48488 m
.4736 .48517 L
s
.41732 .48824 m
.41622 .48808 L
s
.41743 .48823 m
.41634 .48807 L
s
.41653 .48821 m
.41544 .48804 L
s
.41675 .48821 m
.41566 .48805 L
s
.47451 .48487 m
.47345 .48515 L
s
.47465 .48486 m
.47359 .48515 L
s
.18669 .49523 m
.18644 .49491 L
s
.30076 .48894 m
.30032 .48853 L
s
.47442 .48487 m
.47336 .48515 L
s
.41663 .48817 m
.41554 .488 L
s
.47465 .48484 m
.47359 .48512 L
s
.47489 .4848 m
.47383 .48509 L
s
.47478 .48479 m
.47372 .48507 L
s
.47455 .48483 m
.47349 .48512 L
s
.41649 .48817 m
.41541 .488 L
s
.70134 .47575 m
.70114 .47609 L
s
.47523 .48471 m
.47418 .485 L
s
.41633 .48813 m
.41525 .48796 L
s
.47488 .48477 m
.47382 .48506 L
s
.41604 .48812 m
.41495 .48795 L
s
.41648 .48813 m
.41539 .48796 L
s
.60261 .48483 m
.60224 .48522 L
s
.47514 .48468 m
.47408 .48497 L
s
.60264 .48481 m
.60227 .4852 L
s
.30058 .48882 m
.30014 .48841 L
s
.85813 .32841 m
.85815 .32867 L
s
.4159 .48807 m
.41482 .48789 L
s
.70141 .47565 m
.70121 .47599 L
s
.41622 .48808 m
.41514 .48791 L
s
.47571 .48459 m
.47466 .48488 L
s
.41634 .48807 m
.41525 .4879 L
s
.41544 .48804 m
.41436 .48787 L
s
.41566 .48805 m
.41458 .48787 L
s
.47557 .48458 m
.47451 .48487 L
s
.4757 .48457 m
.47465 .48486 L
s
.47548 .48458 m
.47442 .48487 L
s
.41554 .488 m
.41445 .48783 L
s
.18653 .49498 m
.18628 .49466 L
s
.4757 .48454 m
.47465 .48484 L
s
.47594 .48451 m
.47489 .4848 L
s
.4756 .48454 m
.47455 .48483 L
s
.47583 .48449 m
.47478 .48479 L
s
.41541 .488 m
.41432 .48783 L
s
.20965 .58211 m
.20937 .58181 L
s
.30057 .48865 m
.30014 .48825 L
s
.60277 .48464 m
.6024 .48503 L
s
.60287 .48463 m
.6025 .48502 L
s
.41525 .48796 m
.41416 .48778 L
s
.47594 .48447 m
.47488 .48477 L
s
.47628 .48441 m
.47523 .48471 L
s
.41495 .48795 m
.41387 .48777 L
s
.41539 .48796 m
.4143 .48778 L
s
.18644 .49491 m
.18619 .49458 L
s
.47619 .48439 m
.47514 .48468 L
s
.41482 .48789 m
.41374 .48772 L
s
.41514 .48791 m
.41405 .48773 L
s
.85811 .32815 m
.85813 .32841 L
s
.70153 .4754 m
.70134 .47575 L
s
.41525 .4879 m
.41416 .48773 L
s
.47676 .48429 m
.47571 .48459 L
s
.30032 .48853 m
.29989 .48812 L
s
.41436 .48787 m
.41328 .48769 L
s
.41458 .48787 m
.4135 .48769 L
s
.47662 .48428 m
.47557 .48458 L
s
.47675 .48427 m
.4757 .48457 L
s
.47653 .48428 m
.47548 .48458 L
s
.41445 .48783 m
.41337 .48765 L
s
.60297 .48443 m
.60261 .48483 L
s
.47675 .48424 m
.4757 .48454 L
s
.47699 .4842 m
.47594 .48451 L
s
.7016 .4753 m
.70141 .47565 L
s
.47665 .48424 m
.4756 .48454 L
s
.47688 .48419 m
.47583 .48449 L
s
.41432 .48783 m
.41324 .48764 L
s
.603 .48442 m
.60264 .48481 L
s
.30014 .48841 m
.29971 .488 L
s
.41416 .48778 m
.41308 .4876 L
s
.47698 .48417 m
.47594 .48447 L
s
.41387 .48777 m
.41279 .48759 L
s
.47733 .48411 m
.47628 .48441 L
s
.4143 .48778 m
.41323 .4876 L
s
.47723 .48408 m
.47619 .48439 L
s
.18628 .49466 m
.18603 .49433 L
s
.41374 .48772 m
.41266 .48753 L
s
.41405 .48773 m
.41297 .48754 L
s
.41416 .48773 m
.41309 .48754 L
s
.85809 .32789 m
.85811 .32815 L
s
.4778 .48398 m
.47676 .48429 L
s
.20937 .58181 m
.20908 .5815 L
s
.41328 .48769 m
.4122 .4875 L
s
.60313 .48425 m
.60277 .48464 L
s
.4135 .48769 m
.41243 .4875 L
s
.60323 .48424 m
.60287 .48463 L
s
.18619 .49458 m
.18594 .49426 L
s
.47766 .48397 m
.47662 .48428 L
s
.30014 .48825 m
.2997 .48784 L
s
.47779 .48396 m
.47675 .48427 L
s
.47757 .48397 m
.47653 .48428 L
s
.41337 .48765 m
.4123 .48745 L
s
.47779 .48393 m
.47675 .48424 L
s
.70173 .47506 m
.70153 .4754 L
s
.47803 .48389 m
.47699 .4842 L
s
.4777 .48393 m
.47665 .48424 L
s
.41324 .48764 m
.41217 .48745 L
s
.47792 .48388 m
.47688 .48419 L
s
.41308 .4876 m
.41201 .4874 L
s
.47802 .48386 m
.47698 .48417 L
s
.41279 .48759 m
.41172 .48739 L
s
.41323 .4876 m
.41215 .48741 L
s
.47837 .48379 m
.47733 .48411 L
s
.29989 .48812 m
.29946 .48771 L
s
.47827 .48377 m
.47723 .48408 L
s
.70179 .47495 m
.7016 .4753 L
s
.41266 .48753 m
.41159 .48733 L
s
.41297 .48754 m
.4119 .48735 L
s
.60333 .48404 m
.60297 .48443 L
s
.41309 .48754 m
.41201 .48735 L
s
.85808 .32763 m
.85809 .32789 L
s
.60336 .48402 m
.603 .48442 L
s
.47883 .48366 m
.4778 .48398 L
s
.4122 .4875 m
.41113 .4873 L
s
.41243 .4875 m
.41136 .4873 L
s
.18603 .49433 m
.18579 .49401 L
s
.4787 .48365 m
.47766 .48397 L
s
.29971 .488 m
.29928 .48759 L
s
.47883 .48364 m
.47779 .48396 L
s
.47861 .48365 m
.47757 .48397 L
s
.4123 .48745 m
.41123 .48726 L
s
.47883 .48361 m
.47779 .48393 L
s
.47906 .48357 m
.47803 .48389 L
s
.47873 .48362 m
.4777 .48393 L
s
.41217 .48745 m
.4111 .48725 L
s
.47896 .48356 m
.47792 .48388 L
s
.18594 .49426 m
.1857 .49393 L
s
.20908 .5815 m
.2088 .5812 L
s
.41201 .4874 m
.41094 .4872 L
s
.60349 .48386 m
.60313 .48425 L
s
.47906 .48354 m
.47802 .48386 L
s
.41215 .48741 m
.41108 .48721 L
s
.60359 .48385 m
.60323 .48424 L
s
.41172 .48739 m
.41066 .48719 L
s
.4794 .48347 m
.47837 .48379 L
s
.4793 .48345 m
.47827 .48377 L
s
.70192 .47471 m
.70173 .47506 L
s
.2997 .48784 m
.29928 .48742 L
s
.41159 .48733 m
.41052 .48713 L
s
.4119 .48735 m
.41083 .48715 L
s
.85806 .32736 m
.85808 .32763 L
s
.41201 .48735 m
.41094 .48714 L
s
.47986 .48334 m
.47883 .48366 L
s
.41113 .4873 m
.41007 .48709 L
s
.41136 .4873 m
.41029 .4871 L
s
.70198 .47461 m
.70179 .47495 L
s
.47973 .48333 m
.4787 .48365 L
s
.47986 .48332 m
.47883 .48364 L
s
.47964 .48333 m
.47861 .48365 L
s
.41123 .48726 m
.41017 .48705 L
s
.29946 .48771 m
.29903 .4873 L
s
.47986 .48329 m
.47883 .48361 L
s
.4111 .48725 m
.41004 .48704 L
s
.47976 .48329 m
.47873 .48362 L
s
.60369 .48365 m
.60333 .48404 L
s
.48009 .48325 m
.47906 .48357 L
s
.47999 .48324 m
.47896 .48356 L
s
.60372 .48363 m
.60336 .48402 L
s
.18579 .49401 m
.18554 .49368 L
s
.41094 .4872 m
.40988 .48699 L
s
.41108 .48721 m
.41002 .487 L
s
.41066 .48719 m
.40959 .48698 L
s
.48008 .48321 m
.47906 .48354 L
s
.48042 .48314 m
.4794 .48347 L
s
.48033 .48312 m
.4793 .48345 L
s
.1857 .49393 m
.18545 .49361 L
s
.29928 .48759 m
.29885 .48717 L
s
.85804 .3271 m
.85806 .32736 L
s
.41052 .48713 m
.40946 .48691 L
s
.41083 .48715 m
.40977 .48694 L
s
.41094 .48714 m
.40988 .48693 L
s
.2088 .5812 m
.20851 .58089 L
s
.48088 .48301 m
.47986 .48334 L
s
.41007 .48709 m
.40901 .48687 L
s
.70211 .47436 m
.70192 .47471 L
s
.60385 .48346 m
.60349 .48386 L
s
.41029 .4871 m
.40923 .48688 L
s
.60395 .48345 m
.60359 .48385 L
s
.48075 .48299 m
.47973 .48333 L
s
.48088 .48298 m
.47986 .48332 L
s
.48066 .483 m
.47964 .48333 L
s
.41017 .48705 m
.40911 .48683 L
s
.29928 .48742 m
.29885 .48701 L
s
.48088 .48296 m
.47986 .48329 L
s
.41004 .48704 m
.40898 .48683 L
s
.48079 .48296 m
.47976 .48329 L
s
.48111 .48291 m
.48009 .48325 L
s
.48101 .4829 m
.47999 .48324 L
s
.70217 .47426 m
.70198 .47461 L
s
.40988 .48699 m
.40882 .48677 L
s
.41002 .487 m
.40896 .48678 L
s
.40959 .48698 m
.40854 .48676 L
s
.48111 .48288 m
.48008 .48321 L
s
.48144 .4828 m
.48042 .48314 L
s
.85801 .32684 m
.85804 .3271 L
s
.18554 .49368 m
.1853 .49336 L
s
.48135 .48278 m
.48033 .48312 L
s
.29903 .4873 m
.29861 .48689 L
s
.60405 .48325 m
.60369 .48365 L
s
.40946 .48691 m
.40841 .48669 L
s
.40977 .48694 m
.40871 .48672 L
s
.40988 .48693 m
.40882 .48672 L
s
.60408 .48323 m
.60372 .48363 L
s
.18545 .49361 m
.18521 .49328 L
s
.4819 .48267 m
.48088 .48301 L
s
.40901 .48687 m
.40796 .48665 L
s
.40923 .48688 m
.40818 .48666 L
s
.48177 .48265 m
.48075 .48299 L
s
.40911 .48683 m
.40805 .48661 L
s
.48189 .48264 m
.48088 .48298 L
s
.48168 .48266 m
.48066 .483 L
s
.29885 .48717 m
.29843 .48676 L
s
.7023 .47401 m
.70211 .47436 L
s
.20851 .58089 m
.20823 .58059 L
s
.40898 .48683 m
.40793 .4866 L
s
.48189 .48261 m
.48088 .48296 L
s
.48181 .48262 m
.48079 .48296 L
s
.48212 .48257 m
.48111 .48291 L
s
.48202 .48256 m
.48101 .4829 L
s
.6042 .48307 m
.60385 .48346 L
s
.6043 .48306 m
.60395 .48345 L
s
.40882 .48677 m
.40777 .48655 L
s
.85799 .32658 m
.85801 .32684 L
s
.40896 .48678 m
.40791 .48655 L
s
.40854 .48676 m
.40749 .48653 L
s
.48212 .48253 m
.48111 .48288 L
s
.70236 .47391 m
.70217 .47426 L
s
.48245 .48246 m
.48144 .4828 L
s
.48236 .48244 m
.48135 .48278 L
s
.40841 .48669 m
.40736 .48647 L
s
.40871 .48672 m
.40766 .48649 L
s
.40882 .48672 m
.40777 .48649 L
s
.29885 .48701 m
.29843 .4866 L
s
.1853 .49336 m
.18506 .49303 L
s
.40796 .48665 m
.40691 .48642 L
s
.40818 .48666 m
.40713 .48643 L
s
.48291 .48232 m
.4819 .48267 L
s
.6044 .48286 m
.60405 .48325 L
s
.48278 .48231 m
.48177 .48265 L
s
.40805 .48661 m
.40701 .48638 L
s
.18521 .49328 m
.18497 .49296 L
s
.4829 .48229 m
.48189 .48264 L
s
.60443 .48284 m
.60408 .48323 L
s
.48269 .48231 m
.48168 .48266 L
s
.29861 .48689 m
.29819 .48647 L
s
.40793 .4866 m
.40688 .48637 L
s
.4829 .48226 m
.48189 .48261 L
s
.48282 .48227 m
.48181 .48262 L
s
.48313 .48222 m
.48212 .48257 L
s
.85797 .32632 m
.85799 .32658 L
s
.48303 .48221 m
.48202 .48256 L
s
.40777 .48655 m
.40672 .48631 L
s
.70248 .47367 m
.7023 .47401 L
s
.40791 .48655 m
.40686 .48632 L
s
.40749 .48653 m
.40645 .48629 L
s
.48313 .48218 m
.48212 .48253 L
s
.20823 .58059 m
.20795 .58028 L
s
.48346 .48211 m
.48245 .48246 L
s
.29843 .48676 m
.29801 .48635 L
s
.48336 .48208 m
.48236 .48244 L
s
.40766 .48649 m
.40662 .48625 L
s
.40736 .48647 m
.40631 .48623 L
s
.60455 .48267 m
.6042 .48307 L
s
.40777 .48649 m
.40672 .48625 L
s
.60465 .48266 m
.6043 .48306 L
s
.70255 .47357 m
.70236 .47391 L
s
.40691 .48642 m
.40587 .48618 L
s
.40713 .48643 m
.40609 .48619 L
s
.48391 .48196 m
.48291 .48232 L
s
.18506 .49303 m
.18482 .49271 L
s
.40701 .48638 m
.40596 .48614 L
s
.48378 .48195 m
.48278 .48231 L
s
.48369 .48195 m
.48269 .48231 L
s
.4839 .48194 m
.4829 .48229 L
s
.85795 .32606 m
.85797 .32632 L
s
.29843 .4866 m
.29801 .48618 L
s
.40688 .48637 m
.40584 .48613 L
s
.4839 .48191 m
.4829 .48226 L
s
.48382 .48191 m
.48282 .48227 L
s
.18497 .49296 m
.18473 .49263 L
s
.48413 .48186 m
.48313 .48222 L
s
.48403 .48185 m
.48303 .48221 L
s
.60475 .48246 m
.6044 .48286 L
s
.40672 .48631 m
.40568 .48607 L
s
.40686 .48632 m
.40582 .48608 L
s
.60478 .48244 m
.60443 .48284 L
s
.40645 .48629 m
.40541 .48605 L
s
.48413 .48182 m
.48313 .48218 L
s
.29819 .48647 m
.29777 .48606 L
s
.48445 .48175 m
.48346 .48211 L
s
.70267 .47332 m
.70248 .47367 L
s
.40662 .48625 m
.40558 .48601 L
s
.40631 .48623 m
.40528 .48598 L
s
.48436 .48172 m
.48336 .48208 L
s
.40672 .48625 m
.40568 .48601 L
s
.20795 .58028 m
.20767 .57997 L
s
.40587 .48618 m
.40484 .48593 L
s
.40609 .48619 m
.40505 .48594 L
s
.70274 .47322 m
.70255 .47357 L
s
.85793 .3258 m
.85795 .32606 L
s
.4849 .4816 m
.48391 .48196 L
s
.6049 .48227 m
.60455 .48267 L
s
.605 .48226 m
.60465 .48266 L
s
.29801 .48635 m
.2976 .48593 L
s
.40596 .48614 m
.40493 .48589 L
s
.48477 .48158 m
.48378 .48195 L
s
.48469 .48159 m
.48369 .48195 L
s
.48489 .48157 m
.4839 .48194 L
s
.18482 .49271 m
.18458 .49238 L
s
.40584 .48613 m
.4048 .48588 L
s
.48489 .48154 m
.4839 .48191 L
s
.48481 .48155 m
.48382 .48191 L
s
.48512 .4815 m
.48413 .48186 L
s
.48502 .48148 m
.48403 .48185 L
s
.40568 .48607 m
.40465 .48582 L
s
.40582 .48608 m
.40478 .48583 L
s
.18473 .49263 m
.18449 .4923 L
s
.40541 .48605 m
.40438 .4858 L
s
.48512 .48146 m
.48413 .48182 L
s
.29801 .48618 m
.29759 .48576 L
s
.48544 .48138 m
.48445 .48175 L
s
.40558 .48601 m
.40454 .48576 L
s
.40528 .48598 m
.40424 .48573 L
s
.40568 .48601 m
.40465 .48576 L
s
.6051 .48206 m
.60475 .48246 L
s
.48535 .48135 m
.48436 .48172 L
s
.60513 .48204 m
.60478 .48244 L
s
.70286 .47297 m
.70267 .47332 L
s
.8579 .32554 m
.85793 .3258 L
s
.40505 .48594 m
.40402 .48569 L
s
.40484 .48593 m
.40381 .48567 L
s
.29777 .48606 m
.29736 .48564 L
s
.48589 .48122 m
.4849 .4816 L
s
.20767 .57997 m
.20739 .57966 L
s
.40493 .48589 m
.4039 .48563 L
s
.70292 .47287 m
.70274 .47322 L
s
.48576 .48121 m
.48477 .48158 L
s
.48568 .48122 m
.48469 .48159 L
s
.48588 .4812 m
.48489 .48157 L
s
.4048 .48588 m
.40377 .48562 L
s
.60525 .48188 m
.6049 .48227 L
s
.60535 .48187 m
.605 .48226 L
s
.18458 .49238 m
.18434 .49205 L
s
.48588 .48117 m
.48489 .48154 L
s
.4858 .48118 m
.48481 .48155 L
s
.4861 .48112 m
.48512 .4815 L
s
.48601 .48111 m
.48502 .48148 L
s
.2976 .48593 m
.29718 .48551 L
s
.40465 .48582 m
.40362 .48556 L
s
.40478 .48583 m
.40376 .48557 L
s
.40438 .4858 m
.40335 .48554 L
s
.4861 .48108 m
.48512 .48146 L
s
.18449 .4923 m
.18425 .49198 L
s
.85788 .32527 m
.8579 .32554 L
s
.40454 .48576 m
.40352 .4855 L
s
.48642 .481 m
.48544 .48138 L
s
.40424 .48573 m
.40322 .48547 L
s
.40465 .48576 m
.40362 .4855 L
s
.48633 .48098 m
.48535 .48135 L
s
.29759 .48576 m
.29718 .48535 L
s
.70304 .47262 m
.70286 .47297 L
s
.40402 .48569 m
.403 .48543 L
s
.40381 .48567 m
.40279 .48541 L
s
.60544 .48166 m
.6051 .48206 L
s
.60547 .48165 m
.60513 .48204 L
s
.48686 .48084 m
.48589 .48122 L
s
.4039 .48563 m
.40288 .48537 L
s
.48674 .48083 m
.48576 .48121 L
s
.48666 .48084 m
.48568 .48122 L
s
.48685 .48082 m
.48588 .4812 L
s
.40377 .48562 m
.40275 .48536 L
s
.7031 .47252 m
.70292 .47287 L
s
.20739 .57966 m
.20711 .57935 L
s
.29736 .48564 m
.29694 .48522 L
s
.48678 .4808 m
.4858 .48118 L
s
.48686 .48079 m
.48588 .48117 L
s
.85785 .32501 m
.85788 .32527 L
s
.48708 .48074 m
.4861 .48112 L
s
.40362 .48556 m
.4026 .4853 L
s
.18434 .49205 m
.1841 .49172 L
s
.48698 .48073 m
.48601 .48111 L
s
.40376 .48557 m
.40273 .4853 L
s
.40335 .48554 m
.40233 .48527 L
s
.60559 .48148 m
.60525 .48188 L
s
.60569 .48147 m
.60535 .48187 L
s
.48708 .4807 m
.4861 .48108 L
s
.40352 .4855 m
.4025 .48523 L
s
.18425 .49198 m
.18401 .49165 L
s
.40362 .4855 m
.4026 .48523 L
s
.40322 .48547 m
.4022 .4852 L
s
.48739 .48062 m
.48642 .481 L
s
.29718 .48551 m
.29677 .48509 L
s
.48731 .48059 m
.48633 .48098 L
s
.403 .48543 m
.40198 .48516 L
s
.40279 .48541 m
.40178 .48514 L
s
.70322 .47227 m
.70304 .47262 L
s
.48783 .48046 m
.48686 .48084 L
s
.40288 .48537 m
.40186 .4851 L
s
.85783 .32475 m
.85785 .32501 L
s
.60578 .48126 m
.60544 .48166 L
s
.48771 .48045 m
.48674 .48083 L
s
.48763 .48045 m
.48666 .48084 L
s
.29718 .48535 m
.29677 .48493 L
s
.40275 .48536 m
.40174 .48509 L
s
.48782 .48043 m
.48685 .48082 L
s
.60581 .48125 m
.60547 .48165 L
s
.70329 .47217 m
.7031 .47252 L
s
.48775 .48041 m
.48678 .4808 L
s
.48783 .4804 m
.48686 .48079 L
s
.4026 .4853 m
.40159 .48502 L
s
.48804 .48035 m
.48708 .48074 L
s
.40273 .4853 m
.40172 .48503 L
s
.48795 .48034 m
.48698 .48073 L
s
.20711 .57935 m
.20683 .57904 L
s
.1841 .49172 m
.18386 .49139 L
s
.40233 .48527 m
.40132 .485 L
s
.48805 .48031 m
.48708 .4807 L
s
.29694 .48522 m
.29654 .4848 L
s
.4025 .48523 m
.40148 .48496 L
s
.4026 .48523 m
.40158 .48496 L
s
.4022 .4852 m
.40119 .48493 L
s
.48836 .48023 m
.48739 .48062 L
s
.18401 .49165 m
.18378 .49132 L
s
.60593 .48108 m
.60559 .48148 L
s
.60603 .48107 m
.60569 .48147 L
s
.48827 .4802 m
.48731 .48059 L
s
.8578 .32449 m
.85783 .32475 L
s
.40198 .48516 m
.40097 .48488 L
s
.40178 .48514 m
.40077 .48486 L
s
.29677 .48509 m
.29636 .48467 L
s
.7034 .47192 m
.70322 .47227 L
s
.40186 .4851 m
.40085 .48482 L
s
.48879 .48006 m
.48783 .48046 L
s
.48867 .48005 m
.48771 .48045 L
s
.40174 .48509 m
.40073 .48481 L
s
.48859 .48006 m
.48763 .48045 L
s
.48878 .48004 m
.48782 .48043 L
s
.48872 .48002 m
.48775 .48041 L
s
.48879 .48001 m
.48783 .4804 L
s
.60612 .48086 m
.60578 .48126 L
s
.40159 .48502 m
.40058 .48474 L
s
.70347 .47182 m
.70329 .47217 L
s
.40172 .48503 m
.40071 .48475 L
s
.60615 .48085 m
.60581 .48125 L
s
.489 .47996 m
.48804 .48035 L
s
.48891 .47994 m
.48795 .48034 L
s
.40132 .485 m
.40032 .48471 L
s
.29677 .48493 m
.29637 .48451 L
s
.18386 .49139 m
.18363 .49107 L
s
.48901 .47991 m
.48805 .48031 L
s
.20683 .57904 m
.20655 .57873 L
s
.85778 .32423 m
.8578 .32449 L
s
.40148 .48496 m
.40047 .48468 L
s
.40158 .48496 m
.40058 .48468 L
s
.40119 .48493 m
.40018 .48464 L
s
.48932 .47983 m
.48836 .48023 L
s
.18378 .49132 m
.18354 .49099 L
s
.48923 .4798 m
.48827 .4802 L
s
.29654 .4848 m
.29613 .48438 L
s
.40097 .48488 m
.39997 .48459 L
s
.60627 .48068 m
.60593 .48108 L
s
.60637 .48067 m
.60603 .48107 L
s
.40077 .48486 m
.39977 .48457 L
s
.40085 .48482 m
.39985 .48453 L
s
.48975 .47966 m
.48879 .48006 L
s
.70358 .47157 m
.7034 .47192 L
s
.40073 .48481 m
.39973 .48452 L
s
.48963 .47965 m
.48867 .48005 L
s
.48955 .47966 m
.48859 .48006 L
s
.29636 .48467 m
.29596 .48425 L
s
.48974 .47963 m
.48878 .48004 L
s
.85775 .32397 m
.85778 .32423 L
s
.48967 .47961 m
.48872 .48002 L
s
.48974 .4796 m
.48879 .48001 L
s
.40058 .48474 m
.39958 .48445 L
s
.40071 .48475 m
.39971 .48446 L
s
.70365 .47147 m
.70347 .47182 L
s
.48995 .47955 m
.489 .47996 L
s
.40032 .48471 m
.39932 .48442 L
s
.48986 .47954 m
.48891 .47994 L
s
.60646 .48046 m
.60612 .48086 L
s
.18363 .49107 m
.18339 .49074 L
s
.60649 .48045 m
.60615 .48085 L
s
.40047 .48468 m
.39947 .48439 L
s
.48996 .47951 m
.48901 .47991 L
s
.40058 .48468 m
.39958 .48439 L
s
.40018 .48464 m
.39919 .48435 L
s
.29637 .48451 m
.29596 .48409 L
s
.20655 .57873 m
.20627 .57842 L
s
.49026 .47942 m
.48932 .47983 L
s
.18354 .49099 m
.18331 .49066 L
s
.49018 .4794 m
.48923 .4798 L
s
.39997 .48459 m
.39898 .4843 L
s
.39977 .48457 m
.39877 .48428 L
s
.6066 .48027 m
.60627 .48068 L
s
.85772 .32371 m
.85775 .32397 L
s
.39985 .48453 m
.39885 .48424 L
s
.6067 .48027 m
.60637 .48067 L
s
.29613 .48438 m
.29573 .48396 L
s
.49069 .47925 m
.48975 .47966 L
s
.70376 .47122 m
.70358 .47157 L
s
.39973 .48452 m
.39873 .48422 L
s
.49057 .47924 m
.48963 .47965 L
s
.49049 .47925 m
.48955 .47966 L
s
.49068 .47922 m
.48974 .47963 L
s
.39958 .48445 m
.39859 .48416 L
s
.49062 .4792 m
.48967 .47961 L
s
.49068 .47919 m
.48974 .4796 L
s
.39971 .48446 m
.39871 .48417 L
s
.70382 .47112 m
.70365 .47147 L
s
.39932 .48442 m
.39833 .48412 L
s
.4909 .47914 m
.48995 .47955 L
s
.29596 .48425 m
.29556 .48383 L
s
.49081 .47913 m
.48986 .47954 L
s
.18339 .49074 m
.18316 .49041 L
s
.39947 .48439 m
.39848 .48409 L
s
.39958 .48439 m
.39858 .48409 L
s
.4909 .4791 m
.48996 .47951 L
s
.39919 .48435 m
.3982 .48405 L
s
.60679 .48006 m
.60646 .48046 L
s
.60682 .48004 m
.60649 .48045 L
s
.4912 .47901 m
.49026 .47942 L
s
.18331 .49066 m
.18308 .49033 L
s
.8577 .32345 m
.85772 .32371 L
s
.49112 .47898 m
.49018 .4794 L
s
.20627 .57842 m
.206 .57811 L
s
.39898 .4843 m
.39799 .484 L
s
.39877 .48428 m
.39778 .48397 L
s
.29596 .48409 m
.29556 .48366 L
s
.39885 .48424 m
.39787 .48394 L
s
.70394 .47087 m
.70376 .47122 L
s
.49163 .47884 m
.49069 .47925 L
s
.60693 .47987 m
.6066 .48027 L
s
.39873 .48422 m
.39775 .48392 L
s
.60704 .47986 m
.6067 .48027 L
s
.49151 .47882 m
.49057 .47924 L
s
.49143 .47883 m
.49049 .47925 L
s
.29573 .48396 m
.29533 .48354 L
s
.49162 .47881 m
.49068 .47922 L
s
.39859 .48416 m
.3976 .48385 L
s
.39871 .48417 m
.39773 .48386 L
s
.49155 .47879 m
.49062 .4792 L
s
.49162 .47878 m
.49068 .47919 L
s
.704 .47077 m
.70382 .47112 L
s
.39833 .48412 m
.39734 .48382 L
s
.85767 .32319 m
.8577 .32345 L
s
.49183 .47872 m
.4909 .47914 L
s
.49174 .47871 m
.49081 .47913 L
s
.18316 .49041 m
.18293 .49008 L
s
.39848 .48409 m
.3975 .48378 L
s
.39858 .48409 m
.3976 .48378 L
s
.3982 .48405 m
.39721 .48375 L
s
.49184 .47868 m
.4909 .4791 L
s
.29556 .48383 m
.29516 .48341 L
s
.18308 .49033 m
.18284 .49 L
s
.60712 .47966 m
.60679 .48006 L
s
.49213 .47859 m
.4912 .47901 L
s
.60715 .47964 m
.60682 .48004 L
s
.49205 .47856 m
.49112 .47898 L
s
.39799 .484 m
.39701 .48369 L
s
.206 .57811 m
.20572 .57779 L
s
.39778 .48397 m
.39681 .48366 L
s
.39787 .48394 m
.39689 .48363 L
s
.29556 .48366 m
.29517 .48324 L
s
.70412 .47052 m
.70394 .47087 L
s
.85764 .32293 m
.85767 .32319 L
s
.49255 .47841 m
.49163 .47884 L
s
.39775 .48392 m
.39677 .48361 L
s
.49244 .4784 m
.49151 .47882 L
s
.49236 .47841 m
.49143 .47883 L
s
.60726 .47947 m
.60693 .47987 L
s
.60736 .47946 m
.60704 .47986 L
s
.49254 .47838 m
.49162 .47881 L
s
.3976 .48385 m
.39662 .48354 L
s
.39773 .48386 m
.39675 .48355 L
s
.49248 .47836 m
.49155 .47879 L
s
.70418 .47042 m
.704 .47077 L
s
.49255 .47835 m
.49162 .47878 L
s
.39734 .48382 m
.39637 .48351 L
s
.18293 .49008 m
.1827 .48975 L
s
.29533 .48354 m
.29493 .48312 L
s
.49275 .4783 m
.49183 .47872 L
s
.49267 .47829 m
.49174 .47871 L
s
.3975 .48378 m
.39652 .48347 L
s
.3976 .48378 m
.39662 .48347 L
s
.39721 .48375 m
.39624 .48343 L
s
.49276 .47825 m
.49184 .47868 L
s
.18284 .49 m
.18261 .48967 L
s
.49305 .47816 m
.49213 .47859 L
s
.85761 .32267 m
.85764 .32293 L
s
.29516 .48341 m
.29477 .48298 L
s
.49297 .47813 m
.49205 .47856 L
s
.60744 .47925 m
.60712 .47966 L
s
.39701 .48369 m
.39603 .48337 L
s
.60748 .47924 m
.60715 .47964 L
s
.39681 .48366 m
.39583 .48335 L
s
.20572 .57779 m
.20545 .57748 L
s
.39689 .48363 m
.39591 .48331 L
s
.70429 .47017 m
.70412 .47052 L
s
.39677 .48361 m
.39579 .48329 L
s
.49347 .47798 m
.49255 .47841 L
s
.29517 .48324 m
.29477 .48282 L
s
.49336 .47797 m
.49244 .4784 L
s
.49328 .47798 m
.49236 .47841 L
s
.49346 .47795 m
.49254 .47838 L
s
.39662 .48354 m
.39565 .48322 L
s
.60759 .47906 m
.60726 .47947 L
s
.39675 .48355 m
.39578 .48323 L
s
.60769 .47906 m
.60736 .47946 L
s
.70435 .47007 m
.70418 .47042 L
s
.1827 .48975 m
.18247 .48942 L
s
.4934 .47793 m
.49248 .47836 L
s
.39637 .48351 m
.3954 .48319 L
s
.49346 .47792 m
.49255 .47835 L
s
.85758 .32241 m
.85761 .32267 L
s
.49367 .47787 m
.49275 .4783 L
s
.49358 .47785 m
.49267 .47829 L
s
.39652 .48347 m
.39555 .48315 L
s
.39662 .48347 m
.39565 .48315 L
s
.29493 .48312 m
.29454 .48269 L
s
.18261 .48967 m
.18239 .48934 L
s
.39624 .48343 m
.39527 .48311 L
s
.49368 .47782 m
.49276 .47825 L
s
.49397 .47773 m
.49305 .47816 L
s
.49388 .4777 m
.49297 .47813 L
s
.39603 .48337 m
.39507 .48305 L
s
.39583 .48335 m
.39487 .48302 L
s
.60777 .47885 m
.60744 .47925 L
s
.6078 .47883 m
.60748 .47924 L
s
.20545 .57748 m
.20518 .57717 L
s
.29477 .48298 m
.29438 .48256 L
s
.39591 .48331 m
.39495 .48299 L
s
.70446 .46982 m
.70429 .47017 L
s
.85755 .32215 m
.85758 .32241 L
s
.39579 .48329 m
.39483 .48296 L
s
.49438 .47755 m
.49347 .47798 L
s
.49427 .47753 m
.49336 .47797 L
s
.70452 .46972 m
.70435 .47007 L
s
.49419 .47754 m
.49328 .47798 L
s
.18247 .48942 m
.18224 .48909 L
s
.39565 .48322 m
.39469 .4829 L
s
.49437 .47751 m
.49346 .47795 L
s
.39578 .48323 m
.39481 .48291 L
s
.29477 .48282 m
.29438 .48239 L
s
.60791 .47866 m
.60759 .47906 L
s
.60801 .47865 m
.60769 .47906 L
s
.3954 .48319 m
.39444 .48286 L
s
.49431 .4775 m
.4934 .47793 L
s
.49437 .47748 m
.49346 .47792 L
s
.49457 .47743 m
.49367 .47787 L
s
.18239 .48934 m
.18216 .48901 L
s
.49449 .47741 m
.49358 .47785 L
s
.39555 .48315 m
.39459 .48282 L
s
.39565 .48315 m
.39468 .48282 L
s
.39527 .48311 m
.39431 .48278 L
s
.49458 .47738 m
.49368 .47782 L
s
.29454 .48269 m
.29415 .48226 L
s
.85752 .32189 m
.85755 .32215 L
s
.49487 .47728 m
.49397 .47773 L
s
.39507 .48305 m
.39411 .48272 L
s
.49479 .47726 m
.49388 .4777 L
s
.39487 .48302 m
.39391 .48269 L
s
.70464 .46947 m
.70446 .46982 L
s
.60809 .47844 m
.60777 .47885 L
s
.20518 .57717 m
.20491 .57685 L
s
.60812 .47843 m
.6078 .47883 L
s
.39495 .48299 m
.39399 .48266 L
s
.29438 .48256 m
.29399 .48213 L
s
.39483 .48296 m
.39387 .48263 L
s
.49528 .4771 m
.49438 .47755 L
s
.7047 .46937 m
.70452 .46972 L
s
.18224 .48909 m
.18202 .48876 L
s
.49517 .47709 m
.49427 .47753 L
s
.49509 .4771 m
.49419 .47754 L
s
.39469 .4829 m
.39373 .48256 L
s
.39481 .48291 m
.39385 .48257 L
s
.49526 .47707 m
.49437 .47751 L
s
.39444 .48286 m
.39349 .48252 L
s
.85749 .32163 m
.85752 .32189 L
s
.49521 .47705 m
.49431 .4775 L
s
.18216 .48901 m
.18193 .48868 L
s
.60823 .47825 m
.60791 .47866 L
s
.60833 .47825 m
.60801 .47865 L
s
.49527 .47704 m
.49437 .47748 L
s
.29438 .48239 m
.29399 .48196 L
s
.49547 .47698 m
.49457 .47743 L
s
.39459 .48282 m
.39363 .48249 L
s
.49539 .47697 m
.49449 .47741 L
s
.39468 .48282 m
.39373 .48249 L
s
.39431 .48278 m
.39336 .48245 L
s
.49548 .47693 m
.49458 .47738 L
s
.29415 .48226 m
.29377 .48184 L
s
.49576 .47684 m
.49487 .47728 L
s
.39411 .48272 m
.39316 .48238 L
s
.70481 .46912 m
.70464 .46947 L
s
.39391 .48269 m
.39296 .48235 L
s
.49568 .47681 m
.49479 .47726 L
s
.20491 .57685 m
.20464 .57653 L
s
.60841 .47803 m
.60809 .47844 L
s
.39399 .48266 m
.39304 .48232 L
s
.60844 .47802 m
.60812 .47843 L
s
.85746 .32137 m
.85749 .32163 L
s
.18202 .48876 m
.18179 .48843 L
s
.39387 .48263 m
.39292 .48229 L
s
.70487 .46902 m
.7047 .46937 L
s
.29399 .48213 m
.2936 .48171 L
s
.49617 .47665 m
.49528 .4771 L
s
.39373 .48256 m
.39278 .48222 L
s
.39385 .48257 m
.39291 .48223 L
s
.49606 .47664 m
.49517 .47709 L
s
.49599 .47665 m
.49509 .4771 L
s
.18193 .48868 m
.18171 .48835 L
s
.49615 .47662 m
.49526 .47707 L
s
.39349 .48252 m
.39254 .48218 L
s
.49611 .4766 m
.49521 .47705 L
s
.60855 .47784 m
.60823 .47825 L
s
.60865 .47784 m
.60833 .47825 L
s
.49616 .47658 m
.49527 .47704 L
s
.39363 .48249 m
.39268 .48214 L
s
.39373 .48249 m
.39278 .48215 L
s
.49636 .47653 m
.49547 .47698 L
s
.49628 .47651 m
.49539 .47697 L
s
.39336 .48245 m
.39241 .4821 L
s
.29399 .48196 m
.29361 .48153 L
s
.85743 .32111 m
.85746 .32137 L
s
.49637 .47648 m
.49548 .47693 L
s
.70498 .46877 m
.70481 .46912 L
s
.39316 .48238 m
.39222 .48204 L
s
.49665 .47638 m
.49576 .47684 L
s
.39296 .48235 m
.39202 .48201 L
s
.49657 .47635 m
.49568 .47681 L
s
.29377 .48184 m
.29338 .48141 L
s
.20464 .57653 m
.20437 .57622 L
s
.39304 .48232 m
.3921 .48197 L
s
.60872 .47763 m
.60841 .47803 L
s
.18179 .48843 m
.18157 .48809 L
s
.70503 .46866 m
.70487 .46902 L
s
.60876 .47761 m
.60844 .47802 L
s
.39292 .48229 m
.39198 .48194 L
s
.18171 .48835 m
.18148 .48802 L
s
.49705 .47619 m
.49617 .47665 L
s
.2936 .48171 m
.29322 .48128 L
s
.39278 .48222 m
.39185 .48187 L
s
.39291 .48223 m
.39197 .48188 L
s
.85739 .32085 m
.85743 .32111 L
s
.49694 .47618 m
.49606 .47664 L
s
.49687 .47619 m
.49599 .47665 L
s
.39254 .48218 m
.39161 .48183 L
s
.49703 .47616 m
.49615 .47662 L
s
.60886 .47744 m
.60855 .47784 L
s
.49699 .47614 m
.49611 .4766 L
s
.60897 .47743 m
.60865 .47784 L
s
.49704 .47612 m
.49616 .47658 L
s
.39268 .48214 m
.39175 .48179 L
s
.39278 .48215 m
.39184 .4818 L
s
.49724 .47607 m
.49636 .47653 L
s
.39241 .4821 m
.39148 .48175 L
s
.49716 .47605 m
.49628 .47651 L
s
.70514 .46841 m
.70498 .46877 L
s
.29361 .48153 m
.29323 .48111 L
s
.49725 .47602 m
.49637 .47648 L
s
.39222 .48204 m
.39128 .48169 L
s
.39202 .48201 m
.39109 .48165 L
s
.18157 .48809 m
.18134 .48776 L
s
.49752 .47592 m
.49665 .47638 L
s
.20437 .57622 m
.2041 .5759 L
s
.7052 .46831 m
.70503 .46866 L
s
.85736 .32059 m
.85739 .32085 L
s
.49744 .47589 m
.49657 .47635 L
s
.3921 .48197 m
.39117 .48162 L
s
.29338 .48141 m
.293 .48098 L
s
.60903 .47722 m
.60872 .47763 L
s
.60907 .4772 m
.60876 .47761 L
s
.18148 .48802 m
.18126 .48769 L
s
.39198 .48194 m
.39105 .48159 L
s
.49792 .47573 m
.49705 .47619 L
s
.39185 .48187 m
.39091 .48152 L
s
.39197 .48188 m
.39103 .48153 L
s
.29322 .48128 m
.29284 .48085 L
s
.49774 .47572 m
.49687 .47619 L
s
.49781 .47571 m
.49694 .47618 L
s
.39161 .48183 m
.39068 .48147 L
s
.4979 .47569 m
.49703 .47616 L
s
.60917 .47703 m
.60886 .47744 L
s
.60928 .47702 m
.60897 .47743 L
s
.49786 .47568 m
.49699 .47614 L
s
.49791 .47566 m
.49704 .47612 L
s
.39175 .48179 m
.39082 .48144 L
s
.70531 .46806 m
.70514 .46841 L
s
.39184 .4818 m
.39091 .48144 L
s
.85733 .32033 m
.85736 .32059 L
s
.39148 .48175 m
.39055 .48139 L
s
.4981 .4756 m
.49724 .47607 L
s
.49802 .47559 m
.49716 .47605 L
s
.18134 .48776 m
.18112 .48743 L
s
.29323 .48111 m
.29285 .48068 L
s
.49811 .47555 m
.49725 .47602 L
s
.70537 .46796 m
.7052 .46831 L
s
.39128 .48169 m
.39036 .48133 L
s
.2041 .5759 m
.20383 .57558 L
s
.39109 .48165 m
.39017 .48129 L
s
.49838 .47545 m
.49752 .47592 L
s
.18126 .48769 m
.18104 .48735 L
s
.49831 .47542 m
.49744 .47589 L
s
.39117 .48162 m
.39024 .48126 L
s
.60934 .47681 m
.60903 .47722 L
s
.60938 .47679 m
.60907 .4772 L
s
.293 .48098 m
.29263 .48055 L
s
.39105 .48159 m
.39013 .48123 L
s
.85729 .32007 m
.85733 .32033 L
s
.39091 .48152 m
.38999 .48115 L
s
.39103 .48153 m
.39011 .48117 L
s
.49878 .47525 m
.49792 .47573 L
s
.39068 .48147 m
.38976 .48111 L
s
.4986 .47525 m
.49774 .47572 L
s
.29284 .48085 m
.29247 .48042 L
s
.49868 .47524 m
.49781 .47571 L
s
.70548 .46771 m
.70531 .46806 L
s
.49876 .47522 m
.4979 .47569 L
s
.60948 .47662 m
.60917 .47703 L
s
.60959 .47661 m
.60928 .47702 L
s
.49872 .4752 m
.49786 .47568 L
s
.39082 .48144 m
.38989 .48107 L
s
.39091 .48144 m
.38999 .48108 L
s
.49877 .47518 m
.49791 .47566 L
s
.39055 .48139 m
.38963 .48103 L
s
.18112 .48743 m
.1809 .4871 L
s
.49896 .47513 m
.4981 .4756 L
s
.49888 .47511 m
.49802 .47559 L
s
.70553 .46761 m
.70537 .46796 L
s
.85726 .31981 m
.85729 .32007 L
s
.20383 .57558 m
.20356 .57526 L
s
.18104 .48735 m
.18082 .48702 L
s
.29285 .48068 m
.29247 .48024 L
s
.49897 .47507 m
.49811 .47555 L
s
.39036 .48133 m
.38944 .48096 L
s
.39017 .48129 m
.38925 .48092 L
s
.49924 .47497 m
.49838 .47545 L
s
.60965 .4764 m
.60934 .47681 L
s
.39024 .48126 m
.38933 .48089 L
s
.49916 .47495 m
.49831 .47542 L
s
.60968 .47638 m
.60938 .47679 L
s
.29263 .48055 m
.29225 .48012 L
s
.39013 .48123 m
.38921 .48086 L
s
.70564 .46736 m
.70548 .46771 L
s
.38999 .48115 m
.38908 .48079 L
s
.39011 .48117 m
.3892 .4808 L
s
.49963 .47478 m
.49878 .47525 L
s
.85722 .31955 m
.85726 .31981 L
s
.38976 .48111 m
.38885 .48074 L
s
.60979 .47621 m
.60948 .47662 L
s
.49946 .47477 m
.4986 .47525 L
s
.60989 .4762 m
.60959 .47661 L
s
.49953 .47476 m
.49868 .47524 L
s
.1809 .4871 m
.18068 .48676 L
s
.29247 .48042 m
.29209 .47998 L
s
.49961 .47474 m
.49876 .47522 L
s
.7057 .46725 m
.70553 .46761 L
s
.38989 .48107 m
.38898 .4807 L
s
.38999 .48108 m
.38908 .48071 L
s
.49957 .47472 m
.49872 .4752 L
s
.38963 .48103 m
.38872 .48066 L
s
.49962 .4747 m
.49877 .47518 L
s
.18082 .48702 m
.1806 .48669 L
s
.49981 .47465 m
.49896 .47513 L
s
.49973 .47463 m
.49888 .47511 L
s
.20356 .57526 m
.2033 .57494 L
s
.38944 .48096 m
.38853 .48059 L
s
.49982 .47459 m
.49897 .47507 L
s
.29247 .48024 m
.2921 .47981 L
s
.38925 .48092 m
.38835 .48055 L
s
.60995 .47599 m
.60965 .4764 L
s
.85719 .31929 m
.85722 .31955 L
s
.50008 .47449 m
.49924 .47497 L
s
.60999 .47597 m
.60968 .47638 L
s
.38933 .48089 m
.38842 .48052 L
s
.50001 .47446 m
.49916 .47495 L
s
.38921 .48086 m
.38831 .48049 L
s
.7058 .467 m
.70564 .46736 L
s
.29225 .48012 m
.29188 .47969 L
s
.18068 .48676 m
.18047 .48643 L
s
.38908 .48079 m
.38817 .48041 L
s
.3892 .4808 m
.38829 .48042 L
s
.70586 .4669 m
.7057 .46725 L
s
.50047 .47429 m
.49963 .47478 L
s
.61009 .4758 m
.60979 .47621 L
s
.61019 .47579 m
.60989 .4762 L
s
.38885 .48074 m
.38794 .48036 L
s
.5003 .47429 m
.49946 .47477 L
s
.50037 .47428 m
.49953 .47476 L
s
.1806 .48669 m
.18038 .48636 L
s
.29209 .47998 m
.29172 .47955 L
s
.50045 .47425 m
.49961 .47474 L
s
.38898 .4807 m
.38808 .48033 L
s
.38908 .48071 m
.38817 .48033 L
s
.85715 .31903 m
.85719 .31929 L
s
.50041 .47424 m
.49957 .47472 L
s
.38872 .48066 m
.38782 .48028 L
s
.50046 .47422 m
.49962 .4747 L
s
.2033 .57494 m
.20303 .57462 L
s
.50064 .47416 m
.49981 .47465 L
s
.50057 .47415 m
.49973 .47463 L
s
.38853 .48059 m
.38763 .48021 L
s
.50066 .47411 m
.49982 .47459 L
s
.2921 .47981 m
.29173 .47938 L
s
.38835 .48055 m
.38745 .48017 L
s
.61025 .47558 m
.60995 .47599 L
s
.61029 .47556 m
.60999 .47597 L
s
.70597 .46665 m
.7058 .467 L
s
.38842 .48052 m
.38752 .48013 L
s
.50092 .474 m
.50008 .47449 L
s
.50084 .47398 m
.50001 .47446 L
s
.18047 .48643 m
.18025 .4861 L
s
.38831 .48049 m
.38741 .4801 L
s
.85711 .31877 m
.85715 .31903 L
s
.29188 .47969 m
.29152 .47925 L
s
.70602 .46655 m
.70586 .4669 L
s
.38817 .48041 m
.38728 .48003 L
s
.18038 .48636 m
.18017 .48602 L
s
.38829 .48042 m
.38739 .48004 L
s
.61039 .47538 m
.61009 .4758 L
s
.61049 .47538 m
.61019 .47579 L
s
.38794 .48036 m
.38705 .47998 L
s
.50129 .4738 m
.50047 .47429 L
s
.50113 .4738 m
.5003 .47429 L
s
.29172 .47955 m
.29136 .47912 L
s
.5012 .47379 m
.50037 .47428 L
s
.38808 .48033 m
.38718 .47994 L
s
.20303 .57462 m
.20277 .5743 L
s
.38817 .48033 m
.38728 .47994 L
s
.50128 .47376 m
.50045 .47425 L
s
.38782 .48028 m
.38693 .47989 L
s
.50125 .47375 m
.50041 .47424 L
s
.50129 .47373 m
.50046 .47422 L
s
.85708 .31851 m
.85711 .31877 L
s
.50147 .47367 m
.50064 .47416 L
s
.5014 .47366 m
.50057 .47415 L
s
.70613 .4663 m
.70597 .46665 L
s
.38763 .48021 m
.38674 .47982 L
s
.61055 .47516 m
.61025 .47558 L
s
.61059 .47515 m
.61029 .47556 L
s
.29173 .47938 m
.29137 .47894 L
s
.38745 .48017 m
.38656 .47978 L
s
.50148 .47361 m
.50066 .47411 L
s
.18025 .4861 m
.18003 .48576 L
s
.38752 .48013 m
.38663 .47975 L
s
.70618 .46619 m
.70602 .46655 L
s
.50174 .47351 m
.50092 .474 L
s
.50166 .47348 m
.50084 .47398 L
s
.18017 .48602 m
.17995 .48569 L
s
.38741 .4801 m
.38652 .47971 L
s
.29152 .47925 m
.29115 .47882 L
s
.61079 .47497 m
.61049 .47538 L
s
.61068 .47497 m
.61039 .47538 L
s
.85704 .31825 m
.85708 .31851 L
s
.38728 .48003 m
.38639 .47964 L
s
.38739 .48004 m
.3865 .47965 L
s
.38705 .47998 m
.38617 .47959 L
s
.20277 .5743 m
.20251 .57398 L
s
.50211 .4733 m
.50129 .4738 L
s
.29136 .47912 m
.291 .47868 L
s
.50195 .4733 m
.50113 .4738 L
s
.38718 .47994 m
.3863 .47955 L
s
.50202 .47329 m
.5012 .47379 L
s
.38728 .47994 m
.38639 .47955 L
s
.50209 .47326 m
.50128 .47376 L
s
.38693 .47989 m
.38604 .4795 L
s
.70628 .46594 m
.70613 .4663 L
s
.50207 .47325 m
.50125 .47375 L
s
.5021 .47323 m
.50129 .47373 L
s
.18003 .48576 m
.17982 .48543 L
s
.50228 .47317 m
.50147 .47367 L
s
.61085 .47475 m
.61055 .47516 L
s
.50221 .47316 m
.5014 .47366 L
s
.61088 .47474 m
.61059 .47515 L
s
.38674 .47982 m
.38586 .47943 L
s
.70634 .46584 m
.70618 .46619 L
s
.857 .318 m
.85704 .31825 L
s
.29137 .47894 m
.29101 .47851 L
s
.38656 .47978 m
.38568 .47939 L
s
.17995 .48569 m
.17974 .48535 L
s
.5023 .47311 m
.50148 .47361 L
s
.38663 .47975 m
.38575 .47935 L
s
.50255 .47301 m
.50174 .47351 L
s
.38652 .47971 m
.38564 .47932 L
s
.50248 .47298 m
.50166 .47348 L
s
.29115 .47882 m
.29079 .47838 L
s
.61108 .47455 m
.61079 .47497 L
s
.61098 .47456 m
.61068 .47497 L
s
.38639 .47964 m
.38551 .47924 L
s
.3865 .47965 m
.38563 .47925 L
s
.20251 .57398 m
.20224 .57366 L
s
.38617 .47959 m
.38529 .47919 L
s
.70644 .46559 m
.70628 .46594 L
s
.85696 .31774 m
.857 .318 L
s
.50292 .4728 m
.50211 .4733 L
s
.291 .47868 m
.29064 .47825 L
s
.3863 .47955 m
.38542 .47915 L
s
.17982 .48543 m
.17961 .48509 L
s
.38639 .47955 m
.38551 .47915 L
s
.50276 .4728 m
.50195 .4733 L
s
.50283 .47278 m
.50202 .47329 L
s
.38604 .4795 m
.38517 .4791 L
s
.5029 .47276 m
.50209 .47326 L
s
.7065 .46549 m
.70634 .46584 L
s
.50287 .47275 m
.50207 .47325 L
s
.61114 .47434 m
.61085 .47475 L
s
.17974 .48535 m
.17952 .48502 L
s
.50291 .47272 m
.5021 .47323 L
s
.61117 .47432 m
.61088 .47474 L
s
.50309 .47266 m
.50228 .47317 L
s
.50302 .47265 m
.50221 .47316 L
s
.38586 .47943 m
.38499 .47903 L
s
.29101 .47851 m
.29065 .47807 L
s
.38568 .47939 m
.38481 .47899 L
s
.50311 .47261 m
.5023 .47311 L
s
.38575 .47935 m
.38488 .47895 L
s
.85692 .31748 m
.85696 .31774 L
s
.50335 .4725 m
.50255 .47301 L
s
.61137 .47414 m
.61108 .47455 L
s
.38564 .47932 m
.38477 .47892 L
s
.61127 .47414 m
.61098 .47456 L
s
.29079 .47838 m
.29043 .47794 L
s
.50328 .47247 m
.50248 .47298 L
s
.20224 .57366 m
.20198 .57333 L
s
.7066 .46523 m
.70644 .46559 L
s
.38551 .47924 m
.38465 .47884 L
s
.38563 .47925 m
.38476 .47885 L
s
.17961 .48509 m
.17939 .48476 L
s
.38529 .47919 m
.38443 .47879 L
s
.70665 .46513 m
.7065 .46549 L
s
.29064 .47825 m
.29028 .47781 L
s
.17952 .48502 m
.17931 .48468 L
s
.50372 .47229 m
.50292 .4728 L
s
.38542 .47915 m
.38455 .47875 L
s
.38551 .47915 m
.38464 .47875 L
s
.85688 .31722 m
.85692 .31748 L
s
.50356 .47229 m
.50276 .4728 L
s
.38517 .4791 m
.3843 .4787 L
s
.50362 .47227 m
.50283 .47278 L
s
.61143 .47392 m
.61114 .47434 L
s
.61146 .47391 m
.61117 .47432 L
s
.5037 .47225 m
.5029 .47276 L
s
.50367 .47224 m
.50287 .47275 L
s
.50371 .47221 m
.50291 .47272 L
s
.50388 .47215 m
.50309 .47266 L
s
.38499 .47903 m
.38413 .47862 L
s
.29065 .47807 m
.29029 .47763 L
s
.50381 .47214 m
.50302 .47265 L
s
.38481 .47899 m
.38395 .47858 L
s
.38488 .47895 m
.38402 .47854 L
s
.5039 .47209 m
.50311 .47261 L
s
.70675 .46488 m
.7066 .46523 L
s
.61166 .47373 m
.61137 .47414 L
s
.61156 .47373 m
.61127 .47414 L
s
.20198 .57333 m
.20172 .57301 L
s
.85684 .31696 m
.85688 .31722 L
s
.17939 .48476 m
.17918 .48442 L
s
.38477 .47892 m
.38391 .47851 L
s
.29043 .47794 m
.29008 .47751 L
s
.50414 .47199 m
.50335 .4725 L
s
.50407 .47196 m
.50328 .47247 L
s
.70681 .46478 m
.70665 .46513 L
s
.17931 .48468 m
.1791 .48435 L
s
.38465 .47884 m
.38379 .47843 L
s
.38476 .47885 m
.3839 .47844 L
s
.38443 .47879 m
.38357 .47838 L
s
.29028 .47781 m
.28993 .47737 L
s
.61171 .47351 m
.61143 .47392 L
s
.38455 .47875 m
.38369 .47834 L
s
.38464 .47875 m
.38378 .47834 L
s
.61175 .47349 m
.61146 .47391 L
s
.5045 .47178 m
.50372 .47229 L
s
.3843 .4787 m
.38345 .47829 L
s
.50435 .47177 m
.50356 .47229 L
s
.50441 .47176 m
.50362 .47227 L
s
.8568 .3167 m
.85684 .31696 L
s
.50448 .47173 m
.5037 .47225 L
s
.50446 .47172 m
.50367 .47224 L
s
.50449 .47169 m
.50371 .47221 L
s
.29029 .47763 m
.28994 .47719 L
s
.70691 .46452 m
.70675 .46488 L
s
.38413 .47862 m
.38328 .47821 L
s
.50466 .47163 m
.50388 .47215 L
s
.17918 .48442 m
.17897 .48408 L
s
.5046 .47162 m
.50381 .47214 L
s
.20172 .57301 m
.20146 .57268 L
s
.38395 .47858 m
.3831 .47816 L
s
.61195 .47331 m
.61166 .47373 L
s
.61184 .47331 m
.61156 .47373 L
s
.38402 .47854 m
.38317 .47813 L
s
.50468 .47158 m
.5039 .47209 L
s
.70696 .46442 m
.70681 .46478 L
s
.1791 .48435 m
.17889 .48401 L
s
.29008 .47751 m
.28973 .47707 L
s
.38391 .47851 m
.38306 .47809 L
s
.50492 .47147 m
.50414 .47199 L
s
.85676 .31644 m
.8568 .3167 L
s
.50485 .47144 m
.50407 .47196 L
s
.38379 .47843 m
.38294 .47801 L
s
.3839 .47844 m
.38305 .47802 L
s
.612 .47309 m
.61171 .47351 L
s
.28993 .47737 m
.28958 .47693 L
s
.38357 .47838 m
.38272 .47796 L
s
.61203 .47308 m
.61175 .47349 L
s
.38369 .47834 m
.38285 .47792 L
s
.38378 .47834 m
.38293 .47792 L
s
.50527 .47126 m
.5045 .47178 L
s
.38345 .47829 m
.3826 .47787 L
s
.70706 .46417 m
.70691 .46452 L
s
.17897 .48408 m
.17877 .48375 L
s
.50512 .47125 m
.50435 .47177 L
s
.50519 .47124 m
.50441 .47176 L
s
.50525 .47121 m
.50448 .47173 L
s
.20146 .57268 m
.20121 .57236 L
s
.85672 .31618 m
.85676 .31644 L
s
.50524 .4712 m
.50446 .47172 L
s
.28994 .47719 m
.28959 .47675 L
s
.61223 .47289 m
.61195 .47331 L
s
.50527 .47117 m
.50449 .47169 L
s
.61212 .4729 m
.61184 .47331 L
s
.17889 .48401 m
.17868 .48367 L
s
.70711 .46406 m
.70696 .46442 L
s
.38328 .47821 m
.38243 .47779 L
s
.3831 .47816 m
.38226 .47774 L
s
.50543 .47111 m
.50466 .47163 L
s
.50537 .4711 m
.5046 .47162 L
s
.38317 .47813 m
.38233 .47771 L
s
.28973 .47707 m
.28938 .47663 L
s
.50546 .47105 m
.50468 .47158 L
s
.38306 .47809 m
.38222 .47767 L
s
.50569 .47095 m
.50492 .47147 L
s
.50562 .47092 m
.50485 .47144 L
s
.85667 .31593 m
.85672 .31618 L
s
.61228 .47267 m
.612 .47309 L
s
.38294 .47801 m
.3821 .47759 L
s
.38305 .47802 m
.3822 .4776 L
s
.61231 .47266 m
.61203 .47308 L
s
.28958 .47693 m
.28923 .47649 L
s
.70721 .46381 m
.70706 .46417 L
s
.17877 .48375 m
.17856 .48341 L
s
.38272 .47796 m
.38189 .47753 L
s
.38285 .47792 m
.38201 .4775 L
s
.38293 .47792 m
.3821 .4775 L
s
.20121 .57236 m
.20095 .57203 L
s
.17868 .48367 m
.17848 .48334 L
s
.3826 .47787 m
.38177 .47745 L
s
.70726 .46371 m
.70711 .46406 L
s
.50604 .47073 m
.50527 .47126 L
s
.50589 .47072 m
.50512 .47125 L
s
.61251 .47248 m
.61223 .47289 L
s
.6124 .47248 m
.61212 .4729 L
s
.50595 .47071 m
.50519 .47124 L
s
.28959 .47675 m
.28925 .47631 L
s
.50602 .47068 m
.50525 .47121 L
s
.506 .47067 m
.50524 .4712 L
s
.85663 .31567 m
.85667 .31593 L
s
.38243 .47779 m
.3816 .47736 L
s
.50603 .47064 m
.50527 .47117 L
s
.38226 .47774 m
.38143 .47732 L
s
.50619 .47058 m
.50543 .47111 L
s
.50613 .47057 m
.50537 .4711 L
s
.38233 .47771 m
.38149 .47728 L
s
.28938 .47663 m
.28904 .47619 L
s
.50622 .47052 m
.50546 .47105 L
s
.38222 .47767 m
.38139 .47724 L
s
.70736 .46346 m
.70721 .46381 L
s
.17856 .48341 m
.17835 .48307 L
s
.61255 .47226 m
.61228 .47267 L
s
.61259 .47224 m
.61231 .47266 L
s
.50644 .47042 m
.50569 .47095 L
s
.28923 .47649 m
.28889 .47605 L
s
.3821 .47759 m
.38127 .47716 L
s
.3822 .4776 m
.38137 .47717 L
s
.50637 .47038 m
.50562 .47092 L
s
.17848 .48334 m
.17827 .483 L
s
.85659 .31541 m
.85663 .31567 L
s
.70741 .46335 m
.70726 .46371 L
s
.20095 .57203 m
.20069 .5717 L
s
.38189 .47753 m
.38106 .4771 L
s
.38201 .4775 m
.38118 .47707 L
s
.3821 .4775 m
.38127 .47707 L
s
.61278 .47206 m
.61251 .47248 L
s
.61268 .47206 m
.6124 .47248 L
s
.38177 .47745 m
.38094 .47701 L
s
.50679 .4702 m
.50604 .47073 L
s
.28925 .47631 m
.28891 .47587 L
s
.50664 .47019 m
.50589 .47072 L
s
.5067 .47017 m
.50595 .47071 L
s
.50677 .47015 m
.50602 .47068 L
s
.50675 .47014 m
.506 .47067 L
s
.3816 .47736 m
.38078 .47693 L
s
.85654 .31515 m
.85659 .31541 L
s
.50678 .47011 m
.50603 .47064 L
s
.70751 .4631 m
.70736 .46346 L
s
.38143 .47732 m
.38061 .47688 L
s
.17835 .48307 m
.17815 .48274 L
s
.28904 .47619 m
.2887 .47574 L
s
.50694 .47005 m
.50619 .47058 L
s
.50688 .47004 m
.50613 .47057 L
s
.38149 .47728 m
.38067 .47685 L
s
.61283 .47184 m
.61255 .47226 L
s
.61286 .47182 m
.61259 .47224 L
s
.17827 .483 m
.17807 .48266 L
s
.70756 .463 m
.70741 .46335 L
s
.38139 .47724 m
.38057 .47681 L
s
.50697 .46999 m
.50622 .47052 L
s
.20069 .5717 m
.20044 .57137 L
s
.28889 .47605 m
.28855 .47561 L
s
.50719 .46988 m
.50644 .47042 L
s
.38127 .47716 m
.38045 .47672 L
s
.38137 .47717 m
.38055 .47674 L
s
.50712 .46985 m
.50637 .47038 L
s
.8565 .31489 m
.85654 .31515 L
s
.38106 .4771 m
.38024 .47667 L
s
.61306 .47164 m
.61278 .47206 L
s
.61295 .47164 m
.61268 .47206 L
s
.38118 .47707 m
.38036 .47663 L
s
.38127 .47707 m
.38045 .47663 L
s
.28891 .47587 m
.28857 .47543 L
s
.38094 .47701 m
.38012 .47658 L
s
.17815 .48274 m
.17795 .4824 L
s
.70766 .46274 m
.70751 .4631 L
s
.50753 .46966 m
.50679 .4702 L
s
.50738 .46965 m
.50664 .47019 L
s
.50745 .46964 m
.5067 .47017 L
s
.17807 .48266 m
.17786 .48233 L
s
.5075 .46961 m
.50677 .47015 L
s
.38078 .47693 m
.37996 .47649 L
s
.2887 .47574 m
.28836 .4753 L
s
.5075 .4696 m
.50675 .47014 L
s
.70771 .46264 m
.70756 .463 L
s
.6131 .47142 m
.61283 .47184 L
s
.38061 .47688 m
.3798 .47644 L
s
.50752 .46957 m
.50678 .47011 L
s
.85645 .31464 m
.8565 .31489 L
s
.61314 .4714 m
.61286 .47182 L
s
.38067 .47685 m
.37986 .47641 L
s
.50768 .46951 m
.50694 .47005 L
s
.50762 .4695 m
.50688 .47004 L
s
.20044 .57137 m
.20019 .57105 L
s
.38057 .47681 m
.37976 .47637 L
s
.28855 .47561 m
.28821 .47516 L
s
.5077 .46944 m
.50697 .46999 L
s
.61333 .47122 m
.61306 .47164 L
s
.61322 .47122 m
.61295 .47164 L
s
.38045 .47672 m
.37964 .47628 L
s
.38055 .47674 m
.37974 .47629 L
s
.50792 .46934 m
.50719 .46988 L
s
.50785 .46931 m
.50712 .46985 L
s
.17795 .4824 m
.17774 .48206 L
s
.7078 .46239 m
.70766 .46274 L
s
.38024 .47667 m
.37944 .47623 L
s
.85641 .31438 m
.85645 .31464 L
s
.28857 .47543 m
.28823 .47498 L
s
.38036 .47663 m
.37955 .47619 L
s
.38045 .47663 m
.37964 .47619 L
s
.17786 .48233 m
.17766 .48199 L
s
.38012 .47658 m
.37932 .47613 L
s
.70785 .46228 m
.70771 .46264 L
s
.50826 .46911 m
.50753 .46966 L
s
.61337 .471 m
.6131 .47142 L
s
.28836 .4753 m
.28802 .47486 L
s
.6134 .47098 m
.61314 .4714 L
s
.50812 .46911 m
.50738 .46965 L
s
.50817 .46909 m
.50745 .46964 L
s
.20019 .57105 m
.19993 .57072 L
s
.37996 .47649 m
.37916 .47604 L
s
.50823 .46906 m
.5075 .46961 L
s
.3798 .47644 m
.37899 .476 L
s
.50823 .46905 m
.5075 .4696 L
s
.50825 .46902 m
.50752 .46957 L
s
.85636 .31412 m
.85641 .31438 L
s
.37986 .47641 m
.37905 .47596 L
s
.5084 .46896 m
.50768 .46951 L
s
.50834 .46895 m
.50762 .4695 L
s
.28821 .47516 m
.28788 .47472 L
s
.17774 .48206 m
.17754 .48172 L
s
.37976 .47637 m
.37895 .47592 L
s
.70795 .46203 m
.7078 .46239 L
s
.6136 .4708 m
.61333 .47122 L
s
.61349 .4708 m
.61322 .47122 L
s
.50843 .4689 m
.5077 .46944 L
s
.17766 .48199 m
.17746 .48165 L
s
.37964 .47628 m
.37884 .47583 L
s
.37974 .47629 m
.37894 .47585 L
s
.50864 .46879 m
.50792 .46934 L
s
.708 .46193 m
.70785 .46228 L
s
.37944 .47623 m
.37864 .47578 L
s
.50858 .46876 m
.50785 .46931 L
s
.28823 .47498 m
.2879 .47454 L
s
.85631 .31386 m
.85636 .31412 L
s
.37955 .47619 m
.37875 .47574 L
s
.37964 .47619 m
.37884 .47574 L
s
.37932 .47613 m
.37852 .47569 L
s
.61363 .47058 m
.61337 .471 L
s
.61367 .47056 m
.6134 .47098 L
s
.19993 .57072 m
.19968 .57039 L
s
.28802 .47486 m
.28769 .47441 L
s
.50897 .46856 m
.50826 .46911 L
s
.50883 .46856 m
.50812 .46911 L
s
.37916 .47604 m
.37837 .47559 L
s
.17754 .48172 m
.17734 .48138 L
s
.50889 .46854 m
.50817 .46909 L
s
.70809 .46167 m
.70795 .46203 L
s
.50895 .46851 m
.50823 .46906 L
s
.37899 .476 m
.3782 .47555 L
s
.50894 .4685 m
.50823 .46905 L
s
.28788 .47472 m
.28755 .47427 L
s
.85627 .31361 m
.85631 .31386 L
s
.61386 .47038 m
.6136 .4708 L
s
.37905 .47596 m
.37826 .47551 L
s
.50896 .46847 m
.50825 .46902 L
s
.61375 .47038 m
.61349 .4708 L
s
.17746 .48165 m
.17726 .48131 L
s
.50912 .46841 m
.5084 .46896 L
s
.70814 .46157 m
.708 .46193 L
s
.50906 .4684 m
.50834 .46895 L
s
.37895 .47592 m
.37816 .47547 L
s
.50914 .46834 m
.50843 .4689 L
s
.37884 .47583 m
.37805 .47538 L
s
.37894 .47585 m
.37815 .47539 L
s
.2879 .47454 m
.28757 .47409 L
s
.50935 .46824 m
.50864 .46879 L
s
.37864 .47578 m
.37785 .47532 L
s
.19968 .57039 m
.19943 .57005 L
s
.61389 .47016 m
.61363 .47058 L
s
.50928 .4682 m
.50858 .46876 L
s
.61393 .47014 m
.61367 .47056 L
s
.85622 .31335 m
.85627 .31361 L
s
.37875 .47574 m
.37796 .47528 L
s
.37884 .47574 m
.37805 .47528 L
s
.17734 .48138 m
.17714 .48105 L
s
.28769 .47441 m
.28737 .47397 L
s
.37852 .47569 m
.37774 .47523 L
s
.70823 .46131 m
.70809 .46167 L
s
.17726 .48131 m
.17707 .48097 L
s
.50968 .46801 m
.50897 .46856 L
s
.70828 .46121 m
.70814 .46157 L
s
.61412 .46996 m
.61386 .47038 L
s
.61401 .46996 m
.61375 .47038 L
s
.37837 .47559 m
.37758 .47514 L
s
.50954 .468 m
.50883 .46856 L
s
.28755 .47427 m
.28722 .47383 L
s
.5096 .46798 m
.50889 .46854 L
s
.3782 .47555 m
.37742 .47509 L
s
.50965 .46796 m
.50895 .46851 L
s
.50965 .46795 m
.50894 .4685 L
s
.37826 .47551 m
.37748 .47505 L
s
.85617 .31309 m
.85622 .31335 L
s
.50966 .46791 m
.50896 .46847 L
s
.50982 .46785 m
.50912 .46841 L
s
.37816 .47547 m
.37738 .47501 L
s
.50976 .46784 m
.50906 .4684 L
s
.19943 .57005 m
.19918 .56972 L
s
.28757 .47409 m
.28724 .47365 L
s
.50984 .46779 m
.50914 .46834 L
s
.17714 .48105 m
.17695 .48071 L
s
.61415 .46973 m
.61389 .47016 L
s
.37805 .47538 m
.37727 .47492 L
s
.37815 .47539 m
.37737 .47493 L
s
.61419 .46972 m
.61393 .47014 L
s
.70837 .46096 m
.70823 .46131 L
s
.37785 .47532 m
.37708 .47486 L
s
.51005 .46768 m
.50935 .46824 L
s
.17707 .48097 m
.17687 .48063 L
s
.28737 .47397 m
.28704 .47352 L
s
.50998 .46765 m
.50928 .4682 L
s
.85612 .31283 m
.85617 .31309 L
s
.37796 .47528 m
.37719 .47482 L
s
.37805 .47528 m
.37727 .47482 L
s
.70842 .46085 m
.70828 .46121 L
s
.37774 .47523 m
.37696 .47477 L
s
.61438 .46954 m
.61412 .46996 L
s
.61427 .46954 m
.61401 .46996 L
s
.28722 .47383 m
.2869 .47338 L
s
.51037 .46745 m
.50968 .46801 L
s
.37758 .47514 m
.37681 .47467 L
s
.51023 .46744 m
.50954 .468 L
s
.37742 .47509 m
.37665 .47462 L
s
.51029 .46742 m
.5096 .46798 L
s
.51034 .4674 m
.50965 .46796 L
s
.17695 .48071 m
.17675 .48037 L
s
.19918 .56972 m
.19893 .56939 L
s
.37748 .47505 m
.37671 .47459 L
s
.85607 .31258 m
.85612 .31283 L
s
.51034 .46739 m
.50965 .46795 L
s
.70851 .4606 m
.70837 .46096 L
s
.51036 .46735 m
.50966 .46791 L
s
.61441 .46931 m
.61415 .46973 L
s
.28724 .47365 m
.28692 .4732 L
s
.37738 .47501 m
.37661 .47455 L
s
.61445 .4693 m
.61419 .46972 L
s
.17687 .48063 m
.17667 .48029 L
s
.5105 .46729 m
.50982 .46785 L
s
.51045 .46728 m
.50976 .46784 L
s
.70856 .4605 m
.70842 .46085 L
s
.37727 .47492 m
.3765 .47446 L
s
.37737 .47493 m
.3766 .47447 L
s
.51053 .46722 m
.50984 .46779 L
s
.28704 .47352 m
.28672 .47307 L
s
.37708 .47486 m
.37631 .4744 L
s
.51073 .46712 m
.51005 .46768 L
s
.61463 .46911 m
.61438 .46954 L
s
.61452 .46911 m
.61427 .46954 L
s
.85602 .31232 m
.85607 .31258 L
s
.51067 .46708 m
.50998 .46765 L
s
.37719 .47482 m
.37642 .47436 L
s
.37727 .47482 m
.3765 .47436 L
s
.37696 .47477 m
.3762 .4743 L
s
.2869 .47338 m
.28658 .47293 L
s
.17675 .48037 m
.17656 .48003 L
s
.19893 .56939 m
.19869 .56906 L
s
.70865 .46024 m
.70851 .4606 L
s
.37681 .47467 m
.37605 .47421 L
s
.17667 .48029 m
.17648 .47995 L
s
.51105 .46689 m
.51037 .46745 L
s
.37665 .47462 m
.37589 .47416 L
s
.61466 .46889 m
.61441 .46931 L
s
.51092 .46688 m
.51023 .46744 L
s
.51097 .46686 m
.51029 .46742 L
s
.6147 .46887 m
.61445 .4693 L
s
.70869 .46014 m
.70856 .4605 L
s
.37671 .47459 m
.37595 .47412 L
s
.85597 .31206 m
.85602 .31232 L
s
.28692 .4732 m
.2866 .47275 L
s
.51102 .46683 m
.51034 .4674 L
s
.51102 .46682 m
.51034 .46739 L
s
.51103 .46679 m
.51036 .46735 L
s
.37661 .47455 m
.37585 .47408 L
s
.51118 .46672 m
.5105 .46729 L
s
.51113 .46671 m
.51045 .46728 L
s
.28672 .47307 m
.2864 .47262 L
s
.3765 .47446 m
.37574 .47398 L
s
.3766 .47447 m
.37584 .474 L
s
.61489 .46869 m
.61463 .46911 L
s
.61478 .46869 m
.61452 .46911 L
s
.51121 .46666 m
.51053 .46722 L
s
.17656 .48003 m
.17636 .47969 L
s
.37631 .4744 m
.37556 .47393 L
s
.70878 .45988 m
.70865 .46024 L
s
.85592 .31181 m
.85597 .31206 L
s
.5114 .46655 m
.51073 .46712 L
s
.37642 .47436 m
.37566 .47388 L
s
.19869 .56906 m
.19844 .56872 L
s
.3765 .47436 m
.37574 .47388 L
s
.28658 .47293 m
.28626 .47248 L
s
.17648 .47995 m
.17629 .47961 L
s
.51134 .46651 m
.51067 .46708 L
s
.3762 .4743 m
.37544 .47383 L
s
.70883 .45978 m
.70869 .46014 L
s
.61491 .46846 m
.61466 .46889 L
s
.61495 .46845 m
.6147 .46887 L
s
.37605 .47421 m
.3753 .47373 L
s
.2866 .47275 m
.28629 .4723 L
s
.51171 .46632 m
.51105 .46689 L
s
.37589 .47416 m
.37514 .47368 L
s
.51159 .46631 m
.51092 .46688 L
s
.85587 .31155 m
.85592 .31181 L
s
.51164 .46629 m
.51097 .46686 L
s
.37595 .47412 m
.3752 .47365 L
s
.51168 .46626 m
.51102 .46683 L
s
.51169 .46625 m
.51102 .46682 L
s
.17636 .47969 m
.17617 .47935 L
s
.61513 .46826 m
.61489 .46869 L
s
.37585 .47408 m
.3751 .4736 L
s
.61502 .46826 m
.61478 .46869 L
s
.2864 .47262 m
.28609 .47217 L
s
.5117 .46621 m
.51103 .46679 L
s
.70892 .45952 m
.70878 .45988 L
s
.51184 .46615 m
.51118 .46672 L
s
.17629 .47961 m
.17609 .47927 L
s
.51179 .46614 m
.51113 .46671 L
s
.19844 .56872 m
.19819 .56839 L
s
.37574 .47398 m
.375 .47351 L
s
.37584 .474 m
.37509 .47352 L
s
.51187 .46608 m
.51121 .46666 L
s
.70896 .45942 m
.70883 .45978 L
s
.37556 .47393 m
.37481 .47345 L
s
.28626 .47248 m
.28595 .47203 L
s
.85582 .31129 m
.85587 .31155 L
s
.37566 .47388 m
.37492 .47341 L
s
.37574 .47388 m
.375 .47341 L
s
.51206 .46598 m
.5114 .46655 L
s
.61516 .46804 m
.61491 .46846 L
s
.6152 .46802 m
.61495 .46845 L
s
.37544 .47383 m
.3747 .47335 L
s
.512 .46594 m
.51134 .46651 L
s
.28629 .4723 m
.28598 .47185 L
s
.17617 .47935 m
.17598 .479 L
s
.3753 .47373 m
.37456 .47325 L
s
.70905 .45916 m
.70892 .45952 L
s
.37514 .47368 m
.3744 .4732 L
s
.61538 .46784 m
.61513 .46826 L
s
.17609 .47927 m
.1759 .47893 L
s
.61527 .46784 m
.61502 .46826 L
s
.51237 .46574 m
.51171 .46632 L
s
.85576 .31104 m
.85582 .31129 L
s
.3752 .47365 m
.37446 .47317 L
s
.28609 .47217 m
.28578 .47172 L
s
.51224 .46573 m
.51159 .46631 L
s
.5123 .46571 m
.51164 .46629 L
s
.19819 .56839 m
.19795 .56805 L
s
.51234 .46568 m
.51168 .46626 L
s
.7091 .45906 m
.70896 .45942 L
s
.51235 .46567 m
.51169 .46625 L
s
.3751 .4736 m
.37437 .47312 L
s
.51236 .46564 m
.5117 .46621 L
s
.51249 .46558 m
.51184 .46615 L
s
.28595 .47203 m
.28564 .47158 L
s
.51244 .46556 m
.51179 .46614 L
s
.375 .47351 m
.37426 .47303 L
s
.37509 .47352 m
.37436 .47304 L
s
.6154 .46761 m
.61516 .46804 L
s
.61544 .4676 m
.6152 .46802 L
s
.37481 .47345 m
.37408 .47297 L
s
.51253 .46551 m
.51187 .46608 L
s
.85571 .31078 m
.85576 .31104 L
s
.17598 .479 m
.17579 .47866 L
s
.37492 .47341 m
.37418 .47292 L
s
.375 .47341 m
.37426 .47292 L
s
.44287 .46987 m
.4414 .46991 L
s
.44434 .46981 m
.44287 .46987 L
s
.4414 .46991 m
.43993 .46992 L
s
.44278 .46987 m
.44131 .46991 L
s
.44425 .46981 m
.44278 .46987 L
s
.51271 .4654 m
.51206 .46598 L
s
.44131 .46991 m
.43984 .46992 L
s
.44197 .46988 m
.4405 .4699 L
s
.44344 .46983 m
.44197 .46988 L
s
.44239 .46987 m
.44092 .4699 L
s
.44386 .46981 m
.44239 .46987 L
s
.3747 .47335 m
.37397 .47287 L
s
.44248 .46986 m
.44101 .46989 L
s
.44395 .46981 m
.44248 .46986 L
s
.70918 .45881 m
.70905 .45916 L
s
.44208 .46987 m
.44061 .46989 L
s
.44355 .46982 m
.44208 .46987 L
s
.4449 .46976 m
.44344 .46983 L
s
.4458 .46972 m
.44434 .46981 L
s
.44101 .46989 m
.43954 .4699 L
s
.44149 .46988 m
.44002 .4699 L
s
.44296 .46984 m
.44149 .46988 L
s
.44092 .4699 m
.43945 .4699 L
s
.44443 .46978 m
.44296 .46984 L
s
.44186 .46986 m
.44038 .46988 L
s
.44333 .46982 m
.44186 .46986 L
s
.44193 .46986 m
.44046 .46988 L
s
.4434 .46982 m
.44193 .46986 L
s
.44158 .46987 m
.44011 .46988 L
s
.44305 .46983 m
.44158 .46987 L
s
.44571 .46972 m
.44425 .46981 L
s
.44502 .46974 m
.44355 .46982 L
s
.44452 .46976 m
.44305 .46983 L
s
.43993 .46992 m
.43846 .46991 L
s
.28598 .47185 m
.28567 .4714 L
s
.4405 .4699 m
.43903 .46989 L
s
.44532 .46973 m
.44386 .46981 L
s
.1759 .47893 m
.17572 .47859 L
s
.4448 .46975 m
.44333 .46982 L
s
.44293 .46983 m
.44146 .46987 L
s
.4444 .46976 m
.44293 .46983 L
s
.44487 .46974 m
.4434 .46982 L
s
.44146 .46987 m
.43999 .46988 L
s
.44542 .46972 m
.44395 .46981 L
s
.44061 .46989 m
.43914 .46989 L
s
.44255 .46983 m
.44108 .46986 L
s
.44402 .46977 m
.44255 .46983 L
s
.44275 .46984 m
.44128 .46987 L
s
.44422 .46978 m
.44275 .46984 L
s
.44241 .46984 m
.44094 .46986 L
s
.44388 .46978 m
.44241 .46984 L
s
.44269 .46984 m
.44122 .46987 L
s
.44416 .46978 m
.44269 .46984 L
s
.43984 .46992 m
.43837 .4699 L
s
.51265 .46536 m
.512 .46594 L
s
.44236 .46984 m
.44089 .46987 L
s
.44383 .46979 m
.44236 .46984 L
s
.4423 .46984 m
.44083 .46987 L
s
.44378 .46979 m
.4423 .46984 L
s
.44128 .46987 m
.43981 .46988 L
s
.44122 .46987 m
.43975 .46988 L
s
.44108 .46986 m
.43961 .46987 L
s
.44231 .46983 m
.44084 .46985 L
s
.44378 .46977 m
.44231 .46983 L
s
.44046 .46988 m
.43899 .46987 L
s
.44238 .46982 m
.44091 .46985 L
s
.44385 .46977 m
.44238 .46982 L
s
.44094 .46986 m
.43948 .46987 L
s
.44284 .46981 m
.44137 .46985 L
s
.44431 .46975 m
.44284 .46981 L
s
.44038 .46988 m
.43891 .46987 L
s
.4429 .46981 m
.44143 .46985 L
s
.44437 .46975 m
.4429 .46981 L
s
.44258 .46983 m
.44111 .46986 L
s
.44405 .46977 m
.44258 .46983 L
s
.44137 .46985 m
.4399 .46986 L
s
.44089 .46987 m
.43942 .46987 L
s
.44172 .46984 m
.44025 .46986 L
s
.44319 .4698 m
.44172 .46984 L
s
.44143 .46985 m
.43996 .46986 L
s
.44002 .4699 m
.43856 .46988 L
s
.44011 .46988 m
.43864 .46987 L
s
.44083 .46987 m
.43936 .46987 L
s
.44535 .4697 m
.44388 .46978 L
s
.44525 .46971 m
.44378 .46979 L
s
.4459 .46968 m
.44443 .46978 L
s
.4453 .46971 m
.44383 .46979 L
s
.44637 .46966 m
.4449 .46976 L
s
.44549 .46969 m
.44402 .46977 L
s
.44219 .46983 m
.44072 .46985 L
s
.44366 .46978 m
.44219 .46983 L
s
.44466 .46973 m
.44319 .4698 L
s
.44598 .46967 m
.44452 .46976 L
s
.44111 .46986 m
.43964 .46987 L
s
.44525 .46969 m
.44378 .46977 L
s
.44569 .46969 m
.44422 .46978 L
s
.44084 .46985 m
.43937 .46985 L
s
.44563 .46969 m
.44416 .46978 L
s
.44586 .46967 m
.4444 .46976 L
s
.44091 .46985 m
.43944 .46985 L
s
.43954 .4699 m
.43808 .46987 L
s
.44531 .46969 m
.44385 .46977 L
s
.43999 .46988 m
.43852 .46986 L
s
.43945 .4699 m
.43798 .46987 L
s
.44627 .46965 m
.4448 .46975 L
s
.44648 .46964 m
.44502 .46974 L
s
.44633 .46964 m
.44487 .46974 L
s
.44513 .4697 m
.44366 .46978 L
s
.44217 .46981 m
.4407 .46983 L
s
.44364 .46976 m
.44217 .46981 L
s
.44271 .4698 m
.44124 .46983 L
s
.44418 .46973 m
.44271 .4698 L
s
.44072 .46985 m
.43925 .46985 L
s
.44552 .46968 m
.44405 .46977 L
s
.44578 .46966 m
.44431 .46975 L
s
.43981 .46988 m
.43834 .46986 L
s
.44679 .46962 m
.44532 .46973 L
s
.44584 .46966 m
.44437 .46975 L
s
.44025 .46986 m
.43878 .46985 L
s
.44124 .46983 m
.43977 .46984 L
s
.43975 .46988 m
.43828 .46986 L
s
.43903 .46989 m
.43756 .46986 L
s
.44727 .4696 m
.4458 .46972 L
s
.44718 .4696 m
.44571 .46972 L
s
.43914 .46989 m
.43767 .46986 L
s
.44689 .46961 m
.44542 .46972 L
s
.43961 .46987 m
.43815 .46985 L
s
.44511 .46968 m
.44364 .46976 L
s
.43996 .46986 m
.4385 .46984 L
s
.4399 .46986 m
.43843 .46984 L
s
.4407 .46983 m
.43923 .46983 L
s
.43846 .46991 m
.437 .46986 L
s
.43948 .46987 m
.43801 .46984 L
s
.44613 .46963 m
.44466 .46973 L
s
.61562 .46741 m
.61538 .46784 L
s
.43964 .46987 m
.43818 .46985 L
s
.43942 .46987 m
.43796 .46984 L
s
.44565 .46965 m
.44418 .46973 L
s
.43936 .46987 m
.43789 .46984 L
s
.44671 .4696 m
.44525 .46971 L
s
.43899 .46987 m
.43753 .46984 L
s
.43837 .4699 m
.43691 .46986 L
s
.61551 .46741 m
.61527 .46784 L
s
.44676 .4696 m
.4453 .46971 L
s
.43891 .46987 m
.43745 .46984 L
s
.44682 .46959 m
.44535 .4697 L
s
.44672 .46959 m
.44525 .46969 L
s
.43944 .46985 m
.43797 .46982 L
s
.43937 .46985 m
.4379 .46982 L
s
.44696 .46958 m
.44549 .46969 L
s
.44678 .46958 m
.44531 .46969 L
s
.43864 .46987 m
.43717 .46983 L
s
.43856 .46988 m
.43709 .46984 L
s
.43977 .46984 m
.4383 .46982 L
s
.4466 .46959 m
.44513 .4697 L
s
.4471 .46957 m
.44563 .46969 L
s
.44715 .46957 m
.44569 .46969 L
s
.44737 .46956 m
.4459 .46968 L
s
.43925 .46985 m
.43779 .46982 L
s
.44745 .46954 m
.44598 .46967 L
s
.44733 .46955 m
.44586 .46967 L
s
.44783 .46953 m
.44637 .46966 L
s
.43852 .46986 m
.43706 .46982 L
s
.44699 .46957 m
.44552 .46968 L
s
.44658 .46957 m
.44511 .46968 L
s
.44725 .46954 m
.44578 .46966 L
s
.70923 .4587 m
.7091 .45906 L
s
.44773 .46952 m
.44627 .46965 L
s
.43808 .46987 m
.43662 .46982 L
s
.43878 .46985 m
.43731 .46981 L
s
.4473 .46954 m
.44584 .46966 L
s
.4478 .46952 m
.44633 .46964 L
s
.19795 .56805 m
.19771 .56772 L
s
.43923 .46983 m
.43776 .4698 L
s
.43798 .46987 m
.43652 .46982 L
s
.44795 .46951 m
.44648 .46964 L
s
.43834 .46986 m
.43688 .46982 L
s
.43828 .46986 m
.43682 .46981 L
s
.4385 .46984 m
.43703 .4698 L
s
.43843 .46984 m
.43697 .4698 L
s
.44711 .46953 m
.44565 .46965 L
s
.43815 .46985 m
.43668 .4698 L
s
.37456 .47325 m
.37383 .47277 L
s
.44825 .46948 m
.44679 .46962 L
s
.44759 .4695 m
.44613 .46963 L
s
.43756 .46986 m
.4361 .4698 L
s
.43767 .46986 m
.43621 .4698 L
s
.43801 .46984 m
.43655 .46979 L
s
.44835 .46947 m
.44689 .46961 L
s
.43818 .46985 m
.43671 .4698 L
s
.44864 .46946 m
.44718 .4696 L
s
.44873 .46945 m
.44727 .4696 L
s
.43796 .46984 m
.43649 .46979 L
s
.43789 .46984 m
.43643 .46979 L
s
.28578 .47172 m
.28547 .47127 L
s
.44818 .46946 m
.44671 .4696 L
s
.44823 .46946 m
.44676 .4696 L
s
.43797 .46982 m
.43651 .46977 L
s
.44818 .46945 m
.44672 .46959 L
s
.4383 .46982 m
.43684 .46977 L
s
.44828 .46945 m
.44682 .46959 L
s
.4379 .46982 m
.43644 .46977 L
s
.437 .46986 m
.43554 .46979 L
s
.43753 .46984 m
.43607 .46978 L
s
.43745 .46984 m
.43599 .46978 L
s
.44824 .46945 m
.44678 .46958 L
s
.44842 .46944 m
.44696 .46958 L
s
.44806 .46946 m
.4466 .46959 L
s
.43691 .46986 m
.43545 .46978 L
s
.43779 .46982 m
.43632 .46977 L
s
.3744 .4732 m
.37368 .47271 L
s
.44856 .46943 m
.4471 .46957 L
s
.43717 .46983 m
.43572 .46976 L
s
.44804 .46944 m
.44658 .46957 L
s
.44861 .46943 m
.44715 .46957 L
s
.43709 .46984 m
.43563 .46978 L
s
.44883 .46941 m
.44737 .46956 L
s
.44879 .4694 m
.44733 .46955 L
s
.44845 .46942 m
.44699 .46957 L
s
.85566 .31052 m
.85571 .31078 L
s
.44891 .46939 m
.44745 .46954 L
s
.43776 .4698 m
.4363 .46974 L
s
.43706 .46982 m
.4356 .46975 L
s
.44871 .4694 m
.44725 .46954 L
s
.43731 .46981 m
.43585 .46975 L
s
.44876 .46939 m
.4473 .46954 L
s
.44929 .46937 m
.44783 .46953 L
s
.44919 .46937 m
.44773 .46952 L
s
.43662 .46982 m
.43516 .46975 L
s
.44926 .46936 m
.4478 .46952 L
s
.43688 .46982 m
.43542 .46974 L
s
.44857 .46939 m
.44711 .46953 L
s
.43652 .46982 m
.43507 .46974 L
s
.51301 .46516 m
.51237 .46574 L
s
.4494 .46935 m
.44795 .46951 L
s
.43682 .46981 m
.43536 .46974 L
s
.43703 .4698 m
.43558 .46973 L
s
.43697 .4698 m
.43551 .46972 L
s
.37446 .47317 m
.37373 .47268 L
s
.43668 .4698 m
.43523 .46972 L
s
.44905 .46935 m
.44759 .4695 L
s
.43671 .4698 m
.43526 .46972 L
s
.43655 .46979 m
.43509 .46971 L
s
.44971 .46932 m
.44825 .46948 L
s
.43621 .4698 m
.43476 .46971 L
s
.4361 .4698 m
.43465 .46971 L
s
.43649 .46979 m
.43504 .46971 L
s
.44981 .4693 m
.44835 .46947 L
s
.51289 .46515 m
.51224 .46573 L
s
.43684 .46977 m
.43538 .4697 L
s
.43643 .46979 m
.43497 .46971 L
s
.43651 .46977 m
.43506 .46969 L
s
.44964 .4693 m
.44818 .46946 L
s
.44968 .4693 m
.44823 .46946 L
s
.45009 .46928 m
.44864 .46946 L
s
.43644 .46977 m
.43498 .46969 L
s
.44964 .46929 m
.44818 .46945 L
s
.45018 .46928 m
.44873 .46945 L
s
.44973 .46929 m
.44828 .46945 L
s
.51294 .46513 m
.5123 .46571 L
s
.4497 .46928 m
.44824 .46945 L
s
.44952 .4693 m
.44806 .46946 L
s
.43607 .46978 m
.43461 .46969 L
s
.43599 .46978 m
.43453 .46969 L
s
.44987 .46927 m
.44842 .46944 L
s
.43632 .46977 m
.43487 .46969 L
s
.43554 .46979 m
.43409 .4697 L
s
.4495 .46928 m
.44804 .46944 L
s
.45002 .46926 m
.44856 .46943 L
s
.43545 .46978 m
.434 .46969 L
s
.45007 .46926 m
.44861 .46943 L
s
.43572 .46976 m
.43426 .46967 L
s
.43563 .46978 m
.43418 .46968 L
s
.4363 .46974 m
.43485 .46966 L
s
.4499 .46926 m
.44845 .46942 L
s
.51298 .4651 m
.51234 .46568 L
s
.37437 .47312 m
.37364 .47263 L
s
.45028 .46924 m
.44883 .46941 L
s
.45024 .46923 m
.44879 .4694 L
s
.43585 .46975 m
.4344 .46966 L
s
.45036 .46922 m
.44891 .46939 L
s
.45017 .46923 m
.44871 .4694 L
s
.28564 .47158 m
.28534 .47113 L
s
.4356 .46975 m
.43415 .46966 L
s
.17579 .47866 m
.1756 .47832 L
s
.51299 .46509 m
.51235 .46567 L
s
.45022 .46922 m
.44876 .46939 L
s
.61564 .46718 m
.6154 .46761 L
s
.45003 .46922 m
.44857 .46939 L
s
.45074 .46919 m
.44929 .46937 L
s
.45065 .46919 m
.44919 .46937 L
s
.43542 .46974 m
.43397 .46965 L
s
.43516 .46975 m
.43371 .46964 L
s
.43558 .46973 m
.43412 .46963 L
s
.45071 .46918 m
.44926 .46936 L
s
.61568 .46717 m
.61544 .4676 L
s
.43536 .46974 m
.4339 .46964 L
s
.43551 .46972 m
.43405 .46963 L
s
.43507 .46974 m
.43362 .46964 L
s
.45086 .46916 m
.4494 .46935 L
s
.4505 .46917 m
.44905 .46935 L
s
.513 .46506 m
.51236 .46564 L
s
.43523 .46972 m
.43378 .46962 L
s
.43526 .46972 m
.4338 .46962 L
s
.43509 .46971 m
.43365 .46961 L
s
.43538 .4697 m
.43393 .4696 L
s
.45116 .46913 m
.44971 .46932 L
s
.43504 .46971 m
.43359 .4696 L
s
.43476 .46971 m
.43331 .4696 L
s
.43497 .46971 m
.43352 .4696 L
s
.43465 .46971 m
.4332 .4696 L
s
.43506 .46969 m
.43361 .46958 L
s
.45125 .46911 m
.44981 .4693 L
s
.70931 .45845 m
.70918 .45881 L
s
.45109 .46911 m
.44964 .4693 L
s
.43498 .46969 m
.43353 .46958 L
s
.45109 .4691 m
.44964 .46929 L
s
.45113 .46911 m
.44968 .4693 L
s
.37426 .47303 m
.37353 .47254 L
s
.37436 .47304 m
.37363 .47255 L
s
.17572 .47859 m
.17553 .47825 L
s
.51313 .46499 m
.51249 .46558 L
s
.45118 .46909 m
.44973 .46929 L
s
.45097 .46911 m
.44952 .4693 L
s
.45115 .46909 m
.4497 .46928 L
s
.45154 .46908 m
.45009 .46928 L
s
.43487 .46969 m
.43342 .46958 L
s
.43461 .46969 m
.43317 .46958 L
s
.45163 .46907 m
.45018 .46928 L
s
.45095 .46909 m
.4495 .46928 L
s
.51308 .46498 m
.51244 .46556 L
s
.43453 .46969 m
.43308 .46957 L
s
.45132 .46907 m
.44987 .46927 L
s
.43409 .4697 m
.43265 .46958 L
s
.43485 .46966 m
.4334 .46955 L
s
.45147 .46906 m
.45002 .46926 L
s
.45151 .46906 m
.45007 .46926 L
s
.43426 .46967 m
.43282 .46955 L
s
.45135 .46906 m
.4499 .46926 L
s
.43418 .46968 m
.43274 .46956 L
s
.434 .46969 m
.43256 .46956 L
s
.4344 .46966 m
.43295 .46954 L
s
.45169 .46903 m
.45024 .46923 L
s
.45173 .46903 m
.45028 .46924 L
s
.45162 .46903 m
.45017 .46923 L
s
.43415 .46966 m
.4327 .46954 L
s
.45181 .46901 m
.45036 .46922 L
s
.45166 .46902 m
.45022 .46922 L
s
.8556 .31027 m
.85566 .31052 L
s
.37408 .47297 m
.37336 .47248 L
s
.45148 .46902 m
.45003 .46922 L
s
.43397 .46965 m
.43253 .46952 L
s
.43412 .46963 m
.43268 .46951 L
s
.45219 .46898 m
.45074 .46919 L
s
.45209 .46898 m
.45065 .46919 L
s
.51317 .46492 m
.51253 .46551 L
s
.43405 .46963 m
.43261 .4695 L
s
.43371 .46964 m
.43227 .46951 L
s
.4339 .46964 m
.43246 .46951 L
s
.45215 .46897 m
.45071 .46918 L
s
.43362 .46964 m
.43218 .46951 L
s
.28567 .4714 m
.28536 .47095 L
s
.45195 .46897 m
.4505 .46917 L
s
.4523 .46895 m
.45086 .46916 L
s
.43378 .46962 m
.43233 .46949 L
s
.70936 .45834 m
.70923 .4587 L
s
.4338 .46962 m
.43236 .46949 L
s
.43365 .46961 m
.4322 .46948 L
s
.43393 .4696 m
.43248 .46947 L
s
.37418 .47292 m
.37346 .47243 L
s
.37426 .47292 m
.37354 .47243 L
s
.61586 .46699 m
.61562 .46741 L
s
.43359 .4696 m
.43215 .46947 L
s
.61575 .46698 m
.61551 .46741 L
s
.4526 .46891 m
.45116 .46913 L
s
.43352 .4696 m
.43208 .46946 L
s
.43331 .4696 m
.43187 .46946 L
s
.19771 .56772 m
.19746 .56738 L
s
.43361 .46958 m
.43217 .46945 L
s
.4332 .4696 m
.43177 .46946 L
s
.43353 .46958 m
.43209 .46945 L
s
.4527 .46889 m
.45125 .46911 L
s
.45253 .4689 m
.45109 .46911 L
s
.45253 .46889 m
.45109 .4691 L
s
.45257 .46889 m
.45113 .46911 L
s
.45241 .46889 m
.45097 .46911 L
s
.37397 .47287 m
.37325 .47238 L
s
.45262 .46887 m
.45118 .46909 L
s
.45259 .46888 m
.45115 .46909 L
s
.43342 .46958 m
.43198 .46944 L
s
.45239 .46888 m
.45095 .46909 L
s
.43317 .46958 m
.43173 .46944 L
s
.51334 .46482 m
.51271 .4654 L
s
.45298 .46886 m
.45154 .46908 L
s
.43308 .46957 m
.43164 .46943 L
s
.45277 .46885 m
.45132 .46907 L
s
.45307 .46885 m
.45163 .46907 L
s
.4334 .46955 m
.43196 .46941 L
s
.43265 .46958 m
.43121 .46943 L
s
.45291 .46884 m
.45147 .46906 L
s
.45295 .46883 m
.45151 .46906 L
s
.43282 .46955 m
.43138 .46941 L
s
.45279 .46884 m
.45135 .46906 L
s
.43274 .46956 m
.4313 .46942 L
s
.51328 .46478 m
.51265 .46536 L
s
.43256 .46956 m
.43112 .46941 L
s
.43295 .46954 m
.43152 .4694 L
s
.45306 .4688 m
.45162 .46903 L
s
.45312 .4688 m
.45169 .46903 L
s
.4327 .46954 m
.43127 .46939 L
s
.45316 .4688 m
.45173 .46903 L
s
.4531 .46879 m
.45166 .46902 L
s
.45325 .46878 m
.45181 .46901 L
s
.45292 .46879 m
.45148 .46902 L
s
.28547 .47127 m
.28517 .47082 L
s
.43268 .46951 m
.43125 .46936 L
s
.43253 .46952 m
.43109 .46937 L
s
.43261 .4695 m
.43117 .46935 L
s
.43246 .46951 m
.43102 .46936 L
s
.45353 .46874 m
.45209 .46898 L
s
.45362 .46874 m
.45219 .46898 L
s
.43227 .46951 m
.43084 .46936 L
s
.45359 .46873 m
.45215 .46897 L
s
.43218 .46951 m
.43074 .46935 L
s
.45339 .46873 m
.45195 .46897 L
s
.43233 .46949 m
.4309 .46933 L
s
.43236 .46949 m
.43093 .46934 L
s
.45373 .46871 m
.4523 .46895 L
s
.1756 .47832 m
.17542 .47798 L
s
.43248 .46947 m
.43105 .46932 L
s
.37383 .47277 m
.37311 .47228 L
s
.4322 .46948 m
.43077 .46932 L
s
.43215 .46947 m
.43072 .46931 L
s
.43208 .46946 m
.43065 .46931 L
s
.43217 .46945 m
.43074 .46929 L
s
.43187 .46946 m
.43044 .4693 L
s
.45403 .46866 m
.4526 .46891 L
s
.85555 .31001 m
.8556 .31027 L
s
.43209 .46945 m
.43066 .46929 L
s
.43177 .46946 m
.43034 .4693 L
s
.37368 .47271 m
.37296 .47222 L
s
.45397 .46865 m
.45253 .4689 L
s
.45397 .46864 m
.45253 .46889 L
s
.45413 .46864 m
.4527 .46889 L
s
.45401 .46865 m
.45257 .46889 L
s
.45385 .46865 m
.45241 .46889 L
s
.43198 .46944 m
.43055 .46928 L
s
.45402 .46863 m
.45259 .46888 L
s
.45383 .46864 m
.45239 .46888 L
s
.45406 .46863 m
.45262 .46887 L
s
.43173 .46944 m
.4303 .46927 L
s
.43164 .46943 m
.43021 .46926 L
s
.43196 .46941 m
.43053 .46925 L
s
.61588 .46676 m
.61564 .46718 L
s
.4542 .4686 m
.45277 .46885 L
s
.45441 .4686 m
.45298 .46886 L
s
.70944 .45809 m
.70931 .45845 L
s
.17553 .47825 m
.17534 .47791 L
s
.4545 .46859 m
.45307 .46885 L
s
.61592 .46675 m
.61568 .46717 L
s
.37373 .47268 m
.37301 .47219 L
s
.43121 .46943 m
.42978 .46925 L
s
.28534 .47113 m
.28503 .47068 L
s
.45434 .46858 m
.45291 .46884 L
s
.43138 .46941 m
.42995 .46924 L
s
.45422 .46859 m
.45279 .46884 L
s
.45438 .46858 m
.45295 .46883 L
s
.51364 .46458 m
.51301 .46516 L
s
.4313 .46942 m
.42987 .46924 L
s
.43152 .4694 m
.43009 .46923 L
s
.43112 .46941 m
.4297 .46924 L
s
.45448 .46855 m
.45306 .4688 L
s
.43127 .46939 m
.42984 .46921 L
s
.45455 .46854 m
.45312 .4688 L
s
.45459 .46854 m
.45316 .4688 L
s
.45453 .46854 m
.4531 .46879 L
s
.45435 .46854 m
.45292 .46879 L
s
.51352 .46457 m
.51289 .46515 L
s
.45467 .46852 m
.45325 .46878 L
s
.51357 .46454 m
.51294 .46513 L
s
.43125 .46936 m
.42982 .46918 L
s
.43109 .46937 m
.42967 .46919 L
s
.43117 .46935 m
.42975 .46918 L
s
.37364 .47263 m
.37292 .47214 L
s
.43102 .46936 m
.4296 .46918 L
s
.43084 .46936 m
.42941 .46918 L
s
.45496 .46848 m
.45353 .46874 L
s
.45504 .46847 m
.45362 .46874 L
s
.45501 .46847 m
.45359 .46873 L
s
.51361 .46451 m
.51298 .4651 L
s
.4309 .46933 m
.42948 .46915 L
s
.45481 .46847 m
.45339 .46873 L
s
.43074 .46935 m
.42932 .46917 L
s
.43093 .46934 m
.42951 .46916 L
s
.70949 .45798 m
.70936 .45834 L
s
.51362 .46451 m
.51299 .46509 L
s
.43105 .46932 m
.42963 .46914 L
s
.45516 .46844 m
.45373 .46871 L
s
.43077 .46932 m
.42935 .46914 L
s
.43072 .46931 m
.4293 .46913 L
s
.43065 .46931 m
.42923 .46912 L
s
.43074 .46929 m
.42932 .46911 L
s
.51363 .46447 m
.513 .46506 L
s
.43044 .4693 m
.42902 .46911 L
s
.43066 .46929 m
.42924 .4691 L
s
.45545 .46839 m
.45403 .46866 L
s
.43034 .4693 m
.42892 .46911 L
s
.19746 .56738 m
.19722 .56704 L
s
.45539 .46838 m
.45397 .46865 L
s
.45539 .46837 m
.45397 .46864 L
s
.43055 .46928 m
.42913 .46909 L
s
.37353 .47254 m
.37282 .47205 L
s
.37363 .47255 m
.37291 .47206 L
s
.45527 .46838 m
.45385 .46865 L
s
.45543 .46838 m
.45401 .46865 L
s
.45555 .46837 m
.45413 .46864 L
s
.45525 .46837 m
.45383 .46864 L
s
.45544 .46836 m
.45402 .46863 L
s
.45548 .46836 m
.45406 .46863 L
s
.6161 .46656 m
.61586 .46699 L
s
.4303 .46927 m
.42888 .46908 L
s
.28536 .47095 m
.28506 .47049 L
s
.61599 .46656 m
.61575 .46698 L
s
.43053 .46925 m
.42911 .46906 L
s
.51376 .46441 m
.51313 .46499 L
s
.43021 .46926 m
.42879 .46907 L
s
.51371 .4644 m
.51308 .46498 L
s
.45562 .46833 m
.4542 .4686 L
s
.85549 .30975 m
.85555 .31001 L
s
.45582 .46832 m
.45441 .4686 L
s
.45591 .46831 m
.4545 .46859 L
s
.42978 .46925 m
.42837 .46905 L
s
.42995 .46924 m
.42854 .46904 L
s
.45576 .46831 m
.45434 .46858 L
s
.37336 .47248 m
.37264 .47198 L
s
.45564 .46831 m
.45422 .46859 L
s
.43009 .46923 m
.42867 .46903 L
s
.4558 .4683 m
.45438 .46858 L
s
.42987 .46924 m
.42846 .46905 L
s
.4297 .46924 m
.42828 .46904 L
s
.42984 .46921 m
.42843 .46902 L
s
.4559 .46827 m
.45448 .46855 L
s
.45597 .46826 m
.45455 .46854 L
s
.45577 .46826 m
.45435 .46854 L
s
.45594 .46826 m
.45453 .46854 L
s
.45601 .46826 m
.45459 .46854 L
s
.45609 .46824 m
.45467 .46852 L
s
.51379 .46434 m
.51317 .46492 L
s
.17542 .47798 m
.17523 .47764 L
s
.42982 .46918 m
.42841 .46898 L
s
.37346 .47243 m
.37274 .47194 L
s
.42967 .46919 m
.42826 .46899 L
s
.42975 .46918 m
.42833 .46897 L
s
.37354 .47243 m
.37282 .47194 L
s
.4296 .46918 m
.42818 .46898 L
s
.42941 .46918 m
.428 .46897 L
s
.45637 .46819 m
.45496 .46848 L
s
.45646 .46818 m
.45504 .46847 L
s
.42948 .46915 m
.42807 .46895 L
s
.45642 .46818 m
.45501 .46847 L
s
.28517 .47082 m
.28487 .47037 L
s
.42951 .46916 m
.42809 .46896 L
s
.42932 .46917 m
.42791 .46896 L
s
.45623 .46818 m
.45481 .46847 L
s
.37325 .47238 m
.37254 .47188 L
s
.42963 .46914 m
.42821 .46894 L
s
.42935 .46914 m
.42794 .46893 L
s
.45657 .46815 m
.45516 .46844 L
s
.51396 .46423 m
.51334 .46482 L
s
.4293 .46913 m
.42789 .46892 L
s
.17534 .47791 m
.17516 .47756 L
s
.70957 .45773 m
.70944 .45809 L
s
.42932 .46911 m
.42791 .4689 L
s
.42923 .46912 m
.42782 .46891 L
s
.42902 .46911 m
.42762 .4689 L
s
.42924 .4691 m
.42783 .46889 L
s
.42892 .46911 m
.42751 .46889 L
s
.51391 .46419 m
.51328 .46478 L
s
.45686 .46809 m
.45545 .46839 L
s
.42913 .46909 m
.42772 .46888 L
s
.4568 .46808 m
.45539 .46837 L
s
.4568 .46808 m
.45539 .46838 L
s
.45668 .46808 m
.45527 .46838 L
s
.45683 .46808 m
.45543 .46838 L
s
.45666 .46807 m
.45525 .46837 L
s
.45695 .46807 m
.45555 .46837 L
s
.45685 .46806 m
.45544 .46836 L
s
.61611 .46633 m
.61588 .46676 L
s
.42888 .46908 m
.42748 .46886 L
s
.42911 .46906 m
.4277 .46885 L
s
.45688 .46806 m
.45548 .46836 L
s
.42879 .46907 m
.42739 .46885 L
s
.61615 .46632 m
.61592 .46675 L
s
.45702 .46803 m
.45562 .46833 L
s
.45723 .46802 m
.45582 .46832 L
s
.37311 .47228 m
.3724 .47178 L
s
.85544 .3095 m
.85549 .30975 L
s
.42837 .46905 m
.42697 .46883 L
s
.42854 .46904 m
.42714 .46882 L
s
.45732 .468 m
.45591 .46831 L
s
.42867 .46903 m
.42727 .46881 L
s
.28503 .47068 m
.28473 .47023 L
s
.42846 .46905 m
.42706 .46882 L
s
.45705 .46801 m
.45564 .46831 L
s
.45717 .468 m
.45576 .46831 L
s
.70962 .45762 m
.70949 .45798 L
s
.4572 .468 m
.4558 .4683 L
s
.42828 .46904 m
.42688 .46881 L
s
.42843 .46902 m
.42703 .46879 L
s
.45731 .46796 m
.4559 .46827 L
s
.37296 .47222 m
.37226 .47173 L
s
.45717 .46796 m
.45577 .46826 L
s
.45737 .46795 m
.45597 .46826 L
s
.45735 .46795 m
.45594 .46826 L
s
.45741 .46795 m
.45601 .46826 L
s
.45749 .46793 m
.45609 .46824 L
s
.42841 .46898 m
.42701 .46876 L
s
.42826 .46899 m
.42686 .46876 L
s
.42833 .46897 m
.42693 .46875 L
s
.37301 .47219 m
.37231 .47169 L
s
.42818 .46898 m
.42678 .46875 L
s
.428 .46897 m
.42661 .46874 L
s
.19722 .56704 m
.19698 .5667 L
s
.42807 .46895 m
.42667 .46872 L
s
.45777 .46787 m
.45637 .46819 L
s
.42809 .46896 m
.42669 .46873 L
s
.42791 .46896 m
.42652 .46872 L
s
.42821 .46894 m
.42681 .46871 L
s
.45785 .46786 m
.45646 .46818 L
s
.45782 .46786 m
.45642 .46818 L
s
.45763 .46787 m
.45623 .46818 L
s
.51425 .46399 m
.51364 .46458 L
s
.42794 .46893 m
.42655 .46869 L
s
.45797 .46783 m
.45657 .46815 L
s
.51414 .46398 m
.51352 .46457 L
s
.42789 .46892 m
.42649 .46868 L
s
.61633 .46613 m
.6161 .46656 L
s
.37292 .47214 m
.37222 .47164 L
s
.61622 .46613 m
.61599 .46656 L
s
.42791 .4689 m
.42651 .46866 L
s
.42782 .46891 m
.42642 .46867 L
s
.51419 .46395 m
.51357 .46454 L
s
.42783 .46889 m
.42643 .46865 L
s
.42762 .4689 m
.42622 .46866 L
s
.17523 .47764 m
.17505 .47729 L
s
.42751 .46889 m
.42612 .46865 L
s
.42772 .46888 m
.42632 .46865 L
s
.28506 .47049 m
.28476 .47004 L
s
.51422 .46392 m
.51361 .46451 L
s
.45825 .46776 m
.45686 .46809 L
s
.4582 .46775 m
.4568 .46808 L
s
.4582 .46776 m
.4568 .46808 L
s
.45807 .46776 m
.45668 .46808 L
s
.51424 .46392 m
.51362 .46451 L
s
.45806 .46775 m
.45666 .46807 L
s
.45823 .46775 m
.45683 .46808 L
s
.4277 .46885 m
.42631 .46861 L
s
.42748 .46886 m
.42609 .46862 L
s
.45824 .46774 m
.45685 .46806 L
s
.45835 .46774 m
.45695 .46807 L
s
.45828 .46773 m
.45688 .46806 L
s
.42739 .46885 m
.426 .46861 L
s
.51424 .46388 m
.51363 .46447 L
s
.37282 .47205 m
.37212 .47155 L
s
.37291 .47206 m
.37221 .47156 L
s
.45842 .4677 m
.45702 .46803 L
s
.85538 .30924 m
.85544 .3095 L
s
.17516 .47756 m
.17497 .47722 L
s
.45861 .46768 m
.45723 .46802 L
s
.42727 .46881 m
.42588 .46857 L
s
.42714 .46882 m
.42575 .46857 L
s
.42697 .46883 m
.42558 .46858 L
s
.42706 .46882 m
.42567 .46857 L
s
.7097 .45737 m
.70957 .45773 L
s
.4587 .46766 m
.45732 .468 L
s
.45844 .46767 m
.45705 .46801 L
s
.45856 .46767 m
.45717 .468 L
s
.45859 .46766 m
.4572 .468 L
s
.42688 .46881 m
.4255 .46856 L
s
.51437 .46382 m
.51376 .46441 L
s
.42703 .46879 m
.42564 .46854 L
s
.51433 .4638 m
.51371 .4644 L
s
.37264 .47198 m
.37194 .47148 L
s
.4587 .46763 m
.45731 .46796 L
s
.45856 .46763 m
.45717 .46796 L
s
.45876 .46762 m
.45737 .46795 L
s
.28487 .47037 m
.28457 .46991 L
s
.45874 .46761 m
.45735 .46795 L
s
.4588 .46761 m
.45741 .46795 L
s
.42701 .46876 m
.42562 .46851 L
s
.45888 .46759 m
.45749 .46793 L
s
.42686 .46876 m
.42547 .46851 L
s
.42693 .46875 m
.42554 .46849 L
s
.42678 .46875 m
.4254 .4685 L
s
.42661 .46874 m
.42522 .46848 L
s
.37274 .47194 m
.37204 .47144 L
s
.37282 .47194 m
.37212 .47144 L
s
.51441 .46374 m
.51379 .46434 L
s
.42667 .46872 m
.42529 .46846 L
s
.42669 .46873 m
.42531 .46847 L
s
.42681 .46871 m
.42543 .46846 L
s
.70974 .45726 m
.70962 .45762 L
s
.61635 .4659 m
.61611 .46633 L
s
.42652 .46872 m
.42513 .46846 L
s
.45916 .46753 m
.45777 .46787 L
s
.45901 .46753 m
.45763 .46787 L
s
.45924 .46752 m
.45785 .46786 L
s
.45921 .46752 m
.45782 .46786 L
s
.61639 .46589 m
.61615 .46632 L
s
.42655 .46869 m
.42516 .46844 L
s
.37254 .47188 m
.37184 .47138 L
s
.42649 .46868 m
.42511 .46842 L
s
.45935 .46748 m
.45797 .46783 L
s
.42651 .46866 m
.42513 .4684 L
s
.42642 .46867 m
.42503 .46841 L
s
.42643 .46865 m
.42505 .46839 L
s
.42622 .46866 m
.42484 .4684 L
s
.51457 .46364 m
.51396 .46423 L
s
.42632 .46865 m
.42494 .46838 L
s
.28473 .47023 m
.28444 .46977 L
s
.42612 .46865 m
.42474 .46838 L
s
.45963 .46741 m
.45825 .46776 L
s
.42631 .46861 m
.42493 .46835 L
s
.45958 .4674 m
.4582 .46775 L
s
.45946 .46741 m
.45807 .46776 L
s
.51452 .4636 m
.51391 .46419 L
s
.45958 .46741 m
.4582 .46776 L
s
.45944 .4674 m
.45806 .46775 L
s
.42609 .46862 m
.42471 .46835 L
s
.45961 .4674 m
.45823 .46775 L
s
.19698 .5667 m
.19674 .56636 L
s
.45962 .46739 m
.45824 .46774 L
s
.426 .46861 m
.42462 .46834 L
s
.85532 .30899 m
.85538 .30924 L
s
.45972 .46738 m
.45835 .46774 L
s
.45965 .46738 m
.45828 .46773 L
s
.3724 .47178 m
.37171 .47128 L
s
.17505 .47729 m
.17486 .47695 L
s
.45979 .46734 m
.45842 .4677 L
s
.42588 .46857 m
.4245 .4683 L
s
.42575 .46857 m
.42437 .4683 L
s
.42558 .46858 m
.42421 .4683 L
s
.42567 .46857 m
.42429 .4683 L
s
.45999 .46732 m
.45861 .46768 L
s
.45982 .46732 m
.45844 .46767 L
s
.61656 .4657 m
.61633 .46613 L
s
.46008 .4673 m
.4587 .46766 L
s
.45994 .46731 m
.45856 .46767 L
s
.37226 .47173 m
.37156 .47122 L
s
.45997 .4673 m
.45859 .46766 L
s
.4255 .46856 m
.42413 .46828 L
s
.61645 .4657 m
.61622 .46613 L
s
.42564 .46854 m
.42427 .46827 L
s
.46007 .46727 m
.4587 .46763 L
s
.45994 .46727 m
.45856 .46763 L
s
.46013 .46725 m
.45876 .46762 L
s
.42562 .46851 m
.42425 .46823 L
s
.46011 .46725 m
.45874 .46761 L
s
.37231 .47169 m
.37161 .47119 L
s
.17497 .47722 m
.17479 .47688 L
s
.46017 .46725 m
.4588 .46761 L
s
.42547 .46851 m
.4241 .46823 L
s
.42554 .46849 m
.42417 .46822 L
s
.46025 .46722 m
.45888 .46759 L
s
.70982 .45701 m
.7097 .45737 L
s
.4254 .4685 m
.42402 .46822 L
s
.28476 .47004 m
.28447 .46958 L
s
.42522 .46848 m
.42386 .4682 L
s
.42531 .46847 m
.42394 .46819 L
s
.42529 .46846 m
.42392 .46818 L
s
.42543 .46846 m
.42406 .46818 L
s
.42513 .46846 m
.42377 .46818 L
s
.46052 .46716 m
.45916 .46753 L
s
.37222 .47164 m
.37152 .47114 L
s
.42516 .46844 m
.4238 .46815 L
s
.46038 .46716 m
.45901 .46753 L
s
.46057 .46715 m
.45921 .46752 L
s
.4606 .46715 m
.45924 .46752 L
s
.51474 .46338 m
.51414 .46398 L
s
.42511 .46842 m
.42374 .46814 L
s
.51479 .46336 m
.51419 .46395 L
s
.42513 .4684 m
.42377 .46812 L
s
.42503 .46841 m
.42367 .46813 L
s
.46071 .46711 m
.45935 .46748 L
s
.42505 .46839 m
.42368 .4681 L
s
.70987 .4569 m
.70974 .45726 L
s
.42484 .4684 m
.42348 .46811 L
s
.51483 .46333 m
.51422 .46392 L
s
.42494 .46838 m
.42358 .4681 L
s
.85527 .30873 m
.85532 .30899 L
s
.51485 .46332 m
.51424 .46392 L
s
.42474 .46838 m
.42338 .46809 L
s
.28457 .46991 m
.28428 .46946 L
s
.37212 .47155 m
.37143 .47104 L
s
.37221 .47156 m
.37152 .47106 L
s
.42493 .46835 m
.42356 .46806 L
s
.42471 .46835 m
.42335 .46806 L
s
.46099 .46703 m
.45963 .46741 L
s
.46094 .46702 m
.45958 .4674 L
s
.4608 .46703 m
.45944 .4674 L
s
.46082 .46704 m
.45946 .46741 L
s
.61657 .46547 m
.61635 .4659 L
s
.51484 .46328 m
.51424 .46388 L
s
.46094 .46703 m
.45958 .46741 L
s
.46097 .46702 m
.45961 .4674 L
s
.42462 .46834 m
.42325 .46804 L
s
.61661 .46546 m
.61639 .46589 L
s
.46098 .46701 m
.45962 .46739 L
s
.46108 .467 m
.45972 .46738 L
s
.46101 .467 m
.45965 .46738 L
s
.37194 .47148 m
.37126 .47098 L
s
.51497 .46322 m
.51437 .46382 L
s
.4245 .4683 m
.42314 .468 L
s
.42437 .4683 m
.42302 .468 L
s
.46115 .46696 m
.45979 .46734 L
s
.51493 .46321 m
.51433 .4638 L
s
.42421 .4683 m
.42286 .468 L
s
.42429 .4683 m
.42294 .468 L
s
.46134 .46694 m
.45999 .46732 L
s
.46118 .46693 m
.45982 .46732 L
s
.42427 .46827 m
.42291 .46797 L
s
.42413 .46828 m
.42277 .46798 L
s
.19674 .56636 m
.1965 .56602 L
s
.4613 .46692 m
.45994 .46731 L
s
.46143 .46691 m
.46008 .4673 L
s
.17486 .47695 m
.17468 .47661 L
s
.46132 .46692 m
.45997 .4673 L
s
.37204 .47144 m
.37135 .47094 L
s
.37212 .47144 m
.37143 .47093 L
s
.28444 .46977 m
.28415 .46932 L
s
.46143 .46688 m
.46007 .46727 L
s
.42425 .46823 m
.42289 .46793 L
s
.4613 .46688 m
.45994 .46727 L
s
.51501 .46315 m
.51441 .46374 L
s
.46146 .46687 m
.46011 .46725 L
s
.46148 .46686 m
.46013 .46725 L
s
.4241 .46823 m
.42275 .46793 L
s
.42417 .46822 m
.42281 .46792 L
s
.37184 .47138 m
.37115 .47088 L
s
.46152 .46686 m
.46017 .46725 L
s
.42402 .46822 m
.42267 .46791 L
s
.4616 .46683 m
.46025 .46722 L
s
.42386 .4682 m
.4225 .46789 L
s
.17479 .47688 m
.17461 .47653 L
s
.42394 .46819 m
.42259 .46789 L
s
.42406 .46818 m
.4227 .46788 L
s
.42392 .46818 m
.42256 .46788 L
s
.61679 .46527 m
.61656 .4657 L
s
.42377 .46818 m
.42242 .46787 L
s
.61668 .46527 m
.61645 .4657 L
s
.70995 .45665 m
.70982 .45701 L
s
.4238 .46815 m
.42245 .46785 L
s
.85521 .30847 m
.85527 .30873 L
s
.51517 .46304 m
.51457 .46364 L
s
.46188 .46676 m
.46052 .46716 L
s
.46174 .46677 m
.46038 .46716 L
s
.46192 .46675 m
.46057 .46715 L
s
.46195 .46675 m
.4606 .46715 L
s
.42374 .46814 m
.42239 .46783 L
s
.42377 .46812 m
.42242 .46781 L
s
.51511 .463 m
.51452 .4636 L
s
.42367 .46813 m
.42232 .46782 L
s
.42368 .4681 m
.42233 .46779 L
s
.46206 .46671 m
.46071 .46711 L
s
.42348 .46811 m
.42213 .46779 L
s
.37171 .47128 m
.37102 .47077 L
s
.42358 .4681 m
.42223 .46779 L
s
.42338 .46809 m
.42204 .46778 L
s
.28447 .46958 m
.28418 .46913 L
s
.42356 .46806 m
.42221 .46775 L
s
.70999 .45654 m
.70987 .4569 L
s
.37156 .47122 m
.37088 .47072 L
s
.42335 .46806 m
.422 .46774 L
s
.46215 .46663 m
.4608 .46703 L
s
.46217 .46663 m
.46082 .46704 L
s
.46228 .46662 m
.46094 .46702 L
s
.46233 .46663 m
.46099 .46703 L
s
.42325 .46804 m
.42191 .46773 L
s
.46229 .46662 m
.46094 .46703 L
s
.46231 .46662 m
.46097 .46702 L
s
.46233 .4666 m
.46098 .46701 L
s
.37161 .47119 m
.37093 .47068 L
s
.46236 .46659 m
.46101 .467 L
s
.46243 .46659 m
.46108 .467 L
s
.42314 .468 m
.4218 .46769 L
s
.42302 .468 m
.42168 .46768 L
s
.42294 .468 m
.4216 .46768 L
s
.42286 .468 m
.42152 .46768 L
s
.46249 .46655 m
.46115 .46696 L
s
.42291 .46797 m
.42157 .46765 L
s
.6168 .46504 m
.61657 .46547 L
s
.28428 .46946 m
.28399 .469 L
s
.42277 .46798 m
.42143 .46766 L
s
.46268 .46653 m
.46134 .46694 L
s
.37152 .47114 m
.37084 .47063 L
s
.46252 .46652 m
.46118 .46693 L
s
.61684 .46503 m
.61661 .46546 L
s
.46264 .46651 m
.4613 .46692 L
s
.46266 .46651 m
.46132 .46692 L
s
.46277 .4665 m
.46143 .46691 L
s
.17468 .47661 m
.1745 .47626 L
s
.42289 .46793 m
.42155 .46761 L
s
.85515 .30822 m
.85521 .30847 L
s
.51534 .46278 m
.51474 .46338 L
s
.46264 .46647 m
.4613 .46688 L
s
.46277 .46647 m
.46143 .46688 L
s
.42281 .46792 m
.42148 .46759 L
s
.42275 .46793 m
.42141 .4676 L
s
.51538 .46276 m
.51479 .46336 L
s
.1965 .56602 m
.19627 .56568 L
s
.4628 .46645 m
.46146 .46687 L
s
.46282 .46645 m
.46148 .46686 L
s
.42267 .46791 m
.42133 .46759 L
s
.46286 .46644 m
.46152 .46686 L
s
.4225 .46789 m
.42117 .46756 L
s
.46294 .46642 m
.4616 .46683 L
s
.51541 .46273 m
.51483 .46333 L
s
.4227 .46788 m
.42137 .46755 L
s
.42259 .46789 m
.42125 .46756 L
s
.42256 .46788 m
.42123 .46755 L
s
.37143 .47104 m
.37075 .47053 L
s
.37152 .47106 m
.37083 .47055 L
s
.51544 .46272 m
.51485 .46332 L
s
.17461 .47653 m
.17443 .47619 L
s
.42242 .46787 m
.42108 .46754 L
s
.42245 .46785 m
.42111 .46751 L
s
.71007 .45628 m
.70995 .45665 L
s
.51543 .46268 m
.51484 .46328 L
s
.28415 .46932 m
.28386 .46886 L
s
.46321 .46634 m
.46188 .46676 L
s
.46307 .46635 m
.46174 .46677 L
s
.42239 .46783 m
.42106 .4675 L
s
.37126 .47098 m
.37058 .47047 L
s
.46325 .46633 m
.46192 .46675 L
s
.42242 .46781 m
.42109 .46748 L
s
.46328 .46633 m
.46195 .46675 L
s
.42232 .46782 m
.42098 .46748 L
s
.42233 .46779 m
.421 .46746 L
s
.51556 .46262 m
.51497 .46322 L
s
.61702 .46484 m
.61679 .46527 L
s
.42213 .46779 m
.42081 .46746 L
s
.51552 .46261 m
.51493 .46321 L
s
.6169 .46484 m
.61668 .46527 L
s
.42223 .46779 m
.4209 .46745 L
s
.46339 .46628 m
.46206 .46671 L
s
.42204 .46778 m
.42071 .46744 L
s
.37135 .47094 m
.37067 .47043 L
s
.37143 .47093 m
.37075 .47042 L
s
.42221 .46775 m
.42088 .46741 L
s
.71011 .45618 m
.70999 .45654 L
s
.422 .46774 m
.42068 .4674 L
s
.37115 .47088 m
.37048 .47037 L
s
.42191 .46773 m
.42058 .46739 L
s
.51559 .46255 m
.51501 .46315 L
s
.46348 .4662 m
.46215 .46663 L
s
.46349 .46621 m
.46217 .46663 L
s
.46361 .46619 m
.46228 .46662 L
s
.46365 .4662 m
.46233 .46663 L
s
.46361 .4662 m
.46229 .46662 L
s
.46364 .46619 m
.46231 .46662 L
s
.85509 .30796 m
.85515 .30822 L
s
.46365 .46618 m
.46233 .4666 L
s
.46368 .46616 m
.46236 .46659 L
s
.4218 .46769 m
.42047 .46734 L
s
.46375 .46616 m
.46243 .46659 L
s
.42168 .46768 m
.42035 .46734 L
s
.28418 .46913 m
.28389 .46867 L
s
.4216 .46768 m
.42027 .46734 L
s
.42152 .46768 m
.4202 .46733 L
s
.46382 .46612 m
.46249 .46655 L
s
.42157 .46765 m
.42025 .4673 L
s
.51575 .46244 m
.51517 .46304 L
s
.42143 .46766 m
.42011 .46731 L
s
.464 .46609 m
.46268 .46653 L
s
.46384 .46609 m
.46252 .46652 L
s
.46396 .46608 m
.46264 .46651 L
s
.5157 .4624 m
.51511 .463 L
s
.1745 .47626 m
.17432 .47592 L
s
.37102 .47077 m
.37035 .47026 L
s
.46398 .46607 m
.46266 .46651 L
s
.42155 .46761 m
.42023 .46726 L
s
.46408 .46606 m
.46277 .4665 L
s
.42148 .46759 m
.42015 .46724 L
s
.42141 .4676 m
.42009 .46725 L
s
.46396 .46604 m
.46264 .46647 L
s
.61702 .46461 m
.6168 .46504 L
s
.46409 .46603 m
.46277 .46647 L
s
.42133 .46759 m
.42001 .46724 L
s
.61706 .4646 m
.61684 .46503 L
s
.37088 .47072 m
.37021 .4702 L
s
.46412 .46601 m
.4628 .46645 L
s
.46413 .46601 m
.46282 .46645 L
s
.42117 .46756 m
.41986 .46721 L
s
.42137 .46755 m
.42005 .4672 L
s
.19627 .56568 m
.19603 .56534 L
s
.28399 .469 m
.2837 .46855 L
s
.42125 .46756 m
.41994 .46721 L
s
.46417 .466 m
.46286 .46644 L
s
.42123 .46755 m
.41991 .46719 L
s
.46425 .46597 m
.46294 .46642 L
s
.17443 .47619 m
.17425 .47585 L
s
.37093 .47068 m
.37026 .47017 L
s
.42108 .46754 m
.41977 .46719 L
s
.42111 .46751 m
.4198 .46716 L
s
.71019 .45592 m
.71007 .45628 L
s
.42106 .4675 m
.41975 .46714 L
s
.42109 .46748 m
.41977 .46712 L
s
.46452 .4659 m
.46321 .46634 L
s
.46438 .4659 m
.46307 .46635 L
s
.42098 .46748 m
.41967 .46712 L
s
.46456 .46589 m
.46325 .46633 L
s
.85503 .30771 m
.85509 .30796 L
s
.46459 .46588 m
.46328 .46633 L
s
.37084 .47063 m
.37017 .47012 L
s
.421 .46746 m
.41969 .4671 L
s
.42081 .46746 m
.4195 .4671 L
s
.4209 .46745 m
.41959 .46709 L
s
.42071 .46744 m
.4194 .46708 L
s
.4647 .46583 m
.46339 .46628 L
s
.42088 .46741 m
.41957 .46705 L
s
.28386 .46886 m
.28357 .4684 L
s
.51592 .46218 m
.51534 .46278 L
s
.71023 .45582 m
.71011 .45618 L
s
.61724 .46441 m
.61702 .46484 L
s
.61712 .46441 m
.6169 .46484 L
s
.42068 .4674 m
.41937 .46704 L
s
.51596 .46216 m
.51538 .46276 L
s
.42058 .46739 m
.41927 .46702 L
s
.37075 .47053 m
.37008 .47002 L
s
.37083 .47055 m
.37016 .47003 L
s
.51599 .46212 m
.51541 .46273 L
s
.46478 .46575 m
.46348 .4662 L
s
.4648 .46575 m
.46349 .46621 L
s
.51602 .46212 m
.51544 .46272 L
s
.46491 .46574 m
.46361 .46619 L
s
.46495 .46574 m
.46365 .4662 L
s
.46492 .46574 m
.46361 .4662 L
s
.46494 .46573 m
.46364 .46619 L
s
.42047 .46734 m
.41917 .46698 L
s
.46495 .46572 m
.46365 .46618 L
s
.42035 .46734 m
.41905 .46697 L
s
.46498 .46571 m
.46368 .46616 L
s
.46505 .4657 m
.46375 .46616 L
s
.42027 .46734 m
.41897 .46697 L
s
.37058 .47047 m
.36991 .46996 L
s
.51601 .46208 m
.51543 .46268 L
s
.4202 .46733 m
.4189 .46696 L
s
.42025 .4673 m
.41895 .46693 L
s
.42011 .46731 m
.41881 .46694 L
s
.46512 .46566 m
.46382 .46612 L
s
.17432 .47592 m
.17414 .47558 L
s
.51613 .46202 m
.51556 .46262 L
s
.51609 .46201 m
.51552 .46261 L
s
.37067 .47043 m
.37001 .46991 L
s
.37075 .47042 m
.37008 .46991 L
s
.42023 .46726 m
.41893 .46689 L
s
.46529 .46562 m
.464 .46609 L
s
.46514 .46563 m
.46384 .46609 L
s
.28389 .46867 m
.2836 .46821 L
s
.46525 .46561 m
.46396 .46608 L
s
.46527 .46561 m
.46398 .46607 L
s
.42015 .46724 m
.41885 .46687 L
s
.42009 .46725 m
.41879 .46688 L
s
.46538 .4656 m
.46408 .46606 L
s
.85497 .30745 m
.85503 .30771 L
s
.37048 .47037 m
.36981 .46985 L
s
.42001 .46724 m
.41871 .46686 L
s
.46525 .46557 m
.46396 .46604 L
s
.46538 .46556 m
.46409 .46603 L
s
.17425 .47585 m
.17407 .4755 L
s
.46541 .46555 m
.46412 .46601 L
s
.42005 .4672 m
.41875 .46683 L
s
.51617 .46194 m
.51559 .46255 L
s
.41986 .46721 m
.41856 .46683 L
s
.41994 .46721 m
.41864 .46683 L
s
.46542 .46554 m
.46413 .46601 L
s
.61724 .46418 m
.61702 .46461 L
s
.41991 .46719 m
.41862 .46682 L
s
.19603 .56534 m
.1958 .565 L
s
.61728 .46417 m
.61706 .4646 L
s
.46546 .46553 m
.46417 .466 L
s
.41977 .46719 m
.41848 .46681 L
s
.71031 .45556 m
.71019 .45592 L
s
.46554 .4655 m
.46425 .46597 L
s
.4198 .46716 m
.41851 .46678 L
s
.2837 .46855 m
.28342 .46809 L
s
.41975 .46714 m
.41845 .46676 L
s
.41977 .46712 m
.41848 .46674 L
s
.51632 .46183 m
.51575 .46244 L
s
.41967 .46712 m
.41838 .46674 L
s
.37035 .47026 m
.36969 .46974 L
s
.41969 .4671 m
.41839 .46672 L
s
.46567 .46543 m
.46438 .4659 L
s
.46581 .46542 m
.46452 .4659 L
s
.46585 .46541 m
.46456 .46589 L
s
.4195 .4671 m
.41821 .46671 L
s
.51627 .46179 m
.5157 .4624 L
s
.41959 .46709 m
.4183 .46671 L
s
.46587 .46541 m
.46459 .46588 L
s
.71035 .45546 m
.71023 .45582 L
s
.37021 .4702 m
.36955 .46969 L
s
.4194 .46708 m
.41811 .46669 L
s
.41957 .46705 m
.41828 .46667 L
s
.46598 .46536 m
.4647 .46583 L
s
.41937 .46704 m
.41808 .46665 L
s
.37026 .47017 m
.3696 .46965 L
s
.61746 .46398 m
.61724 .46441 L
s
.41927 .46702 m
.41799 .46663 L
s
.61734 .46398 m
.61712 .46441 L
s
.85491 .3072 m
.85497 .30745 L
s
.28357 .4684 m
.28329 .46794 L
s
.46607 .46527 m
.46478 .46575 L
s
.41917 .46698 m
.41788 .46659 L
s
.46608 .46527 m
.4648 .46575 L
s
.4662 .46526 m
.46491 .46574 L
s
.4662 .46526 m
.46492 .46574 L
s
.46623 .46526 m
.46495 .46574 L
s
.41905 .46697 m
.41777 .46658 L
s
.46622 .46525 m
.46494 .46573 L
s
.37017 .47012 m
.36951 .4696 L
s
.46623 .46524 m
.46495 .46572 L
s
.41897 .46697 m
.41769 .46658 L
s
.17414 .47558 m
.17397 .47523 L
s
.4189 .46696 m
.41762 .46657 L
s
.46626 .46522 m
.46498 .46571 L
s
.46633 .46522 m
.46505 .4657 L
s
.41895 .46693 m
.41767 .46654 L
s
.41881 .46694 m
.41753 .46654 L
s
.46639 .46517 m
.46512 .46566 L
s
.41893 .46689 m
.41766 .46649 L
s
.51648 .46157 m
.51592 .46218 L
s
.17407 .4755 m
.17389 .47516 L
s
.37008 .47002 m
.36942 .4695 L
s
.37016 .47003 m
.36951 .46951 L
s
.51653 .46155 m
.51596 .46216 L
s
.41885 .46687 m
.41757 .46647 L
s
.46641 .46514 m
.46514 .46563 L
s
.41879 .46688 m
.41751 .46648 L
s
.46656 .46514 m
.46529 .46562 L
s
.46653 .46513 m
.46525 .46561 L
s
.46655 .46512 m
.46527 .46561 L
s
.41871 .46686 m
.41743 .46646 L
s
.46665 .4651 m
.46538 .4656 L
s
.51655 .46152 m
.51599 .46212 L
s
.71043 .4552 m
.71031 .45556 L
s
.2836 .46821 m
.28332 .46776 L
s
.51658 .46151 m
.51602 .46212 L
s
.1958 .565 m
.19556 .56466 L
s
.46653 .46509 m
.46525 .46557 L
s
.41875 .46683 m
.41747 .46643 L
s
.41864 .46683 m
.41736 .46644 L
s
.41856 .46683 m
.41729 .46644 L
s
.46666 .46508 m
.46538 .46556 L
s
.41862 .46682 m
.41734 .46642 L
s
.36991 .46996 m
.36926 .46944 L
s
.46668 .46506 m
.46541 .46555 L
s
.61746 .46375 m
.61724 .46418 L
s
.46669 .46505 m
.46542 .46554 L
s
.41848 .46681 m
.4172 .46641 L
s
.51657 .46147 m
.51601 .46208 L
s
.6175 .46374 m
.61728 .46417 L
s
.46673 .46504 m
.46546 .46553 L
s
.41851 .46678 m
.41723 .46638 L
s
.46681 .46501 m
.46554 .4655 L
s
.85485 .30694 m
.85491 .3072 L
s
.37001 .46991 m
.36935 .46939 L
s
.37008 .46991 m
.36943 .46939 L
s
.41845 .46676 m
.41718 .46636 L
s
.51669 .46141 m
.51613 .46202 L
s
.41848 .46674 m
.41721 .46634 L
s
.51665 .4614 m
.51609 .46201 L
s
.71047 .4551 m
.71035 .45546 L
s
.41838 .46674 m
.4171 .46634 L
s
.41839 .46672 m
.41712 .46632 L
s
.36981 .46985 m
.36916 .46933 L
s
.28342 .46809 m
.28314 .46763 L
s
.41821 .46671 m
.41694 .46631 L
s
.4183 .46671 m
.41703 .46631 L
s
.46694 .46493 m
.46567 .46543 L
s
.46707 .46493 m
.46581 .46542 L
s
.46711 .46492 m
.46585 .46541 L
s
.46713 .46491 m
.46587 .46541 L
s
.41811 .46669 m
.41685 .46628 L
s
.41828 .46667 m
.41702 .46627 L
s
.51673 .46133 m
.51617 .46194 L
s
.41808 .46665 m
.41682 .46624 L
s
.46724 .46486 m
.46598 .46536 L
s
.41799 .46663 m
.41672 .46622 L
s
.61767 .46355 m
.61746 .46398 L
s
.17397 .47523 m
.17379 .47489 L
s
.61756 .46355 m
.61734 .46398 L
s
.36969 .46974 m
.36904 .46922 L
s
.51687 .46122 m
.51632 .46183 L
s
.41788 .46659 m
.41662 .46618 L
s
.28329 .46794 m
.28301 .46749 L
s
.46733 .46477 m
.46607 .46527 L
s
.41777 .46658 m
.41651 .46616 L
s
.46734 .46477 m
.46608 .46527 L
s
.46745 .46476 m
.4662 .46526 L
s
.41769 .46658 m
.41643 .46616 L
s
.51682 .46119 m
.51627 .46179 L
s
.46745 .46475 m
.4662 .46526 L
s
.36955 .46969 m
.3689 .46916 L
s
.46749 .46475 m
.46623 .46526 L
s
.41762 .46657 m
.41636 .46616 L
s
.46747 .46475 m
.46622 .46525 L
s
.46749 .46474 m
.46623 .46524 L
s
.17389 .47516 m
.17372 .47481 L
s
.85479 .30669 m
.85485 .30694 L
s
.41767 .46654 m
.41641 .46612 L
s
.46751 .46472 m
.46626 .46522 L
s
.41753 .46654 m
.41628 .46612 L
s
.46758 .46471 m
.46633 .46522 L
s
.3696 .46965 m
.36895 .46913 L
s
.71055 .45484 m
.71043 .4552 L
s
.41766 .46649 m
.4164 .46608 L
s
.46765 .46466 m
.46639 .46517 L
s
.41757 .46647 m
.41632 .46605 L
s
.41751 .46648 m
.41626 .46606 L
s
.19556 .56466 m
.19533 .56431 L
s
.41743 .46646 m
.41618 .46604 L
s
.46766 .46463 m
.46641 .46514 L
s
.36951 .4696 m
.36886 .46908 L
s
.46781 .46462 m
.46656 .46514 L
s
.46778 .46461 m
.46653 .46513 L
s
.4678 .46461 m
.46655 .46512 L
s
.41747 .46643 m
.41622 .46601 L
s
.41736 .46644 m
.41611 .46602 L
s
.41729 .46644 m
.41603 .46601 L
s
.4679 .46459 m
.46665 .4651 L
s
.41734 .46642 m
.41609 .466 L
s
.61767 .46332 m
.61746 .46375 L
s
.46778 .46458 m
.46653 .46509 L
s
.28332 .46776 m
.28305 .4673 L
s
.4679 .46456 m
.46666 .46508 L
s
.61771 .46331 m
.6175 .46374 L
s
.71059 .45474 m
.71047 .4551 L
s
.4172 .46641 m
.41595 .46598 L
s
.46793 .46455 m
.46668 .46506 L
s
.46794 .46454 m
.46669 .46505 L
s
.41723 .46638 m
.41598 .46596 L
s
.46798 .46452 m
.46673 .46504 L
s
.36942 .4695 m
.36877 .46898 L
s
.36951 .46951 m
.36886 .46899 L
s
.51704 .46096 m
.51648 .46157 L
s
.41718 .46636 m
.41593 .46593 L
s
.46806 .46449 m
.46681 .46501 L
s
.41721 .46634 m
.41596 .46591 L
s
.51708 .46094 m
.51653 .46155 L
s
.4171 .46634 m
.41585 .46591 L
s
.41712 .46632 m
.41587 .46589 L
s
.5171 .4609 m
.51655 .46152 L
s
.41703 .46631 m
.41578 .46588 L
s
.36926 .46944 m
.36861 .46891 L
s
.41694 .46631 m
.41569 .46588 L
s
.85473 .30643 m
.85479 .30669 L
s
.51714 .4609 m
.51658 .46151 L
s
.28314 .46763 m
.28286 .46717 L
s
.17379 .47489 m
.17362 .47454 L
s
.46818 .46441 m
.46694 .46493 L
s
.41685 .46628 m
.4156 .46585 L
s
.46831 .4644 m
.46707 .46493 L
s
.41702 .46627 m
.41577 .46584 L
s
.46835 .46439 m
.46711 .46492 L
s
.51712 .46086 m
.51657 .46147 L
s
.46837 .46438 m
.46713 .46491 L
s
.36935 .46939 m
.3687 .46887 L
s
.36943 .46939 m
.36878 .46886 L
s
.41682 .46624 m
.41557 .46581 L
s
.61788 .46312 m
.61767 .46355 L
s
.61777 .46312 m
.61756 .46355 L
s
.41672 .46622 m
.41548 .46579 L
s
.51724 .4608 m
.51669 .46141 L
s
.46848 .46433 m
.46724 .46486 L
s
.17372 .47481 m
.17355 .47447 L
s
.36916 .46933 m
.36852 .46881 L
s
.5172 .46078 m
.51665 .4614 L
s
.41662 .46618 m
.41538 .46575 L
s
.41651 .46616 m
.41527 .46573 L
s
.71066 .45448 m
.71055 .45484 L
s
.28301 .46749 m
.28274 .46703 L
s
.41643 .46616 m
.41519 .46573 L
s
.46856 .46424 m
.46733 .46477 L
s
.41636 .46616 m
.41512 .46572 L
s
.51728 .46072 m
.51673 .46133 L
s
.46857 .46424 m
.46734 .46477 L
s
.46869 .46423 m
.46745 .46476 L
s
.46869 .46423 m
.46745 .46475 L
s
.46872 .46422 m
.46749 .46475 L
s
.41641 .46612 m
.41518 .46569 L
s
.4687 .46422 m
.46747 .46475 L
s
.46872 .46421 m
.46749 .46474 L
s
.41628 .46612 m
.41504 .46568 L
s
.19533 .56431 m
.1951 .56397 L
s
.46874 .46419 m
.46751 .46472 L
s
.46881 .46418 m
.46758 .46471 L
s
.36904 .46922 m
.3684 .4687 L
s
.4164 .46608 m
.41516 .46564 L
s
.85466 .30618 m
.85473 .30643 L
s
.7107 .45438 m
.71059 .45474 L
s
.41632 .46605 m
.41508 .46561 L
s
.51742 .46061 m
.51687 .46122 L
s
.41626 .46606 m
.41502 .46562 L
s
.46887 .46413 m
.46765 .46466 L
s
.3689 .46916 m
.36826 .46864 L
s
.41618 .46604 m
.41494 .4656 L
s
.51737 .46057 m
.51682 .46119 L
s
.61788 .46289 m
.61767 .46332 L
s
.41622 .46601 m
.41499 .46557 L
s
.46889 .4641 m
.46766 .46463 L
s
.41611 .46602 m
.41488 .46557 L
s
.46903 .46409 m
.46781 .46462 L
s
.61792 .46288 m
.61771 .46331 L
s
.41603 .46601 m
.41481 .46557 L
s
.36895 .46913 m
.36831 .4686 L
s
.41609 .466 m
.41486 .46556 L
s
.469 .46408 m
.46778 .46461 L
s
.46902 .46407 m
.4678 .46461 L
s
.28305 .4673 m
.28277 .46684 L
s
.46912 .46405 m
.4679 .46459 L
s
.41595 .46598 m
.41472 .46554 L
s
.469 .46404 m
.46778 .46458 L
s
.46913 .46402 m
.4679 .46456 L
s
.41598 .46596 m
.41476 .46551 L
s
.17362 .47454 m
.17345 .4742 L
s
.46915 .46401 m
.46793 .46455 L
s
.46916 .464 m
.46794 .46454 L
s
.36886 .46908 m
.36823 .46855 L
s
.41593 .46593 m
.41471 .46549 L
s
.41596 .46591 m
.41473 .46547 L
s
.4692 .46398 m
.46798 .46452 L
s
.41585 .46591 m
.41463 .46546 L
s
.46927 .46395 m
.46806 .46449 L
s
.41587 .46589 m
.41465 .46544 L
s
.17355 .47447 m
.17337 .47412 L
s
.41578 .46588 m
.41456 .46543 L
s
.41569 .46588 m
.41447 .46543 L
s
.28286 .46717 m
.28259 .46671 L
s
.41577 .46584 m
.41455 .46539 L
s
.4156 .46585 m
.41438 .4654 L
s
.36877 .46898 m
.36814 .46845 L
s
.36886 .46899 m
.36822 .46846 L
s
.61809 .46269 m
.61788 .46312 L
s
.61798 .46268 m
.61777 .46312 L
s
.8546 .30592 m
.85466 .30618 L
s
.46939 .46387 m
.46818 .46441 L
s
.46953 .46386 m
.46831 .4644 L
s
.71078 .45412 m
.71066 .45448 L
s
.51758 .46035 m
.51704 .46096 L
s
.46956 .46385 m
.46835 .46439 L
s
.41557 .46581 m
.41436 .46536 L
s
.46958 .46384 m
.46837 .46438 L
s
.51762 .46032 m
.51708 .46094 L
s
.41548 .46579 m
.41426 .46533 L
s
.36861 .46891 m
.36798 .46838 L
s
.51764 .46029 m
.5171 .4609 L
s
.51768 .46029 m
.51714 .4609 L
s
.46969 .46378 m
.46848 .46433 L
s
.41538 .46575 m
.41416 .46529 L
s
.1951 .56397 m
.19487 .56362 L
s
.28274 .46703 m
.28247 .46657 L
s
.41527 .46573 m
.41406 .46527 L
s
.3687 .46887 m
.36807 .46834 L
s
.36878 .46886 m
.36815 .46833 L
s
.71082 .45401 m
.7107 .45438 L
s
.51766 .46024 m
.51712 .46086 L
s
.41519 .46573 m
.41398 .46527 L
s
.41512 .46572 m
.41391 .46526 L
s
.36852 .46881 m
.36789 .46828 L
s
.46977 .46369 m
.46856 .46424 L
s
.41518 .46569 m
.41396 .46523 L
s
.46978 .46369 m
.46857 .46424 L
s
.46989 .46368 m
.46869 .46423 L
s
.51777 .46018 m
.51724 .4608 L
s
.41504 .46568 m
.41383 .46522 L
s
.46989 .46367 m
.46869 .46423 L
s
.51773 .46017 m
.5172 .46078 L
s
.46992 .46367 m
.46872 .46422 L
s
.46991 .46367 m
.4687 .46422 L
s
.46992 .46365 m
.46872 .46421 L
s
.41516 .46564 m
.41395 .46518 L
s
.46994 .46363 m
.46874 .46419 L
s
.47001 .46362 m
.46881 .46418 L
s
.61809 .46245 m
.61788 .46289 L
s
.17345 .4742 m
.17327 .47385 L
s
.41508 .46561 m
.41387 .46515 L
s
.41502 .46562 m
.41381 .46516 L
s
.61813 .46244 m
.61792 .46288 L
s
.41494 .4656 m
.41373 .46514 L
s
.51781 .4601 m
.51728 .46072 L
s
.85454 .30567 m
.8546 .30592 L
s
.47007 .46357 m
.46887 .46413 L
s
.41499 .46557 m
.41378 .46511 L
s
.41488 .46557 m
.41367 .46511 L
s
.41481 .46557 m
.4136 .4651 L
s
.3684 .4687 m
.36777 .46817 L
s
.28277 .46684 m
.2825 .46638 L
s
.41486 .46556 m
.41366 .46509 L
s
.47009 .46354 m
.46889 .4641 L
s
.17337 .47412 m
.1732 .47378 L
s
.47023 .46352 m
.46903 .46409 L
s
.4702 .46352 m
.469 .46408 L
s
.41472 .46554 m
.41352 .46507 L
s
.47021 .46351 m
.46902 .46407 L
s
.36826 .46864 m
.36764 .46811 L
s
.41476 .46551 m
.41355 .46505 L
s
.51795 .45999 m
.51742 .46061 L
s
.47031 .46349 m
.46912 .46405 L
s
.4702 .46348 m
.469 .46404 L
s
.47032 .46346 m
.46913 .46402 L
s
.41471 .46549 m
.4135 .46502 L
s
.36831 .4686 m
.36768 .46807 L
s
.47034 .46345 m
.46915 .46401 L
s
.5179 .45995 m
.51737 .46057 L
s
.71089 .45375 m
.71078 .45412 L
s
.41473 .46547 m
.41353 .465 L
s
.47035 .46344 m
.46916 .464 L
s
.41463 .46546 m
.41342 .465 L
s
.41465 .46544 m
.41345 .46497 L
s
.47039 .46341 m
.4692 .46398 L
s
.6183 .46225 m
.61809 .46269 L
s
.28259 .46671 m
.28232 .46625 L
s
.61818 .46225 m
.61798 .46268 L
s
.41456 .46543 m
.41336 .46496 L
s
.47046 .46339 m
.46927 .46395 L
s
.41447 .46543 m
.41328 .46496 L
s
.36823 .46855 m
.3676 .46802 L
s
.41455 .46539 m
.41335 .46492 L
s
.41438 .4654 m
.41319 .46493 L
s
.71093 .45365 m
.71082 .45401 L
s
.19487 .56362 m
.19464 .56328 L
s
.41436 .46536 m
.41316 .46488 L
s
.85447 .30541 m
.85454 .30567 L
s
.47058 .4633 m
.46939 .46387 L
s
.47071 .46329 m
.46953 .46386 L
s
.47074 .46328 m
.46956 .46385 L
s
.41426 .46533 m
.41306 .46486 L
s
.47076 .46327 m
.46958 .46384 L
s
.36814 .46845 m
.36752 .46792 L
s
.36822 .46846 m
.3676 .46793 L
s
.28247 .46657 m
.2822 .4661 L
s
.41416 .46529 m
.41297 .46481 L
s
.17327 .47385 m
.1731 .47351 L
s
.47087 .46321 m
.46969 .46378 L
s
.41406 .46527 m
.41287 .46479 L
s
.5181 .45973 m
.51758 .46035 L
s
.41398 .46527 m
.41279 .46479 L
s
.36798 .46838 m
.36736 .46785 L
s
.51814 .4597 m
.51762 .46032 L
s
.41391 .46526 m
.41272 .46478 L
s
.41396 .46523 m
.41278 .46475 L
s
.61829 .46202 m
.61809 .46245 L
s
.51816 .45967 m
.51764 .46029 L
s
.5182 .45967 m
.51768 .46029 L
s
.41383 .46522 m
.41265 .46474 L
s
.61833 .46201 m
.61813 .46244 L
s
.1732 .47378 m
.17303 .47343 L
s
.47095 .46312 m
.46977 .46369 L
s
.36807 .46834 m
.36745 .4678 L
s
.47096 .46311 m
.46978 .46369 L
s
.36815 .46833 m
.36753 .4678 L
s
.47107 .4631 m
.46989 .46368 L
s
.41395 .46518 m
.41277 .4647 L
s
.47107 .46309 m
.46989 .46367 L
s
.47109 .46309 m
.46992 .46367 L
s
.47108 .46309 m
.46991 .46367 L
s
.4711 .46308 m
.46992 .46365 L
s
.51818 .45962 m
.51766 .46024 L
s
.36789 .46828 m
.36727 .46774 L
s
.41387 .46515 m
.41268 .46467 L
s
.41381 .46516 m
.41263 .46468 L
s
.47112 .46305 m
.46994 .46363 L
s
.47118 .46304 m
.47001 .46362 L
s
.711 .45339 m
.71089 .45375 L
s
.41373 .46514 m
.41255 .46465 L
s
.2825 .46638 m
.28223 .46592 L
s
.51829 .45956 m
.51777 .46018 L
s
.85441 .30516 m
.85447 .30541 L
s
.51826 .45955 m
.51773 .46017 L
s
.41378 .46511 m
.41259 .46462 L
s
.41367 .46511 m
.41249 .46462 L
s
.4136 .4651 m
.41242 .46462 L
s
.47125 .46299 m
.47007 .46357 L
s
.41366 .46509 m
.41248 .4646 L
s
.41352 .46507 m
.41234 .46458 L
s
.47126 .46295 m
.47009 .46354 L
s
.41355 .46505 m
.41237 .46456 L
s
.47139 .46294 m
.47023 .46352 L
s
.51833 .45948 m
.51781 .4601 L
s
.6185 .46182 m
.6183 .46225 L
s
.47137 .46293 m
.4702 .46352 L
s
.47138 .46293 m
.47021 .46351 L
s
.36777 .46817 m
.36715 .46763 L
s
.71104 .45329 m
.71093 .45365 L
s
.61839 .46181 m
.61818 .46225 L
s
.47147 .4629 m
.47031 .46349 L
s
.4135 .46502 m
.41233 .46453 L
s
.47137 .4629 m
.4702 .46348 L
s
.41353 .465 m
.41236 .46451 L
s
.28232 .46625 m
.28205 .46579 L
s
.47149 .46288 m
.47032 .46346 L
s
.41342 .465 m
.41225 .4645 L
s
.19464 .56328 m
.19441 .56293 L
s
.36764 .46811 m
.36702 .46757 L
s
.47151 .46286 m
.47034 .46345 L
s
.41345 .46497 m
.41227 .46448 L
s
.47151 .46285 m
.47035 .46344 L
s
.41336 .46496 m
.41218 .46447 L
s
.51846 .45937 m
.51795 .45999 L
s
.41328 .46496 m
.4121 .46446 L
s
.36768 .46807 m
.36707 .46754 L
s
.47155 .46282 m
.47039 .46341 L
s
.1731 .47351 m
.17293 .47316 L
s
.41335 .46492 m
.41217 .46443 L
s
.47163 .4628 m
.47046 .46339 L
s
.41319 .46493 m
.41202 .46443 L
s
.51841 .45933 m
.5179 .45995 L
s
.41316 .46488 m
.41199 .46439 L
s
.85434 .30491 m
.85441 .30516 L
s
.3676 .46802 m
.36699 .46748 L
s
.2822 .4661 m
.28193 .46564 L
s
.17303 .47343 m
.17286 .47309 L
s
.41306 .46486 m
.41189 .46436 L
s
.47174 .46271 m
.47058 .4633 L
s
.47187 .4627 m
.47071 .46329 L
s
.4719 .46268 m
.47074 .46328 L
s
.47192 .46267 m
.47076 .46327 L
s
.61849 .46158 m
.61829 .46202 L
s
.41297 .46481 m
.41181 .46432 L
s
.61853 .46157 m
.61833 .46201 L
s
.41287 .46479 m
.4117 .46429 L
s
.71111 .45303 m
.711 .45339 L
s
.36752 .46792 m
.36691 .46738 L
s
.3676 .46793 m
.36699 .46739 L
s
.41279 .46479 m
.41163 .46429 L
s
.47202 .46261 m
.47087 .46321 L
s
.41272 .46478 m
.41156 .46428 L
s
.41278 .46475 m
.41161 .46424 L
s
.41265 .46474 m
.41149 .46424 L
s
.36736 .46785 m
.36676 .46731 L
s
.51862 .4591 m
.5181 .45973 L
s
.41277 .4647 m
.41161 .46419 L
s
.28223 .46592 m
.28197 .46545 L
s
.4721 .46252 m
.47095 .46312 L
s
.51865 .45908 m
.51814 .4597 L
s
.71115 .45293 m
.71104 .45329 L
s
.4721 .46252 m
.47096 .46311 L
s
.47222 .4625 m
.47107 .4631 L
s
.41268 .46467 m
.41152 .46416 L
s
.41263 .46468 m
.41147 .46417 L
s
.47222 .46249 m
.47107 .46309 L
s
.36745 .4678 m
.36684 .46726 L
s
.47224 .46249 m
.47109 .46309 L
s
.47223 .46249 m
.47108 .46309 L
s
.47224 .46248 m
.4711 .46308 L
s
.51867 .45904 m
.51816 .45967 L
s
.36753 .4678 m
.36692 .46726 L
s
.51871 .45904 m
.5182 .45967 L
s
.41255 .46465 m
.41139 .46415 L
s
.85427 .30465 m
.85434 .30491 L
s
.6187 .46139 m
.6185 .46182 L
s
.47226 .46245 m
.47112 .46305 L
s
.61859 .46138 m
.61839 .46181 L
s
.41259 .46462 m
.41144 .46412 L
s
.36727 .46774 m
.36666 .46721 L
s
.47232 .46244 m
.47118 .46304 L
s
.41249 .46462 m
.41133 .46412 L
s
.19441 .56293 m
.19418 .56258 L
s
.41242 .46462 m
.41127 .46411 L
s
.51869 .459 m
.51818 .45962 L
s
.41248 .4646 m
.41132 .4641 L
s
.17293 .47316 m
.17277 .47281 L
s
.47239 .46239 m
.47125 .46299 L
s
.41234 .46458 m
.41119 .46407 L
s
.28205 .46579 m
.28179 .46533 L
s
.5188 .45894 m
.51829 .45956 L
s
.41237 .46456 m
.41122 .46405 L
s
.51876 .45892 m
.51826 .45955 L
s
.4724 .46235 m
.47126 .46295 L
s
.47253 .46233 m
.47139 .46294 L
s
.41233 .46453 m
.41118 .46402 L
s
.17286 .47309 m
.1727 .47274 L
s
.47251 .46232 m
.47137 .46293 L
s
.41236 .46451 m
.41121 .464 L
s
.47252 .46232 m
.47138 .46293 L
s
.41225 .4645 m
.4111 .46399 L
s
.36715 .46763 m
.36655 .46709 L
s
.47261 .46229 m
.47147 .4629 L
s
.47251 .46229 m
.47137 .4629 L
s
.41227 .46448 m
.41112 .46397 L
s
.51884 .45885 m
.51833 .45948 L
s
.47262 .46227 m
.47149 .46288 L
s
.41218 .46447 m
.41103 .46396 L
s
.47264 .46225 m
.47151 .46286 L
s
.4121 .46446 m
.41096 .46395 L
s
.47265 .46224 m
.47151 .46285 L
s
.36702 .46757 m
.36642 .46703 L
s
.71122 .45267 m
.71111 .45303 L
s
.41217 .46443 m
.41103 .46392 L
s
.28193 .46564 m
.28167 .46518 L
s
.41202 .46443 m
.41087 .46392 L
s
.47268 .46221 m
.47155 .46282 L
s
.61869 .46115 m
.61849 .46158 L
s
.36707 .46754 m
.36647 .467 L
s
.47276 .46218 m
.47163 .4628 L
s
.61873 .46114 m
.61853 .46157 L
s
.85421 .3044 m
.85427 .30465 L
s
.51896 .45875 m
.51846 .45937 L
s
.41199 .46439 m
.41085 .46387 L
s
.51891 .45871 m
.51841 .45933 L
s
.41189 .46436 m
.41075 .46384 L
s
.71126 .45256 m
.71115 .45293 L
s
.36699 .46748 m
.36639 .46694 L
s
.47287 .4621 m
.47174 .46271 L
s
.41181 .46432 m
.41067 .4638 L
s
.47299 .46208 m
.47187 .4627 L
s
.47302 .46207 m
.4719 .46268 L
s
.4117 .46429 m
.41056 .46377 L
s
.47304 .46206 m
.47192 .46267 L
s
.41163 .46429 m
.41049 .46377 L
s
.41156 .46428 m
.41043 .46375 L
s
.17277 .47281 m
.1726 .47247 L
s
.28197 .46545 m
.28171 .46499 L
s
.41161 .46424 m
.41048 .46372 L
s
.36691 .46738 m
.36631 .46683 L
s
.36699 .46739 m
.36639 .46685 L
s
.19418 .56258 m
.19396 .56223 L
s
.47314 .46199 m
.47202 .46261 L
s
.6189 .46095 m
.6187 .46139 L
s
.41149 .46424 m
.41035 .46371 L
s
.61878 .46094 m
.61859 .46138 L
s
.41161 .46419 m
.41047 .46367 L
s
.1727 .47274 m
.17253 .47239 L
s
.36676 .46731 m
.36616 .46677 L
s
.41152 .46416 m
.41039 .46364 L
s
.41147 .46417 m
.41034 .46365 L
s
.47322 .4619 m
.4721 .46252 L
s
.85414 .30414 m
.85421 .3044 L
s
.47322 .46189 m
.4721 .46252 L
s
.51911 .45848 m
.51862 .4591 L
s
.47333 .46188 m
.47222 .4625 L
s
.41139 .46415 m
.41026 .46362 L
s
.28179 .46533 m
.28153 .46486 L
s
.47333 .46187 m
.47222 .46249 L
s
.51915 .45845 m
.51865 .45908 L
s
.47334 .46187 m
.47223 .46249 L
s
.47335 .46187 m
.47224 .46249 L
s
.41144 .46412 m
.41031 .46359 L
s
.36684 .46726 m
.36624 .46672 L
s
.47336 .46185 m
.47224 .46248 L
s
.36692 .46726 m
.36632 .46671 L
s
.41133 .46412 m
.4102 .46359 L
s
.41127 .46411 m
.41014 .46358 L
s
.41132 .4641 m
.41019 .46357 L
s
.47337 .46183 m
.47226 .46245 L
s
.51917 .45842 m
.51867 .45904 L
s
.71133 .4523 m
.71122 .45267 L
s
.51921 .45842 m
.51871 .45904 L
s
.36666 .46721 m
.36607 .46666 L
s
.47344 .46181 m
.47232 .46244 L
s
.41119 .46407 m
.41006 .46355 L
s
.41122 .46405 m
.4101 .46352 L
s
.51919 .45837 m
.51869 .459 L
s
.4735 .46176 m
.47239 .46239 L
s
.41118 .46402 m
.41005 .46349 L
s
.61888 .46071 m
.61869 .46115 L
s
.41121 .464 m
.41008 .46347 L
s
.51929 .45831 m
.5188 .45894 L
s
.61893 .4607 m
.61873 .46114 L
s
.47351 .46172 m
.4724 .46235 L
s
.28167 .46518 m
.28141 .46472 L
s
.4111 .46399 m
.40997 .46346 L
s
.71137 .4522 m
.71126 .45256 L
s
.51926 .4583 m
.51876 .45892 L
s
.47363 .4617 m
.47253 .46233 L
s
.47361 .4617 m
.47251 .46232 L
s
.41112 .46397 m
.41 .46344 L
s
.47362 .46169 m
.47252 .46232 L
s
.41103 .46396 m
.40991 .46343 L
s
.36655 .46709 m
.36596 .46654 L
s
.41096 .46395 m
.40984 .46342 L
s
.47361 .46166 m
.47251 .46229 L
s
.47371 .46166 m
.47261 .46229 L
s
.47373 .46164 m
.47262 .46227 L
s
.47374 .46162 m
.47264 .46225 L
s
.51933 .45823 m
.51884 .45885 L
s
.1726 .47247 m
.17244 .47212 L
s
.85407 .30389 m
.85414 .30414 L
s
.41087 .46392 m
.40975 .46338 L
s
.36642 .46703 m
.36583 .46648 L
s
.47375 .46161 m
.47265 .46224 L
s
.47378 .46158 m
.47268 .46221 L
s
.41085 .46387 m
.40973 .46333 L
s
.36647 .467 m
.36588 .46645 L
s
.19396 .56223 m
.19373 .56189 L
s
.47386 .46155 m
.47276 .46218 L
s
.41075 .46384 m
.40964 .46331 L
s
.17253 .47239 m
.17236 .47204 L
s
.51945 .45812 m
.51896 .45875 L
s
.61909 .46051 m
.6189 .46095 L
s
.28171 .46499 m
.28145 .46453 L
s
.61898 .46051 m
.61878 .46094 L
s
.41067 .4638 m
.40955 .46326 L
s
.5194 .45808 m
.51891 .45871 L
s
.36639 .46694 m
.3658 .46639 L
s
.41056 .46377 m
.40945 .46323 L
s
.47396 .46146 m
.47287 .4621 L
s
.47409 .46144 m
.47299 .46208 L
s
.41049 .46377 m
.40938 .46323 L
s
.47411 .46143 m
.47302 .46207 L
s
.41043 .46375 m
.40932 .46321 L
s
.71144 .45194 m
.71133 .4523 L
s
.47413 .46142 m
.47304 .46206 L
s
.41048 .46372 m
.40937 .46318 L
s
.41035 .46371 m
.40925 .46317 L
s
.36631 .46683 m
.36572 .46629 L
s
.28153 .46486 m
.28128 .4644 L
s
.36639 .46685 m
.3658 .4663 L
s
.47423 .46135 m
.47314 .46199 L
s
.41047 .46367 m
.40937 .46313 L
s
.854 .30364 m
.85407 .30389 L
s
.41039 .46364 m
.40928 .4631 L
s
.41034 .46365 m
.40923 .4631 L
s
.71147 .45184 m
.71137 .4522 L
s
.36616 .46677 m
.36558 .46622 L
s
.41026 .46362 m
.40916 .46308 L
s
.47431 .46126 m
.47322 .4619 L
s
.61908 .46028 m
.61888 .46071 L
s
.41031 .46359 m
.4092 .46305 L
s
.47431 .46125 m
.47322 .46189 L
s
.61912 .46027 m
.61893 .4607 L
s
.4102 .46359 m
.4091 .46305 L
s
.47442 .46123 m
.47333 .46188 L
s
.5196 .45785 m
.51911 .45848 L
s
.41014 .46358 m
.40904 .46304 L
s
.36624 .46672 m
.36566 .46617 L
s
.41019 .46357 m
.40909 .46303 L
s
.17244 .47212 m
.17227 .47177 L
s
.47442 .46123 m
.47333 .46187 L
s
.36632 .46671 m
.36573 .46617 L
s
.47442 .46122 m
.47334 .46187 L
s
.47443 .46122 m
.47335 .46187 L
s
.47444 .46121 m
.47336 .46185 L
s
.51964 .45782 m
.51915 .45845 L
s
.28141 .46472 m
.28116 .46425 L
s
.41006 .46355 m
.40897 .463 L
s
.36607 .46666 m
.36549 .46611 L
s
.47445 .46118 m
.47337 .46183 L
s
.4101 .46352 m
.409 .46297 L
s
.51965 .45779 m
.51917 .45842 L
s
.51969 .45779 m
.51921 .45842 L
s
.47451 .46117 m
.47344 .46181 L
s
.17236 .47204 m
.1722 .4717 L
s
.19373 .56189 m
.19351 .56154 L
s
.41005 .46349 m
.40896 .46294 L
s
.41008 .46347 m
.40899 .46292 L
s
.47458 .46111 m
.4735 .46176 L
s
.51967 .45774 m
.51919 .45837 L
s
.40997 .46346 m
.40888 .46291 L
s
.41 .46344 m
.4089 .46289 L
s
.47458 .46107 m
.47351 .46172 L
s
.85394 .30338 m
.854 .30364 L
s
.40991 .46343 m
.40882 .46288 L
s
.51977 .45768 m
.51929 .45831 L
s
.51974 .45767 m
.51926 .4583 L
s
.40984 .46342 m
.40875 .46287 L
s
.61928 .46008 m
.61909 .46051 L
s
.4747 .46105 m
.47363 .4617 L
s
.47469 .46104 m
.47361 .4617 L
s
.4747 .46104 m
.47362 .46169 L
s
.61917 .46007 m
.61898 .46051 L
s
.36596 .46654 m
.36538 .466 L
s
.71154 .45158 m
.71144 .45194 L
s
.47469 .46101 m
.47361 .46166 L
s
.40975 .46338 m
.40867 .46283 L
s
.28145 .46453 m
.2812 .46406 L
s
.47478 .46101 m
.47371 .46166 L
s
.4748 .46099 m
.47373 .46164 L
s
.36583 .46648 m
.36526 .46593 L
s
.47481 .46097 m
.47374 .46162 L
s
.51981 .45759 m
.51933 .45823 L
s
.47482 .46095 m
.47375 .46161 L
s
.40973 .46333 m
.40865 .46278 L
s
.36588 .46645 m
.3653 .4659 L
s
.40964 .46331 m
.40855 .46275 L
s
.47485 .46092 m
.47378 .46158 L
s
.71158 .45147 m
.71147 .45184 L
s
.47492 .46089 m
.47386 .46155 L
s
.40955 .46326 m
.40847 .4627 L
s
.51992 .45749 m
.51945 .45812 L
s
.28128 .4644 m
.28103 .46393 L
s
.3658 .46639 m
.36523 .46584 L
s
.40945 .46323 m
.40837 .46268 L
s
.17227 .47177 m
.17211 .47142 L
s
.51988 .45745 m
.5194 .45808 L
s
.40938 .46323 m
.4083 .46267 L
s
.40932 .46321 m
.40824 .46265 L
s
.47502 .4608 m
.47396 .46146 L
s
.61926 .45984 m
.61908 .46028 L
s
.85387 .30313 m
.85394 .30338 L
s
.47515 .46078 m
.47409 .46144 L
s
.40937 .46318 m
.40829 .46262 L
s
.61931 .45983 m
.61912 .46027 L
s
.47517 .46077 m
.47411 .46143 L
s
.47519 .46076 m
.47413 .46142 L
s
.40925 .46317 m
.40817 .46261 L
s
.1722 .4717 m
.17204 .47135 L
s
.36572 .46629 m
.36515 .46574 L
s
.3658 .4663 m
.36523 .46575 L
s
.40937 .46313 m
.40829 .46256 L
s
.28116 .46425 m
.28091 .46379 L
s
.19351 .56154 m
.19328 .56119 L
s
.47528 .46069 m
.47423 .46135 L
s
.40928 .4631 m
.40821 .46253 L
s
.40923 .4631 m
.40816 .46254 L
s
.36558 .46622 m
.36501 .46567 L
s
.40916 .46308 m
.40808 .46251 L
s
.4092 .46305 m
.40813 .46248 L
s
.4091 .46305 m
.40803 .46248 L
s
.71164 .45121 m
.71154 .45158 L
s
.40904 .46304 m
.40797 .46247 L
s
.40909 .46303 m
.40802 .46246 L
s
.36566 .46617 m
.36509 .46562 L
s
.47536 .46059 m
.47431 .46126 L
s
.36573 .46617 m
.36516 .46561 L
s
.47536 .46058 m
.47431 .46125 L
s
.61947 .45964 m
.61928 .46008 L
s
.52007 .45721 m
.5196 .45785 L
s
.47547 .46057 m
.47442 .46123 L
s
.61935 .45963 m
.61917 .46007 L
s
.40897 .463 m
.4079 .46243 L
s
.47547 .46056 m
.47442 .46123 L
s
.36549 .46611 m
.36492 .46556 L
s
.47547 .46056 m
.47442 .46122 L
s
.5201 .45719 m
.51964 .45782 L
s
.47548 .46055 m
.47443 .46122 L
s
.47549 .46054 m
.47444 .46121 L
s
.409 .46297 m
.40793 .46241 L
s
.4755 .46051 m
.47445 .46118 L
s
.52011 .45715 m
.51965 .45779 L
s
.52017 .45715 m
.51969 .45779 L
s
.8538 .30288 m
.85387 .30313 L
s
.71168 .45111 m
.71158 .45147 L
s
.2812 .46406 m
.28095 .4636 L
s
.40896 .46294 m
.40789 .46237 L
s
.47556 .4605 m
.47451 .46117 L
s
.40899 .46292 m
.40792 .46235 L
s
.40888 .46291 m
.40781 .46234 L
s
.52014 .4571 m
.51967 .45774 L
s
.4089 .46289 m
.40784 .46231 L
s
.47562 .46044 m
.47458 .46111 L
s
.17211 .47142 m
.17195 .47107 L
s
.40882 .46288 m
.40776 .46231 L
s
.40875 .46287 m
.40769 .46229 L
s
.36538 .466 m
.36481 .46544 L
s
.52023 .45704 m
.51977 .45768 L
s
.47562 .4604 m
.47458 .46107 L
s
.5202 .45703 m
.51974 .45767 L
s
.40867 .46283 m
.40761 .46225 L
s
.47574 .46038 m
.4747 .46105 L
s
.47573 .46037 m
.47469 .46104 L
s
.47573 .46037 m
.4747 .46104 L
s
.28103 .46393 m
.28078 .46347 L
s
.17204 .47135 m
.17188 .471 L
s
.36526 .46593 m
.36469 .46538 L
s
.47573 .46034 m
.47469 .46101 L
s
.47582 .46033 m
.47478 .46101 L
s
.61945 .4594 m
.61926 .45984 L
s
.40865 .46278 m
.40759 .4622 L
s
.47584 .46031 m
.4748 .46099 L
s
.61949 .45939 m
.61931 .45983 L
s
.52028 .45696 m
.51981 .45759 L
s
.3653 .4659 m
.36474 .46535 L
s
.47585 .4603 m
.47481 .46097 L
s
.40855 .46275 m
.40749 .46217 L
s
.47585 .46028 m
.47482 .46095 L
s
.19328 .56119 m
.19306 .56084 L
s
.47588 .46024 m
.47485 .46092 L
s
.40847 .4627 m
.40741 .46213 L
s
.85373 .30262 m
.8538 .30288 L
s
.71175 .45085 m
.71164 .45121 L
s
.47595 .46022 m
.47492 .46089 L
s
.36523 .46584 m
.36466 .46528 L
s
.52038 .45685 m
.51992 .45749 L
s
.40837 .46268 m
.40732 .4621 L
s
.28091 .46379 m
.28066 .46332 L
s
.4083 .46267 m
.40725 .46209 L
s
.40824 .46265 m
.4072 .46207 L
s
.52034 .45681 m
.51988 .45745 L
s
.40829 .46262 m
.40724 .46204 L
s
.47605 .46012 m
.47502 .4608 L
s
.40817 .46261 m
.40712 .46203 L
s
.61965 .4592 m
.61947 .45964 L
s
.36515 .46574 m
.36458 .46518 L
s
.36523 .46575 m
.36466 .46519 L
s
.61954 .4592 m
.61935 .45963 L
s
.71178 .45075 m
.71168 .45111 L
s
.47617 .4601 m
.47515 .46078 L
s
.4762 .46009 m
.47517 .46077 L
s
.40829 .46256 m
.40724 .46198 L
s
.47621 .46007 m
.47519 .46076 L
s
.40821 .46253 m
.40716 .46195 L
s
.17195 .47107 m
.17179 .47073 L
s
.40816 .46254 m
.40711 .46196 L
s
.36501 .46567 m
.36445 .46511 L
s
.40808 .46251 m
.40704 .46193 L
s
.4763 .46 m
.47528 .46069 L
s
.28095 .4636 m
.28071 .46313 L
s
.40813 .46248 m
.40709 .4619 L
s
.40803 .46248 m
.40699 .4619 L
s
.36509 .46562 m
.36453 .46506 L
s
.40802 .46246 m
.40698 .46188 L
s
.40797 .46247 m
.40693 .46188 L
s
.36516 .46561 m
.3646 .46506 L
s
.85366 .30237 m
.85373 .30262 L
s
.17188 .471 m
.17172 .47065 L
s
.36492 .46556 m
.36436 .465 L
s
.4079 .46243 m
.40686 .46184 L
s
.52053 .45658 m
.52007 .45721 L
s
.47638 .45991 m
.47536 .46059 L
s
.40793 .46241 m
.40689 .46182 L
s
.47638 .4599 m
.47536 .46058 L
s
.52056 .45655 m
.5201 .45719 L
s
.47648 .45988 m
.47547 .46057 L
s
.47648 .45987 m
.47547 .46056 L
s
.47648 .45987 m
.47547 .46056 L
s
.47649 .45987 m
.47548 .46055 L
s
.28078 .46347 m
.28053 .463 L
s
.4765 .45986 m
.47549 .46054 L
s
.61963 .45897 m
.61945 .4594 L
s
.40789 .46237 m
.40685 .46178 L
s
.52062 .45652 m
.52017 .45715 L
s
.52057 .45651 m
.52011 .45715 L
s
.40792 .46235 m
.40688 .46176 L
s
.61967 .45896 m
.61949 .45939 L
s
.19306 .56084 m
.19284 .56048 L
s
.47651 .45983 m
.4755 .46051 L
s
.40781 .46234 m
.40677 .46175 L
s
.71185 .45048 m
.71175 .45085 L
s
.40784 .46231 m
.4068 .46173 L
s
.47657 .45981 m
.47556 .4605 L
s
.52059 .45646 m
.52014 .4571 L
s
.40776 .46231 m
.40672 .46172 L
s
.40769 .46229 m
.40666 .4617 L
s
.36481 .46544 m
.36426 .46488 L
s
.47663 .45975 m
.47562 .46044 L
s
.52068 .4564 m
.52023 .45704 L
s
.52065 .45639 m
.5202 .45703 L
s
.40761 .46225 m
.40658 .46166 L
s
.36469 .46538 m
.36414 .46482 L
s
.71188 .45038 m
.71178 .45075 L
s
.47663 .45971 m
.47562 .4604 L
s
.28066 .46332 m
.28042 .46286 L
s
.85358 .30212 m
.85366 .30237 L
s
.47674 .45968 m
.47574 .46038 L
s
.47673 .45968 m
.47573 .46037 L
s
.47674 .45968 m
.47573 .46037 L
s
.36474 .46535 m
.36418 .46479 L
s
.40759 .4622 m
.40656 .46161 L
s
.17179 .47073 m
.17163 .47038 L
s
.52073 .45632 m
.52028 .45696 L
s
.61984 .45877 m
.61965 .4592 L
s
.47673 .45965 m
.47573 .46034 L
s
.61972 .45876 m
.61954 .4592 L
s
.40749 .46217 m
.40646 .46158 L
s
.47682 .45964 m
.47582 .46033 L
s
.47684 .45962 m
.47584 .46031 L
s
.47685 .4596 m
.47585 .4603 L
s
.40741 .46213 m
.40639 .46153 L
s
.36466 .46528 m
.36411 .46473 L
s
.47685 .45958 m
.47585 .46028 L
s
.17172 .47065 m
.17156 .4703 L
s
.40732 .4621 m
.4063 .4615 L
s
.52083 .45622 m
.52038 .45685 L
s
.47688 .45955 m
.47588 .46024 L
s
.40725 .46209 m
.40623 .46149 L
s
.47695 .45952 m
.47595 .46022 L
s
.4072 .46207 m
.40618 .46147 L
s
.52079 .45617 m
.52034 .45681 L
s
.28071 .46313 m
.28046 .46266 L
s
.40724 .46204 m
.40622 .46144 L
s
.36458 .46518 m
.36403 .46462 L
s
.36466 .46519 m
.36411 .46463 L
s
.40712 .46203 m
.40611 .46143 L
s
.40724 .46198 m
.40622 .46138 L
s
.71195 .45012 m
.71185 .45048 L
s
.47704 .45942 m
.47605 .46012 L
s
.19284 .56048 m
.19262 .56013 L
s
.85351 .30186 m
.85358 .30212 L
s
.36445 .46511 m
.3639 .46455 L
s
.47716 .4594 m
.47617 .4601 L
s
.61981 .45853 m
.61963 .45897 L
s
.40716 .46195 m
.40614 .46135 L
s
.47719 .45939 m
.4762 .46009 L
s
.40711 .46196 m
.4061 .46135 L
s
.61985 .45852 m
.61967 .45896 L
s
.4772 .45937 m
.47621 .46007 L
s
.28053 .463 m
.28029 .46254 L
s
.40704 .46193 m
.40602 .46133 L
s
.40709 .4619 m
.40607 .4613 L
s
.36453 .46506 m
.36398 .4645 L
s
.3646 .46506 m
.36405 .4645 L
s
.40699 .4619 m
.40598 .4613 L
s
.40698 .46188 m
.40597 .46127 L
s
.40693 .46188 m
.40592 .46128 L
s
.71198 .45002 m
.71188 .45038 L
s
.47729 .4593 m
.4763 .46 L
s
.36436 .465 m
.36382 .46444 L
s
.17163 .47038 m
.17147 .47003 L
s
.40686 .46184 m
.40585 .46124 L
s
.52097 .45594 m
.52053 .45658 L
s
.40689 .46182 m
.40589 .46121 L
s
.521 .45591 m
.52056 .45655 L
s
.47736 .4592 m
.47638 .45991 L
s
.28042 .46286 m
.28018 .46239 L
s
.40685 .46178 m
.40585 .46117 L
s
.52106 .45588 m
.52062 .45652 L
s
.52101 .45587 m
.52057 .45651 L
s
.47736 .45919 m
.47638 .4599 L
s
.40688 .46176 m
.40588 .46116 L
s
.62001 .45833 m
.61984 .45877 L
s
.47746 .45918 m
.47648 .45988 L
s
.17156 .4703 m
.1714 .46996 L
s
.6199 .45832 m
.61972 .45876 L
s
.47746 .45916 m
.47648 .45987 L
s
.40677 .46175 m
.40577 .46114 L
s
.47746 .45916 m
.47648 .45987 L
s
.47746 .45916 m
.47649 .45987 L
s
.47748 .45915 m
.4765 .45986 L
s
.4068 .46173 m
.40579 .46112 L
s
.36426 .46488 m
.36372 .46432 L
s
.52103 .45582 m
.52059 .45646 L
s
.85344 .30161 m
.85351 .30186 L
s
.40672 .46172 m
.40572 .46111 L
s
.47749 .45912 m
.47651 .45983 L
s
.40666 .4617 m
.40566 .46109 L
s
.47754 .4591 m
.47657 .45981 L
s
.52112 .45576 m
.52068 .4564 L
s
.36414 .46482 m
.3636 .46426 L
s
.52109 .45575 m
.52065 .45639 L
s
.40658 .46166 m
.40558 .46105 L
s
.4776 .45904 m
.47663 .45975 L
s
.36418 .46479 m
.36364 .46423 L
s
.71204 .44976 m
.71195 .45012 L
s
.40656 .46161 m
.40556 .461 L
s
.28046 .46266 m
.28022 .46219 L
s
.52117 .45568 m
.52073 .45632 L
s
.4776 .459 m
.47663 .45971 L
s
.19262 .56013 m
.1924 .55978 L
s
.40646 .46158 m
.40547 .46096 L
s
.47771 .45897 m
.47674 .45968 L
s
.4777 .45896 m
.47673 .45968 L
s
.4777 .45897 m
.47674 .45968 L
s
.36411 .46473 m
.36357 .46416 L
s
.4777 .45893 m
.47673 .45965 L
s
.61999 .45809 m
.61981 .45853 L
s
.40639 .46153 m
.4054 .46092 L
s
.47778 .45892 m
.47682 .45964 L
s
.62003 .45808 m
.61985 .45852 L
s
.71208 .44965 m
.71198 .45002 L
s
.47781 .45891 m
.47684 .45962 L
s
.52126 .45557 m
.52083 .45622 L
s
.47781 .45889 m
.47685 .4596 L
s
.4063 .4615 m
.40531 .46089 L
s
.17147 .47003 m
.17132 .46968 L
s
.47781 .45887 m
.47685 .45958 L
s
.40623 .46149 m
.40524 .46088 L
s
.28029 .46254 m
.28005 .46207 L
s
.85337 .30136 m
.85344 .30161 L
s
.52122 .45553 m
.52079 .45617 L
s
.40618 .46147 m
.40519 .46086 L
s
.36403 .46462 m
.3635 .46406 L
s
.36411 .46463 m
.36357 .46407 L
s
.47784 .45883 m
.47688 .45955 L
s
.40622 .46144 m
.40524 .46083 L
s
.47791 .4588 m
.47695 .45952 L
s
.40611 .46143 m
.40512 .46081 L
s
.1714 .46996 m
.17125 .46961 L
s
.3639 .46455 m
.36336 .46399 L
s
.40622 .46138 m
.40524 .46077 L
s
.62019 .45789 m
.62001 .45833 L
s
.40614 .46135 m
.40516 .46073 L
s
.4061 .46135 m
.40512 .46074 L
s
.62007 .45788 m
.6199 .45832 L
s
.36398 .4645 m
.36344 .46394 L
s
.478 .4587 m
.47704 .45942 L
s
.28018 .46239 m
.27994 .46192 L
s
.36405 .4645 m
.36351 .46393 L
s
.40602 .46133 m
.40504 .46071 L
s
.47812 .45868 m
.47716 .4594 L
s
.47814 .45867 m
.47719 .45939 L
s
.40607 .4613 m
.40509 .46068 L
s
.36382 .46444 m
.36328 .46388 L
s
.40598 .4613 m
.405 .46068 L
s
.47815 .45865 m
.4772 .45937 L
s
.40597 .46127 m
.40499 .46065 L
s
.40592 .46128 m
.40494 .46066 L
s
.71214 .44939 m
.71204 .44976 L
s
.5214 .4553 m
.52097 .45594 L
s
.85329 .3011 m
.85337 .30136 L
s
.40585 .46124 m
.40487 .46061 L
s
.47824 .45857 m
.47729 .4593 L
s
.52143 .45527 m
.521 .45591 L
s
.40589 .46121 m
.40491 .46059 L
s
.1924 .55978 m
.19218 .55942 L
s
.52149 .45523 m
.52106 .45588 L
s
.52143 .45523 m
.52101 .45587 L
s
.40585 .46117 m
.40487 .46055 L
s
.71217 .44929 m
.71208 .44965 L
s
.40588 .46116 m
.4049 .46053 L
s
.36372 .46432 m
.36319 .46376 L
s
.28022 .46219 m
.27999 .46173 L
s
.40577 .46114 m
.40479 .46052 L
s
.17132 .46968 m
.17116 .46933 L
s
.47831 .45848 m
.47736 .4592 L
s
.52146 .45518 m
.52103 .45582 L
s
.40579 .46112 m
.40482 .46049 L
s
.62016 .45765 m
.61999 .45809 L
s
.4783 .45847 m
.47736 .45919 L
s
.47841 .45845 m
.47746 .45918 L
s
.6202 .45764 m
.62003 .45808 L
s
.40572 .46111 m
.40475 .46048 L
s
.3636 .46426 m
.36307 .46369 L
s
.4784 .45844 m
.47746 .45916 L
s
.4784 .45843 m
.47746 .45916 L
s
.40566 .46109 m
.40469 .46047 L
s
.4784 .45843 m
.47746 .45916 L
s
.47842 .45842 m
.47748 .45915 L
s
.52154 .45512 m
.52112 .45576 L
s
.52152 .45511 m
.52109 .45575 L
s
.36364 .46423 m
.36311 .46366 L
s
.17125 .46961 m
.17109 .46926 L
s
.47843 .45839 m
.47749 .45912 L
s
.40558 .46105 m
.40461 .46043 L
s
.47848 .45837 m
.47754 .4591 L
s
.28005 .46207 m
.27982 .4616 L
s
.52159 .45503 m
.52117 .45568 L
s
.40556 .461 m
.4046 .46037 L
s
.36357 .46416 m
.36304 .46359 L
s
.85322 .30085 m
.85329 .3011 L
s
.47854 .45831 m
.4776 .45904 L
s
.40547 .46096 m
.4045 .46033 L
s
.47853 .45826 m
.4776 .459 L
s
.62036 .45745 m
.62019 .45789 L
s
.62024 .45744 m
.62007 .45788 L
s
.4054 .46092 m
.40443 .46029 L
s
.47863 .45824 m
.47771 .45897 L
s
.71224 .44903 m
.71214 .44939 L
s
.47863 .45823 m
.4777 .45896 L
s
.47863 .45823 m
.4777 .45897 L
s
.52168 .45493 m
.52126 .45557 L
s
.3635 .46406 m
.36297 .46349 L
s
.36357 .46407 m
.36305 .4635 L
s
.40531 .46089 m
.40435 .46026 L
s
.27994 .46192 m
.27971 .46145 L
s
.47863 .4582 m
.4777 .45893 L
s
.52164 .45489 m
.52122 .45553 L
s
.47871 .45818 m
.47778 .45892 L
s
.40524 .46088 m
.40428 .46024 L
s
.47873 .45817 m
.47781 .45891 L
s
.40519 .46086 m
.40424 .46022 L
s
.47874 .45815 m
.47781 .45889 L
s
.40524 .46083 m
.40428 .46019 L
s
.36336 .46399 m
.36284 .46342 L
s
.47873 .45813 m
.47781 .45887 L
s
.19218 .55942 m
.19197 .55907 L
s
.71227 .44892 m
.71217 .44929 L
s
.40512 .46081 m
.40417 .46017 L
s
.17116 .46933 m
.17101 .46898 L
s
.40524 .46077 m
.40428 .46013 L
s
.36344 .46394 m
.36292 .46337 L
s
.47883 .45806 m
.47791 .4588 L
s
.36351 .46393 m
.36299 .46336 L
s
.85314 .3006 m
.85322 .30085 L
s
.40516 .46073 m
.4042 .46009 L
s
.40512 .46074 m
.40416 .4601 L
s
.36328 .46388 m
.36276 .46331 L
s
.17109 .46926 m
.17094 .46891 L
s
.62033 .45721 m
.62016 .45765 L
s
.27999 .46173 m
.27976 .46126 L
s
.40504 .46071 m
.40409 .46007 L
s
.62037 .4572 m
.6202 .45764 L
s
.40509 .46068 m
.40414 .46005 L
s
.405 .46068 m
.40405 .46004 L
s
.47892 .45796 m
.478 .4587 L
s
.40499 .46065 m
.40405 .46002 L
s
.40494 .46066 m
.404 .46002 L
s
.47903 .45794 m
.47812 .45868 L
s
.52181 .45465 m
.5214 .4553 L
s
.47905 .45793 m
.47814 .45867 L
s
.52184 .45462 m
.52143 .45527 L
s
.47906 .45791 m
.47815 .45865 L
s
.40487 .46061 m
.40393 .45997 L
s
.40491 .46059 m
.40397 .45995 L
s
.52191 .45459 m
.52149 .45523 L
s
.36319 .46376 m
.36267 .46319 L
s
.52184 .45458 m
.52143 .45523 L
s
.27982 .4616 m
.27959 .46113 L
s
.71233 .44866 m
.71224 .44903 L
s
.47915 .45783 m
.47824 .45857 L
s
.40487 .46055 m
.40393 .45991 L
s
.4049 .46053 m
.40396 .45989 L
s
.52187 .45453 m
.52146 .45518 L
s
.36307 .46369 m
.36256 .46312 L
s
.62053 .45701 m
.62036 .45745 L
s
.40479 .46052 m
.40385 .45988 L
s
.62041 .457 m
.62024 .45744 L
s
.40482 .46049 m
.40388 .45985 L
s
.36311 .46366 m
.3626 .46309 L
s
.85307 .30035 m
.85314 .3006 L
s
.40475 .46048 m
.40381 .45984 L
s
.52195 .45447 m
.52154 .45512 L
s
.52193 .45446 m
.52152 .45511 L
s
.40469 .46047 m
.40375 .45983 L
s
.47921 .45774 m
.47831 .45848 L
s
.71236 .44856 m
.71227 .44892 L
s
.47921 .45772 m
.4783 .45847 L
s
.47931 .45771 m
.47841 .45845 L
s
.17101 .46898 m
.17086 .46863 L
s
.19197 .55907 m
.19175 .55871 L
s
.27971 .46145 m
.27948 .46098 L
s
.4793 .45769 m
.4784 .45844 L
s
.40461 .46043 m
.40368 .45978 L
s
.4793 .45769 m
.4784 .45843 L
s
.47932 .45768 m
.47842 .45842 L
s
.36304 .46359 m
.36253 .46302 L
s
.4793 .45768 m
.4784 .45843 L
s
.522 .45439 m
.52159 .45503 L
s
.47933 .45764 m
.47843 .45839 L
s
.4046 .46037 m
.40367 .45972 L
s
.17094 .46891 m
.17079 .46856 L
s
.47938 .45762 m
.47848 .45837 L
s
.4045 .46033 m
.40357 .45969 L
s
.36297 .46349 m
.36246 .46292 L
s
.36305 .4635 m
.36253 .46293 L
s
.52208 .45428 m
.52168 .45493 L
s
.47944 .45756 m
.47854 .45831 L
s
.40443 .46029 m
.40351 .45964 L
s
.62049 .45677 m
.62033 .45721 L
s
.62054 .45676 m
.62037 .4572 L
s
.52204 .45424 m
.52164 .45489 L
s
.47943 .45751 m
.47853 .45826 L
s
.40435 .46026 m
.40343 .45961 L
s
.27976 .46126 m
.27953 .46079 L
s
.36284 .46342 m
.36233 .46285 L
s
.85299 .30009 m
.85307 .30035 L
s
.40428 .46024 m
.40336 .4596 L
s
.47952 .45749 m
.47863 .45824 L
s
.47952 .45748 m
.47863 .45823 L
s
.47953 .45748 m
.47863 .45823 L
s
.40424 .46022 m
.40331 .45957 L
s
.47953 .45745 m
.47863 .4582 L
s
.71242 .4483 m
.71233 .44866 L
s
.40428 .46019 m
.40336 .45954 L
s
.36292 .46337 m
.36241 .46279 L
s
.47959 .45743 m
.47871 .45818 L
s
.47962 .45742 m
.47873 .45817 L
s
.36299 .46336 m
.36248 .46279 L
s
.40417 .46017 m
.40325 .45952 L
s
.47963 .4574 m
.47874 .45815 L
s
.36276 .46331 m
.36225 .46274 L
s
.47962 .45738 m
.47873 .45813 L
s
.40428 .46013 m
.40336 .45948 L
s
.27959 .46113 m
.27936 .46066 L
s
.62069 .45657 m
.62053 .45701 L
s
.4042 .46009 m
.40328 .45944 L
s
.71245 .44819 m
.71236 .44856 L
s
.40416 .4601 m
.40324 .45945 L
s
.62057 .45656 m
.62041 .457 L
s
.17086 .46863 m
.17071 .46828 L
s
.47971 .45731 m
.47883 .45806 L
s
.40409 .46007 m
.40317 .45942 L
s
.40414 .46005 m
.40322 .45939 L
s
.19175 .55871 m
.19154 .55836 L
s
.52221 .454 m
.52181 .45465 L
s
.40405 .46004 m
.40313 .45939 L
s
.40405 .46002 m
.40313 .45936 L
s
.52224 .45397 m
.52184 .45462 L
s
.404 .46002 m
.40308 .45937 L
s
.36267 .46319 m
.36216 .46261 L
s
.17079 .46856 m
.17064 .46821 L
s
.85292 .29984 m
.85299 .30009 L
s
.52231 .45394 m
.52191 .45459 L
s
.27948 .46098 m
.27926 .46051 L
s
.4798 .4572 m
.47892 .45796 L
s
.52224 .45393 m
.52184 .45458 L
s
.40393 .45997 m
.40302 .45932 L
s
.47991 .45718 m
.47903 .45794 L
s
.40397 .45995 m
.40305 .4593 L
s
.36256 .46312 m
.36205 .46255 L
s
.47993 .45717 m
.47905 .45793 L
s
.47993 .45715 m
.47906 .45791 L
s
.52226 .45388 m
.52187 .45453 L
s
.3626 .46309 m
.36209 .46251 L
s
.40393 .45991 m
.40302 .45925 L
s
.40396 .45989 m
.40305 .45924 L
s
.52234 .45382 m
.52195 .45447 L
s
.40385 .45988 m
.40294 .45922 L
s
.52232 .45381 m
.52193 .45446 L
s
.62066 .45633 m
.62049 .45677 L
s
.48002 .45707 m
.47915 .45783 L
s
.40388 .45985 m
.40297 .45919 L
s
.6207 .45632 m
.62054 .45676 L
s
.40381 .45984 m
.4029 .45918 L
s
.71251 .44793 m
.71242 .4483 L
s
.36253 .46302 m
.36203 .46245 L
s
.40375 .45983 m
.40285 .45917 L
s
.27953 .46079 m
.27931 .46032 L
s
.52239 .45374 m
.522 .45439 L
s
.40368 .45978 m
.40278 .45912 L
s
.48008 .45697 m
.47921 .45774 L
s
.48007 .45696 m
.47921 .45772 L
s
.85284 .29959 m
.85292 .29984 L
s
.48017 .45694 m
.47931 .45771 L
s
.71254 .44783 m
.71245 .44819 L
s
.36246 .46292 m
.36196 .46234 L
s
.36253 .46293 m
.36203 .46235 L
s
.17071 .46828 m
.17056 .46793 L
s
.48017 .45693 m
.4793 .45769 L
s
.48017 .45693 m
.4793 .45769 L
s
.40367 .45972 m
.40277 .45906 L
s
.48019 .45691 m
.47932 .45768 L
s
.48016 .45692 m
.4793 .45768 L
s
.52247 .45363 m
.52208 .45428 L
s
.40357 .45969 m
.40267 .45902 L
s
.48018 .45688 m
.47933 .45764 L
s
.62086 .45613 m
.62069 .45657 L
s
.27936 .46066 m
.27914 .46019 L
s
.36233 .46285 m
.36184 .46227 L
s
.62074 .45612 m
.62057 .45656 L
s
.52243 .45359 m
.52204 .45424 L
s
.19154 .55836 m
.19133 .558 L
s
.48024 .45685 m
.47938 .45762 L
s
.17064 .46821 m
.17049 .46786 L
s
.40351 .45964 m
.40261 .45898 L
s
.40343 .45961 m
.40253 .45894 L
s
.48029 .45679 m
.47944 .45756 L
s
.36241 .46279 m
.36191 .46222 L
s
.36248 .46279 m
.36198 .46221 L
s
.40336 .4596 m
.40247 .45893 L
s
.36225 .46274 m
.36176 .46216 L
s
.40331 .45957 m
.40242 .45891 L
s
.48028 .45674 m
.47943 .45751 L
s
.40336 .45954 m
.40247 .45888 L
s
.48037 .45672 m
.47952 .45749 L
s
.48037 .45671 m
.47952 .45748 L
s
.48038 .45671 m
.47953 .45748 L
s
.27926 .46051 m
.27903 .46004 L
s
.40325 .45952 m
.40236 .45885 L
s
.48038 .45668 m
.47953 .45745 L
s
.85276 .29934 m
.85284 .29959 L
s
.40336 .45948 m
.40248 .45881 L
s
.48044 .45666 m
.47959 .45743 L
s
.7126 .44756 m
.71251 .44793 L
s
.48047 .45665 m
.47962 .45742 L
s
.48047 .45663 m
.47963 .4574 L
s
.62082 .45589 m
.62066 .45633 L
s
.40328 .45944 m
.4024 .45877 L
s
.40324 .45945 m
.40236 .45878 L
s
.48046 .45661 m
.47962 .45738 L
s
.62086 .45588 m
.6207 .45632 L
s
.5226 .45335 m
.52221 .454 L
s
.36216 .46261 m
.36167 .46203 L
s
.52263 .45332 m
.52224 .45397 L
s
.40317 .45942 m
.40228 .45875 L
s
.40322 .45939 m
.40234 .45873 L
s
.40313 .45939 m
.40225 .45872 L
s
.17056 .46793 m
.17041 .46758 L
s
.71263 .44746 m
.71254 .44783 L
s
.52269 .45329 m
.52231 .45394 L
s
.48056 .45653 m
.47971 .45731 L
s
.52262 .45328 m
.52224 .45393 L
s
.36205 .46255 m
.36156 .46197 L
s
.40313 .45936 m
.40225 .45869 L
s
.40308 .45937 m
.40221 .4587 L
s
.27931 .46032 m
.27908 .45985 L
s
.36209 .46251 m
.3616 .46194 L
s
.52265 .45323 m
.52226 .45388 L
s
.40302 .45932 m
.40214 .45865 L
s
.40305 .4593 m
.40218 .45863 L
s
.17049 .46786 m
.17034 .46751 L
s
.19133 .558 m
.19111 .55764 L
s
.48063 .45643 m
.4798 .4572 L
s
.52272 .45317 m
.52234 .45382 L
s
.5227 .45316 m
.52232 .45381 L
s
.62102 .45569 m
.62086 .45613 L
s
.48074 .4564 m
.47991 .45718 L
s
.36203 .46245 m
.36154 .46187 L
s
.85268 .29909 m
.85276 .29934 L
s
.40302 .45925 m
.40214 .45858 L
s
.62089 .45568 m
.62074 .45612 L
s
.40305 .45924 m
.40218 .45856 L
s
.48076 .45639 m
.47993 .45717 L
s
.48076 .45637 m
.47993 .45715 L
s
.27914 .46019 m
.27892 .45972 L
s
.40294 .45922 m
.40207 .45854 L
s
.40297 .45919 m
.4021 .45852 L
s
.52277 .45308 m
.52239 .45374 L
s
.4029 .45918 m
.40203 .45851 L
s
.40285 .45917 m
.40198 .45849 L
s
.36196 .46234 m
.36147 .46176 L
s
.36203 .46235 m
.36154 .46177 L
s
.48084 .45629 m
.48002 .45707 L
s
.71269 .4472 m
.7126 .44756 L
s
.40278 .45912 m
.40191 .45844 L
s
.52285 .45298 m
.52247 .45363 L
s
.36184 .46227 m
.36135 .46169 L
s
.27903 .46004 m
.27882 .45957 L
s
.40277 .45906 m
.4019 .45838 L
s
.48091 .45619 m
.48008 .45697 L
s
.52281 .45294 m
.52243 .45359 L
s
.4809 .45618 m
.48007 .45696 L
s
.481 .45616 m
.48017 .45694 L
s
.62097 .45544 m
.62082 .45589 L
s
.17041 .46758 m
.17026 .46723 L
s
.40267 .45902 m
.40181 .45834 L
s
.36191 .46222 m
.36142 .46164 L
s
.71272 .4471 m
.71263 .44746 L
s
.48099 .45615 m
.48017 .45693 L
s
.62102 .45544 m
.62086 .45588 L
s
.36198 .46221 m
.36149 .46163 L
s
.48099 .45614 m
.48017 .45693 L
s
.48101 .45613 m
.48019 .45691 L
s
.48098 .45614 m
.48016 .45692 L
s
.85261 .29883 m
.85268 .29909 L
s
.36176 .46216 m
.36128 .46158 L
s
.40261 .45898 m
.40175 .4583 L
s
.481 .45609 m
.48018 .45688 L
s
.17034 .46751 m
.17019 .46715 L
s
.40253 .45894 m
.40168 .45826 L
s
.48105 .45607 m
.48024 .45685 L
s
.40247 .45893 m
.40161 .45825 L
s
.40242 .45891 m
.40157 .45823 L
s
.27908 .45985 m
.27887 .45937 L
s
.48111 .45601 m
.48029 .45679 L
s
.19111 .55764 m
.1909 .55728 L
s
.40247 .45888 m
.40161 .4582 L
s
.40236 .45885 m
.40151 .45817 L
s
.48109 .45596 m
.48028 .45674 L
s
.36167 .46203 m
.36119 .46145 L
s
.62117 .45525 m
.62102 .45569 L
s
.62105 .45524 m
.62089 .45568 L
s
.52297 .4527 m
.5226 .45335 L
s
.40248 .45881 m
.40162 .45813 L
s
.48118 .45593 m
.48037 .45672 L
s
.48118 .45593 m
.48037 .45671 L
s
.48119 .45592 m
.48038 .45671 L
s
.523 .45267 m
.52263 .45332 L
s
.36156 .46197 m
.36109 .46139 L
s
.48119 .45589 m
.48038 .45668 L
s
.4024 .45877 m
.40155 .45809 L
s
.40236 .45878 m
.40151 .45809 L
s
.27892 .45972 m
.2787 .45925 L
s
.52306 .45263 m
.52269 .45329 L
s
.48124 .45587 m
.48044 .45666 L
s
.71278 .44683 m
.71269 .4472 L
s
.52299 .45263 m
.52262 .45328 L
s
.48128 .45586 m
.48047 .45665 L
s
.85253 .29858 m
.85261 .29883 L
s
.3616 .46194 m
.36113 .46136 L
s
.40228 .45875 m
.40143 .45806 L
s
.48128 .45584 m
.48047 .45663 L
s
.40234 .45873 m
.40149 .45804 L
s
.48127 .45582 m
.48046 .45661 L
s
.40225 .45872 m
.4014 .45803 L
s
.52302 .45258 m
.52265 .45323 L
s
.40225 .45869 m
.40141 .45801 L
s
.40221 .4587 m
.40136 .45801 L
s
.17026 .46723 m
.17012 .46688 L
s
.36154 .46187 m
.36106 .46129 L
s
.71281 .44673 m
.71272 .4471 L
s
.52309 .45252 m
.52272 .45317 L
s
.52307 .45251 m
.5227 .45316 L
s
.48136 .45574 m
.48056 .45653 L
s
.40214 .45865 m
.4013 .45796 L
s
.40218 .45863 m
.40133 .45794 L
s
.27882 .45957 m
.2786 .4591 L
s
.62113 .455 m
.62097 .45544 L
s
.17019 .46715 m
.17005 .4668 L
s
.62117 .455 m
.62102 .45544 L
s
.40214 .45858 m
.4013 .45789 L
s
.52314 .45243 m
.52277 .45308 L
s
.40218 .45856 m
.40134 .45788 L
s
.36147 .46176 m
.361 .46118 L
s
.36154 .46177 m
.36107 .46119 L
s
.48143 .45564 m
.48063 .45643 L
s
.40207 .45854 m
.40123 .45785 L
s
.48154 .45561 m
.48074 .4564 L
s
.4021 .45852 m
.40126 .45783 L
s
.48155 .4556 m
.48076 .45639 L
s
.40203 .45851 m
.40119 .45782 L
s
.85245 .29833 m
.85253 .29858 L
s
.1909 .55728 m
.19069 .55693 L
s
.36135 .46169 m
.36088 .46111 L
s
.48155 .45558 m
.48076 .45637 L
s
.40198 .45849 m
.40114 .4578 L
s
.52321 .45232 m
.52285 .45298 L
s
.40191 .45844 m
.40108 .45775 L
s
.52317 .45228 m
.52281 .45294 L
s
.27887 .45937 m
.27865 .4589 L
s
.36142 .46164 m
.36095 .46105 L
s
.36149 .46163 m
.36102 .46105 L
s
.48163 .45549 m
.48084 .45629 L
s
.62132 .45481 m
.62117 .45525 L
s
.71286 .44647 m
.71278 .44683 L
s
.6212 .45479 m
.62105 .45524 L
s
.36128 .46158 m
.36081 .461 L
s
.4019 .45838 m
.40107 .45769 L
s
.40181 .45834 m
.40098 .45765 L
s
.48169 .4554 m
.48091 .45619 L
s
.17012 .46688 m
.16997 .46652 L
s
.2787 .45925 m
.27849 .45878 L
s
.48168 .45538 m
.4809 .45618 L
s
.40175 .4583 m
.40092 .45761 L
s
.48178 .45536 m
.481 .45616 L
s
.71289 .44636 m
.71281 .44673 L
s
.48177 .45535 m
.48099 .45615 L
s
.48177 .45535 m
.48099 .45614 L
s
.48179 .45533 m
.48101 .45613 L
s
.48176 .45534 m
.48098 .45614 L
s
.40168 .45826 m
.40085 .45757 L
s
.85237 .29808 m
.85245 .29833 L
s
.36119 .46145 m
.36072 .46087 L
s
.40161 .45825 m
.40079 .45755 L
s
.17005 .4668 m
.1699 .46645 L
s
.48178 .4553 m
.481 .45609 L
s
.40157 .45823 m
.40075 .45753 L
s
.52333 .45204 m
.52297 .4527 L
s
.48183 .45526 m
.48105 .45607 L
s
.40161 .4582 m
.40079 .4575 L
s
.36109 .46139 m
.36062 .4608 L
s
.52335 .45201 m
.523 .45267 L
s
.62128 .45456 m
.62113 .455 L
s
.62132 .45455 m
.62117 .455 L
s
.40151 .45817 m
.40069 .45747 L
s
.2786 .4591 m
.27839 .45863 L
s
.36113 .46136 m
.36066 .46077 L
s
.48188 .4552 m
.48111 .45601 L
s
.52342 .45197 m
.52306 .45263 L
s
.52334 .45197 m
.52299 .45263 L
s
.40162 .45813 m
.4008 .45743 L
s
.19069 .55693 m
.19049 .55657 L
s
.48186 .45516 m
.48109 .45596 L
s
.40155 .45809 m
.40073 .45739 L
s
.52337 .45192 m
.52302 .45258 L
s
.40151 .45809 m
.40069 .45739 L
s
.36106 .46129 m
.36059 .4607 L
s
.48194 .45513 m
.48118 .45593 L
s
.48195 .45512 m
.48118 .45593 L
s
.48195 .45512 m
.48119 .45592 L
s
.40143 .45806 m
.40062 .45736 L
s
.40149 .45804 m
.40067 .45734 L
s
.48196 .45509 m
.48119 .45589 L
s
.52344 .45186 m
.52309 .45252 L
s
.71295 .4461 m
.71286 .44647 L
s
.52342 .45185 m
.52307 .45251 L
s
.4014 .45803 m
.40059 .45733 L
s
.48201 .45507 m
.48124 .45587 L
s
.48205 .45506 m
.48128 .45586 L
s
.40141 .45801 m
.40059 .45731 L
s
.40136 .45801 m
.40055 .45731 L
s
.85229 .29783 m
.85237 .29808 L
s
.48204 .45504 m
.48128 .45584 L
s
.62147 .45436 m
.62132 .45481 L
s
.27865 .4589 m
.27844 .45843 L
s
.62135 .45435 m
.6212 .45479 L
s
.361 .46118 m
.36054 .46059 L
s
.48203 .45501 m
.48127 .45582 L
s
.36107 .46119 m
.3606 .4606 L
s
.16997 .46652 m
.16983 .46617 L
s
.52349 .45177 m
.52314 .45243 L
s
.4013 .45796 m
.40049 .45726 L
s
.40133 .45794 m
.40053 .45724 L
s
.71297 .446 m
.71289 .44636 L
s
.36088 .46111 m
.36042 .46052 L
s
.48211 .45493 m
.48136 .45574 L
s
.4013 .45789 m
.4005 .45719 L
s
.40134 .45788 m
.40053 .45717 L
s
.1699 .46645 m
.16976 .4661 L
s
.52355 .45167 m
.52321 .45232 L
s
.27849 .45878 m
.27828 .4583 L
s
.40123 .45785 m
.40042 .45715 L
s
.36095 .46105 m
.36049 .46047 L
s
.40126 .45783 m
.40046 .45713 L
s
.36102 .46105 m
.36056 .46046 L
s
.40119 .45782 m
.40039 .45712 L
s
.52352 .45162 m
.52317 .45228 L
s
.40114 .4578 m
.40034 .4571 L
s
.48218 .45483 m
.48143 .45564 L
s
.36081 .461 m
.36035 .46041 L
s
.48229 .4548 m
.48154 .45561 L
s
.4823 .45479 m
.48155 .4556 L
s
.8522 .29758 m
.85229 .29783 L
s
.62143 .45412 m
.62128 .45456 L
s
.40108 .45775 m
.40028 .45704 L
s
.4823 .45477 m
.48155 .45558 L
s
.62147 .45411 m
.62132 .45455 L
s
.19049 .55657 m
.19028 .55621 L
s
.27839 .45863 m
.27818 .45815 L
s
.40107 .45769 m
.40028 .45698 L
s
.71303 .44573 m
.71295 .4461 L
s
.48238 .45468 m
.48163 .45549 L
s
.36072 .46087 m
.36027 .46028 L
s
.40098 .45765 m
.40019 .45694 L
s
.40092 .45761 m
.40013 .4569 L
s
.16983 .46617 m
.16969 .46582 L
s
.36062 .4608 m
.36017 .46021 L
s
.52367 .45138 m
.52333 .45204 L
s
.48243 .45458 m
.48169 .4554 L
s
.71306 .44563 m
.71297 .446 L
s
.40085 .45757 m
.40006 .45686 L
s
.62162 .45392 m
.62147 .45436 L
s
.36066 .46077 m
.36021 .46018 L
s
.5237 .45135 m
.52335 .45201 L
s
.48242 .45457 m
.48168 .45538 L
s
.6215 .45391 m
.62135 .45435 L
s
.48252 .45455 m
.48178 .45536 L
s
.40079 .45755 m
.4 .45684 L
s
.52376 .45132 m
.52342 .45197 L
s
.48251 .45453 m
.48177 .45535 L
s
.4825 .45453 m
.48177 .45535 L
s
.16976 .4661 m
.16962 .46575 L
s
.40075 .45753 m
.39997 .45682 L
s
.52368 .45131 m
.52334 .45197 L
s
.48252 .45452 m
.48179 .45533 L
s
.27844 .45843 m
.27824 .45796 L
s
.48249 .45452 m
.48176 .45534 L
s
.85212 .29733 m
.8522 .29758 L
s
.40079 .4575 m
.40001 .45679 L
s
.48251 .45448 m
.48178 .4553 L
s
.36059 .4607 m
.36014 .46011 L
s
.52371 .45126 m
.52337 .45192 L
s
.40069 .45747 m
.39991 .45676 L
s
.48256 .45445 m
.48183 .45526 L
s
.4008 .45743 m
.40002 .45672 L
s
.52377 .4512 m
.52344 .45186 L
s
.52376 .45119 m
.52342 .45185 L
s
.40073 .45739 m
.39995 .45668 L
s
.48261 .45439 m
.48188 .4552 L
s
.27828 .4583 m
.27808 .45783 L
s
.40069 .45739 m
.39991 .45668 L
s
.36054 .46059 m
.36009 .46 L
s
.3606 .4606 m
.36015 .46001 L
s
.40062 .45736 m
.39984 .45665 L
s
.40067 .45734 m
.3999 .45663 L
s
.48259 .45434 m
.48186 .45516 L
s
.52383 .45111 m
.52349 .45177 L
s
.19028 .55621 m
.19007 .55584 L
s
.40059 .45733 m
.39981 .45662 L
s
.62157 .45367 m
.62143 .45412 L
s
.62162 .45367 m
.62147 .45411 L
s
.48267 .45431 m
.48194 .45513 L
s
.71311 .44537 m
.71303 .44573 L
s
.48267 .45431 m
.48195 .45512 L
s
.40059 .45731 m
.39982 .45659 L
s
.48268 .4543 m
.48195 .45512 L
s
.36042 .46052 m
.35997 .45993 L
s
.40055 .45731 m
.39978 .4566 L
s
.48268 .45427 m
.48196 .45509 L
s
.48273 .45424 m
.48201 .45507 L
s
.48277 .45424 m
.48205 .45506 L
s
.85204 .29708 m
.85212 .29733 L
s
.40049 .45726 m
.39972 .45654 L
s
.16969 .46582 m
.16955 .46547 L
s
.36049 .46047 m
.36004 .45988 L
s
.27818 .45815 m
.27798 .45768 L
s
.40053 .45724 m
.39975 .45652 L
s
.48276 .45422 m
.48204 .45504 L
s
.52388 .45101 m
.52355 .45167 L
s
.36056 .46046 m
.36011 .45987 L
s
.48275 .45419 m
.48203 .45501 L
s
.71314 .44526 m
.71306 .44563 L
s
.36035 .46041 m
.35991 .45982 L
s
.52385 .45096 m
.52352 .45162 L
s
.4005 .45719 m
.39973 .45647 L
s
.40053 .45717 m
.39976 .45646 L
s
.16962 .46575 m
.16948 .46539 L
s
.40042 .45715 m
.39966 .45643 L
s
.48283 .45411 m
.48211 .45493 L
s
.62176 .45348 m
.62162 .45392 L
s
.40046 .45713 m
.39969 .45641 L
s
.62164 .45346 m
.6215 .45391 L
s
.40039 .45712 m
.39963 .4564 L
s
.40034 .4571 m
.39958 .45638 L
s
.36027 .46028 m
.35983 .45969 L
s
.27824 .45796 m
.27803 .45748 L
s
.40028 .45704 m
.39952 .45632 L
s
.48289 .454 m
.48218 .45483 L
s
.48299 .45398 m
.48229 .4548 L
s
.85196 .29682 m
.85204 .29708 L
s
.48301 .45397 m
.4823 .45479 L
s
.36017 .46021 m
.35973 .45962 L
s
.40028 .45698 m
.39952 .45626 L
s
.483 .45394 m
.4823 .45477 L
s
.36021 .46018 m
.35977 .45959 L
s
.524 .45072 m
.52367 .45138 L
s
.71319 .445 m
.71311 .44537 L
s
.40019 .45694 m
.39943 .45622 L
s
.52402 .45069 m
.5237 .45135 L
s
.19007 .55584 m
.18987 .55548 L
s
.27808 .45783 m
.27788 .45736 L
s
.52409 .45065 m
.52376 .45132 L
s
.40013 .4569 m
.39938 .45618 L
s
.62171 .45323 m
.62157 .45367 L
s
.48308 .45385 m
.48238 .45468 L
s
.52401 .45065 m
.52368 .45131 L
s
.62176 .45322 m
.62162 .45367 L
s
.16955 .46547 m
.16941 .46512 L
s
.36014 .46011 m
.3597 .45952 L
s
.40006 .45686 m
.39931 .45614 L
s
.71322 .4449 m
.71314 .44526 L
s
.52403 .4506 m
.52371 .45126 L
s
.4 .45684 m
.39925 .45612 L
s
.39997 .45682 m
.39922 .45609 L
s
.16948 .46539 m
.16934 .46504 L
s
.48313 .45376 m
.48243 .45458 L
s
.5241 .45054 m
.52377 .4512 L
s
.40001 .45679 m
.39926 .45606 L
s
.48311 .45374 m
.48242 .45457 L
s
.27798 .45768 m
.27778 .45721 L
s
.52408 .45053 m
.52376 .45119 L
s
.36009 .46 m
.35965 .45941 L
s
.36015 .46001 m
.35972 .45942 L
s
.48321 .45372 m
.48252 .45455 L
s
.4832 .4537 m
.48251 .45453 L
s
.48319 .4537 m
.4825 .45453 L
s
.39991 .45676 m
.39916 .45603 L
s
.85187 .29657 m
.85196 .29682 L
s
.48322 .45369 m
.48252 .45452 L
s
.48318 .45369 m
.48249 .45452 L
s
.40002 .45672 m
.39928 .456 L
s
.6219 .45303 m
.62176 .45348 L
s
.35997 .45993 m
.35954 .45934 L
s
.52415 .45045 m
.52383 .45111 L
s
.4832 .45365 m
.48251 .45448 L
s
.62178 .45302 m
.62164 .45346 L
s
.39995 .45668 m
.3992 .45595 L
s
.39991 .45668 m
.39917 .45595 L
s
.48325 .45362 m
.48256 .45445 L
s
.36004 .45988 m
.35961 .45928 L
s
.39984 .45665 m
.3991 .45592 L
s
.3999 .45663 m
.39915 .4559 L
s
.36011 .45987 m
.35968 .45927 L
s
.48329 .45355 m
.48261 .45439 L
s
.39981 .45662 m
.39908 .45589 L
s
.5242 .45035 m
.52388 .45101 L
s
.35991 .45982 m
.35948 .45923 L
s
.39982 .45659 m
.39908 .45586 L
s
.27803 .45748 m
.27783 .45701 L
s
.39978 .4566 m
.39904 .45587 L
s
.71327 .44463 m
.71319 .445 L
s
.52417 .4503 m
.52385 .45096 L
s
.48327 .45351 m
.48259 .45434 L
s
.18987 .55548 m
.18966 .55512 L
s
.48334 .45347 m
.48267 .45431 L
s
.48335 .45347 m
.48267 .45431 L
s
.39972 .45654 m
.39899 .45581 L
s
.48336 .45347 m
.48268 .4543 L
s
.16941 .46512 m
.16927 .46476 L
s
.39975 .45652 m
.39902 .45579 L
s
.48336 .45344 m
.48268 .45427 L
s
.85179 .29632 m
.85187 .29657 L
s
.71329 .44453 m
.71322 .4449 L
s
.4834 .45341 m
.48273 .45424 L
s
.48344 .45341 m
.48277 .45424 L
s
.27788 .45736 m
.27768 .45688 L
s
.62185 .45279 m
.62171 .45323 L
s
.39973 .45647 m
.399 .45574 L
s
.39976 .45646 m
.39903 .45573 L
s
.6219 .45278 m
.62176 .45322 L
s
.48344 .45339 m
.48276 .45422 L
s
.35983 .45969 m
.3594 .45909 L
s
.16934 .46504 m
.1692 .46469 L
s
.48342 .45336 m
.48275 .45419 L
s
.39966 .45643 m
.39893 .4557 L
s
.39969 .45641 m
.39896 .45568 L
s
.39963 .4564 m
.3989 .45567 L
s
.35973 .45962 m
.3593 .45903 L
s
.39958 .45638 m
.39886 .45565 L
s
.35977 .45959 m
.35934 .45899 L
s
.4835 .45327 m
.48283 .45411 L
s
.52432 .45006 m
.524 .45072 L
s
.39952 .45632 m
.3988 .45559 L
s
.27778 .45721 m
.27758 .45673 L
s
.52433 .45003 m
.52402 .45069 L
s
.62204 .45259 m
.6219 .45303 L
s
.3597 .45952 m
.35928 .45892 L
s
.5244 .44999 m
.52409 .45065 L
s
.62192 .45258 m
.62178 .45302 L
s
.52432 .44998 m
.52401 .45065 L
s
.39952 .45626 m
.3988 .45553 L
s
.48356 .45317 m
.48289 .454 L
s
.8517 .29607 m
.85179 .29632 L
s
.48366 .45314 m
.48299 .45398 L
s
.71334 .44427 m
.71327 .44463 L
s
.39943 .45622 m
.39871 .45548 L
s
.48367 .45313 m
.48301 .45397 L
s
.52434 .44993 m
.52403 .4506 L
s
.48366 .4531 m
.483 .45394 L
s
.39938 .45618 m
.39866 .45544 L
s
.35965 .45941 m
.35923 .45882 L
s
.35972 .45942 m
.35929 .45882 L
s
.16927 .46476 m
.16913 .46441 L
s
.5244 .44987 m
.5241 .45054 L
s
.52439 .44987 m
.52408 .45053 L
s
.18966 .55512 m
.18946 .55476 L
s
.39931 .45614 m
.3986 .4554 L
s
.27783 .45701 m
.27764 .45653 L
s
.71337 .44416 m
.71329 .44453 L
s
.39925 .45612 m
.39854 .45538 L
s
.48373 .45301 m
.48308 .45385 L
s
.35954 .45934 m
.35912 .45874 L
s
.1692 .46469 m
.16907 .46434 L
s
.39922 .45609 m
.39851 .45536 L
s
.52446 .44978 m
.52415 .45045 L
s
.39926 .45606 m
.39855 .45533 L
s
.62198 .45234 m
.62185 .45279 L
s
.35961 .45928 m
.35919 .45869 L
s
.62203 .45233 m
.6219 .45278 L
s
.35968 .45927 m
.35925 .45868 L
s
.39916 .45603 m
.39845 .45529 L
s
.48378 .45291 m
.48313 .45376 L
s
.27768 .45688 m
.27748 .45641 L
s
.39928 .456 m
.39857 .45526 L
s
.35948 .45923 m
.35906 .45863 L
s
.48377 .45289 m
.48311 .45374 L
s
.85162 .29582 m
.8517 .29607 L
s
.48386 .45288 m
.48321 .45372 L
s
.5245 .44968 m
.5242 .45035 L
s
.48385 .45286 m
.4832 .4537 L
s
.48384 .45286 m
.48319 .4537 L
s
.48386 .45285 m
.48322 .45369 L
s
.48383 .45285 m
.48318 .45369 L
s
.3992 .45595 m
.39849 .45521 L
s
.39917 .45595 m
.39846 .45521 L
s
.52447 .44964 m
.52417 .4503 L
s
.48385 .45281 m
.4832 .45365 L
s
.3991 .45592 m
.3984 .45518 L
s
.39915 .4559 m
.39845 .45516 L
s
.39908 .45589 m
.39837 .45515 L
s
.48389 .45277 m
.48325 .45362 L
s
.39908 .45586 m
.39838 .45512 L
s
.39904 .45587 m
.39834 .45513 L
s
.27758 .45673 m
.27739 .45626 L
s
.71342 .4439 m
.71334 .44427 L
s
.3594 .45909 m
.35898 .4585 L
s
.62217 .45214 m
.62204 .45259 L
s
.62205 .45213 m
.62192 .45258 L
s
.48394 .45271 m
.48329 .45355 L
s
.16913 .46441 m
.169 .46406 L
s
.39899 .45581 m
.39829 .45507 L
s
.39902 .45579 m
.39832 .45505 L
s
.3593 .45903 m
.35889 .45843 L
s
.48391 .45266 m
.48327 .45351 L
s
.35934 .45899 m
.35893 .4584 L
s
.18946 .55476 m
.18926 .55439 L
s
.71345 .4438 m
.71337 .44416 L
s
.48398 .45263 m
.48334 .45347 L
s
.85153 .29557 m
.85162 .29582 L
s
.48399 .45262 m
.48335 .45347 L
s
.48399 .45262 m
.48336 .45347 L
s
.399 .45574 m
.3983 .45499 L
s
.39903 .45573 m
.39834 .45498 L
s
.16907 .46434 m
.16893 .46398 L
s
.484 .45259 m
.48336 .45344 L
s
.52461 .44939 m
.52432 .45006 L
s
.39893 .4557 m
.39823 .45495 L
s
.48408 .45256 m
.48344 .45341 L
s
.48403 .45256 m
.4834 .45341 L
s
.39896 .45568 m
.39826 .45493 L
s
.52463 .44936 m
.52433 .45003 L
s
.35928 .45892 m
.35887 .45832 L
s
.27764 .45653 m
.27745 .45606 L
s
.3989 .45567 m
.39821 .45492 L
s
.48407 .45254 m
.48344 .45339 L
s
.39886 .45565 m
.39817 .4549 L
s
.5247 .44933 m
.5244 .44999 L
s
.48405 .45251 m
.48342 .45336 L
s
.52461 .44932 m
.52432 .44998 L
s
.62212 .4519 m
.62198 .45234 L
s
.62216 .45189 m
.62203 .45233 L
s
.3988 .45559 m
.39811 .45484 L
s
.52464 .44927 m
.52434 .44993 L
s
.35923 .45882 m
.35882 .45822 L
s
.35929 .45882 m
.35888 .45822 L
s
.48412 .45242 m
.4835 .45327 L
s
.27748 .45641 m
.27729 .45593 L
s
.3988 .45553 m
.39812 .45478 L
s
.5247 .44921 m
.5244 .44987 L
s
.52468 .4492 m
.52439 .44987 L
s
.35912 .45874 m
.35871 .45814 L
s
.85145 .29532 m
.85153 .29557 L
s
.71349 .44353 m
.71342 .4439 L
s
.39871 .45548 m
.39803 .45474 L
s
.48418 .45231 m
.48356 .45317 L
s
.169 .46406 m
.16887 .4637 L
s
.52475 .44912 m
.52446 .44978 L
s
.39866 .45544 m
.39798 .45469 L
s
.35919 .45869 m
.35878 .45809 L
s
.48427 .45228 m
.48366 .45314 L
s
.62231 .4517 m
.62217 .45214 L
s
.35925 .45868 m
.35884 .45808 L
s
.48428 .45227 m
.48367 .45313 L
s
.62218 .45169 m
.62205 .45213 L
s
.3986 .4554 m
.39792 .45465 L
s
.27739 .45626 m
.2772 .45578 L
s
.48427 .45225 m
.48366 .4531 L
s
.35906 .45863 m
.35865 .45803 L
s
.71352 .44343 m
.71345 .4438 L
s
.39854 .45538 m
.39787 .45463 L
s
.16893 .46398 m
.1688 .46363 L
s
.18926 .55439 m
.18906 .55403 L
s
.39851 .45536 m
.39784 .45461 L
s
.52479 .44902 m
.5245 .44968 L
s
.39855 .45533 m
.39787 .45458 L
s
.48434 .45216 m
.48373 .45301 L
s
.52476 .44897 m
.52447 .44964 L
s
.39845 .45529 m
.39778 .45454 L
s
.39857 .45526 m
.3979 .45451 L
s
.35898 .4585 m
.35858 .4579 L
s
.85136 .29507 m
.85145 .29532 L
s
.48439 .45206 m
.48378 .45291 L
s
.39849 .45521 m
.39783 .45446 L
s
.39846 .45521 m
.3978 .45446 L
s
.27745 .45606 m
.27726 .45558 L
s
.48437 .45204 m
.48377 .45289 L
s
.35889 .45843 m
.35849 .45783 L
s
.48446 .45202 m
.48386 .45288 L
s
.62224 .45145 m
.62212 .4519 L
s
.62229 .45144 m
.62216 .45189 L
s
.3984 .45518 m
.39773 .45442 L
s
.39845 .45516 m
.39778 .45441 L
s
.48445 .452 m
.48385 .45286 L
s
.48444 .452 m
.48384 .45286 L
s
.48446 .45199 m
.48386 .45285 L
s
.35893 .4584 m
.35853 .4578 L
s
.48443 .45199 m
.48383 .45285 L
s
.39837 .45515 m
.39771 .4544 L
s
.39838 .45512 m
.39772 .45437 L
s
.71357 .44316 m
.71349 .44353 L
s
.39834 .45513 m
.39768 .45437 L
s
.48445 .45195 m
.48385 .45281 L
s
.16887 .4637 m
.16873 .46335 L
s
.27729 .45593 m
.27711 .45545 L
s
.48448 .45191 m
.48389 .45277 L
s
.5249 .44872 m
.52461 .44939 L
s
.35887 .45832 m
.35847 .45772 L
s
.39829 .45507 m
.39763 .45431 L
s
.39832 .45505 m
.39766 .4543 L
s
.52492 .44869 m
.52463 .44936 L
s
.71359 .44306 m
.71352 .44343 L
s
.48453 .45185 m
.48394 .45271 L
s
.1688 .46363 m
.16867 .46327 L
s
.52498 .44866 m
.5247 .44933 L
s
.52489 .44865 m
.52461 .44932 L
s
.3983 .45499 m
.39765 .45424 L
s
.62243 .45125 m
.62231 .4517 L
s
.39834 .45498 m
.39768 .45423 L
s
.85127 .29482 m
.85136 .29507 L
s
.62231 .45124 m
.62218 .45169 L
s
.18906 .55403 m
.18886 .55366 L
s
.4845 .4518 m
.48391 .45266 L
s
.35882 .45822 m
.35842 .45761 L
s
.35888 .45822 m
.35848 .45762 L
s
.39823 .45495 m
.39758 .4542 L
s
.52492 .4486 m
.52464 .44927 L
s
.39826 .45493 m
.39761 .45417 L
s
.48457 .45176 m
.48399 .45262 L
s
.48456 .45176 m
.48398 .45263 L
s
.2772 .45578 m
.27701 .4553 L
s
.48458 .45176 m
.48399 .45262 L
s
.39821 .45492 m
.39755 .45417 L
s
.48458 .45173 m
.484 .45259 L
s
.39817 .4549 m
.39752 .45414 L
s
.35871 .45814 m
.35832 .45754 L
s
.52497 .44854 m
.5247 .44921 L
s
.52496 .44853 m
.52468 .4492 L
s
.48466 .4517 m
.48408 .45256 L
s
.48461 .4517 m
.48403 .45256 L
s
.48465 .45168 m
.48407 .45254 L
s
.39811 .45484 m
.39746 .45409 L
s
.48463 .45165 m
.48405 .45251 L
s
.35878 .45809 m
.35838 .45748 L
s
.35884 .45808 m
.35845 .45747 L
s
.52503 .44845 m
.52475 .44912 L
s
.35865 .45803 m
.35826 .45743 L
s
.39812 .45478 m
.39747 .45402 L
s
.71364 .4428 m
.71357 .44316 L
s
.62237 .451 m
.62224 .45145 L
s
.4847 .45156 m
.48412 .45242 L
s
.27726 .45558 m
.27707 .4551 L
s
.62242 .451 m
.62229 .45144 L
s
.39803 .45474 m
.39738 .45397 L
s
.85119 .29457 m
.85127 .29482 L
s
.16873 .46335 m
.1686 .46299 L
s
.52506 .44835 m
.52479 .44902 L
s
.39798 .45469 m
.39734 .45393 L
s
.52503 .4483 m
.52476 .44897 L
s
.16867 .46327 m
.16854 .46292 L
s
.39792 .45465 m
.39728 .45389 L
s
.71366 .44269 m
.71359 .44306 L
s
.48475 .45145 m
.48418 .45231 L
s
.35858 .4579 m
.35819 .45729 L
s
.39787 .45463 m
.39723 .45387 L
s
.27711 .45545 m
.27692 .45498 L
s
.48484 .45142 m
.48427 .45228 L
s
.48485 .45141 m
.48428 .45227 L
s
.39784 .45461 m
.3972 .45384 L
s
.39787 .45458 m
.39724 .45381 L
s
.48484 .45138 m
.48427 .45225 L
s
.35849 .45783 m
.3581 .45722 L
s
.18886 .55366 m
.18866 .5533 L
s
.62256 .45081 m
.62243 .45125 L
s
.62243 .45079 m
.62231 .45124 L
s
.35853 .4578 m
.35814 .45719 L
s
.39778 .45454 m
.39715 .45378 L
s
.3979 .45451 m
.39726 .45374 L
s
.4849 .45129 m
.48434 .45216 L
s
.8511 .29432 m
.85119 .29457 L
s
.27701 .4553 m
.27683 .45483 L
s
.39783 .45446 m
.39719 .45369 L
s
.3978 .45446 m
.39717 .4537 L
s
.35847 .45772 m
.35808 .45712 L
s
.52517 .44805 m
.5249 .44872 L
s
.39773 .45442 m
.3971 .45366 L
s
.39778 .45441 m
.39715 .45365 L
s
.52518 .44803 m
.52492 .44869 L
s
.48495 .45119 m
.48439 .45206 L
s
.39771 .4544 m
.39708 .45363 L
s
.71371 .44243 m
.71364 .4428 L
s
.39772 .45437 m
.39709 .45361 L
s
.48493 .45117 m
.48437 .45204 L
s
.1686 .46299 m
.16847 .46264 L
s
.39768 .45437 m
.39706 .45361 L
s
.52525 .44799 m
.52498 .44866 L
s
.48502 .45115 m
.48446 .45202 L
s
.52516 .44798 m
.52489 .44865 L
s
.35842 .45761 m
.35803 .45701 L
s
.35848 .45762 m
.35809 .45701 L
s
.485 .45113 m
.48445 .452 L
s
.48499 .45113 m
.48444 .452 L
s
.48502 .45112 m
.48446 .45199 L
s
.48498 .45112 m
.48443 .45199 L
s
.62249 .45056 m
.62237 .451 L
s
.62254 .45055 m
.62242 .451 L
s
.39763 .45431 m
.39701 .45355 L
s
.52519 .44793 m
.52492 .4486 L
s
.39766 .4543 m
.39704 .45353 L
s
.16854 .46292 m
.16841 .46257 L
s
.485 .45108 m
.48445 .45195 L
s
.71373 .44233 m
.71366 .44269 L
s
.35832 .45754 m
.35794 .45693 L
s
.27707 .4551 m
.27689 .45462 L
s
.48503 .45104 m
.48448 .45191 L
s
.52524 .44787 m
.52497 .44854 L
s
.52523 .44786 m
.52496 .44853 L
s
.39765 .45424 m
.39703 .45347 L
s
.39768 .45423 m
.39706 .45346 L
s
.85101 .29407 m
.8511 .29432 L
s
.35838 .45748 m
.358 .45688 L
s
.35845 .45747 m
.35806 .45686 L
s
.39758 .4542 m
.39696 .45343 L
s
.48508 .45097 m
.48453 .45185 L
s
.39761 .45417 m
.39699 .45341 L
s
.18866 .5533 m
.18846 .55293 L
s
.39755 .45417 m
.39694 .4534 L
s
.35826 .45743 m
.35788 .45682 L
s
.52529 .44778 m
.52503 .44845 L
s
.27692 .45498 m
.27674 .4545 L
s
.39752 .45414 m
.3969 .45338 L
s
.48505 .45093 m
.4845 .4518 L
s
.62268 .45036 m
.62256 .45081 L
s
.62255 .45035 m
.62243 .45079 L
s
.48511 .45089 m
.48457 .45176 L
s
.4851 .45089 m
.48456 .45176 L
s
.48512 .45088 m
.48458 .45176 L
s
.39746 .45409 m
.39685 .45332 L
s
.48513 .45086 m
.48458 .45173 L
s
.52532 .44768 m
.52506 .44835 L
s
.4852 .45082 m
.48466 .4517 L
s
.48515 .45082 m
.48461 .4517 L
s
.48519 .4508 m
.48465 .45168 L
s
.52529 .44763 m
.52503 .4483 L
s
.71378 .44206 m
.71371 .44243 L
s
.39747 .45402 m
.39686 .45325 L
s
.35819 .45729 m
.35781 .45669 L
s
.16847 .46264 m
.16834 .46228 L
s
.27683 .45483 m
.27665 .45435 L
s
.48516 .45077 m
.48463 .45165 L
s
.39738 .45397 m
.39678 .4532 L
s
.85092 .29382 m
.85101 .29407 L
s
.3581 .45722 m
.35773 .45661 L
s
.39734 .45393 m
.39674 .45316 L
s
.16841 .46257 m
.16828 .46221 L
s
.35814 .45719 m
.35776 .45658 L
s
.7138 .44196 m
.71373 .44233 L
s
.48523 .45068 m
.4847 .45156 L
s
.39728 .45389 m
.39669 .45312 L
s
.62261 .45011 m
.62249 .45056 L
s
.62266 .4501 m
.62254 .45055 L
s
.39723 .45387 m
.39663 .4531 L
s
.3972 .45384 m
.39661 .45307 L
s
.35808 .45712 m
.35771 .45651 L
s
.39724 .45381 m
.39664 .45304 L
s
.48527 .45057 m
.48475 .45145 L
s
.27689 .45462 m
.27672 .45415 L
s
.52542 .44738 m
.52517 .44805 L
s
.48536 .45054 m
.48484 .45142 L
s
.18846 .55293 m
.18827 .55256 L
s
.39715 .45378 m
.39656 .453 L
s
.48537 .45053 m
.48485 .45141 L
s
.52544 .44735 m
.52518 .44803 L
s
.39726 .45374 m
.39667 .45297 L
s
.48536 .4505 m
.48484 .45138 L
s
.35803 .45701 m
.35766 .4564 L
s
.35809 .45701 m
.35772 .45641 L
s
.52551 .44732 m
.52525 .44799 L
s
.85083 .29357 m
.85092 .29382 L
s
.52541 .44731 m
.52516 .44798 L
s
.39719 .45369 m
.3966 .45292 L
s
.6228 .44991 m
.62268 .45036 L
s
.39717 .4537 m
.39658 .45292 L
s
.27674 .4545 m
.27657 .45402 L
s
.62267 .4499 m
.62255 .45035 L
s
.35794 .45693 m
.35757 .45633 L
s
.52544 .44726 m
.52519 .44793 L
s
.48542 .45041 m
.4849 .45129 L
s
.3971 .45366 m
.39651 .45288 L
s
.71384 .44169 m
.71378 .44206 L
s
.39715 .45365 m
.39657 .45287 L
s
.16834 .46228 m
.16822 .46193 L
s
.39708 .45363 m
.39649 .45286 L
s
.39709 .45361 m
.39651 .45283 L
s
.52548 .4472 m
.52524 .44787 L
s
.39706 .45361 m
.39647 .45283 L
s
.52548 .44719 m
.52523 .44786 L
s
.358 .45688 m
.35763 .45627 L
s
.35806 .45686 m
.35769 .45626 L
s
.16828 .46221 m
.16815 .46186 L
s
.48546 .45031 m
.48495 .45119 L
s
.35788 .45682 m
.35752 .45621 L
s
.71387 .44159 m
.7138 .44196 L
s
.39701 .45355 m
.39643 .45277 L
s
.48544 .45029 m
.48493 .45117 L
s
.39704 .45353 m
.39646 .45275 L
s
.27665 .45435 m
.27648 .45387 L
s
.48553 .45027 m
.48502 .45115 L
s
.52554 .44711 m
.52529 .44778 L
s
.48551 .45025 m
.485 .45113 L
s
.4855 .45025 m
.48499 .45113 L
s
.48553 .45024 m
.48502 .45112 L
s
.48548 .45024 m
.48498 .45112 L
s
.39703 .45347 m
.39645 .45269 L
s
.39706 .45346 m
.39648 .45268 L
s
.85074 .29333 m
.85083 .29357 L
s
.62273 .44966 m
.62261 .45011 L
s
.4855 .4502 m
.485 .45108 L
s
.62277 .44966 m
.62266 .4501 L
s
.39696 .45343 m
.39638 .45265 L
s
.52557 .44701 m
.52532 .44768 L
s
.48553 .45016 m
.48503 .45104 L
s
.39699 .45341 m
.39641 .45263 L
s
.35781 .45669 m
.35745 .45608 L
s
.39694 .4534 m
.39636 .45262 L
s
.18827 .55256 m
.18807 .55219 L
s
.52553 .44696 m
.52529 .44763 L
s
.3969 .45338 m
.39633 .4526 L
s
.48558 .45009 m
.48508 .45097 L
s
.35773 .45661 m
.35737 .456 L
s
.27672 .45415 m
.27654 .45367 L
s
.39685 .45332 m
.39628 .45253 L
s
.35776 .45658 m
.3574 .45597 L
s
.48554 .45004 m
.48505 .45093 L
s
.71391 .44132 m
.71384 .44169 L
s
.16822 .46193 m
.16809 .46157 L
s
.48561 .45001 m
.48511 .45089 L
s
.48559 .45001 m
.4851 .45089 L
s
.48562 .45 m
.48512 .45088 L
s
.62291 .44947 m
.6228 .44991 L
s
.39686 .45325 m
.3963 .45247 L
s
.62278 .44945 m
.62267 .4499 L
s
.48562 .44997 m
.48513 .45086 L
s
.35771 .45651 m
.35735 .4559 L
s
.27657 .45402 m
.2764 .45354 L
s
.85065 .29308 m
.85074 .29333 L
s
.48569 .44994 m
.4852 .45082 L
s
.16815 .46186 m
.16803 .4615 L
s
.39678 .4532 m
.39621 .45242 L
s
.48564 .44994 m
.48515 .45082 L
s
.48568 .44992 m
.48519 .4508 L
s
.71393 .44122 m
.71387 .44159 L
s
.39674 .45316 m
.39617 .45238 L
s
.48565 .44989 m
.48516 .45077 L
s
.52566 .44671 m
.52542 .44738 L
s
.39669 .45312 m
.39612 .45234 L
s
.35766 .4564 m
.3573 .45579 L
s
.35772 .45641 m
.35736 .45579 L
s
.52568 .44668 m
.52544 .44735 L
s
.39663 .4531 m
.39607 .45232 L
s
.52575 .44665 m
.52551 .44732 L
s
.48571 .4498 m
.48523 .45068 L
s
.39661 .45307 m
.39605 .45229 L
s
.52565 .44664 m
.52541 .44731 L
s
.27648 .45387 m
.27631 .45339 L
s
.35757 .45633 m
.35721 .45571 L
s
.39664 .45304 m
.39608 .45226 L
s
.62284 .44922 m
.62273 .44966 L
s
.52567 .44658 m
.52544 .44726 L
s
.62289 .44921 m
.62277 .44966 L
s
.39656 .453 m
.396 .45222 L
s
.18807 .55219 m
.18788 .55182 L
s
.35763 .45627 m
.35727 .45566 L
s
.39667 .45297 m
.39612 .45218 L
s
.48575 .44968 m
.48527 .45057 L
s
.35769 .45626 m
.35734 .45564 L
s
.52572 .44653 m
.52548 .4472 L
s
.85055 .29283 m
.85065 .29308 L
s
.52571 .44652 m
.52548 .44719 L
s
.48584 .44965 m
.48536 .45054 L
s
.35752 .45621 m
.35716 .4556 L
s
.48584 .44964 m
.48537 .45053 L
s
.3966 .45292 m
.39605 .45213 L
s
.16809 .46157 m
.16797 .46122 L
s
.39658 .45292 m
.39602 .45213 L
s
.71397 .44095 m
.71391 .44132 L
s
.48583 .44962 m
.48536 .4505 L
s
.39657 .45287 m
.39601 .45209 L
s
.39651 .45288 m
.39596 .4521 L
s
.52578 .44643 m
.52554 .44711 L
s
.27654 .45367 m
.27637 .45319 L
s
.39649 .45286 m
.39595 .45207 L
s
.16803 .4615 m
.1679 .46115 L
s
.39651 .45283 m
.39596 .45205 L
s
.39647 .45283 m
.39593 .45204 L
s
.62302 .44902 m
.62291 .44947 L
s
.71399 .44085 m
.71393 .44122 L
s
.62289 .449 m
.62278 .44945 L
s
.48588 .44952 m
.48542 .45041 L
s
.35745 .45608 m
.3571 .45546 L
s
.52579 .44633 m
.52557 .44701 L
s
.39643 .45277 m
.39588 .45198 L
s
.39646 .45275 m
.39592 .45197 L
s
.2764 .45354 m
.27623 .45306 L
s
.52576 .44629 m
.52553 .44696 L
s
.35737 .456 m
.35702 .45539 L
s
.48593 .44942 m
.48546 .45031 L
s
.85046 .29258 m
.85055 .29283 L
s
.39645 .45269 m
.39591 .4519 L
s
.39648 .45268 m
.39594 .45189 L
s
.4859 .4494 m
.48544 .45029 L
s
.3574 .45597 m
.35705 .45536 L
s
.48599 .44938 m
.48553 .45027 L
s
.48597 .44936 m
.48551 .45025 L
s
.48596 .44936 m
.4855 .45025 L
s
.39638 .45265 m
.39584 .45186 L
s
.48598 .44935 m
.48553 .45024 L
s
.48594 .44935 m
.48548 .45024 L
s
.39641 .45263 m
.39588 .45184 L
s
.39636 .45262 m
.39583 .45183 L
s
.48596 .4493 m
.4855 .4502 L
s
.35735 .4559 m
.357 .45529 L
s
.39633 .4526 m
.3958 .45181 L
s
.27631 .45339 m
.27614 .45291 L
s
.18788 .55182 m
.18769 .55146 L
s
.62295 .44877 m
.62284 .44922 L
s
.62299 .44876 m
.62289 .44921 L
s
.48599 .44926 m
.48553 .45016 L
s
.16797 .46122 m
.16784 .46086 L
s
.71404 .44059 m
.71397 .44095 L
s
.39628 .45253 m
.39575 .45174 L
s
.48603 .4492 m
.48558 .45009 L
s
.3573 .45579 m
.35696 .45518 L
s
.35736 .45579 m
.35702 .45518 L
s
.52589 .44604 m
.52566 .44671 L
s
.1679 .46115 m
.16778 .46079 L
s
.3963 .45247 m
.39577 .45167 L
s
.5259 .44601 m
.52568 .44668 L
s
.48599 .44915 m
.48554 .45004 L
s
.85037 .29233 m
.85046 .29258 L
s
.71406 .44048 m
.71399 .44085 L
s
.52597 .44597 m
.52575 .44665 L
s
.39621 .45242 m
.39568 .45163 L
s
.35721 .45571 m
.35687 .4551 L
s
.48605 .44911 m
.48561 .45001 L
s
.48603 .44911 m
.48559 .45001 L
s
.52587 .44596 m
.52565 .44664 L
s
.48606 .44911 m
.48562 .45 L
s
.27637 .45319 m
.27621 .45271 L
s
.62313 .44857 m
.62302 .44902 L
s
.48607 .44908 m
.48562 .44997 L
s
.39617 .45238 m
.39565 .45159 L
s
.623 .44856 m
.62289 .449 L
s
.5259 .44591 m
.52567 .44658 L
s
.35727 .45566 m
.35693 .45504 L
s
.48613 .44904 m
.48569 .44994 L
s
.48608 .44904 m
.48564 .44994 L
s
.35734 .45564 m
.35699 .45503 L
s
.39612 .45234 m
.3956 .45154 L
s
.48612 .44902 m
.48568 .44992 L
s
.35716 .4556 m
.35682 .45499 L
s
.39607 .45232 m
.39555 .45152 L
s
.52594 .44585 m
.52572 .44653 L
s
.48609 .44899 m
.48565 .44989 L
s
.52593 .44585 m
.52571 .44652 L
s
.39605 .45229 m
.39553 .45149 L
s
.27623 .45306 m
.27606 .45258 L
s
.39608 .45226 m
.39557 .45146 L
s
.526 .44576 m
.52578 .44643 L
s
.48615 .4489 m
.48571 .4498 L
s
.396 .45222 m
.39549 .45142 L
s
.16784 .46086 m
.16772 .46051 L
s
.18769 .55146 m
.1875 .55108 L
s
.85028 .29208 m
.85037 .29233 L
s
.39612 .45218 m
.3956 .45139 L
s
.7141 .44022 m
.71404 .44059 L
s
.3571 .45546 m
.35676 .45485 L
s
.62305 .44832 m
.62295 .44877 L
s
.6231 .44831 m
.62299 .44876 L
s
.39605 .45213 m
.39554 .45134 L
s
.39602 .45213 m
.39551 .45134 L
s
.27614 .45291 m
.27598 .45243 L
s
.52601 .44566 m
.52579 .44633 L
s
.16778 .46079 m
.16766 .46043 L
s
.48618 .44879 m
.48575 .44968 L
s
.35702 .45539 m
.35668 .45478 L
s
.39601 .45209 m
.3955 .45129 L
s
.39596 .4521 m
.39545 .4513 L
s
.48626 .44876 m
.48584 .44965 L
s
.52598 .44562 m
.52576 .44629 L
s
.71412 .44011 m
.71406 .44048 L
s
.39595 .45207 m
.39544 .45127 L
s
.48627 .44875 m
.48584 .44964 L
s
.35705 .45536 m
.35672 .45475 L
s
.39596 .45205 m
.39545 .45125 L
s
.39593 .45204 m
.39542 .45125 L
s
.48625 .44872 m
.48583 .44962 L
s
.39588 .45198 m
.39538 .45118 L
s
.357 .45529 m
.35666 .45467 L
s
.39592 .45197 m
.39541 .45117 L
s
.62324 .44812 m
.62313 .44857 L
s
.4863 .44862 m
.48588 .44952 L
s
.62311 .44811 m
.623 .44856 L
s
.85018 .29183 m
.85028 .29208 L
s
.27621 .45271 m
.27604 .45223 L
s
.39591 .4519 m
.39541 .4511 L
s
.39594 .45189 m
.39544 .4511 L
s
.35696 .45518 m
.35663 .45456 L
s
.35702 .45518 m
.35668 .45456 L
s
.39584 .45186 m
.39534 .45106 L
s
.48634 .44852 m
.48593 .44942 L
s
.39588 .45184 m
.39538 .45104 L
s
.5261 .44536 m
.52589 .44604 L
s
.39583 .45183 m
.39533 .45103 L
s
.16772 .46051 m
.1676 .46015 L
s
.48631 .4485 m
.4859 .4494 L
s
.4864 .44848 m
.48599 .44938 L
s
.3958 .45181 m
.39531 .45101 L
s
.27606 .45258 m
.2759 .4521 L
s
.52611 .44533 m
.5259 .44601 L
s
.71416 .43985 m
.7141 .44022 L
s
.35687 .4551 m
.35654 .45448 L
s
.1875 .55108 m
.18731 .55071 L
s
.48638 .44846 m
.48597 .44936 L
s
.48637 .44846 m
.48596 .44936 L
s
.48639 .44845 m
.48598 .44935 L
s
.48635 .44845 m
.48594 .44935 L
s
.52618 .4453 m
.52597 .44597 L
s
.52608 .44529 m
.52587 .44596 L
s
.16766 .46043 m
.16754 .46008 L
s
.39575 .45174 m
.39526 .45094 L
s
.48636 .4484 m
.48596 .4493 L
s
.35693 .45504 m
.3566 .45442 L
s
.35699 .45503 m
.35666 .45441 L
s
.62316 .44787 m
.62305 .44832 L
s
.5261 .44523 m
.5259 .44591 L
s
.71418 .43975 m
.71412 .44011 L
s
.6232 .44787 m
.6231 .44831 L
s
.44167 .45087 m
.43912 .45072 L
s
.44425 .45074 m
.44167 .45087 L
s
.48639 .44836 m
.48599 .44926 L
s
.35682 .45499 m
.3565 .45437 L
s
.44252 .45084 m
.43995 .45077 L
s
.44509 .45061 m
.44252 .45084 L
s
.85009 .29159 m
.85018 .29183 L
s
.39577 .45167 m
.39528 .45087 L
s
.44266 .45084 m
.44009 .45079 L
s
.44522 .45059 m
.44266 .45084 L
s
.44238 .45084 m
.43982 .45076 L
s
.44495 .45063 m
.44238 .45084 L
s
.44187 .45085 m
.43931 .45071 L
s
.44445 .45069 m
.44187 .45085 L
s
.44279 .45083 m
.44021 .45079 L
s
.44535 .45057 m
.44279 .45083 L
s
.44261 .45083 m
.44004 .45079 L
s
.44517 .45058 m
.44261 .45083 L
s
.44212 .45084 m
.43955 .45073 L
s
.44469 .45065 m
.44212 .45084 L
s
.44333 .45082 m
.44075 .45084 L
s
.44588 .45049 m
.44333 .45082 L
s
.44146 .45085 m
.43891 .45066 L
s
.44404 .45074 m
.44146 .45085 L
s
.4426 .45083 m
.44003 .45077 L
s
.44517 .45059 m
.4426 .45083 L
s
.44236 .45083 m
.43979 .45075 L
s
.44493 .45061 m
.44236 .45083 L
s
.44206 .45083 m
.4395 .45072 L
s
.44463 .45065 m
.44206 .45083 L
s
.44113 .45084 m
.43859 .45062 L
s
.44371 .45077 m
.44113 .45084 L
s
.44235 .45082 m
.43979 .45073 L
s
.44493 .45062 m
.44235 .45082 L
s
.44151 .45084 m
.43896 .45066 L
s
.44409 .45072 m
.44151 .45084 L
s
.44197 .45083 m
.43941 .45071 L
s
.44454 .45066 m
.44197 .45083 L
s
.44311 .45081 m
.44053 .45081 L
s
.44567 .45052 m
.44311 .45081 L
s
.44289 .45081 m
.44031 .45079 L
s
.44545 .45054 m
.44289 .45081 L
s
.44075 .45084 m
.43823 .45058 L
s
.44181 .45083 m
.43925 .45068 L
s
.44439 .45068 m
.44181 .45083 L
s
.44181 .45083 m
.43925 .45068 L
s
.44439 .45068 m
.44181 .45083 L
s
.4417 .45083 m
.43915 .45067 L
s
.44428 .4507 m
.4417 .45083 L
s
.44216 .45082 m
.4396 .45071 L
s
.44474 .45064 m
.44216 .45082 L
s
.44164 .45083 m
.43909 .45067 L
s
.44422 .4507 m
.44164 .45083 L
s
.44221 .45082 m
.43964 .45072 L
s
.44478 .45063 m
.44221 .45082 L
s
.44224 .45082 m
.43967 .45072 L
s
.44481 .45062 m
.44224 .45082 L
s
.44095 .45084 m
.43842 .4506 L
s
.44353 .45079 m
.44095 .45084 L
s
.44119 .45084 m
.43865 .45062 L
s
.44377 .45076 m
.44119 .45084 L
s
.44102 .45084 m
.43848 .45061 L
s
.44359 .45078 m
.44102 .45084 L
s
.44136 .45083 m
.43882 .45064 L
s
.44394 .45074 m
.44136 .45083 L
s
.44258 .45081 m
.44 .45075 L
s
.44515 .45058 m
.44258 .45081 L
s
.44196 .45082 m
.4394 .45069 L
s
.44453 .45066 m
.44196 .45082 L
s
.52614 .44518 m
.52594 .44585 L
s
.44241 .45082 m
.43985 .45074 L
s
.44498 .4506 m
.44241 .45082 L
s
.27598 .45243 m
.27582 .45195 L
s
.44211 .45082 m
.43955 .4507 L
s
.44468 .45064 m
.44211 .45082 L
s
.44183 .45082 m
.43928 .45067 L
s
.44441 .45068 m
.44183 .45082 L
s
.44193 .45082 m
.43937 .45068 L
s
.44451 .45066 m
.44193 .45082 L
s
.44286 .45081 m
.44029 .45078 L
s
.44543 .45054 m
.44286 .45081 L
s
.44158 .45082 m
.43903 .45064 L
s
.44416 .45071 m
.44158 .45082 L
s
.4423 .45082 m
.43973 .45073 L
s
.44487 .45061 m
.4423 .45082 L
s
.44142 .45083 m
.43887 .45064 L
s
.444 .45072 m
.44142 .45083 L
s
.44316 .4508 m
.44058 .45081 L
s
.44572 .4505 m
.44316 .4508 L
s
.44282 .45081 m
.44025 .45077 L
s
.44538 .45054 m
.44282 .45081 L
s
.44285 .4508 m
.44028 .45077 L
s
.44542 .45054 m
.44285 .4508 L
s
.44329 .4508 m
.44071 .45082 L
s
.44584 .45048 m
.44329 .4508 L
s
.4425 .45081 m
.43993 .45073 L
s
.44507 .45058 m
.4425 .45081 L
s
.44087 .45083 m
.43834 .45058 L
s
.44345 .45079 m
.44087 .45083 L
s
.44162 .45082 m
.43907 .45066 L
s
.4442 .4507 m
.44162 .45082 L
s
.44192 .45082 m
.43936 .45068 L
s
.4445 .45066 m
.44192 .45082 L
s
.44599 .45046 m
.44345 .45079 L
s
.52614 .44517 m
.52593 .44585 L
s
.44256 .45081 m
.43999 .45075 L
s
.44513 .45057 m
.44256 .45081 L
s
.44608 .45044 m
.44353 .45079 L
s
.44123 .45082 m
.43868 .45062 L
s
.44381 .45074 m
.44123 .45082 L
s
.44301 .4508 m
.44043 .45078 L
s
.44557 .45052 m
.44301 .4508 L
s
.4414 .45082 m
.43886 .45063 L
s
.44398 .45072 m
.4414 .45082 L
s
.44275 .4508 m
.44018 .45076 L
s
.44531 .45054 m
.44275 .4508 L
s
.44305 .45079 m
.44047 .45078 L
s
.4456 .4505 m
.44305 .45079 L
s
.44224 .4508 m
.43967 .4507 L
s
.44481 .45061 m
.44224 .4508 L
s
.44158 .45081 m
.43903 .45063 L
s
.44416 .4507 m
.44158 .45081 L
s
.44204 .45081 m
.43948 .45068 L
s
.44461 .45064 m
.44204 .45081 L
s
.44245 .4508 m
.43988 .45073 L
s
.44502 .45057 m
.44245 .4508 L
s
.44184 .45081 m
.43928 .45067 L
s
.44441 .45066 m
.44184 .45081 L
s
.44218 .4508 m
.43961 .45069 L
s
.44476 .45062 m
.44218 .4508 L
s
.44163 .45081 m
.43908 .45064 L
s
.44421 .45069 m
.44163 .45081 L
s
.44225 .4508 m
.43969 .4507 L
s
.44483 .45061 m
.44225 .4508 L
s
.44165 .45081 m
.4391 .45064 L
s
.44423 .45069 m
.44165 .45081 L
s
.44614 .45042 m
.44359 .45078 L
s
.44123 .45082 m
.43868 .45061 L
s
.4438 .45073 m
.44123 .45082 L
s
.44283 .45079 m
.44025 .45077 L
s
.44539 .45052 m
.44283 .45079 L
s
.44202 .45081 m
.43946 .45069 L
s
.44459 .45063 m
.44202 .45081 L
s
.44625 .45041 m
.44371 .45077 L
s
.44226 .4508 m
.4397 .45071 L
s
.44483 .4506 m
.44226 .4508 L
s
.48643 .44829 m
.48603 .4492 L
s
.44261 .45079 m
.44004 .45074 L
s
.44518 .45055 m
.44261 .45079 L
s
.4422 .4508 m
.43964 .4507 L
s
.44477 .4506 m
.4422 .4508 L
s
.44071 .45082 m
.43818 .45054 L
s
.44297 .45079 m
.4404 .45077 L
s
.44553 .4505 m
.44297 .45079 L
s
.44247 .45079 m
.4399 .45072 L
s
.44504 .45057 m
.44247 .45079 L
s
.4428 .45079 m
.44023 .45075 L
s
.44536 .45052 m
.4428 .45079 L
s
.4419 .4508 m
.43934 .45066 L
s
.44447 .45064 m
.4419 .4508 L
s
.44217 .4508 m
.43961 .4507 L
s
.44475 .4506 m
.44217 .4508 L
s
.39568 .45163 m
.3952 .45083 L
s
.44142 .4508 m
.43887 .45061 L
s
.444 .4507 m
.44142 .4508 L
s
.44302 .45078 m
.44045 .45078 L
s
.44558 .45049 m
.44302 .45078 L
s
.44153 .4508 m
.43898 .45063 L
s
.44411 .45068 m
.44153 .4508 L
s
.4413 .4508 m
.43875 .45059 L
s
.44388 .45072 m
.4413 .4508 L
s
.44317 .45077 m
.4406 .45078 L
s
.44573 .45047 m
.44317 .45077 L
s
.44319 .45077 m
.44061 .45078 L
s
.44574 .45047 m
.44319 .45077 L
s
.44053 .45081 m
.43802 .45052 L
s
.44101 .45081 m
.43848 .45058 L
s
.44359 .45074 m
.44101 .45081 L
s
.44242 .45078 m
.43985 .4507 L
s
.44498 .45057 m
.44242 .45078 L
s
.44225 .45079 m
.43969 .45069 L
s
.44482 .45059 m
.44225 .45079 L
s
.44122 .4508 m
.43869 .45059 L
s
.4438 .45072 m
.44122 .4508 L
s
.44307 .45078 m
.44049 .45078 L
s
.44562 .45048 m
.44307 .45078 L
s
.44058 .45081 m
.43806 .45052 L
s
.44139 .4508 m
.43885 .4506 L
s
.44397 .4507 m
.44139 .4508 L
s
.44172 .45079 m
.43916 .45064 L
s
.44429 .45065 m
.44172 .45079 L
s
.44119 .4508 m
.43865 .45058 L
s
.44378 .45072 m
.44119 .4508 L
s
.44188 .45079 m
.43932 .45065 L
s
.44445 .45063 m
.44188 .45079 L
s
.4431 .45077 m
.44052 .45076 L
s
.44566 .45047 m
.4431 .45077 L
s
.44156 .45079 m
.43901 .45062 L
s
.44414 .45067 m
.44156 .45079 L
s
.44631 .45039 m
.44377 .45076 L
s
.44131 .45079 m
.43877 .45058 L
s
.44389 .45071 m
.44131 .45079 L
s
.44331 .45077 m
.44073 .4508 L
s
.44586 .45044 m
.44331 .45077 L
s
.44344 .45076 m
.44086 .4508 L
s
.44599 .45043 m
.44344 .45076 L
s
.44304 .45077 m
.44046 .45076 L
s
.44559 .45048 m
.44304 .45077 L
s
.44185 .45078 m
.43929 .45064 L
s
.44443 .45063 m
.44185 .45078 L
s
.44086 .4508 m
.43834 .45054 L
s
.44092 .45079 m
.43839 .45055 L
s
.4435 .45075 m
.44092 .45079 L
s
.44216 .45078 m
.4396 .45067 L
s
.44473 .45059 m
.44216 .45078 L
s
.44324 .45076 m
.44067 .45078 L
s
.4458 .45045 m
.44324 .45076 L
s
.44256 .45077 m
.43999 .4507 L
s
.44513 .45054 m
.44256 .45077 L
s
.44257 .45077 m
.44 .45071 L
s
.44513 .45054 m
.44257 .45077 L
s
.44329 .45076 m
.44071 .45078 L
s
.44583 .45045 m
.44329 .45076 L
s
.44146 .45079 m
.43892 .4506 L
s
.44404 .45068 m
.44146 .45079 L
s
.44258 .45077 m
.44001 .45071 L
s
.44515 .45054 m
.44258 .45077 L
s
.44073 .4508 m
.43821 .45054 L
s
.44318 .45076 m
.4406 .45076 L
s
.44573 .45046 m
.44318 .45076 L
s
.44118 .45079 m
.43864 .45057 L
s
.44375 .45072 m
.44118 .45079 L
s
.44125 .45079 m
.43871 .45058 L
s
.44382 .4507 m
.44125 .45079 L
s
.44605 .45041 m
.4435 .45075 L
s
.44115 .45078 m
.43861 .45056 L
s
.44373 .45072 m
.44115 .45078 L
s
.4429 .45076 m
.44033 .45073 L
s
.44546 .45049 m
.4429 .45076 L
s
.44216 .45077 m
.4396 .45067 L
s
.44473 .45058 m
.44216 .45077 L
s
.44194 .45078 m
.43939 .45065 L
s
.44452 .45061 m
.44194 .45078 L
s
.44259 .45076 m
.44002 .4507 L
s
.44515 .45053 m
.44259 .45076 L
s
.44149 .45078 m
.43894 .45061 L
s
.44406 .45067 m
.44149 .45078 L
s
.44274 .45076 m
.44017 .45072 L
s
.4453 .45051 m
.44274 .45076 L
s
.44183 .45077 m
.43928 .45063 L
s
.44441 .45062 m
.44183 .45077 L
s
.44146 .45078 m
.43891 .45059 L
s
.44404 .45067 m
.44146 .45078 L
s
.44251 .45077 m
.43994 .4507 L
s
.44508 .45054 m
.44251 .45077 L
s
.44115 .45078 m
.43861 .45056 L
s
.44373 .45071 m
.44115 .45078 L
s
.44321 .45075 m
.44064 .45076 L
s
.44576 .45045 m
.44321 .45075 L
s
.44323 .45075 m
.44065 .45075 L
s
.44578 .45045 m
.44323 .45075 L
s
.44677 .4503 m
.44425 .45074 L
s
.44104 .45078 m
.43851 .45055 L
s
.44362 .45073 m
.44104 .45078 L
s
.44083 .45079 m
.43831 .45054 L
s
.44341 .45075 m
.44083 .45079 L
s
.44129 .45078 m
.43875 .45057 L
s
.44387 .4507 m
.44129 .45078 L
s
.44096 .45078 m
.43843 .45054 L
s
.44354 .45073 m
.44096 .45078 L
s
.44596 .45041 m
.44341 .45075 L
s
.44123 .45078 m
.43869 .45056 L
s
.44381 .4507 m
.44123 .45078 L
s
.44318 .45075 m
.4406 .45076 L
s
.44574 .45044 m
.44318 .45075 L
s
.44099 .45078 m
.43846 .45054 L
s
.44357 .45073 m
.44099 .45078 L
s
.44189 .45077 m
.43933 .45063 L
s
.44446 .45061 m
.44189 .45077 L
s
.44273 .45076 m
.44016 .45071 L
s
.44529 .45051 m
.44273 .45076 L
s
.44293 .45075 m
.44036 .45072 L
s
.4455 .45048 m
.44293 .45075 L
s
.44656 .45033 m
.44404 .45074 L
s
.44031 .45079 m
.4378 .45047 L
s
.44634 .45036 m
.44381 .45074 L
s
.44285 .45075 m
.44027 .45073 L
s
.44541 .45048 m
.44285 .45075 L
s
.44343 .45074 m
.44085 .45077 L
s
.44597 .45042 m
.44343 .45074 L
s
.4425 .45076 m
.43993 .45069 L
s
.44506 .45053 m
.4425 .45076 L
s
.44099 .45078 m
.43846 .45053 L
s
.44357 .45073 m
.44099 .45078 L
s
.44159 .45077 m
.43904 .45059 L
s
.44416 .45065 m
.44159 .45077 L
s
.44094 .45078 m
.43841 .45054 L
s
.44352 .45073 m
.44094 .45078 L
s
.44648 .45034 m
.44394 .45074 L
s
.44287 .45075 m
.4403 .45072 L
s
.44544 .45048 m
.44287 .45075 L
s
.4406 .45078 m
.43808 .4505 L
s
.44613 .45038 m
.44359 .45074 L
s
.44061 .45078 m
.43809 .4505 L
s
.44071 .45078 m
.43819 .45052 L
s
.44297 .45075 m
.44039 .45073 L
s
.44552 .45047 m
.44297 .45075 L
s
.44021 .45079 m
.43771 .45046 L
s
.44283 .45075 m
.44026 .45071 L
s
.44539 .45049 m
.44283 .45075 L
s
.44047 .45078 m
.43795 .45049 L
s
.44043 .45078 m
.43792 .45048 L
s
.44225 .45076 m
.43969 .45065 L
s
.44482 .45057 m
.44225 .45076 L
s
.44171 .45077 m
.43916 .45061 L
s
.44428 .45063 m
.44171 .45077 L
s
.44092 .45077 m
.43839 .45052 L
s
.4435 .45073 m
.44092 .45077 L
s
.4416 .45077 m
.43905 .4506 L
s
.44417 .45065 m
.4416 .45077 L
s
.44343 .45074 m
.44085 .45077 L
s
.44598 .4504 m
.44343 .45074 L
s
.44085 .45077 m
.43833 .45052 L
s
.44634 .45035 m
.4438 .45073 L
s
.44009 .45079 m
.43759 .45045 L
s
.44094 .45078 m
.43842 .45053 L
s
.44352 .45073 m
.44094 .45078 L
s
.44067 .45078 m
.43815 .4505 L
s
.44085 .45077 m
.43832 .45051 L
s
.44612 .45039 m
.44357 .45073 L
s
.44327 .45074 m
.44069 .45075 L
s
.44583 .45043 m
.44327 .45074 L
s
.44609 .45039 m
.44354 .45073 L
s
.44227 .45075 m
.43971 .45065 L
s
.44485 .45056 m
.44227 .45075 L
s
.44004 .45079 m
.43754 .45045 L
s
.44159 .45076 m
.43904 .45059 L
s
.44416 .45064 m
.44159 .45076 L
s
.44327 .45074 m
.44069 .45076 L
s
.44582 .45042 m
.44327 .45074 L
s
.44611 .45039 m
.44357 .45073 L
s
.44605 .45039 m
.4435 .45073 L
s
.44049 .45078 m
.43797 .4505 L
s
.39565 .45159 m
.39516 .45079 L
s
.44029 .45078 m
.43778 .45046 L
s
.44652 .45032 m
.444 .45072 L
s
.44607 .45039 m
.44352 .45073 L
s
.44661 .4503 m
.44409 .45072 L
s
.44045 .45078 m
.43794 .45048 L
s
.44606 .45038 m
.44352 .45073 L
s
.44194 .45075 m
.43938 .45061 L
s
.44452 .4506 m
.44194 .45075 L
s
.44028 .45077 m
.43777 .45045 L
s
.44282 .45074 m
.44025 .4507 L
s
.44538 .45047 m
.44282 .45074 L
s
.44244 .45074 m
.43987 .45066 L
s
.44501 .45052 m
.44244 .45074 L
s
.44634 .45035 m
.4438 .45072 L
s
.4404 .45077 m
.43789 .45047 L
s
.44616 .45037 m
.44362 .45073 L
s
.4465 .45032 m
.44398 .45072 L
s
.44025 .45077 m
.43774 .45045 L
s
.44052 .45076 m
.43801 .45047 L
s
.44641 .45034 m
.44388 .45072 L
s
.44627 .45036 m
.44373 .45072 L
s
.48639 .44824 m
.48599 .44915 L
s
.44317 .45073 m
.44059 .45074 L
s
.44572 .45042 m
.44317 .45073 L
s
.44631 .45034 m
.44378 .45072 L
s
.44668 .4503 m
.44416 .45071 L
s
.44087 .45076 m
.43834 .45052 L
s
.44345 .45072 m
.44087 .45076 L
s
.44064 .45076 m
.43812 .45049 L
s
.44069 .45076 m
.43817 .4505 L
s
.43995 .45077 m
.43746 .45041 L
s
.44046 .45076 m
.43795 .45047 L
s
.44629 .45035 m
.44375 .45072 L
s
.44025 .45077 m
.43775 .45046 L
s
.4406 .45076 m
.43809 .45047 L
s
.44643 .45033 m
.44389 .45071 L
s
.44003 .45077 m
.43754 .45042 L
s
.44126 .45075 m
.43872 .45054 L
s
.44384 .45067 m
.44126 .45075 L
s
.4406 .45076 m
.43809 .45047 L
s
.44599 .45038 m
.44345 .45072 L
s
.44065 .45075 m
.43813 .45046 L
s
.44626 .45034 m
.44373 .45071 L
s
.44674 .45027 m
.44422 .4507 L
s
.4465 .45031 m
.44397 .4507 L
s
.44317 .45072 m
.44059 .45072 L
s
.44572 .45041 m
.44317 .45072 L
s
.44018 .45076 m
.43767 .45043 L
s
.44669 .45029 m
.44416 .4507 L
s
.44679 .45027 m
.44428 .4507 L
s
.44653 .4503 m
.444 .4507 L
s
.5262 .44508 m
.526 .44576 L
s
.44069 .45075 m
.43818 .45047 L
s
.44635 .45033 m
.44381 .4507 L
s
.44672 .45027 m
.4442 .4507 L
s
.44023 .45075 m
.43772 .45043 L
s
.44124 .45074 m
.43871 .45052 L
s
.44382 .45066 m
.44124 .45074 L
s
.44636 .45032 m
.44382 .4507 L
s
.43982 .45076 m
.43733 .45039 L
s
.44696 .45023 m
.44445 .45069 L
s
.44 .45075 m
.43751 .4504 L
s
.4464 .45031 m
.44387 .4507 L
s
.44673 .45027 m
.44421 .45069 L
s
.44676 .45027 m
.44423 .45069 L
s
.44059 .45074 m
.43807 .45046 L
s
.4469 .45024 m
.44439 .45068 L
s
.43999 .45075 m
.4375 .4504 L
s
.43979 .45075 m
.43731 .45039 L
s
.44693 .45024 m
.44441 .45068 L
s
.4469 .45023 m
.44439 .45068 L
s
.44092 .45073 m
.4384 .45048 L
s
.4435 .45069 m
.44092 .45073 L
s
.48645 .44821 m
.48605 .44911 L
s
.44664 .45027 m
.44411 .45068 L
s
.43985 .45074 m
.43736 .45039 L
s
.48643 .44821 m
.48603 .44911 L
s
.44004 .45074 m
.43755 .4504 L
s
.44657 .45028 m
.44404 .45068 L
s
.44033 .45073 m
.43782 .45042 L
s
.43993 .45073 m
.43744 .45037 L
s
.3956 .45154 m
.39512 .45074 L
s
.44345 .45069 m
.44087 .45072 L
s
.446 .45036 m
.44345 .45069 L
s
.44039 .45073 m
.43789 .45042 L
s
.48646 .4482 m
.48606 .44911 L
s
.44605 .45034 m
.4435 .45069 L
s
.43979 .45073 m
.43731 .45036 L
s
.44087 .45072 m
.43834 .45046 L
s
.44666 .45025 m
.44414 .45067 L
s
.43988 .45073 m
.43739 .45038 L
s
.44059 .45072 m
.43807 .45044 L
s
.44703 .45021 m
.44451 .45066 L
s
.44027 .45073 m
.43776 .45041 L
s
.44036 .45072 m
.43785 .45041 L
s
.44656 .45026 m
.44404 .45067 L
s
.44704 .4502 m
.44453 .45066 L
s
.4403 .45072 m
.4378 .45041 L
s
.35676 .45485 m
.35644 .45423 L
s
.44701 .45021 m
.4445 .45066 L
s
.44705 .45019 m
.44454 .45066 L
s
.43955 .45073 m
.43708 .45035 L
s
.43973 .45073 m
.43725 .45036 L
s
.44017 .45072 m
.43767 .4504 L
s
.44692 .45021 m
.44441 .45066 L
s
.44658 .45025 m
.44406 .45067 L
s
.44714 .45018 m
.44463 .45065 L
s
.44637 .45028 m
.44384 .45067 L
s
.44719 .45016 m
.44469 .45065 L
s
.44026 .45071 m
.43775 .45039 L
s
.43967 .45072 m
.43719 .45034 L
s
.44636 .45029 m
.44382 .45066 L
s
.4399 .45072 m
.43741 .45035 L
s
.43964 .45072 m
.43717 .45033 L
s
.44669 .45023 m
.44416 .45065 L
s
.44719 .45017 m
.44468 .45064 L
s
.4468 .45021 m
.44429 .45065 L
s
.44016 .45071 m
.43766 .45038 L
s
.4395 .45072 m
.43703 .45032 L
s
.44 .45071 m
.43751 .45036 L
s
.44001 .45071 m
.43752 .45036 L
s
.44723 .45016 m
.44474 .45064 L
s
.44025 .4507 m
.43774 .45038 L
s
.4396 .45071 m
.43713 .45032 L
s
.48646 .44818 m
.48607 .44908 L
s
.39555 .45152 m
.39508 .45072 L
s
.62334 .44767 m
.62324 .44812 L
s
.44698 .45018 m
.44447 .45064 L
s
.43999 .4507 m
.4375 .45035 L
s
.44669 .45023 m
.44416 .45064 L
s
.43912 .45072 m
.43667 .45028 L
s
.44711 .45017 m
.44461 .45064 L
s
.44669 .45022 m
.44417 .45065 L
s
.4397 .45071 m
.43722 .45034 L
s
.43931 .45071 m
.43685 .4503 L
s
.43985 .4507 m
.43737 .45034 L
s
.44744 .45012 m
.44495 .45063 L
s
.44728 .45014 m
.44478 .45063 L
s
.44002 .4507 m
.43753 .45034 L
s
.43941 .45071 m
.43695 .4503 L
s
.43967 .4507 m
.43719 .45031 L
s
.44695 .45018 m
.44443 .45063 L
s
.43969 .4507 m
.43721 .45032 L
s
.44731 .45013 m
.44481 .45062 L
s
.44697 .45018 m
.44445 .45063 L
s
.43994 .4507 m
.43745 .45035 L
s
.43955 .4507 m
.43708 .4503 L
s
.44742 .45012 m
.44493 .45062 L
s
.44709 .45015 m
.44459 .45063 L
s
.44758 .45009 m
.44509 .45061 L
s
.43993 .45069 m
.43743 .45034 L
s
.4468 .4502 m
.44428 .45063 L
s
.43964 .4507 m
.43716 .45031 L
s
.43961 .4507 m
.43713 .45031 L
s
.44692 .45018 m
.44441 .45062 L
s
.43961 .45069 m
.43714 .4503 L
s
.62321 .44766 m
.62311 .44811 L
s
.44726 .45013 m
.44476 .45062 L
s
.43969 .45069 m
.43721 .45031 L
s
.44742 .4501 m
.44493 .45061 L
s
.44731 .45012 m
.44481 .45061 L
s
.4394 .45069 m
.43693 .45027 L
s
.43946 .45069 m
.43699 .45029 L
s
.44732 .45011 m
.44483 .45061 L
s
.44736 .4501 m
.44487 .45061 L
s
.44697 .45016 m
.44446 .45061 L
s
.43948 .45068 m
.43701 .45028 L
s
.43925 .45068 m
.4368 .45026 L
s
.39553 .45149 m
.39506 .45069 L
s
.44702 .45015 m
.44452 .45061 L
s
.43937 .45068 m
.43691 .45026 L
s
.48653 .44814 m
.48613 .44904 L
s
.44727 .45011 m
.44477 .4506 L
s
.43925 .45068 m
.43679 .45025 L
s
.43936 .45068 m
.4369 .45026 L
s
.44765 .45006 m
.44517 .45059 L
s
.4477 .45005 m
.44522 .45059 L
s
.44724 .45011 m
.44475 .4506 L
s
.44746 .45008 m
.44498 .4506 L
s
.48647 .44813 m
.48608 .44904 L
s
.43987 .45066 m
.43738 .4503 L
s
.4396 .45067 m
.43713 .45028 L
s
.44732 .45009 m
.44483 .4506 L
s
.44723 .45011 m
.44473 .45059 L
s
.43928 .45067 m
.43683 .45024 L
s
.4396 .45067 m
.43712 .45028 L
s
.44703 .45014 m
.44452 .4506 L
s
.44756 .45006 m
.44507 .45058 L
s
.43915 .45067 m
.4367 .45023 L
s
.44764 .45004 m
.44517 .45058 L
s
.35668 .45478 m
.35636 .45416 L
s
.44732 .45009 m
.44482 .45059 L
s
.44763 .45005 m
.44515 .45058 L
s
.43928 .45067 m
.43683 .45024 L
s
.43934 .45066 m
.43687 .45024 L
s
.43909 .45067 m
.43664 .45022 L
s
.44782 .45002 m
.44535 .45057 L
s
.52621 .44499 m
.52601 .44566 L
s
.48651 .44812 m
.48612 .44902 L
s
.43971 .45065 m
.43723 .45027 L
s
.39557 .45146 m
.39509 .45066 L
s
.1676 .46015 m
.16748 .45979 L
s
.43891 .45066 m
.43647 .4502 L
s
.44723 .45009 m
.44473 .45058 L
s
.43969 .45065 m
.43721 .45026 L
s
.43896 .45066 m
.43651 .4502 L
s
.44752 .45006 m
.44504 .45057 L
s
.4475 .45005 m
.44502 .45057 L
s
.44761 .45004 m
.44513 .45057 L
s
.27604 .45223 m
.27588 .45175 L
s
.44747 .45006 m
.44498 .45057 L
s
.43932 .45065 m
.43686 .45023 L
s
.43907 .45066 m
.43662 .45021 L
s
.44732 .45008 m
.44482 .45057 L
s
.43939 .45065 m
.43693 .45023 L
s
.43929 .45064 m
.43684 .45022 L
s
.43903 .45064 m
.43659 .45018 L
s
.43916 .45064 m
.43671 .45021 L
s
.43908 .45064 m
.43664 .45019 L
s
.44734 .45006 m
.44485 .45056 L
s
.4391 .45064 m
.43665 .45018 L
s
.44765 .45001 m
.44518 .45055 L
s
.43887 .45064 m
.43644 .45018 L
s
.35672 .45475 m
.3564 .45413 L
s
.44792 .44997 m
.44545 .45054 L
s
.44785 .44998 m
.44538 .45054 L
s
.43933 .45063 m
.43687 .45021 L
s
.43882 .45064 m
.43639 .45016 L
s
.43903 .45063 m
.43659 .45017 L
s
.44789 .44997 m
.44543 .45054 L
s
.71422 .43948 m
.71416 .43985 L
s
.44761 .45002 m
.44513 .45054 L
s
.44778 .44999 m
.44531 .45054 L
s
.43928 .45063 m
.43682 .4502 L
s
.44789 .44997 m
.44542 .45054 L
s
.48648 .44809 m
.48609 .44899 L
s
.44761 .45001 m
.44513 .45054 L
s
.43898 .45063 m
.43654 .45017 L
s
.44763 .45 m
.44515 .45054 L
s
.43886 .45063 m
.43643 .45015 L
s
.44755 .45001 m
.44508 .45054 L
s
.44763 .45 m
.44515 .45053 L
s
.43901 .45062 m
.43657 .45017 L
s
.43938 .45061 m
.43692 .45019 L
s
.52618 .44494 m
.52598 .44562 L
s
.84999 .29134 m
.85009 .29159 L
s
.43865 .45062 m
.43623 .45013 L
s
.43859 .45062 m
.43617 .45012 L
s
.44783 .44996 m
.44536 .45052 L
s
.44754 .45 m
.44506 .45053 L
s
.39549 .45142 m
.39502 .45062 L
s
.44812 .44992 m
.44567 .45052 L
s
.43868 .45062 m
.43625 .45013 L
s
.44785 .44995 m
.44539 .45052 L
s
.43887 .45061 m
.43644 .45014 L
s
.43916 .45061 m
.43671 .45017 L
s
.44802 .44993 m
.44557 .45052 L
s
.44749 .45001 m
.44501 .45052 L
s
.43894 .45061 m
.4365 .45015 L
s
.44806 .44992 m
.4456 .4505 L
s
.43892 .4506 m
.43648 .45014 L
s
.43848 .45061 m
.43607 .4501 L
s
.43868 .45061 m
.43626 .45012 L
s
.44776 .44996 m
.44529 .45051 L
s
.43904 .45059 m
.43659 .45014 L
s
.43905 .4506 m
.4366 .45015 L
s
.44777 .44995 m
.4453 .45051 L
s
.44832 .44987 m
.44588 .45049 L
s
.44816 .4499 m
.44572 .4505 L
s
.44798 .44992 m
.44553 .4505 L
s
.43885 .4506 m
.43642 .45012 L
s
.43891 .45059 m
.43647 .45013 L
s
.43875 .45059 m
.43633 .45011 L
s
.43842 .4506 m
.43601 .45008 L
s
.3956 .45139 m
.39513 .45058 L
s
.18731 .55071 m
.18712 .55034 L
s
.43904 .45059 m
.4366 .45013 L
s
.44803 .44991 m
.44558 .45049 L
s
.44792 .44992 m
.44546 .45049 L
s
.43869 .45059 m
.43626 .4501 L
s
.43877 .45058 m
.43634 .45009 L
s
.44786 .44993 m
.44539 .45049 L
s
.44828 .44987 m
.44584 .45048 L
s
.43865 .45058 m
.43623 .45009 L
s
.16754 .46008 m
.16742 .45972 L
s
.44796 .44992 m
.4455 .45048 L
s
.44787 .44992 m
.44541 .45048 L
s
.43871 .45058 m
.43628 .4501 L
s
.4479 .44992 m
.44544 .45048 L
s
.43834 .45058 m
.43593 .45005 L
s
.44804 .44989 m
.44559 .45048 L
s
.43823 .45058 m
.43583 .45005 L
s
.43848 .45058 m
.43606 .45008 L
s
.44812 .44988 m
.44566 .45047 L
s
.44807 .44988 m
.44562 .45048 L
s
.44785 .44991 m
.44538 .45047 L
s
.43875 .45057 m
.43632 .45008 L
s
.44798 .4499 m
.44552 .45047 L
s
.44819 .44986 m
.44574 .45047 L
s
.44817 .44986 m
.44573 .45047 L
s
.43864 .45057 m
.43623 .45007 L
s
.44842 .44982 m
.44599 .45046 L
s
.44818 .44987 m
.44573 .45046 L
s
.43861 .45056 m
.43619 .45007 L
s
.43869 .45056 m
.43627 .45006 L
s
.43861 .45056 m
.4362 .45005 L
s
.44823 .44985 m
.44578 .45045 L
s
.44824 .44984 m
.4458 .45045 L
s
.4485 .4498 m
.44608 .45044 L
s
.4482 .44984 m
.44576 .45045 L
s
.43839 .45055 m
.43598 .45003 L
s
.44818 .44984 m
.44574 .45044 L
s
.43851 .45055 m
.4361 .45004 L
s
.44827 .44983 m
.44583 .45045 L
s
.35666 .45467 m
.35634 .45405 L
s
.44829 .44982 m
.44586 .45044 L
s
.43872 .45054 m
.4363 .45005 L
s
.43818 .45054 m
.43579 .45 L
s
.48653 .44799 m
.48615 .4489 L
s
.43834 .45054 m
.43594 .45001 L
s
.43843 .45054 m
.43602 .45002 L
s
.43841 .45054 m
.436 .45003 L
s
.44842 .4498 m
.44599 .45043 L
s
.43846 .45054 m
.43605 .45002 L
s
.39554 .45134 m
.39506 .45053 L
s
.44827 .44982 m
.44583 .45043 L
s
.39551 .45134 m
.39504 .45053 L
s
.44855 .44977 m
.44614 .45042 L
s
.43846 .45053 m
.43605 .45001 L
s
.43821 .45054 m
.43581 .45001 L
s
.2759 .4521 m
.27574 .45162 L
s
.43831 .45054 m
.43591 .45001 L
s
.43871 .45052 m
.43629 .45003 L
s
.43842 .45053 m
.43601 .45001 L
s
.43839 .45052 m
.43599 .45 L
s
.71424 .43938 m
.71418 .43975 L
s
.44841 .44979 m
.44597 .45042 L
s
.44816 .44982 m
.44572 .45042 L
s
.44866 .44975 m
.44625 .45041 L
s
.44826 .4498 m
.44582 .45042 L
s
.43833 .45052 m
.43593 .44999 L
s
.44838 .44978 m
.44596 .45041 L
s
.43806 .45052 m
.43568 .44997 L
s
.44847 .44977 m
.44605 .45041 L
s
.44817 .44981 m
.44572 .45041 L
s
.43802 .45052 m
.43564 .44996 L
s
.44841 .44977 m
.44598 .4504 L
s
.43832 .45051 m
.43593 .44998 L
s
.43834 .45052 m
.43594 .44999 L
s
.43819 .45052 m
.4358 .44998 L
s
.44848 .44976 m
.44605 .45039 L
s
.44854 .44975 m
.44612 .45039 L
s
.43808 .4505 m
.43569 .44995 L
s
.44851 .44975 m
.44609 .45039 L
s
.43815 .4505 m
.43576 .44996 L
s
.44871 .44971 m
.44631 .45039 L
s
.43809 .4505 m
.4357 .44995 L
s
.44853 .44974 m
.44611 .45039 L
s
.44849 .44975 m
.44607 .45039 L
s
.3955 .45129 m
.39504 .45049 L
s
.39545 .4513 m
.39498 .45049 L
s
.43817 .4505 m
.43578 .44996 L
s
.44854 .44972 m
.44613 .45038 L
s
.44848 .44974 m
.44606 .45038 L
s
.43797 .4505 m
.43559 .44994 L
s
.44841 .44974 m
.44599 .45038 L
s
.4384 .45048 m
.43599 .44996 L
s
.44857 .44972 m
.44616 .45037 L
s
.43795 .45049 m
.43558 .44991 L
s
.43812 .45049 m
.43574 .44993 L
s
.43792 .45048 m
.43555 .44991 L
s
.44868 .4497 m
.44627 .45036 L
s
.43801 .45047 m
.43563 .44991 L
s
.43809 .45047 m
.4357 .44992 L
s
.43794 .45048 m
.43556 .44991 L
s
.44875 .44968 m
.44634 .45036 L
s
.4378 .45047 m
.43544 .44989 L
s
.43809 .45047 m
.43571 .44991 L
s
.43818 .45047 m
.43579 .44992 L
s
.44874 .44968 m
.44634 .45035 L
s
.39544 .45127 m
.39497 .45047 L
s
.62325 .44742 m
.62316 .44787 L
s
.43813 .45046 m
.43575 .4499 L
s
.44843 .44973 m
.446 .45036 L
s
.43795 .45047 m
.43557 .44991 L
s
.43789 .45047 m
.43552 .4499 L
s
.43834 .45046 m
.43595 .44993 L
s
.4487 .44968 m
.44629 .45035 L
s
.44874 .44967 m
.44634 .45035 L
s
.44887 .44965 m
.44648 .45034 L
s
.43807 .45046 m
.43569 .44991 L
s
.6233 .44742 m
.6232 .44787 L
s
.44872 .44967 m
.44631 .45034 L
s
.43778 .45046 m
.43542 .44988 L
s
.44867 .44967 m
.44626 .45034 L
s
.44882 .44966 m
.44641 .45034 L
s
.44847 .4497 m
.44605 .45034 L
s
.43771 .45046 m
.43536 .44986 L
s
.39545 .45125 m
.39499 .45044 L
s
.43777 .45045 m
.43541 .44986 L
s
.44876 .44966 m
.44635 .45033 L
s
.44895 .44962 m
.44656 .45033 L
s
.44883 .44965 m
.44643 .45033 L
s
.43775 .45046 m
.43538 .44987 L
s
.43774 .45045 m
.43538 .44986 L
s
.44889 .44963 m
.4465 .45032 L
s
.39542 .45125 m
.39496 .45044 L
s
.44891 .44962 m
.44652 .45032 L
s
.43754 .45045 m
.43519 .44985 L
s
.35663 .45456 m
.35631 .45394 L
s
.43759 .45045 m
.43524 .44984 L
s
.43807 .45044 m
.43569 .44988 L
s
.35668 .45456 m
.35636 .45394 L
s
.4489 .44963 m
.4465 .45031 L
s
.4488 .44964 m
.4464 .45031 L
s
.44875 .44964 m
.44636 .45032 L
s
.48656 .44788 m
.48618 .44879 L
s
.449 .44959 m
.44661 .4503 L
s
.43772 .45043 m
.43537 .44984 L
s
.44914 .44957 m
.44677 .4503 L
s
.43767 .45043 m
.43532 .44984 L
s
.44907 .44959 m
.44668 .4503 L
s
.44892 .44961 m
.44653 .4503 L
s
.43789 .45042 m
.43552 .44984 L
s
.43782 .45042 m
.43546 .44983 L
s
.44908 .44958 m
.44669 .45029 L
s
.43754 .45042 m
.4352 .4498 L
s
.43776 .45041 m
.4354 .44983 L
s
.43785 .45041 m
.43549 .44982 L
s
.43746 .45041 m
.43513 .44979 L
s
.44877 .44961 m
.44636 .45029 L
s
.4378 .45041 m
.43543 .44982 L
s
.44877 .44961 m
.44637 .45028 L
s
.48664 .44785 m
.48626 .44876 L
s
.44911 .44955 m
.44674 .45027 L
s
.4491 .44955 m
.44672 .45027 L
s
.44895 .44958 m
.44657 .45028 L
s
.44911 .44955 m
.44673 .45027 L
s
.4375 .4504 m
.43515 .44979 L
s
.44916 .44954 m
.44679 .45027 L
s
.43751 .4504 m
.43517 .44978 L
s
.44914 .44955 m
.44676 .45027 L
s
.48664 .44784 m
.48627 .44875 L
s
.43755 .4504 m
.4352 .44979 L
s
.44902 .44955 m
.44664 .45027 L
s
.43767 .4504 m
.43532 .4498 L
s
.44895 .44956 m
.44656 .45026 L
s
.43775 .45039 m
.4354 .44979 L
s
.43774 .45038 m
.43538 .44979 L
s
.43733 .45039 m
.43501 .44975 L
s
.44904 .44954 m
.44666 .45025 L
s
.5263 .44469 m
.5261 .44536 L
s
.27582 .45195 m
.27566 .45147 L
s
.43731 .45039 m
.43498 .44976 L
s
.43736 .45039 m
.43503 .44976 L
s
.44896 .44954 m
.44658 .45025 L
s
.39538 .45118 m
.39492 .45037 L
s
.43744 .45037 m
.4351 .44975 L
s
.43739 .45038 m
.43505 .44976 L
s
.43766 .45038 m
.43532 .44977 L
s
.44929 .4495 m
.44693 .45024 L
s
.44927 .4495 m
.4469 .45024 L
s
.39541 .45117 m
.39495 .45036 L
s
.35654 .45448 m
.35622 .45387 L
s
.44926 .44949 m
.4469 .45023 L
s
.8499 .29109 m
.84999 .29134 L
s
.48662 .44781 m
.48625 .44872 L
s
.44931 .44948 m
.44696 .45023 L
s
.44907 .44952 m
.44669 .45023 L
s
.43752 .45036 m
.43518 .44974 L
s
.44907 .44952 m
.44669 .45023 L
s
.43751 .45036 m
.43517 .44974 L
s
.43731 .45036 m
.43498 .44972 L
s
.44907 .44951 m
.44669 .45022 L
s
.43741 .45035 m
.43508 .44973 L
s
.43725 .45036 m
.43492 .44972 L
s
.4375 .45035 m
.43516 .44973 L
s
.5263 .44466 m
.52611 .44533 L
s
.44939 .44946 m
.44703 .45021 L
s
.43753 .45034 m
.43519 .44972 L
s
.44928 .44947 m
.44692 .45021 L
s
.44936 .44946 m
.44701 .45021 L
s
.43745 .45035 m
.43512 .44973 L
s
.44917 .44948 m
.4468 .45021 L
s
.4494 .44945 m
.44704 .4502 L
s
.43743 .45034 m
.4351 .44972 L
s
.43708 .45035 m
.43476 .44969 L
s
.43737 .45034 m
.43504 .4497 L
s
.43719 .45034 m
.43488 .44968 L
s
.44939 .44943 m
.44705 .45019 L
s
.44917 .44947 m
.4468 .4502 L
s
.43722 .45034 m
.4349 .4497 L
s
.43717 .45033 m
.43486 .44968 L
s
.44934 .44943 m
.44698 .45018 L
s
.52638 .44462 m
.52618 .4453 L
s
.44931 .44944 m
.44695 .45018 L
s
.44948 .4494 m
.44714 .45018 L
s
.44928 .44944 m
.44692 .45018 L
s
.43713 .45032 m
.43482 .44966 L
s
.43719 .45031 m
.43488 .44966 L
s
.43721 .45032 m
.43489 .44966 L
s
.44932 .44943 m
.44697 .45018 L
s
.43703 .45032 m
.43472 .44965 L
s
.44953 .4494 m
.44719 .45017 L
s
.44946 .44941 m
.44711 .45017 L
s
.43713 .45031 m
.43481 .44966 L
s
.43716 .45031 m
.43485 .44966 L
s
.43721 .45031 m
.4349 .44967 L
s
.44952 .44938 m
.44719 .45016 L
s
.43738 .4503 m
.43505 .44967 L
s
.39541 .4511 m
.39495 .4503 L
s
.52627 .44461 m
.52608 .44529 L
s
.39544 .4511 m
.39498 .45029 L
s
.3566 .45442 m
.35628 .4538 L
s
.44957 .44938 m
.44723 .45016 L
s
.43714 .4503 m
.43483 .44963 L
s
.16748 .45979 m
.16737 .45944 L
s
.44933 .44941 m
.44697 .45016 L
s
.43708 .4503 m
.43477 .44963 L
s
.43695 .4503 m
.43465 .44963 L
s
.44943 .44939 m
.44709 .45015 L
s
.43685 .4503 m
.43456 .44962 L
s
.44937 .44939 m
.44702 .45015 L
s
.35666 .45441 m
.35635 .45379 L
s
.44961 .44936 m
.44728 .45014 L
s
.43699 .45029 m
.43469 .44962 L
s
.44938 .44939 m
.44703 .45014 L
s
.4496 .44936 m
.44726 .45013 L
s
.44964 .44934 m
.44731 .45013 L
s
.62344 .44723 m
.62334 .44767 L
s
.43712 .45028 m
.43481 .44962 L
s
.43713 .45028 m
.43482 .44962 L
s
.43701 .45028 m
.43471 .44961 L
s
.43667 .45028 m
.43439 .44958 L
s
.43723 .45027 m
.43492 .44962 L
s
.48667 .44771 m
.4863 .44862 L
s
.43693 .45027 m
.43464 .44959 L
s
.44976 .44932 m
.44744 .45012 L
s
.44974 .44932 m
.44742 .45012 L
s
.44964 .44933 m
.44731 .45012 L
s
.43721 .45026 m
.4349 .4496 L
s
.71427 .43911 m
.71422 .43948 L
s
.62331 .44721 m
.62321 .44766 L
s
.39534 .45106 m
.39489 .45025 L
s
.44965 .44933 m
.44732 .45011 L
s
.43691 .45026 m
.43462 .44957 L
s
.3565 .45437 m
.35619 .45375 L
s
.4369 .45026 m
.43461 .44958 L
s
.4496 .44933 m
.44727 .45011 L
s
.44957 .44933 m
.44723 .45011 L
s
.4368 .45026 m
.43451 .44957 L
s
.5263 .44456 m
.5261 .44523 L
s
.44957 .44932 m
.44724 .45011 L
s
.44973 .44929 m
.44742 .4501 L
s
.43679 .45025 m
.43451 .44956 L
s
.44968 .4493 m
.44736 .4501 L
s
.44989 .44928 m
.44758 .45009 L
s
.39538 .45104 m
.39492 .45023 L
s
.43687 .45024 m
.43458 .44956 L
s
.44964 .4493 m
.44732 .45009 L
s
.44964 .4493 m
.44732 .45009 L
s
.43683 .45024 m
.43454 .44956 L
s
.44956 .44931 m
.44723 .45009 L
s
.43683 .45024 m
.43455 .44954 L
s
.39533 .45103 m
.39487 .45023 L
s
.44966 .4493 m
.44732 .45008 L
s
.43686 .45023 m
.43457 .44955 L
s
.43693 .45023 m
.43463 .44956 L
s
.4367 .45023 m
.43443 .44953 L
s
.44977 .44926 m
.44746 .45008 L
s
.16742 .45972 m
.1673 .45936 L
s
.43664 .45022 m
.43437 .44952 L
s
.44987 .44925 m
.44756 .45006 L
s
.43684 .45022 m
.43455 .44953 L
s
.44995 .44924 m
.44765 .45006 L
s
.44967 .44928 m
.44734 .45006 L
s
.43687 .45021 m
.43459 .44953 L
s
.44978 .44925 m
.44747 .45006 L
s
.39531 .45101 m
.39485 .4502 L
s
.44983 .44924 m
.44752 .45006 L
s
.44993 .44923 m
.44763 .45005 L
s
.43671 .45021 m
.43443 .44952 L
s
.44999 .44921 m
.4477 .45005 L
s
.43662 .45021 m
.43436 .4495 L
s
.43651 .4502 m
.43425 .44949 L
s
.43682 .4502 m
.43454 .44951 L
s
.44981 .44923 m
.4475 .45005 L
s
.43692 .45019 m
.43464 .44951 L
s
.52633 .4445 m
.52614 .44518 L
s
.43647 .4502 m
.43421 .44948 L
s
.44993 .4492 m
.44764 .45004 L
s
.18712 .55034 m
.18693 .54997 L
s
.44991 .44921 m
.44761 .45004 L
s
.52633 .4445 m
.52614 .44517 L
s
.43664 .45019 m
.43438 .44948 L
s
.43665 .45018 m
.43439 .44947 L
s
.27588 .45175 m
.27573 .45127 L
s
.45011 .44918 m
.44782 .45002 L
s
.43659 .45018 m
.43433 .44946 L
s
.48671 .44761 m
.48634 .44852 L
s
.44992 .4492 m
.44761 .45002 L
s
.43659 .45017 m
.43433 .44945 L
s
.43671 .45017 m
.43443 .44947 L
s
.43654 .45017 m
.43427 .44945 L
s
.43644 .45018 m
.43418 .44945 L
s
.44994 .44918 m
.44765 .45001 L
s
.43657 .45017 m
.43431 .44945 L
s
.44986 .44919 m
.44755 .45001 L
s
.44991 .44918 m
.44761 .45001 L
s
.44994 .44918 m
.44763 .45 L
s
.4498 .4492 m
.44749 .45001 L
s
.44993 .44918 m
.44763 .45 L
s
.43639 .45016 m
.43414 .44943 L
s
.71429 .43901 m
.71424 .43938 L
s
.44985 .44918 m
.44754 .45 L
s
.48668 .44759 m
.48631 .4485 L
s
.43643 .45015 m
.43418 .44942 L
s
.45007 .44914 m
.44778 .44999 L
s
.45012 .44913 m
.44785 .44998 L
s
.4366 .45015 m
.43434 .44943 L
s
.4365 .45015 m
.43424 .44943 L
s
.39526 .45094 m
.39481 .45013 L
s
.43659 .45014 m
.43433 .44942 L
s
.43644 .45014 m
.43419 .44941 L
s
.48676 .44757 m
.4864 .44848 L
s
.45017 .44912 m
.44789 .44997 L
s
.45019 .44911 m
.44792 .44997 L
s
.45016 .44912 m
.44789 .44997 L
s
.43648 .45014 m
.43423 .44941 L
s
.4366 .45013 m
.43434 .44941 L
s
.43647 .45013 m
.43421 .4494 L
s
.43625 .45013 m
.43402 .44938 L
s
.43623 .45013 m
.43399 .44938 L
s
.4501 .44911 m
.44783 .44996 L
s
.45005 .44912 m
.44776 .44996 L
s
.43642 .45012 m
.43418 .44938 L
s
.43617 .45012 m
.43395 .44936 L
s
.48674 .44755 m
.48638 .44846 L
s
.48673 .44755 m
.48637 .44846 L
s
.45005 .44911 m
.44777 .44995 L
s
.45012 .44909 m
.44785 .44995 L
s
.43626 .45012 m
.43402 .44937 L
s
.52639 .44441 m
.5262 .44508 L
s
.8498 .29084 m
.8499 .29109 L
s
.35644 .45423 m
.35613 .45361 L
s
.43633 .45011 m
.43409 .44936 L
s
.48675 .44754 m
.48639 .44845 L
s
.45029 .44906 m
.44802 .44993 L
s
.4867 .44754 m
.48635 .44845 L
s
.43634 .45009 m
.43411 .44935 L
s
.45014 .44908 m
.44786 .44993 L
s
.43626 .4501 m
.43403 .44935 L
s
.43628 .4501 m
.43404 .44936 L
s
.43607 .4501 m
.43385 .44934 L
s
.43623 .45009 m
.43399 .44934 L
s
.45037 .44904 m
.44812 .44992 L
s
.4502 .44907 m
.44792 .44992 L
s
.45032 .44904 m
.44806 .44992 L
s
.45024 .44905 m
.44798 .44992 L
s
.45024 .44906 m
.44796 .44992 L
s
.43632 .45008 m
.43409 .44934 L
s
.45014 .44906 m
.44787 .44992 L
s
.45017 .44906 m
.4479 .44992 L
s
.45013 .44906 m
.44785 .44991 L
s
.43601 .45008 m
.4338 .44931 L
s
.39528 .45087 m
.39483 .45006 L
s
.45029 .44903 m
.44803 .44991 L
s
.43606 .45008 m
.43384 .44932 L
s
.45041 .44901 m
.44816 .4499 L
s
.43623 .45007 m
.434 .44932 L
s
.45025 .44903 m
.44798 .4499 L
s
.43627 .45006 m
.43404 .44931 L
s
.43619 .45007 m
.43397 .44931 L
s
.27574 .45162 m
.27559 .45114 L
s
.48672 .44749 m
.48636 .4484 L
s
.4503 .44901 m
.44804 .44989 L
s
.4363 .45005 m
.43406 .44931 L
s
.4362 .45005 m
.43398 .44929 L
s
.45037 .449 m
.44812 .44988 L
s
.45055 .44896 m
.44832 .44987 L
s
.43593 .45005 m
.43373 .44927 L
s
.45031 .44899 m
.44807 .44988 L
s
.45052 .44897 m
.44828 .44987 L
s
.35636 .45416 m
.35606 .45354 L
s
.45043 .44898 m
.44818 .44987 L
s
.43583 .45005 m
.43364 .44925 L
s
.4361 .45004 m
.43388 .44927 L
s
.45044 .44897 m
.44819 .44986 L
s
.45042 .44897 m
.44817 .44986 L
s
.43629 .45003 m
.43406 .44928 L
s
.62335 .44697 m
.62325 .44742 L
s
.43598 .45003 m
.43377 .44925 L
s
.45048 .44896 m
.44823 .44985 L
s
.3952 .45083 m
.39475 .45002 L
s
.436 .45003 m
.43379 .44926 L
s
.6234 .44697 m
.6233 .44742 L
s
.43602 .45002 m
.43381 .44925 L
s
.43605 .45002 m
.43384 .44924 L
s
.45048 .44895 m
.44824 .44984 L
s
.48674 .44745 m
.48639 .44836 L
s
.45043 .44895 m
.44818 .44984 L
s
.45045 .44895 m
.4482 .44984 L
s
.43605 .45001 m
.43385 .44923 L
s
.43594 .45001 m
.43374 .44923 L
s
.3564 .45413 m
.35609 .45351 L
s
.52639 .44431 m
.52621 .44499 L
s
.43601 .45001 m
.43381 .44923 L
s
.4505 .44893 m
.44827 .44983 L
s
.43591 .45001 m
.43371 .44923 L
s
.45064 .4489 m
.44842 .44982 L
s
.43599 .45 m
.43378 .44922 L
s
.45051 .44893 m
.44827 .44982 L
s
.43581 .45001 m
.43361 .44922 L
s
.43579 .45 m
.43361 .4492 L
s
.43593 .44999 m
.43372 .4492 L
s
.45051 .4489 m
.44829 .44982 L
s
.43594 .44999 m
.43373 .44921 L
s
.4504 .44892 m
.44816 .44982 L
s
.39516 .45079 m
.39472 .44998 L
s
.45041 .44892 m
.44817 .44981 L
s
.45071 .44887 m
.4485 .4498 L
s
.45065 .44888 m
.44842 .4498 L
s
.43593 .44998 m
.43374 .44919 L
s
.45048 .44889 m
.44826 .4498 L
s
.45063 .44888 m
.44841 .44979 L
s
.4358 .44998 m
.43362 .44918 L
s
.43568 .44997 m
.4335 .44916 L
s
.52636 .44427 m
.52618 .44494 L
s
.43599 .44996 m
.43379 .44918 L
s
.4506 .44886 m
.44838 .44978 L
s
.43564 .44996 m
.43347 .44915 L
s
.43578 .44996 m
.43359 .44916 L
s
.45075 .44883 m
.44855 .44977 L
s
.45063 .44885 m
.44841 .44977 L
s
.43576 .44996 m
.43358 .44915 L
s
.48678 .44738 m
.48643 .44829 L
s
.45068 .44884 m
.44847 .44977 L
s
.43569 .44995 m
.43351 .44914 L
s
.4357 .44995 m
.43352 .44914 L
s
.39512 .45074 m
.39468 .44993 L
s
.4507 .44883 m
.44848 .44976 L
s
.45076 .44882 m
.44854 .44975 L
s
.45086 .4488 m
.44866 .44975 L
s
.43595 .44993 m
.43375 .44914 L
s
.4507 .44882 m
.44849 .44975 L
s
.43574 .44993 m
.43356 .44913 L
s
.43559 .44994 m
.43342 .44913 L
s
.16737 .45944 m
.16725 .45908 L
s
.45072 .44881 m
.44851 .44975 L
s
.45074 .44881 m
.44853 .44974 L
s
.4357 .44992 m
.43353 .44911 L
s
.43579 .44992 m
.43361 .44911 L
s
.45063 .44881 m
.44841 .44974 L
s
.45069 .4488 m
.44848 .44974 L
s
.35634 .45405 m
.35604 .45343 L
s
.43558 .44991 m
.43342 .44909 L
s
.39508 .45072 m
.39464 .44991 L
s
.43563 .44991 m
.43346 .44909 L
s
.43571 .44991 m
.43354 .4491 L
s
.43575 .4499 m
.43358 .44909 L
s
.43569 .44991 m
.43351 .44911 L
s
.45065 .44881 m
.44843 .44973 L
s
.43556 .44991 m
.4334 .44909 L
s
.45073 .44878 m
.44854 .44972 L
s
.43555 .44991 m
.43339 .44908 L
s
.27566 .45147 m
.27551 .45099 L
s
.45077 .44878 m
.44857 .44972 L
s
.43557 .44991 m
.43341 .44909 L
s
.4509 .44876 m
.44871 .44971 L
s
.48674 .44733 m
.48639 .44824 L
s
.43552 .4499 m
.43336 .44908 L
s
.43544 .44989 m
.43329 .44905 L
s
.45088 .44875 m
.44868 .4497 L
s
.71433 .43874 m
.71427 .43911 L
s
.45068 .44878 m
.44847 .4497 L
s
.43569 .44988 m
.43352 .44907 L
s
.39506 .45069 m
.39462 .44988 L
s
.43542 .44988 m
.43327 .44904 L
s
.45089 .44873 m
.4487 .44968 L
s
.48679 .4473 m
.48645 .44821 L
s
.45092 .44872 m
.44874 .44968 L
s
.45092 .44871 m
.44875 .44968 L
s
.48677 .4473 m
.48643 .44821 L
s
.43541 .44986 m
.43326 .44902 L
s
.43538 .44987 m
.43323 .44904 L
s
.45092 .44871 m
.44874 .44967 L
s
.45086 .44872 m
.44867 .44967 L
s
.4868 .44729 m
.48646 .4482 L
s
.43538 .44986 m
.43324 .44902 L
s
.43536 .44986 m
.43322 .44901 L
s
.39509 .45066 m
.39465 .44985 L
s
.4509 .44871 m
.44872 .44967 L
s
.45095 .44871 m
.44876 .44966 L
s
.45099 .44869 m
.44882 .44966 L
s
.1673 .45936 m
.16719 .45901 L
s
.8497 .29059 m
.8498 .29084 L
s
.45101 .44869 m
.44883 .44965 L
s
.45104 .44867 m
.44887 .44965 L
s
.43552 .44984 m
.43337 .44901 L
s
.43519 .44985 m
.43306 .449 L
s
.43537 .44984 m
.43322 .449 L
s
.43524 .44984 m
.43311 .44899 L
s
.62353 .44678 m
.62344 .44723 L
s
.48681 .44726 m
.48646 .44818 L
s
.43532 .44984 m
.43318 .44899 L
s
.43546 .44983 m
.43331 .44899 L
s
.45098 .44867 m
.4488 .44964 L
s
.45093 .44867 m
.44875 .44964 L
s
.45106 .44865 m
.44889 .44963 L
s
.4354 .44983 m
.43325 .44899 L
s
.43549 .44982 m
.43335 .44898 L
s
.45107 .44866 m
.4489 .44963 L
s
.43543 .44982 m
.43329 .44898 L
s
.4511 .44864 m
.44895 .44962 L
s
.6234 .44676 m
.62331 .44721 L
s
.45107 .44864 m
.44891 .44962 L
s
.35631 .45394 m
.356 .45332 L
s
.39502 .45062 m
.39458 .44981 L
s
.45095 .44866 m
.44877 .44961 L
s
.35636 .45394 m
.35606 .45332 L
s
.45108 .44863 m
.44892 .44961 L
s
.48687 .44723 m
.48653 .44814 L
s
.4352 .4498 m
.43308 .44894 L
s
.45095 .44864 m
.44877 .44961 L
s
.4354 .44979 m
.43326 .44895 L
s
.43532 .4498 m
.43318 .44895 L
s
.48681 .44722 m
.48647 .44813 L
s
.45122 .4486 m
.44907 .44959 L
s
.43538 .44979 m
.43324 .44895 L
s
.45115 .4486 m
.449 .44959 L
s
.18693 .54997 m
.18674 .5496 L
s
.43513 .44979 m
.43301 .44891 L
s
.4352 .44979 m
.43308 .44893 L
s
.43515 .44979 m
.43303 .44893 L
s
.39513 .45058 m
.39469 .44977 L
s
.43517 .44978 m
.43305 .44891 L
s
.48685 .44721 m
.48651 .44812 L
s
.45123 .44859 m
.44908 .44958 L
s
.71435 .43864 m
.71429 .43901 L
s
.45127 .44856 m
.44914 .44957 L
s
.43532 .44977 m
.43319 .44892 L
s
.45111 .44859 m
.44895 .44958 L
s
.45111 .44858 m
.44895 .44956 L
s
.43505 .44976 m
.43294 .44889 L
s
.45125 .44856 m
.44911 .44955 L
s
.45124 .44855 m
.4491 .44955 L
s
.43503 .44976 m
.43292 .44889 L
s
.45128 .44855 m
.44914 .44955 L
s
.45124 .44854 m
.44911 .44955 L
s
.45117 .44856 m
.44902 .44955 L
s
.4351 .44975 m
.43299 .44887 L
s
.43498 .44976 m
.43287 .44888 L
s
.43501 .44975 m
.43291 .44887 L
s
.48681 .44717 m
.48648 .44809 L
s
.43518 .44974 m
.43306 .44888 L
s
.4513 .44853 m
.44916 .44954 L
s
.43517 .44974 m
.43305 .44888 L
s
.45111 .44855 m
.44896 .44954 L
s
.45119 .44854 m
.44904 .44954 L
s
.35622 .45387 m
.35592 .45324 L
s
.43516 .44973 m
.43305 .44886 L
s
.39506 .45053 m
.39463 .44972 L
s
.43519 .44972 m
.43307 .44886 L
s
.39504 .45053 m
.39461 .44972 L
s
.43508 .44973 m
.43298 .44885 L
s
.45121 .44853 m
.44907 .44952 L
s
.43512 .44973 m
.43301 .44886 L
s
.4351 .44972 m
.43298 .44885 L
s
.45122 .44852 m
.44907 .44952 L
s
.52648 .44401 m
.5263 .44469 L
s
.43498 .44972 m
.43289 .44883 L
s
.43492 .44972 m
.43282 .44883 L
s
.45142 .44849 m
.44929 .4495 L
s
.45121 .44851 m
.44907 .44951 L
s
.45139 .44848 m
.44927 .4495 L
s
.27573 .45127 m
.27558 .45078 L
s
.43504 .4497 m
.43294 .44882 L
s
.45137 .44846 m
.44926 .44949 L
s
.39504 .45049 m
.39461 .44968 L
s
.4349 .4497 m
.43281 .44881 L
s
.45142 .44844 m
.44931 .44948 L
s
.43488 .44968 m
.43279 .44879 L
s
.52648 .44398 m
.5263 .44466 L
s
.39498 .45049 m
.39455 .44968 L
s
.43476 .44969 m
.43268 .44879 L
s
.45129 .44846 m
.44917 .44948 L
s
.43486 .44968 m
.43278 .44878 L
s
.45139 .44844 m
.44928 .44947 L
s
.43505 .44967 m
.43295 .44879 L
s
.45129 .44846 m
.44917 .44947 L
s
.4515 .44843 m
.44939 .44946 L
s
.45147 .44843 m
.44936 .44946 L
s
.35628 .4538 m
.35598 .45318 L
s
.43489 .44966 m
.43281 .44877 L
s
.43488 .44966 m
.43279 .44876 L
s
.4349 .44967 m
.43281 .44877 L
s
.43481 .44966 m
.43273 .44877 L
s
.39497 .45047 m
.39455 .44966 L
s
.45151 .44841 m
.4494 .44945 L
s
.43485 .44966 m
.43277 .44877 L
s
.43482 .44966 m
.43275 .44876 L
s
.52656 .44395 m
.52638 .44462 L
s
.48686 .44708 m
.48653 .44799 L
s
.43472 .44965 m
.43265 .44875 L
s
.35635 .45379 m
.35604 .45317 L
s
.45142 .44841 m
.44931 .44944 L
s
.4514 .44841 m
.44928 .44944 L
s
.39499 .45044 m
.39456 .44963 L
s
.45145 .4484 m
.44934 .44943 L
s
.45148 .44838 m
.44939 .44943 L
s
.43483 .44963 m
.43275 .44873 L
s
.52644 .44394 m
.52627 .44461 L
s
.45143 .4484 m
.44932 .44943 L
s
.39496 .45044 m
.39453 .44963 L
s
.43477 .44963 m
.43271 .44872 L
s
.43465 .44963 m
.43259 .44872 L
s
.43481 .44962 m
.43273 .44872 L
s
.35619 .45375 m
.35589 .45313 L
s
.43492 .44962 m
.43284 .44872 L
s
.45156 .44836 m
.44946 .44941 L
s
.45143 .44838 m
.44933 .44941 L
s
.43469 .44962 m
.43263 .44871 L
s
.43482 .44962 m
.43275 .44871 L
s
.45156 .44835 m
.44948 .4494 L
s
.45162 .44835 m
.44953 .4494 L
s
.43456 .44962 m
.43251 .44869 L
s
.4349 .4496 m
.43283 .4487 L
s
.43471 .44961 m
.43265 .44869 L
s
.45147 .44836 m
.44937 .44939 L
s
.45149 .44836 m
.44938 .44939 L
s
.45165 .44833 m
.44957 .44938 L
s
.4516 .44832 m
.44952 .44938 L
s
.45152 .44834 m
.44943 .44939 L
s
.43464 .44959 m
.43259 .44867 L
s
.8496 .29035 m
.8497 .29059 L
s
.62344 .44652 m
.62335 .44697 L
s
.52647 .44388 m
.5263 .44456 L
s
.27559 .45114 m
.27544 .45066 L
s
.43462 .44957 m
.43257 .44865 L
s
.43461 .44958 m
.43256 .44865 L
s
.62349 .44652 m
.6234 .44697 L
s
.43439 .44958 m
.43236 .44864 L
s
.45169 .4483 m
.44961 .44936 L
s
.45168 .4483 m
.4496 .44936 L
s
.43451 .44957 m
.43247 .44864 L
s
.39492 .45037 m
.3945 .44956 L
s
.43458 .44956 m
.43253 .44864 L
s
.45171 .44828 m
.44964 .44934 L
s
.43451 .44956 m
.43247 .44862 L
s
.39495 .45036 m
.39453 .44955 L
s
.16725 .45908 m
.16714 .45872 L
s
.43463 .44956 m
.43258 .44864 L
s
.43454 .44956 m
.4325 .44863 L
s
.45172 .44827 m
.44964 .44933 L
s
.45165 .44828 m
.44957 .44933 L
s
.43457 .44955 m
.43252 .44862 L
s
.45173 .44826 m
.44965 .44933 L
s
.4518 .44825 m
.44974 .44932 L
s
.43455 .44954 m
.43251 .4486 L
s
.45167 .44826 m
.4496 .44933 L
s
.48689 .44697 m
.48656 .44788 L
s
.45181 .44824 m
.44976 .44932 L
s
.45164 .44825 m
.44957 .44932 L
s
.43455 .44953 m
.4325 .4486 L
s
.43459 .44953 m
.43254 .4486 L
s
.5265 .44383 m
.52633 .4445 L
s
.43443 .44953 m
.4324 .44859 L
s
.45164 .44824 m
.44956 .44931 L
s
.5265 .44382 m
.52633 .4445 L
s
.45174 .44822 m
.44968 .4493 L
s
.45171 .44823 m
.44964 .4493 L
s
.45173 .44824 m
.44966 .4493 L
s
.4517 .44822 m
.44964 .4493 L
s
.43437 .44952 m
.43234 .44857 L
s
.43464 .44951 m
.43259 .44858 L
s
.45178 .44821 m
.44973 .44929 L
s
.48696 .44693 m
.48664 .44785 L
s
.43443 .44952 m
.4324 .44858 L
s
.43454 .44951 m
.4325 .44857 L
s
.71438 .43837 m
.71433 .43874 L
s
.45193 .44818 m
.44989 .44928 L
s
.48697 .44692 m
.48664 .44784 L
s
.43436 .4495 m
.43233 .44855 L
s
.45174 .44821 m
.44967 .44928 L
s
.39495 .4503 m
.39453 .44948 L
s
.39498 .45029 m
.39457 .44947 L
s
.43425 .44949 m
.43224 .44853 L
s
.45181 .44817 m
.44977 .44926 L
s
.16719 .45901 m
.16707 .45865 L
s
.43438 .44948 m
.43236 .44853 L
s
.43421 .44948 m
.43221 .44852 L
s
.45183 .44817 m
.44978 .44925 L
s
.43439 .44947 m
.43237 .44852 L
s
.45191 .44815 m
.44987 .44925 L
s
.48694 .44689 m
.48662 .44781 L
s
.43443 .44947 m
.4324 .44853 L
s
.35613 .45361 m
.35583 .45299 L
s
.45188 .44816 m
.44983 .44924 L
s
.43433 .44946 m
.43233 .4485 L
s
.45198 .44813 m
.44995 .44924 L
s
.43433 .44945 m
.43232 .44849 L
s
.43427 .44945 m
.43226 .4485 L
s
.45197 .44813 m
.44993 .44923 L
s
.43431 .44945 m
.43229 .4485 L
s
.45184 .44813 m
.44981 .44923 L
s
.43418 .44945 m
.43218 .44848 L
s
.39489 .45025 m
.39447 .44944 L
s
.45201 .4481 m
.44999 .44921 L
s
.52657 .44373 m
.52639 .44441 L
s
.43434 .44943 m
.43232 .44848 L
s
.45193 .4481 m
.44991 .44921 L
s
.43414 .44943 m
.43214 .44846 L
s
.43424 .44943 m
.43223 .44848 L
s
.43433 .44942 m
.43232 .44847 L
s
.45194 .44809 m
.44993 .4492 L
s
.39492 .45023 m
.39451 .44941 L
s
.45196 .4481 m
.44992 .4492 L
s
.27551 .45099 m
.27536 .45051 L
s
.43418 .44942 m
.43219 .44845 L
s
.45185 .44811 m
.4498 .4492 L
s
.39487 .45023 m
.39446 .44941 L
s
.45189 .4481 m
.44986 .44919 L
s
.43434 .44941 m
.43232 .44845 L
s
.43419 .44941 m
.43219 .44844 L
s
.43423 .44941 m
.43223 .44845 L
s
.45194 .44808 m
.44991 .44918 L
s
.45212 .44806 m
.45011 .44918 L
s
.45197 .44808 m
.44994 .44918 L
s
.45196 .44807 m
.44994 .44918 L
s
.45196 .44808 m
.44993 .44918 L
s
.45188 .44808 m
.44985 .44918 L
s
.43421 .4494 m
.43221 .44844 L
s
.35606 .45354 m
.35576 .45291 L
s
.7144 .43827 m
.71435 .43864 L
s
.39485 .4502 m
.39444 .44938 L
s
.62362 .44633 m
.62353 .44678 L
s
.43402 .44938 m
.43203 .4484 L
s
.43418 .44938 m
.43219 .44841 L
s
.43399 .44938 m
.43202 .4484 L
s
.18674 .5496 m
.18656 .54922 L
s
.48699 .44679 m
.48667 .44771 L
s
.62349 .44631 m
.6234 .44676 L
s
.45207 .44802 m
.45007 .44914 L
s
.43402 .44937 m
.43204 .44839 L
s
.35609 .45351 m
.35579 .45289 L
s
.43409 .44936 m
.43211 .44838 L
s
.45212 .44801 m
.45012 .44913 L
s
.43395 .44936 m
.43198 .44837 L
s
.43404 .44936 m
.43206 .44838 L
s
.43411 .44935 m
.43212 .44837 L
s
.45206 .44801 m
.45005 .44912 L
s
.45216 .44799 m
.45017 .44912 L
s
.45216 .44798 m
.45016 .44912 L
s
.43403 .44935 m
.43206 .44836 L
s
.43399 .44934 m
.43202 .44836 L
s
.45218 .44798 m
.45019 .44911 L
s
.4521 .44798 m
.4501 .44911 L
s
.45205 .44799 m
.45005 .44911 L
s
.43409 .44934 m
.43211 .44835 L
s
.52656 .44363 m
.52639 .44431 L
s
.43385 .44934 m
.43189 .44834 L
s
.84951 .2901 m
.8496 .29035 L
s
.4521 .44796 m
.45012 .44909 L
s
.39481 .45013 m
.3944 .44932 L
s
.45214 .44796 m
.45014 .44908 L
s
.434 .44932 m
.43203 .44833 L
s
.43404 .44931 m
.43207 .44832 L
s
.43397 .44931 m
.432 .44832 L
s
.43384 .44932 m
.43188 .44832 L
s
.43406 .44931 m
.43208 .44833 L
s
.4338 .44931 m
.43186 .4483 L
s
.45226 .44792 m
.45029 .44906 L
s
.45219 .44793 m
.4502 .44907 L
s
.43398 .44929 m
.43202 .4483 L
s
.45212 .44793 m
.45013 .44906 L
s
.45223 .44792 m
.45024 .44906 L
s
.45216 .44793 m
.45017 .44906 L
s
.45213 .44793 m
.45014 .44906 L
s
.52653 .44359 m
.52636 .44427 L
s
.45221 .4479 m
.45024 .44905 L
s
.43406 .44928 m
.43208 .44829 L
s
.45229 .4479 m
.45032 .44904 L
s
.45233 .44788 m
.45037 .44904 L
s
.48702 .4467 m
.48671 .44761 L
s
.35604 .45343 m
.35574 .45281 L
s
.43388 .44927 m
.43193 .44827 L
s
.45223 .4479 m
.45025 .44903 L
s
.43373 .44927 m
.43179 .44825 L
s
.45225 .44788 m
.45029 .44903 L
s
.43377 .44925 m
.43183 .44824 L
s
.43379 .44926 m
.43184 .44825 L
s
.39483 .45006 m
.39443 .44925 L
s
.43364 .44925 m
.43172 .44823 L
s
.48699 .44667 m
.48668 .44759 L
s
.43381 .44925 m
.43187 .44824 L
s
.43384 .44924 m
.4319 .44824 L
s
.45237 .44784 m
.45041 .44901 L
s
.45226 .44786 m
.4503 .44901 L
s
.48707 .44666 m
.48676 .44757 L
s
.45233 .44784 m
.45037 .449 L
s
.43385 .44923 m
.43191 .44822 L
s
.43381 .44923 m
.43187 .44822 L
s
.45227 .44783 m
.45031 .44899 L
s
.43374 .44923 m
.43181 .44821 L
s
.43378 .44922 m
.43184 .44821 L
s
.43371 .44923 m
.43177 .44821 L
s
.45239 .44782 m
.45043 .44898 L
s
.27558 .45078 m
.27543 .4503 L
s
.43373 .44921 m
.43179 .4482 L
s
.48704 .44663 m
.48673 .44755 L
s
.48705 .44663 m
.48674 .44755 L
s
.45239 .44781 m
.45044 .44897 L
s
.45237 .4478 m
.45042 .44897 L
s
.43361 .44922 m
.43168 .4482 L
s
.45248 .44778 m
.45055 .44896 L
s
.45246 .44779 m
.45052 .44897 L
s
.43372 .4492 m
.43179 .44819 L
s
.45244 .4478 m
.45048 .44896 L
s
.48706 .44662 m
.48675 .44754 L
s
.43361 .4492 m
.43169 .44817 L
s
.39475 .45002 m
.39435 .4492 L
s
.48701 .44662 m
.4867 .44754 L
s
.45238 .44779 m
.45043 .44895 L
s
.43374 .44919 m
.43181 .44817 L
s
.45239 .44778 m
.45045 .44895 L
s
.45242 .44778 m
.45048 .44895 L
s
.43379 .44918 m
.43185 .44817 L
s
.16714 .45872 m
.16702 .45837 L
s
.43362 .44918 m
.4317 .44815 L
s
.45246 .44776 m
.45051 .44893 L
s
.45243 .44775 m
.4505 .44893 L
s
.356 .45332 m
.35571 .4527 L
s
.45236 .44776 m
.45041 .44892 L
s
.39472 .44998 m
.39432 .44916 L
s
.43359 .44916 m
.43167 .44814 L
s
.35606 .45332 m
.35577 .4527 L
s
.45235 .44775 m
.4504 .44892 L
s
.4335 .44916 m
.4316 .44812 L
s
.48702 .44657 m
.48672 .44749 L
s
.43358 .44915 m
.43167 .44812 L
s
.45256 .44771 m
.45064 .4489 L
s
.45244 .44772 m
.45051 .4489 L
s
.43375 .44914 m
.43182 .44812 L
s
.43347 .44915 m
.43157 .4481 L
s
.43351 .44914 m
.4316 .4481 L
s
.43352 .44914 m
.43162 .4481 L
s
.45241 .44772 m
.45048 .44889 L
s
.62353 .44607 m
.62344 .44652 L
s
.45257 .4477 m
.45065 .44888 L
s
.45255 .4477 m
.45063 .44888 L
s
.43356 .44913 m
.43165 .44809 L
s
.71443 .438 m
.71438 .43837 L
s
.62358 .44607 m
.62349 .44652 L
s
.45262 .44767 m
.45071 .44887 L
s
.43342 .44913 m
.43152 .44809 L
s
.43361 .44911 m
.43171 .44808 L
s
.39468 .44993 m
.39429 .44911 L
s
.43353 .44911 m
.43162 .44807 L
s
.48705 .44653 m
.48674 .44745 L
s
.45251 .44767 m
.4506 .44886 L
s
.43351 .44911 m
.4316 .44807 L
s
.16707 .45865 m
.16696 .45829 L
s
.43358 .44909 m
.43168 .44805 L
s
.45255 .44766 m
.45063 .44885 L
s
.43354 .4491 m
.43164 .44805 L
s
.43346 .44909 m
.43156 .44805 L
s
.43342 .44909 m
.43153 .44804 L
s
.27544 .45066 m
.27529 .45018 L
s
.4334 .44909 m
.43151 .44805 L
s
.35592 .45324 m
.35563 .45262 L
s
.45259 .44764 m
.45068 .44884 L
s
.43341 .44909 m
.43151 .44804 L
s
.39464 .44991 m
.39424 .44909 L
s
.43339 .44908 m
.43151 .44803 L
s
.45264 .44762 m
.45075 .44883 L
s
.45261 .44764 m
.4507 .44883 L
s
.43352 .44907 m
.43161 .44803 L
s
.45266 .44763 m
.45076 .44882 L
s
.45261 .44763 m
.4507 .44882 L
s
.43336 .44908 m
.43148 .44802 L
s
.45265 .44761 m
.45074 .44881 L
s
.45263 .44761 m
.45072 .44881 L
s
.84941 .28985 m
.84951 .2901 L
s
.45253 .44762 m
.45063 .44881 L
s
.45257 .44762 m
.45065 .44881 L
s
.43329 .44905 m
.43142 .44799 L
s
.39462 .44988 m
.39423 .44906 L
s
.45259 .4476 m
.45069 .4488 L
s
.45274 .44758 m
.45086 .4488 L
s
.48708 .44646 m
.48678 .44738 L
s
.52664 .44333 m
.52648 .44401 L
s
.43327 .44904 m
.4314 .44798 L
s
.43323 .44904 m
.43136 .44798 L
s
.45266 .44757 m
.45077 .44878 L
s
.45261 .44757 m
.45073 .44878 L
s
.43326 .44902 m
.43139 .44796 L
s
.39465 .44985 m
.39426 .44903 L
s
.45259 .44758 m
.45068 .44878 L
s
.43324 .44902 m
.43138 .44796 L
s
.35598 .45318 m
.35569 .45256 L
s
.71445 .4379 m
.7144 .43827 L
s
.43337 .44901 m
.43149 .44796 L
s
.43322 .44901 m
.43137 .44794 L
s
.45277 .44753 m
.4509 .44876 L
s
.45276 .44754 m
.45088 .44875 L
s
.52665 .4433 m
.52648 .44398 L
s
.35604 .45317 m
.35575 .45254 L
s
.43322 .449 m
.43136 .44793 L
s
.43331 .44899 m
.43145 .44793 L
s
.43306 .449 m
.43121 .44792 L
s
.48703 .44641 m
.48674 .44733 L
s
.43325 .44899 m
.43138 .44792 L
s
.43318 .44899 m
.43132 .44792 L
s
.43335 .44898 m
.43148 .44792 L
s
.43329 .44898 m
.43142 .44792 L
s
.45276 .44751 m
.45089 .44873 L
s
.43311 .44899 m
.43127 .44791 L
s
.52672 .44327 m
.52656 .44395 L
s
.39458 .44981 m
.39419 .44898 L
s
.45273 .4475 m
.45086 .44872 L
s
.35589 .45313 m
.3556 .4525 L
s
.45278 .44749 m
.45092 .44872 L
s
.45279 .44749 m
.45092 .44871 L
s
.45278 .44748 m
.45092 .44871 L
s
.18656 .54922 m
.18637 .54885 L
s
.45282 .44749 m
.45095 .44871 L
s
.45277 .44748 m
.4509 .44871 L
s
.52661 .44326 m
.52644 .44394 L
s
.48708 .44638 m
.48679 .4473 L
s
.48706 .44638 m
.48677 .4473 L
s
.43326 .44895 m
.4314 .44788 L
s
.45286 .44746 m
.45099 .44869 L
s
.39469 .44977 m
.3943 .44895 L
s
.43324 .44895 m
.43138 .44788 L
s
.4871 .44637 m
.4868 .44729 L
s
.43318 .44895 m
.43133 .44788 L
s
.45288 .44746 m
.45101 .44869 L
s
.43308 .44894 m
.43125 .44785 L
s
.62371 .44588 m
.62362 .44633 L
s
.27536 .45051 m
.27521 .45002 L
s
.45288 .44743 m
.45104 .44867 L
s
.45284 .44744 m
.45098 .44867 L
s
.43308 .44893 m
.43124 .44785 L
s
.45278 .44744 m
.45093 .44867 L
s
.43303 .44893 m
.43119 .44784 L
s
.4871 .44634 m
.48681 .44726 L
s
.43319 .44892 m
.43134 .44784 L
s
.45292 .44742 m
.45107 .44866 L
s
.62358 .44586 m
.62349 .44631 L
s
.43305 .44891 m
.43122 .44782 L
s
.43301 .44891 m
.43119 .44782 L
s
.4529 .44741 m
.45106 .44865 L
s
.45282 .44743 m
.45095 .44866 L
s
.52663 .4432 m
.52647 .44388 L
s
.45291 .44739 m
.45107 .44864 L
s
.45293 .44739 m
.4511 .44864 L
s
.45281 .44741 m
.45095 .44864 L
s
.39463 .44972 m
.39424 .4489 L
s
.39461 .44972 m
.39422 .4489 L
s
.48716 .44631 m
.48687 .44723 L
s
.45292 .44738 m
.45108 .44863 L
s
.43294 .44889 m
.43111 .4478 L
s
.43306 .44888 m
.43123 .44779 L
s
.43292 .44889 m
.4311 .44779 L
s
.48709 .4463 m
.48681 .44722 L
s
.43305 .44888 m
.43122 .44779 L
s
.43299 .44887 m
.43117 .44778 L
s
.43287 .44888 m
.43106 .44778 L
s
.45305 .44735 m
.45122 .4486 L
s
.43291 .44887 m
.4311 .44777 L
s
.48714 .44629 m
.48685 .44721 L
s
.45297 .44734 m
.45115 .4486 L
s
.43305 .44886 m
.43122 .44776 L
s
.43307 .44886 m
.43125 .44777 L
s
.43301 .44886 m
.43118 .44777 L
s
.39461 .44968 m
.39422 .44886 L
s
.45306 .44733 m
.45123 .44859 L
s
.43298 .44885 m
.43115 .44776 L
s
.45294 .44734 m
.45111 .44859 L
s
.39455 .44968 m
.39417 .44886 L
s
.43298 .44885 m
.43116 .44775 L
s
.52666 .44315 m
.5265 .44383 L
s
.52666 .44314 m
.5265 .44382 L
s
.45294 .44733 m
.45111 .44858 L
s
.4871 .44625 m
.48681 .44717 L
s
.43282 .44883 m
.43102 .44773 L
s
.43289 .44883 m
.43109 .44772 L
s
.45306 .44728 m
.45127 .44856 L
s
.39455 .44966 m
.39416 .44884 L
s
.43294 .44882 m
.43113 .44772 L
s
.45306 .44729 m
.45125 .44856 L
s
.45298 .4473 m
.45117 .44856 L
s
.4531 .44729 m
.45128 .44855 L
s
.35583 .45299 m
.35555 .45236 L
s
.45305 .44729 m
.45124 .44855 L
s
.45293 .4473 m
.45111 .44855 L
s
.45305 .44728 m
.45124 .44854 L
s
.39456 .44963 m
.39418 .44881 L
s
.453 .44728 m
.45119 .44854 L
s
.16702 .45837 m
.16691 .45801 L
s
.43281 .44881 m
.43101 .4477 L
s
.45309 .44726 m
.4513 .44853 L
s
.43295 .44879 m
.43113 .44769 L
s
.39453 .44963 m
.39415 .44881 L
s
.84931 .2896 m
.84941 .28985 L
s
.43279 .44879 m
.431 .44767 L
s
.45303 .44727 m
.45121 .44853 L
s
.45304 .44727 m
.45122 .44852 L
s
.43268 .44879 m
.4309 .44767 L
s
.43278 .44878 m
.43099 .44766 L
s
.43281 .44877 m
.43102 .44766 L
s
.45302 .44725 m
.45121 .44851 L
s
.43281 .44877 m
.43102 .44765 L
s
.43279 .44876 m
.43101 .44765 L
s
.43273 .44877 m
.43094 .44765 L
s
.43277 .44877 m
.43098 .44765 L
s
.52673 .44305 m
.52657 .44373 L
s
.4532 .44721 m
.45142 .44849 L
s
.43275 .44876 m
.43097 .44764 L
s
.45317 .4472 m
.45139 .44848 L
s
.35576 .45291 m
.35548 .45229 L
s
.43265 .44875 m
.43087 .44762 L
s
.71449 .43763 m
.71443 .438 L
s
.43275 .44873 m
.43098 .44761 L
s
.48715 .44615 m
.48686 .44708 L
s
.45315 .44718 m
.45137 .44846 L
s
.27543 .4503 m
.27529 .44982 L
s
.43284 .44872 m
.43105 .44761 L
s
.3945 .44956 m
.39412 .44874 L
s
.43273 .44872 m
.43094 .4476 L
s
.45307 .44718 m
.45129 .44846 L
s
.43271 .44872 m
.43094 .44759 L
s
.45309 .44718 m
.45129 .44846 L
s
.16696 .45829 m
.16685 .45794 L
s
.39453 .44955 m
.39415 .44873 L
s
.45318 .44715 m
.45142 .44844 L
s
.35579 .45289 m
.35551 .45226 L
s
.45317 .44716 m
.45139 .44844 L
s
.43275 .44871 m
.43097 .44759 L
s
.43259 .44872 m
.43082 .44759 L
s
.43263 .44871 m
.43086 .44759 L
s
.43283 .4487 m
.43105 .44758 L
s
.45327 .44714 m
.4515 .44843 L
s
.45324 .44714 m
.45147 .44843 L
s
.43265 .44869 m
.43089 .44756 L
s
.45327 .44712 m
.45151 .44841 L
s
.43251 .44869 m
.43075 .44755 L
s
.45318 .44713 m
.4514 .44841 L
s
.45319 .44712 m
.45142 .44841 L
s
.62362 .44562 m
.62353 .44607 L
s
.45321 .44711 m
.45145 .4484 L
s
.43259 .44867 m
.43084 .44753 L
s
.62367 .44562 m
.62358 .44607 L
s
.4532 .4471 m
.45143 .4484 L
s
.45323 .44708 m
.45148 .44838 L
s
.43257 .44865 m
.43083 .44751 L
s
.52671 .44295 m
.52656 .44363 L
s
.43256 .44865 m
.43082 .44751 L
s
.4532 .44709 m
.45143 .44838 L
s
.39453 .44948 m
.39415 .44866 L
s
.39457 .44947 m
.39419 .44865 L
s
.43247 .44864 m
.43073 .44749 L
s
.43253 .44864 m
.43078 .4475 L
s
.45331 .44706 m
.45156 .44836 L
s
.43236 .44864 m
.43063 .44749 L
s
.43258 .44864 m
.43082 .4475 L
s
.45326 .44707 m
.45149 .44836 L
s
.7145 .43753 m
.71445 .4379 L
s
.45337 .44705 m
.45162 .44835 L
s
.45323 .44706 m
.45147 .44836 L
s
.4533 .44704 m
.45156 .44835 L
s
.43247 .44862 m
.43073 .44748 L
s
.43252 .44862 m
.43077 .44748 L
s
.48716 .44604 m
.48689 .44697 L
s
.4325 .44863 m
.43076 .44748 L
s
.35574 .45281 m
.35546 .45218 L
s
.45326 .44703 m
.45152 .44834 L
s
.43251 .4486 m
.43078 .44746 L
s
.52669 .44291 m
.52653 .44359 L
s
.45339 .44701 m
.45165 .44833 L
s
.43254 .4486 m
.43079 .44746 L
s
.27529 .45018 m
.27515 .4497 L
s
.39447 .44944 m
.39409 .44861 L
s
.45333 .44701 m
.4516 .44832 L
s
.4325 .4486 m
.43076 .44745 L
s
.48724 .44601 m
.48696 .44693 L
s
.43259 .44858 m
.43084 .44744 L
s
.4324 .44859 m
.43068 .44743 L
s
.39451 .44941 m
.39413 .44859 L
s
.48724 .446 m
.48697 .44692 L
s
.4325 .44857 m
.43076 .44743 L
s
.4324 .44858 m
.43067 .44743 L
s
.39446 .44941 m
.39409 .44859 L
s
.45341 .44698 m
.45168 .4483 L
s
.45341 .44698 m
.45169 .4483 L
s
.43234 .44857 m
.43062 .44741 L
s
.45343 .44696 m
.45171 .44828 L
s
.45338 .44697 m
.45165 .44828 L
s
.48722 .44597 m
.48694 .44689 L
s
.18637 .54885 m
.18619 .54847 L
s
.39444 .44938 m
.39407 .44856 L
s
.43233 .44855 m
.43062 .44739 L
s
.45344 .44695 m
.45172 .44827 L
s
.45345 .44694 m
.45173 .44826 L
s
.45338 .44694 m
.45167 .44826 L
s
.45351 .44692 m
.4518 .44825 L
s
.43224 .44853 m
.43053 .44736 L
s
.4324 .44853 m
.43068 .44738 L
s
.84921 .28936 m
.84931 .2896 L
s
.45335 .44693 m
.45164 .44825 L
s
.43236 .44853 m
.43065 .44736 L
s
.43237 .44852 m
.43066 .44735 L
s
.45336 .44693 m
.45164 .44824 L
s
.45351 .4469 m
.45181 .44824 L
s
.45346 .44692 m
.45173 .44824 L
s
.43221 .44852 m
.43051 .44735 L
s
.45342 .44691 m
.45171 .44823 L
s
.35571 .4527 m
.35544 .45207 L
s
.43233 .4485 m
.43063 .44733 L
s
.35577 .4527 m
.35549 .45207 L
s
.4534 .4469 m
.4517 .44822 L
s
.45343 .44689 m
.45174 .44822 L
s
.43229 .4485 m
.43058 .44733 L
s
.43226 .4485 m
.43055 .44733 L
s
.43232 .44849 m
.43062 .44732 L
s
.45347 .44687 m
.45178 .44821 L
s
.45345 .44689 m
.45174 .44821 L
s
.43232 .44848 m
.43061 .44732 L
s
.6238 .44543 m
.62371 .44588 L
s
.43218 .44848 m
.43049 .44731 L
s
.3944 .44932 m
.39404 .44849 L
s
.43232 .44847 m
.43062 .4473 L
s
.45361 .44684 m
.45193 .44818 L
s
.43223 .44848 m
.43053 .44731 L
s
.62367 .44541 m
.62358 .44586 L
s
.43232 .44845 m
.43062 .44729 L
s
.43214 .44846 m
.43046 .44728 L
s
.45349 .44683 m
.45181 .44817 L
s
.45352 .44683 m
.45183 .44817 L
s
.43219 .44845 m
.4305 .44728 L
s
.43223 .44845 m
.43054 .44728 L
s
.48725 .44587 m
.48699 .44679 L
s
.43219 .44844 m
.43051 .44727 L
s
.27521 .45002 m
.27507 .44954 L
s
.45359 .44681 m
.45191 .44815 L
s
.43221 .44844 m
.43052 .44726 L
s
.45356 .44682 m
.45188 .44816 L
s
.35563 .45262 m
.35536 .452 L
s
.45364 .44678 m
.45198 .44813 L
s
.16691 .45801 m
.1668 .45765 L
s
.45363 .44678 m
.45197 .44813 L
s
.45351 .44678 m
.45184 .44813 L
s
.43219 .44841 m
.43052 .44722 L
s
.39443 .44925 m
.39406 .44842 L
s
.43203 .4484 m
.43036 .44722 L
s
.43202 .4484 m
.43036 .44721 L
s
.45366 .44674 m
.45201 .4481 L
s
.45359 .44675 m
.45193 .4481 L
s
.45353 .44677 m
.45185 .44811 L
s
.43204 .44839 m
.43038 .4472 L
s
.45363 .44675 m
.45196 .4481 L
s
.43211 .44838 m
.43045 .44719 L
s
.45356 .44675 m
.45189 .4481 L
s
.43206 .44838 m
.43039 .44719 L
s
.45359 .44672 m
.45194 .44809 L
s
.43212 .44837 m
.43046 .44718 L
s
.45364 .44673 m
.45197 .44808 L
s
.45361 .44673 m
.45194 .44808 L
s
.43198 .44837 m
.43033 .44717 L
s
.45355 .44673 m
.45188 .44808 L
s
.35569 .45256 m
.35541 .45193 L
s
.43206 .44836 m
.4304 .44717 L
s
.45363 .44672 m
.45196 .44808 L
s
.43202 .44836 m
.43035 .44717 L
s
.45361 .44671 m
.45196 .44807 L
s
.43211 .44835 m
.43045 .44717 L
s
.52679 .44265 m
.52664 .44333 L
s
.39435 .4492 m
.39399 .44837 L
s
.71454 .43726 m
.71449 .43763 L
s
.45376 .44669 m
.45212 .44806 L
s
.48728 .44577 m
.48702 .4467 L
s
.35575 .45254 m
.35548 .45192 L
s
.16685 .45794 m
.16674 .45758 L
s
.43189 .44834 m
.43025 .44713 L
s
.43208 .44833 m
.43042 .44714 L
s
.43203 .44833 m
.43038 .44713 L
s
.43207 .44832 m
.43042 .44712 L
s
.432 .44832 m
.43035 .44713 L
s
.48725 .44575 m
.48699 .44667 L
s
.5268 .44262 m
.52665 .4433 L
s
.3556 .4525 m
.35533 .45188 L
s
.43188 .44832 m
.43024 .44712 L
s
.39432 .44916 m
.39396 .44833 L
s
.48734 .44573 m
.48707 .44666 L
s
.4537 .44665 m
.45207 .44802 L
s
.43202 .4483 m
.43038 .4471 L
s
.43186 .4483 m
.43023 .44709 L
s
.45375 .44663 m
.45212 .44801 L
s
.45371 .44664 m
.45206 .44801 L
s
.43208 .44829 m
.43043 .4471 L
s
.52687 .44259 m
.52672 .44327 L
s
.48729 .44571 m
.48704 .44663 L
s
.48731 .44571 m
.48705 .44663 L
s
.45378 .44661 m
.45216 .44799 L
s
.45368 .44662 m
.45205 .44799 L
s
.45378 .44661 m
.45216 .44798 L
s
.48732 .4457 m
.48706 .44662 L
s
.45372 .44661 m
.4521 .44798 L
s
.43193 .44827 m
.43029 .44707 L
s
.52675 .44258 m
.52661 .44326 L
s
.45379 .4466 m
.45218 .44798 L
s
.48727 .44569 m
.48701 .44662 L
s
.39429 .44911 m
.39393 .44829 L
s
.84911 .28911 m
.84921 .28936 L
s
.43179 .44825 m
.43018 .44704 L
s
.45372 .44658 m
.4521 .44796 L
s
.45377 .44659 m
.45214 .44796 L
s
.43184 .44825 m
.43022 .44704 L
s
.43183 .44824 m
.43021 .44703 L
s
.71455 .43716 m
.7145 .43753 L
s
.4319 .44824 m
.43028 .44703 L
s
.43187 .44824 m
.43024 .44703 L
s
.39424 .44909 m
.39389 .44826 L
s
.27529 .44982 m
.27515 .44934 L
s
.43172 .44823 m
.43012 .44701 L
s
.43191 .44822 m
.43029 .44701 L
s
.4538 .44655 m
.45219 .44793 L
s
.45375 .44656 m
.45212 .44793 L
s
.48728 .44565 m
.48702 .44657 L
s
.6237 .44517 m
.62362 .44562 L
s
.43187 .44822 m
.43025 .44701 L
s
.45378 .44655 m
.45216 .44793 L
s
.45384 .44654 m
.45223 .44792 L
s
.45375 .44655 m
.45213 .44793 L
s
.52678 .44252 m
.52663 .4432 L
s
.45386 .44653 m
.45226 .44792 L
s
.62375 .44517 m
.62367 .44562 L
s
.43184 .44821 m
.43022 .44699 L
s
.43181 .44821 m
.4302 .44699 L
s
.43177 .44821 m
.43016 .447 L
s
.39423 .44906 m
.39388 .44823 L
s
.43179 .4482 m
.43017 .44699 L
s
.4538 .44652 m
.45221 .4479 L
s
.45388 .4465 m
.45229 .4479 L
s
.43179 .44819 m
.43018 .44697 L
s
.43168 .4482 m
.43008 .44698 L
s
.45383 .44651 m
.45223 .4479 L
s
.45391 .44648 m
.45233 .44788 L
s
.4873 .4456 m
.48705 .44653 L
s
.39426 .44903 m
.3939 .4482 L
s
.43185 .44817 m
.43023 .44696 L
s
.45384 .44648 m
.45225 .44788 L
s
.43169 .44817 m
.4301 .44694 L
s
.43181 .44817 m
.43021 .44695 L
s
.35555 .45236 m
.35527 .45174 L
s
.52681 .44247 m
.52666 .44315 L
s
.52681 .44246 m
.52666 .44314 L
s
.45384 .44646 m
.45226 .44786 L
s
.4317 .44815 m
.43011 .44693 L
s
.45394 .44644 m
.45237 .44784 L
s
.45391 .44644 m
.45233 .44784 L
s
.43167 .44814 m
.43008 .44691 L
s
.18619 .54847 m
.18601 .5481 L
s
.39419 .44898 m
.39384 .44816 L
s
.45384 .44643 m
.45227 .44783 L
s
.43182 .44812 m
.43022 .4469 L
s
.45396 .44642 m
.45239 .44782 L
s
.4316 .44812 m
.43003 .44688 L
s
.43167 .44812 m
.43009 .44689 L
s
.48733 .44553 m
.48708 .44646 L
s
.27515 .4497 m
.27501 .44921 L
s
.4316 .4481 m
.43003 .44687 L
s
.45395 .4464 m
.45239 .44781 L
s
.45393 .4464 m
.45237 .4478 L
s
.43162 .4481 m
.43004 .44687 L
s
.45402 .4464 m
.45244 .4478 L
s
.3943 .44895 m
.39395 .44812 L
s
.43157 .4481 m
.43001 .44686 L
s
.45401 .44638 m
.45246 .44779 L
s
.43165 .44809 m
.43008 .44686 L
s
.35548 .45229 m
.35521 .45166 L
s
.45402 .44637 m
.45248 .44778 L
s
.45394 .44638 m
.45238 .44779 L
s
.45395 .44638 m
.45239 .44778 L
s
.43171 .44808 m
.43013 .44684 L
s
.43152 .44809 m
.42995 .44685 L
s
.45397 .44637 m
.45242 .44778 L
s
.43162 .44807 m
.43005 .44683 L
s
.4316 .44807 m
.43002 .44684 L
s
.52687 .44237 m
.52673 .44305 L
s
.45402 .44635 m
.45246 .44776 L
s
.43168 .44805 m
.43011 .44681 L
s
.48728 .44549 m
.48703 .44641 L
s
.43164 .44805 m
.43008 .44681 L
s
.45393 .44636 m
.45236 .44776 L
s
.35551 .45226 m
.35524 .45164 L
s
.45398 .44634 m
.45243 .44775 L
s
.43156 .44805 m
.43 .44681 L
s
.45391 .44634 m
.45235 .44775 L
s
.39424 .4489 m
.3939 .44807 L
s
.43153 .44804 m
.42997 .4468 L
s
.43151 .44805 m
.42996 .4468 L
s
.39422 .4489 m
.39388 .44807 L
s
.1668 .45765 m
.16669 .45729 L
s
.43151 .44804 m
.42996 .4468 L
s
.43161 .44803 m
.43004 .4468 L
s
.43151 .44803 m
.42996 .44678 L
s
.48733 .44545 m
.48708 .44638 L
s
.4873 .44545 m
.48706 .44638 L
s
.62388 .44498 m
.6238 .44543 L
s
.45397 .4463 m
.45244 .44772 L
s
.43148 .44802 m
.42993 .44678 L
s
.48734 .44544 m
.4871 .44637 L
s
.45408 .44628 m
.45256 .44771 L
s
.45395 .4463 m
.45241 .44772 L
s
.39422 .44886 m
.39387 .44803 L
s
.62375 .44496 m
.62367 .44541 L
s
.45409 .44627 m
.45255 .4477 L
s
.45409 .44627 m
.45257 .4477 L
s
.39417 .44886 m
.39382 .44803 L
s
.43142 .44799 m
.42988 .44674 L
s
.84901 .28886 m
.84911 .28911 L
s
.48735 .44542 m
.4871 .44634 L
s
.45413 .44624 m
.45262 .44767 L
s
.45403 .44624 m
.45251 .44767 L
s
.39416 .44884 m
.39382 .44801 L
s
.4314 .44798 m
.42987 .44672 L
s
.43136 .44798 m
.42983 .44672 L
s
.45407 .44623 m
.45255 .44766 L
s
.71458 .43689 m
.71454 .43726 L
s
.43139 .44796 m
.42986 .4467 L
s
.52685 .44228 m
.52671 .44295 L
s
.35546 .45218 m
.35519 .45155 L
s
.16674 .45758 m
.16663 .45722 L
s
.43149 .44796 m
.42996 .44671 L
s
.39418 .44881 m
.39384 .44798 L
s
.4874 .44538 m
.48716 .44631 L
s
.43138 .44796 m
.42986 .4467 L
s
.27507 .44954 m
.27493 .44906 L
s
.4541 .44621 m
.45259 .44764 L
s
.39415 .44881 m
.39381 .44798 L
s
.48733 .44537 m
.48709 .4463 L
s
.45412 .44621 m
.45261 .44764 L
s
.43137 .44794 m
.42985 .44667 L
s
.45412 .4462 m
.45261 .44763 L
s
.43145 .44793 m
.42992 .44667 L
s
.48738 .44536 m
.48714 .44629 L
s
.43136 .44793 m
.42984 .44667 L
s
.45417 .44619 m
.45266 .44763 L
s
.45413 .44618 m
.45264 .44762 L
s
.45409 .4462 m
.45257 .44762 L
s
.43138 .44792 m
.42985 .44667 L
s
.43148 .44792 m
.42995 .44666 L
s
.43142 .44792 m
.42989 .44666 L
s
.45415 .44618 m
.45265 .44761 L
s
.45413 .44618 m
.45263 .44761 L
s
.45404 .44618 m
.45253 .44762 L
s
.43132 .44792 m
.42981 .44665 L
s
.52683 .44223 m
.52669 .44291 L
s
.43121 .44792 m
.4297 .44665 L
s
.45408 .44616 m
.45259 .4476 L
s
.43127 .44791 m
.42977 .44664 L
s
.48734 .44533 m
.4871 .44625 L
s
.45421 .44613 m
.45274 .44758 L
s
.4314 .44788 m
.42988 .44661 L
s
.43138 .44788 m
.42986 .44662 L
s
.45409 .44615 m
.45259 .44758 L
s
.45415 .44613 m
.45266 .44757 L
s
.43133 .44788 m
.42982 .44662 L
s
.45409 .44612 m
.45261 .44757 L
s
.39412 .44874 m
.39378 .44791 L
s
.39415 .44873 m
.39381 .4479 L
s
.7146 .43679 m
.71455 .43716 L
s
.45424 .44609 m
.45276 .44754 L
s
.35544 .45207 m
.35517 .45144 L
s
.43125 .44785 m
.42976 .44657 L
s
.43124 .44785 m
.42974 .44658 L
s
.35549 .45207 m
.35522 .45145 L
s
.45423 .44608 m
.45277 .44753 L
s
.43134 .44784 m
.42984 .44658 L
s
.43119 .44784 m
.4297 .44657 L
s
.43122 .44782 m
.42973 .44654 L
s
.45423 .44606 m
.45276 .44751 L
s
.43119 .44782 m
.42972 .44654 L
s
.4542 .44605 m
.45273 .4475 L
s
.45425 .44603 m
.45279 .44749 L
s
.45424 .44603 m
.45278 .44749 L
s
.48738 .44523 m
.48715 .44615 L
s
.45429 .44603 m
.45282 .44749 L
s
.43111 .4478 m
.42963 .44652 L
s
.43123 .44779 m
.42975 .44652 L
s
.45423 .44602 m
.45278 .44748 L
s
.39415 .44866 m
.39382 .44783 L
s
.39419 .44865 m
.39385 .44782 L
s
.43122 .44779 m
.42974 .44651 L
s
.45422 .44602 m
.45277 .44748 L
s
.4311 .44779 m
.42962 .44651 L
s
.43117 .44778 m
.42969 .44649 L
s
.45431 .446 m
.45286 .44746 L
s
.35536 .452 m
.3551 .45137 L
s
.43106 .44778 m
.42959 .44649 L
s
.45433 .446 m
.45288 .44746 L
s
.43125 .44777 m
.42977 .44649 L
s
.43122 .44776 m
.42974 .44648 L
s
.4311 .44777 m
.42965 .44648 L
s
.43118 .44777 m
.4297 .44649 L
s
.62378 .44472 m
.6237 .44517 L
s
.43115 .44776 m
.42967 .44648 L
s
.4543 .44598 m
.45284 .44744 L
s
.62383 .44472 m
.62375 .44517 L
s
.43116 .44775 m
.4297 .44647 L
s
.45423 .44598 m
.45278 .44744 L
s
.45432 .44596 m
.45288 .44743 L
s
.39409 .44861 m
.39376 .44778 L
s
.45427 .44598 m
.45282 .44743 L
s
.27515 .44934 m
.27501 .44885 L
s
.45436 .44595 m
.45292 .44742 L
s
.45432 .44594 m
.4529 .44741 L
s
.39413 .44859 m
.3938 .44776 L
s
.43102 .44773 m
.42956 .44644 L
s
.84891 .28862 m
.84901 .28886 L
s
.43113 .44772 m
.42967 .44643 L
s
.45426 .44595 m
.45281 .44741 L
s
.39409 .44859 m
.39375 .44776 L
s
.43109 .44772 m
.42964 .44643 L
s
.18601 .5481 m
.18583 .54772 L
s
.45433 .44592 m
.45291 .44739 L
s
.45434 .44591 m
.45293 .44739 L
s
.35541 .45193 m
.35515 .45131 L
s
.43113 .44769 m
.42967 .44641 L
s
.45434 .44591 m
.45292 .44738 L
s
.43101 .4477 m
.42956 .44641 L
s
.39407 .44856 m
.39374 .44773 L
s
.35548 .45192 m
.35521 .45129 L
s
.48739 .44512 m
.48716 .44604 L
s
.431 .44767 m
.42956 .44637 L
s
.45446 .44587 m
.45305 .44735 L
s
.4309 .44767 m
.42947 .44637 L
s
.52693 .44198 m
.52679 .44265 L
s
.43099 .44766 m
.42956 .44636 L
s
.43102 .44766 m
.42958 .44637 L
s
.45436 .44586 m
.45297 .44734 L
s
.45435 .44586 m
.45294 .44734 L
s
.16669 .45729 m
.16658 .45693 L
s
.35533 .45188 m
.35507 .45125 L
s
.43102 .44765 m
.42958 .44635 L
s
.48746 .44508 m
.48724 .44601 L
s
.43094 .44765 m
.4295 .44635 L
s
.43101 .44765 m
.42957 .44635 L
s
.45447 .44585 m
.45306 .44733 L
s
.43098 .44765 m
.42954 .44635 L
s
.48746 .44507 m
.48724 .446 L
s
.45435 .44585 m
.45294 .44733 L
s
.43097 .44764 m
.42955 .44633 L
s
.52693 .44194 m
.5268 .44262 L
s
.39404 .44849 m
.39371 .44766 L
s
.43087 .44762 m
.42945 .44631 L
s
.43098 .44761 m
.42955 .4463 L
s
.45445 .44581 m
.45306 .44729 L
s
.43105 .44761 m
.42961 .44631 L
s
.45438 .44581 m
.45298 .4473 L
s
.27501 .44921 m
.27487 .44873 L
s
.45433 .44581 m
.45293 .4473 L
s
.48743 .44504 m
.48722 .44597 L
s
.45449 .4458 m
.4531 .44729 L
s
.45443 .44579 m
.45306 .44728 L
s
.43094 .4476 m
.42951 .4463 L
s
.45443 .4458 m
.45305 .44729 L
s
.52701 .44191 m
.52687 .44259 L
s
.45443 .44578 m
.45305 .44728 L
s
.45439 .44579 m
.453 .44728 L
s
.43094 .44759 m
.42952 .44628 L
s
.43097 .44759 m
.42955 .44629 L
s
.43105 .44758 m
.42962 .44628 L
s
.45447 .44577 m
.45309 .44726 L
s
.45442 .44578 m
.45303 .44727 L
s
.43082 .44759 m
.42941 .44628 L
s
.43086 .44759 m
.42944 .44628 L
s
.45443 .44578 m
.45304 .44727 L
s
.52689 .4419 m
.52675 .44258 L
s
.16663 .45722 m
.16652 .45686 L
s
.71463 .43652 m
.71458 .43689 L
s
.62396 .44453 m
.62388 .44498 L
s
.45441 .44576 m
.45302 .44725 L
s
.43089 .44756 m
.42949 .44625 L
s
.43075 .44755 m
.42936 .44623 L
s
.39406 .44842 m
.39374 .44759 L
s
.62383 .44451 m
.62375 .44496 L
s
.43084 .44753 m
.42945 .44621 L
s
.45456 .44571 m
.4532 .44721 L
s
.52691 .44184 m
.52678 .44252 L
s
.45452 .44569 m
.45317 .4472 L
s
.43083 .44751 m
.42944 .44618 L
s
.43082 .44751 m
.42943 .44619 L
s
.48747 .44494 m
.48725 .44587 L
s
.45445 .44569 m
.45309 .44718 L
s
.4545 .44567 m
.45315 .44718 L
s
.45443 .44568 m
.45307 .44718 L
s
.43078 .4475 m
.42939 .44618 L
s
.43082 .4475 m
.42943 .44618 L
s
.35527 .45174 m
.35502 .45111 L
s
.39399 .44837 m
.39367 .44754 L
s
.43073 .44749 m
.42934 .44617 L
s
.45451 .44565 m
.45317 .44716 L
s
.43063 .44749 m
.42926 .44616 L
s
.43077 .44748 m
.42939 .44616 L
s
.45452 .44564 m
.45318 .44715 L
s
.43076 .44748 m
.42938 .44616 L
s
.43073 .44748 m
.42936 .44615 L
s
.52694 .44179 m
.52681 .44247 L
s
.45461 .44563 m
.45327 .44714 L
s
.45458 .44563 m
.45324 .44714 L
s
.43079 .44746 m
.42941 .44614 L
s
.71465 .43642 m
.7146 .43679 L
s
.52694 .44178 m
.52681 .44246 L
s
.43078 .44746 m
.42941 .44613 L
s
.39396 .44833 m
.39364 .4475 L
s
.43076 .44745 m
.42938 .44613 L
s
.84881 .28837 m
.84891 .28862 L
s
.27493 .44906 m
.2748 .44857 L
s
.45453 .44562 m
.45318 .44713 L
s
.43084 .44744 m
.42946 .44612 L
s
.4546 .44561 m
.45327 .44712 L
s
.45454 .44562 m
.45319 .44712 L
s
.43076 .44743 m
.42938 .4461 L
s
.45455 .44559 m
.45321 .44711 L
s
.43068 .44743 m
.42932 .4461 L
s
.45453 .44559 m
.4532 .4471 L
s
.43067 .44743 m
.42929 .4461 L
s
.35521 .45166 m
.35496 .45103 L
s
.45455 .44556 m
.45323 .44708 L
s
.45454 .44558 m
.4532 .44709 L
s
.43062 .44741 m
.42927 .44608 L
s
.39393 .44829 m
.39361 .44745 L
s
.4875 .44484 m
.48728 .44577 L
s
.35524 .45164 m
.35499 .45101 L
s
.45459 .44556 m
.45326 .44707 L
s
.45462 .44554 m
.45331 .44706 L
s
.43062 .44739 m
.42927 .44605 L
s
.45455 .44554 m
.45323 .44706 L
s
.48746 .44482 m
.48725 .44575 L
s
.39389 .44826 m
.39357 .44743 L
s
.527 .44169 m
.52687 .44237 L
s
.43068 .44738 m
.42932 .44605 L
s
.45467 .44552 m
.45337 .44705 L
s
.4546 .44552 m
.4533 .44704 L
s
.48754 .4448 m
.48734 .44573 L
s
.43053 .44736 m
.42919 .44602 L
s
.43065 .44736 m
.42931 .44602 L
s
.43066 .44735 m
.42932 .44601 L
s
.45456 .44551 m
.45326 .44703 L
s
.45468 .44549 m
.45339 .44701 L
s
.39388 .44823 m
.39357 .4474 L
s
.43051 .44735 m
.42918 .446 L
s
.4875 .44478 m
.48729 .44571 L
s
.48752 .44478 m
.48731 .44571 L
s
.45461 .44548 m
.45333 .44701 L
s
.43063 .44733 m
.4293 .44599 L
s
.43058 .44733 m
.42924 .44599 L
s
.43055 .44733 m
.42921 .44599 L
s
.48753 .44477 m
.48732 .4457 L
s
.48747 .44476 m
.48727 .44569 L
s
.43062 .44732 m
.42929 .44597 L
s
.43061 .44732 m
.42927 .44598 L
s
.3939 .4482 m
.39359 .44737 L
s
.4547 .44545 m
.45341 .44698 L
s
.45469 .44544 m
.45341 .44698 L
s
.43062 .4473 m
.42928 .44596 L
s
.43049 .44731 m
.42917 .44596 L
s
.43053 .44731 m
.42919 .44597 L
s
.62386 .44427 m
.62378 .44472 L
s
.35519 .45155 m
.35494 .45092 L
s
.45467 .44544 m
.45338 .44697 L
s
.43062 .44729 m
.42929 .44595 L
s
.62391 .44427 m
.62383 .44472 L
s
.18583 .54772 m
.18565 .54734 L
s
.45471 .44542 m
.45343 .44696 L
s
.48748 .44472 m
.48728 .44565 L
s
.43046 .44728 m
.42915 .44593 L
s
.45472 .44541 m
.45344 .44695 L
s
.43054 .44728 m
.42922 .44593 L
s
.4305 .44728 m
.42919 .44593 L
s
.16658 .45693 m
.16647 .45657 L
s
.45466 .44541 m
.45338 .44694 L
s
.45472 .4454 m
.45345 .44694 L
s
.43051 .44727 m
.42919 .44592 L
s
.52698 .4416 m
.52685 .44228 L
s
.39384 .44816 m
.39353 .44732 L
s
.43052 .44726 m
.42919 .44591 L
s
.45462 .44539 m
.45335 .44693 L
s
.45477 .44538 m
.45351 .44692 L
s
.45474 .44539 m
.45346 .44692 L
s
.45464 .44539 m
.45336 .44693 L
s
.27501 .44885 m
.27488 .44837 L
s
.39395 .44812 m
.39364 .44729 L
s
.45468 .44537 m
.45342 .44691 L
s
.45476 .44536 m
.45351 .4469 L
s
.4875 .44467 m
.4873 .4456 L
s
.45466 .44536 m
.4534 .4469 L
s
.43052 .44722 m
.42922 .44587 L
s
.45469 .44535 m
.45343 .44689 L
s
.52695 .44155 m
.52683 .44223 L
s
.43036 .44722 m
.42907 .44586 L
s
.45472 .44535 m
.45345 .44689 L
s
.45471 .44532 m
.45347 .44687 L
s
.43036 .44721 m
.42907 .44584 L
s
.43038 .4472 m
.42909 .44584 L
s
.43045 .44719 m
.42916 .44583 L
s
.16652 .45686 m
.16642 .4565 L
s
.43039 .44719 m
.4291 .44584 L
s
.35517 .45144 m
.35492 .45082 L
s
.8487 .28812 m
.84881 .28837 L
s
.43046 .44718 m
.42917 .44582 L
s
.71468 .43615 m
.71463 .43652 L
s
.3939 .44807 m
.39359 .44723 L
s
.35522 .45145 m
.35497 .45082 L
s
.39388 .44807 m
.39357 .44724 L
s
.45484 .44528 m
.45361 .44684 L
s
.4304 .44717 m
.42912 .44581 L
s
.43033 .44717 m
.42906 .4458 L
s
.43035 .44717 m
.42907 .4458 L
s
.43045 .44717 m
.42916 .44581 L
s
.45477 .44528 m
.45352 .44683 L
s
.45472 .44528 m
.45349 .44683 L
s
.48753 .4446 m
.48733 .44553 L
s
.45479 .44526 m
.45356 .44682 L
s
.45482 .44526 m
.45359 .44681 L
s
.39387 .44803 m
.39357 .4472 L
s
.43042 .44714 m
.42913 .44578 L
s
.39382 .44803 m
.39352 .4472 L
s
.43042 .44712 m
.42914 .44576 L
s
.43038 .44713 m
.42911 .44577 L
s
.43025 .44713 m
.42899 .44576 L
s
.43035 .44713 m
.42907 .44576 L
s
.45486 .44522 m
.45364 .44678 L
s
.43024 .44712 m
.42897 .44575 L
s
.45473 .44523 m
.45351 .44678 L
s
.27487 .44873 m
.27474 .44824 L
s
.39382 .44801 m
.39352 .44717 L
s
.45485 .44521 m
.45363 .44678 L
s
.48748 .44455 m
.48728 .44549 L
s
.3551 .45137 m
.35485 .45074 L
s
.43043 .4471 m
.42915 .44574 L
s
.62404 .44408 m
.62396 .44453 L
s
.43038 .4471 m
.42911 .44573 L
s
.45476 .44521 m
.45353 .44677 L
s
.39384 .44798 m
.39354 .44715 L
s
.4548 .44519 m
.45359 .44675 L
s
.43023 .44709 m
.42898 .44571 L
s
.45485 .44519 m
.45363 .44675 L
s
.39381 .44798 m
.39351 .44714 L
s
.45485 .44518 m
.45366 .44674 L
s
.45478 .44519 m
.45356 .44675 L
s
.6239 .44406 m
.62383 .44451 L
s
.48752 .44452 m
.48733 .44545 L
s
.48749 .44452 m
.4873 .44545 L
s
.71469 .43605 m
.71465 .43642 L
s
.48753 .44451 m
.48734 .44544 L
s
.45485 .44518 m
.45364 .44673 L
s
.43029 .44707 m
.42904 .4457 L
s
.45482 .44517 m
.45361 .44673 L
s
.45476 .44518 m
.45355 .44673 L
s
.45477 .44516 m
.45359 .44672 L
s
.45484 .44516 m
.45363 .44672 L
s
.45481 .44515 m
.45361 .44671 L
s
.48754 .44449 m
.48735 .44542 L
s
.43022 .44704 m
.42897 .44567 L
s
.43018 .44704 m
.42895 .44565 L
s
.35515 .45131 m
.3549 .45068 L
s
.45494 .44512 m
.45376 .44669 L
s
.43028 .44703 m
.42903 .44565 L
s
.43021 .44703 m
.42896 .44565 L
s
.43024 .44703 m
.429 .44565 L
s
.35521 .45129 m
.35496 .45066 L
s
.43029 .44701 m
.42905 .44563 L
s
.48759 .44445 m
.4874 .44538 L
s
.39378 .44791 m
.39348 .44707 L
s
.43025 .44701 m
.42901 .44563 L
s
.43012 .44701 m
.4289 .44562 L
s
.39381 .4479 m
.39351 .44706 L
s
.48752 .44444 m
.48733 .44537 L
s
.43022 .44699 m
.42899 .44561 L
s
.43016 .447 m
.42893 .44561 L
s
.35507 .45125 m
.35482 .45062 L
s
.4302 .44699 m
.42898 .4456 L
s
.43017 .44699 m
.42894 .44561 L
s
.45487 .44507 m
.4537 .44665 L
s
.48757 .44443 m
.48738 .44536 L
s
.45489 .44507 m
.45371 .44664 L
s
.43018 .44697 m
.42895 .44558 L
s
.45491 .44505 m
.45375 .44663 L
s
.43008 .44698 m
.42886 .44559 L
s
.52705 .4413 m
.52693 .44198 L
s
.43023 .44696 m
.42899 .44558 L
s
.45486 .44505 m
.45368 .44662 L
s
.2748 .44857 m
.27467 .44809 L
s
.45493 .44503 m
.45378 .44661 L
s
.43021 .44695 m
.42899 .44556 L
s
.45488 .44503 m
.45372 .44661 L
s
.48752 .44439 m
.48734 .44533 L
s
.45494 .44503 m
.45378 .44661 L
s
.4301 .44694 m
.42889 .44555 L
s
.45494 .44501 m
.45379 .4466 L
s
.52705 .44126 m
.52693 .44194 L
s
.39382 .44783 m
.39353 .44699 L
s
.39385 .44782 m
.39356 .44699 L
s
.45494 .44501 m
.45377 .44659 L
s
.43011 .44693 m
.4289 .44553 L
s
.45486 .445 m
.45372 .44658 L
s
.8486 .28788 m
.8487 .28812 L
s
.43008 .44691 m
.42886 .44552 L
s
.43022 .4469 m
.429 .44552 L
s
.52713 .44123 m
.52701 .44191 L
s
.45491 .44498 m
.45375 .44656 L
s
.45495 .44497 m
.4538 .44655 L
s
.43009 .44689 m
.42889 .4455 L
s
.45493 .44497 m
.45378 .44655 L
s
.16647 .45657 m
.16637 .45622 L
s
.455 .44496 m
.45384 .44654 L
s
.4549 .44496 m
.45375 .44655 L
s
.43003 .44688 m
.42884 .44548 L
s
.527 .44122 m
.52689 .4419 L
s
.39376 .44778 m
.39347 .44695 L
s
.45499 .44494 m
.45386 .44653 L
s
.43003 .44687 m
.42883 .44547 L
s
.18565 .54734 m
.18547 .54696 L
s
.43004 .44687 m
.42885 .44547 L
s
.3938 .44776 m
.39351 .44692 L
s
.43001 .44686 m
.42883 .44546 L
s
.45493 .44493 m
.4538 .44652 L
s
.39375 .44776 m
.39347 .44692 L
s
.43008 .44686 m
.42889 .44546 L
s
.45497 .44492 m
.45383 .44651 L
s
.455 .44491 m
.45388 .4465 L
s
.48756 .44429 m
.48738 .44523 L
s
.43013 .44684 m
.42894 .44545 L
s
.42995 .44685 m
.42876 .44545 L
s
.62393 .44382 m
.62386 .44427 L
s
.43002 .44684 m
.42883 .44544 L
s
.43005 .44683 m
.42886 .44543 L
s
.45502 .44489 m
.45391 .44648 L
s
.35502 .45111 m
.35477 .45048 L
s
.62398 .44382 m
.62391 .44427 L
s
.45496 .44489 m
.45384 .44648 L
s
.39374 .44773 m
.39346 .44689 L
s
.52703 .44116 m
.52691 .44184 L
s
.43011 .44681 m
.42893 .44541 L
s
.43008 .44681 m
.4289 .44541 L
s
.43 .44681 m
.42882 .4454 L
s
.16642 .4565 m
.16631 .45614 L
s
.45495 .44486 m
.45384 .44646 L
s
.43004 .4468 m
.42886 .4454 L
s
.42996 .4468 m
.42879 .4454 L
s
.42997 .4468 m
.42881 .44539 L
s
.42996 .4468 m
.42878 .44539 L
s
.71472 .43578 m
.71468 .43615 L
s
.45503 .44484 m
.45394 .44644 L
s
.45502 .44484 m
.45391 .44644 L
s
.42996 .44678 m
.4288 .44537 L
s
.45493 .44483 m
.45384 .44643 L
s
.42993 .44678 m
.42877 .44537 L
s
.45507 .44482 m
.45396 .44642 L
s
.52705 .44111 m
.52694 .44179 L
s
.52705 .4411 m
.52694 .44178 L
s
.35496 .45103 m
.35471 .4504 L
s
.39371 .44766 m
.39343 .44682 L
s
.45511 .4448 m
.45402 .4464 L
s
.27488 .44837 m
.27475 .44788 L
s
.45504 .4448 m
.45395 .4464 L
s
.45502 .44479 m
.45393 .4464 L
s
.42988 .44674 m
.42874 .44532 L
s
.48757 .44418 m
.48739 .44512 L
s
.45508 .44477 m
.45401 .44638 L
s
.35499 .45101 m
.35475 .45038 L
s
.45503 .44478 m
.45394 .44638 L
s
.45504 .44477 m
.45395 .44638 L
s
.45508 .44475 m
.45402 .44637 L
s
.42987 .44672 m
.42873 .4453 L
s
.42983 .44672 m
.42868 .44531 L
s
.45505 .44476 m
.45397 .44637 L
s
.42986 .4467 m
.42873 .44528 L
s
.42996 .44671 m
.42881 .44529 L
s
.48763 .44415 m
.48746 .44508 L
s
.45511 .44475 m
.45402 .44635 L
s
.45502 .44475 m
.45393 .44636 L
s
.42986 .4467 m
.42873 .44528 L
s
.48763 .44414 m
.48746 .44507 L
s
.45499 .44474 m
.45391 .44634 L
s
.45505 .44473 m
.45398 .44634 L
s
.39374 .44759 m
.39346 .44675 L
s
.71474 .43568 m
.71469 .43605 L
s
.52712 .44101 m
.527 .44169 L
s
.42992 .44667 m
.42878 .44526 L
s
.42985 .44667 m
.42874 .44525 L
s
.42984 .44667 m
.42871 .44525 L
s
.42995 .44666 m
.42881 .44525 L
s
.42985 .44667 m
.42871 .44525 L
s
.42989 .44666 m
.42875 .44525 L
s
.4876 .44411 m
.48743 .44504 L
s
.42981 .44665 m
.42868 .44523 L
s
.45502 .44468 m
.45397 .4463 L
s
.45501 .44469 m
.45395 .4463 L
s
.4297 .44665 m
.42859 .44523 L
s
.8485 .28763 m
.8486 .28788 L
s
.62411 .44363 m
.62404 .44408 L
s
.42977 .44664 m
.42866 .44521 L
s
.45512 .44466 m
.45408 .44628 L
s
.35494 .45092 m
.3547 .45029 L
s
.39367 .44754 m
.39339 .4467 L
s
.45514 .44466 m
.45409 .44627 L
s
.42986 .44662 m
.42873 .4452 L
s
.42988 .44661 m
.42876 .4452 L
s
.45514 .44465 m
.45409 .44627 L
s
.62397 .44361 m
.6239 .44406 L
s
.27474 .44824 m
.27461 .44776 L
s
.42982 .44662 m
.4287 .4452 L
s
.45507 .44463 m
.45403 .44624 L
s
.45515 .44461 m
.45413 .44624 L
s
.39364 .4475 m
.39336 .44666 L
s
.45511 .44461 m
.45407 .44623 L
s
.42984 .44658 m
.42873 .44515 L
s
.42974 .44658 m
.42864 .44515 L
s
.42976 .44657 m
.42867 .44514 L
s
.52709 .44092 m
.52698 .4416 L
s
.4297 .44657 m
.42861 .44514 L
s
.45512 .44458 m
.4541 .44621 L
s
.45515 .44458 m
.45412 .44621 L
s
.48763 .444 m
.48747 .44494 L
s
.42973 .44654 m
.42864 .44511 L
s
.45515 .44457 m
.45412 .4462 L
s
.45514 .44458 m
.45409 .4462 L
s
.4552 .44457 m
.45417 .44619 L
s
.39361 .44745 m
.39334 .44662 L
s
.42972 .44654 m
.42864 .4451 L
s
.45513 .44455 m
.45413 .44618 L
s
.45507 .44456 m
.45404 .44618 L
s
.45517 .44455 m
.45415 .44618 L
s
.45515 .44455 m
.45413 .44618 L
s
.52706 .44087 m
.52695 .44155 L
s
.35492 .45082 m
.35468 .45018 L
s
.42975 .44652 m
.42866 .44508 L
s
.4551 .44454 m
.45408 .44616 L
s
.42963 .44652 m
.42855 .44508 L
s
.42974 .44651 m
.42865 .44508 L
s
.35497 .45082 m
.35473 .45018 L
s
.39357 .44743 m
.3933 .44659 L
s
.42962 .44651 m
.42855 .44507 L
s
.16637 .45622 m
.16627 .45586 L
s
.42969 .44649 m
.42862 .44506 L
s
.45512 .44452 m
.45409 .44615 L
s
.42977 .44649 m
.42868 .44505 L
s
.42974 .44648 m
.42866 .44505 L
s
.4552 .44449 m
.45421 .44613 L
s
.42959 .44649 m
.42853 .44505 L
s
.4297 .44649 m
.42862 .44506 L
s
.45515 .4445 m
.45415 .44613 L
s
.42967 .44648 m
.42859 .44505 L
s
.39357 .4474 m
.3933 .44656 L
s
.42965 .44648 m
.42859 .44504 L
s
.45508 .44449 m
.45409 .44612 L
s
.4297 .44647 m
.42863 .44503 L
s
.48766 .44391 m
.4875 .44484 L
s
.27467 .44809 m
.27454 .44761 L
s
.45524 .44446 m
.45424 .44609 L
s
.39359 .44737 m
.39332 .44653 L
s
.18547 .54696 m
.1853 .54658 L
s
.35485 .45074 m
.35461 .45011 L
s
.42967 .44643 m
.42861 .44499 L
s
.4552 .44443 m
.45423 .44608 L
s
.42956 .44644 m
.42851 .44499 L
s
.42964 .44643 m
.42859 .44498 L
s
.48762 .44388 m
.48746 .44482 L
s
.16631 .45614 m
.16621 .45578 L
s
.45521 .44442 m
.45423 .44606 L
s
.4877 .44387 m
.48754 .4448 L
s
.42967 .44641 m
.4286 .44497 L
s
.45517 .44441 m
.4542 .44605 L
s
.42956 .44641 m
.42851 .44496 L
s
.71476 .43541 m
.71472 .43578 L
s
.39353 .44732 m
.39327 .44648 L
s
.48766 .44385 m
.4875 .44478 L
s
.48767 .44384 m
.48752 .44478 L
s
.45521 .44439 m
.45425 .44603 L
s
.45519 .44439 m
.45424 .44603 L
s
.45526 .44439 m
.45429 .44603 L
s
.42956 .44637 m
.42853 .44493 L
s
.48768 .44383 m
.48753 .44477 L
s
.45518 .44438 m
.45422 .44602 L
s
.45519 .44437 m
.45423 .44602 L
s
.624 .44337 m
.62393 .44382 L
s
.84839 .28738 m
.8485 .28763 L
s
.48762 .44383 m
.48747 .44476 L
s
.39364 .44729 m
.39338 .44645 L
s
.3549 .45068 m
.35466 .45004 L
s
.62405 .44336 m
.62398 .44382 L
s
.42958 .44637 m
.42854 .44492 L
s
.42947 .44637 m
.42844 .44491 L
s
.42956 .44636 m
.42853 .44491 L
s
.45526 .44436 m
.45431 .446 L
s
.42958 .44635 m
.42855 .4449 L
s
.45529 .44435 m
.45433 .446 L
s
.4295 .44635 m
.42846 .44491 L
s
.42957 .44635 m
.42854 .4449 L
s
.35496 .45066 m
.35473 .45003 L
s
.42954 .44635 m
.42851 .4449 L
s
.45525 .44434 m
.4543 .44598 L
s
.45518 .44433 m
.45423 .44598 L
s
.42955 .44633 m
.42853 .44488 L
s
.45524 .44433 m
.45427 .44598 L
s
.48763 .44378 m
.48748 .44472 L
s
.35482 .45062 m
.35459 .44999 L
s
.45525 .44431 m
.45432 .44596 L
s
.42961 .44631 m
.42858 .44486 L
s
.4553 .4443 m
.45436 .44595 L
s
.39359 .44723 m
.39333 .44639 L
s
.42945 .44631 m
.42844 .44486 L
s
.42955 .4463 m
.42853 .44485 L
s
.39357 .44724 m
.39331 .4464 L
s
.42951 .4463 m
.42848 .44485 L
s
.45521 .4443 m
.45426 .44595 L
s
.45525 .44429 m
.45432 .44594 L
s
.42955 .44629 m
.42853 .44483 L
s
.71478 .43531 m
.71474 .43568 L
s
.42952 .44628 m
.42851 .44483 L
s
.42962 .44628 m
.4286 .44483 L
s
.45525 .44426 m
.45433 .44592 L
s
.48765 .44374 m
.4875 .44467 L
s
.42944 .44628 m
.42843 .44482 L
s
.39357 .4472 m
.39331 .44636 L
s
.42941 .44628 m
.42841 .44482 L
s
.45525 .44425 m
.45434 .44591 L
s
.45526 .44425 m
.45434 .44591 L
s
.52716 .44062 m
.52705 .4413 L
s
.39352 .4472 m
.39326 .44636 L
s
.42949 .44625 m
.42849 .44479 L
s
.27475 .44788 m
.27462 .4474 L
s
.39352 .44717 m
.39326 .44633 L
s
.52715 .44058 m
.52705 .44126 L
s
.42936 .44623 m
.42837 .44477 L
s
.45536 .44421 m
.45446 .44587 L
s
.39354 .44715 m
.39328 .44631 L
s
.45526 .44421 m
.45435 .44586 L
s
.45526 .4442 m
.45436 .44586 L
s
.42945 .44621 m
.42846 .44475 L
s
.39351 .44714 m
.39326 .4463 L
s
.45537 .44419 m
.45447 .44585 L
s
.48767 .44367 m
.48753 .4446 L
s
.52723 .44055 m
.52713 .44123 L
s
.45526 .44419 m
.45435 .44585 L
s
.42943 .44619 m
.42845 .44473 L
s
.42944 .44618 m
.42846 .44472 L
s
.42943 .44618 m
.42844 .44472 L
s
.52711 .44054 m
.527 .44122 L
s
.42939 .44618 m
.4284 .44471 L
s
.62418 .44317 m
.62411 .44363 L
s
.45522 .44415 m
.45433 .44581 L
s
.45534 .44414 m
.45445 .44581 L
s
.42934 .44617 m
.42837 .4447 L
s
.45527 .44415 m
.45438 .44581 L
s
.45538 .44413 m
.45449 .4458 L
s
.35477 .45048 m
.35454 .44985 L
s
.42939 .44616 m
.42841 .44469 L
s
.45532 .44413 m
.45443 .4458 L
s
.48762 .44362 m
.48748 .44455 L
s
.42938 .44616 m
.42841 .44469 L
s
.62404 .44316 m
.62397 .44361 L
s
.45529 .44412 m
.45443 .44579 L
s
.42926 .44616 m
.42831 .44468 L
s
.45528 .44413 m
.45439 .44579 L
s
.42936 .44615 m
.42839 .44468 L
s
.4553 .44412 m
.45443 .44578 L
s
.42941 .44614 m
.42843 .44468 L
s
.45531 .44412 m
.45442 .44578 L
s
.45533 .44412 m
.45443 .44578 L
s
.39348 .44707 m
.39323 .44623 L
s
.45534 .4441 m
.45447 .44577 L
s
.42938 .44613 m
.4284 .44466 L
s
.39351 .44706 m
.39326 .44622 L
s
.42941 .44613 m
.42846 .44466 L
s
.42946 .44612 m
.42848 .44466 L
s
.52713 .44048 m
.52703 .44116 L
s
.48766 .44359 m
.48752 .44452 L
s
.48763 .44358 m
.48749 .44452 L
s
.27461 .44776 m
.27449 .44728 L
s
.45529 .44409 m
.45441 .44576 L
s
.16627 .45586 m
.16616 .4555 L
s
.48767 .44358 m
.48753 .44451 L
s
.42938 .4461 m
.42842 .44463 L
s
.84829 .28714 m
.84839 .28738 L
s
.42929 .4461 m
.42833 .44463 L
s
.42932 .4461 m
.42838 .44463 L
s
.35471 .4504 m
.35449 .44977 L
s
.48768 .44355 m
.48754 .44449 L
s
.42927 .44608 m
.42832 .4446 L
s
.45542 .44403 m
.45456 .44571 L
s
.52715 .44043 m
.52705 .44111 L
s
.52715 .44042 m
.52705 .4411 L
s
.45537 .44402 m
.45452 .44569 L
s
.35475 .45038 m
.35452 .44974 L
s
.39353 .44699 m
.39328 .44615 L
s
.39356 .44699 m
.39331 .44614 L
s
.48773 .44352 m
.48759 .44445 L
s
.42927 .44605 m
.42834 .44457 L
s
.45531 .44401 m
.45445 .44569 L
s
.42932 .44605 m
.42837 .44457 L
s
.45527 .444 m
.45443 .44568 L
s
.48765 .4435 m
.48752 .44444 L
s
.45533 .44399 m
.4545 .44567 L
s
.16621 .45578 m
.1661 .45543 L
s
.48771 .44349 m
.48757 .44443 L
s
.1853 .54658 m
.18512 .5462 L
s
.42931 .44602 m
.42838 .44455 L
s
.42919 .44602 m
.42827 .44454 L
s
.42932 .44601 m
.42839 .44454 L
s
.45535 .44398 m
.45451 .44565 L
s
.45534 .44396 m
.45452 .44564 L
s
.39347 .44695 m
.39322 .4461 L
s
.71481 .43504 m
.71476 .43541 L
s
.42918 .446 m
.42827 .44452 L
s
.42924 .44599 m
.42832 .44451 L
s
.45541 .44394 m
.45458 .44563 L
s
.4293 .44599 m
.42838 .44451 L
s
.45543 .44394 m
.45461 .44563 L
s
.42921 .44599 m
.42829 .44451 L
s
.48765 .44346 m
.48752 .44439 L
s
.39351 .44692 m
.39326 .44608 L
s
.45536 .44395 m
.45453 .44562 L
s
.39347 .44692 m
.39322 .44608 L
s
.42929 .44597 m
.42838 .44449 L
s
.42927 .44598 m
.42834 .4445 L
s
.52722 .44033 m
.52712 .44101 L
s
.45537 .44394 m
.45454 .44562 L
s
.45542 .44392 m
.4546 .44561 L
s
.42928 .44596 m
.42836 .44448 L
s
.3547 .45029 m
.35447 .44966 L
s
.42919 .44597 m
.42827 .44449 L
s
.45537 .44391 m
.45455 .44559 L
s
.42917 .44596 m
.42827 .44448 L
s
.45535 .44391 m
.45453 .44559 L
s
.39346 .44689 m
.39321 .44605 L
s
.27454 .44761 m
.27442 .44712 L
s
.42929 .44595 m
.42837 .44447 L
s
.45536 .4439 m
.45454 .44558 L
s
.45534 .44388 m
.45455 .44556 L
s
.42922 .44593 m
.42831 .44445 L
s
.42915 .44593 m
.42825 .44444 L
s
.42919 .44593 m
.4283 .44444 L
s
.45541 .44387 m
.45459 .44556 L
s
.42919 .44591 m
.42828 .44443 L
s
.42919 .44592 m
.42829 .44443 L
s
.62407 .44292 m
.624 .44337 L
s
.45536 .44386 m
.45455 .44554 L
s
.45542 .44385 m
.45462 .44554 L
s
.62412 .44291 m
.62405 .44336 L
s
.71482 .43494 m
.71478 .43531 L
s
.45546 .44383 m
.45467 .44552 L
s
.48768 .44336 m
.48756 .44429 L
s
.45538 .44383 m
.4546 .44552 L
s
.42907 .44589 m
.42818 .4444 L
s
.39343 .44682 m
.39319 .44598 L
s
.45535 .44382 m
.45456 .44551 L
s
.42922 .44587 m
.42833 .44438 L
s
.52718 .44024 m
.52709 .44092 L
s
.45546 .44379 m
.45468 .44549 L
s
.42907 .44586 m
.42819 .44436 L
s
.35468 .45018 m
.35446 .44955 L
s
.45538 .44378 m
.45461 .44548 L
s
.35473 .45018 m
.3545 .44955 L
s
.42907 .44584 m
.42821 .44435 L
s
.42916 .44583 m
.42828 .44434 L
s
.42909 .44584 m
.42822 .44434 L
s
.84818 .28689 m
.84829 .28714 L
s
.4291 .44584 m
.42822 .44434 L
s
.42917 .44582 m
.4283 .44432 L
s
.52716 .44019 m
.52706 .44087 L
s
.45547 .44376 m
.4547 .44545 L
s
.45545 .44375 m
.45469 .44544 L
s
.42912 .44581 m
.42825 .44431 L
s
.42916 .44581 m
.42829 .44431 L
s
.42907 .4458 m
.4282 .44431 L
s
.39346 .44675 m
.39322 .44591 L
s
.45544 .44374 m
.45467 .44544 L
s
.42906 .4458 m
.4282 .4443 L
s
.45546 .44372 m
.45471 .44542 L
s
.42913 .44578 m
.42826 .44429 L
s
.45547 .44371 m
.45472 .44541 L
s
.45541 .44371 m
.45466 .44541 L
s
.48769 .44325 m
.48757 .44418 L
s
.45547 .4437 m
.45472 .4454 L
s
.35461 .45011 m
.35439 .44947 L
s
.42914 .44576 m
.42829 .44426 L
s
.42911 .44577 m
.42826 .44427 L
s
.42907 .44576 m
.42822 .44426 L
s
.4555 .44369 m
.45474 .44539 L
s
.45537 .44369 m
.45462 .44539 L
s
.45539 .4437 m
.45464 .44539 L
s
.42899 .44576 m
.42815 .44426 L
s
.45551 .44367 m
.45477 .44538 L
s
.39339 .4467 m
.39315 .44586 L
s
.42897 .44575 m
.42813 .44425 L
s
.27462 .4474 m
.2745 .44691 L
s
.48775 .44322 m
.48763 .44415 L
s
.42915 .44574 m
.42829 .44424 L
s
.45543 .44367 m
.45468 .44537 L
s
.45548 .44365 m
.45476 .44536 L
s
.48775 .4432 m
.48763 .44414 L
s
.42911 .44573 m
.42827 .44423 L
s
.45539 .44365 m
.45466 .44536 L
s
.16616 .4555 m
.16606 .45514 L
s
.45541 .44364 m
.45469 .44535 L
s
.45547 .44365 m
.45472 .44535 L
s
.39336 .44666 m
.39313 .44582 L
s
.42898 .44571 m
.42816 .44421 L
s
.62424 .44272 m
.62418 .44317 L
s
.35466 .45004 m
.35444 .44941 L
s
.42904 .4457 m
.4282 .4442 L
s
.48772 .44317 m
.4876 .44411 L
s
.45543 .44362 m
.45471 .44532 L
s
.62411 .4427 m
.62404 .44316 L
s
.35473 .45003 m
.3545 .44939 L
s
.39334 .44662 m
.39311 .44577 L
s
.42897 .44567 m
.42814 .44416 L
s
.45554 .44357 m
.45484 .44528 L
s
.45548 .44358 m
.45477 .44528 L
s
.42895 .44565 m
.42814 .44414 L
s
.42903 .44565 m
.42822 .44414 L
s
.429 .44565 m
.42818 .44414 L
s
.45542 .44357 m
.45472 .44528 L
s
.35459 .44999 m
.35437 .44936 L
s
.42896 .44565 m
.42815 .44414 L
s
.1661 .45543 m
.166 .45507 L
s
.4555 .44355 m
.45479 .44526 L
s
.42905 .44563 m
.42824 .44412 L
s
.3933 .44659 m
.39307 .44575 L
s
.45552 .44354 m
.45482 .44526 L
s
.42901 .44563 m
.4282 .44412 L
s
.4289 .44562 m
.42812 .4441 L
s
.42899 .44561 m
.42818 .4441 L
s
.27449 .44728 m
.27437 .44679 L
s
.71484 .43467 m
.71481 .43504 L
s
.42894 .44561 m
.42812 .4441 L
s
.42893 .44561 m
.42813 .4441 L
s
.42898 .4456 m
.42818 .44409 L
s
.3933 .44656 m
.39307 .44572 L
s
.18512 .5462 m
.18495 .54582 L
s
.45554 .44351 m
.45486 .44522 L
s
.45542 .44351 m
.45473 .44523 L
s
.42895 .44558 m
.42815 .44407 L
s
.45553 .4435 m
.45485 .44521 L
s
.48774 .44306 m
.48763 .444 L
s
.42899 .44558 m
.42818 .44408 L
s
.45546 .44351 m
.45476 .44521 L
s
.42886 .44559 m
.42806 .44408 L
s
.39332 .44653 m
.3931 .44568 L
s
.52725 .43993 m
.52716 .44062 L
s
.45546 .44348 m
.45478 .44519 L
s
.45554 .44348 m
.45485 .44519 L
s
.45547 .44347 m
.4548 .44519 L
s
.42899 .44556 m
.4282 .44405 L
s
.84808 .28665 m
.84818 .28689 L
s
.45551 .44346 m
.45485 .44518 L
s
.42889 .44555 m
.42812 .44403 L
s
.45554 .44346 m
.45485 .44518 L
s
.45549 .44346 m
.45482 .44517 L
s
.45544 .44346 m
.45476 .44518 L
s
.45551 .44345 m
.45484 .44516 L
s
.45542 .44344 m
.45477 .44516 L
s
.4289 .44553 m
.42813 .44402 L
s
.52724 .4399 m
.52715 .44058 L
s
.429 .44552 m
.4282 .444 L
s
.45547 .44343 m
.45481 .44515 L
s
.39327 .44648 m
.39305 .44564 L
s
.42886 .44552 m
.42808 .44401 L
s
.52733 .43987 m
.52723 .44055 L
s
.71486 .43457 m
.71482 .43494 L
s
.45558 .44339 m
.45494 .44512 L
s
.42889 .4455 m
.42812 .44398 L
s
.39338 .44645 m
.39316 .44561 L
s
.35454 .44985 m
.35433 .44921 L
s
.48777 .44297 m
.48766 .44391 L
s
.42884 .44548 m
.42808 .44396 L
s
.52719 .43986 m
.52711 .44054 L
s
.42883 .44547 m
.42807 .44395 L
s
.42885 .44547 m
.42809 .44395 L
s
.48772 .44294 m
.48762 .44388 L
s
.42889 .44546 m
.42813 .44394 L
s
.42883 .44546 m
.42808 .44394 L
s
.48781 .44293 m
.4877 .44387 L
s
.42894 .44545 m
.42818 .44393 L
s
.27442 .44712 m
.2743 .44664 L
s
.45554 .44335 m
.45489 .44507 L
s
.4555 .44335 m
.45487 .44507 L
s
.62414 .44247 m
.62407 .44292 L
s
.42883 .44544 m
.42807 .44392 L
s
.42876 .44545 m
.42801 .44392 L
s
.42886 .44543 m
.4281 .44391 L
s
.62419 .44246 m
.62412 .44291 L
s
.39333 .44639 m
.3931 .44555 L
s
.45553 .44333 m
.45491 .44505 L
s
.39331 .4464 m
.39309 .44555 L
s
.48776 .44291 m
.48766 .44385 L
s
.45549 .44333 m
.45486 .44505 L
s
.48777 .44291 m
.48767 .44384 L
s
.52722 .4398 m
.52713 .44048 L
s
.42893 .44541 m
.42819 .44389 L
s
.35449 .44977 m
.35427 .44914 L
s
.4289 .44541 m
.42816 .44389 L
s
.48779 .4429 m
.48768 .44383 L
s
.48772 .44289 m
.48762 .44383 L
s
.42882 .4454 m
.42808 .44388 L
s
.4555 .4433 m
.45488 .44503 L
s
.45555 .4433 m
.45493 .44503 L
s
.45555 .4433 m
.45494 .44503 L
s
.42886 .4454 m
.42811 .44388 L
s
.39331 .44636 m
.39309 .44551 L
s
.42879 .4454 m
.42805 .44387 L
s
.42878 .44539 m
.42805 .44387 L
s
.42881 .44539 m
.42808 .44386 L
s
.45555 .44328 m
.45494 .44501 L
s
.39326 .44636 m
.39304 .44551 L
s
.35452 .44974 m
.35431 .44911 L
s
.45556 .44328 m
.45494 .44501 L
s
.4288 .44537 m
.42808 .44385 L
s
.45547 .44327 m
.45486 .445 L
s
.42877 .44537 m
.42804 .44384 L
s
.39326 .44633 m
.39304 .44549 L
s
.52723 .43975 m
.52715 .44043 L
s
.48773 .44284 m
.48763 .44378 L
s
.52724 .43974 m
.52715 .44042 L
s
.45552 .44325 m
.45491 .44498 L
s
.45556 .44324 m
.45495 .44497 L
s
.39328 .44631 m
.39307 .44547 L
s
.45554 .44324 m
.45493 .44497 L
s
.16606 .45514 m
.16596 .45478 L
s
.4555 .44323 m
.4549 .44496 L
s
.45561 .44323 m
.455 .44496 L
s
.39326 .4463 m
.39304 .44546 L
s
.42874 .44532 m
.42803 .44379 L
s
.45557 .4432 m
.45499 .44494 L
s
.48774 .4428 m
.48765 .44374 L
s
.45551 .44319 m
.45493 .44493 L
s
.45557 .44319 m
.45497 .44492 L
s
.42873 .4453 m
.42803 .44377 L
s
.42868 .44531 m
.42798 .44377 L
s
.42881 .44529 m
.42809 .44377 L
s
.45558 .44317 m
.455 .44491 L
s
.42873 .44528 m
.42803 .44375 L
s
.35447 .44966 m
.35426 .44903 L
s
.84797 .2864 m
.84808 .28665 L
s
.42873 .44528 m
.42803 .44374 L
s
.5273 .43965 m
.52722 .44033 L
s
.45558 .44315 m
.45502 .44489 L
s
.45553 .44315 m
.45496 .44489 L
s
.42878 .44526 m
.42808 .44373 L
s
.166 .45507 m
.1659 .45471 L
s
.39323 .44623 m
.39302 .44538 L
s
.42871 .44525 m
.42802 .44372 L
s
.42881 .44525 m
.42811 .44372 L
s
.42871 .44525 m
.42801 .44372 L
s
.42874 .44525 m
.42805 .44371 L
s
.39326 .44622 m
.39305 .44538 L
s
.42875 .44525 m
.42805 .44372 L
s
.62431 .44227 m
.62424 .44272 L
s
.45551 .44313 m
.45495 .44486 L
s
.2745 .44691 m
.27438 .44643 L
s
.48776 .44273 m
.48767 .44367 L
s
.42868 .44523 m
.42799 .4437 L
s
.62417 .44225 m
.62411 .4427 L
s
.42859 .44523 m
.42791 .44369 L
s
.45558 .4431 m
.45502 .44484 L
s
.45557 .44309 m
.45503 .44484 L
s
.71488 .4343 m
.71484 .43467 L
s
.42866 .44521 m
.42799 .44367 L
s
.45548 .44309 m
.45493 .44483 L
s
.45562 .44308 m
.45507 .44482 L
s
.42873 .4452 m
.42804 .44366 L
s
.42876 .4452 m
.42807 .44366 L
s
.4287 .4452 m
.42801 .44366 L
s
.48771 .44268 m
.48762 .44362 L
s
.45566 .44306 m
.45511 .4448 L
s
.35446 .44955 m
.35425 .44892 L
s
.18495 .54582 m
.18477 .54544 L
s
.39328 .44615 m
.39307 .4453 L
s
.39331 .44614 m
.3931 .4453 L
s
.45555 .44305 m
.45502 .44479 L
s
.45558 .44305 m
.45504 .4448 L
s
.3545 .44955 m
.35429 .44892 L
s
.52726 .43956 m
.52718 .44024 L
s
.48775 .44265 m
.48766 .44359 L
s
.45557 .44304 m
.45503 .44478 L
s
.45558 .44303 m
.45504 .44477 L
s
.4556 .44302 m
.45508 .44477 L
s
.48772 .44265 m
.48763 .44358 L
s
.42873 .44515 m
.42806 .44361 L
s
.42864 .44515 m
.42798 .44361 L
s
.48776 .44264 m
.48767 .44358 L
s
.42867 .44514 m
.42802 .4436 L
s
.45558 .44301 m
.45505 .44476 L
s
.45559 .443 m
.45508 .44475 L
s
.42861 .44514 m
.42795 .44359 L
s
.45556 .44301 m
.45502 .44475 L
s
.45564 .443 m
.45511 .44475 L
s
.39322 .4461 m
.39302 .44526 L
s
.48777 .44261 m
.48768 .44355 L
s
.52724 .43951 m
.52716 .44019 L
s
.42864 .44511 m
.428 .44357 L
s
.45552 .443 m
.45499 .44474 L
s
.27437 .44679 m
.27425 .44631 L
s
.45556 .44298 m
.45505 .44473 L
s
.39326 .44608 m
.39306 .44523 L
s
.42864 .4451 m
.428 .44356 L
s
.39322 .44608 m
.39302 .44524 L
s
.7149 .43419 m
.71486 .43457 L
s
.35439 .44947 m
.35418 .44884 L
s
.42866 .44508 m
.42801 .44354 L
s
.48781 .44258 m
.48773 .44352 L
s
.42865 .44508 m
.428 .44354 L
s
.42855 .44508 m
.42791 .44354 L
s
.39321 .44605 m
.39301 .44521 L
s
.48773 .44256 m
.48765 .4435 L
s
.45552 .44294 m
.45501 .44469 L
s
.45551 .44293 m
.45502 .44468 L
s
.42855 .44507 m
.42792 .44352 L
s
.42862 .44506 m
.42798 .44351 L
s
.48779 .44256 m
.48771 .44349 L
s
.42868 .44505 m
.42804 .44351 L
s
.42866 .44505 m
.42802 .44351 L
s
.42862 .44506 m
.42798 .44351 L
s
.4556 .44291 m
.45512 .44466 L
s
.42859 .44505 m
.42794 .4435 L
s
.42853 .44505 m
.4279 .4435 L
s
.45563 .44291 m
.45514 .44466 L
s
.42859 .44504 m
.42798 .44349 L
s
.45562 .4429 m
.45514 .44465 L
s
.42863 .44503 m
.428 .44348 L
s
.35444 .44941 m
.35423 .44877 L
s
.48773 .44252 m
.48765 .44346 L
s
.84786 .28616 m
.84797 .2864 L
s
.45555 .44287 m
.45507 .44463 L
s
.3545 .44939 m
.35429 .44876 L
s
.45561 .44285 m
.45515 .44461 L
s
.39319 .44598 m
.39299 .44513 L
s
.42861 .44499 m
.42799 .44345 L
s
.45559 .44286 m
.45511 .44461 L
s
.42851 .44499 m
.42789 .44344 L
s
.42859 .44498 m
.42799 .44343 L
s
.6242 .44201 m
.62414 .44247 L
s
.35437 .44936 m
.35417 .44872 L
s
.4286 .44497 m
.42797 .44342 L
s
.62425 .44201 m
.62419 .44246 L
s
.45559 .44283 m
.45512 .44458 L
s
.45563 .44283 m
.45515 .44458 L
s
.45562 .44283 m
.45514 .44458 L
s
.42851 .44496 m
.42791 .44341 L
s
.45562 .44282 m
.45515 .44457 L
s
.16596 .45478 m
.16586 .45442 L
s
.45567 .44281 m
.4552 .44457 L
s
.2743 .44664 m
.27418 .44615 L
s
.45553 .44281 m
.45507 .44456 L
s
.45557 .44279 m
.45513 .44455 L
s
.45563 .44279 m
.45517 .44455 L
s
.45561 .44279 m
.45515 .44455 L
s
.42853 .44493 m
.42794 .44337 L
s
.39322 .44591 m
.39303 .44506 L
s
.45555 .44278 m
.4551 .44454 L
s
.48776 .44242 m
.48768 .44336 L
s
.42854 .44492 m
.42794 .44337 L
s
.42853 .44491 m
.42795 .44335 L
s
.42844 .44491 m
.42786 .44336 L
s
.42855 .4449 m
.42796 .44335 L
s
.42846 .44491 m
.42787 .44335 L
s
.42854 .4449 m
.42795 .44334 L
s
.42851 .4449 m
.42792 .44335 L
s
.45558 .44277 m
.45512 .44452 L
s
.45559 .44274 m
.45515 .4445 L
s
.45562 .44273 m
.4552 .44449 L
s
.42853 .44488 m
.42796 .44332 L
s
.45551 .44273 m
.45508 .44449 L
s
.39315 .44586 m
.39296 .44501 L
s
.1659 .45471 m
.16581 .45435 L
s
.42858 .44486 m
.42799 .44331 L
s
.52732 .43925 m
.52725 .43993 L
s
.42853 .44485 m
.42796 .44329 L
s
.42844 .44486 m
.42787 .4433 L
s
.42848 .44485 m
.4279 .4433 L
s
.45566 .4427 m
.45524 .44446 L
s
.42853 .44483 m
.42796 .44328 L
s
.4286 .44483 m
.42802 .44327 L
s
.39313 .44582 m
.39294 .44498 L
s
.42851 .44483 m
.42796 .44327 L
s
.52732 .43922 m
.52724 .4399 L
s
.4556 .44267 m
.4552 .44443 L
s
.71492 .43392 m
.71488 .4343 L
s
.42843 .44482 m
.42787 .44327 L
s
.35433 .44921 m
.35412 .44858 L
s
.42841 .44482 m
.42786 .44325 L
s
.45563 .44266 m
.45521 .44442 L
s
.48776 .44231 m
.48769 .44325 L
s
.5274 .43919 m
.52733 .43987 L
s
.45558 .44265 m
.45517 .44441 L
s
.42849 .44479 m
.42794 .44323 L
s
.39311 .44577 m
.39293 .44493 L
s
.62437 .44182 m
.62431 .44227 L
s
.45561 .44262 m
.45521 .44439 L
s
.45559 .44262 m
.45519 .44439 L
s
.48782 .44228 m
.48775 .44322 L
s
.45567 .44262 m
.45526 .44439 L
s
.52726 .43918 m
.52719 .43986 L
s
.42837 .44477 m
.42784 .44321 L
s
.45558 .44261 m
.45518 .44438 L
s
.48782 .44226 m
.48775 .4432 L
s
.45557 .44261 m
.45519 .44437 L
s
.62423 .4418 m
.62417 .44225 L
s
.39307 .44575 m
.39289 .4449 L
s
.42846 .44475 m
.42793 .44318 L
s
.18477 .54544 m
.1846 .54506 L
s
.45565 .44259 m
.45526 .44436 L
s
.35427 .44914 m
.35407 .4485 L
s
.84776 .28591 m
.84786 .28616 L
s
.45568 .44258 m
.45529 .44435 L
s
.27438 .44643 m
.27427 .44594 L
s
.42845 .44473 m
.42792 .44316 L
s
.48778 .44223 m
.48772 .44317 L
s
.42846 .44472 m
.42794 .44316 L
s
.45564 .44257 m
.45525 .44434 L
s
.42844 .44472 m
.4279 .44316 L
s
.39307 .44572 m
.39289 .44487 L
s
.45564 .44257 m
.45524 .44433 L
s
.45556 .44256 m
.45518 .44433 L
s
.52729 .43912 m
.52722 .4398 L
s
.4284 .44471 m
.42787 .44315 L
s
.35431 .44911 m
.3541 .44847 L
s
.71493 .43382 m
.7149 .43419 L
s
.42837 .4447 m
.42786 .44313 L
s
.45561 .44254 m
.45525 .44431 L
s
.42841 .44469 m
.42788 .44313 L
s
.45567 .44253 m
.4553 .4443 L
s
.42841 .44469 m
.42789 .44313 L
s
.45559 .44254 m
.45521 .4443 L
s
.3931 .44568 m
.39291 .44484 L
s
.42839 .44468 m
.42788 .44311 L
s
.45561 .44252 m
.45525 .44429 L
s
.42831 .44468 m
.42781 .44311 L
s
.42843 .44468 m
.4279 .44311 L
s
.4284 .44466 m
.42788 .44309 L
s
.42848 .44466 m
.42795 .4431 L
s
.42846 .44466 m
.42795 .44309 L
s
.5273 .43907 m
.52723 .43975 L
s
.4556 .44249 m
.45525 .44426 L
s
.52731 .43906 m
.52724 .43974 L
s
.45561 .44248 m
.45526 .44425 L
s
.45559 .44248 m
.45525 .44425 L
s
.42842 .44463 m
.4279 .44307 L
s
.39305 .44564 m
.39287 .44479 L
s
.42833 .44463 m
.42783 .44307 L
s
.42838 .44463 m
.42789 .44306 L
s
.4878 .44212 m
.48774 .44306 L
s
.35426 .44903 m
.35406 .44839 L
s
.39316 .44561 m
.39298 .44476 L
s
.27425 .44631 m
.27414 .44582 L
s
.42832 .4446 m
.42784 .44303 L
s
.45569 .44243 m
.45536 .44421 L
s
.45561 .44243 m
.45526 .44421 L
s
.45558 .44242 m
.45526 .4442 L
s
.4557 .44241 m
.45537 .44419 L
s
.4556 .44242 m
.45526 .44419 L
s
.42834 .44457 m
.42786 .443 L
s
.42837 .44457 m
.42788 .443 L
s
.52737 .43897 m
.5273 .43965 L
s
.16586 .45442 m
.16577 .45406 L
s
.3931 .44555 m
.39293 .4447 L
s
.42838 .44455 m
.42791 .44297 L
s
.39309 .44555 m
.39291 .4447 L
s
.42839 .44454 m
.42792 .44296 L
s
.42827 .44454 m
.4278 .44297 L
s
.45555 .44238 m
.45522 .44415 L
s
.45566 .44236 m
.45534 .44414 L
s
.45559 .44237 m
.45527 .44415 L
s
.45569 .44236 m
.45538 .44413 L
s
.45562 .44235 m
.45532 .44413 L
s
.48782 .44203 m
.48777 .44297 L
s
.42832 .44451 m
.42785 .44294 L
s
.45559 .44235 m
.45528 .44413 L
s
.42827 .44452 m
.42781 .44294 L
s
.42838 .44451 m
.42793 .44293 L
s
.39309 .44551 m
.39291 .44467 L
s
.45557 .44234 m
.45529 .44412 L
s
.62425 .44156 m
.6242 .44201 L
s
.42829 .44451 m
.42782 .44293 L
s
.45559 .44234 m
.4553 .44412 L
s
.45563 .44234 m
.45531 .44412 L
s
.42834 .4445 m
.42787 .44293 L
s
.6243 .44156 m
.62425 .44201 L
s
.45565 .44234 m
.45533 .44412 L
s
.35425 .44892 m
.35405 .44828 L
s
.39304 .44551 m
.39286 .44466 L
s
.42838 .44449 m
.42792 .44292 L
s
.35429 .44892 m
.35409 .44828 L
s
.45563 .44232 m
.45534 .4441 L
s
.48778 .442 m
.48772 .44294 L
s
.42836 .44448 m
.42789 .44291 L
s
.42827 .44449 m
.42781 .44291 L
s
.39304 .44549 m
.39287 .44464 L
s
.48786 .44199 m
.48781 .44293 L
s
.16581 .45435 m
.16571 .45399 L
s
.4556 .44231 m
.45529 .44409 L
s
.42827 .44448 m
.42783 .4429 L
s
.42837 .44447 m
.42791 .44289 L
s
.84765 .28566 m
.84776 .28591 L
s
.39307 .44547 m
.39289 .44462 L
s
.52733 .43888 m
.52726 .43956 L
s
.48781 .44197 m
.48776 .44291 L
s
.48783 .44197 m
.48777 .44291 L
s
.39304 .44546 m
.39287 .44461 L
s
.42831 .44445 m
.42786 .44287 L
s
.27418 .44615 m
.27407 .44567 L
s
.48784 .44196 m
.48779 .4429 L
s
.42825 .44444 m
.42782 .44286 L
s
.4283 .44444 m
.42786 .44286 L
s
.48777 .44195 m
.48772 .44289 L
s
.42828 .44443 m
.42783 .44285 L
s
.42829 .44443 m
.42785 .44285 L
s
.45569 .44225 m
.45542 .44403 L
s
.71496 .43355 m
.71492 .43392 L
s
.35418 .44884 m
.35399 .4482 L
s
.5273 .43883 m
.52724 .43951 L
s
.45563 .44223 m
.45537 .44402 L
s
.45559 .44223 m
.45531 .44401 L
s
.45554 .44222 m
.45527 .444 L
s
.42818 .4444 m
.42776 .44282 L
s
.45558 .44221 m
.45533 .44399 L
s
.48778 .4419 m
.48773 .44284 L
s
.42833 .44438 m
.42791 .4428 L
s
.39302 .44538 m
.39285 .44453 L
s
.4556 .44219 m
.45535 .44398 L
s
.39305 .44538 m
.39288 .44453 L
s
.42819 .44436 m
.42778 .44278 L
s
.45557 .44217 m
.45534 .44396 L
s
.35423 .44877 m
.35404 .44814 L
s
.42828 .44434 m
.42787 .44276 L
s
.42821 .44435 m
.42781 .44276 L
s
.42822 .44434 m
.42781 .44276 L
s
.45565 .44216 m
.45541 .44394 L
s
.42822 .44434 m
.42781 .44276 L
s
.48778 .44186 m
.48774 .4428 L
s
.45568 .44216 m
.45543 .44394 L
s
.45562 .44216 m
.45536 .44395 L
s
.4283 .44432 m
.42789 .44274 L
s
.35429 .44876 m
.3541 .44812 L
s
.45562 .44215 m
.45537 .44394 L
s
.1846 .54506 m
.18443 .54468 L
s
.42829 .44431 m
.42788 .44273 L
s
.45565 .44214 m
.45542 .44392 L
s
.42825 .44431 m
.42785 .44273 L
s
.71497 .43345 m
.71493 .43382 L
s
.4282 .44431 m
.42779 .44273 L
s
.62442 .44137 m
.62437 .44182 L
s
.4282 .4443 m
.42782 .44272 L
s
.4556 .44213 m
.45537 .44391 L
s
.35417 .44872 m
.35398 .44808 L
s
.45559 .44213 m
.45535 .44391 L
s
.42826 .44429 m
.42784 .44271 L
s
.3931 .4453 m
.39294 .44445 L
s
.39307 .4453 m
.3929 .44445 L
s
.62429 .44135 m
.62423 .4418 L
s
.4556 .44211 m
.45536 .4439 L
s
.45555 .44209 m
.45534 .44388 L
s
.42829 .44426 m
.42789 .44268 L
s
.42826 .44427 m
.42787 .44269 L
s
.4878 .44179 m
.48776 .44273 L
s
.42822 .44426 m
.42782 .44268 L
s
.45565 .44209 m
.45541 .44387 L
s
.42815 .44426 m
.42778 .44267 L
s
.45558 .44207 m
.45536 .44386 L
s
.45563 .44207 m
.45542 .44385 L
s
.42813 .44425 m
.42775 .44267 L
s
.42829 .44424 m
.42789 .44266 L
s
.39302 .44526 m
.39285 .44441 L
s
.42827 .44423 m
.42789 .44264 L
s
.27427 .44594 m
.27416 .44546 L
s
.45567 .44204 m
.45546 .44383 L
s
.45557 .44204 m
.45538 .44383 L
s
.39306 .44523 m
.39289 .44438 L
s
.39302 .44524 m
.39285 .44439 L
s
.48775 .44174 m
.48771 .44268 L
s
.45555 .44203 m
.45535 .44382 L
s
.42816 .44421 m
.42781 .44262 L
s
.84754 .28542 m
.84765 .28566 L
s
.4282 .4442 m
.42783 .44261 L
s
.45565 .442 m
.45546 .44379 L
s
.39301 .44521 m
.39286 .44436 L
s
.48778 .44171 m
.48775 .44265 L
s
.48775 .44171 m
.48772 .44265 L
s
.45555 .44199 m
.45538 .44378 L
s
.4878 .4417 m
.48776 .44264 L
s
.16577 .45406 m
.16567 .4537 L
s
.42814 .44416 m
.42778 .44257 L
s
.52739 .43857 m
.52732 .43925 L
s
.45566 .44196 m
.45547 .44376 L
s
.42822 .44414 m
.42786 .44256 L
s
.42818 .44414 m
.42783 .44255 L
s
.48781 .44167 m
.48777 .44261 L
s
.42814 .44414 m
.4278 .44255 L
s
.42815 .44414 m
.4278 .44255 L
s
.45562 .44195 m
.45545 .44375 L
s
.35412 .44858 m
.35393 .44794 L
s
.45562 .44195 m
.45544 .44374 L
s
.42824 .44412 m
.42789 .44253 L
s
.4282 .44412 m
.42786 .44253 L
s
.45562 .44193 m
.45546 .44372 L
s
.52738 .43854 m
.52732 .43922 L
s
.39299 .44513 m
.39284 .44428 L
s
.48785 .44164 m
.48781 .44258 L
s
.45563 .44192 m
.45547 .44371 L
s
.42818 .4441 m
.42784 .44251 L
s
.45557 .44192 m
.45541 .44371 L
s
.42812 .4441 m
.4278 .44251 L
s
.27414 .44582 m
.27403 .44533 L
s
.42812 .4441 m
.42778 .44251 L
s
.42813 .4441 m
.42779 .44251 L
s
.42818 .44409 m
.42785 .4425 L
s
.45564 .44191 m
.45547 .4437 L
s
.48776 .44162 m
.48773 .44256 L
s
.52746 .43851 m
.5274 .43919 L
s
.16571 .45399 m
.16561 .45363 L
s
.45568 .4419 m
.4555 .44369 L
s
.48782 .44161 m
.48779 .44256 L
s
.45556 .4419 m
.45539 .4437 L
s
.45553 .4419 m
.45537 .44369 L
s
.42815 .44407 m
.42781 .44248 L
s
.42818 .44408 m
.42783 .44249 L
s
.45566 .44188 m
.45551 .44367 L
s
.42806 .44408 m
.42774 .44248 L
s
.35407 .4485 m
.35388 .44786 L
s
.45558 .44188 m
.45543 .44367 L
s
.52732 .43849 m
.52726 .43918 L
s
.4282 .44405 m
.42788 .44246 L
s
.45561 .44185 m
.45548 .44365 L
s
.45553 .44186 m
.45539 .44365 L
s
.48776 .44158 m
.48773 .44252 L
s
.45563 .44186 m
.45547 .44365 L
s
.62431 .44111 m
.62425 .44156 L
s
.45555 .44185 m
.45541 .44364 L
s
.39303 .44506 m
.39288 .44421 L
s
.3541 .44847 m
.35392 .44784 L
s
.42812 .44403 m
.42781 .44244 L
s
.62436 .4411 m
.6243 .44156 L
s
.71499 .43318 m
.71496 .43355 L
s
.42813 .44402 m
.42782 .44243 L
s
.45555 .44182 m
.45543 .44362 L
s
.4282 .444 m
.42788 .44241 L
s
.52735 .43844 m
.52729 .43912 L
s
.42808 .44401 m
.42777 .44241 L
s
.39296 .44501 m
.39281 .44416 L
s
.42812 .44398 m
.42782 .44238 L
s
.4556 .44178 m
.45548 .44358 L
s
.45564 .44177 m
.45554 .44357 L
s
.42808 .44396 m
.4278 .44237 L
s
.45553 .44177 m
.45542 .44357 L
s
.42807 .44395 m
.42778 .44235 L
s
.42809 .44395 m
.4278 .44235 L
s
.45561 .44176 m
.4555 .44355 L
s
.52736 .43839 m
.5273 .43907 L
s
.39294 .44498 m
.39279 .44412 L
s
.52736 .43838 m
.52731 .43906 L
s
.42813 .44394 m
.42784 .44235 L
s
.48778 .44147 m
.48776 .44242 L
s
.45562 .44175 m
.45552 .44354 L
s
.42808 .44394 m
.42781 .44234 L
s
.27407 .44567 m
.27397 .44518 L
s
.35406 .44839 m
.35387 .44775 L
s
.42818 .44393 m
.42789 .44233 L
s
.42807 .44392 m
.42778 .44233 L
s
.84743 .28518 m
.84754 .28542 L
s
.42801 .44392 m
.42773 .44233 L
s
.4281 .44391 m
.42781 .44232 L
s
.715 .43308 m
.71497 .43345 L
s
.45551 .44171 m
.45542 .44351 L
s
.45562 .4417 m
.45554 .44351 L
s
.42819 .44389 m
.42791 .44229 L
s
.45562 .4417 m
.45553 .4435 L
s
.42816 .44389 m
.42788 .4423 L
s
.45557 .44171 m
.45546 .44351 L
s
.18443 .54468 m
.18426 .5443 L
s
.39293 .44493 m
.39278 .44408 L
s
.42808 .44388 m
.4278 .44228 L
s
.42811 .44388 m
.42782 .44228 L
s
.45556 .44168 m
.45546 .44348 L
s
.45563 .44168 m
.45554 .44348 L
s
.45555 .44167 m
.45547 .44347 L
s
.42805 .44387 m
.42779 .44228 L
s
.42805 .44387 m
.42778 .44227 L
s
.42808 .44386 m
.42781 .44226 L
s
.39289 .4449 m
.39275 .44405 L
s
.52743 .43829 m
.52737 .43897 L
s
.45557 .44165 m
.45551 .44346 L
s
.45562 .44166 m
.45554 .44346 L
s
.45553 .44166 m
.45544 .44346 L
s
.45557 .44166 m
.45549 .44346 L
s
.42808 .44385 m
.42782 .44225 L
s
.62448 .44091 m
.62442 .44137 L
s
.45559 .44164 m
.45551 .44345 L
s
.42804 .44384 m
.42779 .44224 L
s
.45547 .44163 m
.45542 .44344 L
s
.39289 .44487 m
.39275 .44402 L
s
.48778 .44137 m
.48776 .44231 L
s
.45553 .44163 m
.45547 .44343 L
s
.35405 .44828 m
.35386 .44764 L
s
.62434 .44089 m
.62429 .44135 L
s
.35409 .44828 m
.35391 .44764 L
s
.39291 .44484 m
.39277 .44398 L
s
.48784 .44134 m
.48782 .44228 L
s
.42803 .44379 m
.4278 .44219 L
s
.45562 .44159 m
.45558 .44339 L
s
.48783 .44132 m
.48782 .44226 L
s
.16567 .4537 m
.16558 .45334 L
s
.42803 .44377 m
.4278 .44217 L
s
.42798 .44377 m
.42774 .44217 L
s
.42809 .44377 m
.42785 .44216 L
s
.42803 .44375 m
.4278 .44215 L
s
.45559 .44155 m
.45554 .44335 L
s
.48779 .44129 m
.48778 .44223 L
s
.45554 .44155 m
.4555 .44335 L
s
.52738 .4382 m
.52733 .43888 L
s
.39287 .44479 m
.39273 .44394 L
s
.35399 .4482 m
.3538 .44756 L
s
.42803 .44374 m
.42782 .44214 L
s
.42808 .44373 m
.42785 .44213 L
s
.45556 .44152 m
.45553 .44333 L
s
.27416 .44546 m
.27405 .44497 L
s
.45553 .44152 m
.45549 .44333 L
s
.42811 .44372 m
.42789 .44212 L
s
.42802 .44372 m
.4278 .44212 L
s
.42801 .44372 m
.42778 .44212 L
s
.42805 .44372 m
.42783 .44211 L
s
.39298 .44476 m
.39284 .44391 L
s
.42805 .44371 m
.42785 .44211 L
s
.45552 .4415 m
.4555 .4433 L
s
.52735 .43815 m
.5273 .43883 L
s
.45556 .44149 m
.45555 .4433 L
s
.16561 .45363 m
.16552 .45327 L
s
.42799 .4437 m
.42778 .44209 L
s
.45556 .44149 m
.45555 .4433 L
s
.42791 .44369 m
.42771 .44208 L
s
.45555 .44147 m
.45555 .44328 L
s
.45559 .44148 m
.45556 .44328 L
s
.42799 .44367 m
.4278 .44207 L
s
.35404 .44814 m
.35385 .4475 L
s
.42804 .44366 m
.42782 .44206 L
s
.42807 .44366 m
.42786 .44206 L
s
.45547 .44146 m
.45547 .44327 L
s
.42801 .44366 m
.42781 .44206 L
s
.39293 .4447 m
.39279 .44385 L
s
.39291 .4447 m
.39278 .44385 L
s
.3541 .44812 m
.35391 .44748 L
s
.84732 .28493 m
.84743 .28518 L
s
.45554 .44145 m
.45552 .44325 L
s
.45557 .44144 m
.45556 .44324 L
s
.48781 .44118 m
.4878 .44212 L
s
.45554 .44143 m
.45554 .44324 L
s
.71502 .43281 m
.71499 .43318 L
s
.45551 .44143 m
.4555 .44323 L
s
.45561 .44142 m
.45561 .44323 L
s
.35398 .44808 m
.3538 .44745 L
s
.39291 .44467 m
.39278 .44381 L
s
.42806 .44361 m
.42786 .44201 L
s
.39286 .44466 m
.39273 .44381 L
s
.42798 .44361 m
.42779 .442 L
s
.45556 .4414 m
.45557 .4432 L
s
.42802 .4436 m
.42785 .44199 L
s
.27403 .44533 m
.27393 .44485 L
s
.45549 .44139 m
.45551 .44319 L
s
.45556 .44139 m
.45557 .44319 L
s
.42795 .44359 m
.42777 .44199 L
s
.39287 .44464 m
.39274 .44379 L
s
.45555 .44137 m
.45558 .44317 L
s
.428 .44357 m
.42783 .44196 L
s
.62436 .44066 m
.62431 .44111 L
s
.39289 .44462 m
.39276 .44377 L
s
.62441 .44065 m
.62436 .4411 L
s
.428 .44356 m
.42785 .44195 L
s
.39287 .44461 m
.39275 .44376 L
s
.45549 .44135 m
.45553 .44315 L
s
.45554 .44134 m
.45558 .44315 L
s
.42801 .44354 m
.42784 .44194 L
s
.428 .44354 m
.42783 .44193 L
s
.48783 .44109 m
.48782 .44203 L
s
.42791 .44354 m
.42774 .44193 L
s
.45547 .44132 m
.45551 .44313 L
s
.42792 .44352 m
.42777 .44191 L
s
.71503 .43271 m
.715 .43308 L
s
.42804 .44351 m
.42788 .4419 L
s
.42798 .44351 m
.42783 .4419 L
s
.42802 .44351 m
.42786 .4419 L
s
.48778 .44106 m
.48778 .442 L
s
.42798 .44351 m
.42782 .4419 L
s
.42794 .4435 m
.42778 .44189 L
s
.48786 .44105 m
.48786 .44199 L
s
.45553 .4413 m
.45558 .4431 L
s
.4279 .4435 m
.42776 .44189 L
s
.45551 .44128 m
.45557 .44309 L
s
.45542 .44128 m
.45548 .44309 L
s
.42798 .44349 m
.42784 .44188 L
s
.428 .44348 m
.42786 .44187 L
s
.45557 .44127 m
.45562 .44308 L
s
.39285 .44453 m
.39273 .44368 L
s
.39288 .44453 m
.39276 .44367 L
s
.48781 .44103 m
.48781 .44197 L
s
.48782 .44102 m
.48783 .44197 L
s
.18426 .5443 m
.18409 .54391 L
s
.48783 .44101 m
.48784 .44196 L
s
.35393 .44794 m
.35376 .4473 L
s
.48776 .44101 m
.48777 .44195 L
s
.45561 .44125 m
.45566 .44306 L
s
.45548 .44124 m
.45555 .44305 L
s
.45551 .44124 m
.45558 .44305 L
s
.42799 .44345 m
.42785 .44184 L
s
.52743 .43789 m
.52739 .43857 L
s
.42789 .44344 m
.42776 .44183 L
s
.42799 .44343 m
.42787 .44182 L
s
.4555 .44123 m
.45557 .44304 L
s
.4555 .44122 m
.45558 .44303 L
s
.27397 .44518 m
.27386 .44469 L
s
.45551 .44121 m
.4556 .44302 L
s
.42797 .44342 m
.42783 .44181 L
s
.4555 .4412 m
.45558 .44301 L
s
.45548 .44119 m
.45559 .443 L
s
.42791 .44341 m
.42779 .4418 L
s
.45549 .4412 m
.45556 .44301 L
s
.48777 .44096 m
.48778 .4419 L
s
.52742 .43786 m
.52738 .43854 L
s
.45557 .44119 m
.45564 .443 L
s
.39294 .44445 m
.39282 .4436 L
s
.3929 .44445 m
.39278 .4436 L
s
.45544 .44119 m
.45552 .443 L
s
.16558 .45334 m
.16548 .45298 L
s
.35388 .44786 m
.35371 .44722 L
s
.45547 .44117 m
.45556 .44298 L
s
.52751 .43783 m
.52746 .43851 L
s
.42794 .44337 m
.42783 .44176 L
s
.84721 .28469 m
.84732 .28493 L
s
.62453 .44046 m
.62448 .44091 L
s
.42794 .44337 m
.42783 .44176 L
s
.42795 .44335 m
.42785 .44174 L
s
.48778 .44091 m
.48778 .44186 L
s
.35392 .44784 m
.35374 .4472 L
s
.42796 .44335 m
.42786 .44174 L
s
.42786 .44336 m
.42776 .44174 L
s
.52736 .43781 m
.52732 .43849 L
s
.42787 .44335 m
.42776 .44174 L
s
.39285 .44441 m
.39273 .44355 L
s
.42795 .44334 m
.42784 .44173 L
s
.62439 .44044 m
.62434 .44089 L
s
.42792 .44335 m
.42782 .44174 L
s
.45542 .44113 m
.45552 .44294 L
s
.4554 .44112 m
.45551 .44293 L
s
.39289 .44438 m
.39278 .44353 L
s
.39285 .44439 m
.39274 .44353 L
s
.42796 .44332 m
.42787 .44171 L
s
.42799 .44331 m
.42788 .4417 L
s
.45547 .4411 m
.4556 .44291 L
s
.45552 .4411 m
.45563 .44291 L
s
.16552 .45327 m
.16543 .45291 L
s
.42796 .44329 m
.42787 .44168 L
s
.4555 .44109 m
.45562 .4429 L
s
.4279 .4433 m
.4278 .44168 L
s
.42787 .4433 m
.42779 .44168 L
s
.39286 .44436 m
.39274 .4435 L
s
.52739 .43776 m
.52735 .43844 L
s
.48779 .44084 m
.4878 .44179 L
s
.42796 .44328 m
.42787 .44167 L
s
.42802 .44327 m
.42793 .44166 L
s
.45542 .44106 m
.45555 .44287 L
s
.42796 .44327 m
.42788 .44165 L
s
.42787 .44327 m
.4278 .44165 L
s
.45546 .44104 m
.45561 .44285 L
s
.45545 .44105 m
.45559 .44286 L
s
.35387 .44775 m
.3537 .44711 L
s
.42786 .44325 m
.42779 .44164 L
s
.5274 .4377 m
.52736 .43839 L
s
.48774 .4408 m
.48775 .44174 L
s
.71505 .43244 m
.71502 .43281 L
s
.52741 .4377 m
.52736 .43838 L
s
.42794 .44323 m
.42787 .44162 L
s
.45544 .44102 m
.45559 .44283 L
s
.45549 .44102 m
.45563 .44283 L
s
.4555 .44102 m
.45562 .44283 L
s
.45547 .44101 m
.45562 .44282 L
s
.39284 .44428 m
.39273 .44343 L
s
.27405 .44497 m
.27395 .44448 L
s
.45552 .441 m
.45567 .44281 L
s
.42784 .44321 m
.42779 .44159 L
s
.48777 .44077 m
.48778 .44171 L
s
.45538 .441 m
.45553 .44281 L
s
.48773 .44076 m
.48775 .44171 L
s
.4554 .44098 m
.45557 .44279 L
s
.45548 .44098 m
.45563 .44279 L
s
.45546 .44098 m
.45561 .44279 L
s
.48778 .44076 m
.4878 .4417 L
s
.42793 .44318 m
.42788 .44157 L
s
.45539 .44097 m
.45555 .44278 L
s
.48779 .44073 m
.48781 .44167 L
s
.42792 .44316 m
.42788 .44155 L
s
.42794 .44316 m
.4279 .44154 L
s
.45543 .44096 m
.45558 .44277 L
s
.4279 .44316 m
.42784 .44155 L
s
.42787 .44315 m
.42782 .44153 L
s
.52747 .43761 m
.52743 .43829 L
s
.35386 .44764 m
.35369 .447 L
s
.45542 .44093 m
.45559 .44274 L
s
.39288 .44421 m
.39277 .44335 L
s
.42786 .44313 m
.42782 .44152 L
s
.45543 .44092 m
.45562 .44273 L
s
.35391 .44764 m
.35373 .447 L
s
.42788 .44313 m
.42784 .44151 L
s
.45532 .44092 m
.45551 .44273 L
s
.48783 .4407 m
.48785 .44164 L
s
.42789 .44313 m
.42786 .44151 L
s
.71506 .43234 m
.71503 .43271 L
s
.42788 .44311 m
.42786 .4415 L
s
.4279 .44311 m
.42786 .4415 L
s
.48774 .44068 m
.48776 .44162 L
s
.42781 .44311 m
.4278 .4415 L
s
.4878 .44067 m
.48782 .44161 L
s
.62441 .4402 m
.62436 .44066 L
s
.42795 .4431 m
.42791 .44148 L
s
.8471 .28444 m
.84721 .28469 L
s
.45548 .44088 m
.45566 .4427 L
s
.42788 .44309 m
.42785 .44148 L
s
.62446 .4402 m
.62441 .44065 L
s
.42795 .44309 m
.42794 .44147 L
s
.27393 .44485 m
.27382 .44436 L
s
.39281 .44416 m
.39271 .4433 L
s
.45539 .44086 m
.4556 .44267 L
s
.4279 .44307 m
.42788 .44145 L
s
.48774 .44064 m
.48776 .44158 L
s
.45543 .44085 m
.45563 .44266 L
s
.3538 .44756 m
.35364 .44693 L
s
.42783 .44307 m
.42781 .44145 L
s
.42789 .44306 m
.42789 .44144 L
s
.39279 .44412 m
.39269 .44327 L
s
.45538 .44084 m
.45558 .44265 L
s
.18409 .54391 m
.18393 .54353 L
s
.52741 .43752 m
.52738 .4382 L
s
.42784 .44303 m
.42784 .44141 L
s
.4554 .44081 m
.45561 .44262 L
s
.45536 .44081 m
.45559 .44262 L
s
.45546 .44081 m
.45567 .44262 L
s
.45535 .4408 m
.45558 .44261 L
s
.45534 .4408 m
.45557 .44261 L
s
.42788 .443 m
.42787 .44139 L
s
.42786 .443 m
.42787 .44138 L
s
.39278 .44408 m
.39268 .44322 L
s
.16548 .45298 m
.16539 .45262 L
s
.45543 .44077 m
.45565 .44259 L
s
.35385 .4475 m
.35369 .44686 L
s
.52739 .43747 m
.52735 .43815 L
s
.45545 .44077 m
.45568 .44258 L
s
.42791 .44297 m
.42793 .44136 L
s
.39275 .44405 m
.39265 .4432 L
s
.42792 .44296 m
.42794 .44135 L
s
.35391 .44748 m
.35375 .44684 L
s
.45541 .44076 m
.45564 .44257 L
s
.4278 .44297 m
.42783 .44135 L
s
.45542 .44076 m
.45564 .44257 L
s
.45532 .44075 m
.45556 .44256 L
s
.48775 .44053 m
.48778 .44147 L
s
.42785 .44294 m
.42786 .44132 L
s
.45536 .44073 m
.45561 .44254 L
s
.3538 .44745 m
.35363 .44681 L
s
.42781 .44294 m
.42784 .44132 L
s
.42793 .44293 m
.42796 .44132 L
s
.45543 .44072 m
.45567 .44253 L
s
.42782 .44293 m
.42784 .44132 L
s
.45536 .44073 m
.45559 .44254 L
s
.39275 .44402 m
.39266 .44316 L
s
.42787 .44293 m
.42789 .44131 L
s
.42792 .44292 m
.42795 .4413 L
s
.45536 .44071 m
.45561 .44252 L
s
.27386 .44469 m
.27376 .44421 L
s
.16543 .45291 m
.16533 .45254 L
s
.42789 .44291 m
.42791 .44129 L
s
.42781 .44291 m
.42784 .44129 L
s
.39277 .44398 m
.39268 .44313 L
s
.62457 .44001 m
.62453 .44046 L
s
.42791 .44289 m
.42793 .44128 L
s
.42783 .4429 m
.42787 .44128 L
s
.45533 .44068 m
.4556 .44249 L
s
.45534 .44067 m
.45561 .44248 L
s
.45531 .44066 m
.45559 .44248 L
s
.62444 .43999 m
.62439 .44044 L
s
.42786 .44287 m
.4279 .44125 L
s
.42782 .44286 m
.42788 .44124 L
s
.42786 .44286 m
.42792 .44124 L
s
.42783 .44285 m
.42787 .44123 L
s
.42785 .44285 m
.4279 .44123 L
s
.39273 .44394 m
.39264 .44308 L
s
.48774 .44043 m
.48778 .44137 L
s
.45533 .44062 m
.45561 .44243 L
s
.4554 .44062 m
.45569 .44243 L
s
.71508 .43207 m
.71505 .43244 L
s
.84699 .2842 m
.8471 .28444 L
s
.39284 .44391 m
.39275 .44305 L
s
.45528 .44061 m
.45558 .44242 L
s
.4878 .44039 m
.48784 .44134 L
s
.42776 .44282 m
.42783 .4412 L
s
.45541 .4406 m
.4557 .44241 L
s
.45531 .4406 m
.4556 .44242 L
s
.42791 .4428 m
.42798 .44118 L
s
.48779 .44038 m
.48783 .44132 L
s
.42778 .44278 m
.42786 .44116 L
s
.35376 .4473 m
.35359 .44666 L
s
.45525 .44057 m
.45555 .44238 L
s
.45528 .44056 m
.45559 .44237 L
s
.45535 .44055 m
.45566 .44236 L
s
.48775 .44035 m
.48779 .44129 L
s
.42787 .44276 m
.42795 .44114 L
s
.42781 .44276 m
.4279 .44114 L
s
.39279 .44385 m
.3927 .44299 L
s
.39278 .44385 m
.39269 .44299 L
s
.42781 .44276 m
.42789 .44114 L
s
.45538 .44054 m
.45569 .44236 L
s
.42781 .44276 m
.42788 .44114 L
s
.45531 .44054 m
.45562 .44235 L
s
.45528 .44054 m
.45559 .44235 L
s
.42789 .44274 m
.42797 .44112 L
s
.45523 .44053 m
.45557 .44234 L
s
.45527 .44053 m
.45559 .44234 L
s
.45532 .44053 m
.45563 .44234 L
s
.45534 .44053 m
.45565 .44234 L
s
.42788 .44273 m
.42796 .44111 L
s
.42785 .44273 m
.42794 .44111 L
s
.42779 .44273 m
.42788 .4411 L
s
.52746 .43721 m
.52743 .43789 L
s
.39278 .44381 m
.39269 .44296 L
s
.4553 .4405 m
.45563 .44232 L
s
.42782 .44272 m
.42792 .4411 L
s
.71509 .43197 m
.71506 .43234 L
s
.39273 .44381 m
.39264 .44295 L
s
.45529 .4405 m
.4556 .44231 L
s
.27395 .44448 m
.27385 .444 L
s
.42784 .44271 m
.42793 .44109 L
s
.35371 .44722 m
.35355 .44658 L
s
.39274 .44379 m
.39265 .44293 L
s
.52745 .43718 m
.52742 .43786 L
s
.42789 .44268 m
.42799 .44106 L
s
.42787 .44269 m
.42797 .44107 L
s
.42782 .44268 m
.42792 .44106 L
s
.39276 .44377 m
.39268 .44291 L
s
.35374 .4472 m
.35358 .44656 L
s
.42778 .44267 m
.4279 .44105 L
s
.52754 .43715 m
.52751 .43783 L
s
.39275 .44376 m
.39266 .4429 L
s
.42789 .44266 m
.42798 .44104 L
s
.42775 .44267 m
.42786 .44104 L
s
.45534 .44043 m
.45569 .44225 L
s
.48776 .44024 m
.48781 .44118 L
s
.42789 .44264 m
.42801 .44102 L
s
.52739 .43713 m
.52736 .43781 L
s
.45527 .44042 m
.45563 .44223 L
s
.45525 .44042 m
.45559 .44223 L
s
.62445 .43975 m
.62441 .4402 L
s
.45519 .44041 m
.45554 .44222 L
s
.6245 .43975 m
.62446 .4402 L
s
.42781 .44262 m
.42795 .44099 L
s
.45521 .4404 m
.45558 .44221 L
s
.42783 .44261 m
.42796 .44099 L
s
.18393 .54353 m
.18376 .54314 L
s
.16539 .45262 m
.1653 .45226 L
s
.45524 .44038 m
.4556 .44219 L
s
.39273 .44368 m
.39265 .44282 L
s
.52742 .43707 m
.52739 .43776 L
s
.27382 .44436 m
.27373 .44387 L
s
.39276 .44367 m
.39268 .44282 L
s
.45518 .44036 m
.45557 .44217 L
s
.3537 .44711 m
.35354 .44647 L
s
.42778 .44257 m
.42792 .44095 L
s
.45527 .44035 m
.45565 .44216 L
s
.42786 .44256 m
.42801 .44094 L
s
.45525 .44035 m
.45562 .44216 L
s
.45529 .44035 m
.45568 .44216 L
s
.42783 .44255 m
.42797 .44093 L
s
.48778 .44015 m
.48783 .44109 L
s
.4278 .44255 m
.42796 .44093 L
s
.4278 .44255 m
.42794 .44093 L
s
.84687 .28395 m
.84699 .2842 L
s
.45524 .44034 m
.45562 .44215 L
s
.42789 .44253 m
.42804 .44091 L
s
.45526 .44032 m
.45565 .44214 L
s
.42786 .44253 m
.428 .44091 L
s
.48773 .44012 m
.48778 .44106 L
s
.45521 .44032 m
.4556 .44213 L
s
.4552 .44032 m
.45559 .44213 L
s
.16533 .45254 m
.16524 .45218 L
s
.52742 .43702 m
.5274 .4377 L
s
.52743 .43702 m
.52741 .4377 L
s
.42784 .44251 m
.42799 .44089 L
s
.48781 .44011 m
.48786 .44105 L
s
.42778 .44251 m
.42793 .44089 L
s
.45521 .4403 m
.4556 .44211 L
s
.4278 .44251 m
.42798 .44089 L
s
.42779 .44251 m
.42795 .44089 L
s
.42785 .4425 m
.42801 .44088 L
s
.39282 .4436 m
.39274 .44274 L
s
.39278 .4436 m
.3927 .44274 L
s
.45514 .44028 m
.45555 .44209 L
s
.48775 .44009 m
.48781 .44103 L
s
.48777 .44008 m
.48782 .44102 L
s
.42783 .44249 m
.42798 .44087 L
s
.42781 .44248 m
.42797 .44086 L
s
.45526 .44028 m
.45565 .44209 L
s
.42774 .44248 m
.42791 .44086 L
s
.45518 .44027 m
.45558 .44207 L
s
.48778 .44007 m
.48783 .44101 L
s
.48771 .44007 m
.48776 .44101 L
s
.45522 .44025 m
.45563 .44207 L
s
.35369 .447 m
.35354 .44636 L
s
.42788 .44246 m
.42805 .44084 L
s
.35373 .447 m
.35358 .44636 L
s
.39273 .44355 m
.39266 .4427 L
s
.45524 .44023 m
.45567 .44204 L
s
.42781 .44244 m
.428 .44082 L
s
.45514 .44023 m
.45557 .44204 L
s
.71511 .4317 m
.71508 .43207 L
s
.52749 .43693 m
.52747 .43761 L
s
.45512 .44022 m
.45555 .44203 L
s
.39274 .44353 m
.39266 .44268 L
s
.39278 .44353 m
.3927 .44267 L
s
.62462 .43955 m
.62457 .44001 L
s
.42782 .44243 m
.42801 .4408 L
s
.42788 .44241 m
.42805 .44079 L
s
.48771 .44002 m
.48777 .44096 L
s
.27376 .44421 m
.27366 .44372 L
s
.42777 .44241 m
.42795 .44079 L
s
.45521 .44019 m
.45565 .442 L
s
.62448 .43953 m
.62444 .43999 L
s
.39274 .4435 m
.39267 .44265 L
s
.4551 .44018 m
.45555 .44199 L
s
.42782 .44238 m
.42803 .44076 L
s
.35364 .44693 m
.35348 .44628 L
s
.48771 .43997 m
.48778 .44091 L
s
.4278 .44237 m
.42801 .44075 L
s
.45521 .44015 m
.45566 .44196 L
s
.42778 .44235 m
.42799 .44073 L
s
.4278 .44235 m
.42801 .44073 L
s
.45516 .44014 m
.45562 .44195 L
s
.45517 .44014 m
.45562 .44195 L
s
.42784 .44235 m
.42804 .44073 L
s
.42781 .44234 m
.42803 .44072 L
s
.42789 .44233 m
.4281 .44071 L
s
.45515 .44012 m
.45562 .44193 L
s
.42778 .44233 m
.42798 .44071 L
s
.42781 .44232 m
.42803 .44069 L
s
.71512 .43159 m
.71509 .43197 L
s
.45517 .44011 m
.45563 .44192 L
s
.39273 .44343 m
.39266 .44257 L
s
.42773 .44233 m
.42794 .4407 L
s
.52743 .43683 m
.52741 .43752 L
s
.45511 .44011 m
.45557 .44192 L
s
.45517 .4401 m
.45564 .44191 L
s
.35369 .44686 m
.35353 .44622 L
s
.42791 .44229 m
.42813 .44067 L
s
.42788 .4423 m
.42811 .44067 L
s
.45522 .44009 m
.45568 .4419 L
s
.45509 .4401 m
.45556 .4419 L
s
.45505 .44009 m
.45553 .4419 L
s
.48773 .4399 m
.48779 .44084 L
s
.4278 .44228 m
.42803 .44066 L
s
.35375 .44684 m
.35359 .4462 L
s
.45517 .44007 m
.45566 .44188 L
s
.42782 .44228 m
.42804 .44066 L
s
.45511 .44007 m
.45558 .44188 L
s
.84676 .28371 m
.84687 .28395 L
s
.52741 .43679 m
.52739 .43747 L
s
.42779 .44228 m
.42803 .44065 L
s
.42778 .44227 m
.42801 .44065 L
s
.42781 .44226 m
.42805 .44064 L
s
.45505 .44006 m
.45553 .44186 L
s
.45511 .44005 m
.45561 .44185 L
s
.35363 .44681 m
.35348 .44617 L
s
.45516 .44005 m
.45563 .44186 L
s
.45505 .44004 m
.45555 .44185 L
s
.42782 .44225 m
.42807 .44063 L
s
.48767 .43986 m
.48774 .4408 L
s
.39277 .44335 m
.39271 .4425 L
s
.42779 .44224 m
.42804 .44062 L
s
.45504 .44001 m
.45555 .44182 L
s
.4877 .43983 m
.48777 .44077 L
s
.48766 .43982 m
.48773 .44076 L
s
.1653 .45226 m
.16521 .45189 L
s
.48771 .43981 m
.48778 .44076 L
s
.27385 .444 m
.27375 .44351 L
s
.4278 .44219 m
.42806 .44057 L
s
.39271 .4433 m
.39264 .44245 L
s
.45509 .43998 m
.4556 .44178 L
s
.48772 .43979 m
.48779 .44073 L
s
.45511 .43997 m
.45564 .44177 L
s
.18376 .54314 m
.1836 .54276 L
s
.455 .43997 m
.45553 .44177 L
s
.4278 .44217 m
.42808 .44055 L
s
.42774 .44217 m
.42801 .44055 L
s
.42785 .44216 m
.42811 .44054 L
s
.62449 .4393 m
.62445 .43975 L
s
.45509 .43995 m
.45561 .44176 L
s
.39269 .44327 m
.39263 .44241 L
s
.4278 .44215 m
.42807 .44053 L
s
.62454 .43929 m
.6245 .43975 L
s
.45509 .43994 m
.45562 .44175 L
s
.48776 .43976 m
.48783 .4407 L
s
.42782 .44214 m
.4281 .44052 L
s
.42785 .44213 m
.42812 .44051 L
s
.16524 .45218 m
.16516 .45182 L
s
.48766 .43974 m
.48774 .44068 L
s
.42789 .44212 m
.42816 .4405 L
s
.4278 .44212 m
.42808 .4405 L
s
.42783 .44211 m
.4281 .44049 L
s
.42778 .44212 m
.42805 .44049 L
s
.48773 .43973 m
.4878 .44067 L
s
.45496 .43991 m
.45551 .44171 L
s
.42785 .44211 m
.42815 .44049 L
s
.45507 .4399 m
.45562 .4417 L
s
.39268 .44322 m
.39262 .44237 L
s
.45505 .4399 m
.45557 .44171 L
s
.45507 .4399 m
.45562 .4417 L
s
.35359 .44666 m
.35344 .44602 L
s
.42778 .44209 m
.42807 .44047 L
s
.45502 .43988 m
.45556 .44168 L
s
.48766 .4397 m
.48774 .44064 L
s
.45499 .43987 m
.45555 .44167 L
s
.42771 .44208 m
.42802 .44046 L
s
.45509 .43987 m
.45563 .44168 L
s
.39265 .4432 m
.39259 .44234 L
s
.27373 .44387 m
.27363 .44339 L
s
.4278 .44207 m
.42811 .44045 L
s
.42786 .44206 m
.42815 .44044 L
s
.42782 .44206 m
.4281 .44044 L
s
.455 .43985 m
.45557 .44165 L
s
.45508 .43986 m
.45562 .44166 L
s
.45498 .43986 m
.45553 .44166 L
s
.45502 .43985 m
.45557 .44166 L
s
.42781 .44206 m
.4281 .44044 L
s
.45504 .43984 m
.45559 .44164 L
s
.45489 .43983 m
.45547 .44163 L
s
.39266 .44316 m
.3926 .44231 L
s
.71514 .43132 m
.71511 .4317 L
s
.45497 .43983 m
.45553 .44163 L
s
.35355 .44658 m
.3534 .44594 L
s
.52748 .43653 m
.52746 .43721 L
s
.42786 .44201 m
.42817 .44039 L
s
.39268 .44313 m
.39262 .44227 L
s
.42779 .442 m
.42811 .44038 L
s
.84665 .28346 m
.84676 .28371 L
s
.42785 .44199 m
.42818 .44038 L
s
.45503 .43979 m
.45562 .44159 L
s
.35358 .44656 m
.35344 .44592 L
s
.42777 .44199 m
.4281 .44037 L
s
.52747 .4365 m
.52745 .43718 L
s
.48767 .43959 m
.48775 .44053 L
s
.42783 .44196 m
.42816 .44034 L
s
.44244 .44174 m
.44244 .44174 L
s
.44245 .44174 m
.44244 .44174 L
s
.44245 .44174 m
.44245 .44174 L
s
.44244 .44174 m
.44244 .44174 L
s
.44245 .44174 m
.44245 .44174 L
s
.44244 .44174 m
.44244 .44174 L
s
.44245 .44174 m
.44245 .44174 L
s
.44244 .44174 m
.44244 .44174 L
s
.44245 .44174 m
.44245 .44174 L
s
.44244 .44174 m
.44244 .44174 L
s
.44246 .44174 m
.44245 .44174 L
s
.44244 .44174 m
.44243 .44174 L
s
.44246 .44174 m
.44246 .44174 L
s
.62466 .4391 m
.62462 .43955 L
s
.44243 .44174 m
.44243 .44174 L
s
.44246 .44174 m
.44246 .44174 L
s
.44246 .44174 m
.44246 .44174 L
s
.44243 .44174 m
.44243 .44174 L
s
.44246 .44174 m
.44246 .44174 L
s
.44243 .44174 m
.44243 .44174 L
s
.44246 .44174 m
.44246 .44174 L
s
.44243 .44174 m
.44243 .44174 L
s
.44247 .44174 m
.44246 .44174 L
s
.44243 .44174 m
.44243 .44174 L
s
.44247 .44174 m
.44247 .44174 L
s
.44243 .44174 m
.44242 .44174 L
s
.44247 .44174 m
.44247 .44174 L
s
.44242 .44174 m
.44242 .44174 L
s
.44247 .44174 m
.44247 .44174 L
s
.44242 .44174 m
.44242 .44174 L
s
.42785 .44195 m
.4282 .44033 L
s
.44247 .44174 m
.44247 .44174 L
s
.44242 .44174 m
.44242 .44174 L
s
.52755 .43647 m
.52754 .43715 L
s
.44247 .44174 m
.44247 .44174 L
s
.44242 .44174 m
.44242 .44174 L
s
.44247 .44174 m
.44247 .44174 L
s
.44242 .44174 m
.44242 .44174 L
s
.44248 .44174 m
.44247 .44174 L
s
.45501 .43975 m
.45559 .44155 L
s
.44242 .44174 m
.44241 .44174 L
s
.44248 .44173 m
.44248 .44174 L
s
.39264 .44308 m
.39259 .44222 L
s
.44241 .44174 m
.44241 .44174 L
s
.44248 .44173 m
.44248 .44173 L
s
.44241 .44174 m
.44241 .44174 L
s
.44248 .44173 m
.44248 .44173 L
s
.44241 .44174 m
.44241 .44174 L
s
.44248 .44173 m
.44248 .44173 L
s
.44241 .44174 m
.44241 .44173 L
s
.44248 .44173 m
.44248 .44173 L
s
.44241 .44173 m
.44241 .44173 L
s
.44248 .44173 m
.44248 .44173 L
s
.44248 .44173 m
.44248 .44173 L
s
.44241 .44173 m
.4424 .44173 L
s
.45493 .43975 m
.45554 .44155 L
s
.44249 .44173 m
.44248 .44173 L
s
.4424 .44173 m
.4424 .44173 L
s
.44249 .44173 m
.44249 .44173 L
s
.4424 .44173 m
.4424 .44173 L
s
.44249 .44173 m
.44249 .44173 L
s
.4424 .44173 m
.4424 .44173 L
s
.44249 .44173 m
.44249 .44173 L
s
.4424 .44173 m
.4424 .44173 L
s
.44249 .44173 m
.44249 .44173 L
s
.4424 .44173 m
.4424 .44173 L
s
.44249 .44173 m
.44249 .44173 L
s
.4424 .44173 m
.4424 .44173 L
s
.44249 .44173 m
.44249 .44173 L
s
.4424 .44173 m
.44239 .44173 L
s
.44249 .44173 m
.44249 .44173 L
s
.4425 .44172 m
.4425 .44172 L
s
.44251 .44172 m
.4425 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44239 .44173 m
.44239 .44173 L
s
.44249 .44172 m
.44249 .44173 L
s
.4425 .44172 m
.4425 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.4425 .44172 m
.44249 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44252 .44172 m
.44251 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.4425 .44172 m
.44249 .44172 L
s
.44251 .44172 m
.4425 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44252 .44172 m
.44252 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44252 .44172 m
.44252 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44239 .44173 m
.44239 .44173 L
s
.44249 .44172 m
.44249 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44252 .44172 m
.44252 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44247 .44173 m
.44247 .44173 L
s
.44247 .44173 m
.44247 .44173 L
s
.44248 .44172 m
.44247 .44173 L
s
.44247 .44173 m
.44247 .44173 L
s
.44252 .44172 m
.44252 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44247 .44173 m
.44247 .44173 L
s
.44249 .44172 m
.44248 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44247 .44173 m
.44247 .44173 L
s
.44252 .44172 m
.44251 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44247 .44173 m
.44246 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44252 .44172 m
.44252 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.4425 .44172 m
.44249 .44172 L
s
.44252 .44172 m
.44252 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44239 .44173 m
.44239 .44173 L
s
.44249 .44172 m
.44248 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44253 .44172 m
.44252 .44172 L
s
.44252 .44172 m
.44252 .44172 L
s
.44249 .44172 m
.44248 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.42784 .44194 m
.42817 .44032 L
s
.44252 .44172 m
.44252 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44252 .44172 m
.44252 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44239 .44173 m
.44239 .44172 L
s
.44246 .44172 m
.44245 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44252 .44172 m
.44252 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44248 .44172 m
.44247 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44253 .44172 m
.44252 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.4425 .44172 m
.44249 .44172 L
s
.44239 .44172 m
.44239 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44248 .44172 m
.44247 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44239 .44172 m
.44239 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44254 .44172 m
.44253 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44246 .44172 m
.44245 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.44245 .44172 m
.44244 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44247 .44172 m
.44246 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44254 .44172 m
.44254 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44239 .44172 m
.44239 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44254 .44172 m
.44254 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44253 .44172 m
.44253 .44172 L
s
.44247 .44172 m
.44246 .44172 L
s
.44251 .44172 m
.4425 .44172 L
s
.44245 .44172 m
.44244 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44239 .44172 m
.44239 .44172 L
s
.42783 .44193 m
.42817 .44031 L
s
.4425 .44172 m
.4425 .44172 L
s
.44254 .44172 m
.44254 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44254 .44172 m
.44253 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44248 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44254 .44172 m
.44254 .44172 L
s
.44248 .44172 m
.44247 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44247 .44172 m
.44246 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44254 .44172 m
.44254 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44239 .44172 m
.44239 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44254 .44171 m
.44254 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44254 .44172 m
.44254 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44249 .44172 m
.44248 .44172 L
s
.4425 .44172 m
.4425 .44172 L
s
.44247 .44172 m
.44247 .44172 L
s
.44246 .44172 m
.44245 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44254 .44171 m
.44254 .44171 L
s
.44251 .44172 m
.44251 .44172 L
s
.44239 .44172 m
.44239 .44172 L
s
.44254 .44171 m
.44254 .44172 L
s
.44244 .44172 m
.44243 .44172 L
s
.62452 .43908 m
.62448 .43953 L
s
.44245 .44172 m
.44245 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44247 .44172 m
.44246 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44251 .44172 m
.44251 .44172 L
s
.4425 .44171 m
.4425 .44172 L
s
.44254 .44171 m
.44254 .44171 L
s
.44254 .44171 m
.44254 .44171 L
s
.44243 .44172 m
.44243 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44239 .44172 m
.44238 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44244 .44172 m
.44244 .44172 L
s
.44249 .44172 m
.44249 .44172 L
s
.44251 .44171 m
.44251 .44172 L
s
.44248 .44172 m
.44248 .44172 L
s
.44254 .44171 m
.44254 .44171 L
s
.44255 .44171 m
.44254 .44171 L
s
.44243 .44172 m
.44243 .44172 L
s
.4425 .44171 m
.4425 .44171 L
s
.44245 .44172 m
.44245 .44172 L
s
.44249 .44171 m
.44249 .44172 L
s
.44244 .44172 m
.44243 .44172 L
s
.44246 .44172 m
.44246 .44172 L
s
.44246 .44172 m
.44246 .44171 L
s
.44248 .44171 m
.44248 .44172 L
s
.44251 .44171 m
.44251 .44171 L
s
.44254 .44171 m
.44254 .44171 L
s
.44245 .44172 m
.44245 .44172 L
s
.44238 .44172 m
.44238 .44172 L
s
.44255 .44171 m
.44255 .44171 L
s
.4425 .44171 m
.44249 .44171 L
s
.44243 .44172 m
.44243 .44172 L
s
.44243 .44172 m
.44243 .44172 L
s
.44248 .44171 m
.44248 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44245 .44172 m
.44245 .44172 L
s
.44246 .44172 m
.44245 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44254 .44171 m
.44254 .44171 L
s
.44243 .44172 m
.44243 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44243 .44172 m
.44243 .44172 L
s
.44248 .44171 m
.44248 .44171 L
s
.44245 .44172 m
.44244 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44238 .44172 m
.44238 .44172 L
s
.44246 .44171 m
.44246 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44252 .44171 m
.44251 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .44171 m
.44248 .44171 L
s
.44254 .44171 m
.44254 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44243 .44172 m
.44243 .44171 L
s
.44247 .44171 m
.44246 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44248 .44171 m
.44247 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.4425 .44171 m
.44249 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44245 .44172 m
.44245 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44249 .44171 m
.44249 .44171 L
s
.44245 .44172 m
.44245 .44172 L
s
.44249 .44171 m
.44249 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44245 .44172 m
.44245 .44172 L
s
.44245 .44172 m
.44245 .44172 L
s
.44249 .44171 m
.44249 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44245 .44172 m
.44244 .44172 L
s
.44246 .44171 m
.44245 .44172 L
s
.44248 .44171 m
.44248 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44238 .44172 m
.44238 .44172 L
s
.44255 .44171 m
.44254 .44171 L
s
.44244 .44172 m
.44244 .44172 L
s
.4425 .44171 m
.4425 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44244 .44172 m
.44244 .44172 L
s
.44246 .44171 m
.44246 .44171 L
s
.44251 .44171 m
.4425 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44244 .44172 m
.44244 .44172 L
s
.44248 .44171 m
.44248 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44246 .44171 m
.44245 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44249 .44171 m
.44248 .44171 L
s
.44244 .44172 m
.44244 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.42774 .44193 m
.42808 .44031 L
s
.4425 .44171 m
.4425 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44238 .44172 m
.44238 .44171 L
s
.44243 .44171 m
.44242 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44247 .44171 m
.44246 .44171 L
s
.44244 .44171 m
.44243 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44249 .44171 m
.44248 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44252 .44171 m
.44251 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.45495 .43972 m
.45556 .44152 L
s
.44243 .44171 m
.44243 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44248 .44171 m
.44247 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44238 .44171 m
.44238 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .44171 m
.44248 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44248 .44171 m
.44247 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.45493 .43972 m
.45553 .44152 L
s
.44251 .44171 m
.4425 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44245 .44171 m
.44244 .44171 L
s
.39275 .44305 m
.3927 .44219 L
s
.44247 .44171 m
.44246 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44238 .44171 m
.44238 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44244 .44171 m
.44243 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.4425 .44171 m
.44249 .44171 L
s
.44243 .44171 m
.44242 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44246 .44171 m
.44245 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44238 .44171 m
.44238 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44248 .44171 m
.44247 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44256 .4417 m
.44255 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44246 .44171 m
.44245 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44253 .44171 m
.44252 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.4425 .44171 m
.44249 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44255 .44171 m
.44255 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44253 .44171 m
.44253 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44256 .4417 m
.44256 .4417 L
s
.4425 .44171 m
.4425 .44171 L
s
.44238 .44171 m
.44238 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.5274 .43645 m
.52739 .43713 L
s
.44255 .4417 m
.44255 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44253 .44171 m
.44253 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44247 .44171 m
.44246 .44171 L
s
.44251 .44171 m
.4425 .44171 L
s
.44245 .44171 m
.44244 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44252 .44171 m
.44252 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44256 .4417 m
.44256 .4417 L
s
.44253 .4417 m
.44253 .44171 L
s
.44244 .44171 m
.44243 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44238 .44171 m
.44238 .44171 L
s
.44255 .4417 m
.44255 .4417 L
s
.44249 .44171 m
.44249 .44171 L
s
.44251 .4417 m
.44251 .44171 L
s
.44251 .44171 m
.44251 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44253 .4417 m
.44253 .4417 L
s
.44243 .44171 m
.44243 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.71515 .43122 m
.71512 .43159 L
s
.44252 .4417 m
.44252 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44251 .4417 m
.44251 .44171 L
s
.44243 .44171 m
.44242 .44171 L
s
.44256 .4417 m
.44256 .4417 L
s
.4425 .4417 m
.4425 .44171 L
s
.44245 .44171 m
.44245 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44249 .4417 m
.44249 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44248 .44171 m
.44247 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.4425 .44171 m
.4425 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44251 .4417 m
.44251 .4417 L
s
.44242 .44171 m
.44242 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44255 .4417 m
.44255 .4417 L
s
.44245 .44171 m
.44244 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44247 .44171 m
.44247 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44253 .4417 m
.44253 .4417 L
s
.44247 .44171 m
.44247 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44238 .44171 m
.44238 .44171 L
s
.44251 .4417 m
.44251 .4417 L
s
.44247 .44171 m
.44247 .44171 L
s
.44243 .44171 m
.44243 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44253 .4417 m
.44252 .4417 L
s
.4425 .4417 m
.4425 .44171 L
s
.44247 .44171 m
.44246 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44246 .44171 m
.44246 .4417 L
s
.44249 .44171 m
.44248 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44242 .44171 m
.44241 .44171 L
s
.44249 .4417 m
.44249 .4417 L
s
.44246 .44171 m
.44246 .44171 L
s
.44249 .44171 m
.44249 .44171 L
s
.4425 .4417 m
.4425 .4417 L
s
.44245 .44171 m
.44245 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44243 .44171 m
.44243 .44171 L
s
.44246 .44171 m
.44246 .44171 L
s
.44255 .4417 m
.44255 .4417 L
s
.44249 .44171 m
.44249 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.4425 .4417 m
.4425 .4417 L
s
.44243 .44171 m
.44243 .44171 L
s
.44249 .4417 m
.44249 .44171 L
s
.44246 .4417 m
.44246 .4417 L
s
.44246 .44171 m
.44246 .44171 L
s
.44248 .44171 m
.44248 .44171 L
s
.44242 .44171 m
.44242 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44238 .44171 m
.44238 .44171 L
s
.44253 .4417 m
.44253 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44241 .44171 m
.44241 .44171 L
s
.44249 .4417 m
.44249 .4417 L
s
.44246 .44171 m
.44246 .44171 L
s
.44249 .4417 m
.44249 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44243 .44171 m
.44243 .44171 L
s
.44244 .44171 m
.44244 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44246 .44171 m
.44246 .44171 L
s
.44248 .4417 m
.44248 .44171 L
s
.44255 .4417 m
.44255 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44243 .44171 m
.44243 .4417 L
s
.44244 .44171 m
.44244 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44242 .44171 m
.44242 .44171 L
s
.44249 .4417 m
.44249 .4417 L
s
.44242 .44171 m
.44242 .4417 L
s
.44241 .44171 m
.44241 .44171 L
s
.44246 .44171 m
.44246 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44243 .44171 m
.44243 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44238 .44171 m
.44238 .44171 L
s
.44251 .4417 m
.44251 .4417 L
s
.44246 .4417 m
.44245 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.4425 .4417 m
.44249 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44256 .4417 m
.44255 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44244 .44171 m
.44244 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44241 .44171 m
.44241 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44244 .44171 m
.44244 .44171 L
s
.44245 .4417 m
.44245 .4417 L
s
.44244 .44171 m
.44243 .44171 L
s
.44254 .4417 m
.44253 .4417 L
s
.44244 .4417 m
.44244 .44171 L
s
.44242 .44171 m
.44241 .4417 L
s
.44243 .44171 m
.44243 .44171 L
s
.44244 .4417 m
.44244 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44243 .44171 m
.44243 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44252 .4417 m
.44251 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44252 .4417 m
.44251 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44245 .4417 m
.44244 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44238 .44171 m
.44238 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44241 .44171 m
.44241 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44249 .4417 m
.44248 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44254 .4417 m
.44254 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44243 .4417 m
.44242 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44251 .4417 m
.4425 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44252 .4417 m
.44251 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44254 .4417 m
.44254 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44243 .4417 m
.44242 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44238 .4417 m
.44238 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.4425 .4417 m
.44249 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44246 .4417 m
.44245 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44244 .4417 m
.44243 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44254 .4417 m
.44254 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44251 .4417 m
.4425 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44253 .4417 m
.44252 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44238 .4417 m
.44238 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44245 .4417 m
.44244 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44254 .4417 m
.44254 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44246 .4417 m
.44245 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44248 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44249 .4417 m
.44248 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44249 .4417 m
.44248 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44238 .4417 m
.44238 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44243 .4417 m
.44242 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44254 .4417 m
.44254 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44241 .4417 m
.4424 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44248 .4417 m
.44247 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44252 .4417 m
.44251 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44251 .4417 m
.4425 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44256 .4417 m
.44256 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44251 .4417 m
.4425 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44256 .44169 m
.44256 .4417 L
s
.44254 .4417 m
.44254 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44251 .4417 m
.4425 .4417 L
s
.44254 .4417 m
.44253 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44238 .4417 m
.44238 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.4424 .4417 m
.4424 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.44249 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44253 .4417 m
.44252 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44242 .4417 m
.44241 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44256 .44169 m
.44256 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44254 .4417 m
.44254 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44254 .44169 m
.44254 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.4425 .4417 m
.44249 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44256 .44169 m
.44256 .44169 L
s
.44253 .4417 m
.44253 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44252 .4417 m
.44252 .4417 L
s
.4424 .4417 m
.4424 .4417 L
s
.44254 .4417 m
.44254 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44238 .4417 m
.44238 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44253 .4417 m
.44253 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44248 .4417 m
.44247 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44256 .44169 m
.44256 .44169 L
s
.4425 .4417 m
.4425 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44254 .44169 m
.44254 .4417 L
s
.42788 .4419 m
.42822 .44029 L
s
.44241 .4417 m
.44241 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44253 .44169 m
.44253 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44254 .44169 m
.44254 .44169 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44248 .4417 m
.44247 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.4425 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44245 .4417 m
.44245 .4417 L
s
.44253 .44169 m
.44253 .4417 L
s
.44252 .44169 m
.44252 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44247 .4417 m
.44246 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.44249 .4417 m
.44248 .4417 L
s
.44252 .44169 m
.44252 .4417 L
s
.44252 .44169 m
.44251 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4424 .4417 m
.4424 .4417 L
s
.44256 .44169 m
.44256 .44169 L
s
.44251 .4417 m
.44251 .4417 L
s
.44253 .44169 m
.44253 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.4425 .44169 m
.4425 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44251 .4417 m
.4425 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44251 .4417 m
.44251 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44244 .4417 m
.44244 .4417 L
s
.44252 .44169 m
.44252 .44169 L
s
.44241 .4417 m
.44241 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.4425 .44169 m
.4425 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44238 .4417 m
.44238 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44246 .4417 m
.44246 .4417 L
s
.44252 .44169 m
.44252 .44169 L
s
.44247 .4417 m
.44247 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44249 .4417 L
s
.4425 .44169 m
.4425 .4417 L
s
.4425 .44169 m
.4425 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44242 .4417 m
.44242 .4417 L
s
.44251 .4417 m
.44251 .4417 L
s
.44248 .4417 m
.44248 .4417 L
s
.44256 .44169 m
.44256 .44169 L
s
.44242 .4417 m
.44242 .4417 L
s
.44252 .44169 m
.44252 .44169 L
s
.44251 .4417 m
.44251 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44254 .44169 m
.44254 .44169 L
s
.44245 .4417 m
.44245 .4417 L
s
.4425 .44169 m
.4425 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44245 .4417 m
.44245 .4417 L
s
.4425 .44169 m
.4425 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44249 .4417 m
.44249 .4417 L
s
.44248 .4417 m
.44248 .44169 L
s
.44242 .4417 m
.44242 .4417 L
s
.44252 .44169 m
.44252 .44169 L
s
.44246 .4417 m
.44246 .4417 L
s
.44253 .44169 m
.44253 .44169 L
s
.44246 .4417 m
.44246 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44249 .44169 m
.44249 .4417 L
s
.4425 .4417 m
.4425 .4417 L
s
.44249 .4417 m
.44249 .44169 L
s
.44241 .4417 m
.44241 .4417 L
s
.4425 .44169 m
.4425 .44169 L
s
.44251 .44169 m
.44251 .4417 L
s
.44254 .44169 m
.44253 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44254 .44169 m
.44253 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44244 .4417 m
.44244 .4417 L
s
.44252 .44169 m
.44252 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.4424 .4417 m
.4424 .4417 L
s
.44247 .4417 m
.44247 .4417 L
s
.44253 .44169 m
.44253 .44169 L
s
.44251 .44169 m
.44251 .4417 L
s
.44254 .44169 m
.44254 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44251 .44169 m
.44251 .4417 L
s
.44243 .4417 m
.44243 .4417 L
s
.44254 .44169 m
.44254 .44169 L
s
.44246 .4417 m
.44246 .4417 L
s
.44251 .44169 m
.4425 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44244 .4417 m
.44244 .4417 L
s
.44248 .44169 m
.44248 .44169 L
s
.44247 .4417 m
.44247 .4417 L
s
.44249 .44169 m
.44249 .44169 L
s
.4425 .44169 m
.4425 .4417 L
s
.44254 .44169 m
.44254 .44169 L
s
.44246 .4417 m
.44246 .4417 L
s
.4425 .44169 m
.4425 .44169 L
s
.44255 .44169 m
.44254 .44169 L
s
.44238 .4417 m
.44238 .4417 L
s
.44254 .44169 m
.44254 .44169 L
s
.44242 .4417 m
.44242 .4417 L
s
.42777 .44191 m
.42812 .44029 L
s
.44253 .44169 m
.44252 .44169 L
s
.44249 .4417 m
.44249 .4417 L
s
.44253 .44169 m
.44252 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44245 .4417 m
.44245 .44169 L
s
.44241 .4417 m
.44241 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44242 .4417 m
.44242 .4417 L
s
.44251 .44169 m
.44251 .44169 L
s
.44253 .44169 m
.44252 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44245 .4417 m
.44245 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44247 .4417 m
.44247 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44246 .4417 m
.44246 .4417 L
s
.44241 .4417 m
.44241 .4417 L
s
.44253 .44169 m
.44253 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44244 .4417 m
.44243 .4417 L
s
.44249 .44169 m
.44248 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44247 .4417 m
.44247 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44246 .4417 m
.44246 .4417 L
s
.44251 .44169 m
.44251 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44248 .44169 m
.44247 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.4424 .4417 m
.4424 .4417 L
s
.44255 .44169 m
.44255 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44243 .4417 m
.44242 .4417 L
s
.42783 .4419 m
.42818 .44028 L
s
.44241 .4417 m
.44241 .4417 L
s
.44256 .44169 m
.44256 .44169 L
s
.44249 .44169 m
.44249 .4417 L
s
.44253 .44169 m
.44253 .44169 L
s
.44246 .4417 m
.44246 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44242 .4417 m
.44243 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44242 .4417 m
.44242 .4417 L
s
.44247 .44169 m
.44247 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44251 .44169 m
.4425 .44169 L
s
.4425 .44169 m
.44249 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44244 .4417 m
.44244 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44246 .4417 m
.44246 .4417 L
s
.44254 .44169 m
.44254 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44238 .4417 m
.44238 .4417 L
s
.44245 .44169 m
.44245 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44255 .44169 m
.44254 .44169 L
s
.44252 .44169 m
.44251 .44169 L
s
.44242 .4417 m
.44242 .4417 L
s
.44249 .44169 m
.44249 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44255 .44169 m
.44254 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44243 .4417 m
.44243 .4417 L
s
.44251 .44169 m
.44251 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44241 .4417 m
.44241 .4417 L
s
.44249 .44169 m
.4425 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44241 .4417 m
.44241 .4417 L
s
.44251 .44169 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44246 .44169 m
.44246 .4417 L
s
.44252 .44169 m
.44252 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.4424 .4417 m
.4424 .4417 L
s
.44251 .44169 m
.44251 .44169 L
s
.44252 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44242 .4417 m
.44242 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44242 .4417 m
.44242 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44256 .44169 m
.44255 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44243 .4417 m
.44243 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44238 .4417 m
.44238 .4417 L
s
.44247 .44169 m
.44247 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44242 .4417 m
.44242 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44241 .4417 m
.44241 .4417 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44247 .44169 m
.44246 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44241 .4417 m
.44241 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44247 .44169 m
.44246 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.4424 .4417 m
.4424 .4417 L
s
.44246 .44169 m
.44246 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44241 .4417 m
.44241 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44248 .44169 m
.44247 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44238 .4417 m
.44238 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44242 .44169 m
.44241 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44247 .44169 m
.44246 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44255 .44169 m
.44254 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.42786 .4419 m
.42821 .44028 L
s
.44248 .44169 m
.44248 .44169 L
s
.44252 .44169 m
.44251 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.4424 .4417 m
.4424 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44238 .44169 m
.44238 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44246 .44169 m
.44245 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44246 .44169 m
.44245 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44254 .44169 m
.44253 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44248 .44169 m
.44247 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.27366 .44372 m
.27357 .44323 L
s
.44245 .44169 m
.44245 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44251 .44169 m
.4425 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44238 .44169 m
.44238 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44257 .44169 m
.44256 .44169 L
s
.44247 .44169 m
.44246 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44248 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44257 .44169 m
.44257 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44241 .44169 m
.4424 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44238 .44169 m
.44238 .44169 L
s
.44249 .44169 m
.44248 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44257 .44169 m
.44257 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44256 .44169 m
.44256 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44257 .44168 m
.44257 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44238 .44169 m
.44238 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.45491 .4397 m
.45552 .4415 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44256 .44168 m
.44256 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.4425 .44169 m
.44249 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44249 .44169 m
.44248 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44254 .44169 m
.44254 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44255 .44169 m
.44255 .44169 L
s
.44255 .44168 m
.44255 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44257 .44168 m
.44257 .44168 L
s
.44246 .44169 m
.44246 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44256 .44168 m
.44256 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44253 .44169 m
.44253 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44255 .44168 m
.44255 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44238 .44169 m
.44239 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44254 .44168 m
.44254 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44246 .44169 m
.44246 .44169 L
s
.44245 .44169 m
.44244 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44252 .44168 m
.44252 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44257 .44168 m
.44257 .44168 L
s
.4425 .44169 m
.4425 .44169 L
s
.44255 .44168 m
.44255 .44169 L
s
.44255 .44168 m
.44255 .44168 L
s
.44244 .44169 m
.44244 .44169 L
s
.42782 .4419 m
.42816 .44029 L
s
.44242 .44169 m
.44242 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44253 .44168 m
.44253 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44248 .44169 m
.44247 .44169 L
s
.4425 .44169 m
.4425 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44251 .44169 m
.4425 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44252 .44168 m
.44252 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44252 .44169 m
.44252 .44169 L
s
.44254 .44168 m
.44254 .44168 L
s
.44249 .44169 m
.44249 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44253 .44168 m
.44253 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44248 .44169 m
.44249 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44255 .44168 m
.44255 .44168 L
s
.44239 .44169 m
.44239 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44169 m
.44246 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44257 .44168 m
.44257 .44168 L
s
.4424 .44169 m
.4424 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44256 .44168 m
.44255 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44248 .44169 m
.44248 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.4425 .44169 m
.4425 .44168 L
s
.44251 .44169 m
.44251 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44251 .44169 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44253 .44168 m
.44253 .44168 L
s
.44252 .44169 m
.44251 .44169 L
s
.44252 .44168 m
.44252 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.44248 .44169 m
.44248 .44169 L
s
.44244 .44169 m
.44244 .44169 L
s
.44254 .44168 m
.44254 .44168 L
s
.44243 .44169 m
.44243 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44245 .44169 m
.44245 .44169 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44169 m
.44246 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.44245 .44169 m
.44245 .44169 L
s
.44253 .44168 m
.44253 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44257 .44168 m
.44257 .44168 L
s
.44246 .44169 m
.44246 .44169 L
s
.45494 .4397 m
.45556 .44149 L
s
.44248 .44169 m
.44248 .44168 L
s
.44239 .44169 m
.44239 .44169 L
s
.44251 .44168 m
.44251 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.4425 .44168 m
.44249 .44168 L
s
.44243 .44169 m
.44243 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44255 .44168 m
.44255 .44168 L
s
.44244 .44169 m
.44244 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44256 .44168 m
.44255 .44168 L
s
.44251 .44168 m
.44251 .44169 L
s
.44248 .44168 m
.44248 .44169 L
s
.44242 .44169 m
.44243 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44242 .44169 m
.44242 .44169 L
s
.44252 .44168 m
.44252 .44168 L
s
.44249 .44169 m
.44249 .44169 L
s
.44241 .44169 m
.44241 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44246 .44169 m
.44245 .44169 L
s
.44252 .44168 m
.44252 .44169 L
s
.44254 .44168 m
.44254 .44168 L
s
.4424 .44169 m
.4424 .44169 L
s
.44253 .44168 m
.44253 .44168 L
s
.44245 .44169 m
.44245 .44169 L
s
.44251 .44169 m
.44251 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44247 .44169 m
.44247 .44169 L
s
.44246 .44169 m
.44246 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44245 .44169 m
.44245 .44169 L
s
.44249 .44168 m
.44249 .44169 L
s
.44247 .44169 m
.44247 .44168 L
s
.44243 .44169 m
.44244 .44169 L
s
.4425 .44168 m
.44251 .44168 L
s
.44258 .44168 m
.44257 .44168 L
s
.44244 .44169 m
.44244 .44169 L
s
.44245 .44169 m
.44245 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44243 .44169 m
.44243 .44169 L
s
.44248 .44168 m
.44248 .44168 L
s
.44246 .44169 m
.44246 .44168 L
s
.44246 .44169 m
.44246 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44244 .44169 m
.44244 .44169 L
s
.44249 .44169 m
.44249 .44169 L
s
.44253 .44168 m
.44253 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44251 .44168 m
.44251 .44169 L
s
.44251 .44168 m
.44251 .44168 L
s
.44249 .44169 m
.44249 .44169 L
s
.44252 .44168 m
.44252 .44168 L
s
.44239 .44169 m
.44239 .44169 L
s
.44247 .44169 m
.44247 .44169 L
s
.44252 .44168 m
.44252 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44243 .44169 m
.44243 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44241 .44169 m
.44241 .44169 L
s
.44254 .44168 m
.44254 .44168 L
s
.44244 .44169 m
.44244 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44245 .44169 m
.44245 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44245 .44169 m
.44245 .44168 L
s
.4424 .44169 m
.4424 .44169 L
s
.44246 .44168 m
.44246 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44253 .44168 m
.44252 .44168 L
s
.44245 .44169 m
.44245 .44168 L
s
.44242 .44169 m
.44242 .44169 L
s
.44249 .44168 m
.44249 .44169 L
s
.44246 .44169 m
.44246 .44169 L
s
.44248 .44168 m
.44248 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44241 .44169 m
.44241 .44169 L
s
.44247 .44168 m
.44247 .44168 L
s
.44244 .44169 m
.44244 .44169 L
s
.44258 .44168 m
.44258 .44168 L
s
.44247 .44169 m
.44246 .44169 L
s
.4424 .44169 m
.4424 .44169 L
s
.44246 .44168 m
.44246 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44249 .44168 m
.44249 .44169 L
s
.44251 .44168 m
.44251 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44244 .44169 m
.44244 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44243 .44169 m
.44242 .44169 L
s
.44243 .44169 m
.44243 .44169 L
s
.4425 .44168 m
.4425 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44239 .44169 m
.44239 .44169 L
s
.44256 .44168 m
.44256 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44245 .44168 m
.44246 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44169 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44169 L
s
.44246 .44168 m
.44246 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44244 .44169 m
.44244 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44241 .44169 m
.44241 .44169 L
s
.44253 .44168 m
.44253 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44252 .44168 m
.44251 .44168 L
s
.4424 .44169 m
.4424 .44169 L
s
.44252 .44168 m
.44251 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44258 .44168 m
.44258 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44242 .44169 m
.44242 .44168 L
s
.44241 .44169 m
.44241 .44169 L
s
.44249 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44243 .44169 m
.44243 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.4424 .44169 m
.44239 .44169 L
s
.44246 .44168 m
.44246 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44239 .44169 m
.44239 .44169 L
s
.44251 .44168 m
.44251 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44242 .44169 m
.44242 .44168 L
s
.44253 .44168 m
.44252 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44251 .44168 m
.4425 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44258 .44168 m
.44258 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44247 .44168 m
.44246 .44168 L
s
.4424 .44169 m
.4424 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44241 .44169 m
.44241 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44247 .44168 m
.44248 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44255 .44168 m
.44254 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44253 .44168 m
.44252 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44239 .44169 m
.44239 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44241 .44169 m
.44241 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44242 .44168 m
.44241 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44239 .44169 m
.44239 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44242 .44168 m
.44242 .44168 L
s
.44258 .44168 m
.44258 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44239 .44169 m
.44239 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44252 .44168 m
.44251 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44244 .44168 m
.44245 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44255 .44168 m
.44256 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44254 .44168 m
.44253 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44258 .44168 m
.44258 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44242 .44168 m
.44242 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.4425 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.42778 .44189 m
.42812 .44027 L
s
.44247 .44168 m
.44247 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44248 .44168 m
.44249 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44254 .44168 m
.44253 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44248 .44168 m
.44249 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44168 m
.44247 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44258 .44168 m
.44258 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44239 .44168 m
.4424 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44245 .44168 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44242 .44168 m
.44242 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44251 .44168 m
.4425 .44168 L
s
.44246 .44168 m
.44245 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44258 .44167 m
.44258 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.4425 .44168 m
.44249 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44252 .44168 m
.44253 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44242 .44168 m
.44242 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.45494 .43969 m
.45556 .44149 L
s
.44252 .44168 m
.44252 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44258 .44167 m
.44258 .44167 L
s
.44249 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44255 .44168 m
.44254 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44256 .44167 m
.44256 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44256 .44168 m
.44256 .44168 L
s
.44249 .44168 m
.4425 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44239 .44168 m
.4424 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44246 .44168 m
.44247 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44242 .44168 m
.44242 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44258 .44167 m
.44258 .44167 L
s
.44252 .44168 m
.44252 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44256 .44167 m
.44256 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44255 .44167 m
.44255 .44168 L
s
.44255 .44168 m
.44255 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44255 .44167 m
.44255 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44253 .44168 m
.44253 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44255 .44167 m
.44255 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44256 .44167 m
.44256 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44256 .44167 m
.44256 .44167 L
s
.44249 .44168 m
.44249 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44246 .44168 m
.44245 .44168 L
s
.44244 .44168 m
.44243 .44168 L
s
.35354 .44647 m
.35339 .44583 L
s
.44255 .44167 m
.44255 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44254 .44168 m
.44254 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44253 .44167 m
.44253 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44249 .44168 m
.44248 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44258 .44167 m
.44258 .44167 L
s
.44246 .44168 m
.44246 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44256 .44167 m
.44256 .44167 L
s
.44252 .44167 m
.44252 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44242 .44168 m
.44242 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44248 .44168 m
.44248 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44245 .44168 m
.44246 .44168 L
s
.44253 .44167 m
.44253 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44244 .44168 m
.44244 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44247 .44168 m
.44247 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44254 .44167 m
.44254 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44256 .44167 m
.44256 .44167 L
s
.44241 .44168 m
.44241 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44251 .44168 m
.44251 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44256 .44167 m
.44256 .44167 L
s
.44249 .44168 m
.44249 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44249 .44168 m
.44249 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.4425 .44168 m
.4425 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44247 .44168 m
.44247 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44259 .44167 m
.44258 .44167 L
s
.4425 .44168 m
.4425 .44167 L
s
.44243 .44168 m
.44244 .44168 L
s
.44252 .44168 m
.44252 .44168 L
s
.44254 .44167 m
.44254 .44167 L
s
.44245 .44168 m
.44245 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44247 .44168 m
.44247 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44252 .44167 m
.44252 .44168 L
s
.44256 .44167 m
.44256 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44241 .44168 m
.44241 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44252 .44167 m
.44252 .44167 L
s
.44247 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44249 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.42776 .44189 m
.42812 .44027 L
s
.44242 .44168 m
.44242 .44168 L
s
.44251 .44167 m
.44251 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44245 .44168 m
.44245 .44167 L
s
.44252 .44167 m
.44252 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44256 .44167 m
.44256 .44167 L
s
.4424 .44168 m
.4424 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44239 .44168 m
.44239 .44168 L
s
.44248 .44168 m
.44248 .44167 L
s
.44243 .44168 m
.44243 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44252 .44167 m
.44252 .44168 L
s
.4425 .44168 m
.4425 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.4425 .44167 m
.4425 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44248 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44254 .44167 m
.44254 .44167 L
s
.44248 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44253 .44167 m
.44252 .44168 L
s
.44253 .44167 m
.44253 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44245 .44168 m
.44245 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44249 .44167 m
.44248 .44167 L
s
.44246 .44168 m
.44246 .44168 L
s
.44246 .44168 m
.44246 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44252 .44167 m
.44252 .44167 L
s
.44245 .44168 m
.44245 .44168 L
s
.44259 .44167 m
.44259 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44244 .44168 m
.44244 .44168 L
s
.44253 .44167 m
.44253 .44167 L
s
.4424 .44168 m
.4424 .44168 L
s
.44248 .44168 m
.44248 .44167 L
s
.44248 .44168 m
.44248 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.4424 .44168 m
.4424 .44168 L
s
.44256 .44167 m
.44256 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44249 .44168 m
.4425 .44168 L
s
.44245 .44167 m
.44245 .44167 L
s
.44245 .44168 m
.44245 .44168 L
s
.44252 .44167 m
.44252 .44167 L
s
.44255 .44167 m
.44254 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44244 .44168 m
.44244 .44168 L
s
.44252 .44167 m
.44252 .44167 L
s
.44248 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44256 .44167 m
.44256 .44167 L
s
.44249 .44168 m
.44248 .44168 L
s
.44253 .44167 m
.44253 .44167 L
s
.44247 .44168 m
.44248 .44168 L
s
.44243 .44168 m
.44243 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.44242 .44168 m
.44242 .44168 L
s
.44244 .44168 m
.44244 .44168 L
s
.44248 .44168 m
.44248 .44168 L
s
.44249 .44168 m
.44249 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44247 .44168 m
.44248 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44253 .44167 m
.44253 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44248 .44168 m
.44248 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44249 .44167 m
.44249 .44168 L
s
.44245 .44168 m
.44245 .44167 L
s
.44239 .44168 m
.44239 .44168 L
s
.44248 .44167 m
.44248 .44167 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44168 m
.44246 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44248 .44168 m
.44248 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44245 .44168 m
.44245 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44246 .44168 m
.44246 .44167 L
s
.4425 .44167 m
.44249 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44245 .44168 m
.44245 .44168 L
s
.4424 .44168 m
.44241 .44168 L
s
.44249 .44167 m
.44249 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44244 .44168 m
.44244 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44247 .44167 m
.44247 .44168 L
s
.44253 .44167 m
.44253 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44259 .44167 m
.44259 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44247 .44167 m
.44247 .44168 L
s
.44253 .44167 m
.44253 .44167 L
s
.44245 .44168 m
.44245 .44167 L
s
.44248 .44167 m
.44247 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.4424 .44168 m
.4424 .44168 L
s
.44245 .44168 m
.44245 .44168 L
s
.44244 .44168 m
.44244 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44243 .44168 m
.44243 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44244 .44168 m
.44244 .44168 L
s
.44253 .44167 m
.44253 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44241 .44168 m
.44241 .44168 L
s
.4424 .44168 m
.4424 .44168 L
s
.44249 .44167 m
.44249 .44167 L
s
.44241 .44168 m
.44241 .44168 L
s
.44247 .44167 m
.44247 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44241 .44168 m
.44241 .44168 L
s
.44255 .44167 m
.44255 .44167 L
s
.44245 .44168 m
.44245 .44168 L
s
.44246 .44167 m
.44246 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44242 .44168 m
.44242 .44167 L
s
.4424 .44168 m
.44241 .44168 L
s
.44248 .44167 m
.44248 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44241 .44168 m
.44241 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44244 .44168 m
.44244 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44245 .44168 m
.44245 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44245 .44167 m
.44246 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44239 .44168 m
.4424 .44168 L
s
.44253 .44167 m
.44253 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44245 .44167 m
.44244 .44167 L
s
.44259 .44167 m
.44259 .44167 L
s
.44245 .44168 m
.44245 .44168 L
s
.44245 .44167 m
.44245 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.4425 .44167 m
.44249 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44241 .44168 m
.44241 .44168 L
s
.44241 .44168 m
.44241 .44168 L
s
.44252 .44167 m
.44252 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44256 .44167 m
.44255 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44245 .44167 m
.44245 .44168 L
s
.44251 .44167 m
.44251 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44241 .44168 m
.44242 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4424 .44168 m
.4424 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44241 .44168 m
.44241 .44168 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44245 .44167 m
.44246 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44241 .44168 m
.44241 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44241 .44168 m
.44241 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44244 .44167 m
.44245 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44241 .44168 m
.44241 .44168 L
s
.44252 .44167 m
.44252 .44167 L
s
.44259 .44167 m
.44259 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.4424 .44168 m
.4424 .44168 L
s
.44244 .44167 m
.44245 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44244 .44167 m
.44245 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44241 .44168 m
.44241 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.4425 .44167 m
.44251 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44245 .44167 m
.44244 .44167 L
s
.44246 .44167 m
.44247 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44255 .44167 m
.44256 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44259 .44167 m
.44259 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.4424 .44168 m
.4424 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44257 .44167 m
.44256 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44245 .44167 m
.44246 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44247 .44167 m
.44246 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44245 .44167 m
.44246 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44241 .44167 m
.44242 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44254 .44167 m
.44255 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44246 .44167 m
.44247 .44167 L
s
.44248 .44167 m
.44247 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44241 .44167 m
.44242 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44259 .44167 m
.44259 .44167 L
s
.44251 .44167 m
.44252 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44251 .44167 m
.44252 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44257 .44167 m
.44257 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44243 .44167 m
.44244 .44167 L
s
.44254 .44167 m
.44254 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44242 .44167 m
.44243 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44252 .44167 m
.44251 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44259 .44166 m
.44259 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44254 .44167 m
.44254 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44251 .44167 m
.44252 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44252 .44167 m
.44253 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44251 .44167 m
.4425 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44257 .44167 m
.44257 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44254 .44167 m
.44254 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44248 .44167 m
.44249 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44259 .44166 m
.44259 .44166 L
s
.4425 .44167 m
.4425 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44243 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44245 .44167 m
.44246 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44254 .44167 m
.44254 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44255 .44166 m
.44255 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44257 .44166 m
.44257 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44256 .44167 m
.44256 .44167 L
s
.44256 .44166 m
.44256 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44253 .44167 m
.44252 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44254 .44167 m
.44254 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44255 .44166 m
.44255 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44255 .44167 m
.44255 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44259 .44166 m
.44259 .44166 L
s
.44253 .44167 m
.44253 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44246 .44167 m
.44247 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44255 .44166 m
.44255 .44166 L
s
.4425 .44167 m
.4425 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44244 .44167 m
.44245 .44167 L
s
.44243 .44167 m
.44244 .44167 L
s
.44256 .44166 m
.44256 .44167 L
s
.44251 .44167 m
.4425 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44252 .44166 m
.44252 .44167 L
s
.44255 .44166 m
.44255 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44256 .44166 m
.44256 .44166 L
s
.44254 .44166 m
.44254 .44167 L
s
.44257 .44166 m
.44257 .44166 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.4425 .44167 m
.4425 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44255 .44166 m
.44255 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44249 .44167 m
.4425 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44245 .44167 m
.44245 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44254 .44166 m
.44255 .44166 L
s
.44251 .44167 m
.44251 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44254 .44166 m
.44254 .44166 L
s
.44251 .44167 m
.44251 .44167 L
s
.4425 .44167 m
.44249 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44253 .44166 m
.44253 .44167 L
s
.44259 .44166 m
.44259 .44166 L
s
.4424 .44167 m
.44241 .44167 L
s
.44255 .44166 m
.44255 .44166 L
s
.44251 .44166 m
.44251 .44167 L
s
.44253 .44167 m
.44253 .44167 L
s
.44252 .44166 m
.44252 .44166 L
s
.44242 .44167 m
.44242 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44256 .44166 m
.44256 .44166 L
s
.44246 .44167 m
.44246 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44256 .44166 m
.44256 .44166 L
s
.42784 .44188 m
.42821 .44026 L
s
.44249 .44167 m
.44249 .44167 L
s
.44255 .44166 m
.44255 .44166 L
s
.44253 .44167 m
.44253 .44167 L
s
.44255 .44166 m
.44255 .44166 L
s
.44245 .44167 m
.44245 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44252 .44167 m
.44252 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44253 .44166 m
.44253 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44257 .44166 m
.44257 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44244 .44167 m
.44244 .44167 L
s
.44249 .44167 m
.44249 .44166 L
s
.44242 .44167 m
.44242 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.4424 .44167 m
.4424 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44252 .44166 m
.44252 .44166 L
s
.44248 .44167 m
.44248 .44166 L
s
.44249 .44167 m
.44249 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44249 .44167 m
.44249 .44166 L
s
.44246 .44167 m
.44246 .44167 L
s
.44249 .44167 m
.44249 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44246 .44167 m
.44246 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.4425 .44166 m
.44251 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44245 .44167 m
.44246 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44251 .44167 m
.44251 .44167 L
s
.44251 .44166 m
.44251 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44251 .44167 m
.44251 .44167 L
s
.44253 .44166 m
.44253 .44167 L
s
.44253 .44166 m
.44254 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44246 .44167 m
.44246 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44249 .44166 m
.44249 .44166 L
s
.44259 .44166 m
.44259 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44247 .44167 m
.44247 .44167 L
s
.44247 .44167 m
.44247 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44249 .44167 m
.44249 .44167 L
s
.44255 .44166 m
.44255 .44166 L
s
.44246 .44167 m
.44246 .44167 L
s
.44253 .44166 m
.44253 .44166 L
s
.44251 .44166 m
.44252 .44167 L
s
.44249 .44166 m
.44249 .44166 L
s
.44247 .44167 m
.44247 .44167 L
s
.44243 .44167 m
.44243 .44167 L
s
.4425 .44166 m
.4425 .44166 L
s
.44249 .44167 m
.44249 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44252 .44166 m
.44252 .44166 L
s
.44251 .44166 m
.44251 .44167 L
s
.44249 .44166 m
.44249 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44247 .44167 m
.44248 .44167 L
s
.44246 .44167 m
.44246 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44257 .44166 m
.44257 .44166 L
s
.44249 .44167 m
.44249 .44167 L
s
.44244 .44167 m
.44244 .44167 L
s
.44251 .44166 m
.44251 .44167 L
s
.44246 .44166 m
.44246 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44248 .44167 m
.44248 .44167 L
s
.44248 .44166 m
.44248 .44166 L
s
.44248 .44167 m
.44249 .44167 L
s
.44241 .44167 m
.44241 .44167 L
s
.44242 .44167 m
.44242 .44167 L
s
.44253 .44166 m
.44253 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44246 .44167 m
.44246 .44167 L
s
.44246 .44167 m
.44247 .44167 L
s
.44255 .44166 m
.44255 .44166 L
s
.44241 .44167 m
.44241 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44246 .44167 m
.44246 .44166 L
s
.4424 .44167 m
.4424 .44167 L
s
.44253 .44166 m
.44253 .44166 L
s
.44248 .44167 m
.44248 .44167 L
s
.4425 .44166 m
.4425 .44166 L
s
.44249 .44167 m
.44249 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44253 .44166 m
.44253 .44166 L
s
.44248 .44167 m
.44248 .44167 L
s
.44249 .44166 m
.44249 .44166 L
s
.44241 .44167 m
.44241 .44167 L
s
.44256 .44166 m
.44256 .44166 L
s
.44248 .44167 m
.44248 .44167 L
s
.44248 .44167 m
.44248 .44167 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44167 m
.44248 .44167 L
s
.44254 .44166 m
.44254 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44244 .44167 m
.44244 .44167 L
s
.44249 .44166 m
.44249 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44246 .44167 m
.44246 .44167 L
s
.44252 .44166 m
.44252 .44166 L
s
.44247 .44167 m
.44247 .44166 L
s
.44259 .44166 m
.44259 .44166 L
s
.44247 .44167 m
.44247 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44242 .44167 m
.44243 .44167 L
s
.44253 .44166 m
.44253 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44246 .44167 m
.44246 .44166 L
s
.44243 .44167 m
.44243 .44167 L
s
.44249 .44166 m
.44249 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44249 .44166 m
.44249 .44167 L
s
.44253 .44166 m
.44253 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44246 .44167 m
.44245 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44246 .44167 m
.44246 .44166 L
s
.44257 .44166 m
.44257 .44166 L
s
.45492 .43968 m
.45555 .44147 L
s
.44244 .44167 m
.44244 .44167 L
s
.44253 .44166 m
.44253 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44241 .44167 m
.44241 .44167 L
s
.44252 .44166 m
.44252 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44241 .44167 m
.44241 .44167 L
s
.44249 .44166 m
.44249 .44166 L
s
.44242 .44167 m
.44242 .44167 L
s
.44247 .44166 m
.44247 .44166 L
s
.4424 .44167 m
.4424 .44167 L
s
.44253 .44166 m
.44253 .44166 L
s
.44241 .44167 m
.44241 .44167 L
s
.44256 .44166 m
.44256 .44166 L
s
.4425 .44166 m
.44251 .44166 L
s
.44243 .44167 m
.44243 .44167 L
s
.44246 .44166 m
.44246 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.42786 .44187 m
.42821 .44026 L
s
.44253 .44166 m
.44253 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44244 .44167 m
.44244 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44259 .44166 m
.44259 .44166 L
s
.44249 .44166 m
.4425 .44166 L
s
.44243 .44167 m
.44243 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44254 .44166 m
.44255 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44248 .44166 m
.44249 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44243 .44167 m
.44243 .44167 L
s
.4425 .44166 m
.4425 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44241 .44167 m
.44241 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44257 .44166 m
.44257 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44244 .44167 m
.44244 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44249 .44166 m
.4425 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.4424 .44167 m
.4424 .44167 L
s
.44241 .44167 m
.44241 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44241 .44167 m
.44242 .44166 L
s
.44242 .44167 m
.44242 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44246 .44166 m
.44247 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44243 .44166 m
.44243 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44243 .44167 m
.44243 .44166 L
s
.44247 .44166 m
.44248 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44259 .44166 m
.44259 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44241 .44166 m
.44241 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44252 .44166 m
.44253 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44257 .44166 m
.44257 .44166 L
s
.44243 .44166 m
.44243 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44246 .44166 m
.44247 .44166 L
s
.44254 .44166 m
.44253 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.45498 .43968 m
.45559 .44148 L
s
.44251 .44166 m
.44251 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.4424 .44167 m
.4424 .44166 L
s
.44248 .44166 m
.44249 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44241 .44166 m
.44241 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44243 .44166 m
.44244 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44251 .44166 m
.44252 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44259 .44166 m
.44259 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44243 .44166 m
.44243 .44166 L
s
.44241 .44166 m
.44241 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.4425 .44166 m
.44251 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44252 .44166 m
.44253 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44257 .44166 m
.44257 .44166 L
s
.44246 .44166 m
.44247 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44243 .44166 m
.44243 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44251 .44166 m
.44252 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.4424 .44166 m
.4424 .44166 L
s
.44254 .44166 m
.44255 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44249 .44166 m
.4425 .44166 L
s
.44241 .44166 m
.44242 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44241 .44166 m
.44241 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.4425 .44166 m
.44251 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44243 .44166 m
.44243 .44166 L
s
.44259 .44166 m
.44259 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44249 .44166 m
.44248 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44243 .44166 m
.44243 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44256 .44166 m
.44257 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44247 .44166 m
.44248 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44246 .44166 m
.44247 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44241 .44166 m
.44241 .44166 L
s
.4424 .44166 m
.4424 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44252 .44166 m
.44253 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44243 .44166 m
.44244 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44248 .44166 m
.44249 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44259 .44165 m
.44259 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44249 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44241 .44166 m
.44241 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44247 .44166 m
.44248 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.4424 .44166 m
.4424 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44242 .44166 m
.44243 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44259 .44165 m
.44259 .44165 L
s
.44249 .44166 m
.44249 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44256 .44166 m
.44256 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44241 .44166 m
.44241 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44253 .44166 m
.44254 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.4424 .44166 m
.4424 .44166 L
s
.44256 .44165 m
.44256 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44256 .44165 m
.44256 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44255 .44166 m
.44255 .44166 L
s
.4425 .44166 m
.44251 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44256 .44165 m
.44256 .44166 L
s
.44241 .44166 m
.44242 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44243 .44166 m
.44243 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44253 .44166 m
.44253 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44254 .44165 m
.44254 .44166 L
s
.44259 .44165 m
.44259 .44165 L
s
.4425 .44166 m
.4425 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44247 .44166 m
.44248 .44166 L
s
.44244 .44166 m
.44245 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44247 .44166 m
.44248 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44255 .44165 m
.44255 .44166 L
s
.4424 .44166 m
.44241 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44253 .44165 m
.44253 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44256 .44165 m
.44256 .44165 L
s
.44242 .44166 m
.44242 .44166 L
s
.44255 .44165 m
.44256 .44165 L
s
.4425 .44166 m
.4425 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44256 .44165 m
.44256 .44165 L
s
.44247 .44166 m
.44247 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44254 .44166 m
.44254 .44166 L
s
.44246 .44166 m
.44247 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44254 .44165 m
.44254 .44165 L
s
.44243 .44166 m
.44243 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44253 .44165 m
.44253 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44252 .44166 m
.44252 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44252 .44165 m
.44252 .44166 L
s
.44254 .44165 m
.44254 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44259 .44165 m
.44259 .44165 L
s
.44245 .44166 m
.44245 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44255 .44165 m
.44255 .44165 L
s
.44245 .44166 m
.44245 .44166 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44249 .44166 m
.44249 .44166 L
s
.44245 .44166 m
.44246 .44166 L
s
.44246 .44166 m
.44246 .44166 L
s
.44241 .44166 m
.44241 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.4425 .44166 m
.4425 .44166 L
s
.44254 .44165 m
.44254 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44247 .44166 m
.44247 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44256 .44165 m
.44256 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44242 .44166 m
.44242 .44166 L
s
.44252 .44166 m
.44252 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.4425 .44165 m
.4425 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44249 .44166 m
.44249 .44165 L
s
.44245 .44166 m
.44245 .44166 L
s
.44255 .44165 m
.44255 .44165 L
s
.44251 .44166 m
.44251 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44253 .44165 m
.44254 .44165 L
s
.44249 .44165 m
.4425 .44165 L
s
.44248 .44166 m
.44248 .44166 L
s
.44248 .44166 m
.44248 .44166 L
s
.44252 .44165 m
.44252 .44165 L
s
.44244 .44166 m
.44244 .44166 L
s
.44249 .44165 m
.44249 .44165 L
s
.44247 .44166 m
.44247 .44166 L
s
.44249 .44165 m
.4425 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44254 .44165 m
.44254 .44165 L
s
.44243 .44166 m
.44243 .44166 L
s
.44248 .44166 m
.44248 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44166 m
.44249 .44165 L
s
.44248 .44165 m
.44249 .44165 L
s
.44251 .44166 m
.44251 .44166 L
s
.44254 .44165 m
.44254 .44165 L
s
.44247 .44166 m
.44247 .44166 L
s
.44249 .44165 m
.44249 .44165 L
s
.44259 .44165 m
.44259 .44165 L
s
.44252 .44165 m
.44252 .44166 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44248 .44166 m
.44248 .44165 L
s
.44241 .44166 m
.44241 .44166 L
s
.44255 .44165 m
.44255 .44165 L
s
.44248 .44166 m
.44248 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44251 .44165 m
.44251 .44166 L
s
.44244 .44166 m
.44245 .44166 L
s
.44253 .44165 m
.44253 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44244 .44166 m
.44244 .44166 L
s
.44245 .44166 m
.44245 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44242 .44166 m
.44242 .44166 L
s
.44253 .44165 m
.44253 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44242 .44166 m
.44242 .44166 L
s
.44252 .44165 m
.44252 .44165 L
s
.44247 .44166 m
.44247 .44166 L
s
.44255 .44165 m
.44255 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.4425 .44165 m
.44251 .44166 L
s
.44252 .44165 m
.44253 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44243 .44166 m
.44243 .44166 L
s
.44251 .44165 m
.44251 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44244 .44166 m
.44244 .44166 L
s
.44247 .44166 m
.44247 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44241 .44166 m
.44241 .44166 L
s
.44248 .44165 m
.44248 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44259 .44165 m
.44259 .44165 L
s
.44247 .44166 m
.44247 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44242 .44166 m
.44242 .44166 L
s
.44244 .44166 m
.44244 .44166 L
s
.44252 .44165 m
.44252 .44165 L
s
.44245 .44166 m
.44245 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44242 .44166 m
.44242 .44166 L
s
.44252 .44165 m
.44252 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44242 .44166 m
.44242 .44166 L
s
.44245 .44166 m
.44245 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44248 .44165 m
.44249 .44165 L
s
.44242 .44166 m
.44242 .44166 L
s
.44243 .44166 m
.44243 .44166 L
s
.44252 .44165 m
.44252 .44165 L
s
.44241 .44166 m
.44241 .44166 L
s
.44255 .44165 m
.44255 .44165 L
s
.52743 .43639 m
.52742 .43707 L
s
.44247 .44165 m
.44247 .44165 L
s
.44244 .44166 m
.44244 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44244 .44166 m
.44244 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44259 .44165 m
.44259 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44242 .44166 m
.44242 .44165 L
s
.44242 .44166 m
.44242 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44242 .44166 m
.44242 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44251 .44165 m
.44252 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44254 .44165 m
.44255 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44241 .44166 m
.44241 .44166 L
s
.44244 .44165 m
.44244 .44165 L
s
.44251 .44165 m
.44252 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44243 .44166 m
.44243 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44242 .44165 m
.44243 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44247 .44165 m
.44248 .44165 L
s
.44259 .44165 m
.44259 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44249 .44165 m
.4425 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.4425 .44165 m
.44251 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44241 .44166 m
.44241 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.4425 .44165 m
.44251 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44248 .44165 m
.44249 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44242 .44165 m
.44243 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44259 .44165 m
.44259 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44244 .44165 m
.44245 .44165 L
s
.44241 .44165 m
.44241 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44251 .44165 m
.44252 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.45484 .43967 m
.45547 .44146 L
s
.44256 .44165 m
.44256 .44165 L
s
.44249 .44165 m
.4425 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44255 .44165 m
.44255 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.3927 .44299 m
.39265 .44214 L
s
.44241 .44165 m
.44242 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44259 .44165 m
.44259 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.39269 .44299 m
.39264 .44214 L
s
.44254 .44165 m
.44255 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44242 .44165 m
.44243 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44253 .44165 m
.44254 .44165 L
s
.44243 .44165 m
.44244 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44252 .44165 m
.44253 .44165 L
s
.4425 .44165 m
.44251 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44248 .44165 m
.44249 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44259 .44164 m
.44259 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44249 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.4425 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44247 .44165 m
.44248 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44249 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44259 .44164 m
.44259 .44164 L
s
.44252 .44165 m
.44252 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44243 .44165 m
.44244 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44256 .44165 m
.44256 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44244 .44165 m
.44245 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44256 .44164 m
.44256 .44165 L
s
.44246 .44165 m
.44247 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44246 .44165 m
.44246 .44165 L
s
.44259 .44164 m
.44259 .44164 L
s
.44245 .44165 m
.44245 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.44246 .44165 m
.44246 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44246 .44165 m
.44246 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44246 .44165 m
.44246 .44165 L
s
.44245 .44165 m
.44246 .44165 L
s
.44256 .44164 m
.44256 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44246 .44165 m
.44246 .44165 L
s
.44251 .44165 m
.44251 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44254 .44165 m
.44254 .44165 L
s
.44254 .44164 m
.44254 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44253 .44165 m
.44254 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44256 .44164 m
.44256 .44164 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44252 .44165 m
.44252 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44254 .44164 m
.44254 .44164 L
s
.44251 .44165 m
.44251 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44253 .44165 m
.44253 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44242 .44165 m
.44242 .44165 L
s
.44258 .44164 m
.44259 .44164 L
s
.4425 .44165 m
.4425 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44243 .44165 m
.44244 .44165 L
s
.44249 .44165 m
.44249 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44256 .44164 m
.44256 .44164 L
s
.44254 .44164 m
.44254 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44253 .44164 m
.44254 .44164 L
s
.4425 .44165 m
.4425 .44165 L
s
.44247 .44165 m
.44247 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44253 .44164 m
.44253 .44165 L
s
.4425 .44165 m
.44251 .44164 L
s
.44252 .44164 m
.44252 .44165 L
s
.44253 .44164 m
.44253 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.44251 .44165 L
s
.44242 .44165 m
.44243 .44165 L
s
.44253 .44164 m
.44253 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44249 .44165 m
.44249 .44165 L
s
.44245 .44165 m
.44245 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44248 .44165 m
.44248 .44164 L
s
.44245 .44165 m
.44246 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.4425 .44165 m
.44251 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44254 .44164 m
.44254 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44258 .44164 m
.44258 .44164 L
s
.44243 .44165 m
.44243 .44165 L
s
.44251 .44164 m
.44251 .44164 L
s
.44251 .44164 m
.44252 .44164 L
s
.44245 .44165 m
.44245 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.4425 .44164 m
.4425 .44165 L
s
.44251 .44164 m
.44251 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44248 .44165 m
.44249 .44165 L
s
.44251 .44164 m
.44251 .44164 L
s
.44247 .44165 m
.44247 .44165 L
s
.44246 .44165 m
.44246 .44165 L
s
.4425 .44165 m
.4425 .44165 L
s
.44251 .44164 m
.44251 .44164 L
s
.44244 .44165 m
.44244 .44165 L
s
.44253 .44164 m
.44253 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44244 .44165 m
.44244 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44254 .44164 m
.44254 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44245 .44165 m
.44245 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44251 .44164 m
.44251 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44248 .44165 m
.44248 .44165 L
s
.4425 .44164 m
.4425 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.48765 .43948 m
.48774 .44043 L
s
.44253 .44164 m
.44253 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44246 .44165 m
.44246 .44165 L
s
.44251 .44164 m
.44251 .44164 L
s
.44245 .44165 m
.44245 .44165 L
s
.44253 .44164 m
.44253 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.4425 .44164 m
.4425 .44165 L
s
.44258 .44164 m
.44258 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44244 .44165 m
.44244 .44165 L
s
.44253 .44164 m
.44253 .44164 L
s
.44252 .44164 m
.44253 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44243 .44165 m
.44243 .44165 L
s
.44248 .44165 m
.44248 .44165 L
s
.44253 .44164 m
.44253 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44251 .44164 m
.44252 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44253 .44164 m
.44254 .44164 L
s
.44243 .44165 m
.44244 .44165 L
s
.44252 .44164 m
.44253 .44164 L
s
.44244 .44165 m
.44244 .44165 L
s
.44252 .44164 m
.44252 .44164 L
s
.44246 .44165 m
.44246 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44249 .44164 m
.4425 .44164 L
s
.44247 .44165 m
.44247 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44245 .44165 m
.44245 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44251 .44164 m
.44252 .44164 L
s
.44252 .44164 m
.44253 .44164 L
s
.44248 .44165 m
.44248 .44165 L
s
.44243 .44165 m
.44243 .44165 L
s
.44244 .44165 m
.44244 .44165 L
s
.44252 .44164 m
.44252 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44244 .44165 m
.44244 .44165 L
s
.44252 .44164 m
.44252 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44245 .44165 m
.44245 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44244 .44165 m
.44244 .44165 L
s
.44258 .44164 m
.44258 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44248 .44164 m
.44248 .44165 L
s
.44255 .44164 m
.44256 .44164 L
s
.44243 .44165 m
.44243 .44165 L
s
.44244 .44165 m
.44244 .44164 L
s
.44244 .44165 m
.44244 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44243 .44165 m
.44244 .44165 L
s
.44244 .44165 m
.44244 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44246 .44164 m
.44247 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44244 .44165 m
.44244 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.4425 .44164 m
.44251 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44244 .44164 m
.44245 .44164 L
s
.44244 .44165 m
.44244 .44165 L
s
.44258 .44164 m
.44258 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44255 .44164 m
.44255 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44248 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44244 .44164 m
.44245 .44164 L
s
.44244 .44165 m
.44244 .44165 L
s
.44249 .44164 m
.4425 .44164 L
s
.44245 .44164 m
.44246 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44245 .44164 m
.44246 .44164 L
s
.44244 .44165 m
.44244 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44258 .44164 m
.44258 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44255 .44164 m
.44255 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44244 .44164 m
.44245 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44249 .44164 m
.4425 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44246 .44164 m
.44247 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44248 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44255 .44164 m
.44255 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44258 .44164 m
.44258 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44245 .44164 m
.44246 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44248 .44164 m
.44249 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44244 .44164 m
.44245 .44164 L
s
.44248 .44164 m
.44249 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44245 .44164 m
.44246 .44164 L
s
.44255 .44164 m
.44255 .44164 L
s
.44248 .44164 m
.44249 .44164 L
s
.44258 .44164 m
.44258 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44251 .44164 m
.44252 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44255 .44164 m
.44255 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44258 .44164 m
.44258 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44246 .44164 m
.44247 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44247 .44164 m
.44248 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44244 .44164 m
.44244 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44245 .44164 m
.44246 .44164 L
s
.44256 .44164 m
.44256 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44255 .44164 m
.44255 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44258 .44163 m
.44258 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44245 .44164 m
.44246 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44247 .44164 m
.44248 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44244 .44164 m
.44245 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44255 .44164 m
.44256 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44255 .44164 m
.44255 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44246 .44164 m
.44247 .44164 L
s
.44258 .44163 m
.44258 .44163 L
s
.44246 .44164 m
.44246 .44164 L
s
.44253 .44164 m
.44253 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44251 .44164 m
.44251 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44255 .44163 m
.44255 .44164 L
s
.44255 .44163 m
.44255 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.4425 .44164 m
.44251 .44164 L
s
.44248 .44164 m
.44249 .44164 L
s
.44252 .44164 m
.44253 .44164 L
s
.44258 .44163 m
.44258 .44163 L
s
.44246 .44164 m
.44247 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44254 .44163 m
.44255 .44163 L
s
.44246 .44164 m
.44247 .44164 L
s
.44252 .44164 m
.44252 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44255 .44163 m
.44255 .44163 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44245 .44164 m
.44245 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44257 .44163 m
.44258 .44163 L
s
.44252 .44164 m
.44252 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.4425 .44164 m
.4425 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44254 .44163 m
.44254 .44163 L
s
.44247 .44164 m
.44247 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44249 .44164 m
.4425 .44164 L
s
.44255 .44163 m
.44255 .44163 L
s
.44249 .44164 m
.44249 .44163 L
s
.44252 .44163 m
.44252 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44257 .44163 m
.44257 .44163 L
s
.44245 .44164 m
.44245 .44164 L
s
.44247 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44247 .44164 m
.44247 .44164 L
s
.44246 .44164 m
.44246 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44254 .44163 m
.44254 .44163 L
s
.44252 .44163 m
.44252 .44163 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44164 m
.44249 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44248 .44164 m
.44249 .44164 L
s
.44248 .44164 m
.44248 .44164 L
s
.44249 .44163 m
.44249 .44163 L
s
.44255 .44163 m
.44255 .44163 L
s
.44247 .44164 m
.44247 .44164 L
s
.44252 .44163 m
.44252 .44163 L
s
.44257 .44163 m
.44257 .44163 L
s
.44246 .44164 m
.44247 .44163 L
s
.44247 .44164 m
.44247 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.44245 .44164 m
.44245 .44164 L
s
.44252 .44163 m
.44252 .44163 L
s
.44247 .44164 m
.44247 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44255 .44163 m
.44255 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.44257 .44163 m
.44257 .44163 L
s
.44252 .44163 m
.44252 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.44247 .44163 m
.44248 .44163 L
s
.44245 .44164 m
.44245 .44163 L
s
.45492 .43965 m
.45554 .44145 L
s
.44252 .44163 m
.44252 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.44255 .44163 m
.44255 .44163 L
s
.44257 .44163 m
.44257 .44163 L
s
.44251 .44163 m
.44252 .44163 L
s
.44247 .44163 m
.44248 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44245 .44163 m
.44245 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.44257 .44163 m
.44257 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44255 .44163 m
.44255 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44253 .44163 m
.44254 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44245 .44163 m
.44245 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44257 .44163 m
.44257 .44163 L
s
.44255 .44163 m
.44255 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.44253 .44163 m
.44253 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44245 .44163 m
.44245 .44163 L
s
.44257 .44163 m
.44257 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44248 .44163 m
.44249 .44163 L
s
.4425 .44163 m
.44251 .44163 L
s
.44255 .44163 m
.44255 .44163 L
s
.44253 .44163 m
.44253 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44247 .44163 m
.44247 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44256 .44163 m
.44257 .44163 L
s
.44253 .44163 m
.44253 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44245 .44163 m
.44246 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44249 .44163 m
.4425 .44163 L
s
.44254 .44163 m
.44255 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44247 .44163 m
.44248 .44163 L
s
.44253 .44163 m
.44253 .44163 L
s
.44256 .44163 m
.44256 .44163 L
s
.44249 .44163 m
.4425 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44246 .44163 m
.44246 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.44253 .44163 m
.44253 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44256 .44163 m
.44256 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44253 .44163 m
.44253 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.44246 .44163 m
.44246 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44256 .44163 m
.44256 .44163 L
s
.44252 .44163 m
.44253 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44252 .44163 m
.44252 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.44256 .44162 m
.44256 .44163 L
s
.44246 .44163 m
.44246 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44252 .44163 m
.44252 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44248 .44163 m
.44248 .44163 L
s
.44256 .44162 m
.44256 .44162 L
s
.44252 .44163 m
.44252 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44246 .44163 m
.44246 .44163 L
s
.44248 .44163 m
.44249 .44163 L
s
.44252 .44163 m
.44252 .44163 L
s
.44256 .44162 m
.44256 .44162 L
s
.44248 .44163 m
.44248 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44252 .44163 m
.44252 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44254 .44163 m
.44254 .44163 L
s
.44249 .44163 m
.44249 .44163 L
s
.44246 .44163 m
.44246 .44163 L
s
.44251 .44163 m
.44252 .44163 L
s
.42785 .44184 m
.42822 .44022 L
s
.44255 .44162 m
.44256 .44162 L
s
.44249 .44163 m
.44249 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.4425 .44163 m
.4425 .44162 L
s
.44249 .44163 m
.44249 .44163 L
s
.44248 .44163 m
.44249 .44163 L
s
.44254 .44162 m
.44254 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44255 .44162 m
.44255 .44162 L
s
.44249 .44163 m
.44249 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.44246 .44163 m
.44246 .44163 L
s
.44249 .44163 m
.4425 .44163 L
s
.4425 .44162 m
.44251 .44162 L
s
.44251 .44163 m
.44251 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44251 .44163 m
.44251 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.4425 .44163 m
.44251 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44255 .44162 m
.44255 .44162 L
s
.4425 .44163 m
.4425 .44163 L
s
.4425 .44163 m
.4425 .44163 L
s
.44253 .44162 m
.44254 .44162 L
s
.44249 .44163 m
.44249 .44163 L
s
.44251 .44162 m
.44251 .44162 L
s
.44246 .44163 m
.44247 .44163 L
s
.44255 .44162 m
.44255 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44255 .44162 m
.44255 .44162 L
s
.44249 .44163 m
.44249 .44162 L
s
.44247 .44163 m
.44247 .44163 L
s
.44251 .44162 m
.44251 .44162 L
s
.44255 .44162 m
.44255 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.45494 .43964 m
.45557 .44144 L
s
.44249 .44162 m
.44249 .44162 L
s
.44247 .44163 m
.44247 .44163 L
s
.44254 .44162 m
.44255 .44162 L
s
.44256 .44162 m
.44256 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44247 .44163 m
.44247 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44256 .44162 m
.44256 .44162 L
s
.44249 .44162 m
.44249 .44162 L
s
.44251 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44247 .44162 m
.44247 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44256 .44162 m
.44256 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44249 .44162 m
.44249 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44254 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44247 .44162 m
.44247 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44252 .44162 m
.44253 .44162 L
s
.44256 .44162 m
.44256 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44249 .44162 m
.44249 .44162 L
s
.44247 .44162 m
.44247 .44162 L
s
.44252 .44162 m
.44253 .44162 L
s
.44256 .44162 m
.44256 .44162 L
s
.44249 .44162 m
.4425 .44162 L
s
.44247 .44162 m
.44248 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44256 .44162 m
.44256 .44162 L
s
.44248 .44162 m
.44248 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.44248 .44162 m
.44248 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44255 .44162 m
.44256 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44248 .44162 m
.44248 .44162 L
s
.44255 .44162 m
.44255 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.44248 .44162 m
.44248 .44162 L
s
.44251 .44162 m
.44252 .44162 L
s
.44255 .44162 m
.44255 .44162 L
s
.44248 .44162 m
.44249 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44249 .44162 m
.44249 .44162 L
s
.44255 .44162 m
.44255 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44249 .44162 m
.44249 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44249 .44162 m
.44249 .44162 L
s
.44255 .44162 m
.44255 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44249 .44162 m
.44249 .44162 L
s
.4425 .44162 m
.44251 .44162 L
s
.4425 .44162 m
.44251 .44162 L
s
.44249 .44162 m
.44249 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.44249 .44162 m
.4425 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.44255 .44162 m
.44255 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.4425 .44162 m
.4425 .44162 L
s
.39269 .44296 m
.39265 .4421 L
s
.44251 .44162 m
.44251 .44162 L
s
.44254 .44162 m
.44255 .44162 L
s
.45491 .43963 m
.45554 .44143 L
s
.44251 .44162 m
.44251 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44251 .44162 m
.44251 .44162 L
s
.44254 .44162 m
.44254 .44162 L
s
.44251 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44254 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.42776 .44183 m
.42814 .44021 L
s
.44253 .44162 m
.44253 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44252 .44162 m
.44252 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.44252 .44162 m
.44253 .44162 L
s
.44253 .44162 m
.44253 .44162 L
s
.45488 .43963 m
.45551 .44143 L
s
.48771 .43945 m
.4878 .44039 L
s
.42787 .44182 m
.42826 .4402 L
s
.45499 .43963 m
.45561 .44142 L
s
.16521 .45189 m
.16512 .45153 L
s
.42783 .44181 m
.42819 .4402 L
s
.39264 .44295 m
.3926 .4421 L
s
.4877 .43944 m
.48779 .44038 L
s
.52743 .43634 m
.52742 .43702 L
s
.52744 .43634 m
.52743 .43702 L
s
.4549 .4396 m
.45556 .4414 L
s
.39265 .44293 m
.39261 .44208 L
s
.42779 .4418 m
.42817 .44018 L
s
.45483 .43959 m
.45549 .44139 L
s
.45492 .43959 m
.45556 .44139 L
s
.35354 .44636 m
.35339 .44572 L
s
.39268 .44291 m
.39264 .44205 L
s
.48766 .43941 m
.48775 .44035 L
s
.45488 .43957 m
.45555 .44137 L
s
.35358 .44636 m
.35343 .44572 L
s
.39266 .4429 m
.39262 .44205 L
s
.42783 .44176 m
.42823 .44014 L
s
.42783 .44176 m
.42822 .44014 L
s
.45483 .43955 m
.45549 .44135 L
s
.1836 .54276 m
.18343 .54237 L
s
.42785 .44174 m
.42826 .44013 L
s
.45486 .43955 m
.45554 .44134 L
s
.42786 .44174 m
.42826 .44012 L
s
.42776 .44174 m
.42817 .44013 L
s
.42776 .44174 m
.42816 .44012 L
s
.42784 .44173 m
.42825 .44011 L
s
.16516 .45182 m
.16507 .45146 L
s
.42782 .44174 m
.42822 .44012 L
s
.84653 .28322 m
.84665 .28346 L
s
.4548 .43953 m
.45547 .44132 L
s
.5275 .43624 m
.52749 .43693 L
s
.42787 .44171 m
.42829 .44009 L
s
.42788 .4417 m
.42828 .44008 L
s
.35348 .44628 m
.35334 .44564 L
s
.45484 .4395 m
.45553 .4413 L
s
.42787 .44168 m
.42829 .44007 L
s
.27375 .44351 m
.27366 .44302 L
s
.4278 .44168 m
.42821 .44007 L
s
.62453 .43884 m
.62449 .4393 L
s
.45481 .43949 m
.45551 .44128 L
s
.45473 .43949 m
.45542 .44128 L
s
.42779 .44168 m
.42822 .44007 L
s
.39265 .44282 m
.39261 .44197 L
s
.39268 .44282 m
.39264 .44196 L
s
.62458 .43884 m
.62454 .43929 L
s
.45488 .43948 m
.45557 .44127 L
s
.42793 .44166 m
.42834 .44005 L
s
.42787 .44167 m
.42829 .44005 L
s
.48766 .4393 m
.48776 .44024 L
s
.42788 .44165 m
.42831 .44004 L
s
.4278 .44165 m
.42823 .44004 L
s
.45491 .43945 m
.45561 .44125 L
s
.45477 .43945 m
.45548 .44124 L
s
.45481 .43945 m
.45551 .44124 L
s
.42779 .44164 m
.42823 .44002 L
s
.71516 .43095 m
.71514 .43132 L
s
.4548 .43943 m
.4555 .44122 L
s
.4548 .43944 m
.4555 .44123 L
s
.35353 .44622 m
.35339 .44558 L
s
.45479 .43943 m
.45551 .44121 L
s
.42787 .44162 m
.42832 .44 L
s
.45479 .43941 m
.4555 .4412 L
s
.52743 .43616 m
.52743 .43683 L
s
.35359 .4462 m
.35345 .44556 L
s
.39274 .44274 m
.39271 .44188 L
s
.45475 .43941 m
.45548 .44119 L
s
.3927 .44274 m
.39267 .44189 L
s
.45479 .43941 m
.45549 .4412 L
s
.45486 .4394 m
.45557 .44119 L
s
.42779 .44159 m
.42825 .43997 L
s
.45473 .4394 m
.45544 .44119 L
s
.42788 .44157 m
.42834 .43996 L
s
.35348 .44617 m
.35334 .44552 L
s
.45474 .43938 m
.45547 .44117 L
s
.48767 .43921 m
.48778 .44015 L
s
.27363 .44339 m
.27354 .4429 L
s
.52741 .43611 m
.52741 .43679 L
s
.39266 .4427 m
.39263 .44184 L
s
.42788 .44155 m
.42835 .43994 L
s
.4279 .44154 m
.42836 .43993 L
s
.42784 .44155 m
.4283 .43993 L
s
.48762 .43918 m
.48773 .44012 L
s
.42782 .44153 m
.42828 .43992 L
s
.39266 .44268 m
.39263 .44182 L
s
.3927 .44267 m
.39267 .44182 L
s
.45468 .43935 m
.45542 .44113 L
s
.4877 .43917 m
.48781 .44011 L
s
.45465 .43934 m
.4554 .44112 L
s
.42782 .44152 m
.4283 .4399 L
s
.71517 .43085 m
.71515 .43122 L
s
.42784 .44151 m
.4283 .4399 L
s
.42786 .44151 m
.42834 .4399 L
s
.4547 .43932 m
.45547 .4411 L
s
.48764 .43915 m
.48775 .44009 L
s
.39267 .44265 m
.39264 .44179 L
s
.42786 .4415 m
.42834 .43989 L
s
.42786 .4415 m
.42833 .43989 L
s
.48766 .43914 m
.48777 .44008 L
s
.45477 .43931 m
.45552 .4411 L
s
.4278 .4415 m
.42829 .43988 L
s
.45474 .4393 m
.4555 .44109 L
s
.42791 .44148 m
.42838 .43987 L
s
.48767 .43913 m
.48778 .44007 L
s
.42785 .44148 m
.42832 .43987 L
s
.4876 .43913 m
.48771 .44007 L
s
.62469 .43865 m
.62466 .4391 L
s
.42794 .44147 m
.42843 .43986 L
s
.45465 .43928 m
.45542 .44106 L
s
.62456 .43863 m
.62452 .43908 L
s
.42788 .44145 m
.42836 .43984 L
s
.45468 .43927 m
.45545 .44105 L
s
.45467 .43926 m
.45546 .44104 L
s
.84642 .28298 m
.84653 .28322 L
s
.42781 .44145 m
.4283 .43983 L
s
.42789 .44144 m
.42839 .43983 L
s
.4876 .43908 m
.48771 .44002 L
s
.16512 .45153 m
.16504 .45117 L
s
.39266 .44257 m
.39263 .44171 L
s
.45465 .43924 m
.45544 .44102 L
s
.35344 .44602 m
.35331 .44538 L
s
.45471 .43923 m
.45549 .44102 L
s
.45473 .43923 m
.4555 .44102 L
s
.42784 .44141 m
.42835 .4398 L
s
.45469 .43922 m
.45547 .44101 L
s
.45473 .43921 m
.45552 .441 L
s
.27357 .44323 m
.27348 .44274 L
s
.4546 .43922 m
.45538 .441 L
s
.42787 .44139 m
.42837 .43978 L
s
.42787 .44138 m
.42838 .43977 L
s
.45459 .4392 m
.4554 .44098 L
s
.45469 .4392 m
.45548 .44098 L
s
.4876 .43903 m
.48771 .43997 L
s
.45467 .4392 m
.45546 .44098 L
s
.45459 .43919 m
.45539 .44097 L
s
.42793 .44136 m
.42846 .43975 L
s
.42794 .44135 m
.42847 .43974 L
s
.45464 .43917 m
.45543 .44096 L
s
.42783 .44135 m
.42836 .43974 L
s
.39271 .4425 m
.39269 .44164 L
s
.16507 .45146 m
.16498 .4511 L
s
.3534 .44594 m
.35327 .4453 L
s
.45461 .43915 m
.45542 .44093 L
s
.42786 .44132 m
.42839 .43971 L
s
.42796 .44132 m
.4285 .43971 L
s
.45459 .43914 m
.45543 .44092 L
s
.42784 .44132 m
.42839 .43971 L
s
.42784 .44132 m
.42837 .43971 L
s
.4545 .43914 m
.45532 .44092 L
s
.18343 .54237 m
.18327 .54198 L
s
.42789 .44131 m
.42841 .4397 L
s
.42795 .4413 m
.42849 .43969 L
s
.35344 .44592 m
.3533 .44528 L
s
.48761 .43896 m
.48773 .4399 L
s
.52748 .43585 m
.52748 .43653 L
s
.42791 .44129 m
.42845 .43968 L
s
.42784 .44129 m
.42837 .43968 L
s
.39264 .44245 m
.39262 .44159 L
s
.45466 .43911 m
.45548 .44088 L
s
.42793 .44128 m
.42847 .43967 L
s
.42787 .44128 m
.42843 .43967 L
s
.45454 .43908 m
.45539 .44086 L
s
.52747 .43582 m
.52747 .4365 L
s
.48755 .43892 m
.48767 .43986 L
s
.39263 .44241 m
.39261 .44156 L
s
.4279 .44125 m
.42846 .43964 L
s
.45459 .43907 m
.45543 .44085 L
s
.42792 .44124 m
.42849 .43964 L
s
.42788 .44124 m
.42844 .43963 L
s
.42787 .44123 m
.42842 .43963 L
s
.52756 .43579 m
.52755 .43647 L
s
.45453 .43906 m
.45538 .44084 L
s
.4279 .44123 m
.42846 .43962 L
s
.71519 .43058 m
.71516 .43095 L
s
.48757 .43889 m
.4877 .43983 L
s
.48753 .43888 m
.48766 .43982 L
s
.48759 .43887 m
.48771 .43981 L
s
.62456 .43839 m
.62453 .43884 L
s
.45454 .43904 m
.4554 .44081 L
s
.4545 .43904 m
.45536 .44081 L
s
.35339 .44583 m
.35326 .44519 L
s
.5274 .43577 m
.5274 .43645 L
s
.62462 .43839 m
.62458 .43884 L
s
.45461 .43903 m
.45546 .44081 L
s
.39262 .44237 m
.39261 .44151 L
s
.45449 .43903 m
.45535 .4408 L
s
.45447 .43903 m
.45534 .4408 L
s
.42783 .4412 m
.42841 .43959 L
s
.4876 .43885 m
.48772 .43979 L
s
.42798 .44118 m
.42856 .43958 L
s
.27366 .44302 m
.27357 .44253 L
s
.45456 .439 m
.45543 .44077 L
s
.39259 .44234 m
.39258 .44148 L
s
.8463 .28273 m
.84642 .28298 L
s
.45459 .439 m
.45545 .44077 L
s
.42786 .44116 m
.42844 .43956 L
s
.48763 .43882 m
.48776 .43976 L
s
.45454 .43899 m
.45541 .44076 L
s
.45445 .43898 m
.45532 .44075 L
s
.45456 .43898 m
.45542 .44076 L
s
.52743 .43571 m
.52743 .43639 L
s
.42795 .44114 m
.42855 .43954 L
s
.4279 .44114 m
.4285 .43954 L
s
.42789 .44114 m
.42848 .43954 L
s
.42788 .44114 m
.42847 .43954 L
s
.3926 .44231 m
.3926 .44145 L
s
.48753 .4388 m
.48766 .43974 L
s
.42797 .44112 m
.42857 .43952 L
s
.4876 .43879 m
.48773 .43973 L
s
.45446 .43896 m
.45536 .44073 L
s
.45455 .43895 m
.45543 .44072 L
s
.45449 .43896 m
.45536 .44073 L
s
.7152 .43048 m
.71517 .43085 L
s
.42796 .44111 m
.42855 .43951 L
s
.42794 .44111 m
.42854 .43951 L
s
.42788 .4411 m
.42848 .4395 L
s
.45446 .43894 m
.45536 .44071 L
s
.39262 .44227 m
.39262 .44141 L
s
.42792 .4411 m
.42854 .4395 L
s
.35339 .44572 m
.35327 .44508 L
s
.52742 .43566 m
.52743 .43634 L
s
.42793 .44109 m
.42852 .43948 L
s
.48753 .43876 m
.48766 .4397 L
s
.52744 .43566 m
.52744 .43634 L
s
.35343 .44572 m
.3533 .44507 L
s
.45442 .43891 m
.45533 .44068 L
s
.45444 .43891 m
.45534 .44067 L
s
.42799 .44106 m
.4286 .43946 L
s
.42797 .44107 m
.42858 .43947 L
s
.45439 .4389 m
.45531 .44066 L
s
.42792 .44106 m
.42854 .43945 L
s
.27354 .4429 m
.27345 .44241 L
s
.39259 .44222 m
.39258 .44136 L
s
.4279 .44105 m
.42853 .43945 L
s
.42798 .44104 m
.42859 .43944 L
s
.42786 .44104 m
.42849 .43944 L
s
.16504 .45117 m
.16495 .45081 L
s
.42801 .44102 m
.42863 .43942 L
s
.3927 .44219 m
.39269 .44133 L
s
.45441 .43886 m
.45533 .44062 L
s
.45448 .43885 m
.4554 .44062 L
s
.35334 .44564 m
.35321 .445 L
s
.62473 .43819 m
.62469 .43865 L
s
.45435 .43885 m
.45528 .44061 L
s
.5275 .43556 m
.5275 .43624 L
s
.42795 .44099 m
.4286 .4394 L
s
.45439 .43884 m
.45531 .4406 L
s
.45448 .43883 m
.45541 .4406 L
s
.42796 .44099 m
.4286 .43939 L
s
.62459 .43817 m
.62456 .43863 L
s
.48753 .43865 m
.48767 .43959 L
s
.45431 .43881 m
.45525 .44057 L
s
.39264 .44214 m
.39264 .44128 L
s
.39265 .44214 m
.39265 .44128 L
s
.45434 .4388 m
.45528 .44056 L
s
.4544 .43879 m
.45535 .44055 L
s
.16498 .4511 m
.1649 .45074 L
s
.42792 .44095 m
.42856 .43935 L
s
.42801 .44094 m
.42866 .43934 L
s
.45443 .43878 m
.45538 .44054 L
s
.42797 .44093 m
.42862 .43934 L
s
.45435 .43878 m
.45531 .44054 L
s
.35339 .44558 m
.35326 .44493 L
s
.42796 .44093 m
.42862 .43933 L
s
.45433 .43878 m
.45528 .44054 L
s
.42794 .44093 m
.4286 .43933 L
s
.39265 .4421 m
.39264 .44125 L
s
.45426 .43877 m
.45523 .44053 L
s
.4543 .43877 m
.45527 .44053 L
s
.45438 .43877 m
.45532 .44053 L
s
.42804 .44091 m
.4287 .43932 L
s
.4544 .43877 m
.45534 .44053 L
s
.35345 .44556 m
.35332 .44491 L
s
.3926 .4421 m
.3926 .44124 L
s
.428 .44091 m
.42867 .43932 L
s
.45433 .43875 m
.4553 .4405 L
s
.39261 .44208 m
.39261 .44122 L
s
.42799 .44089 m
.42865 .43929 L
s
.84619 .28249 m
.8463 .28273 L
s
.45434 .43874 m
.45529 .4405 L
s
.42793 .44089 m
.42859 .43929 L
s
.42798 .44089 m
.42867 .43929 L
s
.35334 .44552 m
.35322 .44488 L
s
.42795 .44089 m
.42862 .43929 L
s
.42801 .44088 m
.42869 .43929 L
s
.52742 .43548 m
.52743 .43616 L
s
.18327 .54198 m
.18311 .5416 L
s
.27348 .44274 m
.2734 .44225 L
s
.39264 .44205 m
.39264 .4412 L
s
.42798 .44087 m
.42864 .43927 L
s
.42797 .44086 m
.42865 .43926 L
s
.48751 .43855 m
.48765 .43948 L
s
.39262 .44205 m
.39263 .44119 L
s
.42791 .44086 m
.42859 .43926 L
s
.42805 .44084 m
.42874 .43924 L
s
.5274 .43543 m
.52741 .43611 L
s
.48756 .43851 m
.48771 .43945 L
s
.45435 .43868 m
.45534 .44043 L
s
.71521 .43021 m
.71519 .43058 L
s
.48756 .4385 m
.4877 .43944 L
s
.428 .44082 m
.42871 .43922 L
s
.45427 .43867 m
.45527 .44042 L
s
.45427 .43867 m
.45525 .44042 L
s
.4542 .43866 m
.45519 .44041 L
s
.42801 .4408 m
.42871 .43921 L
s
.42805 .44079 m
.42873 .4392 L
s
.4542 .43865 m
.45521 .4404 L
s
.42795 .44079 m
.42865 .43919 L
s
.48751 .43847 m
.48766 .43941 L
s
.39261 .44197 m
.39262 .44111 L
s
.39264 .44196 m
.39265 .4411 L
s
.45423 .43863 m
.45524 .44038 L
s
.42803 .44076 m
.42874 .43917 L
s
.45416 .43862 m
.45518 .44036 L
s
.42801 .44075 m
.42874 .43916 L
s
.45425 .4386 m
.45527 .44035 L
s
.45424 .4386 m
.45525 .44035 L
s
.45427 .4386 m
.45529 .44035 L
s
.6246 .43793 m
.62456 .43839 L
s
.42799 .44073 m
.42871 .43914 L
s
.42801 .44073 m
.42873 .43914 L
s
.45422 .43859 m
.45524 .44034 L
s
.62465 .43793 m
.62462 .43839 L
s
.42804 .44073 m
.42877 .43914 L
s
.35331 .44538 m
.35319 .44474 L
s
.42803 .44072 m
.42877 .43913 L
s
.45423 .43858 m
.45526 .44032 L
s
.4281 .44071 m
.42882 .43912 L
s
.71522 .43011 m
.7152 .43048 L
s
.45418 .43857 m
.45521 .44032 L
s
.45417 .43857 m
.4552 .44032 L
s
.42798 .44071 m
.4287 .43912 L
s
.42803 .44069 m
.42875 .43911 L
s
.39271 .44188 m
.39272 .44102 L
s
.39267 .44189 m
.39268 .44103 L
s
.42794 .4407 m
.42867 .43911 L
s
.45419 .43855 m
.45521 .4403 L
s
.42813 .44067 m
.42886 .43909 L
s
.42811 .44067 m
.42885 .43909 L
s
.45409 .43854 m
.45514 .44028 L
s
.48751 .43836 m
.48766 .4393 L
s
.45424 .43853 m
.45526 .44028 L
s
.27357 .44253 m
.27349 .44204 L
s
.42803 .44066 m
.42877 .43907 L
s
.42804 .44066 m
.42877 .43907 L
s
.45415 .43852 m
.45518 .44027 L
s
.42803 .44065 m
.42878 .43907 L
s
.45417 .43851 m
.45522 .44025 L
s
.35327 .4453 m
.35315 .44466 L
s
.39263 .44184 m
.39264 .44098 L
s
.42801 .44065 m
.42876 .43906 L
s
.42805 .44064 m
.42881 .43905 L
s
.16495 .45081 m
.16487 .45045 L
s
.39263 .44182 m
.39265 .44096 L
s
.42807 .44063 m
.42884 .43904 L
s
.39267 .44182 m
.39268 .44096 L
s
.45418 .43849 m
.45524 .44023 L
s
.45407 .43849 m
.45514 .44023 L
s
.3533 .44528 m
.35319 .44463 L
s
.42804 .44062 m
.4288 .43903 L
s
.84607 .28225 m
.84619 .28249 L
s
.45406 .43848 m
.45512 .44022 L
s
.39264 .44179 m
.39266 .44093 L
s
.45413 .43845 m
.45521 .44019 L
s
.45402 .43845 m
.4551 .44018 L
s
.52747 .43517 m
.52748 .43585 L
s
.42806 .44057 m
.42884 .43899 L
s
.48752 .43827 m
.48767 .43921 L
s
.1649 .45074 m
.16481 .45038 L
s
.42808 .44055 m
.42886 .43896 L
s
.42801 .44055 m
.42879 .43896 L
s
.42811 .44054 m
.42889 .43896 L
s
.48747 .43824 m
.48762 .43918 L
s
.45412 .43842 m
.45521 .44015 L
s
.52745 .43514 m
.52747 .43582 L
s
.27345 .44241 m
.27337 .44192 L
s
.45407 .43841 m
.45516 .44014 L
s
.45409 .43841 m
.45517 .44014 L
s
.48754 .43823 m
.4877 .43917 L
s
.62476 .43774 m
.62473 .43819 L
s
.42807 .44053 m
.42886 .43895 L
s
.4281 .44052 m
.4289 .43894 L
s
.35326 .44519 m
.35314 .44454 L
s
.52754 .43511 m
.52756 .43579 L
s
.39263 .44171 m
.39265 .44086 L
s
.42812 .44051 m
.42891 .43893 L
s
.45405 .43839 m
.45515 .44012 L
s
.62462 .43772 m
.62459 .43817 L
s
.48748 .43821 m
.48764 .43915 L
s
.4875 .4382 m
.48766 .43914 L
s
.42816 .4405 m
.42895 .43892 L
s
.45407 .43838 m
.45517 .44011 L
s
.45401 .43838 m
.45511 .44011 L
s
.42808 .4405 m
.42888 .43892 L
s
.4281 .44049 m
.42889 .43891 L
s
.42805 .44049 m
.42884 .43891 L
s
.42815 .44049 m
.42896 .43891 L
s
.48751 .43819 m
.48767 .43913 L
s
.48743 .43819 m
.4876 .43913 L
s
.45407 .43837 m
.45517 .4401 L
s
.52738 .43509 m
.5274 .43577 L
s
.454 .43836 m
.45509 .4401 L
s
.45394 .43836 m
.45505 .44009 L
s
.45413 .43836 m
.45522 .44009 L
s
.42807 .44047 m
.42888 .43889 L
s
.45405 .43834 m
.45517 .44007 L
s
.454 .43834 m
.45511 .44007 L
s
.42802 .44046 m
.42884 .43888 L
s
.18311 .5416 m
.18295 .54121 L
s
.45393 .43833 m
.45505 .44006 L
s
.42811 .44045 m
.42894 .43887 L
s
.42815 .44044 m
.42895 .43886 L
s
.4281 .44044 m
.4289 .43886 L
s
.45398 .43832 m
.45511 .44005 L
s
.39269 .44164 m
.39271 .44078 L
s
.45405 .43832 m
.45516 .44005 L
s
.48743 .43814 m
.4876 .43908 L
s
.4281 .44044 m
.42891 .43886 L
s
.45392 .43832 m
.45505 .44004 L
s
.52741 .43503 m
.52743 .43571 L
s
.71523 .42984 m
.71521 .43021 L
s
.35327 .44508 m
.35315 .44444 L
s
.45389 .43829 m
.45504 .44001 L
s
.3533 .44507 m
.35318 .44443 L
s
.42817 .44039 m
.42899 .43881 L
s
.48743 .43809 m
.4876 .43903 L
s
.39262 .44159 m
.39265 .44073 L
s
.42811 .44038 m
.42894 .4388 L
s
.42818 .44038 m
.42903 .4388 L
s
.2734 .44225 m
.27332 .44177 L
s
.45395 .43825 m
.45509 .43998 L
s
.5274 .43498 m
.52742 .43566 L
s
.4281 .44037 m
.42894 .43879 L
s
.52742 .43498 m
.52744 .43566 L
s
.45395 .43825 m
.45511 .43997 L
s
.45384 .43825 m
.455 .43997 L
s
.39261 .44156 m
.39264 .4407 L
s
.42816 .44034 m
.42901 .43877 L
s
.45394 .43823 m
.45509 .43995 L
s
.84596 .282 m
.84607 .28225 L
s
.4282 .44033 m
.42906 .43876 L
s
.45392 .43822 m
.45509 .43994 L
s
.35321 .445 m
.3531 .44436 L
s
.42817 .44032 m
.42902 .43875 L
s
.42817 .44031 m
.42902 .43874 L
s
.71524 .42973 m
.71522 .43011 L
s
.48744 .43802 m
.48761 .43896 L
s
.42808 .44031 m
.42894 .43873 L
s
.39261 .44151 m
.39264 .44065 L
s
.45379 .4382 m
.45496 .43991 L
s
.45389 .43819 m
.45507 .4399 L
s
.42822 .44029 m
.42907 .43872 L
s
.42818 .44028 m
.42904 .43871 L
s
.42812 .44029 m
.42898 .43872 L
s
.42821 .44028 m
.42906 .43871 L
s
.45389 .43818 m
.45505 .4399 L
s
.45389 .43818 m
.45507 .4399 L
s
.42816 .44029 m
.42902 .43871 L
s
.52748 .43489 m
.5275 .43556 L
s
.42812 .44027 m
.42897 .4387 L
s
.42812 .44027 m
.429 .4387 L
s
.39258 .44148 m
.39261 .44062 L
s
.45384 .43816 m
.45502 .43988 L
s
.48738 .43798 m
.48755 .43892 L
s
.42821 .44026 m
.4291 .43869 L
s
.62462 .43748 m
.6246 .43793 L
s
.4538 .43816 m
.45499 .43987 L
s
.42821 .44026 m
.42909 .43869 L
s
.45391 .43816 m
.45509 .43987 L
s
.62468 .43748 m
.62465 .43793 L
s
.35326 .44493 m
.35315 .44429 L
s
.4538 .43814 m
.455 .43985 L
s
.4539 .43814 m
.45508 .43986 L
s
.4538 .43815 m
.45498 .43986 L
s
.45384 .43814 m
.45502 .43985 L
s
.16487 .45045 m
.16479 .45008 L
s
.4874 .43795 m
.48757 .43889 L
s
.3926 .44145 m
.39263 .44059 L
s
.48735 .43795 m
.48753 .43888 L
s
.35332 .44491 m
.35321 .44427 L
s
.45368 .43813 m
.45489 .43983 L
s
.45385 .43813 m
.45504 .43984 L
s
.48741 .43794 m
.48759 .43887 L
s
.42822 .44022 m
.4291 .43865 L
s
.45376 .43812 m
.45497 .43983 L
s
.42814 .44021 m
.42903 .43864 L
s
.42826 .4402 m
.42915 .43864 L
s
.35322 .44488 m
.35311 .44424 L
s
.39262 .44141 m
.39265 .44056 L
s
.42819 .4402 m
.42906 .43863 L
s
.48742 .43791 m
.4876 .43885 L
s
.4538 .43808 m
.45503 .43979 L
s
.42817 .44018 m
.42907 .43862 L
s
.5274 .4348 m
.52742 .43548 L
s
.48745 .43788 m
.48763 .43882 L
s
.16481 .45038 m
.16473 .45001 L
s
.27349 .44204 m
.27341 .44155 L
s
.42823 .44014 m
.42914 .43858 L
s
.39258 .44136 m
.39262 .44051 L
s
.48735 .43786 m
.48753 .4388 L
s
.42822 .44014 m
.42913 .43858 L
s
.45379 .43804 m
.45501 .43975 L
s
.4537 .43804 m
.45493 .43975 L
s
.48742 .43785 m
.4876 .43879 L
s
.42826 .44013 m
.42918 .43857 L
s
.42826 .44012 m
.42918 .43856 L
s
.42817 .44013 m
.42909 .43856 L
s
.42816 .44012 m
.42907 .43856 L
s
.42825 .44011 m
.42916 .43855 L
s
.39269 .44133 m
.39273 .44048 L
s
.52738 .43475 m
.5274 .43543 L
s
.42822 .44012 m
.42913 .43855 L
s
.45371 .43802 m
.45495 .43972 L
s
.4537 .43802 m
.45493 .43972 L
s
.42829 .44009 m
.42923 .43853 L
s
.48734 .43782 m
.48753 .43876 L
s
.45366 .438 m
.45491 .4397 L
s
.42828 .44008 m
.4292 .43852 L
s
.45369 .438 m
.45494 .4397 L
s
.45369 .438 m
.45494 .43969 L
s
.42829 .44007 m
.42922 .43851 L
s
.42821 .44007 m
.42913 .43851 L
s
.42822 .44007 m
.42916 .43851 L
s
.45366 .43798 m
.45492 .43968 L
s
.45373 .43798 m
.45498 .43968 L
s
.84584 .28176 m
.84596 .282 L
s
.62479 .43729 m
.62476 .43774 L
s
.39264 .44128 m
.39268 .44042 L
s
.39265 .44128 m
.39269 .44042 L
s
.42834 .44005 m
.42927 .43849 L
s
.42829 .44005 m
.42922 .43849 L
s
.45357 .43797 m
.45484 .43967 L
s
.42831 .44004 m
.42926 .43848 L
s
.35319 .44474 m
.35308 .44409 L
s
.62464 .43726 m
.62462 .43772 L
s
.45367 .43795 m
.45492 .43965 L
s
.42823 .44004 m
.42917 .43848 L
s
.39264 .44125 m
.39269 .44039 L
s
.71525 .42946 m
.71523 .42984 L
s
.27337 .44192 m
.27329 .44143 L
s
.45369 .43794 m
.45494 .43964 L
s
.42823 .44002 m
.42919 .43846 L
s
.45365 .43794 m
.45491 .43963 L
s
.18295 .54121 m
.18279 .54082 L
s
.45361 .43794 m
.45488 .43963 L
s
.3926 .44124 m
.39264 .44038 L
s
.45373 .43793 m
.45499 .43963 L
s
.42832 .44 m
.42927 .43845 L
s
.39261 .44122 m
.39265 .44036 L
s
.45362 .43791 m
.4549 .4396 L
s
.45355 .4379 m
.45483 .43959 L
s
.48734 .43771 m
.48753 .43865 L
s
.45364 .4379 m
.45492 .43959 L
s
.39264 .4412 m
.39268 .44034 L
s
.42825 .43997 m
.42922 .43842 L
s
.42834 .43996 m
.42932 .43841 L
s
.45359 .43789 m
.45488 .43957 L
s
.39263 .44119 m
.39267 .44033 L
s
.35315 .44466 m
.35305 .44401 L
s
.45353 .43786 m
.45483 .43955 L
s
.45355 .43786 m
.45486 .43955 L
s
.42836 .43993 m
.42934 .43838 L
s
.42835 .43994 m
.42933 .43838 L
s
.35319 .44463 m
.35308 .44399 L
s
.4283 .43993 m
.42927 .43838 L
s
.42828 .43992 m
.42926 .43837 L
s
.45349 .43784 m
.4548 .43953 L
s
.71526 .42936 m
.71524 .42973 L
s
.4283 .4399 m
.42929 .43835 L
s
.4283 .4399 m
.42928 .43835 L
s
.42834 .4399 m
.42933 .43835 L
s
.42834 .43989 m
.42934 .43834 L
s
.42833 .43989 m
.42931 .43834 L
s
.45353 .43782 m
.45484 .4395 L
s
.42829 .43988 m
.4293 .43834 L
s
.45349 .43781 m
.45481 .43949 L
s
.45341 .43781 m
.45473 .43949 L
s
.39262 .44111 m
.39267 .44025 L
s
.42838 .43987 m
.42936 .43832 L
s
.39265 .4411 m
.3927 .44024 L
s
.48732 .43761 m
.48751 .43855 L
s
.42832 .43987 m
.42931 .43832 L
s
.42843 .43986 m
.42943 .43832 L
s
.45356 .4378 m
.45488 .43948 L
s
.52744 .43449 m
.52747 .43517 L
s
.27332 .44177 m
.27324 .44128 L
s
.42836 .43984 m
.42935 .43829 L
s
.48737 .43758 m
.48756 .43851 L
s
.16479 .45008 m
.16471 .44972 L
s
.45344 .43778 m
.45477 .43945 L
s
.45359 .43777 m
.45491 .43945 L
s
.45347 .43777 m
.45481 .43945 L
s
.4283 .43983 m
.4293 .43829 L
s
.35314 .44454 m
.35304 .4439 L
s
.42839 .43983 m
.42942 .43828 L
s
.48736 .43757 m
.48756 .4385 L
s
.45346 .43775 m
.4548 .43943 L
s
.45346 .43776 m
.4548 .43944 L
s
.52742 .43446 m
.52745 .43514 L
s
.45344 .43775 m
.45479 .43943 L
s
.42835 .4398 m
.42938 .43825 L
s
.45345 .43774 m
.45479 .43941 L
s
.52751 .43443 m
.52754 .43511 L
s
.45338 .43774 m
.45475 .43941 L
s
.39272 .44102 m
.39277 .44017 L
s
.39268 .44103 m
.39273 .44017 L
s
.48731 .43753 m
.48751 .43847 L
s
.45346 .43773 m
.45479 .43941 L
s
.62465 .43703 m
.62462 .43748 L
s
.45352 .43772 m
.45486 .4394 L
s
.84572 .28152 m
.84584 .28176 L
s
.6247 .43702 m
.62468 .43748 L
s
.45338 .43772 m
.45473 .4394 L
s
.42837 .43978 m
.42939 .43823 L
s
.42838 .43977 m
.42942 .43823 L
s
.45339 .43771 m
.45474 .43938 L
s
.52735 .43441 m
.52738 .43509 L
s
.16473 .45001 m
.16465 .44965 L
s
.42846 .43975 m
.4295 .43821 L
s
.42847 .43974 m
.42951 .4382 L
s
.39264 .44098 m
.39269 .44012 L
s
.42836 .43974 m
.4294 .4382 L
s
.39265 .44096 m
.3927 .44011 L
s
.45331 .43768 m
.45468 .43935 L
s
.45327 .43767 m
.45465 .43934 L
s
.39268 .44096 m
.39274 .4401 L
s
.35315 .44444 m
.35305 .44379 L
s
.42839 .43971 m
.42944 .43817 L
s
.4285 .43971 m
.42956 .43817 L
s
.42839 .43971 m
.42945 .43817 L
s
.42837 .43971 m
.42941 .43817 L
s
.52738 .43435 m
.52741 .43503 L
s
.35318 .44443 m
.35308 .44379 L
s
.42841 .4397 m
.42945 .43817 L
s
.42849 .43969 m
.42955 .43816 L
s
.4533 .43765 m
.4547 .43932 L
s
.45339 .43764 m
.45477 .43931 L
s
.39266 .44093 m
.39272 .44008 L
s
.42845 .43968 m
.42949 .43814 L
s
.45336 .43764 m
.45474 .4393 L
s
.42837 .43968 m
.42943 .43814 L
s
.4873 .43742 m
.48751 .43836 L
s
.42847 .43967 m
.42952 .43813 L
s
.42843 .43967 m
.4295 .43814 L
s
.45326 .43762 m
.45465 .43928 L
s
.45326 .4376 m
.45467 .43926 L
s
.52737 .43431 m
.5274 .43498 L
s
.45329 .43761 m
.45468 .43927 L
s
.42846 .43964 m
.42952 .43811 L
s
.52738 .4343 m
.52742 .43498 L
s
.27341 .44155 m
.27333 .44107 L
s
.42849 .43964 m
.42957 .4381 L
s
.42844 .43963 m
.42953 .4381 L
s
.3531 .44436 m
.353 .44371 L
s
.42842 .43963 m
.42949 .43809 L
s
.42846 .43962 m
.42954 .43809 L
s
.71527 .42909 m
.71525 .42946 L
s
.45324 .43758 m
.45465 .43924 L
s
.39265 .44086 m
.39272 .44 L
s
.4533 .43757 m
.45471 .43923 L
s
.45335 .43757 m
.45473 .43923 L
s
.45329 .43756 m
.45469 .43922 L
s
.45332 .43755 m
.45473 .43921 L
s
.45319 .43756 m
.4546 .43922 L
s
.42841 .43959 m
.4295 .43806 L
s
.45315 .43755 m
.45459 .4392 L
s
.18279 .54082 m
.18264 .54043 L
s
.62481 .43683 m
.62479 .43729 L
s
.42856 .43958 m
.42965 .43805 L
s
.45327 .43754 m
.45469 .4392 L
s
.48731 .43733 m
.48752 .43827 L
s
.45325 .43754 m
.45467 .4392 L
s
.45317 .43754 m
.45459 .43919 L
s
.35315 .44429 m
.35305 .44365 L
s
.52744 .43421 m
.52748 .43489 L
s
.42844 .43956 m
.42955 .43803 L
s
.62467 .43681 m
.62464 .43726 L
s
.48726 .43731 m
.48747 .43824 L
s
.45323 .43752 m
.45464 .43917 L
s
.42855 .43954 m
.42965 .43801 L
s
.4285 .43954 m
.42962 .43802 L
s
.48733 .4373 m
.48754 .43823 L
s
.35321 .44427 m
.35311 .44362 L
s
.42848 .43954 m
.42959 .43801 L
s
.39271 .44078 m
.39278 .43992 L
s
.42847 .43954 m
.42957 .43801 L
s
.45318 .4375 m
.45461 .43915 L
s
.42857 .43952 m
.42968 .438 L
s
.45314 .4375 m
.45459 .43914 L
s
.45305 .43749 m
.4545 .43914 L
s
.42855 .43951 m
.42966 .43799 L
s
.48727 .43727 m
.48748 .43821 L
s
.42854 .43951 m
.42966 .43799 L
s
.48729 .43727 m
.4875 .4382 L
s
.35311 .44424 m
.35302 .44359 L
s
.27329 .44143 m
.27322 .44095 L
s
.71528 .42899 m
.71526 .42936 L
s
.42848 .4395 m
.42959 .43798 L
s
.8456 .28128 m
.84572 .28152 L
s
.42854 .4395 m
.42967 .43797 L
s
.4873 .43726 m
.48751 .43819 L
s
.48722 .43726 m
.48743 .43819 L
s
.45321 .43746 m
.45466 .43911 L
s
.42852 .43948 m
.42963 .43796 L
s
.39265 .44073 m
.39272 .43987 L
s
.4286 .43946 m
.42973 .43794 L
s
.42858 .43947 m
.42971 .43794 L
s
.45307 .43744 m
.45454 .43908 L
s
.42854 .43945 m
.42966 .43793 L
s
.45313 .43742 m
.45459 .43907 L
s
.39264 .4407 m
.39271 .43984 L
s
.42853 .43945 m
.42968 .43793 L
s
.52736 .43412 m
.5274 .4348 L
s
.16471 .44972 m
.16463 .44936 L
s
.42859 .43944 m
.42971 .43791 L
s
.48721 .43721 m
.48743 .43814 L
s
.45307 .43742 m
.45453 .43906 L
s
.42849 .43944 m
.42963 .43792 L
s
.42863 .43942 m
.42978 .43791 L
s
.45302 .4374 m
.4545 .43904 L
s
.45306 .4374 m
.45454 .43904 L
s
.45314 .43739 m
.45461 .43903 L
s
.45301 .43739 m
.45449 .43903 L
s
.45298 .43739 m
.45447 .43903 L
s
.4286 .4394 m
.42976 .43788 L
s
.52734 .43408 m
.52738 .43475 L
s
.39264 .44065 m
.39272 .43979 L
s
.48721 .43716 m
.48743 .43809 L
s
.4286 .43939 m
.42975 .43787 L
s
.45307 .43737 m
.45456 .439 L
s
.4531 .43736 m
.45459 .439 L
s
.39261 .44062 m
.39269 .43977 L
s
.16465 .44965 m
.16457 .44929 L
s
.45296 .43735 m
.45445 .43898 L
s
.45306 .43735 m
.45454 .43899 L
s
.45309 .43734 m
.45456 .43898 L
s
.35308 .44409 m
.35298 .44345 L
s
.42856 .43935 m
.42973 .43783 L
s
.42866 .43934 m
.42983 .43783 L
s
.27324 .44128 m
.27316 .44079 L
s
.42862 .43934 m
.42979 .43782 L
s
.42862 .43933 m
.42981 .43782 L
s
.45295 .43733 m
.45446 .43896 L
s
.4286 .43933 m
.42977 .43782 L
s
.45305 .43732 m
.45455 .43895 L
s
.39263 .44059 m
.39271 .43973 L
s
.453 .43732 m
.45449 .43896 L
s
.4287 .43932 m
.42988 .43781 L
s
.45295 .43731 m
.45446 .43894 L
s
.42867 .43932 m
.42984 .43781 L
s
.48722 .43708 m
.48744 .43802 L
s
.62467 .43657 m
.62465 .43703 L
s
.62472 .43657 m
.6247 .43702 L
s
.42865 .43929 m
.42983 .43778 L
s
.42867 .43929 m
.42987 .43779 L
s
.39265 .44056 m
.39273 .4397 L
s
.42859 .43929 m
.42976 .43778 L
s
.42862 .43929 m
.42981 .43778 L
s
.42869 .43929 m
.42988 .43778 L
s
.45289 .43729 m
.45442 .43891 L
s
.45292 .43728 m
.45444 .43891 L
s
.45285 .43728 m
.45439 .4389 L
s
.42864 .43927 m
.42981 .43776 L
s
.42865 .43926 m
.42983 .43776 L
s
.35305 .44401 m
.35295 .44337 L
s
.48715 .43704 m
.48738 .43798 L
s
.42859 .43926 m
.42979 .43775 L
s
.42874 .43924 m
.42994 .43774 L
s
.35308 .44399 m
.35299 .44334 L
s
.48717 .43701 m
.4874 .43795 L
s
.39262 .44051 m
.3927 .43965 L
s
.48712 .43701 m
.48735 .43795 L
s
.45287 .43724 m
.45441 .43886 L
s
.45293 .43723 m
.45448 .43885 L
s
.48718 .437 m
.48741 .43794 L
s
.42871 .43922 m
.42992 .43772 L
s
.84548 .28103 m
.8456 .28128 L
s
.45279 .43723 m
.45435 .43885 L
s
.71529 .42872 m
.71527 .42909 L
s
.39273 .44048 m
.39281 .43962 L
s
.42871 .43921 m
.42993 .43771 L
s
.45285 .43722 m
.45439 .43884 L
s
.45293 .43722 m
.45448 .43883 L
s
.42873 .4392 m
.42993 .43769 L
s
.48719 .43698 m
.48742 .43791 L
s
.42865 .43919 m
.42986 .43769 L
s
.45276 .43719 m
.45431 .43881 L
s
.42874 .43917 m
.42997 .43767 L
s
.45278 .43719 m
.45434 .4388 L
s
.45284 .43718 m
.4544 .43879 L
s
.48722 .43694 m
.48745 .43788 L
s
.42874 .43916 m
.42998 .43766 L
s
.45287 .43717 m
.45443 .43878 L
s
.45278 .43717 m
.45435 .43878 L
s
.45277 .43717 m
.45433 .43878 L
s
.39268 .44042 m
.39277 .43956 L
s
.39269 .44042 m
.39277 .43956 L
s
.45267 .43717 m
.45426 .43877 L
s
.18264 .54043 m
.18248 .54004 L
s
.45273 .43717 m
.4543 .43877 L
s
.42871 .43914 m
.42994 .43764 L
s
.42873 .43914 m
.42997 .43764 L
s
.48712 .43692 m
.48735 .43786 L
s
.35304 .4439 m
.35294 .44325 L
s
.45282 .43716 m
.45438 .43877 L
s
.48719 .43692 m
.48742 .43785 L
s
.42877 .43914 m
.43 .43764 L
s
.5274 .43381 m
.52744 .43449 L
s
.42877 .43913 m
.43002 .43764 L
s
.45285 .43715 m
.4544 .43877 L
s
.42882 .43912 m
.43005 .43763 L
s
.45275 .43714 m
.45433 .43875 L
s
.27333 .44107 m
.27326 .44058 L
s
.39269 .44039 m
.39277 .43953 L
s
.4287 .43912 m
.42993 .43762 L
s
.42875 .43911 m
.42999 .43761 L
s
.45277 .43713 m
.45434 .43874 L
s
.42867 .43911 m
.42992 .43761 L
s
.39264 .44038 m
.39273 .43952 L
s
.62483 .43638 m
.62481 .43683 L
s
.71529 .42862 m
.71528 .42899 L
s
.42886 .43909 m
.43011 .4376 L
s
.48711 .43688 m
.48734 .43782 L
s
.52737 .43378 m
.52742 .43446 L
s
.42885 .43909 m
.4301 .4376 L
s
.39265 .44036 m
.39274 .4395 L
s
.62469 .43636 m
.62467 .43681 L
s
.42877 .43907 m
.43002 .43758 L
s
.42877 .43907 m
.43001 .43758 L
s
.52747 .43375 m
.52751 .43443 L
s
.39268 .44034 m
.39277 .43948 L
s
.42878 .43907 m
.43005 .43758 L
s
.42876 .43906 m
.43002 .43757 L
s
.42881 .43905 m
.43007 .43756 L
s
.39267 .44033 m
.39277 .43947 L
s
.45275 .43708 m
.45435 .43868 L
s
.16463 .44936 m
.16455 .449 L
s
.42884 .43904 m
.43011 .43755 L
s
.45267 .43708 m
.45427 .43867 L
s
.5273 .43373 m
.52735 .43441 L
s
.45268 .43707 m
.45427 .43867 L
s
.45259 .43707 m
.4542 .43866 L
s
.4288 .43903 m
.43008 .43754 L
s
.35305 .44379 m
.35296 .44315 L
s
.45258 .43706 m
.4542 .43865 L
s
.35308 .44379 m
.35299 .44314 L
s
.45261 .43704 m
.45423 .43863 L
s
.27322 .44095 m
.27315 .44046 L
s
.42884 .43899 m
.43014 .43751 L
s
.45252 .43703 m
.45416 .43862 L
s
.4871 .43678 m
.48734 .43771 L
s
.52733 .43368 m
.52738 .43435 L
s
.45262 .43701 m
.45425 .4386 L
s
.39267 .44025 m
.39277 .43939 L
s
.3927 .44024 m
.39279 .43939 L
s
.45262 .43701 m
.45424 .4386 L
s
.42886 .43896 m
.43016 .43748 L
s
.45264 .43701 m
.45427 .4386 L
s
.42889 .43896 m
.43018 .43748 L
s
.16457 .44929 m
.1645 .44893 L
s
.42879 .43896 m
.43009 .43748 L
s
.4526 .437 m
.45422 .43859 L
s
.42886 .43895 m
.43016 .43747 L
s
.4526 .43699 m
.45423 .43858 L
s
.84536 .28079 m
.84548 .28103 L
s
.353 .44371 m
.35291 .44307 L
s
.4289 .43894 m
.43021 .43746 L
s
.45255 .43698 m
.45418 .43857 L
s
.45254 .43698 m
.45417 .43857 L
s
.42891 .43893 m
.43021 .43745 L
s
.52732 .43363 m
.52737 .43431 L
s
.42895 .43892 m
.43025 .43744 L
s
.52733 .43362 m
.52738 .4343 L
s
.45255 .43697 m
.45419 .43855 L
s
.42888 .43892 m
.43019 .43744 L
s
.42896 .43891 m
.43028 .43744 L
s
.42889 .43891 m
.43019 .43743 L
s
.42884 .43891 m
.43013 .43743 L
s
.45243 .43696 m
.45409 .43854 L
s
.4526 .43694 m
.45424 .43853 L
s
.42888 .43889 m
.4302 .43741 L
s
.4525 .43694 m
.45415 .43852 L
s
.39277 .44017 m
.39287 .43931 L
s
.39273 .44017 m
.39283 .43931 L
s
.45251 .43693 m
.45417 .43851 L
s
.42884 .43888 m
.43017 .4374 L
s
.48707 .43668 m
.48732 .43761 L
s
.42894 .43887 m
.43028 .4374 L
s
.35305 .44365 m
.35296 .443 L
s
.42895 .43886 m
.43027 .43739 L
s
.4289 .43886 m
.43021 .43738 L
s
.45252 .43691 m
.45418 .43849 L
s
.45239 .43692 m
.45407 .43849 L
s
.42891 .43886 m
.43024 .43738 L
s
.45239 .43691 m
.45406 .43848 L
s
.35311 .44362 m
.35302 .44298 L
s
.48712 .43665 m
.48737 .43758 L
s
.39269 .44012 m
.39279 .43926 L
s
.52739 .43353 m
.52744 .43421 L
s
.48711 .43663 m
.48736 .43757 L
s
.62469 .43612 m
.62467 .43657 L
s
.27316 .44079 m
.27309 .4403 L
s
.62474 .43611 m
.62472 .43657 L
s
.45245 .43688 m
.45413 .43845 L
s
.3927 .44011 m
.3928 .43925 L
s
.35302 .44359 m
.35293 .44295 L
s
.45233 .43688 m
.45402 .43845 L
s
.42899 .43881 m
.43033 .43734 L
s
.39274 .4401 m
.39284 .43924 L
s
.7153 .42835 m
.71529 .42872 L
s
.42903 .4388 m
.43039 .43734 L
s
.42894 .4388 m
.43029 .43733 L
s
.48705 .4366 m
.48731 .43753 L
s
.42894 .43879 m
.43029 .43732 L
s
.39272 .44008 m
.39282 .43922 L
s
.45244 .43685 m
.45412 .43842 L
s
.42901 .43877 m
.43037 .43731 L
s
.45237 .43684 m
.45407 .43841 L
s
.4524 .43684 m
.45409 .43841 L
s
.42906 .43876 m
.43043 .4373 L
s
.45235 .43683 m
.45405 .43839 L
s
.42902 .43875 m
.43038 .43728 L
s
.42902 .43874 m
.43038 .43728 L
s
.4523 .43682 m
.45401 .43838 L
s
.45237 .43682 m
.45407 .43838 L
s
.42894 .43873 m
.4303 .43727 L
s
.45236 .4368 m
.45407 .43837 L
s
.45224 .4368 m
.45394 .43836 L
s
.42907 .43872 m
.43044 .43725 L
s
.45229 .4368 m
.454 .43836 L
s
.42904 .43871 m
.43042 .43725 L
s
.5273 .43344 m
.52736 .43412 L
s
.42898 .43872 m
.43036 .43726 L
s
.42906 .43871 m
.43043 .43725 L
s
.45243 .43679 m
.45413 .43836 L
s
.42902 .43871 m
.43039 .43725 L
s
.18248 .54004 m
.18232 .53965 L
s
.45234 .43679 m
.45405 .43834 L
s
.39272 .44 m
.39283 .43914 L
s
.429 .4387 m
.43039 .43724 L
s
.45228 .43678 m
.454 .43834 L
s
.42897 .4387 m
.43034 .43724 L
s
.71531 .42824 m
.71529 .42862 L
s
.4291 .43869 m
.4305 .43724 L
s
.45221 .43677 m
.45393 .43833 L
s
.42909 .43869 m
.43047 .43723 L
s
.45225 .43677 m
.45398 .43832 L
s
.45219 .43677 m
.45392 .43832 L
s
.48704 .43649 m
.4873 .43742 L
s
.45234 .43676 m
.45405 .43832 L
s
.52728 .4334 m
.52734 .43408 L
s
.84524 .28055 m
.84536 .28079 L
s
.35298 .44345 m
.3529 .4428 L
s
.45215 .43674 m
.45389 .43829 L
s
.4291 .43865 m
.43049 .43719 L
s
.16455 .449 m
.16447 .44863 L
s
.42915 .43864 m
.43056 .43719 L
s
.42903 .43864 m
.43043 .43719 L
s
.42906 .43863 m
.43045 .43717 L
s
.39278 .43992 m
.39289 .43906 L
s
.62485 .43592 m
.62483 .43638 L
s
.4522 .43671 m
.45395 .43825 L
s
.42907 .43862 m
.43048 .43716 L
s
.45219 .43671 m
.45395 .43825 L
s
.45209 .43671 m
.45384 .43825 L
s
.27326 .44058 m
.27319 .44009 L
s
.62471 .4359 m
.62469 .43636 L
s
.45218 .43668 m
.45394 .43823 L
s
.42914 .43858 m
.43056 .43714 L
s
.48705 .4364 m
.48731 .43733 L
s
.45216 .43668 m
.45392 .43822 L
s
.35295 .44337 m
.35288 .44272 L
s
.42913 .43858 m
.43055 .43713 L
s
.42918 .43857 m
.43061 .43712 L
s
.39272 .43987 m
.39283 .43901 L
s
.42918 .43856 m
.4306 .43712 L
s
.1645 .44893 m
.16442 .44856 L
s
.42909 .43856 m
.43052 .43712 L
s
.42916 .43855 m
.43059 .43711 L
s
.42907 .43856 m
.43049 .43711 L
s
.48699 .43637 m
.48726 .43731 L
s
.42913 .43855 m
.43056 .43711 L
s
.45202 .43666 m
.45379 .4382 L
s
.35299 .44334 m
.35291 .4427 L
s
.45211 .43665 m
.45389 .43819 L
s
.48707 .43637 m
.48733 .4373 L
s
.39271 .43984 m
.39282 .43898 L
s
.45211 .43665 m
.45389 .43818 L
s
.42923 .43853 m
.43067 .43709 L
s
.45213 .43664 m
.45389 .43818 L
s
.4292 .43852 m
.43062 .43708 L
s
.45208 .43662 m
.45384 .43816 L
s
.487 .43634 m
.48727 .43727 L
s
.45202 .43663 m
.4538 .43816 L
s
.48702 .43634 m
.48729 .43727 L
s
.42922 .43851 m
.43066 .43707 L
s
.45214 .43662 m
.45391 .43816 L
s
.42913 .43851 m
.43056 .43706 L
s
.42916 .43851 m
.4306 .43707 L
s
.452 .43662 m
.4538 .43814 L
s
.48703 .43633 m
.4873 .43726 L
s
.48695 .43632 m
.48722 .43726 L
s
.45202 .43661 m
.4538 .43815 L
s
.45212 .4366 m
.4539 .43814 L
s
.45206 .43661 m
.45384 .43814 L
s
.42927 .43849 m
.4307 .43705 L
s
.42922 .43849 m
.43066 .43705 L
s
.39272 .43979 m
.39283 .43894 L
s
.42926 .43848 m
.43072 .43705 L
s
.45187 .43661 m
.45368 .43813 L
s
.45207 .43659 m
.45385 .43813 L
s
.27315 .44046 m
.27308 .43997 L
s
.45197 .43659 m
.45376 .43812 L
s
.42917 .43848 m
.43063 .43704 L
s
.42919 .43846 m
.43065 .43703 L
s
.39269 .43977 m
.39281 .43891 L
s
.42927 .43845 m
.43074 .43701 L
s
.35294 .44325 m
.35287 .44261 L
s
.48694 .43627 m
.48721 .43721 L
s
.45199 .43656 m
.4538 .43808 L
s
.39271 .43973 m
.39283 .43887 L
s
.42922 .43842 m
.4307 .43699 L
s
.42932 .43841 m
.4308 .43698 L
s
.52734 .43314 m
.5274 .43381 L
s
.71531 .42797 m
.7153 .42835 L
s
.45188 .43653 m
.4537 .43804 L
s
.45198 .43652 m
.45379 .43804 L
s
.48694 .43622 m
.48721 .43716 L
s
.42934 .43838 m
.43083 .43696 L
s
.39273 .4397 m
.39285 .43884 L
s
.42933 .43838 m
.43082 .43696 L
s
.84512 .28031 m
.84524 .28055 L
s
.45188 .43651 m
.45371 .43802 L
s
.42927 .43838 m
.43075 .43694 L
s
.45188 .4365 m
.4537 .43802 L
s
.42926 .43837 m
.43074 .43694 L
s
.52731 .43311 m
.52737 .43378 L
s
.42929 .43835 m
.43079 .43693 L
s
.45183 .43649 m
.45366 .438 L
s
.45185 .43649 m
.45369 .438 L
s
.52741 .43307 m
.52747 .43375 L
s
.42928 .43835 m
.43077 .43692 L
s
.6247 .43566 m
.62469 .43612 L
s
.42933 .43835 m
.43083 .43692 L
s
.45185 .43649 m
.45369 .438 L
s
.62476 .43566 m
.62474 .43611 L
s
.42934 .43834 m
.43084 .43692 L
s
.42931 .43834 m
.4308 .43691 L
s
.4293 .43834 m
.43082 .43692 L
s
.35296 .44315 m
.35288 .4425 L
s
.45181 .43648 m
.45366 .43798 L
s
.3927 .43965 m
.39283 .43879 L
s
.4519 .43646 m
.45373 .43798 L
s
.42936 .43832 m
.43085 .4369 L
s
.45172 .43647 m
.45357 .43797 L
s
.42943 .43832 m
.43095 .4369 L
s
.35299 .44314 m
.35291 .44249 L
s
.42931 .43832 m
.4308 .43689 L
s
.48694 .43615 m
.48722 .43708 L
s
.52724 .43306 m
.5273 .43373 L
s
.27309 .4403 m
.27303 .43981 L
s
.39281 .43962 m
.39294 .43876 L
s
.45183 .43644 m
.45367 .43795 L
s
.42935 .43829 m
.43086 .43687 L
s
.71532 .42787 m
.71531 .42824 L
s
.45184 .43643 m
.45369 .43794 L
s
.42942 .43828 m
.43094 .43687 L
s
.45181 .43643 m
.45365 .43794 L
s
.45177 .43643 m
.45361 .43794 L
s
.4293 .43829 m
.43082 .43686 L
s
.45188 .43642 m
.45373 .43793 L
s
.18232 .53965 m
.18217 .53926 L
s
.48687 .43611 m
.48715 .43704 L
s
.45175 .43641 m
.45362 .43791 L
s
.52727 .433 m
.52733 .43368 L
s
.45168 .43641 m
.45355 .4379 L
s
.42938 .43825 m
.43091 .43684 L
s
.35291 .44307 m
.35284 .44242 L
s
.45179 .4364 m
.45364 .4379 L
s
.16447 .44863 m
.1644 .44827 L
s
.39277 .43956 m
.3929 .4387 L
s
.48689 .43608 m
.48717 .43701 L
s
.39277 .43956 m
.3929 .4387 L
s
.45171 .43639 m
.45359 .43789 L
s
.48684 .43608 m
.48712 .43701 L
s
.42942 .43823 m
.43096 .43682 L
s
.4869 .43607 m
.48718 .437 L
s
.42939 .43823 m
.43091 .43682 L
s
.45166 .43638 m
.45355 .43786 L
s
.45165 .43637 m
.45353 .43786 L
s
.39277 .43953 m
.3929 .43867 L
s
.4295 .43821 m
.43104 .4368 L
s
.42951 .4382 m
.43106 .43679 L
s
.48691 .43605 m
.48719 .43698 L
s
.4294 .4382 m
.43096 .43679 L
s
.52725 .43295 m
.52732 .43363 L
s
.39273 .43952 m
.39286 .43866 L
s
.52727 .43295 m
.52733 .43362 L
s
.4516 .43636 m
.45349 .43784 L
s
.42956 .43817 m
.43112 .43677 L
s
.39274 .4395 m
.39287 .43865 L
s
.42944 .43817 m
.43098 .43677 L
s
.35296 .443 m
.35289 .44235 L
s
.42945 .43817 m
.43101 .43677 L
s
.42941 .43817 m
.43096 .43676 L
s
.48694 .43602 m
.48722 .43694 L
s
.42955 .43816 m
.43111 .43676 L
s
.42945 .43817 m
.431 .43676 L
s
.45163 .43634 m
.45353 .43782 L
s
.16442 .44856 m
.16434 .4482 L
s
.39277 .43948 m
.39291 .43863 L
s
.45158 .43633 m
.45349 .43781 L
s
.45151 .43633 m
.45341 .43781 L
s
.35302 .44298 m
.35294 .44233 L
s
.39277 .43947 m
.3929 .43862 L
s
.42949 .43814 m
.43104 .43674 L
s
.45167 .43631 m
.45356 .4378 L
s
.48683 .43599 m
.48712 .43692 L
s
.62486 .43547 m
.62485 .43592 L
s
.4869 .43599 m
.48719 .43692 L
s
.42943 .43814 m
.43098 .43674 L
s
.4295 .43814 m
.43107 .43674 L
s
.42952 .43813 m
.43107 .43673 L
s
.35293 .44295 m
.35286 .4423 L
s
.45153 .4363 m
.45344 .43778 L
s
.62472 .43545 m
.62471 .4359 L
s
.45156 .4363 m
.45347 .43777 L
s
.45169 .43629 m
.45359 .43777 L
s
.42952 .43811 m
.43109 .43671 L
s
.52733 .43285 m
.52739 .43353 L
s
.845 .28007 m
.84512 .28031 L
s
.42957 .4381 m
.43115 .43671 L
s
.42953 .4381 m
.43111 .43671 L
s
.45151 .43628 m
.45344 .43775 L
s
.45155 .43628 m
.45346 .43776 L
s
.45155 .43628 m
.45346 .43775 L
s
.48682 .43595 m
.48711 .43688 L
s
.42949 .43809 m
.43105 .43669 L
s
.42954 .43809 m
.43111 .43669 L
s
.45144 .43627 m
.45338 .43774 L
s
.27319 .44009 m
.27313 .4396 L
s
.45153 .43626 m
.45345 .43774 L
s
.45155 .43626 m
.45346 .43773 L
s
.4516 .43625 m
.45352 .43772 L
s
.45147 .43625 m
.45338 .43772 L
s
.39277 .43939 m
.3929 .43853 L
s
.39279 .43939 m
.39293 .43853 L
s
.45146 .43624 m
.45339 .43771 L
s
.4295 .43806 m
.4311 .43667 L
s
.42965 .43805 m
.43125 .43666 L
s
.42955 .43803 m
.43115 .43664 L
s
.45132 .43622 m
.45327 .43767 L
s
.45137 .43621 m
.45331 .43768 L
s
.42965 .43801 m
.43126 .43663 L
s
.42962 .43802 m
.43124 .43663 L
s
.42959 .43801 m
.4312 .43662 L
s
.42957 .43801 m
.43118 .43662 L
s
.42968 .438 m
.43128 .43661 L
s
.45134 .4362 m
.4533 .43765 L
s
.71533 .4276 m
.71531 .42797 L
s
.52723 .43277 m
.5273 .43344 L
s
.42966 .43799 m
.43128 .4366 L
s
.45144 .43618 m
.45339 .43764 L
s
.42966 .43799 m
.43127 .4366 L
s
.48681 .43585 m
.4871 .43678 L
s
.4514 .43618 m
.45336 .43764 L
s
.39287 .43931 m
.39301 .43845 L
s
.42959 .43798 m
.4312 .43659 L
s
.39283 .43931 m
.39297 .43845 L
s
.42967 .43797 m
.4313 .4366 L
s
.4513 .43617 m
.45326 .43762 L
s
.3529 .4428 m
.35283 .44216 L
s
.27308 .43997 m
.27301 .43948 L
s
.42963 .43796 m
.43124 .43657 L
s
.45128 .43616 m
.45326 .4376 L
s
.52721 .43272 m
.52728 .4334 L
s
.42973 .43794 m
.43135 .43656 L
s
.45132 .43616 m
.45329 .43761 L
s
.42971 .43794 m
.43134 .43657 L
s
.42966 .43793 m
.43129 .43655 L
s
.39279 .43926 m
.39294 .43841 L
s
.42968 .43793 m
.43133 .43655 L
s
.45126 .43614 m
.45324 .43758 L
s
.42971 .43791 m
.43133 .43653 L
s
.42963 .43792 m
.43127 .43654 L
s
.3928 .43925 m
.39295 .43839 L
s
.45133 .43613 m
.4533 .43757 L
s
.42978 .43791 m
.43142 .43653 L
s
.39284 .43924 m
.39298 .43838 L
s
.45131 .43611 m
.45329 .43756 L
s
.45139 .43611 m
.45335 .43757 L
s
.45115 .43612 m
.45315 .43755 L
s
.45121 .43611 m
.45319 .43756 L
s
.45135 .43611 m
.45332 .43755 L
s
.42976 .43788 m
.43143 .43652 L
s
.71533 .4275 m
.71532 .42787 L
s
.35288 .44272 m
.35281 .44208 L
s
.45129 .4361 m
.45327 .43754 L
s
.45127 .4361 m
.45325 .43754 L
s
.39282 .43922 m
.39297 .43836 L
s
.48677 .43575 m
.48707 .43668 L
s
.45118 .4361 m
.45317 .43754 L
s
.42975 .43787 m
.4314 .4365 L
s
.62472 .43521 m
.6247 .43566 L
s
.62477 .43521 m
.62476 .43566 L
s
.35291 .4427 m
.35285 .44205 L
s
.45125 .43607 m
.45323 .43752 L
s
.48682 .43572 m
.48712 .43665 L
s
.1644 .44827 m
.16432 .44791 L
s
.45112 .43607 m
.45314 .4375 L
s
.45118 .43607 m
.45318 .4375 L
s
.18217 .53926 m
.18202 .53886 L
s
.45104 .43607 m
.45305 .43749 L
s
.48681 .4357 m
.48711 .43663 L
s
.42983 .43783 m
.4315 .43646 L
s
.42973 .43783 m
.43139 .43646 L
s
.42981 .43782 m
.43149 .43646 L
s
.42979 .43782 m
.43145 .43646 L
s
.84488 .27982 m
.845 .28007 L
s
.42977 .43782 m
.43144 .43645 L
s
.42988 .43781 m
.43155 .43645 L
s
.42984 .43781 m
.43152 .43644 L
s
.48675 .43567 m
.48705 .4366 L
s
.4512 .43603 m
.45321 .43746 L
s
.39283 .43914 m
.39298 .43828 L
s
.42987 .43779 m
.43158 .43644 L
s
.27303 .43981 m
.27296 .43932 L
s
.42983 .43778 m
.43151 .43642 L
s
.42988 .43778 m
.43157 .43643 L
s
.45104 .43602 m
.45307 .43744 L
s
.42981 .43778 m
.43149 .43642 L
s
.42976 .43778 m
.43144 .43642 L
s
.45111 .436 m
.45313 .43742 L
s
.16434 .4482 m
.16427 .44784 L
s
.42983 .43776 m
.43152 .4364 L
s
.42981 .43776 m
.43149 .4364 L
s
.45104 .436 m
.45307 .43742 L
s
.35287 .44261 m
.3528 .44196 L
s
.42979 .43775 m
.43148 .4364 L
s
.42994 .43774 m
.43164 .43639 L
s
.45098 .43599 m
.45302 .4374 L
s
.45103 .43598 m
.45306 .4374 L
s
.45093 .43598 m
.45298 .43739 L
s
.45097 .43598 m
.45301 .43739 L
s
.42992 .43772 m
.43164 .43638 L
s
.45111 .43597 m
.45314 .43739 L
s
.39289 .43906 m
.39304 .43821 L
s
.42993 .43771 m
.43164 .43636 L
s
.45103 .43595 m
.45307 .43737 L
s
.42993 .43769 m
.43162 .43634 L
s
.45106 .43595 m
.4531 .43736 L
s
.42986 .43769 m
.43156 .43634 L
s
.45091 .43594 m
.45296 .43735 L
s
.52726 .43246 m
.52734 .43314 L
s
.45101 .43594 m
.45306 .43735 L
s
.48673 .43556 m
.48704 .43649 L
s
.45105 .43593 m
.45309 .43734 L
s
.42997 .43767 m
.43169 .43633 L
s
.45089 .43593 m
.45295 .43733 L
s
.42998 .43766 m
.43171 .43632 L
s
.62487 .43501 m
.62486 .43547 L
s
.39283 .43901 m
.39299 .43816 L
s
.45099 .43591 m
.45305 .43732 L
s
.45095 .43591 m
.453 .43732 L
s
.45088 .43591 m
.45295 .43731 L
s
.42997 .43764 m
.43169 .43631 L
s
.42994 .43764 m
.43167 .4363 L
s
.52724 .43243 m
.52731 .43311 L
s
.35288 .4425 m
.35282 .44186 L
s
.43002 .43764 m
.43177 .4363 L
s
.43 .43764 m
.43173 .4363 L
s
.62473 .43499 m
.62472 .43545 L
s
.39282 .43898 m
.39298 .43813 L
s
.43005 .43763 m
.43178 .43629 L
s
.35291 .44249 m
.35285 .44185 L
s
.52734 .4324 m
.52741 .43307 L
s
.45082 .43589 m
.45289 .43729 L
s
.45077 .43589 m
.45285 .43728 L
s
.45084 .43589 m
.45292 .43728 L
s
.42993 .43762 m
.43166 .43627 L
s
.42999 .43761 m
.43172 .43627 L
s
.42992 .43761 m
.43166 .43627 L
s
.43011 .4376 m
.43185 .43626 L
s
.4301 .4376 m
.43184 .43626 L
s
.71534 .42723 m
.71533 .4276 L
s
.52716 .43238 m
.52724 .43306 L
s
.48674 .43548 m
.48705 .4364 L
s
.43002 .43758 m
.43177 .43625 L
s
.39283 .43894 m
.393 .43808 L
s
.43001 .43758 m
.43174 .43624 L
s
.43005 .43758 m
.4318 .43625 L
s
.43007 .43756 m
.43183 .43624 L
s
.27313 .4396 m
.27306 .43911 L
s
.45079 .43585 m
.45287 .43724 L
s
.45084 .43585 m
.45293 .43723 L
s
.43002 .43757 m
.43177 .43623 L
s
.45069 .43585 m
.45279 .43723 L
s
.43011 .43755 m
.43188 .43623 L
s
.48668 .43545 m
.48699 .43637 L
s
.35284 .44242 m
.35278 .44177 L
s
.39281 .43891 m
.39298 .43805 L
s
.45076 .43584 m
.45285 .43722 L
s
.45084 .43583 m
.45293 .43722 L
s
.48675 .43544 m
.48707 .43637 L
s
.43008 .43754 m
.43184 .43622 L
s
.84476 .27958 m
.84488 .27982 L
s
.52719 .43232 m
.52727 .433 L
s
.45066 .43581 m
.45276 .43719 L
s
.48668 .43541 m
.487 .43634 L
s
.48671 .43541 m
.48702 .43634 L
s
.39283 .43887 m
.393 .43802 L
s
.45067 .43581 m
.45278 .43719 L
s
.43014 .43751 m
.43192 .43619 L
s
.45073 .4358 m
.45284 .43718 L
s
.45054 .43581 m
.45267 .43717 L
s
.48671 .4354 m
.48703 .43633 L
s
.48663 .4354 m
.48695 .43632 L
s
.45067 .4358 m
.45278 .43717 L
s
.45076 .43579 m
.45287 .43717 L
s
.45066 .43579 m
.45277 .43717 L
s
.45061 .4358 m
.45273 .43717 L
s
.43016 .43748 m
.43195 .43617 L
s
.45071 .43578 m
.45282 .43716 L
s
.35289 .44235 m
.35283 .44171 L
s
.39285 .43884 m
.39302 .43798 L
s
.43018 .43748 m
.43195 .43616 L
s
.43009 .43748 m
.43187 .43616 L
s
.71534 .42713 m
.71533 .4275 L
s
.45062 .43577 m
.45275 .43714 L
s
.45074 .43577 m
.45285 .43715 L
s
.43016 .43747 m
.43195 .43615 L
s
.52717 .43227 m
.52725 .43295 L
s
.52719 .43227 m
.52727 .43295 L
s
.43021 .43746 m
.43201 .43615 L
s
.35294 .44233 m
.35288 .44168 L
s
.45065 .43576 m
.45277 .43713 L
s
.43021 .43745 m
.432 .43613 L
s
.48662 .43535 m
.48694 .43627 L
s
.16432 .44791 m
.16425 .44754 L
s
.43028 .43744 m
.43209 .43613 L
s
.43025 .43744 m
.43204 .43612 L
s
.27301 .43948 m
.27295 .43899 L
s
.43019 .43744 m
.43198 .43612 L
s
.43019 .43743 m
.43198 .43612 L
s
.35286 .4423 m
.35281 .44165 L
s
.43013 .43743 m
.43192 .43611 L
s
.39283 .43879 m
.393 .43793 L
s
.4302 .43741 m
.432 .4361 L
s
.4506 .43572 m
.45275 .43708 L
s
.45052 .43572 m
.45267 .43708 L
s
.43017 .4374 m
.43199 .4361 L
s
.43028 .4374 m
.4321 .4361 L
s
.39294 .43876 m
.39311 .4379 L
s
.18202 .53886 m
.18187 .53847 L
s
.48661 .4353 m
.48694 .43622 L
s
.45054 .43571 m
.45268 .43707 L
s
.43027 .43739 m
.43207 .43608 L
s
.45045 .43571 m
.45259 .43707 L
s
.62472 .43475 m
.62472 .43521 L
s
.45042 .43571 m
.45258 .43706 L
s
.43021 .43738 m
.43201 .43607 L
s
.52725 .43217 m
.52733 .43285 L
s
.62478 .43475 m
.62477 .43521 L
s
.43024 .43738 m
.43205 .43607 L
s
.45046 .43569 m
.45261 .43704 L
s
.16427 .44784 m
.1642 .44747 L
s
.45035 .43569 m
.45252 .43703 L
s
.43033 .43734 m
.43215 .43604 L
s
.43039 .43734 m
.43223 .43605 L
s
.45046 .43566 m
.45262 .43701 L
s
.43029 .43733 m
.43212 .43604 L
s
.3929 .4387 m
.39307 .43785 L
s
.3929 .4387 m
.39307 .43785 L
s
.45047 .43566 m
.45264 .43701 L
s
.45046 .43566 m
.45262 .43701 L
s
.43029 .43732 m
.43213 .43603 L
s
.45044 .43566 m
.4526 .437 L
s
.48661 .43523 m
.48694 .43615 L
s
.45042 .43565 m
.4526 .43699 L
s
.43037 .43731 m
.43221 .43602 L
s
.43043 .4373 m
.43229 .43601 L
s
.3929 .43867 m
.39307 .43782 L
s
.45038 .43564 m
.45255 .43698 L
s
.45037 .43564 m
.45254 .43698 L
s
.39286 .43866 m
.39303 .43781 L
s
.45024 .43563 m
.45243 .43696 L
s
.45038 .43562 m
.45255 .43697 L
s
.43038 .43728 m
.43222 .43599 L
s
.43038 .43728 m
.43222 .43598 L
s
.48654 .43519 m
.48687 .43611 L
s
.39287 .43865 m
.39305 .43779 L
s
.27296 .43932 m
.27291 .43883 L
s
.4303 .43727 m
.43215 .43598 L
s
.35283 .44216 m
.35278 .44151 L
s
.52715 .43209 m
.52723 .43277 L
s
.84464 .27934 m
.84476 .27958 L
s
.43044 .43725 m
.43229 .43597 L
s
.43042 .43725 m
.43228 .43597 L
s
.45032 .4356 m
.4525 .43694 L
s
.45043 .4356 m
.4526 .43694 L
s
.43036 .43726 m
.43222 .43597 L
s
.43043 .43725 m
.43228 .43596 L
s
.39291 .43863 m
.39309 .43777 L
s
.45032 .4356 m
.45251 .43693 L
s
.43039 .43725 m
.43224 .43596 L
s
.48655 .43516 m
.48689 .43608 L
s
.43039 .43724 m
.43226 .43596 L
s
.4305 .43724 m
.43238 .43596 L
s
.3929 .43862 m
.39308 .43776 L
s
.45018 .4356 m
.45239 .43692 L
s
.4865 .43516 m
.48684 .43608 L
s
.45032 .43559 m
.45252 .43691 L
s
.43034 .43724 m
.43219 .43595 L
s
.48657 .43515 m
.4869 .43607 L
s
.43047 .43723 m
.43234 .43595 L
s
.45019 .43558 m
.45239 .43691 L
s
.52713 .43205 m
.52721 .43272 L
s
.48658 .43513 m
.48691 .43605 L
s
.45011 .43557 m
.45233 .43688 L
s
.45024 .43556 m
.45245 .43688 L
s
.43049 .43719 m
.43237 .43591 L
s
.43056 .43719 m
.43245 .43592 L
s
.35281 .44208 m
.35276 .44143 L
s
.43043 .43719 m
.43231 .43591 L
s
.62488 .43456 m
.62487 .43501 L
s
.71535 .42685 m
.71534 .42723 L
s
.43045 .43717 m
.43231 .43589 L
s
.4866 .43509 m
.48694 .43602 L
s
.45022 .43553 m
.45244 .43685 L
s
.43048 .43716 m
.43237 .43589 L
s
.45015 .43553 m
.45237 .43684 L
s
.35285 .44205 m
.35279 .4414 L
s
.45019 .43552 m
.4524 .43684 L
s
.62474 .43454 m
.62473 .43499 L
s
.3929 .43853 m
.39309 .43768 L
s
.39293 .43853 m
.39311 .43767 L
s
.48649 .43507 m
.48683 .43599 L
s
.45012 .43552 m
.45235 .43683 L
s
.48656 .43507 m
.4869 .43599 L
s
.43056 .43714 m
.43246 .43587 L
s
.45007 .43551 m
.4523 .43682 L
s
.45014 .43551 m
.45237 .43682 L
s
.43061 .43712 m
.43252 .43586 L
s
.43055 .43713 m
.43245 .43586 L
s
.4306 .43712 m
.4325 .43585 L
s
.43052 .43712 m
.43244 .43586 L
s
.45013 .4355 m
.45236 .4368 L
s
.45 .4355 m
.45224 .4368 L
s
.45007 .4355 m
.45229 .4368 L
s
.43059 .43711 m
.43249 .43584 L
s
.43049 .43711 m
.43239 .43584 L
s
.43056 .43711 m
.43247 .43584 L
s
.45009 .43549 m
.45234 .43679 L
s
.48648 .43503 m
.48682 .43595 L
s
.45021 .43548 m
.45243 .43679 L
s
.43067 .43709 m
.43259 .43584 L
s
.45005 .43548 m
.45228 .43678 L
s
.44996 .43548 m
.45221 .43677 L
s
.44999 .43548 m
.45225 .43677 L
s
.44994 .43548 m
.45219 .43677 L
s
.43062 .43708 m
.43253 .43581 L
s
.43066 .43707 m
.43258 .43581 L
s
.39301 .43845 m
.3932 .4376 L
s
.39297 .43845 m
.39316 .4376 L
s
.4306 .43707 m
.43253 .43581 L
s
.45011 .43545 m
.45234 .43676 L
s
.71535 .42675 m
.71534 .42713 L
s
.43056 .43706 m
.43247 .4358 L
s
.44989 .43546 m
.45215 .43674 L
s
.3528 .44196 m
.35275 .44131 L
s
.4307 .43705 m
.43262 .43579 L
s
.43066 .43705 m
.43259 .43579 L
s
.43072 .43705 m
.43265 .4358 L
s
.27306 .43911 m
.27301 .43862 L
s
.16425 .44754 m
.16418 .44718 L
s
.43063 .43704 m
.43256 .43579 L
s
.43065 .43703 m
.4326 .43578 L
s
.44992 .43543 m
.45219 .43671 L
s
.44982 .43543 m
.45209 .43671 L
s
.44994 .43542 m
.4522 .43671 L
s
.39294 .43841 m
.39313 .43755 L
s
.43074 .43701 m
.43268 .43577 L
s
.39295 .43839 m
.39314 .43754 L
s
.39298 .43838 m
.39317 .43753 L
s
.44991 .4354 m
.45218 .43668 L
s
.44989 .43541 m
.45216 .43668 L
s
.4307 .43699 m
.43266 .43575 L
s
.48646 .43492 m
.48681 .43585 L
s
.4308 .43698 m
.43276 .43574 L
s
.84451 .2791 m
.84464 .27934 L
s
.39297 .43836 m
.39317 .43751 L
s
.44973 .43539 m
.45202 .43666 L
s
.44982 .43538 m
.45211 .43665 L
s
.43083 .43696 m
.4328 .43572 L
s
.43082 .43696 m
.43278 .43572 L
s
.1642 .44747 m
.16413 .44711 L
s
.44982 .43538 m
.45211 .43665 L
s
.18187 .53847 m
.18172 .53808 L
s
.52718 .43179 m
.52726 .43246 L
s
.35282 .44186 m
.35278 .44121 L
s
.44986 .43536 m
.45213 .43664 L
s
.43075 .43694 m
.4327 .4357 L
s
.43074 .43694 m
.4327 .4357 L
s
.44972 .43536 m
.45202 .43663 L
s
.43079 .43693 m
.43276 .4357 L
s
.44979 .43535 m
.45208 .43662 L
s
.35285 .44185 m
.3528 .4412 L
s
.4497 .43536 m
.452 .43662 L
s
.43083 .43692 m
.4328 .43569 L
s
.43077 .43692 m
.43273 .43568 L
s
.44986 .43535 m
.45214 .43662 L
s
.43084 .43692 m
.43282 .43569 L
s
.43082 .43692 m
.43281 .43569 L
s
.27295 .43899 m
.2729 .4385 L
s
.44956 .43536 m
.45187 .43661 L
s
.44974 .43534 m
.45202 .43661 L
s
.52715 .43175 m
.52724 .43243 L
s
.44977 .43534 m
.45206 .43661 L
s
.4308 .43691 m
.43276 .43567 L
s
.44983 .43534 m
.45212 .4366 L
s
.43095 .4369 m
.43293 .43568 L
s
.62473 .4343 m
.62472 .43475 L
s
.44967 .43533 m
.45197 .43659 L
s
.43085 .4369 m
.43281 .43566 L
s
.62478 .4343 m
.62478 .43475 L
s
.44978 .43533 m
.45207 .43659 L
s
.52725 .43172 m
.52734 .4324 L
s
.4308 .43689 m
.43277 .43566 L
s
.39298 .43828 m
.39318 .43743 L
s
.48642 .43483 m
.48677 .43575 L
s
.43086 .43687 m
.43283 .43564 L
s
.43094 .43687 m
.43294 .43565 L
s
.44967 .43532 m
.45199 .43656 L
s
.43082 .43686 m
.4328 .43564 L
s
.52707 .4317 m
.52716 .43238 L
s
.35278 .44177 m
.35274 .44113 L
s
.48646 .4348 m
.48682 .43572 L
s
.43091 .43684 m
.43291 .43562 L
s
.48645 .43478 m
.48681 .4357 L
s
.44955 .43529 m
.45188 .43653 L
s
.43096 .43682 m
.43297 .43561 L
s
.44967 .43527 m
.45198 .43652 L
s
.43091 .43682 m
.43291 .43559 L
s
.44954 .43527 m
.45188 .43651 L
s
.39304 .43821 m
.39324 .43735 L
s
.44956 .43526 m
.45188 .4365 L
s
.43104 .4368 m
.43306 .43559 L
s
.5271 .43165 m
.52719 .43232 L
s
.43106 .43679 m
.43307 .43559 L
s
.48639 .43475 m
.48675 .43567 L
s
.44951 .43526 m
.45185 .43649 L
s
.44949 .43526 m
.45183 .43649 L
s
.43096 .43679 m
.43297 .43559 L
s
.44951 .43526 m
.45185 .43649 L
s
.35283 .44171 m
.35278 .44106 L
s
.43112 .43677 m
.43315 .43557 L
s
.44947 .43525 m
.45181 .43648 L
s
.43101 .43677 m
.43304 .43557 L
s
.71535 .42648 m
.71535 .42685 L
s
.44938 .43524 m
.45172 .43647 L
s
.43098 .43677 m
.433 .43556 L
s
.43111 .43676 m
.43313 .43556 L
s
.44957 .43522 m
.4519 .43646 L
s
.43096 .43676 m
.43298 .43555 L
s
.35288 .44168 m
.35284 .44104 L
s
.431 .43676 m
.43301 .43555 L
s
.39299 .43816 m
.39319 .4373 L
s
.27291 .43883 m
.27285 .43834 L
s
.43104 .43674 m
.43306 .43553 L
s
.43107 .43674 m
.43311 .43554 L
s
.4495 .43521 m
.45183 .43644 L
s
.52708 .4316 m
.52717 .43227 L
s
.5271 .4316 m
.52719 .43227 L
s
.35281 .44165 m
.35277 .44101 L
s
.43098 .43674 m
.43301 .43553 L
s
.43107 .43673 m
.43309 .43552 L
s
.44949 .4352 m
.45184 .43643 L
s
.44942 .43521 m
.45177 .43643 L
s
.44946 .4352 m
.45181 .43643 L
s
.39298 .43813 m
.39318 .43728 L
s
.44954 .43519 m
.45188 .43642 L
s
.44939 .4352 m
.45175 .43641 L
s
.44931 .43519 m
.45168 .43641 L
s
.43115 .43671 m
.4332 .43552 L
s
.43109 .43671 m
.43313 .43551 L
s
.43111 .43671 m
.43316 .43552 L
s
.62488 .43411 m
.62488 .43456 L
s
.84439 .27886 m
.84451 .2791 L
s
.44934 .43518 m
.45171 .43639 L
s
.44943 .43517 m
.45179 .4364 L
s
.43111 .43669 m
.43316 .4355 L
s
.43105 .43669 m
.43309 .43549 L
s
.48637 .43464 m
.48673 .43556 L
s
.44928 .43517 m
.45166 .43638 L
s
.393 .43808 m
.3932 .43723 L
s
.44927 .43516 m
.45165 .43637 L
s
.62474 .43408 m
.62474 .43454 L
s
.4311 .43667 m
.43316 .43548 L
s
.43125 .43666 m
.43331 .43547 L
s
.71536 .42638 m
.71535 .42675 L
s
.44922 .43515 m
.4516 .43636 L
s
.52715 .4315 m
.52725 .43217 L
s
.39298 .43805 m
.39318 .4372 L
s
.43115 .43664 m
.43322 .43546 L
s
.16418 .44718 m
.16411 .44682 L
s
.43124 .43663 m
.43332 .43546 L
s
.43126 .43663 m
.43333 .43545 L
s
.44919 .43514 m
.45158 .43633 L
s
.44912 .43514 m
.45151 .43633 L
s
.44925 .43514 m
.45163 .43634 L
s
.4312 .43662 m
.43328 .43544 L
s
.43128 .43661 m
.43336 .43544 L
s
.43118 .43662 m
.43324 .43544 L
s
.44928 .43511 m
.45167 .43631 L
s
.43128 .4366 m
.43335 .43543 L
s
.393 .43802 m
.39321 .43717 L
s
.43127 .4366 m
.43334 .43542 L
s
.4313 .4366 m
.43339 .43543 L
s
.44913 .43511 m
.45153 .4363 L
s
.4312 .43659 m
.43328 .43541 L
s
.44916 .43511 m
.45156 .4363 L
s
.48637 .43456 m
.48674 .43548 L
s
.4491 .4351 m
.45151 .43628 L
s
.4493 .43509 m
.45169 .43629 L
s
.44915 .43509 m
.45155 .43628 L
s
.44915 .43509 m
.45155 .43628 L
s
.44902 .4351 m
.45144 .43627 L
s
.43124 .43657 m
.43331 .43539 L
s
.35278 .44151 m
.35274 .44086 L
s
.39302 .43798 m
.39323 .43713 L
s
.43135 .43656 m
.43344 .43539 L
s
.43134 .43657 m
.43344 .4354 L
s
.48631 .43453 m
.48668 .43545 L
s
.44912 .43508 m
.45153 .43626 L
s
.43133 .43655 m
.43344 .43539 L
s
.16413 .44711 m
.16406 .44674 L
s
.43129 .43655 m
.43338 .43538 L
s
.48638 .43452 m
.48675 .43544 L
s
.44915 .43506 m
.45155 .43626 L
s
.43127 .43654 m
.43337 .43538 L
s
.44906 .43506 m
.45147 .43625 L
s
.4492 .43506 m
.4516 .43625 L
s
.43133 .43653 m
.43341 .43536 L
s
.44904 .43506 m
.45146 .43624 L
s
.43142 .43653 m
.43352 .43537 L
s
.52705 .43142 m
.52715 .43209 L
s
.27301 .43862 m
.27295 .43813 L
s
.48631 .43449 m
.48668 .43541 L
s
.48634 .43449 m
.48671 .43541 L
s
.43143 .43652 m
.43355 .43537 L
s
.18172 .53808 m
.18157 .53768 L
s
.393 .43793 m
.39322 .43708 L
s
.44889 .43505 m
.45132 .43622 L
s
.48634 .43448 m
.48671 .4354 L
s
.48625 .43448 m
.48663 .4354 L
s
.44895 .43504 m
.45137 .43621 L
s
.4314 .4365 m
.43351 .43534 L
s
.4489 .43505 m
.45134 .4362 L
s
.35276 .44143 m
.35272 .44078 L
s
.52703 .43137 m
.52713 .43205 L
s
.39311 .4379 m
.39332 .43705 L
s
.44901 .43502 m
.45144 .43618 L
s
.44896 .43502 m
.4514 .43618 L
s
.4315 .43646 m
.43362 .43532 L
s
.43149 .43646 m
.43362 .43532 L
s
.43145 .43646 m
.43358 .43531 L
s
.35279 .4414 m
.35276 .44076 L
s
.43139 .43646 m
.43351 .43531 L
s
.44886 .43501 m
.4513 .43617 L
s
.43144 .43645 m
.43357 .43531 L
s
.43155 .43645 m
.43368 .4353 L
s
.44883 .43501 m
.45128 .43616 L
s
.48624 .43443 m
.48662 .43535 L
s
.43152 .43644 m
.43365 .4353 L
s
.43158 .43644 m
.43373 .43531 L
s
.44888 .435 m
.45132 .43616 L
s
.43157 .43643 m
.43371 .43529 L
s
.43151 .43642 m
.43364 .43528 L
s
.39307 .43785 m
.39329 .437 L
s
.43149 .43642 m
.43363 .43528 L
s
.39307 .43785 m
.39329 .43699 L
s
.44881 .43499 m
.45126 .43614 L
s
.62473 .43384 m
.62473 .4343 L
s
.43144 .43642 m
.43357 .43527 L
s
.84426 .27862 m
.84439 .27886 L
s
.62479 .43384 m
.62478 .4343 L
s
.44889 .43497 m
.45133 .43613 L
s
.44869 .43498 m
.45115 .43612 L
s
.43152 .4364 m
.43366 .43526 L
s
.44886 .43496 m
.45131 .43611 L
s
.2729 .4385 m
.27284 .43801 L
s
.39307 .43782 m
.39329 .43697 L
s
.48623 .43438 m
.48661 .4353 L
s
.44895 .43495 m
.45139 .43611 L
s
.44876 .43496 m
.45121 .43611 L
s
.43148 .4364 m
.43363 .43526 L
s
.43149 .4364 m
.43361 .43525 L
s
.44889 .43496 m
.45135 .43611 L
s
.43164 .43639 m
.43379 .43525 L
s
.44882 .43495 m
.45127 .4361 L
s
.44883 .43495 m
.45129 .4361 L
s
.44872 .43496 m
.45118 .4361 L
s
.43164 .43638 m
.4338 .43525 L
s
.39303 .43781 m
.39325 .43695 L
s
.39305 .43779 m
.39327 .43694 L
s
.71536 .42611 m
.71535 .42648 L
s
.44864 .43495 m
.45112 .43607 L
s
.43164 .43636 m
.4338 .43523 L
s
.35275 .44131 m
.35271 .44067 L
s
.4488 .43492 m
.45125 .43607 L
s
.44857 .43494 m
.45104 .43607 L
s
.44871 .43493 m
.45118 .43607 L
s
.39309 .43777 m
.39331 .43692 L
s
.43162 .43634 m
.43376 .4352 L
s
.43156 .43634 m
.43372 .43521 L
s
.39308 .43776 m
.3933 .43691 L
s
.43169 .43633 m
.43386 .43521 L
s
.43171 .43632 m
.43389 .43521 L
s
.48623 .43431 m
.48661 .43523 L
s
.44872 .4349 m
.4512 .43603 L
s
.44855 .43491 m
.45104 .43602 L
s
.43169 .43631 m
.43387 .43519 L
s
.43177 .4363 m
.43396 .43519 L
s
.43167 .4363 m
.43385 .43518 L
s
.43173 .4363 m
.43391 .43518 L
s
.43178 .43629 m
.43396 .43517 L
s
.44862 .43488 m
.45111 .436 L
s
.44855 .43488 m
.45104 .436 L
s
.48616 .43427 m
.48654 .43519 L
s
.43166 .43627 m
.43384 .43516 L
s
.43172 .43627 m
.4339 .43515 L
s
.43166 .43627 m
.43385 .43516 L
s
.44848 .43488 m
.45098 .43599 L
s
.43185 .43626 m
.43404 .43515 L
s
.43184 .43626 m
.43403 .43515 L
s
.44853 .43487 m
.45103 .43598 L
s
.44843 .43488 m
.45093 .43598 L
s
.44847 .43487 m
.45097 .43598 L
s
.43177 .43625 m
.43396 .43514 L
s
.44862 .43485 m
.45111 .43597 L
s
.48617 .43424 m
.48655 .43516 L
s
.35278 .44121 m
.35274 .44056 L
s
.4318 .43625 m
.43401 .43514 L
s
.71536 .42601 m
.71536 .42638 L
s
.48611 .43424 m
.4865 .43516 L
s
.39309 .43768 m
.39331 .43682 L
s
.43174 .43624 m
.43393 .43513 L
s
.39311 .43767 m
.39334 .43682 L
s
.43183 .43624 m
.43404 .43513 L
s
.48619 .43423 m
.48657 .43515 L
s
.16411 .44682 m
.16404 .44645 L
s
.43177 .43623 m
.43397 .43513 L
s
.43188 .43623 m
.43409 .43513 L
s
.44853 .43485 m
.45103 .43595 L
s
.3528 .4412 m
.35276 .44055 L
s
.44856 .43484 m
.45106 .43595 L
s
.27285 .43834 m
.2728 .43785 L
s
.52707 .43111 m
.52718 .43179 L
s
.43184 .43622 m
.43406 .43512 L
s
.4484 .43484 m
.45091 .43594 L
s
.62489 .43365 m
.62488 .43411 L
s
.44837 .43484 m
.45089 .43593 L
s
.44851 .43483 m
.45101 .43594 L
s
.4862 .43421 m
.48658 .43513 L
s
.44855 .43482 m
.45105 .43593 L
s
.43192 .43619 m
.43415 .4351 L
s
.44847 .43481 m
.45099 .43591 L
s
.44835 .43482 m
.45088 .43591 L
s
.62474 .43363 m
.62474 .43408 L
s
.44845 .43481 m
.45095 .43591 L
s
.52704 .43108 m
.52715 .43175 L
s
.44823 .43482 m
.45077 .43589 L
s
.48621 .43417 m
.4866 .43509 L
s
.44829 .43481 m
.45082 .43589 L
s
.43195 .43617 m
.43418 .43508 L
s
.44831 .4348 m
.45084 .43589 L
s
.52714 .43105 m
.52725 .43172 L
s
.3932 .4376 m
.39343 .43674 L
s
.39316 .4376 m
.39339 .43675 L
s
.35274 .44113 m
.35271 .44048 L
s
.43187 .43616 m
.4341 .43507 L
s
.43195 .43616 m
.43418 .43506 L
s
.43195 .43615 m
.43419 .43507 L
s
.43201 .43615 m
.43425 .43507 L
s
.16406 .44674 m
.16399 .44638 L
s
.48609 .43415 m
.48649 .43507 L
s
.48617 .43415 m
.48656 .43507 L
s
.43209 .43613 m
.43434 .43506 L
s
.432 .43613 m
.43423 .43505 L
s
.84414 .27838 m
.84426 .27862 L
s
.43204 .43612 m
.43427 .43504 L
s
.43198 .43612 m
.43422 .43504 L
s
.44815 .43479 m
.45069 .43585 L
s
.52696 .43103 m
.52707 .4317 L
s
.4483 .43477 m
.45084 .43585 L
s
.43198 .43612 m
.43421 .43503 L
s
.44825 .43477 m
.45079 .43585 L
s
.43192 .43611 m
.43415 .43503 L
s
.39313 .43755 m
.39336 .4367 L
s
.44829 .43476 m
.45084 .43583 L
s
.432 .4361 m
.43425 .43503 L
s
.44822 .43476 m
.45076 .43584 L
s
.48608 .43411 m
.48648 .43503 L
s
.4321 .4361 m
.43437 .43503 L
s
.43199 .4361 m
.43425 .43503 L
s
.39314 .43754 m
.39337 .43669 L
s
.39317 .43753 m
.3934 .43668 L
s
.35278 .44106 m
.35275 .44041 L
s
.43207 .43608 m
.43431 .435 L
s
.44797 .43476 m
.45054 .43581 L
s
.44812 .43474 m
.45066 .43581 L
s
.44812 .43475 m
.45067 .43581 L
s
.44818 .43473 m
.45073 .4358 L
s
.43205 .43607 m
.4343 .435 L
s
.43201 .43607 m
.43425 .43499 L
s
.18157 .53768 m
.18142 .53729 L
s
.44804 .43474 m
.45061 .4358 L
s
.44811 .43474 m
.45067 .4358 L
s
.52699 .43097 m
.5271 .43165 L
s
.39317 .43751 m
.3934 .43666 L
s
.44821 .43473 m
.45076 .43579 L
s
.4481 .43473 m
.45066 .43579 L
s
.35284 .44104 m
.35281 .44039 L
s
.43223 .43605 m
.43451 .43499 L
s
.44806 .43472 m
.45062 .43577 L
s
.44816 .43471 m
.45071 .43578 L
s
.43215 .43604 m
.43441 .43497 L
s
.43212 .43604 m
.43439 .43497 L
s
.44819 .4347 m
.45074 .43577 L
s
.35277 .44101 m
.35274 .44036 L
s
.43213 .43603 m
.4344 .43497 L
s
.43229 .43601 m
.43458 .43497 L
s
.43221 .43602 m
.43449 .43496 L
s
.4481 .43469 m
.45065 .43576 L
s
.52697 .43093 m
.52708 .4316 L
s
.52699 .43092 m
.5271 .4316 L
s
.27295 .43813 m
.2729 .43764 L
s
.43222 .43599 m
.4345 .43494 L
s
.44802 .43468 m
.4506 .43572 L
s
.44794 .43469 m
.45052 .43572 L
s
.43222 .43598 m
.4345 .43493 L
s
.48606 .43401 m
.48646 .43492 L
s
.43215 .43598 m
.43444 .43493 L
s
.44784 .43468 m
.45042 .43571 L
s
.39318 .43743 m
.39342 .43658 L
s
.44787 .43467 m
.45045 .43571 L
s
.43228 .43597 m
.43457 .43492 L
s
.43222 .43597 m
.43452 .43493 L
s
.43229 .43597 m
.43457 .43492 L
s
.44797 .43466 m
.45054 .43571 L
s
.43228 .43596 m
.43457 .43492 L
s
.43238 .43596 m
.43469 .43493 L
s
.43226 .43596 m
.43456 .43493 L
s
.43224 .43596 m
.43453 .43491 L
s
.44775 .43467 m
.45035 .43569 L
s
.43234 .43595 m
.43464 .43491 L
s
.44787 .43465 m
.45046 .43569 L
s
.71537 .42574 m
.71536 .42611 L
s
.43219 .43595 m
.43447 .4349 L
s
.62473 .43339 m
.62473 .43384 L
s
.44786 .43464 m
.45046 .43566 L
s
.62478 .43339 m
.62479 .43384 L
s
.44788 .43464 m
.45047 .43566 L
s
.43245 .43592 m
.43477 .43489 L
s
.44788 .43463 m
.45046 .43566 L
s
.52704 .43083 m
.52715 .4315 L
s
.43237 .43591 m
.43467 .43488 L
s
.44784 .43463 m
.45044 .43566 L
s
.44782 .43463 m
.45042 .43565 L
s
.43231 .43591 m
.43462 .43488 L
s
.44778 .43463 m
.45038 .43564 L
s
.44777 .43462 m
.45037 .43564 L
s
.39324 .43735 m
.39349 .4365 L
s
.44763 .43463 m
.45024 .43563 L
s
.43237 .43589 m
.43469 .43486 L
s
.43231 .43589 m
.43461 .43485 L
s
.48602 .43391 m
.48642 .43483 L
s
.44779 .4346 m
.45038 .43562 L
s
.43246 .43587 m
.43479 .43485 L
s
.27284 .43801 m
.2728 .43752 L
s
.35274 .44086 m
.35271 .44021 L
s
.43252 .43586 m
.43485 .43485 L
s
.44772 .43459 m
.45032 .4356 L
s
.44771 .43459 m
.45032 .4356 L
s
.44756 .43461 m
.45018 .4356 L
s
.43245 .43586 m
.43478 .43484 L
s
.4325 .43585 m
.43483 .43484 L
s
.43244 .43586 m
.43478 .43484 L
s
.44783 .43458 m
.45043 .4356 L
s
.48606 .43388 m
.48646 .4348 L
s
.4477 .43459 m
.45032 .43559 L
s
.43249 .43584 m
.43482 .43483 L
s
.84401 .27814 m
.84414 .27838 L
s
.43259 .43584 m
.43494 .43483 L
s
.43247 .43584 m
.4348 .43482 L
s
.39319 .4373 m
.39344 .43645 L
s
.43239 .43584 m
.43472 .43482 L
s
.44757 .43458 m
.45019 .43558 L
s
.48604 .43387 m
.48645 .43478 L
s
.71537 .42563 m
.71536 .42601 L
s
.44748 .43459 m
.45011 .43557 L
s
.16404 .44645 m
.16398 .44609 L
s
.44761 .43457 m
.45024 .43556 L
s
.43258 .43581 m
.43492 .43481 L
s
.43253 .43581 m
.43486 .4348 L
s
.39318 .43728 m
.39343 .43643 L
s
.43253 .43581 m
.43488 .43481 L
s
.43265 .4358 m
.435 .4348 L
s
.48598 .43384 m
.48639 .43475 L
s
.52693 .43074 m
.52705 .43142 L
s
.43247 .4358 m
.43481 .43478 L
s
.43259 .43579 m
.43493 .43478 L
s
.43262 .43579 m
.43496 .43478 L
s
.44751 .43455 m
.45015 .43553 L
s
.44759 .43455 m
.45022 .43553 L
s
.35272 .44078 m
.3527 .44013 L
s
.43256 .43579 m
.43492 .43478 L
s
.4326 .43578 m
.43496 .43478 L
s
.44756 .43453 m
.45019 .43552 L
s
.44748 .43454 m
.45012 .43552 L
s
.43268 .43577 m
.43504 .43477 L
s
.44743 .43453 m
.45007 .43551 L
s
.4475 .43453 m
.45014 .43551 L
s
.3932 .43723 m
.39345 .43638 L
s
.35276 .44076 m
.35273 .44011 L
s
.52692 .4307 m
.52703 .43137 L
s
.44736 .43453 m
.45 .4355 L
s
.43266 .43575 m
.43503 .43476 L
s
.44749 .43452 m
.45013 .4355 L
s
.43276 .43574 m
.43513 .43476 L
s
.16399 .44638 m
.16392 .44602 L
s
.44744 .43452 m
.45009 .43549 L
s
.44743 .43452 m
.45007 .4355 L
s
.44734 .43452 m
.44999 .43548 L
s
.39318 .4372 m
.39344 .43635 L
s
.44731 .43451 m
.44996 .43548 L
s
.4474 .4345 m
.45005 .43548 L
s
.4328 .43572 m
.43518 .43474 L
s
.44728 .43452 m
.44994 .43548 L
s
.44758 .43449 m
.45021 .43548 L
s
.43278 .43572 m
.43517 .43474 L
s
.62488 .4332 m
.62489 .43365 L
s
.44723 .43451 m
.44989 .43546 L
s
.4327 .4357 m
.43508 .43472 L
s
.4327 .4357 m
.43507 .43471 L
s
.43276 .4357 m
.43515 .43472 L
s
.44747 .43448 m
.45011 .43545 L
s
.2728 .43785 m
.27275 .43736 L
s
.62474 .43317 m
.62474 .43363 L
s
.43281 .43569 m
.43522 .43473 L
s
.39321 .43717 m
.39347 .43632 L
s
.4328 .43569 m
.43519 .43472 L
s
.43282 .43569 m
.43521 .43472 L
s
.43273 .43568 m
.43511 .4347 L
s
.43293 .43568 m
.43533 .43471 L
s
.44724 .43449 m
.44992 .43543 L
s
.44714 .43449 m
.44982 .43543 L
s
.48596 .43372 m
.48637 .43464 L
s
.43276 .43567 m
.43514 .43469 L
s
.44728 .43447 m
.44994 .43542 L
s
.43281 .43566 m
.43519 .43468 L
s
.43277 .43566 m
.43516 .43468 L
s
.39323 .43713 m
.39348 .43628 L
s
.43294 .43565 m
.43536 .43469 L
s
.35271 .44067 m
.35269 .44002 L
s
.44722 .43447 m
.44989 .43541 L
s
.44724 .43445 m
.44991 .4354 L
s
.43283 .43564 m
.43522 .43467 L
s
.44705 .43446 m
.44973 .43539 L
s
.4328 .43564 m
.4352 .43467 L
s
.44714 .43445 m
.44982 .43538 L
s
.18142 .53729 m
.18128 .53689 L
s
.44714 .43445 m
.44982 .43538 L
s
.43291 .43562 m
.43532 .43466 L
s
.43297 .43561 m
.43539 .43466 L
s
.44704 .43444 m
.44972 .43536 L
s
.447 .43444 m
.4497 .43536 L
s
.44719 .43442 m
.44986 .43536 L
s
.44686 .43445 m
.44956 .43536 L
s
.39322 .43708 m
.39347 .43623 L
s
.43306 .43559 m
.43549 .43465 L
s
.44711 .43441 m
.44979 .43535 L
s
.43307 .43559 m
.4355 .43464 L
s
.43291 .43559 m
.43531 .43463 L
s
.43297 .43559 m
.4354 .43464 L
s
.44718 .43441 m
.44986 .43535 L
s
.48596 .43364 m
.48637 .43456 L
s
.44705 .43441 m
.44974 .43534 L
s
.44708 .43441 m
.44977 .43534 L
s
.43315 .43557 m
.43559 .43463 L
s
.44697 .43442 m
.44967 .43533 L
s
.44715 .4344 m
.44983 .43534 L
s
.39332 .43705 m
.39358 .4362 L
s
.43304 .43557 m
.43548 .43463 L
s
.44709 .4344 m
.44978 .43533 L
s
.43313 .43556 m
.43557 .43462 L
s
.44696 .43441 m
.44967 .43532 L
s
.84389 .27789 m
.84401 .27814 L
s
.48589 .43362 m
.48631 .43453 L
s
.433 .43556 m
.43543 .43461 L
s
.43298 .43555 m
.4354 .43461 L
s
.43301 .43555 m
.43543 .4346 L
s
.48596 .43361 m
.48638 .43452 L
s
.43311 .43554 m
.43556 .43461 L
s
.35274 .44056 m
.35272 .43991 L
s
.71537 .42536 m
.71537 .42574 L
s
.43306 .43553 m
.43549 .43459 L
s
.44684 .43439 m
.44955 .43529 L
s
.35276 .44055 m
.35274 .4399 L
s
.43309 .43552 m
.43552 .43458 L
s
.43301 .43553 m
.43544 .43459 L
s
.48589 .43358 m
.48631 .43449 L
s
.48591 .43358 m
.48634 .43449 L
s
.4332 .43552 m
.43566 .43459 L
s
.43316 .43552 m
.43561 .43459 L
s
.39329 .437 m
.39355 .43615 L
s
.43313 .43551 m
.43557 .43458 L
s
.39329 .43699 m
.39355 .43614 L
s
.44683 .43437 m
.44954 .43527 L
s
.44697 .43435 m
.44967 .43527 L
s
.48583 .43357 m
.48625 .43448 L
s
.48592 .43357 m
.48634 .43448 L
s
.43316 .4355 m
.43561 .43457 L
s
.44679 .43437 m
.44951 .43526 L
s
.44685 .43435 m
.44956 .43526 L
s
.44678 .43437 m
.44949 .43526 L
s
.44679 .43437 m
.44951 .43526 L
s
.43309 .43549 m
.43553 .43456 L
s
.52696 .43044 m
.52707 .43111 L
s
.44674 .43437 m
.44947 .43525 L
s
.39329 .43697 m
.39355 .43612 L
s
.44665 .43436 m
.44938 .43524 L
s
.43331 .43547 m
.43577 .43456 L
s
.43316 .43548 m
.43562 .43456 L
s
.2729 .43764 m
.27286 .43715 L
s
.39325 .43695 m
.39352 .43611 L
s
.43322 .43546 m
.43569 .43455 L
s
.43332 .43546 m
.4358 .43455 L
s
.44685 .43433 m
.44957 .43522 L
s
.35271 .44048 m
.35269 .43983 L
s
.43333 .43545 m
.4358 .43454 L
s
.39327 .43694 m
.39354 .43609 L
s
.52693 .43041 m
.52704 .43108 L
s
.48582 .43352 m
.48624 .43443 L
s
.62472 .43293 m
.62473 .43339 L
s
.43328 .43544 m
.43575 .43453 L
s
.44678 .43432 m
.4495 .43521 L
s
.43336 .43544 m
.43583 .43453 L
s
.44669 .43432 m
.44942 .43521 L
s
.62478 .43293 m
.62478 .43339 L
s
.43324 .43544 m
.43571 .43452 L
s
.39331 .43692 m
.39357 .43607 L
s
.44674 .43432 m
.44946 .4352 L
s
.44677 .43431 m
.44949 .4352 L
s
.43339 .43543 m
.43588 .43453 L
s
.43335 .43543 m
.43583 .43453 L
s
.44665 .43433 m
.44939 .4352 L
s
.44658 .43432 m
.44931 .43519 L
s
.52703 .43038 m
.52714 .43105 L
s
.43334 .43542 m
.43582 .43452 L
s
.44681 .4343 m
.44954 .43519 L
s
.16398 .44609 m
.16391 .44572 L
s
.3933 .43691 m
.39357 .43606 L
s
.4466 .43432 m
.44934 .43518 L
s
.71537 .42526 m
.71537 .42563 L
s
.43328 .43541 m
.43575 .43451 L
s
.44653 .43432 m
.44928 .43517 L
s
.4467 .43429 m
.44943 .43517 L
s
.43344 .4354 m
.43592 .4345 L
s
.43344 .43539 m
.43592 .4345 L
s
.43344 .43539 m
.43594 .43451 L
s
.44653 .4343 m
.44927 .43516 L
s
.4858 .43347 m
.48623 .43438 L
s
.43331 .43539 m
.43578 .43448 L
s
.52684 .43036 m
.52696 .43103 L
s
.44648 .4343 m
.44922 .43515 L
s
.43338 .43538 m
.43587 .43448 L
s
.35275 .44041 m
.35273 .43976 L
s
.43337 .43538 m
.43587 .43449 L
s
.43352 .43537 m
.43601 .43448 L
s
.43355 .43537 m
.43606 .43449 L
s
.44643 .4343 m
.44919 .43514 L
s
.44636 .43429 m
.44912 .43514 L
s
.4465 .43429 m
.44925 .43514 L
s
.43341 .43536 m
.43589 .43446 L
s
.35281 .44039 m
.35279 .43974 L
s
.43351 .43534 m
.43601 .43446 L
s
.2728 .43752 m
.27275 .43703 L
s
.44653 .43426 m
.44928 .43511 L
s
.44637 .43427 m
.44913 .43511 L
s
.16392 .44602 m
.16386 .44565 L
s
.44634 .43427 m
.4491 .4351 L
s
.44641 .43427 m
.44916 .43511 L
s
.52687 .4303 m
.52699 .43097 L
s
.44625 .43428 m
.44902 .4351 L
s
.35274 .44036 m
.35272 .43971 L
s
.39331 .43682 m
.39359 .43598 L
s
.39334 .43682 m
.39361 .43597 L
s
.43362 .43532 m
.43615 .43446 L
s
.43362 .43532 m
.43613 .43444 L
s
.4464 .43425 m
.44915 .43509 L
s
.44654 .43424 m
.4493 .43509 L
s
.44639 .43425 m
.44915 .43509 L
s
.48579 .4334 m
.48623 .43431 L
s
.43358 .43531 m
.43609 .43444 L
s
.43373 .43531 m
.43627 .43446 L
s
.43368 .4353 m
.43619 .43443 L
s
.43357 .43531 m
.43608 .43443 L
s
.43351 .43531 m
.43602 .43443 L
s
.44636 .43424 m
.44912 .43508 L
s
.43365 .4353 m
.43617 .43443 L
s
.43371 .43529 m
.43624 .43443 L
s
.44627 .43424 m
.44904 .43506 L
s
.4463 .43423 m
.44906 .43506 L
s
.44639 .43422 m
.44915 .43506 L
s
.43364 .43528 m
.43616 .43442 L
s
.44644 .43422 m
.4492 .43506 L
s
.43363 .43528 m
.43616 .43442 L
s
.48572 .43336 m
.48616 .43427 L
s
.84376 .27765 m
.84389 .27789 L
s
.44611 .43424 m
.44889 .43505 L
s
.44611 .43425 m
.4489 .43505 L
s
.52684 .43025 m
.52697 .43093 L
s
.43357 .43527 m
.43609 .4344 L
s
.52686 .43025 m
.52699 .43092 L
s
.44618 .43422 m
.44895 .43504 L
s
.43366 .43526 m
.43618 .43439 L
s
.43363 .43526 m
.43617 .4344 L
s
.43379 .43525 m
.43632 .4344 L
s
.4338 .43525 m
.43635 .43441 L
s
.39343 .43674 m
.3937 .4359 L
s
.39339 .43675 m
.39366 .4359 L
s
.48573 .43333 m
.48617 .43424 L
s
.43361 .43525 m
.43613 .43438 L
s
.48568 .43333 m
.48611 .43424 L
s
.44618 .43421 m
.44896 .43502 L
s
.44624 .4342 m
.44901 .43502 L
s
.44603 .43422 m
.44883 .43501 L
s
.62488 .43274 m
.62488 .4332 L
s
.4338 .43523 m
.43635 .43439 L
s
.48575 .43332 m
.48619 .43423 L
s
.44607 .43421 m
.44886 .43501 L
s
.4461 .4342 m
.44888 .435 L
s
.43389 .43521 m
.43645 .43438 L
s
.43386 .43521 m
.43642 .43437 L
s
.62473 .43272 m
.62474 .43317 L
s
.43376 .4352 m
.43629 .43435 L
s
.48576 .4333 m
.4862 .43421 L
s
.44601 .4342 m
.44881 .43499 L
s
.43372 .43521 m
.43626 .43436 L
s
.44588 .43421 m
.44869 .43498 L
s
.43396 .43519 m
.43653 .43437 L
s
.39336 .4367 m
.39363 .43585 L
s
.43387 .43519 m
.43643 .43436 L
s
.4461 .43418 m
.44889 .43497 L
s
.43385 .43518 m
.43641 .43435 L
s
.39337 .43669 m
.39365 .43584 L
s
.52692 .43015 m
.52704 .43083 L
s
.43391 .43518 m
.43647 .43435 L
s
.44607 .43416 m
.44886 .43496 L
s
.18128 .53689 m
.18113 .53649 L
s
.43396 .43517 m
.43652 .43434 L
s
.44597 .43417 m
.44876 .43496 L
s
.4461 .43416 m
.44889 .43496 L
s
.3934 .43668 m
.39368 .43583 L
s
.44592 .43417 m
.44872 .43496 L
s
.27275 .43736 m
.27271 .43687 L
s
.48577 .43327 m
.48621 .43417 L
s
.44602 .43417 m
.44882 .43495 L
s
.44603 .43416 m
.44883 .43495 L
s
.44583 .43419 m
.44864 .43495 L
s
.44616 .43415 m
.44895 .43495 L
s
.35271 .44021 m
.3527 .43957 L
s
.43404 .43515 m
.4366 .43433 L
s
.43403 .43515 m
.4366 .43433 L
s
.43385 .43516 m
.43641 .43433 L
s
.4339 .43515 m
.43646 .43432 L
s
.43384 .43516 m
.43639 .43432 L
s
.44576 .43417 m
.44857 .43494 L
s
.3934 .43666 m
.39368 .43581 L
s
.48565 .43324 m
.48609 .43415 L
s
.43401 .43514 m
.43659 .43433 L
s
.44591 .43415 m
.44871 .43493 L
s
.43396 .43514 m
.43653 .43432 L
s
.48573 .43324 m
.48617 .43415 L
s
.43404 .43513 m
.43662 .43432 L
s
.43409 .43513 m
.43667 .43433 L
s
.446 .43413 m
.4488 .43492 L
s
.43397 .43513 m
.43655 .43431 L
s
.43393 .43513 m
.43649 .4343 L
s
.44573 .43416 m
.44855 .43491 L
s
.43406 .43512 m
.43664 .43431 L
s
.71537 .42499 m
.71537 .42536 L
s
.44591 .43413 m
.44872 .4349 L
s
.43415 .4351 m
.43674 .43431 L
s
.48564 .43321 m
.48608 .43411 L
s
.44574 .43413 m
.44855 .43488 L
s
.44566 .43413 m
.44848 .43488 L
s
.4458 .43412 m
.44862 .43488 L
s
.4456 .43414 m
.44843 .43488 L
s
.43418 .43508 m
.43679 .43429 L
s
.3527 .44013 m
.35269 .43949 L
s
.44565 .43413 m
.44847 .43487 L
s
.44571 .43412 m
.44853 .43487 L
s
.43419 .43507 m
.43679 .43428 L
s
.43425 .43507 m
.43685 .43429 L
s
.4341 .43507 m
.4367 .43427 L
s
.43434 .43506 m
.43696 .43429 L
s
.43418 .43506 m
.43677 .43426 L
s
.39342 .43658 m
.3937 .43573 L
s
.4458 .4341 m
.44862 .43485 L
s
.5268 .43007 m
.52693 .43074 L
s
.35273 .44011 m
.35272 .43946 L
s
.4457 .4341 m
.44853 .43485 L
s
.43423 .43505 m
.43683 .43426 L
s
.44553 .43411 m
.44837 .43484 L
s
.44573 .4341 m
.44856 .43484 L
s
.43422 .43504 m
.43683 .43426 L
s
.43427 .43504 m
.43687 .43425 L
s
.44557 .4341 m
.4484 .43484 L
s
.43437 .43503 m
.437 .43427 L
s
.43421 .43503 m
.43681 .43424 L
s
.44568 .43409 m
.44851 .43483 L
s
.43425 .43503 m
.43687 .43426 L
s
.43425 .43503 m
.43686 .43425 L
s
.44551 .43409 m
.44835 .43482 L
s
.43415 .43503 m
.43675 .43423 L
s
.44538 .43411 m
.44823 .43482 L
s
.44564 .43408 m
.44847 .43481 L
s
.44573 .43407 m
.44855 .43482 L
s
.44544 .43409 m
.44829 .43481 L
s
.52679 .43003 m
.52692 .4307 L
s
.16391 .44572 m
.16385 .44536 L
s
.44547 .43409 m
.44831 .4348 L
s
.44562 .43407 m
.44845 .43481 L
s
.43431 .435 m
.43692 .43422 L
s
.71537 .42489 m
.71537 .42526 L
s
.4343 .435 m
.43692 .43422 L
s
.43451 .43499 m
.43715 .43424 L
s
.43425 .43499 m
.43685 .4342 L
s
.44529 .43409 m
.44815 .43479 L
s
.84363 .27741 m
.84376 .27765 L
s
.39349 .4365 m
.39377 .43566 L
s
.48561 .4331 m
.48606 .43401 L
s
.43458 .43497 m
.43723 .43423 L
s
.43441 .43497 m
.43703 .4342 L
s
.44545 .43406 m
.4483 .43477 L
s
.43439 .43497 m
.43702 .43421 L
s
.43449 .43496 m
.43713 .43421 L
s
.4344 .43497 m
.43704 .43421 L
s
.44541 .43406 m
.44825 .43477 L
s
.4451 .43409 m
.44797 .43476 L
s
.44545 .43406 m
.44829 .43476 L
s
.44537 .43405 m
.44822 .43476 L
s
.62472 .43248 m
.62472 .43293 L
s
.35269 .44002 m
.35268 .43937 L
s
.62477 .43248 m
.62478 .43293 L
s
.44518 .43406 m
.44804 .43474 L
s
.44527 .43405 m
.44812 .43475 L
s
.27286 .43715 m
.27281 .43666 L
s
.4345 .43494 m
.43714 .43418 L
s
.44526 .43404 m
.44812 .43474 L
s
.43469 .43493 m
.43735 .4342 L
s
.44526 .43405 m
.44811 .43474 L
s
.44532 .43404 m
.44818 .43473 L
s
.4345 .43493 m
.43714 .43418 L
s
.43457 .43492 m
.43721 .43418 L
s
.44525 .43404 m
.4481 .43473 L
s
.43444 .43493 m
.43708 .43418 L
s
.43452 .43493 m
.43717 .43418 L
s
.44535 .43403 m
.44821 .43473 L
s
.43456 .43493 m
.43722 .43419 L
s
.39344 .43645 m
.39373 .4356 L
s
.16386 .44565 m
.1638 .44529 L
s
.43457 .43492 m
.43721 .43417 L
s
.43457 .43492 m
.43721 .43417 L
s
.44519 .43404 m
.44806 .43472 L
s
.43464 .43491 m
.43729 .43417 L
s
.43453 .43491 m
.43717 .43416 L
s
.4453 .43402 m
.44816 .43471 L
s
.39343 .43643 m
.39372 .43558 L
s
.43477 .43489 m
.43744 .43417 L
s
.44534 .434 m
.44819 .4347 L
s
.43447 .4349 m
.43711 .43414 L
s
.44524 .434 m
.4481 .43469 L
s
.44506 .43403 m
.44794 .43469 L
s
.43467 .43488 m
.43733 .43415 L
s
.43462 .43488 m
.43728 .43415 L
s
.48557 .43301 m
.48602 .43391 L
s
.44515 .43401 m
.44802 .43468 L
s
.44496 .43403 m
.44784 .43468 L
s
.44487 .43403 m
.44775 .43467 L
s
.445 .43401 m
.44787 .43467 L
s
.43469 .43486 m
.43736 .43414 L
s
.43479 .43485 m
.43747 .43414 L
s
.43485 .43485 m
.43754 .43414 L
s
.4451 .43399 m
.44797 .43466 L
s
.39345 .43638 m
.39375 .43553 L
s
.4856 .43298 m
.48606 .43388 L
s
.44499 .434 m
.44787 .43465 L
s
.43461 .43485 m
.43727 .43411 L
s
.43478 .43484 m
.43746 .43414 L
s
.43483 .43484 m
.43751 .43413 L
s
.43478 .43484 m
.43745 .43412 L
s
.43494 .43483 m
.43763 .43413 L
s
.35272 .43991 m
.35271 .43927 L
s
.48559 .43296 m
.48604 .43387 L
s
.44498 .43399 m
.44786 .43464 L
s
.43482 .43483 m
.4375 .43412 L
s
.445 .43399 m
.44788 .43464 L
s
.4348 .43482 m
.43748 .43411 L
s
.44494 .43399 m
.44782 .43463 L
s
.43472 .43482 m
.4374 .43411 L
s
.44474 .434 m
.44763 .43463 L
s
.35274 .4399 m
.35273 .43925 L
s
.44497 .43398 m
.44784 .43463 L
s
.445 .43398 m
.44788 .43463 L
s
.39344 .43635 m
.39373 .4355 L
s
.27275 .43703 m
.27271 .43654 L
s
.43492 .43481 m
.43761 .43411 L
s
.4449 .43398 m
.44778 .43463 L
s
.44489 .43398 m
.44777 .43462 L
s
.43488 .43481 m
.43757 .43411 L
s
.435 .4348 m
.4377 .43411 L
s
.43486 .4348 m
.43753 .43409 L
s
.48552 .43293 m
.48598 .43384 L
s
.44466 .43399 m
.44756 .43461 L
s
.43493 .43478 m
.43762 .43409 L
s
.4449 .43395 m
.44779 .4346 L
s
.43492 .43478 m
.43762 .43409 L
s
.43496 .43478 m
.43764 .43408 L
s
.43496 .43478 m
.43766 .4341 L
s
.43481 .43478 m
.43749 .43408 L
s
.39347 .43632 m
.39377 .43547 L
s
.44482 .43396 m
.44771 .43459 L
s
.43504 .43477 m
.43775 .43409 L
s
.44483 .43395 m
.44772 .43459 L
s
.44481 .43396 m
.4477 .43459 L
s
.44457 .43398 m
.44748 .43459 L
s
.44467 .43396 m
.44757 .43458 L
s
.43503 .43476 m
.43775 .43409 L
s
.43513 .43476 m
.43784 .43409 L
s
.44495 .43393 m
.44783 .43458 L
s
.44471 .43395 m
.44761 .43457 L
s
.43518 .43474 m
.43789 .43408 L
s
.43517 .43474 m
.43788 .43408 L
s
.35269 .43983 m
.35268 .43918 L
s
.52682 .42977 m
.52696 .43044 L
s
.62487 .43229 m
.62488 .43274 L
s
.39348 .43628 m
.39378 .43543 L
s
.43522 .43473 m
.43795 .43408 L
s
.44461 .43395 m
.44751 .43455 L
s
.18113 .53649 m
.18099 .5361 L
s
.44469 .43394 m
.44759 .43455 L
s
.44457 .43395 m
.44748 .43454 L
s
.43515 .43472 m
.43787 .43406 L
s
.43521 .43472 m
.43794 .43406 L
s
.43519 .43472 m
.43792 .43406 L
s
.43508 .43472 m
.43779 .43405 L
s
.43533 .43471 m
.43806 .43406 L
s
.44465 .43392 m
.44756 .43453 L
s
.44453 .43394 m
.44743 .43453 L
s
.44459 .43394 m
.4475 .43453 L
s
.62472 .43226 m
.62473 .43272 L
s
.43507 .43471 m
.43778 .43404 L
s
.44445 .43394 m
.44736 .43453 L
s
.43511 .4347 m
.43783 .43403 L
s
.52679 .42974 m
.52693 .43041 L
s
.44453 .43393 m
.44744 .43452 L
s
.43536 .43469 m
.43809 .43405 L
s
.44442 .43394 m
.44734 .43452 L
s
.71537 .42462 m
.71537 .42499 L
s
.44458 .43392 m
.44749 .43452 L
s
.8435 .27717 m
.84363 .27741 L
s
.44437 .43394 m
.44728 .43452 L
s
.43514 .43469 m
.43786 .43403 L
s
.44452 .43392 m
.44743 .43452 L
s
.44439 .43393 m
.44731 .43451 L
s
.52689 .42971 m
.52703 .43038 L
s
.39347 .43623 m
.39378 .43538 L
s
.44431 .43394 m
.44723 .43451 L
s
.43516 .43468 m
.43787 .43402 L
s
.43519 .43468 m
.43791 .43402 L
s
.44449 .43391 m
.4474 .4345 L
s
.48549 .43282 m
.48596 .43372 L
s
.35273 .43976 m
.35272 .43912 L
s
.43522 .43467 m
.43795 .43401 L
s
.44467 .43389 m
.44758 .43449 L
s
.43532 .43466 m
.43806 .43403 L
s
.44432 .43393 m
.44724 .43449 L
s
.4352 .43467 m
.43793 .43401 L
s
.44422 .43393 m
.44714 .43449 L
s
.43539 .43466 m
.43813 .43403 L
s
.39358 .4362 m
.39388 .43536 L
s
.43549 .43465 m
.43823 .43402 L
s
.44455 .43388 m
.44747 .43448 L
s
.4355 .43464 m
.43824 .43402 L
s
.5267 .42969 m
.52684 .43036 L
s
.4354 .43464 m
.43815 .43402 L
s
.43559 .43463 m
.43834 .43402 L
s
.35279 .43974 m
.35278 .43909 L
s
.44436 .4339 m
.44728 .43447 L
s
.44429 .43391 m
.44722 .43447 L
s
.27271 .43687 m
.27267 .43638 L
s
.43548 .43463 m
.43824 .43402 L
s
.43531 .43463 m
.43805 .43399 L
s
.44413 .43391 m
.44705 .43446 L
s
.43557 .43462 m
.43832 .434 L
s
.44432 .43389 m
.44724 .43445 L
s
.44421 .4339 m
.44714 .43445 L
s
.44421 .4339 m
.44714 .43445 L
s
.35272 .43971 m
.35272 .43906 L
s
.44392 .43392 m
.44686 .43445 L
s
.43556 .43461 m
.43833 .43401 L
s
.44407 .43391 m
.447 .43444 L
s
.43543 .43461 m
.43817 .43398 L
s
.4441 .4339 m
.44704 .43444 L
s
.4354 .43461 m
.43815 .43398 L
s
.43543 .4346 m
.43818 .43397 L
s
.43566 .43459 m
.43843 .43399 L
s
.16385 .44536 m
.16379 .44499 L
s
.43561 .43459 m
.43838 .43399 L
s
.39355 .43615 m
.39385 .4353 L
s
.39355 .43614 m
.39386 .4353 L
s
.43549 .43459 m
.43824 .43396 L
s
.52674 .42963 m
.52687 .4303 L
s
.44404 .43388 m
.44697 .43442 L
s
.44426 .43386 m
.44719 .43442 L
s
.43552 .43458 m
.43827 .43396 L
s
.43544 .43459 m
.4382 .43397 L
s
.44418 .43386 m
.44711 .43441 L
s
.71537 .42452 m
.71537 .42489 L
s
.44402 .43389 m
.44696 .43441 L
s
.48549 .43274 m
.48596 .43364 L
s
.43557 .43458 m
.43834 .43397 L
s
.44412 .43387 m
.44705 .43441 L
s
.44415 .43386 m
.44708 .43441 L
s
.44425 .43386 m
.44718 .43441 L
s
.43561 .43457 m
.43837 .43396 L
s
.44422 .43385 m
.44715 .4344 L
s
.39355 .43612 m
.39386 .43527 L
s
.43577 .43456 m
.43854 .43397 L
s
.44416 .43385 m
.44709 .4344 L
s
.4358 .43455 m
.43858 .43398 L
s
.43562 .43456 m
.4384 .43396 L
s
.43553 .43456 m
.43829 .43394 L
s
.4439 .43388 m
.44684 .43439 L
s
.48542 .43271 m
.48589 .43362 L
s
.39352 .43611 m
.39382 .43526 L
s
.43569 .43455 m
.43846 .43396 L
s
.4358 .43454 m
.43858 .43396 L
s
.48549 .4327 m
.48596 .43361 L
s
.43588 .43453 m
.43867 .43397 L
s
.44388 .43387 m
.44683 .43437 L
s
.44384 .43387 m
.44679 .43437 L
s
.39354 .43609 m
.39384 .43525 L
s
.43575 .43453 m
.43854 .43395 L
s
.43583 .43453 m
.43861 .43395 L
s
.44384 .43387 m
.44679 .43437 L
s
.43583 .43453 m
.43862 .43395 L
s
.44379 .43387 m
.44674 .43437 L
s
.44383 .43386 m
.44678 .43437 L
s
.5267 .42958 m
.52684 .43025 L
s
.43571 .43452 m
.4385 .43394 L
s
.52673 .42958 m
.52686 .43025 L
s
.4437 .43387 m
.44665 .43436 L
s
.43582 .43452 m
.4386 .43394 L
s
.44402 .43383 m
.44697 .43435 L
s
.4439 .43384 m
.44685 .43435 L
s
.39357 .43607 m
.39388 .43523 L
s
.48542 .43268 m
.48589 .43358 L
s
.48544 .43268 m
.48591 .43358 L
s
.1638 .44529 m
.16373 .44492 L
s
.43594 .43451 m
.43874 .43395 L
s
.43575 .43451 m
.43853 .43393 L
s
.43592 .4345 m
.43872 .43393 L
s
.39357 .43606 m
.39388 .43522 L
s
.43592 .4345 m
.4387 .43393 L
s
.43606 .43449 m
.43887 .43395 L
s
.48535 .43266 m
.48583 .43357 L
s
.48544 .43266 m
.48592 .43357 L
s
.43601 .43448 m
.43881 .43392 L
s
.43587 .43449 m
.43867 .43393 L
s
.44391 .43382 m
.44685 .43433 L
s
.4437 .43385 m
.44665 .43433 L
s
.44362 .43385 m
.44658 .43432 L
s
.43587 .43448 m
.43866 .43391 L
s
.44364 .43385 m
.4466 .43432 L
s
.44374 .43383 m
.44669 .43432 L
s
.43578 .43448 m
.43856 .4339 L
s
.44357 .43386 m
.44653 .43432 L
s
.44383 .43382 m
.44678 .43432 L
s
.44379 .43382 m
.44674 .43432 L
s
.44382 .43382 m
.44677 .43431 L
s
.43627 .43446 m
.4391 .43394 L
s
.43615 .43446 m
.43896 .43393 L
s
.43601 .43446 m
.43882 .43391 L
s
.43589 .43446 m
.43868 .43389 L
s
.44386 .43381 m
.44681 .4343 L
s
.44357 .43383 m
.44653 .4343 L
s
.62471 .43202 m
.62472 .43248 L
s
.44352 .43383 m
.44648 .4343 L
s
.44374 .43381 m
.4467 .43429 L
s
.3527 .43957 m
.3527 .43892 L
s
.44347 .43384 m
.44643 .4343 L
s
.43613 .43444 m
.43894 .43391 L
s
.62476 .43202 m
.62477 .43248 L
s
.4434 .43384 m
.44636 .43429 L
s
.43609 .43444 m
.4389 .4339 L
s
.43619 .43443 m
.439 .4339 L
s
.48534 .43261 m
.48582 .43352 L
s
.43608 .43443 m
.43889 .4339 L
s
.44354 .43383 m
.4465 .43429 L
s
.52678 .42948 m
.52692 .43015 L
s
.43624 .43443 m
.43906 .43391 L
s
.44328 .43385 m
.44625 .43428 L
s
.43617 .43443 m
.43898 .4339 L
s
.43602 .43443 m
.43883 .43388 L
s
.44337 .43384 m
.44634 .43427 L
s
.4434 .43383 m
.44637 .43427 L
s
.43616 .43442 m
.43898 .43389 L
s
.43616 .43442 m
.43897 .43388 L
s
.44344 .43382 m
.44641 .43427 L
s
.43635 .43441 m
.43918 .4339 L
s
.44356 .4338 m
.44653 .43426 L
s
.39359 .43598 m
.3939 .43513 L
s
.39361 .43597 m
.39392 .43513 L
s
.27281 .43666 m
.27278 .43616 L
s
.84337 .27693 m
.8435 .27717 L
s
.43632 .4344 m
.43915 .43388 L
s
.44343 .43381 m
.4464 .43425 L
s
.43617 .4344 m
.43899 .43388 L
s
.44342 .4338 m
.44639 .43425 L
s
.43609 .4344 m
.4389 .43386 L
s
.43618 .43439 m
.439 .43387 L
s
.44314 .43384 m
.44611 .43425 L
s
.44358 .43379 m
.44654 .43424 L
s
.43635 .43439 m
.43919 .43388 L
s
.44338 .4338 m
.44636 .43424 L
s
.43645 .43438 m
.4393 .43389 L
s
.48532 .43256 m
.4858 .43347 L
s
.44314 .43382 m
.44611 .43424 L
s
.44329 .4338 m
.44627 .43424 L
s
.43653 .43437 m
.43938 .43389 L
s
.43613 .43438 m
.43895 .43384 L
s
.43642 .43437 m
.43925 .43387 L
s
.44333 .43379 m
.4463 .43423 L
s
.44305 .43383 m
.44603 .43422 L
s
.4432 .4338 m
.44618 .43422 L
s
.44347 .43377 m
.44644 .43422 L
s
.35269 .43949 m
.35269 .43884 L
s
.44342 .43377 m
.44639 .43422 L
s
.43643 .43436 m
.43927 .43387 L
s
.4432 .4338 m
.44618 .43421 L
s
.43641 .43435 m
.43925 .43386 L
s
.43626 .43436 m
.4391 .43384 L
s
.43647 .43435 m
.43931 .43385 L
s
.44289 .43383 m
.44588 .43421 L
s
.44309 .4338 m
.44607 .43421 L
s
.43629 .43435 m
.43911 .43383 L
s
.44326 .43378 m
.44624 .4342 L
s
.43652 .43434 m
.43935 .43385 L
s
.44312 .43379 m
.4461 .4342 L
s
.4366 .43433 m
.43945 .43385 L
s
.35272 .43946 m
.35273 .43881 L
s
.4366 .43433 m
.43945 .43385 L
s
.44303 .4338 m
.44601 .4342 L
s
.43667 .43433 m
.43953 .43386 L
s
.43659 .43433 m
.43944 .43386 L
s
.43641 .43433 m
.43926 .43384 L
s
.44284 .43382 m
.44583 .43419 L
s
.43662 .43432 m
.43947 .43385 L
s
.3937 .4359 m
.39402 .43505 L
s
.39366 .4359 m
.39398 .43505 L
s
.43646 .43432 m
.4393 .43383 L
s
.43653 .43432 m
.43937 .43384 L
s
.43639 .43432 m
.43923 .43383 L
s
.43674 .43431 m
.43961 .43386 L
s
.43664 .43431 m
.43951 .43385 L
s
.44312 .43378 m
.4461 .43418 L
s
.52666 .4294 m
.5268 .43007 L
s
.43655 .43431 m
.4394 .43383 L
s
.44294 .43378 m
.44592 .43417 L
s
.44277 .4338 m
.44576 .43417 L
s
.44299 .43377 m
.44597 .43417 L
s
.44309 .43376 m
.44607 .43416 L
s
.48531 .43249 m
.48579 .4334 L
s
.44304 .43377 m
.44602 .43417 L
s
.44312 .43377 m
.4461 .43416 L
s
.44305 .43377 m
.44603 .43416 L
s
.43649 .4343 m
.43933 .43381 L
s
.43679 .43429 m
.43965 .43385 L
s
.43696 .43429 m
.43984 .43386 L
s
.43685 .43429 m
.43973 .43385 L
s
.44274 .4338 m
.44573 .43416 L
s
.44292 .43377 m
.44591 .43415 L
s
.43679 .43428 m
.43965 .43384 L
s
.44318 .43373 m
.44616 .43415 L
s
.437 .43427 m
.43988 .43385 L
s
.71537 .42424 m
.71537 .42462 L
s
.4367 .43427 m
.43956 .43382 L
s
.27271 .43654 m
.27267 .43605 L
s
.39363 .43585 m
.39395 .43501 L
s
.18099 .5361 m
.18085 .5357 L
s
.44261 .4338 m
.4456 .43414 L
s
.44266 .43379 m
.44566 .43413 L
s
.43677 .43426 m
.43963 .43381 L
s
.52664 .42936 m
.52679 .43003 L
s
.44302 .43374 m
.446 .43413 L
s
.48524 .43246 m
.48572 .43336 L
s
.43683 .43426 m
.4397 .43381 L
s
.43683 .43426 m
.4397 .43382 L
s
.39365 .43584 m
.39397 .435 L
s
.44292 .43375 m
.44591 .43413 L
s
.43687 .43426 m
.43975 .43383 L
s
.44275 .43377 m
.44574 .43413 L
s
.44266 .43378 m
.44565 .43413 L
s
.43687 .43425 m
.43973 .43381 L
s
.44271 .43377 m
.44571 .43412 L
s
.43715 .43424 m
.44004 .43384 L
s
.39368 .43583 m
.394 .43499 L
s
.44281 .43375 m
.4458 .43412 L
s
.43686 .43425 m
.43974 .43381 L
s
.44253 .43379 m
.44553 .43411 L
s
.43681 .43424 m
.43968 .4338 L
s
.62486 .43183 m
.62487 .43229 L
s
.43723 .43423 m
.44012 .43384 L
s
.44238 .4338 m
.44538 .43411 L
s
.48524 .43243 m
.48573 .43333 L
s
.44271 .43376 m
.4457 .4341 L
s
.43675 .43423 m
.43962 .43379 L
s
.48518 .43243 m
.48568 .43333 L
s
.35268 .43937 m
.35269 .43872 L
s
.39368 .43581 m
.39401 .43497 L
s
.4428 .43374 m
.4458 .4341 L
s
.44257 .43376 m
.44557 .4341 L
s
.43692 .43422 m
.4398 .43379 L
s
.44274 .43375 m
.44573 .4341 L
s
.43692 .43422 m
.4398 .43379 L
s
.44251 .43377 m
.44551 .43409 L
s
.48526 .43242 m
.48575 .43332 L
s
.43713 .43421 m
.44002 .43381 L
s
.44244 .43377 m
.44544 .43409 L
s
.43735 .4342 m
.44026 .43383 L
s
.43704 .43421 m
.43992 .4338 L
s
.44247 .43377 m
.44547 .43409 L
s
.62471 .4318 m
.62472 .43226 L
s
.44209 .43381 m
.4451 .43409 L
s
.43702 .43421 m
.4399 .4338 L
s
.44229 .43379 m
.44529 .43409 L
s
.44268 .43374 m
.44568 .43409 L
s
.43703 .4342 m
.43991 .43378 L
s
.44264 .43374 m
.44564 .43408 L
s
.43685 .4342 m
.43973 .43377 L
s
.43722 .43419 m
.44012 .43381 L
s
.48527 .4324 m
.48576 .4333 L
s
.44273 .43371 m
.44573 .43407 L
s
.44245 .43376 m
.44545 .43406 L
s
.44262 .43372 m
.44562 .43407 L
s
.43721 .43418 m
.44011 .43379 L
s
.43717 .43418 m
.44007 .4338 L
s
.43714 .43418 m
.44003 .43378 L
s
.44217 .43378 m
.44518 .43406 L
s
.43744 .43417 m
.44035 .43381 L
s
.43714 .43418 m
.44003 .43378 L
s
.43708 .43418 m
.43997 .43378 L
s
.16379 .44499 m
.16372 .44463 L
s
.44244 .43375 m
.44545 .43406 L
s
.43729 .43417 m
.44019 .43379 L
s
.4424 .43374 m
.44541 .43406 L
s
.43721 .43417 m
.4401 .43378 L
s
.43721 .43417 m
.4401 .43377 L
s
.44237 .43375 m
.44537 .43405 L
s
.44226 .43376 m
.44527 .43405 L
s
.44225 .43376 m
.44526 .43405 L
s
.43717 .43416 m
.44007 .43377 L
s
.44231 .43375 m
.44532 .43404 L
s
.44218 .43376 m
.44519 .43404 L
s
.44226 .43374 m
.44526 .43404 L
s
.44224 .43375 m
.44525 .43404 L
s
.48528 .43237 m
.48577 .43327 L
s
.71537 .42414 m
.71537 .42452 L
s
.44235 .43374 m
.44535 .43403 L
s
.43728 .43415 m
.44019 .43378 L
s
.43754 .43414 m
.44045 .4338 L
s
.43733 .43415 m
.44024 .43377 L
s
.43747 .43414 m
.44038 .43379 L
s
.44186 .43379 m
.44487 .43403 L
s
.44195 .43378 m
.44496 .43403 L
s
.43763 .43413 m
.44055 .4338 L
s
.43736 .43414 m
.44027 .43377 L
s
.43746 .43414 m
.44038 .43379 L
s
.43711 .43414 m
.44001 .43375 L
s
.44205 .43376 m
.44506 .43403 L
s
.3937 .43573 m
.39403 .43489 L
s
.43751 .43413 m
.44042 .43378 L
s
.4423 .43372 m
.4453 .43402 L
s
.48515 .43234 m
.48565 .43324 L
s
.44214 .43375 m
.44515 .43401 L
s
.48524 .43234 m
.48573 .43324 L
s
.43745 .43412 m
.44037 .43377 L
s
.4375 .43412 m
.44041 .43377 L
s
.44199 .43374 m
.445 .43401 L
s
.4377 .43411 m
.44063 .43378 L
s
.44233 .43371 m
.44534 .434 L
s
.35271 .43927 m
.35272 .43862 L
s
.43761 .43411 m
.44052 .43377 L
s
.43748 .43411 m
.4404 .43376 L
s
.43757 .43411 m
.4405 .43378 L
s
.44223 .43371 m
.44524 .434 L
s
.44172 .43378 m
.44474 .434 L
s
.44197 .43374 m
.44499 .434 L
s
.84324 .27669 m
.84337 .27693 L
s
.43727 .43411 m
.44017 .43373 L
s
.4374 .43411 m
.44031 .43375 L
s
.44199 .43375 m
.445 .43399 L
s
.43766 .4341 m
.4406 .43377 L
s
.44197 .43374 m
.44498 .43399 L
s
.44165 .43378 m
.44466 .43399 L
s
.43784 .43409 m
.44078 .43378 L
s
.43775 .43409 m
.44068 .43377 L
s
.35273 .43925 m
.35274 .43861 L
s
.43762 .43409 m
.44054 .43376 L
s
.44193 .43375 m
.44494 .43399 L
s
.43775 .43409 m
.44068 .43378 L
s
.44209 .43371 m
.4451 .43399 L
s
.43795 .43408 m
.4409 .43381 L
s
.27267 .43638 m
.27263 .43589 L
s
.16373 .44492 m
.16367 .44456 L
s
.43762 .43409 m
.44054 .43375 L
s
.44188 .43374 m
.4449 .43398 L
s
.43753 .43409 m
.44045 .43373 L
s
.44156 .43378 m
.44457 .43398 L
s
.44195 .43373 m
.44497 .43398 L
s
.43789 .43408 m
.44082 .43378 L
s
.44188 .43374 m
.44489 .43398 L
s
.48514 .43231 m
.48564 .43321 L
s
.43788 .43408 m
.44082 .43378 L
s
.43764 .43408 m
.44056 .43374 L
s
.44199 .43372 m
.445 .43398 L
s
.43749 .43408 m
.44041 .43373 L
s
.43806 .43406 m
.441 .43378 L
s
.44179 .43374 m
.44481 .43396 L
s
.43794 .43406 m
.44088 .43377 L
s
.4418 .43373 m
.44482 .43396 L
s
.43809 .43405 m
.44104 .43378 L
s
.43787 .43406 m
.44081 .43376 L
s
.43792 .43406 m
.44086 .43376 L
s
.44165 .43374 m
.44467 .43396 L
s
.44169 .43374 m
.44471 .43395 L
s
.39377 .43566 m
.3941 .43481 L
s
.44181 .43372 m
.44483 .43395 L
s
.44189 .43371 m
.4449 .43395 L
s
.43779 .43405 m
.44072 .43374 L
s
.44159 .43375 m
.44461 .43395 L
s
.44155 .43375 m
.44457 .43395 L
s
.4414 .43377 m
.44442 .43394 L
s
.43778 .43404 m
.44072 .43372 L
s
.44135 .43377 m
.44437 .43394 L
s
.44168 .43373 m
.44469 .43394 L
s
.44158 .43374 m
.44459 .43394 L
s
.44151 .43374 m
.44453 .43394 L
s
.43783 .43403 m
.44077 .43373 L
s
.44129 .43377 m
.44431 .43394 L
s
.44143 .43375 m
.44445 .43394 L
s
.43813 .43403 m
.44108 .43376 L
s
.44151 .43375 m
.44453 .43393 L
s
.43834 .43402 m
.4413 .43378 L
s
.43806 .43403 m
.44101 .43376 L
s
.43823 .43402 m
.44119 .43376 L
s
.44193 .43368 m
.44495 .43393 L
s
.4413 .43378 m
.44432 .43393 L
s
.43786 .43403 m
.4408 .43372 L
s
.43824 .43402 m
.44119 .43376 L
s
.43824 .43402 m
.4412 .43377 L
s
.43815 .43402 m
.44111 .43377 L
s
.4412 .43377 m
.44422 .43393 L
s
.44164 .43372 m
.44465 .43392 L
s
.44137 .43374 m
.44439 .43393 L
s
.35268 .43918 m
.35269 .43854 L
s
.44157 .43373 m
.44458 .43392 L
s
.43787 .43402 m
.44081 .43372 L
s
.43791 .43402 m
.44084 .43371 L
s
.43833 .43401 m
.44129 .43377 L
s
.4409 .43381 m
.44392 .43392 L
s
.43793 .43401 m
.44088 .43373 L
s
.43832 .434 m
.44127 .43376 L
s
.44151 .43372 m
.44452 .43392 L
s
.43795 .43401 m
.44089 .43372 L
s
.44147 .43372 m
.44449 .43391 L
s
.43843 .43399 m
.4414 .43377 L
s
.44127 .43376 m
.44429 .43391 L
s
.44104 .43378 m
.44407 .43391 L
s
.43838 .43399 m
.44135 .43377 L
s
.44111 .43377 m
.44413 .43391 L
s
.44119 .43376 m
.44421 .4339 L
s
.39373 .4356 m
.39406 .43476 L
s
.44119 .43376 m
.44421 .4339 L
s
.44134 .43373 m
.44436 .4339 L
s
.43858 .43398 m
.44156 .43378 L
s
.44108 .43376 m
.4441 .4339 L
s
.52668 .4291 m
.52682 .42977 L
s
.43805 .43399 m
.441 .43371 L
s
.43817 .43398 m
.44113 .43372 L
s
.43815 .43398 m
.4411 .43373 L
s
.441 .43378 m
.44402 .43389 L
s
.44165 .43369 m
.44467 .43389 L
s
.43867 .43397 m
.44165 .43378 L
s
.4413 .43373 m
.44432 .43389 L
s
.43854 .43397 m
.44151 .43375 L
s
.43818 .43397 m
.44113 .43371 L
s
.43834 .43397 m
.4413 .43373 L
s
.44101 .43376 m
.44404 .43388 L
s
.44153 .43369 m
.44455 .43388 L
s
.43858 .43396 m
.44155 .43375 L
s
.39372 .43558 m
.39406 .43474 L
s
.43837 .43396 m
.44134 .43373 L
s
.4384 .43396 m
.44137 .43374 L
s
.43846 .43396 m
.44143 .43375 L
s
.43824 .43396 m
.4412 .43371 L
s
.43887 .43395 m
.44186 .43379 L
s
.43827 .43396 m
.44123 .43371 L
s
.4382 .43397 m
.44116 .43371 L
s
.43874 .43395 m
.44172 .43378 L
s
.48511 .4322 m
.48561 .4331 L
s
.44088 .43377 m
.4439 .43388 L
s
.4391 .43394 m
.44209 .43381 L
s
.43862 .43395 m
.44159 .43375 L
s
.43861 .43395 m
.44158 .43374 L
s
.43854 .43395 m
.44151 .43374 L
s
.44078 .43378 m
.44379 .43387 L
s
.44082 .43378 m
.44384 .43387 L
s
.44082 .43378 m
.44384 .43387 L
s
.44113 .43372 m
.44415 .43386 L
s
.44086 .43376 m
.44388 .43387 L
s
.4411 .43373 m
.44412 .43387 L
s
.44068 .43378 m
.4437 .43387 L
s
.62469 .43157 m
.62471 .43202 L
s
.44116 .43371 m
.44418 .43386 L
s
.43829 .43394 m
.44124 .4337 L
s
.44123 .43371 m
.44425 .43386 L
s
.44081 .43376 m
.44383 .43386 L
s
.43872 .43393 m
.44169 .43374 L
s
.35272 .43912 m
.35273 .43847 L
s
.44124 .4337 m
.44426 .43386 L
s
.52664 .42907 m
.52679 .42974 L
s
.4386 .43394 m
.44157 .43373 L
s
.43896 .43393 m
.44195 .43378 L
s
.4385 .43394 m
.44147 .43372 L
s
.62475 .43157 m
.62476 .43202 L
s
.4412 .43371 m
.44422 .43385 L
s
.44113 .43371 m
.44416 .43385 L
s
.44055 .4338 m
.44357 .43386 L
s
.43881 .43392 m
.44179 .43374 L
s
.4387 .43393 m
.44168 .43373 L
s
.43853 .43393 m
.44151 .43372 L
s
.43867 .43393 m
.44165 .43374 L
s
.44026 .43383 m
.44328 .43385 L
s
.44063 .43378 m
.44364 .43385 L
s
.4406 .43377 m
.44362 .43385 L
s
.52675 .42904 m
.52689 .42971 L
s
.44068 .43377 m
.4437 .43385 L
s
.44045 .4338 m
.44347 .43384 L
s
.43906 .43391 m
.44205 .43376 L
s
.44088 .43373 m
.4439 .43384 L
s
.43918 .4339 m
.44217 .43378 L
s
.39375 .43553 m
.39408 .43469 L
s
.44035 .43381 m
.44337 .43384 L
s
.43894 .43391 m
.44193 .43375 L
s
.43882 .43391 m
.4418 .43373 L
s
.43866 .43391 m
.44164 .43372 L
s
.35278 .43909 m
.35279 .43844 L
s
.44038 .43379 m
.4434 .43384 L
s
.439 .4339 m
.44199 .43375 L
s
.43938 .43389 m
.44238 .4338 L
s
.44012 .43384 m
.44314 .43384 L
s
.441 .43371 m
.44402 .43383 L
s
.4405 .43378 m
.44352 .43383 L
s
.4393 .43389 m
.44229 .43379 L
s
.4389 .4339 m
.44188 .43374 L
s
.44072 .43374 m
.44374 .43383 L
s
.44054 .43376 m
.44357 .43383 L
s
.43898 .4339 m
.44197 .43374 L
s
.43889 .4339 m
.44188 .43374 L
s
.44038 .43379 m
.4434 .43383 L
s
.44004 .43384 m
.44305 .43383 L
s
.43898 .43389 m
.44197 .43374 L
s
.44052 .43377 m
.44354 .43383 L
s
.43856 .4339 m
.44153 .43369 L
s
.44089 .43372 m
.44391 .43382 L
s
.44077 .43373 m
.44379 .43382 L
s
.43919 .43388 m
.44218 .43376 L
s
.43988 .43385 m
.44289 .43383 L
s
.43915 .43388 m
.44214 .43375 L
s
.44081 .43372 m
.44383 .43382 L
s
.44042 .43378 m
.44344 .43382 L
s
.4408 .43372 m
.44382 .43382 L
s
.43897 .43388 m
.44195 .43373 L
s
.44012 .43381 m
.44314 .43382 L
s
.35272 .43906 m
.35274 .43842 L
s
.43899 .43388 m
.44199 .43374 L
s
.43883 .43388 m
.44181 .43372 L
s
.43868 .43389 m
.44165 .43369 L
s
.43984 .43386 m
.44284 .43382 L
s
.43925 .43387 m
.44225 .43376 L
s
.39373 .4355 m
.39407 .43466 L
s
.52655 .42902 m
.5267 .42969 L
s
.44072 .43372 m
.44374 .43381 L
s
.43953 .43386 m
.44253 .43379 L
s
.44084 .43371 m
.44386 .43381 L
s
.44041 .43377 m
.44343 .43381 L
s
.43927 .43387 m
.44226 .43376 L
s
.43961 .43386 m
.44261 .4338 L
s
.439 .43387 m
.44199 .43372 L
s
.44054 .43375 m
.44356 .4338 L
s
.4404 .43376 m
.44342 .4338 L
s
.44037 .43377 m
.44338 .4338 L
s
.43944 .43386 m
.44244 .43377 L
s
.44027 .43377 m
.44329 .4338 L
s
.43925 .43386 m
.44224 .43375 L
s
.43945 .43385 m
.44245 .43376 L
s
.43973 .43385 m
.44274 .4338 L
s
.44002 .43381 m
.44303 .4338 L
s
.4389 .43386 m
.44189 .43371 L
s
.43947 .43385 m
.44247 .43377 L
s
.43931 .43385 m
.44231 .43375 L
s
.44019 .43379 m
.4432 .4338 L
s
.43945 .43385 m
.44244 .43375 L
s
.44019 .43378 m
.4432 .4338 L
s
.44007 .4338 m
.44309 .4338 L
s
.43965 .43385 m
.44266 .43379 L
s
.43935 .43385 m
.44235 .43374 L
s
.43951 .43385 m
.44251 .43377 L
s
.43975 .43383 m
.44277 .4338 L
s
.44056 .43374 m
.44358 .43379 L
s
.44011 .43379 m
.44312 .43379 L
s
.48506 .43211 m
.48557 .43301 L
s
.27278 .43616 m
.27274 .43567 L
s
.44031 .43375 m
.44333 .43379 L
s
.43965 .43384 m
.44266 .43378 L
s
.43926 .43384 m
.44226 .43374 L
s
.43937 .43384 m
.44237 .43375 L
s
.44024 .43377 m
.44326 .43378 L
s
.4391 .43384 m
.44209 .43371 L
s
.39377 .43547 m
.39411 .43463 L
s
.43992 .4338 m
.44294 .43378 L
s
.4394 .43383 m
.4424 .43374 L
s
.43895 .43384 m
.44193 .43368 L
s
.44045 .43373 m
.44347 .43377 L
s
.4393 .43383 m
.4423 .43372 L
s
.71537 .42387 m
.71537 .42424 L
s
.4401 .43378 m
.44312 .43378 L
s
.44041 .43373 m
.44342 .43377 L
s
.43956 .43382 m
.44257 .43376 L
s
.4397 .43382 m
.44271 .43377 L
s
.44003 .43378 m
.44304 .43377 L
s
.43911 .43383 m
.4421 .43369 L
s
.43997 .43378 m
.44299 .43377 L
s
.4399 .4338 m
.44292 .43377 L
s
.43923 .43383 m
.44223 .43371 L
s
.44003 .43378 m
.44305 .43377 L
s
.4397 .43381 m
.44271 .43376 L
s
.4401 .43377 m
.44312 .43377 L
s
.43974 .43381 m
.44275 .43377 L
s
.48509 .43208 m
.4856 .43298 L
s
.44007 .43377 m
.44309 .43376 L
s
.43963 .43381 m
.44264 .43374 L
s
.52658 .42896 m
.52674 .42963 L
s
.43973 .43381 m
.44274 .43375 L
s
.43933 .43381 m
.44233 .43371 L
s
.43991 .43378 m
.44292 .43375 L
s
.48508 .43207 m
.48559 .43296 L
s
.4398 .43379 m
.44281 .43375 L
s
.43968 .4338 m
.44268 .43374 L
s
.84311 .27645 m
.84324 .27669 L
s
.39378 .43543 m
.39412 .43459 L
s
.18085 .5357 m
.18071 .5353 L
s
.4398 .43379 m
.4428 .43374 L
s
.43962 .43379 m
.44262 .43372 L
s
.44001 .43375 m
.44302 .43374 L
s
.44017 .43373 m
.44318 .43373 L
s
.43973 .43377 m
.44273 .43371 L
s
.485 .43203 m
.48552 .43293 L
s
.52655 .42891 m
.5267 .42958 L
s
.52657 .42891 m
.52673 .42958 L
s
.16372 .44463 m
.16366 .44426 L
s
.39378 .43538 m
.39412 .43454 L
s
.62484 .43138 m
.62486 .43183 L
s
.27267 .43605 m
.27264 .43556 L
s
.39388 .43536 m
.39422 .43451 L
s
.71537 .42377 m
.71537 .42414 L
s
.3527 .43892 m
.35271 .43827 L
s
.62469 .43135 m
.62471 .4318 L
s
.52663 .42881 m
.52678 .42948 L
s
.16367 .44456 m
.16361 .44419 L
s
.39385 .4353 m
.3942 .43446 L
s
.39386 .4353 m
.3942 .43446 L
s
.48497 .43192 m
.48549 .43282 L
s
.35269 .43884 m
.35271 .43819 L
s
.39386 .43527 m
.39421 .43443 L
s
.39382 .43526 m
.39417 .43442 L
s
.35273 .43881 m
.35275 .43817 L
s
.39384 .43525 m
.3942 .43441 L
s
.39388 .43523 m
.39423 .43439 L
s
.39388 .43522 m
.39424 .43438 L
s
.48497 .43185 m
.48549 .43274 L
s
.5265 .42873 m
.52666 .4294 L
s
.27263 .43589 m
.2726 .4354 L
s
.4849 .43182 m
.48542 .43271 L
s
.48497 .43181 m
.48549 .4327 L
s
.84298 .27622 m
.84311 .27645 L
s
.52649 .42869 m
.52664 .42936 L
s
.35269 .43872 m
.3527 .43807 L
s
.48489 .43178 m
.48542 .43268 L
s
.48492 .43178 m
.48544 .43268 L
s
.3939 .43513 m
.39426 .43429 L
s
.48482 .43177 m
.48535 .43266 L
s
.39392 .43513 m
.39428 .43429 L
s
.48492 .43177 m
.48544 .43266 L
s
.62467 .43111 m
.62469 .43157 L
s
.62473 .43111 m
.62475 .43157 L
s
.71537 .4235 m
.71537 .42387 L
s
.48481 .43172 m
.48534 .43261 L
s
.39402 .43505 m
.39438 .43421 L
s
.39398 .43505 m
.39434 .43421 L
s
.35272 .43862 m
.35274 .43797 L
s
.35274 .43861 m
.35276 .43796 L
s
.48479 .43167 m
.48532 .43256 L
s
.18071 .5353 m
.18057 .5349 L
s
.39395 .43501 m
.39432 .43417 L
s
.16366 .44426 m
.16361 .4439 L
s
.39397 .435 m
.39433 .43416 L
s
.394 .43499 m
.39436 .43415 L
s
.27274 .43567 m
.27271 .43518 L
s
.39401 .43497 m
.39437 .43413 L
s
.35269 .43854 m
.35271 .43789 L
s
.71536 .42339 m
.71537 .42377 L
s
.48477 .4316 m
.48531 .43249 L
s
.16361 .44419 m
.16355 .44383 L
s
.4847 .43157 m
.48524 .43246 L
s
.52651 .42843 m
.52668 .4291 L
s
.62482 .43092 m
.62484 .43138 L
s
.84285 .27598 m
.84298 .27622 L
s
.35273 .43847 m
.35276 .43782 L
s
.4847 .43154 m
.48524 .43243 L
s
.48464 .43154 m
.48518 .43243 L
s
.39403 .43489 m
.3944 .43405 L
s
.48472 .43153 m
.48526 .43242 L
s
.62467 .43089 m
.62469 .43135 L
s
.35279 .43844 m
.35281 .43779 L
s
.52648 .4284 m
.52664 .42907 L
s
.27264 .43556 m
.27261 .43507 L
s
.48473 .43151 m
.48527 .4324 L
s
.52659 .42837 m
.52675 .42904 L
s
.35274 .43842 m
.35276 .43777 L
s
.48474 .43148 m
.48528 .43237 L
s
.3941 .43481 m
.39448 .43398 L
s
.52639 .42835 m
.52655 .42902 L
s
.48461 .43145 m
.48515 .43234 L
s
.48469 .43145 m
.48524 .43234 L
s
.52642 .42829 m
.52658 .42896 L
s
.39406 .43476 m
.39444 .43392 L
s
.48459 .43142 m
.48514 .43231 L
s
.39406 .43474 m
.39443 .4339 L
s
.52638 .42825 m
.52655 .42891 L
s
.2726 .4354 m
.27257 .43491 L
s
.52641 .42825 m
.52657 .42891 L
s
.35271 .43827 m
.35274 .43762 L
s
.39408 .43469 m
.39447 .43386 L
s
.71536 .42312 m
.71537 .4235 L
s
.39407 .43466 m
.39445 .43383 L
s
.48455 .43131 m
.48511 .4322 L
s
.62465 .43066 m
.62467 .43111 L
s
.62471 .43065 m
.62473 .43111 L
s
.84272 .27574 m
.84285 .27598 L
s
.39411 .43463 m
.3945 .43379 L
s
.52646 .42815 m
.52663 .42881 L
s
.16361 .4439 m
.16355 .44353 L
s
.35271 .43819 m
.35274 .43754 L
s
.35275 .43817 m
.35278 .43752 L
s
.18057 .5349 m
.18043 .5345 L
s
.39412 .43459 m
.39451 .43376 L
s
.71536 .42302 m
.71536 .42339 L
s
.4845 .43122 m
.48506 .43211 L
s
.16355 .44383 m
.1635 .44346 L
s
.39412 .43454 m
.39451 .43371 L
s
.48454 .43119 m
.48509 .43208 L
s
.48452 .43118 m
.48508 .43207 L
s
.39422 .43451 m
.39461 .43368 L
s
.52633 .42807 m
.5265 .42873 L
s
.3527 .43807 m
.35273 .43743 L
s
.27271 .43518 m
.27268 .43469 L
s
.48444 .43115 m
.485 .43203 L
s
.52631 .42803 m
.52649 .42869 L
s
.3942 .43446 m
.39459 .43362 L
s
.3942 .43446 m
.39459 .43362 L
s
.6248 .43046 m
.62482 .43092 L
s
.39421 .43443 m
.3946 .4336 L
s
.62465 .43044 m
.62467 .43089 L
s
.39417 .43442 m
.39457 .43359 L
s
.3942 .43441 m
.39459 .43357 L
s
.35274 .43797 m
.35278 .43732 L
s
.39423 .43439 m
.39463 .43356 L
s
.35276 .43796 m
.35279 .43731 L
s
.39424 .43438 m
.39464 .43354 L
s
.27261 .43507 m
.27258 .43457 L
s
.4844 .43104 m
.48497 .43192 L
s
.84259 .2755 m
.84272 .27574 L
s
.35271 .43789 m
.35275 .43724 L
s
.71535 .42275 m
.71536 .42312 L
s
.39426 .43429 m
.39466 .43346 L
s
.39428 .43429 m
.39468 .43346 L
s
.4844 .43096 m
.48497 .43185 L
s
.48433 .43093 m
.4849 .43182 L
s
.4844 .43093 m
.48497 .43181 L
s
.35276 .43782 m
.35279 .43717 L
s
.16355 .44353 m
.16349 .44317 L
s
.48434 .4309 m
.48492 .43178 L
s
.48432 .4309 m
.48489 .43178 L
s
.52634 .42777 m
.52651 .42843 L
s
.35281 .43779 m
.35285 .43715 L
s
.39438 .43421 m
.39479 .43338 L
s
.39434 .43421 m
.39475 .43338 L
s
.48424 .43089 m
.48482 .43177 L
s
.48434 .43089 m
.48492 .43177 L
s
.27257 .43491 m
.27255 .43442 L
s
.35276 .43777 m
.3528 .43712 L
s
.71535 .42265 m
.71536 .42302 L
s
.62463 .4302 m
.62465 .43066 L
s
.5263 .42773 m
.52648 .4284 L
s
.62468 .4302 m
.62471 .43065 L
s
.18043 .5345 m
.1803 .5341 L
s
.39432 .43417 m
.39472 .43334 L
s
.52641 .4277 m
.52659 .42837 L
s
.39433 .43416 m
.39474 .43333 L
s
.1635 .44346 m
.16344 .4431 L
s
.48423 .43084 m
.48481 .43172 L
s
.39436 .43415 m
.39477 .43331 L
s
.39437 .43413 m
.39478 .4333 L
s
.52621 .42768 m
.52639 .42835 L
s
.4842 .43079 m
.48479 .43167 L
s
.84246 .27526 m
.84259 .2755 L
s
.52624 .42762 m
.52642 .42829 L
s
.3944 .43405 m
.39481 .43322 L
s
.35274 .43762 m
.35278 .43697 L
s
.48419 .43072 m
.48477 .4316 L
s
.5262 .42758 m
.52638 .42825 L
s
.52622 .42758 m
.52641 .42825 L
s
.48412 .43069 m
.4847 .43157 L
s
.27268 .43469 m
.27266 .4342 L
s
.62478 .43001 m
.6248 .43046 L
s
.39448 .43398 m
.3949 .43314 L
s
.48411 .43066 m
.4847 .43154 L
s
.48405 .43066 m
.48464 .43154 L
s
.48413 .43065 m
.48472 .43153 L
s
.35274 .43754 m
.35278 .43689 L
s
.62463 .42998 m
.62465 .43044 L
s
.48414 .43063 m
.48473 .43151 L
s
.35278 .43752 m
.35282 .43687 L
s
.52628 .42748 m
.52646 .42815 L
s
.39444 .43392 m
.39486 .43309 L
s
.48415 .4306 m
.48474 .43148 L
s
.71535 .42237 m
.71535 .42275 L
s
.39443 .4339 m
.39485 .43307 L
s
.48401 .43057 m
.48461 .43145 L
s
.4841 .43057 m
.48469 .43145 L
s
.27258 .43457 m
.27256 .43408 L
s
.39447 .43386 m
.39489 .43303 L
s
.16349 .44317 m
.16344 .4428 L
s
.48399 .43054 m
.48459 .43142 L
s
.35273 .43743 m
.35278 .43678 L
s
.39445 .43383 m
.39488 .433 L
s
.84232 .27502 m
.84246 .27526 L
s
.52614 .4274 m
.52633 .42807 L
s
.71534 .42227 m
.71535 .42265 L
s
.3945 .43379 m
.39493 .43296 L
s
.52613 .42736 m
.52631 .42803 L
s
.16344 .4431 m
.16339 .44273 L
s
.39451 .43376 m
.39494 .43293 L
s
.1803 .5341 m
.18016 .5337 L
s
.35278 .43732 m
.35282 .43668 L
s
.48395 .43043 m
.48455 .43131 L
s
.6246 .42975 m
.62463 .4302 L
s
.35279 .43731 m
.35284 .43666 L
s
.62466 .42974 m
.62468 .4302 L
s
.27255 .43442 m
.27253 .43393 L
s
.39451 .43371 m
.39495 .43288 L
s
.39461 .43368 m
.39505 .43285 L
s
.35275 .43724 m
.3528 .43659 L
s
.4839 .43035 m
.4845 .43122 L
s
.39459 .43362 m
.39503 .4328 L
s
.39459 .43362 m
.39503 .43279 L
s
.48393 .43032 m
.48454 .43119 L
s
.48391 .4303 m
.48452 .43118 L
s
.3946 .4336 m
.39504 .43277 L
s
.39457 .43359 m
.39501 .43276 L
s
.35279 .43717 m
.35284 .43652 L
s
.39459 .43357 m
.39503 .43274 L
s
.48383 .43027 m
.48444 .43115 L
s
.35285 .43715 m
.3529 .4365 L
s
.39463 .43356 m
.39507 .43273 L
s
.84219 .27478 m
.84232 .27502 L
s
.39464 .43354 m
.39508 .43272 L
s
.3528 .43712 m
.35286 .43647 L
s
.52615 .4271 m
.52634 .42777 L
s
.62475 .42955 m
.62478 .43001 L
s
.71534 .422 m
.71535 .42237 L
s
.6246 .42953 m
.62463 .42998 L
s
.27266 .4342 m
.27264 .43371 L
s
.52611 .42707 m
.5263 .42773 L
s
.52622 .42704 m
.52641 .4277 L
s
.16344 .4428 m
.16339 .44244 L
s
.39466 .43346 m
.39511 .43263 L
s
.48378 .43016 m
.4844 .43104 L
s
.39468 .43346 m
.39512 .43263 L
s
.52601 .42702 m
.52621 .42768 L
s
.71533 .4219 m
.71534 .42227 L
s
.16339 .44273 m
.16334 .44236 L
s
.52604 .42696 m
.52624 .42762 L
s
.39475 .43338 m
.3952 .43255 L
s
.35278 .43697 m
.35284 .43633 L
s
.39479 .43338 m
.39523 .43255 L
s
.27256 .43408 m
.27254 .43359 L
s
.48378 .43009 m
.4844 .43096 L
s
.4837 .43006 m
.48433 .43093 L
s
.48378 .43006 m
.4844 .43093 L
s
.39472 .43334 m
.39517 .43251 L
s
.18016 .5337 m
.18003 .5333 L
s
.39474 .43333 m
.39519 .4325 L
s
.526 .42692 m
.5262 .42758 L
s
.52603 .42692 m
.52622 .42758 L
s
.48372 .43003 m
.48434 .4309 L
s
.48369 .43003 m
.48432 .4309 L
s
.39477 .43331 m
.39522 .43249 L
s
.35278 .43689 m
.35284 .43625 L
s
.48362 .43002 m
.48424 .43089 L
s
.39478 .4333 m
.39524 .43247 L
s
.48371 .43001 m
.48434 .43089 L
s
.84205 .27454 m
.84219 .27478 L
s
.35282 .43687 m
.35288 .43622 L
s
.62457 .42929 m
.6246 .42975 L
s
.62463 .42929 m
.62466 .42974 L
s
.52608 .42682 m
.52628 .42748 L
s
.4836 .42997 m
.48423 .43084 L
s
.39481 .43322 m
.39527 .43239 L
s
.27253 .43393 m
.27251 .43343 L
s
.48357 .42992 m
.4842 .43079 L
s
.35278 .43678 m
.35284 .43613 L
s
.3949 .43314 m
.39536 .43232 L
s
.52594 .42674 m
.52614 .4274 L
s
.71532 .42163 m
.71534 .422 L
s
.48355 .42985 m
.48419 .43072 L
s
.48348 .42982 m
.48412 .43069 L
s
.39486 .43309 m
.39532 .43227 L
s
.52592 .4267 m
.52613 .42736 L
s
.16339 .44244 m
.16333 .44207 L
s
.35282 .43668 m
.35289 .43603 L
s
.39485 .43307 m
.39532 .43225 L
s
.48347 .42979 m
.48411 .43066 L
s
.62472 .4291 m
.62475 .42955 L
s
.48341 .42979 m
.48405 .43066 L
s
.35284 .43666 m
.3529 .43601 L
s
.48349 .42978 m
.48413 .43065 L
s
.62456 .42907 m
.6246 .42953 L
s
.48351 .42976 m
.48414 .43063 L
s
.39489 .43303 m
.39536 .4322 L
s
.71532 .42153 m
.71533 .4219 L
s
.84192 .2743 m
.84205 .27454 L
s
.16334 .44236 m
.16328 .442 L
s
.48351 .42973 m
.48415 .4306 L
s
.27264 .43371 m
.27263 .43322 L
s
.39488 .433 m
.39535 .43218 L
s
.3528 .43659 m
.35286 .43595 L
s
.48337 .4297 m
.48401 .43057 L
s
.48346 .4297 m
.4841 .43057 L
s
.39493 .43296 m
.3954 .43214 L
s
.48335 .42967 m
.48399 .43054 L
s
.35284 .43652 m
.3529 .43588 L
s
.39494 .43293 m
.39541 .4321 L
s
.18003 .5333 m
.17989 .53289 L
s
.3529 .4365 m
.35296 .43585 L
s
.27254 .43359 m
.27253 .4331 L
s
.35286 .43647 m
.35292 .43583 L
s
.39495 .43288 m
.39542 .43205 L
s
.39505 .43285 m
.39552 .43203 L
s
.52594 .42644 m
.52615 .4271 L
s
.4833 .42957 m
.48395 .43043 L
s
.5259 .42641 m
.52611 .42707 L
s
.62453 .42883 m
.62457 .42929 L
s
.62459 .42883 m
.62463 .42929 L
s
.39503 .4328 m
.39551 .43198 L
s
.39503 .43279 m
.39551 .43197 L
s
.52601 .42638 m
.52622 .42704 L
s
.39504 .43277 m
.39551 .43195 L
s
.39501 .43276 m
.39549 .43194 L
s
.5258 .42636 m
.52601 .42702 L
s
.84178 .27407 m
.84192 .2743 L
s
.39503 .43274 m
.39551 .43192 L
s
.48324 .42948 m
.4839 .43035 L
s
.71531 .42125 m
.71532 .42163 L
s
.39507 .43273 m
.39555 .43191 L
s
.35284 .43633 m
.35291 .43568 L
s
.27251 .43343 m
.2725 .43294 L
s
.39508 .43272 m
.39556 .4319 L
s
.48327 .42946 m
.48393 .43032 L
s
.16333 .44207 m
.16328 .4417 L
s
.48325 .42944 m
.48391 .4303 L
s
.52583 .4263 m
.52604 .42696 L
s
.48316 .42941 m
.48383 .43027 L
s
.35284 .43625 m
.35291 .4356 L
s
.52578 .42626 m
.526 .42692 L
s
.52582 .42625 m
.52603 .42692 L
s
.39511 .43263 m
.39559 .43181 L
s
.39512 .43263 m
.39561 .43181 L
s
.71531 .42115 m
.71532 .42153 L
s
.35288 .43622 m
.35295 .43558 L
s
.16328 .442 m
.16324 .44163 L
s
.62468 .42864 m
.62472 .4291 L
s
.62453 .42862 m
.62456 .42907 L
s
.52587 .42616 m
.52608 .42682 L
s
.3952 .43255 m
.39569 .43174 L
s
.39523 .43255 m
.39572 .43173 L
s
.48312 .4293 m
.48378 .43016 L
s
.35284 .43613 m
.35291 .43548 L
s
.39517 .43251 m
.39566 .43169 L
s
.27263 .43322 m
.27261 .43272 L
s
.39519 .4325 m
.39569 .43168 L
s
.17989 .53289 m
.17976 .53249 L
s
.39522 .43249 m
.39572 .43167 L
s
.84165 .27383 m
.84178 .27407 L
s
.39524 .43247 m
.39574 .43166 L
s
.48311 .42923 m
.48378 .43009 L
s
.48303 .4292 m
.4837 .43006 L
s
.52572 .42608 m
.52594 .42674 L
s
.4831 .4292 m
.48378 .43006 L
s
.35289 .43603 m
.35296 .43538 L
s
.48305 .42917 m
.48372 .43003 L
s
.48302 .42917 m
.48369 .43003 L
s
.3529 .43601 m
.35297 .43537 L
s
.52571 .42604 m
.52592 .4267 L
s
.48294 .42916 m
.48362 .43002 L
s
.48304 .42915 m
.48371 .43001 L
s
.39527 .43239 m
.39577 .43157 L
s
.27253 .4331 m
.27252 .43261 L
s
.7153 .42088 m
.71531 .42125 L
s
.48292 .42911 m
.4836 .42997 L
s
.6245 .42838 m
.62453 .42883 L
s
.35286 .43595 m
.35294 .4353 L
s
.62455 .42838 m
.62459 .42883 L
s
.39536 .43232 m
.39586 .4315 L
s
.16328 .4417 m
.16324 .44134 L
s
.48289 .42906 m
.48357 .42992 L
s
.3529 .43588 m
.35298 .43523 L
s
.39532 .43227 m
.39582 .43145 L
s
.39532 .43225 m
.39583 .43143 L
s
.35296 .43585 m
.35303 .4352 L
s
.16324 .44163 m
.16319 .44127 L
s
.71529 .42078 m
.71531 .42115 L
s
.48287 .42899 m
.48355 .42985 L
s
.2725 .43294 m
.27249 .43245 L
s
.35292 .43583 m
.353 .43518 L
s
.84151 .27359 m
.84165 .27383 L
s
.39536 .4322 m
.39587 .43139 L
s
.48279 .42896 m
.48348 .42982 L
s
.39535 .43218 m
.39586 .43136 L
s
.48279 .42894 m
.48347 .42979 L
s
.48272 .42894 m
.48341 .42979 L
s
.48281 .42893 m
.48349 .42978 L
s
.52572 .42578 m
.52594 .42644 L
s
.62464 .42819 m
.62468 .42864 L
s
.3954 .43214 m
.39591 .43133 L
s
.48282 .42891 m
.48351 .42976 L
s
.62449 .42816 m
.62453 .42862 L
s
.52568 .42575 m
.5259 .42641 L
s
.52579 .42572 m
.52601 .42638 L
s
.39541 .4321 m
.39592 .43129 L
s
.48282 .42888 m
.48351 .42973 L
s
.48267 .42885 m
.48337 .4297 L
s
.48276 .42885 m
.48346 .4297 L
s
.17976 .53249 m
.17963 .53209 L
s
.35291 .43568 m
.35299 .43503 L
s
.52558 .4257 m
.5258 .42636 L
s
.39542 .43205 m
.39594 .43124 L
s
.48265 .42882 m
.48335 .42967 L
s
.39552 .43203 m
.39604 .43121 L
s
.52561 .42564 m
.52583 .4263 L
s
.27261 .43272 m
.27261 .43223 L
s
.35291 .4356 m
.35299 .43495 L
s
.39551 .43198 m
.39603 .43116 L
s
.39551 .43197 m
.39603 .43116 L
s
.35295 .43558 m
.35304 .43493 L
s
.39551 .43195 m
.39604 .43114 L
s
.71528 .42051 m
.7153 .42088 L
s
.52556 .4256 m
.52578 .42626 L
s
.52559 .4256 m
.52582 .42625 L
s
.84137 .27335 m
.84151 .27359 L
s
.39549 .43194 m
.39601 .43112 L
s
.4826 .42871 m
.4833 .42957 L
s
.16324 .44134 m
.16319 .44097 L
s
.39551 .43192 m
.39604 .43111 L
s
.39555 .43191 m
.39608 .4311 L
s
.39556 .4319 m
.39609 .43109 L
s
.27252 .43261 m
.27251 .43212 L
s
.62446 .42792 m
.6245 .42838 L
s
.62451 .42792 m
.62455 .42838 L
s
.52564 .4255 m
.52587 .42616 L
s
.35291 .43548 m
.35299 .43484 L
s
.16319 .44127 m
.16314 .4409 L
s
.48254 .42863 m
.48324 .42948 L
s
.71528 .42041 m
.71529 .42078 L
s
.48256 .42861 m
.48327 .42946 L
s
.39559 .43181 m
.39613 .431 L
s
.39561 .43181 m
.39614 .431 L
s
.48254 .42859 m
.48325 .42944 L
s
.48245 .42856 m
.48316 .42941 L
s
.35296 .43538 m
.35305 .43474 L
s
.52549 .42542 m
.52572 .42608 L
s
.35297 .43537 m
.35306 .43472 L
s
.39569 .43174 m
.39622 .43092 L
s
.39572 .43173 m
.39626 .43092 L
s
.27249 .43245 m
.27248 .43196 L
s
.52548 .42538 m
.52571 .42604 L
s
.39566 .43169 m
.3962 .43088 L
s
.6246 .42773 m
.62464 .42819 L
s
.39569 .43168 m
.39622 .43087 L
s
.35294 .4353 m
.35303 .43465 L
s
.39572 .43167 m
.39625 .43086 L
s
.84123 .27312 m
.84137 .27335 L
s
.39574 .43166 m
.39628 .43085 L
s
.4824 .42845 m
.48312 .4293 L
s
.62445 .4277 m
.62449 .42816 L
s
.17963 .53209 m
.1795 .53168 L
s
.35298 .43523 m
.35307 .43458 L
s
.35303 .4352 m
.35312 .43456 L
s
.48239 .42838 m
.48311 .42923 L
s
.39577 .43157 m
.39632 .43076 L
s
.353 .43518 m
.3531 .43453 L
s
.71526 .42013 m
.71528 .42051 L
s
.48232 .42836 m
.48303 .4292 L
s
.48238 .42835 m
.4831 .4292 L
s
.16319 .44097 m
.16314 .4406 L
s
.48232 .42833 m
.48305 .42917 L
s
.48229 .42833 m
.48302 .42917 L
s
.48221 .42832 m
.48294 .42916 L
s
.27261 .43223 m
.2726 .43174 L
s
.39586 .4315 m
.39641 .4307 L
s
.48232 .42831 m
.48304 .42915 L
s
.52549 .42512 m
.52572 .42578 L
s
.16314 .4409 m
.16309 .44053 L
s
.39582 .43145 m
.39637 .43065 L
s
.48219 .42826 m
.48292 .42911 L
s
.71526 .42003 m
.71528 .42041 L
s
.39583 .43143 m
.39638 .43063 L
s
.52544 .42509 m
.52568 .42575 L
s
.62441 .42747 m
.62446 .42792 L
s
.52556 .42506 m
.52579 .42572 L
s
.62447 .42747 m
.62451 .42792 L
s
.35299 .43503 m
.35308 .43439 L
s
.48216 .42822 m
.48289 .42906 L
s
.8411 .27288 m
.84123 .27312 L
s
.39587 .43139 m
.39642 .43058 L
s
.27251 .43212 m
.27251 .43163 L
s
.52534 .42504 m
.52558 .4257 L
s
.39586 .43136 m
.39642 .43056 L
s
.48214 .42815 m
.48287 .42899 L
s
.39591 .43133 m
.39647 .43052 L
s
.35299 .43495 m
.35309 .43431 L
s
.52537 .42498 m
.52561 .42564 L
s
.35304 .43493 m
.35313 .43428 L
s
.48206 .42812 m
.48279 .42896 L
s
.39592 .43129 m
.39648 .43048 L
s
.48205 .4281 m
.48279 .42894 L
s
.48198 .4281 m
.48272 .42894 L
s
.48207 .42809 m
.48281 .42893 L
s
.52532 .42494 m
.52556 .4256 L
s
.52535 .42494 m
.52559 .4256 L
s
.48208 .42807 m
.48282 .42891 L
s
.39594 .43124 m
.3965 .43043 L
s
.1795 .53168 m
.17937 .53128 L
s
.27248 .43196 m
.27248 .43147 L
s
.62456 .42728 m
.6246 .42773 L
s
.39604 .43121 m
.3966 .43041 L
s
.48208 .42804 m
.48282 .42888 L
s
.35299 .43484 m
.35309 .43419 L
s
.6244 .42725 m
.62445 .4277 L
s
.48193 .42801 m
.48267 .42885 L
s
.48202 .42801 m
.48276 .42885 L
s
.5254 .42484 m
.52564 .4255 L
s
.71525 .41976 m
.71526 .42013 L
s
.39603 .43116 m
.39659 .43036 L
s
.16314 .4406 m
.1631 .44024 L
s
.39603 .43116 m
.39659 .43035 L
s
.48191 .42798 m
.48265 .42882 L
s
.39604 .43114 m
.3966 .43034 L
s
.84096 .27264 m
.8411 .27288 L
s
.39601 .43112 m
.39657 .43032 L
s
.39604 .43111 m
.3966 .43031 L
s
.35305 .43474 m
.35315 .43409 L
s
.39608 .4311 m
.39665 .4303 L
s
.35306 .43472 m
.35316 .43407 L
s
.39609 .43109 m
.39666 .43028 L
s
.16309 .44053 m
.16305 .44017 L
s
.52524 .42476 m
.52549 .42542 L
s
.71524 .41966 m
.71526 .42003 L
s
.48185 .42788 m
.4826 .42871 L
s
.52523 .42472 m
.52548 .42538 L
s
.35303 .43465 m
.35313 .43401 L
s
.2726 .43174 m
.2726 .43125 L
s
.39613 .431 m
.3967 .4302 L
s
.39614 .431 m
.39671 .4302 L
s
.48179 .4278 m
.48254 .42863 L
s
.62436 .42701 m
.62441 .42747 L
s
.35307 .43458 m
.35317 .43394 L
s
.62442 .42701 m
.62447 .42747 L
s
.48181 .42777 m
.48256 .42861 L
s
.35312 .43456 m
.35323 .43391 L
s
.39622 .43092 m
.3968 .43012 L
s
.39626 .43092 m
.39684 .43012 L
s
.48178 .42776 m
.48254 .42859 L
s
.3531 .43453 m
.35321 .43389 L
s
.27251 .43163 m
.27251 .43114 L
s
.48169 .42773 m
.48245 .42856 L
s
.3962 .43088 m
.39678 .43008 L
s
.39622 .43087 m
.3968 .43007 L
s
.39625 .43086 m
.39683 .43006 L
s
.84082 .27241 m
.84096 .27264 L
s
.39628 .43085 m
.39686 .43005 L
s
.17937 .53128 m
.17925 .53087 L
s
.52524 .42447 m
.52549 .42512 L
s
.48164 .42762 m
.4824 .42845 L
s
.71523 .41938 m
.71525 .41976 L
s
.1631 .44024 m
.16306 .43987 L
s
.39632 .43076 m
.3969 .42997 L
s
.62451 .42682 m
.62456 .42728 L
s
.35308 .43439 m
.35319 .43374 L
s
.52519 .42443 m
.52544 .42509 L
s
.62435 .42679 m
.6244 .42725 L
s
.52531 .42441 m
.52556 .42506 L
s
.27248 .43147 m
.27248 .43098 L
s
.39641 .4307 m
.397 .4299 L
s
.48163 .42755 m
.48239 .42838 L
s
.16305 .44017 m
.16301 .4398 L
s
.52508 .42438 m
.52534 .42504 L
s
.48155 .42753 m
.48232 .42836 L
s
.35309 .43431 m
.3532 .43366 L
s
.48162 .42752 m
.48238 .42835 L
s
.71522 .41928 m
.71524 .41966 L
s
.35313 .43428 m
.35325 .43364 L
s
.48156 .4275 m
.48232 .42833 L
s
.39637 .43065 m
.39696 .42985 L
s
.48152 .4275 m
.48229 .42833 L
s
.52512 .42432 m
.52537 .42498 L
s
.48144 .42749 m
.48221 .42832 L
s
.39638 .43063 m
.39697 .42983 L
s
.48155 .42748 m
.48232 .42831 L
s
.39642 .43058 m
.39702 .42979 L
s
.84068 .27217 m
.84082 .27241 L
s
.52506 .42428 m
.52532 .42494 L
s
.5251 .42428 m
.52535 .42494 L
s
.48142 .42744 m
.48219 .42826 L
s
.39642 .43056 m
.39702 .42976 L
s
.35309 .43419 m
.3532 .43355 L
s
.48138 .42739 m
.48216 .42822 L
s
.39647 .43052 m
.39707 .42973 L
s
.2726 .43125 m
.27261 .43076 L
s
.52515 .42418 m
.5254 .42484 L
s
.62431 .42656 m
.62436 .42701 L
s
.62437 .42656 m
.62442 .42701 L
s
.39648 .43048 m
.39708 .42969 L
s
.35315 .43409 m
.35327 .43344 L
s
.48136 .42732 m
.48214 .42815 L
s
.3965 .43043 m
.39711 .42964 L
s
.35316 .43407 m
.35327 .43343 L
s
.48128 .42729 m
.48206 .42812 L
s
.3966 .43041 m
.3972 .42961 L
s
.48127 .42727 m
.48205 .4281 L
s
.4812 .42727 m
.48198 .4281 L
s
.48129 .42726 m
.48207 .42809 L
s
.27251 .43114 m
.27251 .43064 L
s
.52498 .42411 m
.52524 .42476 L
s
.16306 .43987 m
.16301 .4395 L
s
.7152 .41901 m
.71523 .41938 L
s
.17925 .53087 m
.17912 .53047 L
s
.35313 .43401 m
.35325 .43336 L
s
.4813 .42724 m
.48208 .42807 L
s
.39659 .43036 m
.3972 .42956 L
s
.39659 .43035 m
.3972 .42956 L
s
.52497 .42407 m
.52523 .42472 L
s
.4813 .42721 m
.48208 .42804 L
s
.3966 .43034 m
.39721 .42954 L
s
.39657 .43032 m
.39718 .42953 L
s
.48114 .42719 m
.48193 .42801 L
s
.84053 .27193 m
.84068 .27217 L
s
.48124 .42719 m
.48202 .42801 L
s
.3966 .43031 m
.39721 .42952 L
s
.16301 .4398 m
.16297 .43943 L
s
.35317 .43394 m
.35329 .43329 L
s
.62446 .42637 m
.62451 .42682 L
s
.39665 .4303 m
.39726 .4295 L
s
.39666 .43028 m
.39727 .42949 L
s
.48112 .42716 m
.48191 .42798 L
s
.35323 .43391 m
.35334 .43326 L
s
.7152 .41891 m
.71522 .41928 L
s
.6243 .42634 m
.62435 .42679 L
s
.35321 .43389 m
.35333 .43324 L
s
.27248 .43098 m
.27249 .43049 L
s
.3967 .4302 m
.39732 .4294 L
s
.39671 .4302 m
.39733 .4294 L
s
.48105 .42706 m
.48185 .42788 L
s
.3968 .43012 m
.39741 .42933 L
s
.39684 .43012 m
.39745 .42933 L
s
.35319 .43374 m
.35331 .4331 L
s
.52498 .42381 m
.52524 .42447 L
s
.48099 .42698 m
.48179 .4278 L
s
.39678 .43008 m
.3974 .42929 L
s
.3968 .43007 m
.39742 .42928 L
s
.48101 .42696 m
.48181 .42777 L
s
.39683 .43006 m
.39745 .42927 L
s
.52493 .42378 m
.52519 .42443 L
s
.39686 .43005 m
.39748 .42926 L
s
.48098 .42694 m
.48178 .42776 L
s
.52505 .42375 m
.52531 .42441 L
s
.84039 .2717 m
.84053 .27193 L
s
.62426 .4261 m
.62431 .42656 L
s
.62432 .4261 m
.62437 .42656 L
s
.3532 .43366 m
.35333 .43302 L
s
.48089 .42691 m
.48169 .42773 L
s
.27261 .43076 m
.27261 .43027 L
s
.52482 .42373 m
.52508 .42438 L
s
.35325 .43364 m
.35337 .43299 L
s
.16301 .4395 m
.16297 .43914 L
s
.71518 .41863 m
.7152 .41901 L
s
.3969 .42997 m
.39753 .42918 L
s
.17912 .53047 m
.179 .53006 L
s
.52485 .42367 m
.52512 .42432 L
s
.16297 .43943 m
.16293 .43907 L
s
.48083 .4268 m
.48164 .42762 L
s
.397 .4299 m
.39763 .42911 L
s
.3532 .43355 m
.35333 .4329 L
s
.27251 .43064 m
.27252 .43015 L
s
.52479 .42363 m
.52506 .42428 L
s
.52483 .42363 m
.5251 .42428 L
s
.71517 .41854 m
.7152 .41891 L
s
.39696 .42985 m
.3976 .42906 L
s
.6244 .42591 m
.62446 .42637 L
s
.39697 .42983 m
.3976 .42904 L
s
.48082 .42674 m
.48163 .42755 L
s
.52488 .42353 m
.52515 .42418 L
s
.48074 .42671 m
.48155 .42753 L
s
.62424 .42588 m
.6243 .42634 L
s
.35327 .43344 m
.3534 .4328 L
s
.4808 .42671 m
.48162 .42752 L
s
.39702 .42979 m
.39766 .429 L
s
.35327 .43343 m
.3534 .43278 L
s
.48074 .42668 m
.48156 .4275 L
s
.48071 .42668 m
.48152 .4275 L
s
.84025 .27146 m
.84039 .2717 L
s
.48062 .42667 m
.48144 .42749 L
s
.39702 .42976 m
.39766 .42897 L
s
.48073 .42667 m
.48155 .42748 L
s
.39707 .42973 m
.39772 .42894 L
s
.27249 .43049 m
.2725 .42999 L
s
.35325 .43336 m
.35338 .43272 L
s
.4806 .42662 m
.48142 .42744 L
s
.52471 .42346 m
.52498 .42411 L
s
.39708 .42969 m
.39772 .4289 L
s
.48056 .42658 m
.48138 .42739 L
s
.5247 .42342 m
.52497 .42407 L
s
.35329 .43329 m
.35342 .43265 L
s
.39711 .42964 m
.39775 .42885 L
s
.35334 .43326 m
.35347 .43262 L
s
.3972 .42961 m
.39785 .42883 L
s
.16297 .43914 m
.16294 .43877 L
s
.35333 .43324 m
.35346 .4326 L
s
.71516 .41826 m
.71518 .41863 L
s
.48053 .42651 m
.48136 .42732 L
s
.6242 .42565 m
.62426 .4261 L
s
.3972 .42956 m
.39785 .42878 L
s
.48046 .42648 m
.48128 .42729 L
s
.62426 .42565 m
.62432 .4261 L
s
.3972 .42956 m
.39784 .42878 L
s
.39721 .42954 m
.39786 .42876 L
s
.48044 .42646 m
.48127 .42727 L
s
.48036 .42647 m
.4812 .42727 L
s
.16293 .43907 m
.16289 .4387 L
s
.48046 .42645 m
.48129 .42726 L
s
.179 .53006 m
.17888 .52965 L
s
.39718 .42953 m
.39783 .42874 L
s
.39721 .42952 m
.39786 .42873 L
s
.27261 .43027 m
.27262 .42977 L
s
.48047 .42643 m
.4813 .42724 L
s
.39726 .4295 m
.39791 .42872 L
s
.84011 .27122 m
.84025 .27146 L
s
.39727 .42949 m
.39793 .42871 L
s
.71515 .41816 m
.71517 .41854 L
s
.48047 .42641 m
.4813 .42721 L
s
.4803 .42638 m
.48114 .42719 L
s
.4804 .42638 m
.48124 .42719 L
s
.35331 .4331 m
.35345 .43245 L
s
.48028 .42635 m
.48112 .42716 L
s
.5247 .42316 m
.52498 .42381 L
s
.39732 .4294 m
.39797 .42862 L
s
.39733 .4294 m
.39799 .42862 L
s
.27252 .43015 m
.27253 .42966 L
s
.62434 .42546 m
.6244 .42591 L
s
.52465 .42313 m
.52493 .42378 L
s
.35333 .43302 m
.35347 .43237 L
s
.52477 .4231 m
.52505 .42375 L
s
.35337 .43299 m
.35351 .43235 L
s
.62419 .42543 m
.62424 .42588 L
s
.39741 .42933 m
.39807 .42855 L
s
.39745 .42933 m
.39811 .42855 L
s
.52454 .42308 m
.52482 .42373 L
s
.48021 .42625 m
.48105 .42706 L
s
.3974 .42929 m
.39806 .42851 L
s
.39742 .42928 m
.39809 .4285 L
s
.39745 .42927 m
.39812 .42849 L
s
.52457 .42302 m
.52485 .42367 L
s
.39748 .42926 m
.39815 .42848 L
s
.35333 .4329 m
.35347 .43226 L
s
.2725 .42999 m
.27251 .4295 L
s
.48015 .42617 m
.48099 .42698 L
s
.83996 .27099 m
.84011 .27122 L
s
.16294 .43877 m
.1629 .4384 L
s
.52451 .42298 m
.52479 .42363 L
s
.52454 .42298 m
.52483 .42363 L
s
.48017 .42615 m
.48101 .42696 L
s
.71513 .41789 m
.71516 .41826 L
s
.48013 .42614 m
.48098 .42694 L
s
.39753 .42918 m
.3982 .4284 L
s
.48004 .42611 m
.48089 .42691 L
s
.3534 .4328 m
.35354 .43216 L
s
.16289 .4387 m
.16285 .43833 L
s
.5246 .42288 m
.52488 .42353 L
s
.3534 .43278 m
.35354 .43214 L
s
.39763 .42911 m
.3983 .42833 L
s
.17888 .52965 m
.17876 .52924 L
s
.62414 .42519 m
.6242 .42565 L
s
.6242 .42519 m
.62426 .42565 L
s
.71512 .41779 m
.71515 .41816 L
s
.3976 .42906 m
.39827 .42828 L
s
.35338 .43272 m
.35353 .43207 L
s
.47997 .426 m
.48083 .4268 L
s
.3976 .42904 m
.39828 .42827 L
s
.52442 .42281 m
.52471 .42346 L
s
.27262 .42977 m
.27264 .42928 L
s
.39766 .429 m
.39833 .42823 L
s
.35342 .43265 m
.35357 .43201 L
s
.52441 .42277 m
.5247 .42342 L
s
.39766 .42897 m
.39834 .4282 L
s
.47996 .42594 m
.48082 .42674 L
s
.35347 .43262 m
.35362 .43197 L
s
.47988 .42591 m
.48074 .42671 L
s
.83982 .27075 m
.83996 .27099 L
s
.39772 .42894 m
.3984 .42817 L
s
.47995 .42591 m
.4808 .42671 L
s
.35346 .4326 m
.35361 .43195 L
s
.47988 .42589 m
.48074 .42668 L
s
.47985 .42589 m
.48071 .42668 L
s
.47976 .42588 m
.48062 .42667 L
s
.62428 .425 m
.62434 .42546 L
s
.39772 .4289 m
.39841 .42813 L
s
.47987 .42587 m
.48073 .42667 L
s
.27253 .42966 m
.27255 .42917 L
s
.62412 .42497 m
.62419 .42543 L
s
.39775 .42885 m
.39844 .42808 L
s
.47973 .42583 m
.4806 .42662 L
s
.1629 .4384 m
.16286 .43803 L
s
.39785 .42883 m
.39854 .42806 L
s
.47969 .42578 m
.48056 .42658 L
s
.7151 .41751 m
.71513 .41789 L
s
.35345 .43245 m
.3536 .43181 L
s
.39785 .42878 m
.39853 .42801 L
s
.39784 .42878 m
.39853 .428 L
s
.39786 .42876 m
.39854 .42799 L
s
.16285 .43833 m
.16282 .43796 L
s
.39783 .42874 m
.39852 .42797 L
s
.47966 .42572 m
.48053 .42651 L
s
.39786 .42873 m
.39856 .42796 L
s
.52441 .42251 m
.5247 .42316 L
s
.27251 .4295 m
.27253 .42901 L
s
.39791 .42872 m
.3986 .42795 L
s
.47958 .42569 m
.48046 .42648 L
s
.39793 .42871 m
.39862 .42794 L
s
.35347 .43237 m
.35362 .43173 L
s
.7151 .41741 m
.71512 .41779 L
s
.47956 .42567 m
.48044 .42646 L
s
.47949 .42567 m
.48036 .42647 L
s
.35351 .43235 m
.35366 .43171 L
s
.52435 .42248 m
.52465 .42313 L
s
.47959 .42566 m
.48046 .42645 L
s
.17876 .52924 m
.17864 .52883 L
s
.52448 .42245 m
.52477 .4231 L
s
.83968 .27052 m
.83982 .27075 L
s
.4796 .42564 m
.48047 .42643 L
s
.62408 .42474 m
.62414 .42519 L
s
.52424 .42243 m
.52454 .42308 L
s
.62414 .42474 m
.6242 .42519 L
s
.47959 .42561 m
.48047 .42641 L
s
.39797 .42862 m
.39867 .42785 L
s
.39799 .42862 m
.39868 .42785 L
s
.47942 .42559 m
.4803 .42638 L
s
.47953 .42559 m
.4804 .42638 L
s
.35347 .43226 m
.35362 .43161 L
s
.52427 .42237 m
.52457 .42302 L
s
.4794 .42556 m
.48028 .42635 L
s
.39807 .42855 m
.39878 .42778 L
s
.39811 .42855 m
.39881 .42778 L
s
.52425 .42234 m
.52454 .42298 L
s
.52421 .42234 m
.52451 .42298 L
s
.39806 .42851 m
.39876 .42774 L
s
.27264 .42928 m
.27266 .42879 L
s
.39809 .4285 m
.39879 .42774 L
s
.35354 .43216 m
.35369 .43151 L
s
.39812 .42849 m
.39882 .42772 L
s
.39815 .42848 m
.39886 .42771 L
s
.35354 .43214 m
.35369 .43149 L
s
.47932 .42546 m
.48021 .42625 L
s
.5243 .42224 m
.5246 .42288 L
s
.16286 .43803 m
.16283 .43766 L
s
.62422 .42455 m
.62428 .425 L
s
.62406 .42452 m
.62412 .42497 L
s
.71507 .41714 m
.7151 .41751 L
s
.83953 .27028 m
.83968 .27052 L
s
.35353 .43207 m
.35368 .43143 L
s
.3982 .4284 m
.39891 .42763 L
s
.27255 .42917 m
.27257 .42868 L
s
.47926 .42539 m
.48015 .42617 L
s
.16282 .43796 m
.16278 .4376 L
s
.47927 .42537 m
.48017 .42615 L
s
.47924 .42535 m
.48013 .42614 L
s
.35357 .43201 m
.35372 .43136 L
s
.52412 .42216 m
.52442 .42281 L
s
.3983 .42833 m
.39901 .42757 L
s
.47914 .42533 m
.48004 .42611 L
s
.35362 .43197 m
.35377 .43133 L
s
.71507 .41704 m
.7151 .41741 L
s
.52411 .42213 m
.52441 .42277 L
s
.35361 .43195 m
.35377 .43131 L
s
.39827 .42828 m
.39899 .42752 L
s
.39828 .42827 m
.39899 .4275 L
s
.17864 .52883 m
.17852 .52842 L
s
.27253 .42901 m
.27255 .42852 L
s
.39833 .42823 m
.39905 .42746 L
s
.47907 .42522 m
.47997 .426 L
s
.39834 .4282 m
.39906 .42743 L
s
.62401 .42428 m
.62408 .42474 L
s
.3984 .42817 m
.39912 .42741 L
s
.62407 .42428 m
.62414 .42474 L
s
.3536 .43181 m
.35376 .43117 L
s
.47906 .42516 m
.47996 .42594 L
s
.83939 .27004 m
.83953 .27028 L
s
.39841 .42813 m
.39913 .42736 L
s
.47898 .42513 m
.47988 .42591 L
s
.47904 .42513 m
.47995 .42591 L
s
.47898 .42511 m
.47988 .42589 L
s
.47894 .42511 m
.47985 .42589 L
s
.39844 .42808 m
.39917 .42732 L
s
.47885 .4251 m
.47976 .42588 L
s
.47896 .42509 m
.47987 .42587 L
s
.39854 .42806 m
.39926 .42729 L
s
.16283 .43766 m
.1628 .4373 L
s
.35362 .43173 m
.35378 .43109 L
s
.5241 .42187 m
.52441 .42251 L
s
.35366 .43171 m
.35383 .43107 L
s
.71504 .41676 m
.71507 .41714 L
s
.47882 .42505 m
.47973 .42583 L
s
.39853 .42801 m
.39926 .42725 L
s
.27266 .42879 m
.27268 .4283 L
s
.52405 .42184 m
.52435 .42248 L
s
.39853 .428 m
.39926 .42724 L
s
.52417 .42181 m
.52448 .42245 L
s
.39854 .42799 m
.39927 .42723 L
s
.62415 .42409 m
.62422 .42455 L
s
.16278 .4376 m
.16275 .43723 L
s
.39852 .42797 m
.39925 .42721 L
s
.47878 .425 m
.47969 .42578 L
s
.39856 .42796 m
.39929 .4272 L
s
.52393 .42179 m
.52424 .42243 L
s
.3986 .42795 m
.39934 .42719 L
s
.62399 .42406 m
.62406 .42452 L
s
.39862 .42794 m
.39936 .42718 L
s
.35362 .43161 m
.35378 .43097 L
s
.71504 .41666 m
.71507 .41704 L
s
.52396 .42173 m
.52427 .42237 L
s
.47874 .42494 m
.47966 .42572 L
s
.27257 .42868 m
.27259 .42819 L
s
.47867 .42492 m
.47958 .42569 L
s
.83924 .26981 m
.83939 .27004 L
s
.47857 .4249 m
.47949 .42567 L
s
.47865 .4249 m
.47956 .42567 L
s
.39867 .42785 m
.39941 .42709 L
s
.39868 .42785 m
.39942 .42709 L
s
.47867 .42489 m
.47959 .42566 L
s
.52393 .42169 m
.52425 .42234 L
s
.52389 .42169 m
.52421 .42234 L
s
.35369 .43151 m
.35386 .43087 L
s
.17852 .52842 m
.1784 .52801 L
s
.47868 .42487 m
.4796 .42564 L
s
.35369 .43149 m
.35386 .43085 L
s
.47867 .42484 m
.47959 .42561 L
s
.39878 .42778 m
.39952 .42702 L
s
.39881 .42778 m
.39956 .42702 L
s
.4785 .42482 m
.47942 .42559 L
s
.52399 .42159 m
.5243 .42224 L
s
.4786 .42481 m
.47953 .42559 L
s
.35368 .43143 m
.35385 .43079 L
s
.39876 .42774 m
.39951 .42698 L
s
.39879 .42774 m
.39953 .42698 L
s
.47847 .42479 m
.4794 .42556 L
s
.27255 .42852 m
.27258 .42803 L
s
.39882 .42772 m
.39956 .42696 L
s
.39886 .42771 m
.3996 .42696 L
s
.62394 .42383 m
.62401 .42428 L
s
.624 .42383 m
.62407 .42428 L
s
.35372 .43136 m
.35389 .43072 L
s
.1628 .4373 m
.16276 .43693 L
s
.35377 .43133 m
.35394 .43069 L
s
.5238 .42152 m
.52412 .42216 L
s
.35377 .43131 m
.35395 .43067 L
s
.39891 .42763 m
.39967 .42687 L
s
.47839 .42469 m
.47932 .42546 L
s
.71501 .41639 m
.71504 .41676 L
s
.52379 .42148 m
.52411 .42213 L
s
.16275 .43723 m
.16272 .43686 L
s
.83909 .26957 m
.83924 .26981 L
s
.39901 .42757 m
.39977 .42681 L
s
.47833 .42462 m
.47926 .42539 L
s
.47834 .4246 m
.47927 .42537 L
s
.39899 .42752 m
.39974 .42676 L
s
.4783 .42458 m
.47924 .42535 L
s
.62408 .42364 m
.62415 .42409 L
s
.715 .41629 m
.71504 .41666 L
s
.27268 .4283 m
.27271 .42781 L
s
.39899 .4275 m
.39975 .42675 L
s
.4782 .42456 m
.47914 .42533 L
s
.35376 .43117 m
.35393 .43053 L
s
.62392 .42361 m
.62399 .42406 L
s
.39905 .42746 m
.39981 .42671 L
s
.39906 .42743 m
.39982 .42668 L
s
.39912 .42741 m
.39989 .42666 L
s
.35378 .43109 m
.35396 .43045 L
s
.1784 .52801 m
.17829 .5276 L
s
.27259 .42819 m
.27262 .4277 L
s
.35383 .43107 m
.35401 .43043 L
s
.47813 .42446 m
.47907 .42522 L
s
.52378 .42123 m
.5241 .42187 L
s
.39913 .42736 m
.3999 .42661 L
s
.52373 .4212 m
.52405 .42184 L
s
.39917 .42732 m
.39994 .42657 L
s
.52385 .42117 m
.52417 .42181 L
s
.83894 .26934 m
.83909 .26957 L
s
.47812 .4244 m
.47906 .42516 L
s
.39926 .42729 m
.40003 .42654 L
s
.47803 .42437 m
.47898 .42513 L
s
.35378 .43097 m
.35396 .43033 L
s
.4781 .42437 m
.47904 .42513 L
s
.16276 .43693 m
.16273 .43656 L
s
.52361 .42115 m
.52393 .42179 L
s
.47803 .42435 m
.47898 .42511 L
s
.47799 .42435 m
.47894 .42511 L
s
.39926 .42725 m
.40003 .4265 L
s
.4779 .42434 m
.47885 .4251 L
s
.62387 .42337 m
.62394 .42383 L
s
.39926 .42724 m
.40003 .42649 L
s
.62393 .42337 m
.624 .42383 L
s
.47801 .42433 m
.47896 .42509 L
s
.39927 .42723 m
.40005 .42648 L
s
.27258 .42803 m
.27261 .42754 L
s
.71498 .41602 m
.71501 .41639 L
s
.52364 .42109 m
.52396 .42173 L
s
.39925 .42721 m
.40003 .42646 L
s
.39929 .4272 m
.40006 .42645 L
s
.16272 .43686 m
.16269 .43649 L
s
.39934 .42719 m
.40011 .42644 L
s
.47786 .42429 m
.47882 .42505 L
s
.35386 .43087 m
.35405 .43023 L
s
.39936 .42718 m
.40013 .42643 L
s
.35386 .43085 m
.35404 .43021 L
s
.52361 .42105 m
.52393 .42169 L
s
.52357 .42105 m
.52389 .42169 L
s
.47782 .42424 m
.47878 .425 L
s
.71497 .41592 m
.715 .41629 L
s
.35385 .43079 m
.35404 .43015 L
s
.39941 .42709 m
.40019 .42635 L
s
.39942 .42709 m
.4002 .42635 L
s
.52366 .42095 m
.52399 .42159 L
s
.47778 .42418 m
.47874 .42494 L
s
.47771 .42416 m
.47867 .42492 L
s
.624 .42318 m
.62408 .42364 L
s
.4776 .42415 m
.47857 .4249 L
s
.8388 .26911 m
.83894 .26934 L
s
.47768 .42414 m
.47865 .4249 L
s
.35389 .43072 m
.35408 .43008 L
s
.39952 .42702 m
.4003 .42628 L
s
.47771 .42413 m
.47867 .42489 L
s
.39956 .42702 m
.40034 .42628 L
s
.62384 .42315 m
.62392 .42361 L
s
.27271 .42781 m
.27274 .42732 L
s
.35394 .43069 m
.35413 .43005 L
s
.47772 .42411 m
.47868 .42487 L
s
.39951 .42698 m
.40029 .42624 L
s
.39953 .42698 m
.40032 .42624 L
s
.35395 .43067 m
.35413 .43003 L
s
.17829 .5276 m
.17817 .52719 L
s
.47771 .42409 m
.47867 .42484 L
s
.52347 .42088 m
.5238 .42152 L
s
.39956 .42696 m
.40035 .42622 L
s
.3996 .42696 m
.40039 .42621 L
s
.47753 .42406 m
.4785 .42482 L
s
.47764 .42406 m
.4786 .42481 L
s
.52346 .42084 m
.52379 .42148 L
s
.4775 .42404 m
.47847 .42479 L
s
.27262 .4277 m
.27265 .4272 L
s
.16273 .43656 m
.16271 .43619 L
s
.39967 .42687 m
.40046 .42613 L
s
.35393 .43053 m
.35412 .42989 L
s
.71494 .41564 m
.71498 .41602 L
s
.39977 .42681 m
.40056 .42607 L
s
.47742 .42394 m
.47839 .42469 L
s
.16269 .43649 m
.16266 .43612 L
s
.62379 .42292 m
.62387 .42337 L
s
.62385 .42292 m
.62393 .42337 L
s
.39974 .42676 m
.40054 .42602 L
s
.83865 .26887 m
.8388 .26911 L
s
.39975 .42675 m
.40055 .42601 L
s
.35396 .43045 m
.35415 .42981 L
s
.47735 .42387 m
.47833 .42462 L
s
.35401 .43043 m
.3542 .42979 L
s
.27261 .42754 m
.27264 .42704 L
s
.47736 .42385 m
.47834 .4246 L
s
.71493 .41554 m
.71497 .41592 L
s
.39981 .42671 m
.40061 .42597 L
s
.47733 .42384 m
.4783 .42458 L
s
.39982 .42668 m
.40062 .42595 L
s
.52345 .42059 m
.52378 .42123 L
s
.47722 .42382 m
.4782 .42456 L
s
.39989 .42666 m
.4007 .42592 L
s
.52339 .42056 m
.52373 .4212 L
s
.52352 .42053 m
.52385 .42117 L
s
.35396 .43033 m
.35416 .42969 L
s
.3999 .42661 m
.4007 .42588 L
s
.52327 .42051 m
.52361 .42115 L
s
.62393 .42273 m
.624 .42318 L
s
.39994 .42657 m
.40075 .42583 L
s
.47714 .42371 m
.47813 .42446 L
s
.62376 .4227 m
.62384 .42315 L
s
.40003 .42654 m
.40084 .42581 L
s
.17817 .52719 m
.17806 .52678 L
s
.35405 .43023 m
.35424 .42959 L
s
.5233 .42045 m
.52364 .42109 L
s
.35404 .43021 m
.35423 .42957 L
s
.40003 .4265 m
.40084 .42576 L
s
.27274 .42732 m
.27277 .42682 L
s
.47713 .42365 m
.47812 .4244 L
s
.16271 .43619 m
.16268 .43582 L
s
.40003 .42649 m
.40084 .42576 L
s
.8385 .26864 m
.83865 .26887 L
s
.40005 .42648 m
.40086 .42575 L
s
.52327 .42041 m
.52361 .42105 L
s
.52323 .42041 m
.52357 .42105 L
s
.47704 .42363 m
.47803 .42437 L
s
.47711 .42363 m
.4781 .42437 L
s
.40003 .42646 m
.40084 .42573 L
s
.40006 .42645 m
.40087 .42572 L
s
.47704 .42361 m
.47803 .42435 L
s
.477 .42361 m
.47799 .42435 L
s
.35404 .43015 m
.35423 .42951 L
s
.40011 .42644 m
.40092 .42571 L
s
.4769 .4236 m
.4779 .42434 L
s
.40013 .42643 m
.40095 .4257 L
s
.47702 .42359 m
.47801 .42433 L
s
.71491 .41527 m
.71494 .41564 L
s
.16266 .43612 m
.16263 .43575 L
s
.52332 .42031 m
.52366 .42095 L
s
.27265 .4272 m
.27269 .42671 L
s
.47687 .42355 m
.47786 .42429 L
s
.35408 .43008 m
.35427 .42944 L
s
.35413 .43005 m
.35432 .42941 L
s
.40019 .42635 m
.40101 .42561 L
s
.4002 .42635 m
.40102 .42561 L
s
.47682 .4235 m
.47782 .42424 L
s
.35413 .43003 m
.35434 .42939 L
s
.7149 .41517 m
.71493 .41554 L
s
.62371 .42246 m
.62379 .42292 L
s
.62377 .42246 m
.62385 .42292 L
s
.52312 .42025 m
.52347 .42088 L
s
.4003 .42628 m
.40112 .42555 L
s
.40034 .42628 m
.40116 .42555 L
s
.47678 .42344 m
.47778 .42418 L
s
.47671 .42342 m
.47771 .42416 L
s
.52312 .42021 m
.52346 .42084 L
s
.40029 .42624 m
.40111 .42551 L
s
.40032 .42624 m
.40114 .42551 L
s
.4766 .42341 m
.4776 .42415 L
s
.47668 .42341 m
.47768 .42414 L
s
.47671 .4234 m
.47771 .42413 L
s
.27264 .42704 m
.27268 .42655 L
s
.40039 .42621 m
.40122 .42549 L
s
.40035 .42622 m
.40117 .42549 L
s
.83835 .2684 m
.8385 .26864 L
s
.47672 .42338 m
.47772 .42411 L
s
.35412 .42989 m
.35432 .42925 L
s
.47671 .42335 m
.47771 .42409 L
s
.47652 .42333 m
.47753 .42406 L
s
.47663 .42333 m
.47764 .42406 L
s
.40046 .42613 m
.40129 .4254 L
s
.17806 .52678 m
.17795 .52637 L
s
.62384 .42227 m
.62393 .42273 L
s
.47649 .4233 m
.4775 .42404 L
s
.16268 .43582 m
.16265 .43546 L
s
.35415 .42981 m
.35436 .42917 L
s
.62368 .42224 m
.62376 .4227 L
s
.3542 .42979 m
.35441 .42915 L
s
.40056 .42607 m
.4014 .42534 L
s
.71487 .41489 m
.71491 .41527 L
s
.40054 .42602 m
.40138 .4253 L
s
.16263 .43575 m
.16261 .43539 L
s
.47641 .42321 m
.47742 .42394 L
s
.40055 .42601 m
.40138 .42529 L
s
.5231 .41995 m
.52345 .42059 L
s
.27277 .42682 m
.27281 .42633 L
s
.35416 .42969 m
.35436 .42905 L
s
.40061 .42597 m
.40145 .42525 L
s
.52304 .41992 m
.52339 .42056 L
s
.52317 .41989 m
.52352 .42053 L
s
.40062 .42595 m
.40147 .42522 L
s
.47634 .42315 m
.47735 .42387 L
s
.8382 .26817 m
.83835 .2684 L
s
.4007 .42592 m
.40154 .4252 L
s
.47635 .42313 m
.47736 .42385 L
s
.71486 .41479 m
.7149 .41517 L
s
.52291 .41987 m
.52327 .42051 L
s
.4763 .42311 m
.47733 .42384 L
s
.35424 .42959 m
.35445 .42896 L
s
.27269 .42671 m
.27273 .42622 L
s
.4762 .42309 m
.47722 .42382 L
s
.4007 .42588 m
.40155 .42515 L
s
.35423 .42957 m
.35444 .42893 L
s
.52295 .41981 m
.5233 .42045 L
s
.62362 .42201 m
.62371 .42246 L
s
.62369 .42201 m
.62377 .42246 L
s
.40075 .42583 m
.40159 .42511 L
s
.40084 .42581 m
.40169 .42509 L
s
.52292 .41978 m
.52327 .42041 L
s
.52287 .41978 m
.52323 .42041 L
s
.35423 .42951 m
.35445 .42887 L
s
.47611 .42299 m
.47714 .42371 L
s
.40084 .42576 m
.40169 .42504 L
s
.40084 .42576 m
.40169 .42504 L
s
.40086 .42575 m
.40171 .42503 L
s
.35427 .42944 m
.35448 .42881 L
s
.40084 .42573 m
.40169 .42501 L
s
.52297 .41968 m
.52332 .42031 L
s
.40087 .42572 m
.40173 .425 L
s
.27268 .42655 m
.27272 .42606 L
s
.40092 .42571 m
.40178 .42499 L
s
.16265 .43546 m
.16263 .43509 L
s
.4761 .42293 m
.47713 .42365 L
s
.40095 .4257 m
.40181 .42498 L
s
.35432 .42941 m
.35453 .42877 L
s
.17795 .52637 m
.17784 .52595 L
s
.47601 .42291 m
.47704 .42363 L
s
.35434 .42939 m
.35455 .42875 L
s
.47608 .42291 m
.47711 .42363 L
s
.83805 .26794 m
.8382 .26817 L
s
.47601 .42289 m
.47704 .42361 L
s
.47597 .42288 m
.477 .42361 L
s
.47587 .42288 m
.4769 .4236 L
s
.62376 .42182 m
.62384 .42227 L
s
.47598 .42287 m
.47702 .42359 L
s
.16261 .43539 m
.16258 .43502 L
s
.71483 .41452 m
.71487 .41489 L
s
.6236 .42179 m
.62368 .42224 L
s
.40101 .42561 m
.40187 .4249 L
s
.40102 .42561 m
.40188 .4249 L
s
.52276 .41961 m
.52312 .42025 L
s
.47583 .42283 m
.47687 .42355 L
s
.52276 .41957 m
.52312 .42021 L
s
.40112 .42555 m
.40198 .42483 L
s
.47578 .42279 m
.47682 .4235 L
s
.40116 .42555 m
.40202 .42483 L
s
.35432 .42925 m
.35454 .42861 L
s
.71482 .41442 m
.71486 .41479 L
s
.40111 .42551 m
.40198 .42479 L
s
.40114 .42551 m
.40201 .42479 L
s
.27281 .42633 m
.27285 .42584 L
s
.40122 .42549 m
.40209 .42477 L
s
.40117 .42549 m
.40204 .42477 L
s
.47574 .42273 m
.47678 .42344 L
s
.47567 .42271 m
.47671 .42342 L
s
.47555 .4227 m
.4766 .42341 L
s
.35436 .42917 m
.35458 .42853 L
s
.47564 .42269 m
.47668 .42341 L
s
.47567 .42268 m
.47671 .4234 L
s
.35441 .42915 m
.35463 .42851 L
s
.47568 .42266 m
.47672 .42338 L
s
.40129 .4254 m
.40216 .42469 L
s
.8379 .2677 m
.83805 .26794 L
s
.47566 .42264 m
.47671 .42335 L
s
.27273 .42622 m
.27277 .42573 L
s
.62354 .42155 m
.62362 .42201 L
s
.6236 .42155 m
.62369 .42201 L
s
.47547 .42262 m
.47652 .42333 L
s
.47558 .42261 m
.47663 .42333 L
s
.4014 .42534 m
.40227 .42463 L
s
.35436 .42905 m
.35458 .42842 L
s
.47544 .42259 m
.47649 .4233 L
s
.52274 .41932 m
.5231 .41995 L
s
.16263 .43509 m
.16261 .43472 L
s
.40138 .4253 m
.40225 .42459 L
s
.40138 .42529 m
.40226 .42458 L
s
.52268 .41929 m
.52304 .41992 L
s
.52281 .41926 m
.52317 .41989 L
s
.17784 .52595 m
.17773 .52554 L
s
.40145 .42525 m
.40233 .42454 L
s
.16258 .43502 m
.16256 .43465 L
s
.35445 .42896 m
.35467 .42832 L
s
.47535 .4225 m
.47641 .42321 L
s
.52255 .41924 m
.52291 .41987 L
s
.71479 .41414 m
.71483 .41452 L
s
.40147 .42522 m
.40235 .42451 L
s
.27272 .42606 m
.27276 .42557 L
s
.35444 .42893 m
.35466 .4283 L
s
.40154 .4252 m
.40242 .42449 L
s
.62367 .42137 m
.62376 .42182 L
s
.52258 .41918 m
.52295 .41981 L
s
.47528 .42244 m
.47634 .42315 L
s
.40155 .42515 m
.40243 .42444 L
s
.62351 .42133 m
.6236 .42179 L
s
.35445 .42887 m
.35467 .42824 L
s
.47529 .42242 m
.47635 .42313 L
s
.47524 .4224 m
.4763 .42311 L
s
.52255 .41915 m
.52292 .41978 L
s
.5225 .41915 m
.52287 .41978 L
s
.71478 .41404 m
.71482 .41442 L
s
.40159 .42511 m
.40248 .4244 L
s
.83774 .26747 m
.8379 .2677 L
s
.47513 .42238 m
.4762 .42309 L
s
.40169 .42509 m
.40257 .42438 L
s
.35448 .42881 m
.35471 .42817 L
s
.35453 .42877 m
.35476 .42814 L
s
.40169 .42504 m
.40258 .42434 L
s
.5226 .41905 m
.52297 .41968 L
s
.40169 .42504 m
.40258 .42433 L
s
.35455 .42875 m
.35478 .42812 L
s
.40171 .42503 m
.40259 .42432 L
s
.40169 .42501 m
.40258 .4243 L
s
.40173 .425 m
.40262 .4243 L
s
.47504 .42228 m
.47611 .42299 L
s
.40178 .42499 m
.40267 .42429 L
s
.27285 .42584 m
.2729 .42535 L
s
.40181 .42498 m
.4027 .42428 L
s
.52239 .41898 m
.52276 .41961 L
s
.47503 .42223 m
.4761 .42293 L
s
.16261 .43472 m
.16258 .43435 L
s
.47494 .42221 m
.47601 .42291 L
s
.62345 .4211 m
.62354 .42155 L
s
.47501 .42221 m
.47608 .42291 L
s
.62351 .4211 m
.6236 .42155 L
s
.40187 .4249 m
.40277 .42419 L
s
.40188 .4249 m
.40277 .42419 L
s
.52238 .41894 m
.52276 .41957 L
s
.47494 .42219 m
.47601 .42289 L
s
.4749 .42218 m
.47597 .42288 L
s
.35454 .42861 m
.35477 .42798 L
s
.47479 .42218 m
.47587 .42288 L
s
.27277 .42573 m
.27282 .42524 L
s
.47491 .42217 m
.47598 .42287 L
s
.16256 .43465 m
.16254 .43428 L
s
.40198 .42483 m
.40288 .42413 L
s
.83759 .26724 m
.83774 .26747 L
s
.40202 .42483 m
.40292 .42413 L
s
.71475 .41377 m
.71479 .41414 L
s
.17773 .52554 m
.17762 .52512 L
s
.47475 .42213 m
.47583 .42283 L
s
.35458 .42853 m
.35481 .4279 L
s
.40198 .42479 m
.40288 .42409 L
s
.40201 .42479 m
.40291 .42409 L
s
.35463 .42851 m
.35486 .42788 L
s
.47471 .42209 m
.47578 .42279 L
s
.40209 .42477 m
.40299 .42407 L
s
.40204 .42477 m
.40294 .42407 L
s
.71474 .41367 m
.71478 .41404 L
s
.62358 .42091 m
.62367 .42137 L
s
.47466 .42203 m
.47574 .42273 L
s
.27276 .42557 m
.27281 .42508 L
s
.47459 .42201 m
.47567 .42271 L
s
.40216 .42469 m
.40307 .42399 L
s
.47447 .42201 m
.47555 .4227 L
s
.35458 .42842 m
.35481 .42778 L
s
.47455 .422 m
.47564 .42269 L
s
.62342 .42088 m
.62351 .42133 L
s
.47459 .42199 m
.47567 .42268 L
s
.52237 .41869 m
.52274 .41932 L
s
.4746 .42197 m
.47568 .42266 L
s
.40227 .42463 m
.40318 .42394 L
s
.47458 .42195 m
.47566 .42264 L
s
.5223 .41866 m
.52268 .41929 L
s
.52244 .41863 m
.52281 .41926 L
s
.47438 .42193 m
.47547 .42262 L
s
.4745 .42192 m
.47558 .42261 L
s
.40225 .42459 m
.40316 .42389 L
s
.35467 .42832 m
.35491 .42769 L
s
.40226 .42458 m
.40317 .42388 L
s
.47435 .4219 m
.47544 .42259 L
s
.35466 .4283 m
.35489 .42766 L
s
.83744 .267 m
.83759 .26724 L
s
.52217 .41861 m
.52255 .41924 L
s
.40233 .42454 m
.40325 .42385 L
s
.16258 .43435 m
.16256 .43398 L
s
.40235 .42451 m
.40326 .42382 L
s
.52221 .41855 m
.52258 .41918 L
s
.35467 .42824 m
.35491 .4276 L
s
.40242 .42449 m
.40334 .4238 L
s
.2729 .42535 m
.27295 .42486 L
s
.47426 .42181 m
.47535 .4225 L
s
.16254 .43428 m
.16252 .43391 L
s
.40243 .42444 m
.40335 .42375 L
s
.52217 .41852 m
.52255 .41915 L
s
.52212 .41852 m
.5225 .41915 L
s
.62335 .42064 m
.62345 .4211 L
s
.62341 .42065 m
.62351 .4211 L
s
.35471 .42817 m
.35495 .42754 L
s
.7147 .41339 m
.71475 .41377 L
s
.40248 .4244 m
.4034 .42371 L
s
.35476 .42814 m
.35499 .4275 L
s
.47418 .42175 m
.47528 .42244 L
s
.17762 .52512 m
.17751 .52471 L
s
.47419 .42174 m
.47529 .42242 L
s
.40257 .42438 m
.40349 .42369 L
s
.35478 .42812 m
.35502 .42748 L
s
.52222 .41842 m
.5226 .41905 L
s
.27282 .42524 m
.27287 .42475 L
s
.47415 .42172 m
.47524 .4224 L
s
.47403 .4217 m
.47513 .42238 L
s
.40258 .42434 m
.40351 .42365 L
s
.40258 .42433 m
.4035 .42364 L
s
.40259 .42432 m
.40352 .42363 L
s
.71469 .4133 m
.71474 .41367 L
s
.40258 .4243 m
.4035 .42361 L
s
.40262 .4243 m
.40355 .42361 L
s
.40267 .42429 m
.4036 .4236 L
s
.4027 .42428 m
.40363 .42359 L
s
.83728 .26677 m
.83744 .267 L
s
.522 .41835 m
.52239 .41898 L
s
.62349 .42046 m
.62358 .42091 L
s
.47394 .4216 m
.47504 .42228 L
s
.35477 .42798 m
.35501 .42734 L
s
.522 .41832 m
.52238 .41894 L
s
.62332 .42043 m
.62342 .42088 L
s
.27281 .42508 m
.27286 .42459 L
s
.40277 .42419 m
.4037 .42351 L
s
.40277 .42419 m
.40371 .42351 L
s
.47393 .42155 m
.47503 .42223 L
s
.47384 .42153 m
.47494 .42221 L
s
.35481 .4279 m
.35505 .42726 L
s
.4739 .42153 m
.47501 .42221 L
s
.16256 .43398 m
.16254 .43361 L
s
.40288 .42413 m
.40382 .42345 L
s
.47383 .42151 m
.47494 .42219 L
s
.35486 .42788 m
.3551 .42724 L
s
.40292 .42413 m
.40386 .42344 L
s
.47379 .42151 m
.4749 .42218 L
s
.47368 .4215 m
.47479 .42218 L
s
.4738 .42149 m
.47491 .42217 L
s
.40288 .42409 m
.40381 .42341 L
s
.40291 .42409 m
.40385 .42341 L
s
.40299 .42407 m
.40393 .42339 L
s
.40294 .42407 m
.40388 .42339 L
s
.47364 .42146 m
.47475 .42213 L
s
.16252 .43391 m
.1625 .43354 L
s
.35481 .42778 m
.35506 .42715 L
s
.47359 .42142 m
.47471 .42209 L
s
.71466 .41302 m
.7147 .41339 L
s
.83713 .26654 m
.83728 .26677 L
s
.40307 .42399 m
.40401 .42331 L
s
.27295 .42486 m
.273 .42437 L
s
.52198 .41806 m
.52237 .41869 L
s
.62326 .42019 m
.62335 .42064 L
s
.62332 .42019 m
.62341 .42065 L
s
.17751 .52471 m
.17741 .52429 L
s
.47354 .42136 m
.47466 .42203 L
s
.47347 .42134 m
.47459 .42201 L
s
.35491 .42769 m
.35516 .42705 L
s
.40318 .42394 m
.40413 .42326 L
s
.47334 .42134 m
.47447 .42201 L
s
.47343 .42133 m
.47455 .422 L
s
.52191 .41803 m
.5223 .41866 L
s
.52205 .41801 m
.52244 .41863 L
s
.47347 .42132 m
.47459 .42199 L
s
.71465 .41292 m
.71469 .4133 L
s
.35489 .42766 m
.35514 .42703 L
s
.40316 .42389 m
.40411 .42321 L
s
.47348 .4213 m
.4746 .42197 L
s
.40317 .42388 m
.40412 .4232 L
s
.52178 .41799 m
.52217 .41861 L
s
.47346 .42128 m
.47458 .42195 L
s
.27287 .42475 m
.27292 .42426 L
s
.47325 .42126 m
.47438 .42193 L
s
.35491 .4276 m
.35516 .42697 L
s
.40325 .42385 m
.4042 .42317 L
s
.47337 .42125 m
.4745 .42192 L
s
.40326 .42382 m
.40422 .42314 L
s
.52181 .41793 m
.52221 .41855 L
s
.47322 .42124 m
.47435 .4219 L
s
.40334 .4238 m
.4043 .42312 L
s
.35495 .42754 m
.3552 .4269 L
s
.62339 .42 m
.62349 .42046 L
s
.52177 .41789 m
.52217 .41852 L
s
.52172 .41789 m
.52212 .41852 L
s
.35499 .4275 m
.35524 .42687 L
s
.40335 .42375 m
.40431 .42307 L
s
.16254 .43361 m
.16253 .43324 L
s
.62322 .41997 m
.62332 .42043 L
s
.35502 .42748 m
.35527 .42685 L
s
.83697 .2663 m
.83713 .26654 L
s
.47312 .42115 m
.47426 .42181 L
s
.4034 .42371 m
.40437 .42303 L
s
.27286 .42459 m
.27292 .4241 L
s
.52183 .41779 m
.52222 .41842 L
s
.40349 .42369 m
.40445 .42301 L
s
.1625 .43354 m
.16248 .43317 L
s
.47305 .42109 m
.47418 .42175 L
s
.40351 .42365 m
.40447 .42297 L
s
.47306 .42108 m
.47419 .42174 L
s
.4035 .42364 m
.40447 .42297 L
s
.40352 .42363 m
.40448 .42296 L
s
.47301 .42106 m
.47415 .42172 L
s
.71461 .41265 m
.71466 .41302 L
s
.4035 .42361 m
.40447 .42294 L
s
.40355 .42361 m
.40451 .42293 L
s
.47289 .42104 m
.47403 .4217 L
s
.4036 .4236 m
.40457 .42293 L
s
.40363 .42359 m
.4046 .42292 L
s
.35501 .42734 m
.35526 .42671 L
s
.5216 .41773 m
.522 .41835 L
s
.5216 .41769 m
.522 .41832 L
s
.17741 .52429 m
.17731 .52388 L
s
.7146 .41255 m
.71465 .41292 L
s
.4037 .42351 m
.40468 .42283 L
s
.40371 .42351 m
.40468 .42283 L
s
.35505 .42726 m
.35531 .42663 L
s
.4728 .42094 m
.47394 .4216 L
s
.62316 .41974 m
.62326 .42019 L
s
.62322 .41974 m
.62332 .42019 L
s
.3551 .42724 m
.35536 .42661 L
s
.273 .42437 m
.27306 .42388 L
s
.40382 .42345 m
.40479 .42278 L
s
.83682 .26607 m
.83697 .2663 L
s
.40386 .42344 m
.40483 .42278 L
s
.47278 .42089 m
.47393 .42155 L
s
.47269 .42087 m
.47384 .42153 L
s
.47275 .42087 m
.4739 .42153 L
s
.40381 .42341 m
.40479 .42274 L
s
.40385 .42341 m
.40483 .42274 L
s
.47268 .42085 m
.47383 .42151 L
s
.47264 .42085 m
.47379 .42151 L
s
.40393 .42339 m
.40491 .42272 L
s
.47253 .42085 m
.47368 .4215 L
s
.40388 .42339 m
.40485 .42272 L
s
.35506 .42715 m
.35531 .42652 L
s
.47265 .42083 m
.4738 .42149 L
s
.27292 .42426 m
.27298 .42377 L
s
.16253 .43324 m
.16251 .43287 L
s
.47249 .42081 m
.47364 .42146 L
s
.40401 .42331 m
.405 .42265 L
s
.62329 .41955 m
.62339 .42 L
s
.52158 .41744 m
.52198 .41806 L
s
.47243 .42076 m
.47359 .42142 L
s
.35516 .42705 m
.35542 .42642 L
s
.62312 .41952 m
.62322 .41997 L
s
.16248 .43317 m
.16247 .4328 L
s
.35514 .42703 m
.3554 .4264 L
s
.40413 .42326 m
.40511 .42259 L
s
.52151 .41741 m
.52191 .41803 L
s
.52165 .41738 m
.52205 .41801 L
s
.47238 .42071 m
.47354 .42136 L
s
.71456 .41227 m
.71461 .41265 L
s
.47232 .42069 m
.47347 .42134 L
s
.40411 .42321 m
.4051 .42255 L
s
.47218 .42069 m
.47334 .42134 L
s
.40412 .4232 m
.40511 .42254 L
s
.35516 .42697 m
.35542 .42634 L
s
.47227 .42068 m
.47343 .42133 L
s
.52137 .41736 m
.52178 .41799 L
s
.47231 .42067 m
.47347 .42132 L
s
.27292 .4241 m
.27298 .42361 L
s
.4042 .42317 m
.40519 .42251 L
s
.83666 .26584 m
.83682 .26607 L
s
.47232 .42065 m
.47348 .4213 L
s
.40422 .42314 m
.40521 .42248 L
s
.52141 .4173 m
.52181 .41793 L
s
.4723 .42063 m
.47346 .42128 L
s
.3552 .4269 m
.35546 .42627 L
s
.4043 .42312 m
.4053 .42246 L
s
.47209 .42061 m
.47325 .42126 L
s
.47221 .42061 m
.47337 .42125 L
s
.71455 .41217 m
.7146 .41255 L
s
.35524 .42687 m
.35551 .42624 L
s
.17731 .52388 m
.1772 .52346 L
s
.47206 .42059 m
.47322 .42124 L
s
.52137 .41727 m
.52177 .41789 L
s
.52131 .41727 m
.52172 .41789 L
s
.35527 .42685 m
.35554 .42622 L
s
.40431 .42307 m
.4053 .42241 L
s
.40437 .42303 m
.40537 .42238 L
s
.62305 .41928 m
.62316 .41974 L
s
.62312 .41928 m
.62322 .41974 L
s
.52142 .41717 m
.52183 .41779 L
s
.40445 .42301 m
.40545 .42236 L
s
.47196 .42051 m
.47312 .42115 L
s
.40447 .42297 m
.40547 .42232 L
s
.40447 .42297 m
.40546 .42231 L
s
.27306 .42388 m
.27312 .42339 L
s
.40448 .42296 m
.40548 .4223 L
s
.16251 .43287 m
.1625 .4325 L
s
.40447 .42294 m
.40547 .42229 L
s
.35526 .42671 m
.35553 .42608 L
s
.40451 .42293 m
.40552 .42228 L
s
.47188 .42045 m
.47305 .42109 L
s
.40457 .42293 m
.40557 .42227 L
s
.47189 .42044 m
.47306 .42108 L
s
.4046 .42292 m
.40561 .42226 L
s
.47184 .42042 m
.47301 .42106 L
s
.52119 .41711 m
.5216 .41773 L
s
.8365 .26561 m
.83666 .26584 L
s
.47172 .42041 m
.47289 .42104 L
s
.16247 .4328 m
.16245 .43243 L
s
.52119 .41707 m
.5216 .41769 L
s
.35531 .42663 m
.35558 .426 L
s
.27298 .42377 m
.27304 .42328 L
s
.35536 .42661 m
.35563 .42598 L
s
.40468 .42283 m
.40568 .42218 L
s
.40468 .42283 m
.40569 .42218 L
s
.62318 .4191 m
.62329 .41955 L
s
.71451 .4119 m
.71456 .41227 L
s
.62301 .41906 m
.62312 .41952 L
s
.47162 .42031 m
.4728 .42094 L
s
.40479 .42278 m
.4058 .42212 L
s
.40483 .42278 m
.40584 .42212 L
s
.40479 .42274 m
.4058 .42209 L
s
.40483 .42274 m
.40584 .42209 L
s
.35531 .42652 m
.35558 .42589 L
s
.40491 .42272 m
.40593 .42208 L
s
.47161 .42026 m
.47278 .42089 L
s
.40485 .42272 m
.40587 .42207 L
s
.7145 .4118 m
.71455 .41217 L
s
.47151 .42024 m
.47269 .42087 L
s
.47157 .42024 m
.47275 .42087 L
s
.4715 .42022 m
.47268 .42085 L
s
.47145 .42022 m
.47264 .42085 L
s
.27298 .42361 m
.27304 .42312 L
s
.47135 .42022 m
.47253 .42085 L
s
.1772 .52346 m
.1771 .52304 L
s
.47147 .4202 m
.47265 .42083 L
s
.405 .42265 m
.40602 .422 L
s
.35542 .42642 m
.35569 .42579 L
s
.52116 .41682 m
.52158 .41744 L
s
.4713 .42018 m
.47249 .42081 L
s
.3554 .4264 m
.35567 .42577 L
s
.83635 .26538 m
.8365 .26561 L
s
.40511 .42259 m
.40613 .42195 L
s
.47125 .42014 m
.47243 .42076 L
s
.52109 .41679 m
.52151 .41741 L
s
.52123 .41677 m
.52165 .41738 L
s
.35542 .42634 m
.3557 .42571 L
s
.62295 .41883 m
.62305 .41928 L
s
.1625 .4325 m
.16248 .43213 L
s
.62301 .41883 m
.62312 .41928 L
s
.4051 .42255 m
.40612 .4219 L
s
.40511 .42254 m
.40613 .4219 L
s
.52095 .41674 m
.52137 .41736 L
s
.47119 .42008 m
.47238 .42071 L
s
.40519 .42251 m
.40622 .42186 L
s
.47113 .42007 m
.47232 .42069 L
s
.47099 .42007 m
.47218 .42069 L
s
.47108 .42006 m
.47227 .42068 L
s
.35546 .42627 m
.35574 .42564 L
s
.40521 .42248 m
.40624 .42184 L
s
.47112 .42005 m
.47231 .42067 L
s
.16245 .43243 m
.16244 .43206 L
s
.52099 .41668 m
.52141 .4173 L
s
.4053 .42246 m
.40633 .42182 L
s
.35551 .42624 m
.35578 .42561 L
s
.47113 .42003 m
.47232 .42065 L
s
.27312 .42339 m
.27318 .42289 L
s
.35554 .42622 m
.35582 .42559 L
s
.47111 .42001 m
.4723 .42063 L
s
.47089 .41999 m
.47209 .42061 L
s
.52094 .41666 m
.52137 .41727 L
s
.52089 .41665 m
.52131 .41727 L
s
.71446 .41152 m
.71451 .4119 L
s
.4053 .42241 m
.40633 .42177 L
s
.47101 .41998 m
.47221 .42061 L
s
.47086 .41997 m
.47206 .42059 L
s
.40537 .42238 m
.4064 .42174 L
s
.62308 .41864 m
.62318 .4191 L
s
.40545 .42236 m
.40648 .42172 L
s
.521 .41655 m
.52142 .41717 L
s
.27304 .42328 m
.27311 .42279 L
s
.83619 .26514 m
.83635 .26538 L
s
.62291 .41861 m
.62301 .41906 L
s
.40547 .42232 m
.4065 .42168 L
s
.40546 .42231 m
.4065 .42167 L
s
.71445 .41142 m
.7145 .4118 L
s
.40548 .4223 m
.40652 .42167 L
s
.47075 .41989 m
.47196 .42051 L
s
.35553 .42608 m
.35581 .42545 L
s
.40547 .42229 m
.40651 .42165 L
s
.40552 .42228 m
.40655 .42164 L
s
.40557 .42227 m
.40661 .42164 L
s
.40561 .42226 m
.40665 .42163 L
s
.47068 .41984 m
.47188 .42045 L
s
.52076 .41649 m
.52119 .41711 L
s
.1771 .52304 m
.177 .52262 L
s
.47068 .41982 m
.47189 .42044 L
s
.35558 .426 m
.35586 .42537 L
s
.47063 .41981 m
.47184 .42042 L
s
.35563 .42598 m
.35592 .42535 L
s
.52076 .41646 m
.52119 .41707 L
s
.47051 .41979 m
.47172 .42041 L
s
.40568 .42218 m
.40673 .42155 L
s
.40569 .42218 m
.40673 .42155 L
s
.27304 .42312 m
.27311 .42263 L
s
.16248 .43213 m
.16247 .43176 L
s
.4058 .42212 m
.40685 .42149 L
s
.40584 .42212 m
.40689 .42149 L
s
.35558 .42589 m
.35587 .42526 L
s
.40584 .42209 m
.40689 .42146 L
s
.4058 .42209 m
.40685 .42146 L
s
.4704 .4197 m
.47162 .42031 L
s
.62283 .41838 m
.62295 .41883 L
s
.40593 .42208 m
.40698 .42145 L
s
.6229 .41838 m
.62301 .41883 L
s
.16244 .43206 m
.16243 .4317 L
s
.40587 .42207 m
.40691 .42144 L
s
.83603 .26491 m
.83619 .26514 L
s
.47039 .41965 m
.47161 .42026 L
s
.4703 .41963 m
.47151 .42024 L
s
.71441 .41115 m
.71446 .41152 L
s
.47036 .41963 m
.47157 .42024 L
s
.35569 .42579 m
.35598 .42517 L
s
.40602 .422 m
.40707 .42137 L
s
.47029 .41962 m
.4715 .42022 L
s
.47024 .41961 m
.47145 .42022 L
s
.47013 .41962 m
.47135 .42022 L
s
.35567 .42577 m
.35595 .42514 L
s
.47025 .4196 m
.47147 .4202 L
s
.40613 .42195 m
.40719 .42132 L
s
.52073 .41621 m
.52116 .41682 L
s
.27318 .42289 m
.27325 .4224 L
s
.47008 .41957 m
.4713 .42018 L
s
.3557 .42571 m
.35598 .42508 L
s
.52066 .41618 m
.52109 .41679 L
s
.40612 .4219 m
.40718 .42128 L
s
.5208 .41615 m
.52123 .41677 L
s
.71439 .41105 m
.71445 .41142 L
s
.40613 .4219 m
.40719 .42127 L
s
.47002 .41953 m
.47125 .42014 L
s
.62297 .41819 m
.62308 .41864 L
s
.40622 .42186 m
.40728 .42124 L
s
.52051 .41613 m
.52095 .41674 L
s
.62279 .41816 m
.62291 .41861 L
s
.35574 .42564 m
.35602 .42502 L
s
.40624 .42184 m
.4073 .42122 L
s
.46997 .41948 m
.47119 .42008 L
s
.27311 .42279 m
.27318 .4223 L
s
.40633 .42182 m
.4074 .4212 L
s
.4699 .41947 m
.47113 .42007 L
s
.46976 .41947 m
.47099 .42007 L
s
.35578 .42561 m
.35607 .42498 L
s
.46985 .41946 m
.47108 .42006 L
s
.52055 .41607 m
.52099 .41668 L
s
.46989 .41945 m
.47112 .42005 L
s
.35582 .42559 m
.35611 .42496 L
s
.177 .52262 m
.17691 .5222 L
s
.40633 .42177 m
.4074 .42115 L
s
.83587 .26468 m
.83603 .26491 L
s
.4699 .41943 m
.47113 .42003 L
s
.16247 .43176 m
.16246 .43139 L
s
.46988 .41941 m
.47111 .42001 L
s
.52051 .41604 m
.52094 .41666 L
s
.52045 .41604 m
.52089 .41665 L
s
.4064 .42174 m
.40747 .42111 L
s
.46966 .41939 m
.47089 .41999 L
s
.46978 .41939 m
.47101 .41998 L
s
.40648 .42172 m
.40755 .42109 L
s
.46962 .41938 m
.47086 .41997 L
s
.4065 .42168 m
.40757 .42106 L
s
.16243 .4317 m
.16242 .43133 L
s
.52056 .41594 m
.521 .41655 L
s
.4065 .42167 m
.40757 .42105 L
s
.40652 .42167 m
.40759 .42105 L
s
.27311 .42263 m
.27318 .42214 L
s
.40651 .42165 m
.40758 .42103 L
s
.35581 .42545 m
.35611 .42483 L
s
.40655 .42164 m
.40763 .42102 L
s
.40661 .42164 m
.40768 .42102 L
s
.40665 .42163 m
.40772 .42101 L
s
.46952 .41929 m
.47075 .41989 L
s
.62272 .41792 m
.62283 .41838 L
s
.71436 .41077 m
.71441 .41115 L
s
.62279 .41792 m
.6229 .41838 L
s
.35586 .42537 m
.35616 .42475 L
s
.46944 .41924 m
.47068 .41984 L
s
.52032 .41588 m
.52076 .41649 L
s
.35592 .42535 m
.35622 .42473 L
s
.40673 .42155 m
.40781 .42093 L
s
.46944 .41923 m
.47068 .41982 L
s
.40673 .42155 m
.40781 .42093 L
s
.46939 .41922 m
.47063 .41981 L
s
.52032 .41585 m
.52076 .41646 L
s
.46926 .4192 m
.47051 .41979 L
s
.40685 .42149 m
.40793 .42088 L
s
.71434 .41068 m
.71439 .41105 L
s
.40689 .42149 m
.40797 .42088 L
s
.83571 .26445 m
.83587 .26468 L
s
.40689 .42146 m
.40797 .42084 L
s
.40685 .42146 m
.40793 .42085 L
s
.40698 .42145 m
.40806 .42083 L
s
.35587 .42526 m
.35617 .42463 L
s
.40691 .42144 m
.408 .42082 L
s
.27325 .4224 m
.27333 .42191 L
s
.46916 .41911 m
.4704 .4197 L
s
.62285 .41774 m
.62297 .41819 L
s
.62268 .4177 m
.62279 .41816 L
s
.40707 .42137 m
.40816 .42076 L
s
.35598 .42517 m
.35628 .42454 L
s
.16246 .43139 m
.16245 .43102 L
s
.46915 .41907 m
.47039 .41965 L
s
.17691 .5222 m
.17681 .52178 L
s
.46905 .41905 m
.4703 .41963 L
s
.46911 .41905 m
.47036 .41963 L
s
.35595 .42514 m
.35625 .42451 L
s
.46904 .41903 m
.47029 .41962 L
s
.40719 .42132 m
.40828 .42071 L
s
.46899 .41903 m
.47024 .41961 L
s
.27318 .4223 m
.27325 .42181 L
s
.46887 .41904 m
.47013 .41962 L
s
.469 .41901 m
.47025 .4196 L
s
.16242 .43133 m
.16241 .43096 L
s
.40718 .42128 m
.40827 .42067 L
s
.52029 .4156 m
.52073 .41621 L
s
.40719 .42127 m
.40829 .42066 L
s
.35598 .42508 m
.35629 .42446 L
s
.46882 .41899 m
.47008 .41957 L
s
.40728 .42124 m
.40838 .42064 L
s
.52021 .41557 m
.52066 .41618 L
s
.52036 .41554 m
.5208 .41615 L
s
.46877 .41895 m
.47002 .41953 L
s
.4073 .42122 m
.4084 .42061 L
s
.83555 .26422 m
.83571 .26445 L
s
.4074 .4212 m
.4085 .42059 L
s
.35602 .42502 m
.35633 .42439 L
s
.7143 .4104 m
.71436 .41077 L
s
.52007 .41552 m
.52051 .41613 L
s
.35607 .42498 m
.35637 .42436 L
s
.46871 .4189 m
.46997 .41948 L
s
.46865 .41889 m
.4699 .41947 L
s
.4685 .41889 m
.46976 .41947 L
s
.35611 .42496 m
.35642 .42434 L
s
.27318 .42214 m
.27325 .42165 L
s
.4074 .42115 m
.4085 .42054 L
s
.46859 .41888 m
.46985 .41946 L
s
.46863 .41887 m
.46989 .41945 L
s
.6226 .41747 m
.62272 .41792 L
s
.62267 .41747 m
.62279 .41792 L
s
.5201 .41546 m
.52055 .41607 L
s
.40747 .42111 m
.40857 .42051 L
s
.46864 .41885 m
.4699 .41943 L
s
.40755 .42109 m
.40865 .42049 L
s
.46862 .41884 m
.46988 .41941 L
s
.71428 .4103 m
.71434 .41068 L
s
.46839 .41882 m
.46966 .41939 L
s
.52006 .41543 m
.52051 .41604 L
s
.52 .41543 m
.52045 .41604 L
s
.40757 .42106 m
.40868 .42046 L
s
.46852 .41881 m
.46978 .41939 L
s
.40757 .42105 m
.40867 .42045 L
s
.46836 .41881 m
.46962 .41938 L
s
.40759 .42105 m
.40869 .42045 L
s
.40758 .42103 m
.40868 .42043 L
s
.40763 .42102 m
.40873 .42042 L
s
.40768 .42102 m
.40879 .42042 L
s
.40772 .42101 m
.40883 .42041 L
s
.35611 .42483 m
.35641 .4242 L
s
.52011 .41533 m
.52056 .41594 L
s
.46825 .41873 m
.46952 .41929 L
s
.16245 .43102 m
.16245 .43065 L
s
.62273 .41729 m
.62285 .41774 L
s
.40781 .42093 m
.40892 .42033 L
s
.40781 .42093 m
.40892 .42033 L
s
.83539 .26399 m
.83555 .26422 L
s
.35616 .42475 m
.35647 .42412 L
s
.27333 .42191 m
.2734 .42142 L
s
.17681 .52178 m
.17671 .52136 L
s
.35622 .42473 m
.35653 .4241 L
s
.46817 .41868 m
.46944 .41924 L
s
.62256 .41725 m
.62268 .4177 L
s
.46817 .41867 m
.46944 .41923 L
s
.51987 .41527 m
.52032 .41588 L
s
.40793 .42088 m
.40904 .42028 L
s
.16241 .43096 m
.1624 .43059 L
s
.40797 .42088 m
.40908 .42028 L
s
.46811 .41865 m
.46939 .41922 L
s
.46799 .41864 m
.46926 .4192 L
s
.40797 .42084 m
.40908 .42025 L
s
.51987 .41524 m
.52032 .41585 L
s
.40793 .42085 m
.40904 .42025 L
s
.40806 .42083 m
.40918 .42024 L
s
.408 .42082 m
.40911 .42023 L
s
.27325 .42181 m
.27333 .42132 L
s
.35617 .42463 m
.35648 .42401 L
s
.71424 .41003 m
.7143 .4104 L
s
.46788 .41855 m
.46916 .41911 L
s
.40816 .42076 m
.40928 .42017 L
s
.35628 .42454 m
.3566 .42392 L
s
.40828 .42071 m
.4094 .42012 L
s
.46787 .41851 m
.46915 .41907 L
s
.46777 .41849 m
.46905 .41905 L
s
.46783 .41849 m
.46911 .41905 L
s
.35625 .42451 m
.35656 .42389 L
s
.71423 .40993 m
.71428 .4103 L
s
.46776 .41848 m
.46904 .41903 L
s
.4677 .41848 m
.46899 .41903 L
s
.46759 .41848 m
.46887 .41904 L
s
.40827 .42067 m
.40939 .42008 L
s
.40829 .42066 m
.40941 .42007 L
s
.62248 .41702 m
.6226 .41747 L
s
.62255 .41702 m
.62267 .41747 L
s
.46771 .41846 m
.469 .41901 L
s
.83523 .26376 m
.83539 .26399 L
s
.27325 .42165 m
.27333 .42116 L
s
.40838 .42064 m
.40951 .42005 L
s
.35629 .42446 m
.3566 .42384 L
s
.4084 .42061 m
.40953 .42003 L
s
.46754 .41844 m
.46882 .41899 L
s
.51983 .41499 m
.52029 .4156 L
s
.4085 .42059 m
.40963 .42001 L
s
.46748 .4184 m
.46877 .41895 L
s
.51975 .41496 m
.52021 .41557 L
s
.35633 .42439 m
.35664 .42377 L
s
.5199 .41493 m
.52036 .41554 L
s
.16245 .43065 m
.16244 .43028 L
s
.4085 .42054 m
.40963 .41996 L
s
.35637 .42436 m
.35669 .42373 L
s
.46742 .41835 m
.46871 .4189 L
s
.4672 .41835 m
.4685 .41889 L
s
.46736 .41834 m
.46865 .41889 L
s
.40857 .42051 m
.40971 .41993 L
s
.51961 .41491 m
.52007 .41552 L
s
.35642 .42434 m
.35674 .42372 L
s
.4673 .41833 m
.46859 .41888 L
s
.46735 .41832 m
.46863 .41887 L
s
.40865 .42049 m
.40979 .41991 L
s
.1624 .43059 m
.1624 .43022 L
s
.17671 .52136 m
.17662 .52094 L
s
.46736 .4183 m
.46864 .41885 L
s
.62261 .41683 m
.62273 .41729 L
s
.40868 .42046 m
.40981 .41988 L
s
.51964 .41485 m
.5201 .41546 L
s
.46733 .41829 m
.46862 .41884 L
s
.40867 .42045 m
.40981 .41987 L
s
.40869 .42045 m
.40983 .41986 L
s
.4671 .41828 m
.46839 .41882 L
s
.40868 .42043 m
.40982 .41985 L
s
.40873 .42042 m
.40987 .41985 L
s
.62244 .4168 m
.62256 .41725 L
s
.46723 .41827 m
.46852 .41881 L
s
.40879 .42042 m
.40993 .41984 L
s
.40883 .42041 m
.40997 .41983 L
s
.46706 .41826 m
.46836 .41881 L
s
.2734 .42142 m
.27348 .42093 L
s
.5196 .41483 m
.52006 .41543 L
s
.51954 .41482 m
.52 .41543 L
s
.71418 .40965 m
.71424 .41003 L
s
.83506 .26353 m
.83523 .26376 L
s
.35641 .4242 m
.35673 .42358 L
s
.40892 .42033 m
.41007 .41976 L
s
.40892 .42033 m
.41007 .41976 L
s
.51965 .41472 m
.52011 .41533 L
s
.46695 .41818 m
.46825 .41873 L
s
.27333 .42132 m
.27341 .42083 L
s
.40904 .42028 m
.41019 .41971 L
s
.40908 .42028 m
.41023 .41971 L
s
.35647 .42412 m
.35679 .4235 L
s
.46688 .41814 m
.46817 .41868 L
s
.71417 .40955 m
.71423 .40993 L
s
.35653 .4241 m
.35685 .42348 L
s
.46688 .41813 m
.46817 .41867 L
s
.40908 .42025 m
.41023 .41968 L
s
.40904 .42025 m
.41019 .41968 L
s
.40918 .42024 m
.41033 .41967 L
s
.46681 .41811 m
.46811 .41865 L
s
.46668 .41811 m
.46799 .41864 L
s
.40911 .42023 m
.41026 .41966 L
s
.5194 .41467 m
.51987 .41527 L
s
.62236 .41657 m
.62248 .41702 L
s
.62243 .41657 m
.62255 .41702 L
s
.5194 .41463 m
.51987 .41524 L
s
.40928 .42017 m
.41044 .4196 L
s
.35648 .42401 m
.3568 .42339 L
s
.16244 .43028 m
.16244 .42991 L
s
.46657 .41802 m
.46788 .41855 L
s
.27333 .42116 m
.27342 .42067 L
s
.4094 .42012 m
.41056 .41955 L
s
.40939 .42008 m
.41055 .41951 L
s
.8349 .2633 m
.83506 .26353 L
s
.46656 .41798 m
.46787 .41851 L
s
.40941 .42007 m
.41057 .41951 L
s
.1624 .43022 m
.16239 .42985 L
s
.3566 .42392 m
.35692 .4233 L
s
.46647 .41796 m
.46777 .41849 L
s
.46652 .41796 m
.46783 .41849 L
s
.46645 .41795 m
.46776 .41848 L
s
.46628 .41795 m
.46759 .41848 L
s
.40951 .42005 m
.41067 .41948 L
s
.46639 .41795 m
.4677 .41848 L
s
.35656 .42389 m
.35689 .42327 L
s
.40953 .42003 m
.4107 .41946 L
s
.17662 .52094 m
.17653 .52052 L
s
.4664 .41793 m
.46771 .41846 L
s
.40963 .42001 m
.41079 .41945 L
s
.46622 .41791 m
.46754 .41844 L
s
.62249 .41638 m
.62261 .41683 L
s
.3566 .42384 m
.35693 .42321 L
s
.71412 .40928 m
.71418 .40965 L
s
.46616 .41787 m
.46748 .4184 L
s
.40963 .41996 m
.4108 .4194 L
s
.62232 .41635 m
.62244 .4168 L
s
.51936 .41438 m
.51983 .41499 L
s
.40971 .41993 m
.41088 .41937 L
s
.35664 .42377 m
.35697 .42315 L
s
.40979 .41991 m
.41096 .41935 L
s
.4661 .41783 m
.46742 .41835 L
s
.46588 .41783 m
.4672 .41835 L
s
.46604 .41782 m
.46736 .41834 L
s
.27348 .42093 m
.27357 .42044 L
s
.51928 .41436 m
.51975 .41496 L
s
.51944 .41433 m
.5199 .41493 L
s
.46599 .41781 m
.4673 .41833 L
s
.35669 .42373 m
.35702 .42311 L
s
.40981 .41988 m
.41098 .41932 L
s
.46603 .4178 m
.46735 .41832 L
s
.40981 .41987 m
.41098 .41931 L
s
.35674 .42372 m
.35707 .4231 L
s
.40983 .41986 m
.411 .41931 L
s
.71411 .40918 m
.71417 .40955 L
s
.40982 .41985 m
.41099 .41929 L
s
.46604 .41778 m
.46736 .4183 L
s
.40987 .41985 m
.41104 .41929 L
s
.40993 .41984 m
.4111 .41928 L
s
.40997 .41983 m
.41115 .41928 L
s
.51913 .41431 m
.51961 .41491 L
s
.46601 .41777 m
.46733 .41829 L
s
.46578 .41776 m
.4671 .41828 L
s
.46591 .41775 m
.46723 .41827 L
s
.46574 .41774 m
.46706 .41826 L
s
.83474 .26307 m
.8349 .2633 L
s
.51917 .41425 m
.51964 .41485 L
s
.27341 .42083 m
.2735 .42034 L
s
.41007 .41976 m
.41124 .4192 L
s
.41007 .41976 m
.41124 .4192 L
s
.16244 .42991 m
.16243 .42954 L
s
.51912 .41422 m
.5196 .41483 L
s
.51907 .41422 m
.51954 .41482 L
s
.35673 .42358 m
.35707 .42296 L
s
.46562 .41767 m
.46695 .41818 L
s
.41019 .41971 m
.41136 .41915 L
s
.41023 .41971 m
.41141 .41915 L
s
.62223 .41611 m
.62236 .41657 L
s
.6223 .41611 m
.62243 .41657 L
s
.41023 .41968 m
.41141 .41913 L
s
.41019 .41968 m
.41137 .41912 L
s
.41033 .41967 m
.41152 .41912 L
s
.16239 .42985 m
.16239 .42948 L
s
.46555 .41763 m
.46688 .41814 L
s
.51918 .41412 m
.51965 .41472 L
s
.46555 .41762 m
.46688 .41813 L
s
.41026 .41966 m
.41144 .4191 L
s
.46548 .4176 m
.46681 .41811 L
s
.35679 .4235 m
.35713 .42288 L
s
.46535 .4176 m
.46668 .41811 L
s
.35685 .42348 m
.35719 .42286 L
s
.27342 .42067 m
.2735 .42018 L
s
.41044 .4196 m
.41162 .41905 L
s
.17653 .52052 m
.17644 .5201 L
s
.71406 .4089 m
.71412 .40928 L
s
.41056 .41955 m
.41175 .419 L
s
.51892 .41407 m
.5194 .41467 L
s
.46523 .41751 m
.46657 .41802 L
s
.3568 .42339 m
.35713 .42277 L
s
.41055 .41951 m
.41174 .41897 L
s
.83457 .26284 m
.83474 .26307 L
s
.41057 .41951 m
.41176 .41896 L
s
.62236 .41593 m
.62249 .41638 L
s
.51892 .41403 m
.5194 .41463 L
s
.41067 .41948 m
.41186 .41894 L
s
.46523 .41747 m
.46656 .41798 L
s
.62219 .4159 m
.62232 .41635 L
s
.4107 .41946 m
.41189 .41892 L
s
.46513 .41746 m
.46647 .41796 L
s
.46519 .41746 m
.46652 .41796 L
s
.41079 .41945 m
.41199 .41891 L
s
.46511 .41744 m
.46645 .41795 L
s
.46493 .41745 m
.46628 .41795 L
s
.46505 .41744 m
.46639 .41795 L
s
.71404 .40881 m
.71411 .40918 L
s
.35692 .4233 m
.35726 .42268 L
s
.46506 .41742 m
.4664 .41793 L
s
.46488 .41741 m
.46622 .41791 L
s
.35689 .42327 m
.35722 .42265 L
s
.4108 .4194 m
.412 .41885 L
s
.27357 .42044 m
.27365 .41995 L
s
.41088 .41937 m
.41208 .41883 L
s
.46482 .41737 m
.46616 .41787 L
s
.41096 .41935 m
.41215 .41881 L
s
.16243 .42954 m
.16243 .42917 L
s
.35693 .42321 m
.35727 .4226 L
s
.41098 .41932 m
.41218 .41878 L
s
.46454 .41733 m
.46588 .41783 L
s
.46476 .41733 m
.4661 .41783 L
s
.4647 .41732 m
.46604 .41782 L
s
.411 .41931 m
.4122 .41877 L
s
.41098 .41931 m
.41218 .41877 L
s
.46464 .41731 m
.46599 .41781 L
s
.41099 .41929 m
.41219 .41875 L
s
.41104 .41929 m
.41225 .41875 L
s
.46468 .4173 m
.46603 .4178 L
s
.4111 .41928 m
.4123 .41875 L
s
.41115 .41928 m
.41235 .41874 L
s
.35697 .42315 m
.35731 .42253 L
s
.51888 .41378 m
.51936 .41438 L
s
.16239 .42948 m
.16239 .42911 L
s
.2735 .42034 m
.27359 .41985 L
s
.46469 .41729 m
.46604 .41778 L
s
.46466 .41727 m
.46601 .41777 L
s
.35702 .42311 m
.35736 .42249 L
s
.46442 .41727 m
.46578 .41776 L
s
.83441 .26261 m
.83457 .26284 L
s
.6221 .41566 m
.62223 .41611 L
s
.5188 .41376 m
.51928 .41436 L
s
.62217 .41566 m
.6223 .41611 L
s
.35707 .4231 m
.35742 .42248 L
s
.51895 .41373 m
.51944 .41433 L
s
.46456 .41725 m
.46591 .41775 L
s
.46439 .41725 m
.46574 .41774 L
s
.41124 .4192 m
.41245 .41867 L
s
.41124 .4192 m
.41245 .41866 L
s
.51865 .41371 m
.51913 .41431 L
s
.41136 .41915 m
.41257 .41862 L
s
.714 .40853 m
.71406 .4089 L
s
.41141 .41915 m
.41262 .41862 L
s
.17644 .5201 m
.17635 .51968 L
s
.46427 .41718 m
.46562 .41767 L
s
.41141 .41913 m
.41263 .41859 L
s
.41152 .41912 m
.41273 .41859 L
s
.41137 .41912 m
.41258 .41859 L
s
.51868 .41365 m
.51917 .41425 L
s
.41144 .4191 m
.41265 .41857 L
s
.2735 .42018 m
.27359 .41969 L
s
.46419 .41714 m
.46555 .41763 L
s
.35707 .42296 m
.35741 .42234 L
s
.46419 .41713 m
.46555 .41762 L
s
.51864 .41363 m
.51912 .41422 L
s
.51858 .41362 m
.51907 .41422 L
s
.46412 .41712 m
.46548 .4176 L
s
.41162 .41905 m
.41284 .41852 L
s
.46399 .41711 m
.46535 .4176 L
s
.71398 .40843 m
.71404 .40881 L
s
.62223 .41548 m
.62236 .41593 L
s
.41175 .419 m
.41296 .41848 L
s
.35713 .42288 m
.35748 .42226 L
s
.62206 .41544 m
.62219 .4159 L
s
.51869 .41352 m
.51918 .41412 L
s
.35719 .42286 m
.35754 .42224 L
s
.41174 .41897 m
.41296 .41844 L
s
.41176 .41896 m
.41298 .41844 L
s
.46387 .41703 m
.46523 .41751 L
s
.41186 .41894 m
.41309 .41842 L
s
.83424 .26238 m
.83441 .26261 L
s
.16243 .42917 m
.16243 .4288 L
s
.41189 .41892 m
.41311 .4184 L
s
.41199 .41891 m
.41322 .41839 L
s
.46386 .41699 m
.46523 .41747 L
s
.46377 .41698 m
.46513 .41746 L
s
.46382 .41698 m
.46519 .41746 L
s
.46357 .41698 m
.46493 .41745 L
s
.46375 .41697 m
.46511 .41744 L
s
.51843 .41347 m
.51892 .41407 L
s
.46369 .41697 m
.46505 .41744 L
s
.35713 .42277 m
.35748 .42215 L
s
.16239 .42911 m
.16239 .42874 L
s
.27365 .41995 m
.27375 .41946 L
s
.412 .41885 m
.41322 .41833 L
s
.46369 .41695 m
.46506 .41742 L
s
.51843 .41344 m
.51892 .41403 L
s
.41208 .41883 m
.41331 .41831 L
s
.46351 .41694 m
.46488 .41741 L
s
.41215 .41881 m
.41338 .41829 L
s
.46345 .4169 m
.46482 .41737 L
s
.35726 .42268 m
.35761 .42206 L
s
.41218 .41878 m
.41341 .41826 L
s
.4122 .41877 m
.41343 .41825 L
s
.41218 .41877 m
.41341 .41825 L
s
.35722 .42265 m
.35757 .42203 L
s
.41219 .41875 m
.41342 .41824 L
s
.41225 .41875 m
.41348 .41823 L
s
.41235 .41874 m
.41359 .41823 L
s
.27359 .41985 m
.27368 .41936 L
s
.46316 .41686 m
.46454 .41733 L
s
.4123 .41875 m
.41354 .41823 L
s
.62197 .41521 m
.6221 .41566 L
s
.62204 .41521 m
.62217 .41566 L
s
.46338 .41686 m
.46476 .41733 L
s
.46333 .41685 m
.4647 .41732 L
s
.71393 .40815 m
.714 .40853 L
s
.46327 .41684 m
.46464 .41731 L
s
.46331 .41684 m
.46468 .4173 L
s
.17635 .51968 m
.17626 .51925 L
s
.35727 .4226 m
.35762 .42198 L
s
.46332 .41682 m
.46469 .41729 L
s
.46329 .41681 m
.46466 .41727 L
s
.46305 .4168 m
.46442 .41727 L
s
.41245 .41867 m
.41369 .41815 L
s
.41245 .41866 m
.41369 .41815 L
s
.83408 .26215 m
.83424 .26238 L
s
.46318 .41679 m
.46456 .41725 L
s
.46301 .41679 m
.46439 .41725 L
s
.35731 .42253 m
.35766 .42191 L
s
.71391 .40806 m
.71398 .40843 L
s
.41257 .41862 m
.41381 .41811 L
s
.41262 .41862 m
.41386 .41811 L
s
.35736 .42249 m
.35771 .42188 L
s
.51839 .41319 m
.51888 .41378 L
s
.41263 .41859 m
.41387 .41809 L
s
.41273 .41859 m
.41398 .41808 L
s
.41258 .41859 m
.41382 .41808 L
s
.35742 .42248 m
.35777 .42186 L
s
.27359 .41969 m
.27369 .4192 L
s
.46289 .41672 m
.46427 .41718 L
s
.41265 .41857 m
.41389 .41806 L
s
.5183 .41316 m
.5188 .41376 L
s
.51846 .41313 m
.51895 .41373 L
s
.6221 .41503 m
.62223 .41548 L
s
.16243 .4288 m
.16243 .42843 L
s
.46281 .41668 m
.46419 .41714 L
s
.41284 .41852 m
.41409 .41801 L
s
.46281 .41667 m
.46419 .41713 L
s
.62192 .41499 m
.62206 .41544 L
s
.46274 .41666 m
.46412 .41712 L
s
.51815 .41312 m
.51865 .41371 L
s
.4626 .41666 m
.46399 .41711 L
s
.41296 .41848 m
.41421 .41798 L
s
.16239 .42874 m
.16239 .42836 L
s
.51818 .41306 m
.51868 .41365 L
s
.41296 .41844 m
.41421 .41794 L
s
.41298 .41844 m
.41423 .41794 L
s
.35741 .42234 m
.35777 .42173 L
s
.41309 .41842 m
.41434 .41792 L
s
.41311 .4184 m
.41437 .4179 L
s
.46248 .41658 m
.46387 .41703 L
s
.41322 .41839 m
.41447 .41789 L
s
.51814 .41303 m
.51864 .41363 L
s
.51807 .41303 m
.51858 .41362 L
s
.83391 .26192 m
.83408 .26215 L
s
.46248 .41654 m
.46386 .41699 L
s
.35748 .42226 m
.35784 .42165 L
s
.46238 .41653 m
.46377 .41698 L
s
.27375 .41946 m
.27384 .41898 L
s
.46243 .41653 m
.46382 .41698 L
s
.35754 .42224 m
.3579 .42163 L
s
.46217 .41653 m
.46357 .41698 L
s
.46236 .41652 m
.46375 .41697 L
s
.41322 .41833 m
.41448 .41784 L
s
.4623 .41652 m
.46369 .41697 L
s
.71387 .40778 m
.71393 .40815 L
s
.51819 .41293 m
.51869 .41352 L
s
.41331 .41831 m
.41456 .41781 L
s
.4623 .4165 m
.46369 .41695 L
s
.41338 .41829 m
.41464 .41779 L
s
.46211 .41649 m
.46351 .41694 L
s
.41341 .41826 m
.41467 .41777 L
s
.62184 .41476 m
.62197 .41521 L
s
.6219 .41476 m
.62204 .41521 L
s
.46205 .41646 m
.46345 .4169 L
s
.17626 .51925 m
.17617 .51883 L
s
.41343 .41825 m
.41469 .41776 L
s
.41341 .41825 m
.41466 .41775 L
s
.41342 .41824 m
.41468 .41774 L
s
.41348 .41823 m
.41474 .41774 L
s
.35748 .42215 m
.35784 .42153 L
s
.41359 .41823 m
.41485 .41774 L
s
.41354 .41823 m
.4148 .41774 L
s
.27368 .41936 m
.27378 .41887 L
s
.71385 .40768 m
.71391 .40806 L
s
.51792 .41288 m
.51843 .41347 L
s
.46176 .41643 m
.46316 .41686 L
s
.46199 .41642 m
.46338 .41686 L
s
.46193 .41641 m
.46333 .41685 L
s
.46187 .4164 m
.46327 .41684 L
s
.46192 .4164 m
.46331 .41684 L
s
.51792 .41284 m
.51843 .41344 L
s
.41369 .41815 m
.41496 .41766 L
s
.46193 .41638 m
.46332 .41682 L
s
.41369 .41815 m
.41495 .41766 L
s
.35761 .42206 m
.35798 .42145 L
s
.4619 .41637 m
.46329 .41681 L
s
.46165 .41636 m
.46305 .4168 L
s
.16243 .42843 m
.16244 .42806 L
s
.46178 .41635 m
.46318 .41679 L
s
.35757 .42203 m
.35794 .42142 L
s
.41381 .41811 m
.41508 .41762 L
s
.46161 .41635 m
.46301 .41679 L
s
.41386 .41811 m
.41512 .41762 L
s
.41398 .41808 m
.41525 .4176 L
s
.41387 .41809 m
.41514 .4176 L
s
.41382 .41808 m
.41509 .4176 L
s
.83374 .26169 m
.83391 .26192 L
s
.62196 .41458 m
.6221 .41503 L
s
.41389 .41806 m
.41516 .41758 L
s
.27369 .4192 m
.27378 .41871 L
s
.35762 .42198 m
.35799 .42137 L
s
.16239 .42836 m
.1624 .42799 L
s
.46148 .41629 m
.46289 .41672 L
s
.62178 .41454 m
.62192 .41499 L
s
.41409 .41801 m
.41536 .41753 L
s
.46141 .41625 m
.46281 .41668 L
s
.35766 .42191 m
.35803 .4213 L
s
.46141 .41625 m
.46281 .41667 L
s
.41421 .41798 m
.41549 .41749 L
s
.46133 .41623 m
.46274 .41666 L
s
.4612 .41623 m
.4626 .41666 L
s
.35771 .42188 m
.35808 .42126 L
s
.41421 .41794 m
.41549 .41746 L
s
.35777 .42186 m
.35814 .42125 L
s
.41423 .41794 m
.41551 .41746 L
s
.51788 .4126 m
.51839 .41319 L
s
.41434 .41792 m
.41562 .41744 L
s
.7138 .40741 m
.71387 .40778 L
s
.41437 .4179 m
.41565 .41742 L
s
.41447 .41789 m
.41576 .41741 L
s
.51779 .41257 m
.5183 .41316 L
s
.51795 .41254 m
.51846 .41313 L
s
.46107 .41616 m
.46248 .41658 L
s
.41448 .41784 m
.41576 .41736 L
s
.51763 .41253 m
.51815 .41312 L
s
.46107 .41612 m
.46248 .41654 L
s
.46097 .41611 m
.46238 .41653 L
s
.27384 .41898 m
.27394 .41849 L
s
.46102 .41611 m
.46243 .41653 L
s
.46076 .41611 m
.46217 .41653 L
s
.41456 .41781 m
.41585 .41734 L
s
.46095 .4161 m
.46236 .41652 L
s
.46088 .4161 m
.4623 .41652 L
s
.17617 .51883 m
.17608 .5184 L
s
.71378 .40731 m
.71385 .40768 L
s
.35777 .42173 m
.35814 .42111 L
s
.83358 .26146 m
.83374 .26169 L
s
.41464 .41779 m
.41592 .41732 L
s
.46089 .41608 m
.4623 .4165 L
s
.6217 .41431 m
.62184 .41476 L
s
.51767 .41247 m
.51818 .41306 L
s
.62176 .41431 m
.6219 .41476 L
s
.41467 .41777 m
.41596 .41729 L
s
.4607 .41607 m
.46211 .41649 L
s
.41469 .41776 m
.41598 .41729 L
s
.41466 .41775 m
.41595 .41728 L
s
.41468 .41774 m
.41597 .41727 L
s
.41474 .41774 m
.41603 .41727 L
s
.41485 .41774 m
.41614 .41727 L
s
.4148 .41774 m
.41609 .41727 L
s
.46064 .41604 m
.46205 .41646 L
s
.51762 .41244 m
.51814 .41303 L
s
.51756 .41244 m
.51807 .41303 L
s
.16244 .42806 m
.16244 .42769 L
s
.27378 .41887 m
.27388 .41838 L
s
.35784 .42165 m
.35821 .42104 L
s
.46034 .41601 m
.46176 .41643 L
s
.3579 .42163 m
.35827 .42102 L
s
.46052 .416 m
.46193 .41641 L
s
.46057 .416 m
.46199 .41642 L
s
.46045 .41599 m
.46187 .4164 L
s
.4605 .41598 m
.46192 .4164 L
s
.41496 .41766 m
.41625 .4172 L
s
.41495 .41766 m
.41625 .41719 L
s
.51767 .41234 m
.51819 .41293 L
s
.1624 .42799 m
.1624 .42762 L
s
.46051 .41596 m
.46193 .41638 L
s
.46048 .41596 m
.4619 .41637 L
s
.46022 .41596 m
.46165 .41636 L
s
.41508 .41762 m
.41637 .41716 L
s
.41512 .41762 m
.41642 .41716 L
s
.46036 .41594 m
.46178 .41635 L
s
.41525 .4176 m
.41655 .41714 L
s
.46018 .41594 m
.46161 .41635 L
s
.41514 .4176 m
.41643 .41714 L
s
.41509 .4176 m
.41638 .41713 L
s
.35784 .42153 m
.35822 .42092 L
s
.62182 .41412 m
.62196 .41458 L
s
.41516 .41758 m
.41646 .41711 L
s
.62164 .41409 m
.62178 .41454 L
s
.5174 .41229 m
.51792 .41288 L
s
.27378 .41871 m
.27389 .41822 L
s
.41536 .41753 m
.41667 .41707 L
s
.46006 .41588 m
.46148 .41629 L
s
.35798 .42145 m
.35836 .42084 L
s
.83341 .26124 m
.83358 .26146 L
s
.5174 .41226 m
.51792 .41284 L
s
.41549 .41749 m
.41679 .41704 L
s
.71373 .40703 m
.7138 .40741 L
s
.45999 .41585 m
.46141 .41625 L
s
.45998 .41584 m
.46141 .41625 L
s
.35794 .42142 m
.35831 .4208 L
s
.4599 .41583 m
.46133 .41623 L
s
.45976 .41583 m
.4612 .41623 L
s
.41549 .41746 m
.41679 .41701 L
s
.41551 .41746 m
.41681 .417 L
s
.41562 .41744 m
.41693 .41699 L
s
.41565 .41742 m
.41696 .41697 L
s
.41576 .41741 m
.41707 .41696 L
s
.35799 .42137 m
.35837 .42076 L
s
.45964 .41576 m
.46107 .41616 L
s
.71371 .40693 m
.71378 .40731 L
s
.41576 .41736 m
.41707 .41691 L
s
.17608 .5184 m
.176 .51798 L
s
.35803 .4213 m
.35841 .42069 L
s
.41585 .41734 m
.41716 .41689 L
s
.45964 .41572 m
.46107 .41612 L
s
.45954 .41571 m
.46097 .41611 L
s
.45932 .41572 m
.46076 .41611 L
s
.45959 .41572 m
.46102 .41611 L
s
.41592 .41732 m
.41724 .41687 L
s
.45952 .41571 m
.46095 .4161 L
s
.35808 .42126 m
.35845 .42065 L
s
.45945 .41571 m
.46088 .4161 L
s
.16244 .42769 m
.16245 .42732 L
s
.41596 .41729 m
.41727 .41685 L
s
.27394 .41849 m
.27404 .418 L
s
.35814 .42125 m
.35853 .42064 L
s
.62155 .41386 m
.6217 .41431 L
s
.62162 .41386 m
.62176 .41431 L
s
.45945 .41569 m
.46089 .41608 L
s
.41598 .41729 m
.41729 .41684 L
s
.41595 .41728 m
.41726 .41684 L
s
.41614 .41727 m
.41746 .41683 L
s
.41603 .41727 m
.41735 .41683 L
s
.41597 .41727 m
.41728 .41683 L
s
.45926 .41569 m
.4607 .41607 L
s
.41609 .41727 m
.41741 .41683 L
s
.51736 .41201 m
.51788 .4126 L
s
.4592 .41565 m
.46064 .41604 L
s
.1624 .42762 m
.16241 .42725 L
s
.51727 .41199 m
.51779 .41257 L
s
.51743 .41196 m
.51795 .41254 L
s
.83324 .26101 m
.83341 .26124 L
s
.4589 .41563 m
.46034 .41601 L
s
.41625 .4172 m
.41757 .41676 L
s
.45908 .41561 m
.46052 .416 L
s
.45913 .41562 m
.46057 .416 L
s
.41625 .41719 m
.41757 .41675 L
s
.45901 .41561 m
.46045 .41599 L
s
.27388 .41838 m
.27398 .41789 L
s
.45906 .4156 m
.4605 .41598 L
s
.51711 .41194 m
.51763 .41253 L
s
.41637 .41716 m
.41769 .41672 L
s
.41642 .41716 m
.41774 .41672 L
s
.45907 .41558 m
.46051 .41596 L
s
.35814 .42111 m
.35852 .4205 L
s
.45878 .41558 m
.46022 .41596 L
s
.41655 .41714 m
.41787 .4167 L
s
.45904 .41558 m
.46048 .41596 L
s
.41643 .41714 m
.41776 .4167 L
s
.41638 .41713 m
.4177 .41669 L
s
.45874 .41557 m
.46018 .41594 L
s
.45892 .41556 m
.46036 .41594 L
s
.41646 .41711 m
.41778 .41668 L
s
.51715 .41188 m
.51767 .41247 L
s
.62168 .41367 m
.62182 .41412 L
s
.41667 .41707 m
.41799 .41664 L
s
.71366 .40666 m
.71373 .40703 L
s
.35821 .42104 m
.3586 .42043 L
s
.5171 .41186 m
.51762 .41244 L
s
.6215 .41364 m
.62164 .41409 L
s
.51703 .41186 m
.51756 .41244 L
s
.35827 .42102 m
.35866 .42041 L
s
.45861 .4155 m
.46006 .41588 L
s
.41679 .41704 m
.41812 .4166 L
s
.45854 .41547 m
.45999 .41585 L
s
.27389 .41822 m
.27399 .41773 L
s
.45854 .41547 m
.45998 .41584 L
s
.41679 .41701 m
.41812 .41657 L
s
.41681 .417 m
.41814 .41657 L
s
.45846 .41546 m
.4599 .41583 L
s
.45831 .41546 m
.45976 .41583 L
s
.41693 .41699 m
.41826 .41656 L
s
.51715 .41176 m
.51767 .41234 L
s
.41696 .41697 m
.41829 .41654 L
s
.41707 .41696 m
.41841 .41654 L
s
.71364 .40656 m
.71371 .40693 L
s
.35822 .42092 m
.3586 .42031 L
s
.83307 .26078 m
.83324 .26101 L
s
.45819 .41539 m
.45964 .41576 L
s
.41707 .41691 m
.41841 .41648 L
s
.176 .51798 m
.17592 .51755 L
s
.41716 .41689 m
.4185 .41646 L
s
.16245 .42732 m
.16245 .42695 L
s
.41724 .41687 m
.41857 .41645 L
s
.51687 .41171 m
.5174 .41229 L
s
.35836 .42084 m
.35875 .42023 L
s
.45787 .41536 m
.45932 .41572 L
s
.45818 .41536 m
.45964 .41572 L
s
.45809 .41535 m
.45954 .41571 L
s
.45814 .41535 m
.45959 .41572 L
s
.41727 .41685 m
.41861 .41642 L
s
.45807 .41534 m
.45952 .41571 L
s
.45799 .41534 m
.45945 .41571 L
s
.41729 .41684 m
.41863 .41641 L
s
.41746 .41683 m
.4188 .41641 L
s
.41726 .41684 m
.4186 .41641 L
s
.41735 .41683 m
.41869 .4164 L
s
.41728 .41683 m
.41862 .4164 L
s
.51687 .41167 m
.5174 .41226 L
s
.41741 .41683 m
.41875 .41641 L
s
.35831 .4208 m
.3587 .4202 L
s
.458 .41533 m
.45945 .41569 L
s
.4578 .41533 m
.45926 .41569 L
s
.16241 .42725 m
.16241 .42688 L
s
.62141 .41341 m
.62155 .41386 L
s
.62147 .41341 m
.62162 .41386 L
s
.45774 .4153 m
.4592 .41565 L
s
.27404 .418 m
.27415 .41751 L
s
.35837 .42076 m
.35876 .42015 L
s
.41757 .41676 m
.41892 .41634 L
s
.45744 .41528 m
.4589 .41563 L
s
.41757 .41675 m
.41891 .41633 L
s
.45762 .41525 m
.45908 .41561 L
s
.45767 .41526 m
.45913 .41562 L
s
.45755 .41525 m
.45901 .41561 L
s
.4576 .41524 m
.45906 .4156 L
s
.41769 .41672 m
.41904 .4163 L
s
.41774 .41672 m
.41909 .4163 L
s
.41787 .4167 m
.41922 .41629 L
s
.35841 .42069 m
.3588 .42008 L
s
.41776 .4167 m
.4191 .41628 L
s
.4177 .41669 m
.41905 .41628 L
s
.45732 .41523 m
.45878 .41558 L
s
.45761 .41523 m
.45907 .41558 L
s
.45758 .41522 m
.45904 .41558 L
s
.35845 .42065 m
.35884 .42004 L
s
.41778 .41668 m
.41913 .41626 L
s
.45728 .41522 m
.45874 .41557 L
s
.45745 .41521 m
.45892 .41556 L
s
.27398 .41789 m
.27409 .41741 L
s
.71359 .40628 m
.71366 .40666 L
s
.35853 .42064 m
.35892 .42003 L
s
.41799 .41664 m
.41935 .41623 L
s
.8329 .26055 m
.83307 .26078 L
s
.41812 .4166 m
.41947 .4162 L
s
.62153 .41322 m
.62168 .41367 L
s
.45714 .41516 m
.45861 .4155 L
s
.51682 .41143 m
.51736 .41201 L
s
.41812 .41657 m
.41947 .41617 L
s
.41814 .41657 m
.4195 .41616 L
s
.62135 .41319 m
.6215 .41364 L
s
.45708 .41513 m
.45854 .41547 L
s
.45707 .41513 m
.45854 .41547 L
s
.41826 .41656 m
.41962 .41615 L
s
.41829 .41654 m
.41965 .41614 L
s
.41841 .41654 m
.41977 .41613 L
s
.45685 .41512 m
.45831 .41546 L
s
.45699 .41512 m
.45846 .41546 L
s
.51673 .41141 m
.51727 .41199 L
s
.5169 .41138 m
.51743 .41196 L
s
.71357 .40619 m
.71364 .40656 L
s
.35852 .4205 m
.35892 .4199 L
s
.51657 .41136 m
.51711 .41194 L
s
.27399 .41773 m
.2741 .41725 L
s
.41841 .41648 m
.41977 .41608 L
s
.16245 .42695 m
.16246 .42658 L
s
.4185 .41646 m
.41987 .41606 L
s
.45672 .41505 m
.45819 .41539 L
s
.17592 .51755 m
.17583 .51713 L
s
.41857 .41645 m
.41994 .41605 L
s
.51661 .4113 m
.51715 .41188 L
s
.41861 .41642 m
.41997 .41602 L
s
.45639 .41503 m
.45787 .41536 L
s
.3586 .42043 m
.359 .41982 L
s
.45671 .41502 m
.45818 .41536 L
s
.45662 .41501 m
.45809 .41535 L
s
.4188 .41641 m
.42017 .41601 L
s
.41863 .41641 m
.41999 .41602 L
s
.45667 .41502 m
.45814 .41535 L
s
.41869 .4164 m
.42005 .41601 L
s
.4566 .41501 m
.45807 .41534 L
s
.45652 .41501 m
.45799 .41534 L
s
.41875 .41641 m
.42011 .41601 L
s
.4186 .41641 m
.41997 .41601 L
s
.41862 .4164 m
.41998 .41601 L
s
.35866 .42041 m
.35906 .4198 L
s
.16241 .42688 m
.16242 .42651 L
s
.51656 .41128 m
.5171 .41186 L
s
.45652 .41499 m
.458 .41533 L
s
.51649 .41128 m
.51703 .41186 L
s
.45633 .415 m
.4578 .41533 L
s
.45626 .41497 m
.45774 .4153 L
s
.41892 .41634 m
.42029 .41594 L
s
.83273 .26032 m
.8329 .26055 L
s
.41891 .41633 m
.42028 .41594 L
s
.45596 .41496 m
.45744 .41528 L
s
.62126 .41296 m
.62141 .41341 L
s
.51661 .41118 m
.51715 .41176 L
s
.62132 .41296 m
.62147 .41341 L
s
.41904 .4163 m
.42041 .41591 L
s
.3586 .42031 m
.359 .41971 L
s
.45615 .41493 m
.45762 .41525 L
s
.45607 .41493 m
.45755 .41525 L
s
.41909 .4163 m
.42046 .41591 L
s
.45619 .41493 m
.45767 .41526 L
s
.41922 .41629 m
.4206 .4159 L
s
.45613 .41492 m
.4576 .41524 L
s
.4191 .41628 m
.42048 .41589 L
s
.41905 .41628 m
.42042 .41589 L
s
.45584 .4149 m
.45732 .41523 L
s
.45613 .4149 m
.45761 .41523 L
s
.41913 .41626 m
.4205 .41587 L
s
.4561 .4149 m
.45758 .41522 L
s
.45579 .4149 m
.45728 .41522 L
s
.27415 .41751 m
.27426 .41702 L
s
.45597 .41488 m
.45745 .41521 L
s
.41935 .41623 m
.42072 .41584 L
s
.71351 .40591 m
.71359 .40628 L
s
.35875 .42023 m
.35915 .41962 L
s
.41947 .4162 m
.42085 .41581 L
s
.51632 .41113 m
.51687 .41171 L
s
.3587 .4202 m
.3591 .41959 L
s
.45566 .41484 m
.45714 .41516 L
s
.41947 .41617 m
.42085 .41578 L
s
.4195 .41616 m
.42088 .41578 L
s
.41962 .41615 m
.421 .41577 L
s
.51633 .4111 m
.51687 .41167 L
s
.41965 .41614 m
.42103 .41576 L
s
.41977 .41613 m
.42115 .41576 L
s
.45559 .41481 m
.45707 .41513 L
s
.4556 .41481 m
.45708 .41513 L
s
.45536 .41481 m
.45685 .41512 L
s
.4555 .4148 m
.45699 .41512 L
s
.27409 .41741 m
.2742 .41692 L
s
.35876 .42015 m
.35916 .41954 L
s
.71349 .40581 m
.71357 .40619 L
s
.62138 .41277 m
.62153 .41322 L
s
.41977 .41608 m
.42116 .4157 L
s
.41987 .41606 m
.42125 .41569 L
s
.6212 .41274 m
.62135 .41319 L
s
.3588 .42008 m
.35921 .41947 L
s
.16246 .42658 m
.16247 .42621 L
s
.45523 .41475 m
.45672 .41505 L
s
.41994 .41605 m
.42132 .41567 L
s
.83256 .2601 m
.83273 .26032 L
s
.41997 .41602 m
.42135 .41565 L
s
.35884 .42004 m
.35925 .41944 L
s
.42017 .41601 m
.42156 .41564 L
s
.41999 .41602 m
.42138 .41564 L
s
.4549 .41473 m
.45639 .41503 L
s
.42005 .41601 m
.42144 .41564 L
s
.42011 .41601 m
.4215 .41564 L
s
.41998 .41601 m
.42137 .41563 L
s
.41997 .41601 m
.42135 .41564 L
s
.45513 .41471 m
.45662 .41501 L
s
.45523 .41471 m
.45671 .41502 L
s
.35892 .42003 m
.35933 .41942 L
s
.45518 .41471 m
.45667 .41502 L
s
.45511 .4147 m
.4566 .41501 L
s
.45503 .41471 m
.45652 .41501 L
s
.17583 .51713 m
.17575 .5167 L
s
.16242 .42651 m
.16243 .42614 L
s
.45503 .41469 m
.45652 .41499 L
s
.45484 .4147 m
.45633 .415 L
s
.42029 .41594 m
.42168 .41558 L
s
.2741 .41725 m
.27422 .41676 L
s
.45477 .41467 m
.45626 .41497 L
s
.42028 .41594 m
.42167 .41557 L
s
.45447 .41466 m
.45596 .41496 L
s
.42041 .41591 m
.4218 .41554 L
s
.51628 .41085 m
.51682 .41143 L
s
.4206 .4159 m
.42199 .41554 L
s
.42046 .41591 m
.42185 .41554 L
s
.42048 .41589 m
.42187 .41553 L
s
.45458 .41463 m
.45607 .41493 L
s
.45466 .41463 m
.45615 .41493 L
s
.4547 .41463 m
.45619 .41493 L
s
.42042 .41589 m
.42181 .41552 L
s
.45464 .41462 m
.45613 .41492 L
s
.51619 .41083 m
.51673 .41141 L
s
.51635 .4108 m
.5169 .41138 L
s
.4205 .41587 m
.42189 .41551 L
s
.45434 .41461 m
.45584 .4149 L
s
.35892 .4199 m
.35932 .41929 L
s
.45464 .4146 m
.45613 .4149 L
s
.45461 .4146 m
.4561 .4149 L
s
.42072 .41584 m
.42212 .41548 L
s
.4543 .41461 m
.45579 .4149 L
s
.45448 .41459 m
.45597 .41488 L
s
.42085 .41581 m
.42225 .41546 L
s
.6211 .41251 m
.62126 .41296 L
s
.51602 .41078 m
.51657 .41136 L
s
.62117 .41251 m
.62132 .41296 L
s
.71344 .40554 m
.71351 .40591 L
s
.42085 .41578 m
.42225 .41543 L
s
.42088 .41578 m
.42228 .41543 L
s
.45416 .41455 m
.45566 .41484 L
s
.421 .41577 m
.4224 .41542 L
s
.42115 .41576 m
.42256 .41541 L
s
.42103 .41576 m
.42244 .41541 L
s
.359 .41982 m
.35941 .41922 L
s
.51606 .41072 m
.51661 .4113 L
s
.35906 .4198 m
.35947 .4192 L
s
.45409 .41453 m
.45559 .41481 L
s
.4541 .41453 m
.4556 .41481 L
s
.45386 .41453 m
.45536 .41481 L
s
.83239 .25987 m
.83256 .2601 L
s
.454 .41452 m
.4555 .4148 L
s
.516 .4107 m
.51656 .41128 L
s
.27426 .41702 m
.27438 .41653 L
s
.51594 .4107 m
.51649 .41128 L
s
.42116 .4157 m
.42256 .41535 L
s
.42125 .41569 m
.42266 .41534 L
s
.71342 .40544 m
.71349 .40581 L
s
.42132 .41567 m
.42273 .41532 L
s
.45373 .41447 m
.45523 .41475 L
s
.42135 .41565 m
.42276 .4153 L
s
.42156 .41564 m
.42297 .4153 L
s
.359 .41971 m
.35941 .4191 L
s
.42144 .41564 m
.42285 .41529 L
s
.42138 .41564 m
.42279 .4153 L
s
.4215 .41564 m
.42291 .4153 L
s
.42137 .41563 m
.42278 .41529 L
s
.42135 .41564 m
.42276 .41529 L
s
.4534 .41445 m
.4549 .41473 L
s
.51606 .4106 m
.51661 .41118 L
s
.16247 .42621 m
.16248 .42584 L
s
.45363 .41443 m
.45513 .41471 L
s
.45373 .41443 m
.45523 .41471 L
s
.45368 .41444 m
.45518 .41471 L
s
.45361 .41443 m
.45511 .4147 L
s
.45353 .41443 m
.45503 .41471 L
s
.62123 .41232 m
.62138 .41277 L
s
.2742 .41692 m
.27432 .41643 L
s
.45333 .41442 m
.45484 .4147 L
s
.45353 .41442 m
.45503 .41469 L
s
.42168 .41558 m
.42309 .41524 L
s
.42167 .41557 m
.42309 .41523 L
s
.62104 .41229 m
.6212 .41274 L
s
.35915 .41962 m
.35956 .41902 L
s
.45327 .4144 m
.45477 .41467 L
s
.45296 .4144 m
.45447 .41466 L
s
.4218 .41554 m
.42321 .4152 L
s
.42199 .41554 m
.42341 .4152 L
s
.16243 .42614 m
.16244 .42577 L
s
.42185 .41554 m
.42326 .4152 L
s
.42187 .41553 m
.42329 .41519 L
s
.3591 .41959 m
.35951 .41898 L
s
.42181 .41552 m
.42323 .41519 L
s
.45307 .41437 m
.45458 .41463 L
s
.45315 .41436 m
.45466 .41463 L
s
.17575 .5167 m
.17568 .51627 L
s
.51577 .41056 m
.51632 .41113 L
s
.45319 .41437 m
.4547 .41463 L
s
.45313 .41436 m
.45464 .41462 L
s
.42189 .41551 m
.42331 .41517 L
s
.45283 .41435 m
.45434 .41461 L
s
.42212 .41548 m
.42354 .41515 L
s
.4531 .41434 m
.45461 .4146 L
s
.45314 .41434 m
.45464 .4146 L
s
.51577 .41052 m
.51633 .4111 L
s
.45279 .41434 m
.4543 .41461 L
s
.35916 .41954 m
.35958 .41894 L
s
.45297 .41433 m
.45448 .41459 L
s
.42225 .41546 m
.42367 .41512 L
s
.83221 .25964 m
.83239 .25987 L
s
.42228 .41543 m
.4237 .4151 L
s
.42225 .41543 m
.42367 .4151 L
s
.4224 .41542 m
.42383 .41509 L
s
.42256 .41541 m
.42398 .41508 L
s
.42244 .41541 m
.42386 .41508 L
s
.45265 .4143 m
.45416 .41455 L
s
.27422 .41676 m
.27433 .41627 L
s
.35921 .41947 m
.35962 .41887 L
s
.45258 .41428 m
.45409 .41453 L
s
.45259 .41427 m
.4541 .41453 L
s
.45235 .41428 m
.45386 .41453 L
s
.45249 .41427 m
.454 .41452 L
s
.35925 .41944 m
.35966 .41883 L
s
.71336 .40516 m
.71344 .40554 L
s
.42256 .41535 m
.42399 .41503 L
s
.42266 .41534 m
.42409 .41502 L
s
.35933 .41942 m
.35975 .41882 L
s
.42273 .41532 m
.42415 .415 L
s
.42276 .4153 m
.42419 .41498 L
s
.62095 .41206 m
.6211 .41251 L
s
.42297 .4153 m
.42441 .41498 L
s
.62101 .41206 m
.62117 .41251 L
s
.45221 .41422 m
.45373 .41447 L
s
.42291 .4153 m
.42434 .41498 L
s
.42285 .41529 m
.42428 .41497 L
s
.42279 .4153 m
.42422 .41498 L
s
.42278 .41529 m
.4242 .41497 L
s
.42276 .41529 m
.42419 .41497 L
s
.45188 .41421 m
.4534 .41445 L
s
.45212 .41419 m
.45363 .41443 L
s
.45217 .41419 m
.45368 .41444 L
s
.45201 .41419 m
.45353 .41443 L
s
.4521 .41418 m
.45361 .41443 L
s
.45222 .41419 m
.45373 .41443 L
s
.71334 .40506 m
.71342 .40544 L
s
.42309 .41524 m
.42453 .41492 L
s
.45181 .41418 m
.45333 .41442 L
s
.45201 .41417 m
.45353 .41442 L
s
.51572 .41028 m
.51628 .41085 L
s
.42309 .41523 m
.42452 .41492 L
s
.42341 .4152 m
.42485 .4149 L
s
.45175 .41416 m
.45327 .4144 L
s
.42321 .4152 m
.42464 .41489 L
s
.45144 .41416 m
.45296 .4144 L
s
.42326 .4152 m
.4247 .41489 L
s
.16248 .42584 m
.1625 .42547 L
s
.35932 .41929 m
.35975 .41869 L
s
.42329 .41519 m
.42472 .41488 L
s
.42323 .41519 m
.42466 .41487 L
s
.51562 .41026 m
.51619 .41083 L
s
.5158 .41023 m
.51635 .4108 L
s
.45155 .41413 m
.45307 .41437 L
s
.45164 .41413 m
.45315 .41436 L
s
.45168 .41413 m
.45319 .41437 L
s
.45162 .41412 m
.45313 .41436 L
s
.42331 .41517 m
.42474 .41486 L
s
.27438 .41653 m
.2745 .41605 L
s
.42354 .41515 m
.42498 .41484 L
s
.45131 .41412 m
.45283 .41435 L
s
.83204 .25941 m
.83221 .25964 L
s
.45159 .4141 m
.4531 .41434 L
s
.45127 .41411 m
.45279 .41434 L
s
.45162 .4141 m
.45314 .41434 L
s
.51545 .41021 m
.51602 .41078 L
s
.42367 .41512 m
.42511 .41482 L
s
.16244 .42577 m
.16246 .4254 L
s
.45145 .41409 m
.45297 .41433 L
s
.35941 .41922 m
.35983 .41862 L
s
.62107 .41187 m
.62123 .41232 L
s
.42398 .41508 m
.42543 .41479 L
s
.4237 .4151 m
.42514 .41479 L
s
.42383 .41509 m
.42527 .41479 L
s
.35947 .4192 m
.35989 .41859 L
s
.42367 .4151 m
.42511 .41479 L
s
.42386 .41508 m
.42531 .41478 L
s
.45113 .41407 m
.45265 .4143 L
s
.5155 .41015 m
.51606 .41072 L
s
.62089 .41184 m
.62104 .41229 L
s
.45082 .41406 m
.45235 .41428 L
s
.45106 .41405 m
.45258 .41428 L
s
.17568 .51627 m
.1756 .51584 L
s
.45107 .41405 m
.45259 .41427 L
s
.27432 .41643 m
.27444 .41594 L
s
.45097 .41404 m
.45249 .41427 L
s
.42409 .41502 m
.42554 .41472 L
s
.42399 .41503 m
.42543 .41473 L
s
.51544 .41013 m
.516 .4107 L
s
.51537 .41013 m
.51594 .4107 L
s
.42415 .415 m
.4256 .4147 L
s
.42441 .41498 m
.42586 .41469 L
s
.42419 .41498 m
.42563 .41469 L
s
.35941 .4191 m
.35984 .4185 L
s
.42434 .41498 m
.42579 .41469 L
s
.42428 .41497 m
.42573 .41468 L
s
.45069 .414 m
.45221 .41422 L
s
.42422 .41498 m
.42566 .41468 L
s
.4242 .41497 m
.42565 .41468 L
s
.42419 .41497 m
.42563 .41468 L
s
.45035 .414 m
.45188 .41421 L
s
.51549 .41003 m
.51606 .4106 L
s
.45059 .41397 m
.45212 .41419 L
s
.45049 .41397 m
.45201 .41419 L
s
.45064 .41397 m
.45217 .41419 L
s
.45057 .41397 m
.4521 .41418 L
s
.45069 .41397 m
.45222 .41419 L
s
.42453 .41492 m
.42598 .41463 L
s
.71328 .40479 m
.71336 .40516 L
s
.45029 .41397 m
.45181 .41418 L
s
.42452 .41492 m
.42597 .41463 L
s
.45049 .41396 m
.45201 .41417 L
s
.42485 .4149 m
.4263 .41461 L
s
.35956 .41902 m
.35999 .41842 L
s
.42464 .41489 m
.4261 .41461 L
s
.44991 .41396 m
.45144 .41416 L
s
.45022 .41395 m
.45175 .41416 L
s
.4247 .41489 m
.42615 .41461 L
s
.42472 .41488 m
.42618 .4146 L
s
.42466 .41487 m
.42611 .41459 L
s
.35951 .41898 m
.35993 .41838 L
s
.45002 .41393 m
.45155 .41413 L
s
.27433 .41627 m
.27445 .41578 L
s
.45011 .41392 m
.45164 .41413 L
s
.42474 .41486 m
.4262 .41457 L
s
.45015 .41392 m
.45168 .41413 L
s
.45009 .41391 m
.45162 .41412 L
s
.42498 .41484 m
.42644 .41456 L
s
.44978 .41392 m
.45131 .41412 L
s
.5152 .40999 m
.51577 .41056 L
s
.83187 .25919 m
.83204 .25941 L
s
.42511 .41482 m
.42656 .41454 L
s
.44974 .41391 m
.45127 .41411 L
s
.45006 .4139 m
.45159 .4141 L
s
.45009 .4139 m
.45162 .4141 L
s
.42543 .41479 m
.42689 .41452 L
s
.44992 .41389 m
.45145 .41409 L
s
.35958 .41894 m
.36001 .41834 L
s
.71326 .40469 m
.71334 .40506 L
s
.42527 .41479 m
.42673 .41452 L
s
.62079 .41161 m
.62095 .41206 L
s
.42514 .41479 m
.4266 .41452 L
s
.42531 .41478 m
.42677 .41451 L
s
.42511 .41479 m
.42657 .41452 L
s
.62086 .41161 m
.62101 .41206 L
s
.5152 .40995 m
.51577 .41052 L
s
.4496 .41387 m
.45113 .41407 L
s
.1625 .42547 m
.16251 .42509 L
s
.44929 .41387 m
.45082 .41406 L
s
.44953 .41386 m
.45106 .41405 L
s
.35962 .41887 m
.36005 .41827 L
s
.44954 .41385 m
.45107 .41405 L
s
.44943 .41385 m
.45097 .41404 L
s
.42554 .41472 m
.427 .41445 L
s
.42543 .41473 m
.4269 .41446 L
s
.42586 .41469 m
.42732 .41443 L
s
.35966 .41883 m
.36009 .41823 L
s
.4256 .4147 m
.42706 .41444 L
s
.42563 .41469 m
.4271 .41442 L
s
.42579 .41469 m
.42726 .41442 L
s
.42573 .41468 m
.4272 .41442 L
s
.42566 .41468 m
.42713 .41442 L
s
.16246 .4254 m
.16247 .42503 L
s
.42565 .41468 m
.42712 .41441 L
s
.35975 .41882 m
.36018 .41822 L
s
.44915 .41381 m
.45069 .414 L
s
.42563 .41468 m
.4271 .41441 L
s
.44882 .41382 m
.45035 .414 L
s
.44895 .41379 m
.45049 .41397 L
s
.42598 .41463 m
.42745 .41437 L
s
.44906 .41378 m
.45059 .41397 L
s
.44904 .41378 m
.45057 .41397 L
s
.44911 .41379 m
.45064 .41397 L
s
.44916 .41378 m
.45069 .41397 L
s
.4263 .41461 m
.42778 .41436 L
s
.44875 .41379 m
.45029 .41397 L
s
.42597 .41463 m
.42744 .41437 L
s
.44895 .41377 m
.45049 .41396 L
s
.44837 .41379 m
.44991 .41396 L
s
.4261 .41461 m
.42756 .41435 L
s
.42615 .41461 m
.42762 .41435 L
s
.44868 .41377 m
.45022 .41395 L
s
.42618 .4146 m
.42765 .41434 L
s
.2745 .41605 m
.27462 .41556 L
s
.42611 .41459 m
.42758 .41433 L
s
.62091 .41143 m
.62107 .41187 L
s
.44848 .41375 m
.45002 .41393 L
s
.42644 .41456 m
.42791 .41431 L
s
.4262 .41457 m
.42767 .41432 L
s
.44857 .41374 m
.45011 .41392 L
s
.1756 .51584 m
.17552 .51542 L
s
.44855 .41374 m
.45009 .41391 L
s
.44861 .41374 m
.45015 .41392 L
s
.44824 .41375 m
.44978 .41392 L
s
.42656 .41454 m
.42804 .41429 L
s
.4482 .41374 m
.44974 .41391 L
s
.62073 .41139 m
.62089 .41184 L
s
.42689 .41452 m
.42837 .41427 L
s
.51515 .40971 m
.51572 .41028 L
s
.44852 .41372 m
.45006 .4139 L
s
.35975 .41869 m
.36018 .41809 L
s
.44856 .41372 m
.45009 .4139 L
s
.42673 .41452 m
.42821 .41428 L
s
.42677 .41451 m
.42825 .41426 L
s
.4266 .41452 m
.42808 .41427 L
s
.44838 .41372 m
.44992 .41389 L
s
.42657 .41452 m
.42804 .41427 L
s
.83169 .25896 m
.83187 .25919 L
s
.44806 .4137 m
.4496 .41387 L
s
.51505 .40969 m
.51562 .41026 L
s
.51523 .40966 m
.5158 .41023 L
s
.27444 .41594 m
.27456 .41546 L
s
.44775 .41371 m
.44929 .41387 L
s
.44799 .41369 m
.44953 .41386 L
s
.7132 .40441 m
.71328 .40479 L
s
.427 .41445 m
.42848 .41421 L
s
.448 .41369 m
.44954 .41385 L
s
.44789 .41369 m
.44943 .41385 L
s
.4269 .41446 m
.42838 .41421 L
s
.42732 .41443 m
.42881 .4142 L
s
.35983 .41862 m
.36027 .41802 L
s
.42706 .41444 m
.42854 .41419 L
s
.4271 .41442 m
.42858 .41418 L
s
.51488 .40965 m
.51545 .41021 L
s
.42726 .41442 m
.42874 .41419 L
s
.35989 .41859 m
.36033 .418 L
s
.4272 .41442 m
.42868 .41418 L
s
.42713 .41442 m
.42861 .41418 L
s
.42712 .41441 m
.4286 .41417 L
s
.44761 .41366 m
.44915 .41381 L
s
.44727 .41367 m
.44882 .41382 L
s
.4271 .41441 m
.42857 .41417 L
s
.42745 .41437 m
.42893 .41414 L
s
.44741 .41363 m
.44895 .41379 L
s
.42778 .41436 m
.42926 .41413 L
s
.51492 .40959 m
.5155 .41015 L
s
.4475 .41363 m
.44904 .41378 L
s
.44752 .41363 m
.44906 .41378 L
s
.44757 .41363 m
.44911 .41379 L
s
.42744 .41437 m
.42893 .41413 L
s
.4472 .41364 m
.44875 .41379 L
s
.44762 .41363 m
.44916 .41378 L
s
.44682 .41364 m
.44837 .41379 L
s
.42756 .41435 m
.42905 .41412 L
s
.42765 .41434 m
.42913 .41411 L
s
.4474 .41362 m
.44895 .41377 L
s
.42762 .41435 m
.4291 .41412 L
s
.71318 .40432 m
.71326 .40469 L
s
.44714 .41362 m
.44868 .41377 L
s
.42758 .41433 m
.42907 .4141 L
s
.44694 .41361 m
.44848 .41375 L
s
.16251 .42509 m
.16253 .42472 L
s
.42791 .41431 m
.4294 .41409 L
s
.51486 .40957 m
.51544 .41013 L
s
.35984 .4185 m
.36027 .4179 L
s
.51479 .40956 m
.51537 .41013 L
s
.42767 .41432 m
.42915 .41409 L
s
.44669 .41361 m
.44824 .41375 L
s
.44703 .41359 m
.44857 .41374 L
s
.44701 .41359 m
.44855 .41374 L
s
.44706 .4136 m
.44861 .41374 L
s
.42804 .41429 m
.42952 .41407 L
s
.42837 .41427 m
.42987 .41406 L
s
.27445 .41578 m
.27458 .4153 L
s
.44665 .4136 m
.4482 .41374 L
s
.42821 .41428 m
.4297 .41406 L
s
.42825 .41426 m
.42974 .41405 L
s
.44698 .41358 m
.44852 .41372 L
s
.42808 .41427 m
.42957 .41405 L
s
.62063 .41116 m
.62079 .41161 L
s
.44701 .41357 m
.44856 .41372 L
s
.42804 .41427 m
.42953 .41405 L
s
.62069 .41116 m
.62086 .41161 L
s
.44683 .41358 m
.44838 .41372 L
s
.44651 .41357 m
.44806 .4137 L
s
.51492 .40946 m
.51549 .41003 L
s
.4462 .41358 m
.44775 .41371 L
s
.16247 .42503 m
.16249 .42466 L
s
.42848 .41421 m
.42998 .414 L
s
.44645 .41356 m
.44799 .41369 L
s
.35999 .41842 m
.36043 .41782 L
s
.44635 .41356 m
.44789 .41369 L
s
.44646 .41355 m
.448 .41369 L
s
.42838 .41421 m
.42987 .414 L
s
.42881 .4142 m
.43031 .41399 L
s
.42854 .41419 m
.43003 .41398 L
s
.42858 .41418 m
.43007 .41397 L
s
.42874 .41419 m
.43024 .41398 L
s
.83152 .25873 m
.83169 .25896 L
s
.42868 .41418 m
.43018 .41397 L
s
.35993 .41838 m
.36037 .41779 L
s
.42861 .41418 m
.43011 .41397 L
s
.4286 .41417 m
.43009 .41396 L
s
.44573 .41354 m
.44727 .41367 L
s
.44606 .41353 m
.44761 .41366 L
s
.42857 .41417 m
.43007 .41396 L
s
.42926 .41413 m
.43077 .41394 L
s
.42893 .41414 m
.43043 .41394 L
s
.44586 .41351 m
.44741 .41363 L
s
.44527 .41353 m
.44682 .41364 L
s
.44595 .4135 m
.4475 .41363 L
s
.44602 .41351 m
.44757 .41363 L
s
.44597 .4135 m
.44752 .41363 L
s
.44566 .41352 m
.4472 .41364 L
s
.42893 .41413 m
.43043 .41393 L
s
.42905 .41412 m
.43055 .41391 L
s
.44607 .4135 m
.44762 .41363 L
s
.42913 .41411 m
.43063 .41391 L
s
.36001 .41834 m
.36045 .41774 L
s
.4291 .41412 m
.4306 .41391 L
s
.51462 .40942 m
.5152 .40999 L
s
.44559 .4135 m
.44714 .41362 L
s
.44586 .4135 m
.4474 .41362 L
s
.42907 .4141 m
.43056 .4139 L
s
.4294 .41409 m
.43091 .41389 L
s
.44539 .41349 m
.44694 .41361 L
s
.44514 .4135 m
.44669 .41361 L
s
.42987 .41406 m
.43137 .41387 L
s
.42915 .41409 m
.43065 .41389 L
s
.44548 .41348 m
.44703 .41359 L
s
.42952 .41407 m
.43103 .41388 L
s
.44546 .41348 m
.44701 .41359 L
s
.44551 .41348 m
.44706 .4136 L
s
.4451 .4135 m
.44665 .4136 L
s
.51462 .40939 m
.5152 .40995 L
s
.42974 .41405 m
.43125 .41386 L
s
.4297 .41406 m
.43121 .41387 L
s
.17552 .51542 m
.17545 .51499 L
s
.42957 .41405 m
.43107 .41386 L
s
.44543 .41347 m
.44698 .41358 L
s
.36005 .41827 m
.36049 .41767 L
s
.42953 .41405 m
.43103 .41386 L
s
.62075 .41098 m
.62091 .41143 L
s
.44547 .41346 m
.44701 .41357 L
s
.44528 .41346 m
.44683 .41358 L
s
.44465 .41348 m
.4462 .41358 L
s
.27462 .41556 m
.27474 .41507 L
s
.44496 .41346 m
.44651 .41357 L
s
.42998 .414 m
.43149 .41382 L
s
.36009 .41823 m
.36053 .41764 L
s
.43031 .41399 m
.43182 .41381 L
s
.4449 .41345 m
.44645 .41356 L
s
.44479 .41345 m
.44635 .41356 L
s
.71312 .40404 m
.7132 .40441 L
s
.42987 .414 m
.43138 .41381 L
s
.62056 .41094 m
.62073 .41139 L
s
.44491 .41345 m
.44646 .41355 L
s
.43024 .41398 m
.43175 .4138 L
s
.36018 .41822 m
.36063 .41763 L
s
.43007 .41397 m
.43158 .41379 L
s
.43003 .41398 m
.43154 .4138 L
s
.43018 .41397 m
.43168 .41379 L
s
.44417 .41345 m
.44573 .41354 L
s
.43009 .41396 m
.4316 .41378 L
s
.43011 .41397 m
.43161 .41379 L
s
.44451 .41343 m
.44606 .41353 L
s
.43077 .41394 m
.43228 .41377 L
s
.43007 .41396 m
.43158 .41378 L
s
.43043 .41394 m
.43195 .41376 L
s
.44372 .41345 m
.44527 .41353 L
s
.44431 .41342 m
.44586 .41351 L
s
.4441 .41343 m
.44566 .41352 L
s
.4444 .41341 m
.44595 .4135 L
s
.43043 .41393 m
.43194 .41375 L
s
.44447 .41341 m
.44602 .41351 L
s
.44442 .41341 m
.44597 .4135 L
s
.43055 .41391 m
.43206 .41374 L
s
.43063 .41391 m
.43215 .41374 L
s
.4306 .41391 m
.43212 .41374 L
s
.44452 .4134 m
.44607 .4135 L
s
.44404 .41341 m
.44559 .4135 L
s
.4443 .41341 m
.44586 .4135 L
s
.43137 .41387 m
.43289 .41372 L
s
.43056 .4139 m
.43208 .41373 L
s
.43091 .41389 m
.43242 .41372 L
s
.44359 .41342 m
.44514 .4135 L
s
.44383 .41341 m
.44539 .41349 L
s
.27456 .41546 m
.27469 .41497 L
s
.43103 .41388 m
.43254 .41371 L
s
.43125 .41386 m
.43276 .4137 L
s
.44355 .41342 m
.4451 .4135 L
s
.43121 .41387 m
.43272 .41371 L
s
.43065 .41389 m
.43216 .41372 L
s
.44391 .41339 m
.44546 .41348 L
s
.44393 .41339 m
.44548 .41348 L
s
.44396 .41339 m
.44551 .41348 L
s
.7131 .40394 m
.71318 .40432 L
s
.43107 .41386 m
.43259 .4137 L
s
.43103 .41386 m
.43255 .41369 L
s
.83134 .25851 m
.83152 .25873 L
s
.44388 .41338 m
.44543 .41347 L
s
.44309 .41341 m
.44465 .41348 L
s
.16253 .42472 m
.16255 .42435 L
s
.44373 .41338 m
.44528 .41346 L
s
.44391 .41337 m
.44547 .41346 L
s
.43182 .41381 m
.43334 .41366 L
s
.44341 .41338 m
.44496 .41346 L
s
.43149 .41382 m
.43301 .41366 L
s
.44334 .41338 m
.4449 .41345 L
s
.36018 .41809 m
.36062 .4175 L
s
.44324 .41338 m
.44479 .41345 L
s
.43138 .41381 m
.4329 .41366 L
s
.44335 .41337 m
.44491 .41345 L
s
.43175 .4138 m
.43327 .41365 L
s
.43168 .41379 m
.43321 .41364 L
s
.43158 .41379 m
.4331 .41364 L
s
.44262 .41339 m
.44417 .41345 L
s
.43154 .4138 m
.43306 .41364 L
s
.51457 .40915 m
.51515 .40971 L
s
.43228 .41377 m
.4338 .41363 L
s
.4316 .41378 m
.43312 .41363 L
s
.43161 .41379 m
.43313 .41363 L
s
.44216 .4134 m
.44372 .41345 L
s
.44295 .41336 m
.44451 .41343 L
s
.43195 .41376 m
.43347 .41361 L
s
.43158 .41378 m
.4331 .41362 L
s
.44255 .41337 m
.4441 .41343 L
s
.44275 .41336 m
.44431 .41342 L
s
.43289 .41372 m
.43442 .41359 L
s
.44285 .41335 m
.4444 .41341 L
s
.43215 .41374 m
.43367 .4136 L
s
.43194 .41375 m
.43346 .41361 L
s
.16249 .42466 m
.16251 .42429 L
s
.43206 .41374 m
.43358 .4136 L
s
.44291 .41335 m
.44447 .41341 L
s
.44287 .41334 m
.44442 .41341 L
s
.44248 .41335 m
.44404 .41341 L
s
.51447 .40913 m
.51505 .40969 L
s
.51464 .4091 m
.51523 .40966 L
s
.43212 .41374 m
.43364 .4136 L
s
.44203 .41337 m
.44359 .41342 L
s
.43242 .41372 m
.43395 .41359 L
s
.44296 .41334 m
.44452 .4134 L
s
.44275 .41334 m
.4443 .41341 L
s
.44228 .41335 m
.44383 .41341 L
s
.43208 .41373 m
.4336 .41358 L
s
.43276 .4137 m
.43429 .41357 L
s
.43272 .41371 m
.43425 .41358 L
s
.44199 .41337 m
.44355 .41342 L
s
.43254 .41371 m
.43407 .41358 L
s
.36027 .41802 m
.36071 .41742 L
s
.44236 .41334 m
.44391 .41339 L
s
.44238 .41334 m
.44393 .41339 L
s
.43216 .41372 m
.43369 .41357 L
s
.36033 .418 m
.36078 .4174 L
s
.44241 .41334 m
.44396 .41339 L
s
.43259 .4137 m
.43412 .41356 L
s
.62046 .41071 m
.62063 .41116 L
s
.44154 .41337 m
.44309 .41341 L
s
.62053 .41071 m
.62069 .41116 L
s
.43255 .41369 m
.43407 .41356 L
s
.43334 .41366 m
.43487 .41354 L
s
.44232 .41333 m
.44388 .41338 L
s
.27458 .4153 m
.27471 .41481 L
s
.44217 .41333 m
.44373 .41338 L
s
.43301 .41366 m
.43454 .41354 L
s
.51429 .40908 m
.51488 .40965 L
s
.44185 .41334 m
.44341 .41338 L
s
.44236 .41332 m
.44391 .41337 L
s
.44179 .41334 m
.44334 .41338 L
s
.44168 .41334 m
.44324 .41338 L
s
.44106 .41336 m
.44262 .41339 L
s
.43327 .41365 m
.4348 .41353 L
s
.44061 .41338 m
.44216 .4134 L
s
.4329 .41366 m
.43443 .41353 L
s
.4338 .41363 m
.43534 .41352 L
s
.43321 .41364 m
.43474 .41352 L
s
.4418 .41333 m
.44335 .41337 L
s
.4331 .41364 m
.43463 .41351 L
s
.43306 .41364 m
.43459 .41352 L
s
.43312 .41363 m
.43464 .41351 L
s
.43442 .41359 m
.43596 .41349 L
s
.4414 .41333 m
.44295 .41336 L
s
.43313 .41363 m
.43466 .41351 L
s
.43347 .41361 m
.435 .4135 L
s
.44099 .41335 m
.44255 .41337 L
s
.44119 .41332 m
.44275 .41336 L
s
.4331 .41362 m
.43462 .4135 L
s
.51433 .40902 m
.51492 .40959 L
s
.43367 .4136 m
.4352 .41349 L
s
.44048 .41335 m
.44203 .41337 L
s
.44129 .41331 m
.44285 .41335 L
s
.44093 .41333 m
.44248 .41335 L
s
.43358 .4136 m
.43511 .41348 L
s
.43429 .41357 m
.43583 .41347 L
s
.43346 .41361 m
.435 .41349 L
s
.43395 .41359 m
.43548 .41348 L
s
.44136 .41332 m
.44291 .41335 L
s
.43425 .41358 m
.43579 .41348 L
s
.44132 .41331 m
.44287 .41334 L
s
.44072 .41333 m
.44228 .41335 L
s
.44043 .41335 m
.44199 .41337 L
s
.43364 .4136 m
.43517 .41348 L
s
.43407 .41358 m
.4356 .41347 L
s
.43998 .41336 m
.44154 .41337 L
s
.44119 .41331 m
.44275 .41334 L
s
.4336 .41358 m
.43513 .41347 L
s
.44141 .4133 m
.44296 .41334 L
s
.43487 .41354 m
.43641 .41345 L
s
.4408 .41331 m
.44236 .41334 L
s
.43412 .41356 m
.43565 .41346 L
s
.36027 .4179 m
.36072 .41731 L
s
.44082 .41331 m
.44238 .41334 L
s
.43905 .41338 m
.44061 .41338 L
s
.44085 .41331 m
.44241 .41334 L
s
.43369 .41357 m
.43522 .41346 L
s
.43407 .41356 m
.43561 .41345 L
s
.43951 .41336 m
.44106 .41336 L
s
.43454 .41354 m
.43607 .41344 L
s
.43534 .41352 m
.43688 .41344 L
s
.43596 .41349 m
.4375 .41342 L
s
.44077 .41331 m
.44232 .41333 L
s
.4403 .41332 m
.44185 .41334 L
s
.4348 .41353 m
.43634 .41344 L
s
.44024 .41333 m
.44179 .41334 L
s
.44013 .41333 m
.44168 .41334 L
s
.44062 .41331 m
.44217 .41333 L
s
.51428 .409 m
.51486 .40957 L
s
.5142 .409 m
.51479 .40956 L
s
.43474 .41352 m
.43628 .41343 L
s
.44081 .4133 m
.44236 .41332 L
s
.43443 .41353 m
.43597 .41343 L
s
.43463 .41351 m
.43616 .41342 L
s
.44025 .41331 m
.4418 .41333 L
s
.43892 .41336 m
.44048 .41335 L
s
.43984 .41332 m
.4414 .41333 L
s
.43944 .41335 m
.44099 .41335 L
s
.43459 .41352 m
.43612 .41342 L
s
.43583 .41347 m
.43737 .4134 L
s
.4375 .41342 m
.43905 .41338 L
s
.43464 .41351 m
.43618 .41341 L
s
.435 .4135 m
.43654 .41341 L
s
.43466 .41351 m
.4362 .41342 L
s
.43843 .41338 m
.43998 .41336 L
s
.43579 .41348 m
.43733 .4134 L
s
.43641 .41345 m
.43796 .41339 L
s
.43888 .41336 m
.44043 .41335 L
s
.43964 .41332 m
.44119 .41332 L
s
.4352 .41349 m
.43675 .4134 L
s
.43937 .41333 m
.44093 .41333 L
s
.43548 .41348 m
.43703 .4134 L
s
.17545 .51499 m
.17537 .51456 L
s
.43917 .41334 m
.44072 .41333 L
s
.43796 .41339 m
.43951 .41336 L
s
.43688 .41344 m
.43843 .41338 L
s
.43974 .41331 m
.44129 .41331 L
s
.43511 .41348 m
.43665 .41339 L
s
.4356 .41347 m
.43714 .41339 L
s
.43462 .4135 m
.43616 .4134 L
s
.435 .41349 m
.43654 .4134 L
s
.43981 .41331 m
.44136 .41332 L
s
.43517 .41348 m
.43671 .4134 L
s
.43976 .4133 m
.44132 .41331 L
s
.83117 .25828 m
.83134 .25851 L
s
.43565 .41346 m
.4372 .41338 L
s
.43607 .41344 m
.43762 .41337 L
s
.43963 .41331 m
.44119 .41331 L
s
.43925 .41332 m
.4408 .41331 L
s
.43513 .41347 m
.43667 .41338 L
s
.43737 .4134 m
.43892 .41336 L
s
.43634 .41344 m
.43789 .41338 L
s
.71304 .40367 m
.71312 .40404 L
s
.43927 .41331 m
.44082 .41331 L
s
.43858 .41335 m
.44013 .41333 L
s
.43869 .41334 m
.44024 .41333 L
s
.43986 .4133 m
.44141 .4133 L
s
.43561 .41345 m
.43715 .41338 L
s
.4393 .41332 m
.44085 .41331 L
s
.43874 .41334 m
.4403 .41332 L
s
.43733 .4134 m
.43888 .41336 L
s
.36043 .41782 m
.36088 .41723 L
s
.43628 .41343 m
.43782 .41336 L
s
.43789 .41338 m
.43944 .41335 L
s
.43922 .41332 m
.44077 .41331 L
s
.43522 .41346 m
.43676 .41338 L
s
.43906 .41332 m
.44062 .41331 L
s
.43616 .41342 m
.43771 .41335 L
s
.43829 .41335 m
.43984 .41332 L
s
.43762 .41337 m
.43917 .41334 L
s
.43703 .4134 m
.43858 .41335 L
s
.51433 .4089 m
.51492 .40946 L
s
.43654 .41341 m
.43809 .41335 L
s
.4387 .41333 m
.44025 .41331 L
s
.43782 .41336 m
.43937 .41333 L
s
.43597 .41343 m
.43751 .41336 L
s
.43809 .41335 m
.43964 .41332 L
s
.43675 .4134 m
.43829 .41335 L
s
.43714 .41339 m
.43869 .41334 L
s
.43618 .41341 m
.43772 .41335 L
s
.43925 .4133 m
.44081 .4133 L
s
.62058 .41053 m
.62075 .41098 L
s
.43612 .41342 m
.43767 .41335 L
s
.4362 .41342 m
.43775 .41335 L
s
.4372 .41338 m
.43874 .41334 L
s
.43665 .41339 m
.43819 .41334 L
s
.43819 .41334 m
.43974 .41331 L
s
.43771 .41335 m
.43925 .41332 L
s
.43826 .41334 m
.43981 .41331 L
s
.43671 .4134 m
.43826 .41334 L
s
.43654 .4134 m
.43808 .41334 L
s
.43772 .41335 m
.43927 .41331 L
s
.43821 .41333 m
.43976 .4133 L
s
.43715 .41338 m
.4387 .41333 L
s
.43808 .41334 m
.43963 .41331 L
s
.43667 .41338 m
.43821 .41333 L
s
.36037 .41779 m
.36082 .41719 L
s
.43775 .41335 m
.4393 .41332 L
s
.43616 .4134 m
.4377 .41334 L
s
.43751 .41336 m
.43906 .41332 L
s
.43767 .41335 m
.43922 .41332 L
s
.43831 .41332 m
.43986 .4133 L
s
.43676 .41338 m
.43831 .41332 L
s
.4377 .41334 m
.43925 .4133 L
s
.62039 .41049 m
.62056 .41094 L
s
.27474 .41507 m
.27487 .41459 L
s
.36045 .41774 m
.3609 .41715 L
s
.71302 .40357 m
.7131 .40394 L
s
.16255 .42435 m
.16256 .42398 L
s
.51402 .40886 m
.51462 .40942 L
s
.36049 .41767 m
.36094 .41708 L
s
.51403 .40883 m
.51462 .40939 L
s
.27469 .41497 m
.27482 .41448 L
s
.36053 .41764 m
.36099 .41704 L
s
.16251 .42429 m
.16252 .42391 L
s
.36063 .41763 m
.36108 .41703 L
s
.83099 .25806 m
.83117 .25828 L
s
.62029 .41026 m
.62046 .41071 L
s
.62036 .41026 m
.62053 .41071 L
s
.36062 .4175 m
.36108 .4169 L
s
.27471 .41481 m
.27484 .41433 L
s
.51397 .40859 m
.51457 .40915 L
s
.71296 .40329 m
.71304 .40367 L
s
.17537 .51456 m
.1753 .51413 L
s
.36071 .41742 m
.36117 .41683 L
s
.51405 .40854 m
.51464 .4091 L
s
.51387 .40857 m
.51447 .40913 L
s
.36078 .4174 m
.36124 .41681 L
s
.51369 .40853 m
.51429 .40908 L
s
.62041 .41008 m
.62058 .41053 L
s
.71293 .4032 m
.71302 .40357 L
s
.16256 .42398 m
.16258 .42361 L
s
.51373 .40847 m
.51433 .40902 L
s
.36072 .41731 m
.36118 .41672 L
s
.62022 .41004 m
.62039 .41049 L
s
.83081 .25783 m
.83099 .25806 L
s
.51367 .40845 m
.51428 .409 L
s
.5136 .40845 m
.5142 .409 L
s
.27487 .41459 m
.27501 .4141 L
s
.16252 .42391 m
.16255 .42354 L
s
.36088 .41723 m
.36135 .41664 L
s
.51373 .40835 m
.51433 .4089 L
s
.36082 .41719 m
.36128 .4166 L
s
.27482 .41448 m
.27495 .414 L
s
.3609 .41715 m
.36136 .41656 L
s
.51342 .40831 m
.51402 .40886 L
s
.36094 .41708 m
.36141 .41649 L
s
.62012 .40981 m
.62029 .41026 L
s
.62019 .40982 m
.62036 .41026 L
s
.51342 .40828 m
.51403 .40883 L
s
.36099 .41704 m
.36145 .41645 L
s
.36108 .41703 m
.36155 .41644 L
s
.71287 .40292 m
.71296 .40329 L
s
.83063 .25761 m
.83081 .25783 L
s
.1753 .51413 m
.17523 .5137 L
s
.27484 .41433 m
.27498 .41384 L
s
.16258 .42361 m
.16261 .42324 L
s
.71284 .40282 m
.71293 .4032 L
s
.36108 .4169 m
.36155 .41631 L
s
.62024 .40963 m
.62041 .41008 L
s
.16255 .42354 m
.16257 .42317 L
s
.62005 .40959 m
.62022 .41004 L
s
.51337 .40804 m
.51397 .40859 L
s
.36117 .41683 m
.36165 .41624 L
s
.36124 .41681 m
.36171 .41622 L
s
.51344 .40799 m
.51405 .40854 L
s
.51326 .40802 m
.51387 .40857 L
s
.27501 .4141 m
.27515 .41362 L
s
.51308 .40797 m
.51369 .40853 L
s
.83045 .25738 m
.83063 .25761 L
s
.36118 .41672 m
.36165 .41613 L
s
.51312 .40791 m
.51373 .40847 L
s
.51306 .4079 m
.51367 .40845 L
s
.27495 .414 m
.27509 .41351 L
s
.51298 .4079 m
.5136 .40845 L
s
.36135 .41664 m
.36182 .41605 L
s
.71278 .40255 m
.71287 .40292 L
s
.36128 .4166 m
.36176 .41601 L
s
.61994 .40937 m
.62012 .40981 L
s
.62001 .40937 m
.62019 .40982 L
s
.51311 .4078 m
.51373 .40835 L
s
.36136 .41656 m
.36184 .41597 L
s
.17523 .5137 m
.17516 .51326 L
s
.16261 .42324 m
.16263 .42287 L
s
.71276 .40245 m
.71284 .40282 L
s
.36141 .41649 m
.36189 .4159 L
s
.5128 .40776 m
.51342 .40831 L
s
.27498 .41384 m
.27512 .41336 L
s
.36145 .41645 m
.36193 .41587 L
s
.16257 .42317 m
.16259 .4228 L
s
.36155 .41644 m
.36204 .41586 L
s
.51281 .40773 m
.51342 .40828 L
s
.83028 .25716 m
.83045 .25738 L
s
.62006 .40919 m
.62024 .40963 L
s
.61987 .40915 m
.62005 .40959 L
s
.36155 .41631 m
.36203 .41573 L
s
.27515 .41362 m
.27529 .41313 L
s
.36165 .41624 m
.36213 .41566 L
s
.36171 .41622 m
.3622 .41564 L
s
.51275 .40749 m
.51337 .40804 L
s
.7127 .40217 m
.71278 .40255 L
s
.51282 .40744 m
.51344 .40799 L
s
.51264 .40747 m
.51326 .40802 L
s
.8301 .25693 m
.83028 .25716 L
s
.27509 .41351 m
.27524 .41303 L
s
.61976 .40892 m
.61994 .40937 L
s
.51245 .40743 m
.51308 .40797 L
s
.61983 .40892 m
.62001 .40937 L
s
.16263 .42287 m
.16265 .4225 L
s
.36165 .41613 m
.36214 .41554 L
s
.17516 .51326 m
.1751 .51283 L
s
.71267 .40208 m
.71276 .40245 L
s
.5125 .40737 m
.51312 .40791 L
s
.36182 .41605 m
.36231 .41546 L
s
.16259 .4228 m
.16262 .42243 L
s
.51244 .40735 m
.51306 .4079 L
s
.51236 .40735 m
.51298 .4079 L
s
.36176 .41601 m
.36224 .41543 L
s
.27512 .41336 m
.27526 .41287 L
s
.51249 .40725 m
.51311 .4078 L
s
.36184 .41597 m
.36233 .41539 L
s
.61988 .40874 m
.62006 .40919 L
s
.36189 .4159 m
.36238 .41532 L
s
.61969 .4087 m
.61987 .40915 L
s
.82991 .25671 m
.8301 .25693 L
s
.36193 .41587 m
.36242 .41528 L
s
.51217 .40722 m
.5128 .40776 L
s
.36204 .41586 m
.36253 .41527 L
s
.51218 .40718 m
.51281 .40773 L
s
.7126 .4018 m
.7127 .40217 L
s
.27529 .41313 m
.27543 .41265 L
s
.16265 .4225 m
.16268 .42212 L
s
.36203 .41573 m
.36252 .41515 L
s
.71258 .4017 m
.71267 .40208 L
s
.1751 .51283 m
.17503 .5124 L
s
.61958 .40847 m
.61976 .40892 L
s
.61965 .40847 m
.61983 .40892 L
s
.16262 .42243 m
.16264 .42206 L
s
.36213 .41566 m
.36263 .41507 L
s
.27524 .41303 m
.27538 .41254 L
s
.3622 .41564 m
.3627 .41505 L
s
.51212 .40695 m
.51275 .40749 L
s
.82973 .25648 m
.82991 .25671 L
s
.51219 .4069 m
.51282 .40744 L
s
.51201 .40693 m
.51264 .40747 L
s
.36214 .41554 m
.36263 .41496 L
s
.51182 .40689 m
.51245 .40743 L
s
.6197 .40829 m
.61988 .40874 L
s
.27526 .41287 m
.27541 .41239 L
s
.51186 .40683 m
.5125 .40737 L
s
.36231 .41546 m
.36281 .41488 L
s
.61951 .40825 m
.61969 .4087 L
s
.36224 .41543 m
.36274 .41485 L
s
.5118 .40681 m
.51244 .40735 L
s
.51172 .40681 m
.51236 .40735 L
s
.71251 .40142 m
.7126 .4018 L
s
.36233 .41539 m
.36283 .41481 L
s
.51185 .40671 m
.51249 .40725 L
s
.16268 .42212 m
.16271 .42175 L
s
.36238 .41532 m
.36288 .41474 L
s
.82955 .25626 m
.82973 .25648 L
s
.71249 .40133 m
.71258 .4017 L
s
.36242 .41528 m
.36292 .4147 L
s
.36253 .41527 m
.36303 .41469 L
s
.51153 .40668 m
.51217 .40722 L
s
.16264 .42206 m
.16267 .42168 L
s
.27543 .41265 m
.27558 .41216 L
s
.17503 .5124 m
.17496 .51197 L
s
.51154 .40664 m
.51218 .40718 L
s
.61939 .40802 m
.61958 .40847 L
s
.61946 .40803 m
.61965 .40847 L
s
.27538 .41254 m
.27553 .41206 L
s
.36252 .41515 m
.36303 .41457 L
s
.36263 .41507 m
.36313 .4145 L
s
.3627 .41505 m
.36321 .41448 L
s
.82937 .25603 m
.82955 .25626 L
s
.61951 .40785 m
.6197 .40829 L
s
.51147 .40641 m
.51212 .40695 L
s
.71242 .40105 m
.71251 .40142 L
s
.27541 .41239 m
.27556 .4119 L
s
.61932 .40781 m
.61951 .40825 L
s
.51155 .40636 m
.51219 .4069 L
s
.51136 .40639 m
.51201 .40693 L
s
.36263 .41496 m
.36314 .41438 L
s
.16271 .42175 m
.16274 .42138 L
s
.51117 .40635 m
.51182 .40689 L
s
.71239 .40096 m
.71249 .40133 L
s
.36281 .41488 m
.36332 .41431 L
s
.51122 .40629 m
.51186 .40683 L
s
.16267 .42168 m
.1627 .42131 L
s
.36274 .41485 m
.36325 .41427 L
s
.51115 .40628 m
.5118 .40681 L
s
.51107 .40627 m
.51172 .40681 L
s
.17496 .51197 m
.1749 .51153 L
s
.36283 .41481 m
.36335 .41423 L
s
.51121 .40618 m
.51185 .40671 L
s
.82919 .25581 m
.82937 .25603 L
s
.27558 .41216 m
.27574 .41168 L
s
.36288 .41474 m
.36339 .41416 L
s
.6192 .40758 m
.61939 .40802 L
s
.61927 .40758 m
.61946 .40803 L
s
.36292 .4147 m
.36343 .41413 L
s
.36303 .41469 m
.36355 .41412 L
s
.51087 .40614 m
.51153 .40668 L
s
.27553 .41206 m
.27569 .41158 L
s
.51089 .40611 m
.51154 .40664 L
s
.71233 .40068 m
.71242 .40105 L
s
.36303 .41457 m
.36355 .41399 L
s
.61932 .4074 m
.61951 .40785 L
s
.16274 .42138 m
.16277 .42101 L
s
.61913 .40736 m
.61932 .40781 L
s
.7123 .40058 m
.71239 .40096 L
s
.36313 .4145 m
.36365 .41392 L
s
.36321 .41448 m
.36373 .4139 L
s
.829 .25559 m
.82919 .25581 L
s
.27556 .4119 m
.27571 .41142 L
s
.1627 .42131 m
.16273 .42094 L
s
.51082 .40588 m
.51147 .40641 L
s
.36314 .41438 m
.36366 .41381 L
s
.5109 .40583 m
.51155 .40636 L
s
.51071 .40586 m
.51136 .40639 L
s
.1749 .51153 m
.17484 .5111 L
s
.51051 .40582 m
.51117 .40635 L
s
.36332 .41431 m
.36385 .41373 L
s
.51056 .40576 m
.51122 .40629 L
s
.61901 .40713 m
.6192 .40758 L
s
.36325 .41427 m
.36377 .41369 L
s
.61908 .40714 m
.61927 .40758 L
s
.27574 .41168 m
.27589 .41119 L
s
.51049 .40575 m
.51115 .40628 L
s
.51041 .40574 m
.51107 .40627 L
s
.36335 .41423 m
.36387 .41366 L
s
.71223 .4003 m
.71233 .40068 L
s
.82882 .25536 m
.829 .25559 L
s
.36339 .41416 m
.36392 .41359 L
s
.51055 .40565 m
.51121 .40618 L
s
.27569 .41158 m
.27584 .41109 L
s
.16277 .42101 m
.1628 .42064 L
s
.36343 .41413 m
.36396 .41355 L
s
.36355 .41412 m
.36408 .41355 L
s
.7122 .40021 m
.7123 .40058 L
s
.61913 .40695 m
.61932 .4074 L
s
.51021 .40562 m
.51087 .40614 L
s
.16273 .42094 m
.16276 .42057 L
s
.61894 .40692 m
.61913 .40736 L
s
.51022 .40558 m
.51089 .40611 L
s
.36355 .41399 m
.36407 .41342 L
s
.27571 .41142 m
.27587 .41094 L
s
.17484 .5111 m
.17478 .51066 L
s
.82863 .25514 m
.82882 .25536 L
s
.36365 .41392 m
.36419 .41335 L
s
.36373 .4139 m
.36426 .41333 L
s
.51015 .40535 m
.51082 .40588 L
s
.36366 .41381 m
.36419 .41324 L
s
.61882 .40669 m
.61901 .40713 L
s
.61889 .40669 m
.61908 .40714 L
s
.71213 .39993 m
.71223 .4003 L
s
.51023 .4053 m
.5109 .40583 L
s
.51004 .40533 m
.51071 .40586 L
s
.27589 .41119 m
.27605 .41071 L
s
.36385 .41373 m
.36438 .41316 L
s
.1628 .42064 m
.16283 .42026 L
s
.50984 .40529 m
.51051 .40582 L
s
.36377 .41369 m
.3643 .41312 L
s
.7121 .39984 m
.7122 .40021 L
s
.50989 .40523 m
.51056 .40576 L
s
.16276 .42057 m
.1628 .4202 L
s
.36387 .41366 m
.36441 .41309 L
s
.27584 .41109 m
.276 .41061 L
s
.50974 .40522 m
.51041 .40574 L
s
.50982 .40522 m
.51049 .40575 L
s
.82845 .25492 m
.82863 .25514 L
s
.61893 .40651 m
.61913 .40695 L
s
.36392 .41359 m
.36445 .41302 L
s
.61874 .40647 m
.61894 .40692 L
s
.50987 .40512 m
.51055 .40565 L
s
.36396 .41355 m
.36449 .41298 L
s
.36408 .41355 m
.36462 .41298 L
s
.17478 .51066 m
.17472 .51023 L
s
.27587 .41094 m
.27604 .41045 L
s
.50953 .40509 m
.51021 .40562 L
s
.50955 .40506 m
.51022 .40558 L
s
.36407 .41342 m
.36461 .41285 L
s
.71203 .39956 m
.71213 .39993 L
s
.82826 .25469 m
.82845 .25492 L
s
.36419 .41335 m
.36473 .41278 L
s
.61862 .40624 m
.61882 .40669 L
s
.16283 .42026 m
.16287 .41989 L
s
.61869 .40625 m
.61889 .40669 L
s
.36426 .41333 m
.3648 .41276 L
s
.712 .39946 m
.7121 .39984 L
s
.1628 .4202 m
.16283 .41983 L
s
.27605 .41071 m
.27622 .41023 L
s
.36419 .41324 m
.36473 .41267 L
s
.50948 .40483 m
.51015 .40535 L
s
.50956 .40478 m
.51023 .4053 L
s
.50936 .40481 m
.51004 .40533 L
s
.36438 .41316 m
.36493 .4126 L
s
.61873 .40606 m
.61893 .40651 L
s
.276 .41061 m
.27617 .41013 L
s
.50916 .40477 m
.50984 .40529 L
s
.3643 .41312 m
.36485 .41256 L
s
.61854 .40603 m
.61874 .40647 L
s
.50921 .40471 m
.50989 .40523 L
s
.36441 .41309 m
.36495 .41252 L
s
.82808 .25447 m
.82826 .25469 L
s
.17472 .51023 m
.17466 .50979 L
s
.50905 .4047 m
.50974 .40522 L
s
.50914 .4047 m
.50982 .40522 L
s
.36445 .41302 m
.365 .41246 L
s
.36449 .41298 m
.36504 .41242 L
s
.50919 .4046 m
.50987 .40512 L
s
.71193 .39919 m
.71203 .39956 L
s
.36462 .41298 m
.36517 .41241 L
s
.27604 .41045 m
.2762 .40997 L
s
.16287 .41989 m
.1629 .41952 L
s
.50884 .40458 m
.50953 .40509 L
s
.61842 .4058 m
.61862 .40624 L
s
.7119 .39909 m
.712 .39946 L
s
.61849 .4058 m
.61869 .40625 L
s
.16283 .41983 m
.16287 .41945 L
s
.36461 .41285 m
.36517 .41229 L
s
.50886 .40454 m
.50955 .40506 L
s
.82789 .25425 m
.82808 .25447 L
s
.36473 .41278 m
.36528 .41222 L
s
.3648 .41276 m
.36536 .4122 L
s
.27622 .41023 m
.27638 .40974 L
s
.61853 .40562 m
.61873 .40606 L
s
.36473 .41267 m
.36529 .41211 L
s
.61833 .40558 m
.61854 .40603 L
s
.27617 .41013 m
.27634 .40965 L
s
.50879 .40432 m
.50948 .40483 L
s
.17466 .50979 m
.17461 .50935 L
s
.36493 .4126 m
.36549 .41203 L
s
.50887 .40426 m
.50956 .40478 L
s
.50867 .4043 m
.50936 .40481 L
s
.71183 .39881 m
.71193 .39919 L
s
.36485 .41256 m
.3654 .41199 L
s
.50847 .40426 m
.50916 .40477 L
s
.1629 .41952 m
.16294 .41915 L
s
.36495 .41252 m
.36551 .41196 L
s
.50851 .4042 m
.50921 .40471 L
s
.8277 .25403 m
.82789 .25425 L
s
.2762 .40997 m
.27637 .40949 L
s
.365 .41246 m
.36556 .41189 L
s
.7118 .39872 m
.7119 .39909 L
s
.16287 .41945 m
.1629 .41908 L
s
.50836 .40419 m
.50905 .4047 L
s
.50845 .40419 m
.50914 .4047 L
s
.36504 .41242 m
.3656 .41186 L
s
.36517 .41241 m
.36574 .41185 L
s
.61821 .40535 m
.61842 .4058 L
s
.61828 .40536 m
.61849 .4058 L
s
.5085 .40409 m
.50919 .4046 L
s
.50814 .40407 m
.50884 .40458 L
s
.36517 .41229 m
.36573 .41173 L
s
.50816 .40403 m
.50886 .40454 L
s
.27638 .40974 m
.27656 .40926 L
s
.82751 .25381 m
.8277 .25403 L
s
.61832 .40518 m
.61853 .40562 L
s
.36528 .41222 m
.36585 .41166 L
s
.36536 .4122 m
.36593 .41164 L
s
.61813 .40514 m
.61833 .40558 L
s
.17461 .50935 m
.17455 .50892 L
s
.71172 .39844 m
.71183 .39881 L
s
.16294 .41915 m
.16298 .41878 L
s
.27634 .40965 m
.27651 .40917 L
s
.36529 .41211 m
.36585 .41155 L
s
.1629 .41908 m
.16294 .41871 L
s
.71169 .39834 m
.7118 .39872 L
s
.50809 .40381 m
.50879 .40432 L
s
.36549 .41203 m
.36606 .41148 L
s
.50817 .40376 m
.50887 .40426 L
s
.50797 .40379 m
.50867 .4043 L
s
.3654 .41199 m
.36597 .41143 L
s
.50776 .40375 m
.50847 .40426 L
s
.27637 .40949 m
.27655 .40901 L
s
.36551 .41196 m
.36608 .4114 L
s
.618 .40491 m
.61821 .40535 L
s
.61807 .40491 m
.61828 .40536 L
s
.82732 .25358 m
.82751 .25381 L
s
.50781 .40369 m
.50851 .4042 L
s
.36556 .41189 m
.36613 .41134 L
s
.50765 .40368 m
.50836 .40419 L
s
.50774 .40368 m
.50845 .40419 L
s
.3656 .41186 m
.36617 .4113 L
s
.36574 .41185 m
.36631 .41129 L
s
.5078 .40358 m
.5085 .40409 L
s
.71162 .39807 m
.71172 .39844 L
s
.61811 .40473 m
.61832 .40518 L
s
.16298 .41878 m
.16302 .4184 L
s
.27656 .40926 m
.27673 .40878 L
s
.17455 .50892 m
.1745 .50848 L
s
.36573 .41173 m
.3663 .41117 L
s
.50744 .40356 m
.50814 .40407 L
s
.61792 .40469 m
.61813 .40514 L
s
.50745 .40353 m
.50816 .40403 L
s
.16294 .41871 m
.16299 .41834 L
s
.36585 .41166 m
.36643 .4111 L
s
.71159 .39797 m
.71169 .39834 L
s
.82714 .25336 m
.82732 .25358 L
s
.36593 .41164 m
.36651 .41108 L
s
.27651 .40917 m
.27669 .40868 L
s
.36585 .41155 m
.36643 .41099 L
s
.36606 .41148 m
.36664 .41092 L
s
.50738 .4033 m
.50809 .40381 L
s
.61779 .40447 m
.618 .40491 L
s
.61786 .40447 m
.61807 .40491 L
s
.27655 .40901 m
.27673 .40853 L
s
.36597 .41143 m
.36655 .41088 L
s
.50746 .40325 m
.50817 .40376 L
s
.50726 .40328 m
.50797 .40379 L
s
.36608 .4114 m
.36667 .41085 L
s
.50705 .40325 m
.50776 .40375 L
s
.82694 .25314 m
.82714 .25336 L
s
.71151 .39769 m
.71162 .39807 L
s
.36613 .41134 m
.36672 .41078 L
s
.5071 .40319 m
.50781 .40369 L
s
.16302 .4184 m
.16306 .41803 L
s
.36617 .4113 m
.36675 .41074 L
s
.50693 .40318 m
.50765 .40368 L
s
.50703 .40318 m
.50774 .40368 L
s
.36631 .41129 m
.3669 .41074 L
s
.1745 .50848 m
.17444 .50804 L
s
.6179 .40429 m
.61811 .40473 L
s
.16299 .41834 m
.16303 .41797 L
s
.71148 .3976 m
.71159 .39797 L
s
.6177 .40425 m
.61792 .40469 L
s
.50708 .40308 m
.5078 .40358 L
s
.27673 .40878 m
.27691 .4083 L
s
.3663 .41117 m
.36689 .41062 L
s
.50671 .40306 m
.50744 .40356 L
s
.27669 .40868 m
.27687 .4082 L
s
.50673 .40303 m
.50745 .40353 L
s
.36643 .4111 m
.36702 .41055 L
s
.36651 .41108 m
.3671 .41053 L
s
.82675 .25292 m
.82694 .25314 L
s
.61758 .40402 m
.61779 .40447 L
s
.61765 .40403 m
.61786 .40447 L
s
.36643 .41099 m
.36702 .41044 L
s
.27673 .40853 m
.27691 .40805 L
s
.7114 .39732 m
.71151 .39769 L
s
.16306 .41803 m
.16311 .41766 L
s
.36664 .41092 m
.36723 .41037 L
s
.50666 .4028 m
.50738 .4033 L
s
.36655 .41088 m
.36714 .41033 L
s
.50674 .40275 m
.50746 .40325 L
s
.50653 .40279 m
.50726 .40328 L
s
.16303 .41797 m
.16307 .41759 L
s
.17444 .50804 m
.17439 .5076 L
s
.36667 .41085 m
.36726 .4103 L
s
.71137 .39723 m
.71148 .3976 L
s
.50632 .40275 m
.50705 .40325 L
s
.61769 .40385 m
.6179 .40429 L
s
.82656 .2527 m
.82675 .25292 L
s
.36672 .41078 m
.36731 .41023 L
s
.61749 .40381 m
.6177 .40425 L
s
.50637 .40269 m
.5071 .40319 L
s
.36675 .41074 m
.36735 .4102 L
s
.3669 .41074 m
.3675 .41019 L
s
.27691 .4083 m
.2771 .40782 L
s
.5062 .40268 m
.50693 .40318 L
s
.5063 .40268 m
.50703 .40318 L
s
.50635 .40259 m
.50708 .40308 L
s
.27687 .4082 m
.27705 .40772 L
s
.36689 .41062 m
.36749 .41007 L
s
.50598 .40257 m
.50671 .40306 L
s
.36702 .41055 m
.36762 .41001 L
s
.3671 .41053 m
.3677 .40999 L
s
.506 .40254 m
.50673 .40303 L
s
.61736 .40358 m
.61758 .40402 L
s
.61743 .40359 m
.61765 .40403 L
s
.71129 .39695 m
.7114 .39732 L
s
.16311 .41766 m
.16315 .41729 L
s
.82637 .25248 m
.82656 .2527 L
s
.27691 .40805 m
.27709 .40757 L
s
.16307 .41759 m
.16312 .41722 L
s
.36702 .41044 m
.36762 .40989 L
s
.71126 .39685 m
.71137 .39723 L
s
.17439 .5076 m
.17434 .50716 L
s
.36723 .41037 m
.36784 .40983 L
s
.61747 .40341 m
.61769 .40385 L
s
.36714 .41033 m
.36774 .40978 L
s
.50593 .40231 m
.50666 .4028 L
s
.61727 .40337 m
.61749 .40381 L
s
.36726 .4103 m
.36787 .40975 L
s
.50601 .40226 m
.50674 .40275 L
s
.5058 .40229 m
.50653 .40279 L
s
.50558 .40226 m
.50632 .40275 L
s
.36731 .41023 m
.36792 .40969 L
s
.2771 .40782 m
.27728 .40734 L
s
.82618 .25226 m
.82637 .25248 L
s
.36735 .4102 m
.36795 .40965 L
s
.50563 .4022 m
.50637 .40269 L
s
.3675 .41019 m
.36811 .40965 L
s
.50547 .4022 m
.5062 .40268 L
s
.50556 .40219 m
.5063 .40268 L
s
.16315 .41729 m
.1632 .41692 L
s
.27705 .40772 m
.27724 .40724 L
s
.71118 .39658 m
.71129 .39695 L
s
.50562 .4021 m
.50635 .40259 L
s
.36749 .41007 m
.3681 .40953 L
s
.61714 .40314 m
.61736 .40358 L
s
.61721 .40314 m
.61743 .40359 L
s
.16312 .41722 m
.16316 .41685 L
s
.71115 .39648 m
.71126 .39685 L
s
.50524 .40208 m
.50598 .40257 L
s
.36762 .41001 m
.36823 .40946 L
s
.3677 .40999 m
.36831 .40944 L
s
.50526 .40205 m
.506 .40254 L
s
.17434 .50716 m
.1743 .50672 L
s
.27709 .40757 m
.27728 .40709 L
s
.82598 .25204 m
.82618 .25226 L
s
.36762 .40989 m
.36823 .40935 L
s
.61725 .40297 m
.61747 .40341 L
s
.36784 .40983 m
.36845 .40929 L
s
.61704 .40292 m
.61727 .40337 L
s
.36774 .40978 m
.36835 .40924 L
s
.50519 .40182 m
.50593 .40231 L
s
.36787 .40975 m
.36848 .40921 L
s
.50527 .40178 m
.50601 .40226 L
s
.50506 .40181 m
.5058 .40229 L
s
.27728 .40734 m
.27747 .40686 L
s
.1632 .41692 m
.16325 .41654 L
s
.71107 .3962 m
.71118 .39658 L
s
.36792 .40969 m
.36853 .40915 L
s
.50484 .40178 m
.50558 .40226 L
s
.36795 .40965 m
.36857 .40911 L
s
.82579 .25182 m
.82598 .25204 L
s
.36811 .40965 m
.36873 .40911 L
s
.16316 .41685 m
.16321 .41648 L
s
.50489 .40172 m
.50563 .4022 L
s
.27724 .40724 m
.27743 .40677 L
s
.71104 .39611 m
.71115 .39648 L
s
.61691 .4027 m
.61714 .40314 L
s
.61698 .4027 m
.61721 .40314 L
s
.50472 .40171 m
.50547 .4022 L
s
.50482 .40171 m
.50556 .40219 L
s
.50487 .40161 m
.50562 .4021 L
s
.3681 .40953 m
.36872 .40899 L
s
.1743 .50672 m
.17425 .50628 L
s
.27728 .40709 m
.27748 .40661 L
s
.36823 .40946 m
.36885 .40892 L
s
.36831 .40944 m
.36894 .4089 L
s
.50449 .4016 m
.50524 .40208 L
s
.61702 .40252 m
.61725 .40297 L
s
.50451 .40157 m
.50526 .40205 L
s
.8256 .2516 m
.82579 .25182 L
s
.61682 .40248 m
.61704 .40292 L
s
.36823 .40935 m
.36885 .40881 L
s
.16325 .41654 m
.1633 .41617 L
s
.71096 .39583 m
.71107 .3962 L
s
.36845 .40929 m
.36908 .40875 L
s
.36835 .40924 m
.36897 .4087 L
s
.16321 .41648 m
.16326 .41611 L
s
.27747 .40686 m
.27767 .40638 L
s
.36848 .40921 m
.36911 .40868 L
s
.50444 .40134 m
.50519 .40182 L
s
.71092 .39574 m
.71104 .39611 L
s
.50452 .4013 m
.50527 .40178 L
s
.5043 .40133 m
.50506 .40181 L
s
.36853 .40915 m
.36916 .40861 L
s
.61668 .40226 m
.61691 .4027 L
s
.50408 .4013 m
.50484 .40178 L
s
.61676 .40226 m
.61698 .4027 L
s
.36857 .40911 m
.3692 .40857 L
s
.27743 .40677 m
.27763 .40629 L
s
.36873 .40911 m
.36936 .40857 L
s
.8254 .25138 m
.8256 .2516 L
s
.50413 .40124 m
.50489 .40172 L
s
.17425 .50628 m
.17421 .50584 L
s
.50396 .40123 m
.50472 .40171 L
s
.50406 .40123 m
.50482 .40171 L
s
.36872 .40899 m
.36935 .40845 L
s
.50411 .40113 m
.50487 .40161 L
s
.27748 .40661 m
.27767 .40613 L
s
.61679 .40208 m
.61702 .40252 L
s
.1633 .41617 m
.16335 .4158 L
s
.36885 .40892 m
.36949 .40839 L
s
.36894 .4089 m
.36957 .40837 L
s
.61659 .40204 m
.61682 .40248 L
s
.71084 .39546 m
.71096 .39583 L
s
.50373 .40112 m
.50449 .4016 L
s
.50375 .40109 m
.50451 .40157 L
s
.16326 .41611 m
.16331 .41573 L
s
.36885 .40881 m
.36949 .40828 L
s
.82521 .25116 m
.8254 .25138 L
s
.71081 .39537 m
.71092 .39574 L
s
.36908 .40875 m
.36971 .40822 L
s
.27767 .40638 m
.27787 .4059 L
s
.36897 .4087 m
.36961 .40817 L
s
.36911 .40868 m
.36975 .40814 L
s
.61645 .40182 m
.61668 .40226 L
s
.61653 .40182 m
.61676 .40226 L
s
.50367 .40087 m
.50444 .40134 L
s
.17421 .50584 m
.17416 .5054 L
s
.36916 .40861 m
.3698 .40808 L
s
.27763 .40629 m
.27783 .40581 L
s
.50376 .40082 m
.50452 .4013 L
s
.50354 .40086 m
.5043 .40133 L
s
.3692 .40857 m
.36983 .40804 L
s
.50331 .40083 m
.50408 .4013 L
s
.36936 .40857 m
.37 .40804 L
s
.50336 .40077 m
.50413 .40124 L
s
.16335 .4158 m
.1634 .41543 L
s
.82501 .25094 m
.82521 .25116 L
s
.50319 .40076 m
.50396 .40123 L
s
.50329 .40076 m
.50406 .40123 L
s
.71072 .39509 m
.71084 .39546 L
s
.61656 .40164 m
.61679 .40208 L
s
.36935 .40845 m
.36999 .40792 L
s
.27767 .40613 m
.27787 .40565 L
s
.16331 .41573 m
.16337 .41536 L
s
.61636 .4016 m
.61659 .40204 L
s
.50335 .40066 m
.50411 .40113 L
s
.36949 .40839 m
.37013 .40786 L
s
.36957 .40837 m
.37022 .40784 L
s
.71069 .39499 m
.71081 .39537 L
s
.50295 .40065 m
.50373 .40112 L
s
.50298 .40062 m
.50375 .40109 L
s
.36949 .40828 m
.37013 .40775 L
s
.36971 .40822 m
.37036 .40769 L
s
.82481 .25072 m
.82501 .25094 L
s
.27787 .4059 m
.27807 .40543 L
s
.61622 .40138 m
.61645 .40182 L
s
.61629 .40138 m
.61653 .40182 L
s
.17416 .5054 m
.17412 .50495 L
s
.36961 .40817 m
.37025 .40764 L
s
.36975 .40814 m
.37039 .40762 L
s
.27783 .40581 m
.27803 .40533 L
s
.1634 .41543 m
.16345 .41506 L
s
.5029 .4004 m
.50367 .40087 L
s
.3698 .40808 m
.37045 .40755 L
s
.7106 .39472 m
.71072 .39509 L
s
.50299 .40035 m
.50376 .40082 L
s
.50276 .40039 m
.50354 .40086 L
s
.36983 .40804 m
.37048 .40751 L
s
.37 .40804 m
.37065 .40752 L
s
.16337 .41536 m
.16342 .41499 L
s
.50253 .40036 m
.50331 .40083 L
s
.61632 .4012 m
.61656 .40164 L
s
.50259 .4003 m
.50336 .40077 L
s
.61612 .40116 m
.61636 .4016 L
s
.71057 .39462 m
.71069 .39499 L
s
.27787 .40565 m
.27808 .40517 L
s
.50241 .4003 m
.50319 .40076 L
s
.82461 .2505 m
.82481 .25072 L
s
.50251 .4003 m
.50329 .40076 L
s
.36999 .40792 m
.37064 .4074 L
s
.50257 .4002 m
.50335 .40066 L
s
.37013 .40786 m
.37078 .40734 L
s
.37022 .40784 m
.37087 .40732 L
s
.50217 .40019 m
.50295 .40065 L
s
.37013 .40775 m
.37079 .40722 L
s
.5022 .40016 m
.50298 .40062 L
s
.17412 .50495 m
.17408 .50451 L
s
.61598 .40094 m
.61622 .40138 L
s
.61605 .40094 m
.61629 .40138 L
s
.27807 .40543 m
.27827 .40495 L
s
.16345 .41506 m
.16351 .41468 L
s
.37036 .40769 m
.37102 .40716 L
s
.71048 .39434 m
.7106 .39472 L
s
.37025 .40764 m
.37091 .40712 L
s
.82442 .25028 m
.82461 .2505 L
s
.16342 .41499 m
.16348 .41462 L
s
.27803 .40533 m
.27824 .40486 L
s
.37039 .40762 m
.37105 .40709 L
s
.37045 .40755 m
.37111 .40703 L
s
.50212 .39994 m
.5029 .4004 L
s
.71045 .39425 m
.71057 .39462 L
s
.61609 .40077 m
.61632 .4012 L
s
.37048 .40751 m
.37114 .40699 L
s
.50221 .39989 m
.50299 .40035 L
s
.50198 .39993 m
.50276 .40039 L
s
.37065 .40752 m
.37132 .40699 L
s
.61588 .40072 m
.61612 .40116 L
s
.50175 .3999 m
.50253 .40036 L
s
.27808 .40517 m
.27829 .4047 L
s
.5018 .39984 m
.50259 .4003 L
s
.37064 .4074 m
.3713 .40688 L
s
.50162 .39984 m
.50241 .4003 L
s
.50173 .39984 m
.50251 .4003 L
s
.82422 .25007 m
.82442 .25028 L
s
.50178 .39974 m
.50257 .4002 L
s
.37078 .40734 m
.37145 .40681 L
s
.37087 .40732 m
.37154 .4068 L
s
.17408 .50451 m
.17404 .50407 L
s
.16351 .41468 m
.16357 .41431 L
s
.61574 .4005 m
.61598 .40094 L
s
.61581 .4005 m
.61605 .40094 L
s
.50138 .39973 m
.50217 .40019 L
s
.71036 .39397 m
.71048 .39434 L
s
.37079 .40722 m
.37145 .4067 L
s
.16348 .41462 m
.16353 .41425 L
s
.50141 .3997 m
.5022 .40016 L
s
.27827 .40495 m
.27848 .40447 L
s
.37102 .40716 m
.37169 .40665 L
s
.71032 .39388 m
.71045 .39425 L
s
.37091 .40712 m
.37157 .4066 L
s
.27824 .40486 m
.27845 .40438 L
s
.37105 .40709 m
.37172 .40657 L
s
.82402 .24985 m
.82422 .25007 L
s
.61584 .40033 m
.61609 .40077 L
s
.37111 .40703 m
.37178 .40651 L
s
.61564 .40029 m
.61588 .40072 L
s
.50133 .39949 m
.50212 .39994 L
s
.37114 .40699 m
.37181 .40647 L
s
.37132 .40699 m
.37199 .40648 L
s
.50142 .39944 m
.50221 .39989 L
s
.50118 .39947 m
.50198 .39993 L
s
.50095 .39945 m
.50175 .3999 L
s
.27829 .4047 m
.2785 .40422 L
s
.501 .39939 m
.5018 .39984 L
s
.16357 .41431 m
.16362 .41394 L
s
.3713 .40688 m
.37198 .40636 L
s
.50082 .39939 m
.50162 .39984 L
s
.50093 .39938 m
.50173 .39984 L
s
.17404 .50407 m
.174 .50362 L
s
.71024 .3936 m
.71036 .39397 L
s
.16353 .41425 m
.16359 .41387 L
s
.37145 .40681 m
.37213 .4063 L
s
.37154 .4068 m
.37222 .40628 L
s
.50098 .39929 m
.50178 .39974 L
s
.61549 .40006 m
.61574 .4005 L
s
.61557 .40007 m
.61581 .4005 L
s
.82382 .24963 m
.82402 .24985 L
s
.7102 .39351 m
.71032 .39388 L
s
.50057 .39928 m
.50138 .39973 L
s
.37145 .4067 m
.37213 .40619 L
s
.27848 .40447 m
.2787 .404 L
s
.50061 .39925 m
.50141 .3997 L
s
.37169 .40665 m
.37237 .40613 L
s
.37157 .4066 m
.37225 .40608 L
s
.27845 .40438 m
.27866 .4039 L
s
.6156 .39989 m
.61584 .40033 L
s
.37172 .40657 m
.3724 .40606 L
s
.61539 .39985 m
.61564 .40029 L
s
.37178 .40651 m
.37246 .406 L
s
.37181 .40647 m
.37249 .40596 L
s
.82362 .24941 m
.82382 .24963 L
s
.16362 .41394 m
.16368 .41357 L
s
.50052 .39904 m
.50133 .39949 L
s
.37199 .40648 m
.37268 .40596 L
s
.50061 .39899 m
.50142 .39944 L
s
.50038 .39903 m
.50118 .39947 L
s
.2785 .40422 m
.27872 .40375 L
s
.71011 .39323 m
.71024 .3936 L
s
.50014 .399 m
.50095 .39945 L
s
.16359 .41387 m
.16365 .4135 L
s
.174 .50362 m
.17397 .50318 L
s
.37198 .40636 m
.37266 .40585 L
s
.5002 .39894 m
.501 .39939 L
s
.50001 .39894 m
.50082 .39939 L
s
.50012 .39894 m
.50093 .39938 L
s
.61525 .39962 m
.61549 .40006 L
s
.61532 .39963 m
.61557 .40007 L
s
.71008 .39314 m
.7102 .39351 L
s
.37213 .4063 m
.37281 .40579 L
s
.37222 .40628 m
.37291 .40577 L
s
.50018 .39884 m
.50098 .39929 L
s
.82342 .24919 m
.82362 .24941 L
s
.2787 .404 m
.27892 .40352 L
s
.37213 .40619 m
.37281 .40568 L
s
.49976 .39884 m
.50057 .39928 L
s
.49979 .39881 m
.50061 .39925 L
s
.37237 .40613 m
.37306 .40562 L
s
.61535 .39945 m
.6156 .39989 L
s
.27866 .4039 m
.27888 .40343 L
s
.37225 .40608 m
.37294 .40557 L
s
.61514 .39941 m
.61539 .39985 L
s
.16368 .41357 m
.16375 .41319 L
s
.3724 .40606 m
.3731 .40555 L
s
.37246 .406 m
.37315 .40549 L
s
.70999 .39286 m
.71011 .39323 L
s
.16365 .4135 m
.16371 .41313 L
s
.37249 .40596 m
.37318 .40545 L
s
.37268 .40596 m
.37337 .40546 L
s
.17397 .50318 m
.17393 .50274 L
s
.49971 .3986 m
.50052 .39904 L
s
.27872 .40375 m
.27893 .40327 L
s
.4998 .39855 m
.50061 .39899 L
s
.49957 .39858 m
.50038 .39903 L
s
.82321 .24898 m
.82342 .24919 L
s
.70995 .39276 m
.71008 .39314 L
s
.49933 .39856 m
.50014 .399 L
s
.37266 .40585 m
.37336 .40534 L
s
.615 .39919 m
.61525 .39962 L
s
.61507 .39919 m
.61532 .39963 L
s
.49938 .3985 m
.5002 .39894 L
s
.49919 .3985 m
.50001 .39894 L
s
.4993 .3985 m
.50012 .39894 L
s
.37291 .40577 m
.3736 .40526 L
s
.37281 .40579 m
.37351 .40528 L
s
.49936 .3984 m
.50018 .39884 L
s
.27892 .40352 m
.27914 .40305 L
s
.37281 .40568 m
.37351 .40517 L
s
.16375 .41319 m
.16381 .41282 L
s
.49894 .3984 m
.49976 .39884 L
s
.6151 .39902 m
.61535 .39945 L
s
.37306 .40562 m
.37376 .40512 L
s
.82301 .24876 m
.82321 .24898 L
s
.49897 .39837 m
.49979 .39881 L
s
.61489 .39897 m
.61514 .39941 L
s
.27888 .40343 m
.2791 .40295 L
s
.16371 .41313 m
.16378 .41276 L
s
.37294 .40557 m
.37364 .40507 L
s
.70986 .39249 m
.70999 .39286 L
s
.3731 .40555 m
.3738 .40505 L
s
.17393 .50274 m
.1739 .50229 L
s
.37315 .40549 m
.37385 .40499 L
s
.70982 .39239 m
.70995 .39276 L
s
.37318 .40545 m
.37389 .40495 L
s
.37337 .40546 m
.37408 .40495 L
s
.27893 .40327 m
.27916 .4028 L
s
.49889 .39816 m
.49971 .3986 L
s
.49898 .39811 m
.4998 .39855 L
s
.49874 .39815 m
.49957 .39858 L
s
.61474 .39875 m
.615 .39919 L
s
.61482 .39875 m
.61507 .39919 L
s
.4985 .39813 m
.49933 .39856 L
s
.37336 .40534 m
.37406 .40484 L
s
.82281 .24854 m
.82301 .24876 L
s
.49856 .39807 m
.49938 .3985 L
s
.49836 .39807 m
.49919 .3985 L
s
.3736 .40526 m
.37431 .40476 L
s
.37351 .40528 m
.37422 .40478 L
s
.49848 .39806 m
.4993 .3985 L
s
.16381 .41282 m
.16387 .41245 L
s
.49853 .39797 m
.49936 .3984 L
s
.27914 .40305 m
.27936 .40257 L
s
.61485 .39858 m
.6151 .39902 L
s
.37351 .40517 m
.37422 .40467 L
s
.16378 .41276 m
.16384 .41238 L
s
.70973 .39212 m
.70986 .39249 L
s
.61464 .39854 m
.61489 .39897 L
s
.49811 .39797 m
.49894 .3984 L
s
.37376 .40512 m
.37447 .40462 L
s
.49814 .39794 m
.49897 .39837 L
s
.2791 .40295 m
.27933 .40248 L
s
.37364 .40507 m
.37434 .40457 L
s
.70969 .39202 m
.70982 .39239 L
s
.1739 .50229 m
.17387 .50184 L
s
.3738 .40505 m
.37451 .40455 L
s
.8226 .24833 m
.82281 .24854 L
s
.37385 .40499 m
.37456 .40449 L
s
.37389 .40495 m
.3746 .40445 L
s
.37408 .40495 m
.37479 .40446 L
s
.27916 .4028 m
.27938 .40232 L
s
.49806 .39773 m
.49889 .39816 L
s
.61449 .39832 m
.61474 .39875 L
s
.61456 .39832 m
.61482 .39875 L
s
.49815 .39768 m
.49898 .39811 L
s
.49791 .39772 m
.49874 .39815 L
s
.16387 .41245 m
.16394 .41208 L
s
.49766 .3977 m
.4985 .39813 L
s
.37406 .40484 m
.37477 .40434 L
s
.49772 .39764 m
.49856 .39807 L
s
.37431 .40476 m
.37503 .40427 L
s
.37422 .40478 m
.37494 .40429 L
s
.16384 .41238 m
.16391 .41201 L
s
.49752 .39764 m
.49836 .39807 L
s
.49764 .39764 m
.49848 .39806 L
s
.8224 .24811 m
.8226 .24833 L
s
.7096 .39174 m
.70973 .39212 L
s
.61459 .39814 m
.61485 .39858 L
s
.4977 .39754 m
.49853 .39797 L
s
.27936 .40257 m
.27959 .4021 L
s
.37422 .40467 m
.37493 .40418 L
s
.61438 .3981 m
.61464 .39854 L
s
.70956 .39165 m
.70969 .39202 L
s
.37447 .40462 m
.37519 .40412 L
s
.49727 .39755 m
.49811 .39797 L
s
.17387 .50184 m
.17384 .5014 L
s
.27933 .40248 m
.27956 .40201 L
s
.49731 .39752 m
.49814 .39794 L
s
.37434 .40457 m
.37506 .40407 L
s
.37451 .40455 m
.37523 .40406 L
s
.37456 .40449 m
.37529 .40399 L
s
.3746 .40445 m
.37532 .40395 L
s
.37479 .40446 m
.37552 .40397 L
s
.8222 .24789 m
.8224 .24811 L
s
.61422 .39788 m
.61449 .39832 L
s
.16394 .41208 m
.16401 .4117 L
s
.6143 .39788 m
.61456 .39832 L
s
.27938 .40232 m
.27962 .40185 L
s
.49722 .39731 m
.49806 .39773 L
s
.49707 .3973 m
.49791 .39772 L
s
.49732 .39726 m
.49815 .39768 L
s
.16391 .41201 m
.16397 .41164 L
s
.37477 .40434 m
.3755 .40385 L
s
.70947 .39137 m
.7096 .39174 L
s
.49682 .39728 m
.49766 .3977 L
s
.49688 .39722 m
.49772 .39764 L
s
.37503 .40427 m
.37576 .40378 L
s
.37494 .40429 m
.37566 .4038 L
s
.49668 .39723 m
.49752 .39764 L
s
.61433 .39771 m
.61459 .39814 L
s
.4968 .39722 m
.49764 .39764 L
s
.70943 .39128 m
.70956 .39165 L
s
.61412 .39767 m
.61438 .3981 L
s
.49685 .39712 m
.4977 .39754 L
s
.37493 .40418 m
.37566 .40369 L
s
.27959 .4021 m
.27982 .40163 L
s
.82199 .24768 m
.8222 .24789 L
s
.17384 .5014 m
.17381 .50095 L
s
.37519 .40412 m
.37592 .40364 L
s
.49642 .39713 m
.49727 .39755 L
s
.37506 .40407 m
.37579 .40358 L
s
.27956 .40201 m
.27979 .40153 L
s
.49646 .3971 m
.49731 .39752 L
s
.37523 .40406 m
.37596 .40357 L
s
.16401 .4117 m
.16407 .41133 L
s
.37529 .40399 m
.37602 .40351 L
s
.37532 .40395 m
.37605 .40347 L
s
.37552 .40397 m
.37625 .40348 L
s
.61396 .39745 m
.61422 .39788 L
s
.61404 .39745 m
.6143 .39788 L
s
.16397 .41164 m
.16404 .41127 L
s
.70933 .391 m
.70947 .39137 L
s
.27962 .40185 m
.27985 .40138 L
s
.49637 .39689 m
.49722 .39731 L
s
.82178 .24746 m
.82199 .24768 L
s
.3755 .40385 m
.37623 .40336 L
s
.49622 .39689 m
.49707 .3973 L
s
.49647 .39685 m
.49732 .39726 L
s
.49597 .39687 m
.49682 .39728 L
s
.70929 .39091 m
.70943 .39128 L
s
.37576 .40378 m
.3765 .40329 L
s
.37566 .4038 m
.3764 .40331 L
s
.49602 .39681 m
.49688 .39722 L
s
.61406 .39727 m
.61433 .39771 L
s
.49582 .39681 m
.49668 .39723 L
s
.49594 .39681 m
.4968 .39722 L
s
.61385 .39723 m
.61412 .39767 L
s
.17381 .50095 m
.17378 .5005 L
s
.37566 .40369 m
.3764 .4032 L
s
.496 .39671 m
.49685 .39712 L
s
.27982 .40163 m
.28006 .40115 L
s
.37592 .40364 m
.37667 .40315 L
s
.49556 .39672 m
.49642 .39713 L
s
.16407 .41133 m
.16414 .41096 L
s
.37579 .40358 m
.37653 .4031 L
s
.82158 .24725 m
.82178 .24746 L
s
.27979 .40153 m
.28003 .40106 L
s
.4956 .39669 m
.49646 .3971 L
s
.37596 .40357 m
.3767 .40308 L
s
.16404 .41127 m
.16411 .4109 L
s
.37602 .40351 m
.37676 .40302 L
s
.7092 .39063 m
.70933 .391 L
s
.61369 .39701 m
.61396 .39745 L
s
.37605 .40347 m
.37679 .40298 L
s
.61377 .39701 m
.61404 .39745 L
s
.37625 .40348 m
.377 .403 L
s
.27985 .40138 m
.28009 .40091 L
s
.70916 .39054 m
.70929 .39091 L
s
.49552 .39648 m
.49637 .39689 L
s
.37623 .40336 m
.37698 .40288 L
s
.49536 .39648 m
.49622 .39689 L
s
.49561 .39644 m
.49647 .39685 L
s
.4951 .39646 m
.49597 .39687 L
s
.3765 .40329 m
.37725 .40281 L
s
.6138 .39684 m
.61406 .39727 L
s
.3764 .40331 m
.37715 .40283 L
s
.82137 .24703 m
.82158 .24725 L
s
.49516 .3964 m
.49602 .39681 L
s
.61358 .3968 m
.61385 .39723 L
s
.17378 .5005 m
.17375 .50005 L
s
.49496 .39641 m
.49582 .39681 L
s
.49508 .3964 m
.49594 .39681 L
s
.3764 .4032 m
.37714 .40272 L
s
.16414 .41096 m
.16422 .41059 L
s
.49514 .39631 m
.496 .39671 L
s
.37667 .40315 m
.37742 .40267 L
s
.28006 .40115 m
.2803 .40068 L
s
.16411 .4109 m
.16418 .41052 L
s
.49469 .39632 m
.49556 .39672 L
s
.37653 .4031 m
.37728 .40262 L
s
.3767 .40308 m
.37745 .40261 L
s
.70906 .39026 m
.7092 .39063 L
s
.49473 .39629 m
.4956 .39669 L
s
.28003 .40106 m
.28027 .40059 L
s
.37676 .40302 m
.37751 .40254 L
s
.61342 .39658 m
.61369 .39701 L
s
.6135 .39658 m
.61377 .39701 L
s
.37679 .40298 m
.37754 .40251 L
s
.377 .403 m
.37776 .40252 L
s
.82116 .24682 m
.82137 .24703 L
s
.70902 .39017 m
.70916 .39054 L
s
.28009 .40091 m
.28033 .40044 L
s
.49465 .39608 m
.49552 .39648 L
s
.37698 .40288 m
.37773 .40241 L
s
.49449 .39608 m
.49536 .39648 L
s
.49475 .39604 m
.49561 .39644 L
s
.49423 .39606 m
.4951 .39646 L
s
.61353 .39641 m
.6138 .39684 L
s
.37725 .40281 m
.37801 .40234 L
s
.37715 .40283 m
.3779 .40235 L
s
.17375 .50005 m
.17373 .49961 L
s
.16422 .41059 m
.16429 .41022 L
s
.61331 .39636 m
.61358 .3968 L
s
.49429 .396 m
.49516 .3964 L
s
.49408 .39601 m
.49496 .39641 L
s
.49421 .396 m
.49508 .3964 L
s
.37714 .40272 m
.3779 .40225 L
s
.16418 .41052 m
.16426 .41015 L
s
.82095 .2466 m
.82116 .24682 L
s
.49427 .39591 m
.49514 .39631 L
s
.37742 .40267 m
.37818 .4022 L
s
.2803 .40068 m
.28054 .40021 L
s
.70892 .38989 m
.70906 .39026 L
s
.37728 .40262 m
.37803 .40214 L
s
.49382 .39592 m
.49469 .39632 L
s
.37745 .40261 m
.37821 .40213 L
s
.49386 .39589 m
.49473 .39629 L
s
.37751 .40254 m
.37827 .40207 L
s
.28027 .40059 m
.28051 .40012 L
s
.61315 .39614 m
.61342 .39658 L
s
.70888 .3898 m
.70902 .39017 L
s
.61323 .39615 m
.6135 .39658 L
s
.37754 .40251 m
.3783 .40203 L
s
.37776 .40252 m
.37852 .40205 L
s
.37773 .40241 m
.3785 .40194 L
s
.82074 .24639 m
.82095 .2466 L
s
.49378 .39569 m
.49465 .39608 L
s
.28033 .40044 m
.28058 .39997 L
s
.16429 .41022 m
.16436 .40984 L
s
.49362 .39568 m
.49449 .39608 L
s
.49387 .39564 m
.49475 .39604 L
s
.61325 .39597 m
.61353 .39641 L
s
.37801 .40234 m
.37877 .40187 L
s
.3779 .40235 m
.37867 .40189 L
s
.49335 .39567 m
.49423 .39606 L
s
.17373 .49961 m
.17371 .49916 L
s
.61304 .39593 m
.61331 .39636 L
s
.16426 .41015 m
.16433 .40978 L
s
.49341 .39561 m
.49429 .396 L
s
.4932 .39562 m
.49408 .39601 L
s
.3779 .40225 m
.37867 .40178 L
s
.49333 .39561 m
.49421 .396 L
s
.70878 .38952 m
.70892 .38989 L
s
.37818 .4022 m
.37895 .40173 L
s
.49339 .39551 m
.49427 .39591 L
s
.37803 .40214 m
.3788 .40168 L
s
.28054 .40021 m
.28079 .39974 L
s
.49293 .39553 m
.49382 .39592 L
s
.37821 .40213 m
.37899 .40167 L
s
.70874 .38943 m
.70888 .3898 L
s
.82053 .24617 m
.82074 .24639 L
s
.49298 .3955 m
.49386 .39589 L
s
.37827 .40207 m
.37904 .40161 L
s
.61288 .39571 m
.61315 .39614 L
s
.61295 .39572 m
.61323 .39615 L
s
.3783 .40203 m
.37907 .40157 L
s
.28051 .40012 m
.28076 .39965 L
s
.37852 .40205 m
.3793 .40158 L
s
.16436 .40984 m
.16444 .40947 L
s
.3785 .40194 m
.37927 .40147 L
s
.49289 .3953 m
.49378 .39569 L
s
.28058 .39997 m
.28082 .3995 L
s
.49273 .39529 m
.49362 .39568 L
s
.17371 .49916 m
.17369 .49871 L
s
.61298 .39554 m
.61325 .39597 L
s
.49299 .39525 m
.49387 .39564 L
s
.37877 .40187 m
.37955 .4014 L
s
.16433 .40978 m
.16441 .40941 L
s
.37867 .40189 m
.37945 .40142 L
s
.49246 .39528 m
.49335 .39567 L
s
.61276 .3955 m
.61304 .39593 L
s
.82032 .24596 m
.82053 .24617 L
s
.70864 .38915 m
.70878 .38952 L
s
.49253 .39522 m
.49341 .39561 L
s
.37867 .40178 m
.37944 .40131 L
s
.49231 .39523 m
.4932 .39562 L
s
.49244 .39522 m
.49333 .39561 L
s
.37895 .40173 m
.37973 .40127 L
s
.4925 .39513 m
.49339 .39551 L
s
.7086 .38906 m
.70874 .38943 L
s
.3788 .40168 m
.37958 .40121 L
s
.37899 .40167 m
.37977 .4012 L
s
.49204 .39515 m
.49293 .39553 L
s
.28079 .39974 m
.28104 .39927 L
s
.37904 .40161 m
.37982 .40114 L
s
.49209 .39512 m
.49298 .3955 L
s
.6126 .39528 m
.61288 .39571 L
s
.61267 .39528 m
.61295 .39572 L
s
.37907 .40157 m
.37985 .40111 L
s
.3793 .40158 m
.38008 .40112 L
s
.28076 .39965 m
.28101 .39918 L
s
.16444 .40947 m
.16452 .4091 L
s
.82011 .24575 m
.82032 .24596 L
s
.37927 .40147 m
.38005 .40101 L
s
.16441 .40941 m
.16449 .40903 L
s
.492 .39492 m
.49289 .3953 L
s
.17369 .49871 m
.17367 .49826 L
s
.37955 .4014 m
.38034 .40095 L
s
.37945 .40142 m
.38023 .40096 L
s
.6127 .39511 m
.61298 .39554 L
s
.49184 .39491 m
.49273 .39529 L
s
.4921 .39487 m
.49299 .39525 L
s
.7085 .38878 m
.70864 .38915 L
s
.49157 .3949 m
.49246 .39528 L
s
.28082 .3995 m
.28108 .39903 L
s
.61248 .39507 m
.61276 .3955 L
s
.49163 .39484 m
.49253 .39522 L
s
.37944 .40131 m
.38023 .40086 L
s
.49141 .39486 m
.49231 .39523 L
s
.49155 .39484 m
.49244 .39522 L
s
.37973 .40127 m
.38051 .40081 L
s
.70845 .38869 m
.7086 .38906 L
s
.49161 .39475 m
.4925 .39513 L
s
.37958 .40121 m
.38036 .40075 L
s
.8199 .24553 m
.82011 .24575 L
s
.37977 .4012 m
.38055 .40075 L
s
.49114 .39477 m
.49204 .39515 L
s
.37982 .40114 m
.38061 .40069 L
s
.49119 .39474 m
.49209 .39512 L
s
.28104 .39927 m
.28129 .3988 L
s
.37985 .40111 m
.38064 .40065 L
s
.38008 .40112 m
.38087 .40067 L
s
.61231 .39485 m
.6126 .39528 L
s
.16452 .4091 m
.1646 .40873 L
s
.61239 .39485 m
.61267 .39528 L
s
.16449 .40903 m
.16457 .40866 L
s
.28101 .39918 m
.28127 .39871 L
s
.38005 .40101 m
.38084 .40056 L
s
.17367 .49826 m
.17365 .49781 L
s
.70835 .38841 m
.7085 .38878 L
s
.4911 .39454 m
.492 .39492 L
s
.38034 .40095 m
.38113 .40049 L
s
.38023 .40096 m
.38103 .40051 L
s
.61241 .39468 m
.6127 .39511 L
s
.49094 .39454 m
.49184 .39491 L
s
.4912 .3945 m
.4921 .39487 L
s
.81969 .24532 m
.8199 .24553 L
s
.49066 .39453 m
.49157 .3949 L
s
.61219 .39464 m
.61248 .39507 L
s
.28108 .39903 m
.28133 .39856 L
s
.49073 .39447 m
.49163 .39484 L
s
.38023 .40086 m
.38102 .4004 L
s
.70831 .38832 m
.70845 .38869 L
s
.49051 .39449 m
.49141 .39486 L
s
.38051 .40081 m
.38131 .40036 L
s
.49064 .39447 m
.49155 .39484 L
s
.4907 .39438 m
.49161 .39475 L
s
.38036 .40075 m
.38116 .4003 L
s
.38055 .40075 m
.38135 .4003 L
s
.49023 .39441 m
.49114 .39477 L
s
.38061 .40069 m
.38141 .40024 L
s
.1646 .40873 m
.16468 .40835 L
s
.49028 .39437 m
.49119 .39474 L
s
.38064 .40065 m
.38144 .4002 L
s
.38087 .40067 m
.38168 .40022 L
s
.61203 .39442 m
.61231 .39485 L
s
.61211 .39442 m
.61239 .39485 L
s
.81947 .24511 m
.81969 .24532 L
s
.16457 .40866 m
.16465 .40829 L
s
.28129 .3988 m
.28155 .39833 L
s
.38084 .40056 m
.38165 .40011 L
s
.7082 .38804 m
.70835 .38841 L
s
.28127 .39871 m
.28153 .39825 L
s
.17365 .49781 m
.17363 .49735 L
s
.38113 .40049 m
.38194 .40005 L
s
.38103 .40051 m
.38183 .40006 L
s
.4902 .39418 m
.4911 .39454 L
s
.49003 .39418 m
.49094 .39454 L
s
.4903 .39413 m
.4912 .3945 L
s
.61213 .39425 m
.61241 .39468 L
s
.48975 .39417 m
.49066 .39453 L
s
.70816 .38795 m
.70831 .38832 L
s
.61191 .39421 m
.61219 .39464 L
s
.38102 .4004 m
.38182 .39996 L
s
.48982 .39411 m
.49073 .39447 L
s
.38131 .40036 m
.38212 .39992 L
s
.48959 .39412 m
.49051 .39449 L
s
.48973 .39411 m
.49064 .39447 L
s
.28133 .39856 m
.28159 .39809 L
s
.81926 .24489 m
.81947 .24511 L
s
.38116 .4003 m
.38196 .39986 L
s
.48979 .39402 m
.4907 .39438 L
s
.38135 .4003 m
.38216 .39985 L
s
.16468 .40835 m
.16476 .40798 L
s
.38141 .40024 m
.38222 .39979 L
s
.48932 .39405 m
.49023 .39441 L
s
.38144 .4002 m
.38225 .39975 L
s
.38168 .40022 m
.38249 .39978 L
s
.48937 .39401 m
.49028 .39437 L
s
.16465 .40829 m
.16473 .40792 L
s
.61174 .39399 m
.61203 .39442 L
s
.61182 .39399 m
.61211 .39442 L
s
.70806 .38767 m
.7082 .38804 L
s
.28155 .39833 m
.28181 .39787 L
s
.38165 .40011 m
.38246 .39967 L
s
.38194 .40005 m
.38275 .39961 L
s
.38183 .40006 m
.38264 .39962 L
s
.17363 .49735 m
.17361 .4969 L
s
.48928 .39382 m
.4902 .39418 L
s
.81905 .24468 m
.81926 .24489 L
s
.28153 .39825 m
.28179 .39778 L
s
.48911 .39382 m
.49003 .39418 L
s
.70801 .38758 m
.70816 .38795 L
s
.48938 .39377 m
.4903 .39413 L
s
.48883 .39381 m
.48975 .39417 L
s
.61184 .39382 m
.61213 .39425 L
s
.38182 .39996 m
.38264 .39952 L
s
.4889 .39375 m
.48982 .39411 L
s
.38212 .39992 m
.38294 .39948 L
s
.61161 .39378 m
.61191 .39421 L
s
.48867 .39377 m
.48959 .39412 L
s
.48881 .39375 m
.48973 .39411 L
s
.16476 .40798 m
.16484 .40761 L
s
.38196 .39986 m
.38277 .39942 L
s
.48887 .39366 m
.48979 .39402 L
s
.28159 .39809 m
.28186 .39762 L
s
.38216 .39985 m
.38298 .39942 L
s
.38222 .39979 m
.38304 .39936 L
s
.48839 .39369 m
.48932 .39405 L
s
.16473 .40792 m
.16481 .40755 L
s
.38225 .39975 m
.38307 .39932 L
s
.38249 .39978 m
.38331 .39934 L
s
.48844 .39366 m
.48937 .39401 L
s
.81883 .24447 m
.81905 .24468 L
s
.61145 .39356 m
.61174 .39399 L
s
.61152 .39356 m
.61182 .39399 L
s
.70791 .3873 m
.70806 .38767 L
s
.38246 .39967 m
.38328 .39923 L
s
.38275 .39961 m
.38358 .39917 L
s
.38264 .39962 m
.38347 .39919 L
s
.28181 .39787 m
.28208 .3974 L
s
.17361 .4969 m
.1736 .49645 L
s
.48836 .39346 m
.48928 .39382 L
s
.70786 .38721 m
.70801 .38758 L
s
.48819 .39347 m
.48911 .39382 L
s
.48846 .39342 m
.48938 .39377 L
s
.4879 .39346 m
.48883 .39381 L
s
.38264 .39952 m
.38346 .39908 L
s
.28179 .39778 m
.28206 .39731 L
s
.61154 .39339 m
.61184 .39382 L
s
.38294 .39948 m
.38376 .39905 L
s
.48797 .3934 m
.4889 .39375 L
s
.48774 .39342 m
.48867 .39377 L
s
.61132 .39335 m
.61161 .39378 L
s
.48789 .3934 m
.48881 .39375 L
s
.16484 .40761 m
.16493 .40724 L
s
.81861 .24426 m
.81883 .24447 L
s
.38277 .39942 m
.38359 .39898 L
s
.38298 .39942 m
.3838 .39898 L
s
.48795 .39331 m
.48887 .39366 L
s
.38304 .39936 m
.38386 .39892 L
s
.16481 .40755 m
.1649 .40717 L
s
.48746 .39335 m
.48839 .39369 L
s
.38331 .39934 m
.38414 .39891 L
s
.38307 .39932 m
.38389 .39888 L
s
.28186 .39762 m
.28213 .39716 L
s
.48751 .39331 m
.48844 .39366 L
s
.70776 .38693 m
.70791 .3873 L
s
.38328 .39923 m
.3841 .3988 L
s
.61115 .39313 m
.61145 .39356 L
s
.61123 .39314 m
.61152 .39356 L
s
.38358 .39917 m
.38441 .39874 L
s
.38347 .39919 m
.3843 .39876 L
s
.70771 .38684 m
.70786 .38721 L
s
.8184 .24404 m
.81861 .24426 L
s
.48743 .39312 m
.48836 .39346 L
s
.1736 .49645 m
.17359 .496 L
s
.48725 .39312 m
.48819 .39347 L
s
.48753 .39307 m
.48846 .39342 L
s
.28208 .3974 m
.28235 .39694 L
s
.48697 .39312 m
.4879 .39346 L
s
.38346 .39908 m
.38429 .39865 L
s
.38376 .39905 m
.38459 .39862 L
s
.48704 .39306 m
.48797 .3934 L
s
.61125 .39296 m
.61154 .39339 L
s
.16493 .40724 m
.16501 .40687 L
s
.48681 .39308 m
.48774 .39342 L
s
.48695 .39306 m
.48789 .3934 L
s
.28206 .39731 m
.28233 .39685 L
s
.38359 .39898 m
.38442 .39855 L
s
.61102 .39292 m
.61132 .39335 L
s
.3838 .39898 m
.38464 .39856 L
s
.48701 .39297 m
.48795 .39331 L
s
.1649 .40717 m
.16498 .4068 L
s
.38386 .39892 m
.3847 .3985 L
s
.38414 .39891 m
.38498 .39848 L
s
.38389 .39888 m
.38473 .39846 L
s
.48652 .39301 m
.48746 .39335 L
s
.48658 .39297 m
.48751 .39331 L
s
.81818 .24383 m
.8184 .24404 L
s
.70761 .38656 m
.70776 .38693 L
s
.28213 .39716 m
.2824 .39669 L
s
.3841 .3988 m
.38494 .39838 L
s
.38441 .39874 m
.38525 .39832 L
s
.61085 .3927 m
.61115 .39313 L
s
.3843 .39876 m
.38514 .39833 L
s
.61093 .39271 m
.61123 .39314 L
s
.70756 .38647 m
.70771 .38684 L
s
.48649 .39278 m
.48743 .39312 L
s
.48632 .39278 m
.48725 .39312 L
s
.4866 .39274 m
.48753 .39307 L
s
.17359 .496 m
.17358 .49554 L
s
.38429 .39865 m
.38513 .39823 L
s
.48603 .39278 m
.48697 .39312 L
s
.38459 .39862 m
.38544 .3982 L
s
.16501 .40687 m
.1651 .40649 L
s
.48609 .39272 m
.48704 .39306 L
s
.48586 .39274 m
.48681 .39308 L
s
.28235 .39694 m
.28262 .39647 L
s
.48601 .39273 m
.48695 .39306 L
s
.38442 .39855 m
.38526 .39813 L
s
.61095 .39254 m
.61125 .39296 L
s
.38464 .39856 m
.38548 .39813 L
s
.81796 .24362 m
.81818 .24383 L
s
.16498 .4068 m
.16507 .40643 L
s
.48607 .39264 m
.48701 .39297 L
s
.3847 .3985 m
.38554 .39808 L
s
.61072 .39249 m
.61102 .39292 L
s
.28233 .39685 m
.2826 .39638 L
s
.38498 .39848 m
.38582 .39806 L
s
.38473 .39846 m
.38557 .39804 L
s
.48558 .39268 m
.48652 .39301 L
s
.48563 .39264 m
.48658 .39297 L
s
.70745 .38619 m
.70761 .38656 L
s
.38494 .39838 m
.38579 .39796 L
s
.38525 .39832 m
.3861 .3979 L
s
.38514 .39833 m
.38598 .39792 L
s
.2824 .39669 m
.28267 .39623 L
s
.70741 .3861 m
.70756 .38647 L
s
.61055 .39228 m
.61085 .3927 L
s
.61063 .39228 m
.61093 .39271 L
s
.48555 .39245 m
.48649 .39278 L
s
.38513 .39823 m
.38597 .39781 L
s
.48537 .39245 m
.48632 .39278 L
s
.81775 .24341 m
.81796 .24362 L
s
.48565 .39241 m
.4866 .39274 L
s
.48508 .39246 m
.48603 .39278 L
s
.38544 .3982 m
.38629 .39778 L
s
.17358 .49554 m
.17357 .49509 L
s
.1651 .40649 m
.16519 .40612 L
s
.48515 .39239 m
.48609 .39272 L
s
.48491 .39242 m
.48586 .39274 L
s
.38526 .39813 m
.38611 .39771 L
s
.48506 .3924 m
.48601 .39273 L
s
.38548 .39813 m
.38633 .39772 L
s
.16507 .40643 m
.16516 .40606 L
s
.38554 .39808 m
.38639 .39766 L
s
.48512 .39231 m
.48607 .39264 L
s
.61065 .39211 m
.61095 .39254 L
s
.28262 .39647 m
.2829 .39601 L
s
.38582 .39806 m
.38668 .39765 L
s
.38557 .39804 m
.38642 .39762 L
s
.48462 .39235 m
.48558 .39268 L
s
.61042 .39206 m
.61072 .39249 L
s
.48468 .39232 m
.48563 .39264 L
s
.2826 .39638 m
.28288 .39592 L
s
.7073 .38582 m
.70745 .38619 L
s
.38579 .39796 m
.38664 .39754 L
s
.81753 .2432 m
.81775 .24341 L
s
.3861 .3979 m
.38696 .39749 L
s
.38598 .39792 m
.38684 .39751 L
s
.70725 .38573 m
.70741 .3861 L
s
.4846 .39213 m
.48555 .39245 L
s
.38597 .39781 m
.38683 .3974 L
s
.48442 .39213 m
.48537 .39245 L
s
.28267 .39623 m
.28295 .39577 L
s
.38629 .39778 m
.38715 .39737 L
s
.4847 .39208 m
.48565 .39241 L
s
.48412 .39213 m
.48508 .39246 L
s
.61024 .39185 m
.61055 .39228 L
s
.61033 .39185 m
.61063 .39228 L
s
.16519 .40612 m
.16528 .40575 L
s
.48419 .39207 m
.48515 .39239 L
s
.48395 .3921 m
.48491 .39242 L
s
.17357 .49509 m
.17356 .49464 L
s
.38611 .39771 m
.38697 .3973 L
s
.38633 .39772 m
.38719 .39731 L
s
.48411 .39208 m
.48506 .3924 L
s
.38639 .39766 m
.38725 .39725 L
s
.16516 .40606 m
.16525 .40569 L
s
.48417 .39199 m
.48512 .39231 L
s
.38668 .39765 m
.38754 .39725 L
s
.38642 .39762 m
.38728 .39721 L
s
.81731 .24299 m
.81753 .2432 L
s
.48366 .39203 m
.48462 .39235 L
s
.61034 .39168 m
.61065 .39211 L
s
.48372 .392 m
.48468 .39232 L
s
.2829 .39601 m
.28318 .39554 L
s
.38664 .39754 m
.3875 .39714 L
s
.61011 .39164 m
.61042 .39206 L
s
.70714 .38546 m
.7073 .38582 L
s
.38696 .39749 m
.38782 .39709 L
s
.38684 .39751 m
.38771 .3971 L
s
.28288 .39592 m
.28316 .39546 L
s
.70709 .38536 m
.70725 .38573 L
s
.48364 .39181 m
.4846 .39213 L
s
.38683 .3974 m
.38769 .39699 L
s
.38715 .39737 m
.38801 .39697 L
s
.48346 .39182 m
.48442 .39213 L
s
.48316 .39182 m
.48412 .39213 L
s
.48374 .39177 m
.4847 .39208 L
s
.16528 .40575 m
.16537 .40538 L
s
.48323 .39176 m
.48419 .39207 L
s
.81709 .24278 m
.81731 .24299 L
s
.38697 .3973 m
.38783 .3969 L
s
.48299 .39179 m
.48395 .3921 L
s
.60994 .39142 m
.61024 .39185 L
s
.38719 .39731 m
.38806 .39691 L
s
.61002 .39143 m
.61033 .39185 L
s
.48314 .39177 m
.48411 .39208 L
s
.28295 .39577 m
.28323 .3953 L
s
.38725 .39725 m
.38812 .39685 L
s
.17356 .49464 m
.17355 .49418 L
s
.16525 .40569 m
.16535 .40531 L
s
.38754 .39725 m
.38841 .39684 L
s
.48321 .39168 m
.48417 .39199 L
s
.38728 .39721 m
.38815 .39681 L
s
.4827 .39173 m
.48366 .39203 L
s
.48276 .39169 m
.48372 .392 L
s
.3875 .39714 m
.38837 .39674 L
s
.61003 .39126 m
.61034 .39168 L
s
.70698 .38509 m
.70714 .38546 L
s
.38782 .39709 m
.3887 .39669 L
s
.38771 .3971 m
.38858 .3967 L
s
.6098 .39121 m
.61011 .39164 L
s
.28318 .39554 m
.28346 .39508 L
s
.81687 .24257 m
.81709 .24278 L
s
.38769 .39699 m
.38856 .39659 L
s
.70693 .385 m
.70709 .38536 L
s
.48267 .39151 m
.48364 .39181 L
s
.38801 .39697 m
.38889 .39657 L
s
.48249 .39151 m
.48346 .39182 L
s
.48219 .39152 m
.48316 .39182 L
s
.48278 .39146 m
.48374 .39177 L
s
.28316 .39546 m
.28344 .39499 L
s
.48226 .39145 m
.48323 .39176 L
s
.38783 .3969 m
.3887 .3965 L
s
.16537 .40538 m
.16547 .40501 L
s
.38806 .39691 m
.38893 .39651 L
s
.48202 .39148 m
.48299 .39179 L
s
.48217 .39146 m
.48314 .39177 L
s
.38812 .39685 m
.389 .39645 L
s
.38841 .39684 m
.38929 .39645 L
s
.38815 .39681 m
.38902 .39641 L
s
.48224 .39137 m
.48321 .39168 L
s
.16535 .40531 m
.16544 .40494 L
s
.60963 .391 m
.60994 .39142 L
s
.60971 .391 m
.61002 .39143 L
s
.48172 .39142 m
.4827 .39173 L
s
.17355 .49418 m
.17355 .49373 L
s
.28323 .3953 m
.28352 .39484 L
s
.48179 .39139 m
.48276 .39169 L
s
.38837 .39674 m
.38925 .39634 L
s
.81665 .24236 m
.81687 .24257 L
s
.3887 .39669 m
.38958 .3963 L
s
.38858 .3967 m
.38946 .39631 L
s
.70682 .38472 m
.70698 .38509 L
s
.60972 .39083 m
.61003 .39126 L
s
.38856 .39659 m
.38944 .3962 L
s
.38889 .39657 m
.38977 .39618 L
s
.4817 .3912 m
.48267 .39151 L
s
.60949 .39079 m
.6098 .39121 L
s
.48152 .39121 m
.48249 .39151 L
s
.70677 .38463 m
.70693 .385 L
s
.48121 .39122 m
.48219 .39152 L
s
.48181 .39116 m
.48278 .39146 L
s
.28346 .39508 m
.28375 .39462 L
s
.3887 .3965 m
.38958 .39611 L
s
.48128 .39116 m
.48226 .39145 L
s
.38893 .39651 m
.38982 .39612 L
s
.48104 .39119 m
.48202 .39148 L
s
.16547 .40501 m
.16556 .40463 L
s
.389 .39645 m
.38988 .39606 L
s
.4812 .39116 m
.48217 .39146 L
s
.38929 .39645 m
.39018 .39606 L
s
.38902 .39641 m
.38991 .39602 L
s
.28344 .39499 m
.28373 .39453 L
s
.48126 .39108 m
.48224 .39137 L
s
.81642 .24215 m
.81665 .24236 L
s
.16544 .40494 m
.16553 .40457 L
s
.48074 .39113 m
.48172 .39142 L
s
.48081 .39109 m
.48179 .39139 L
s
.38925 .39634 m
.39014 .39596 L
s
.60931 .39058 m
.60963 .391 L
s
.60939 .39058 m
.60971 .391 L
s
.17355 .49373 m
.17354 .49327 L
s
.38958 .3963 m
.39047 .39591 L
s
.38946 .39631 m
.39035 .39592 L
s
.28352 .39484 m
.28381 .39438 L
s
.70666 .38435 m
.70682 .38472 L
s
.38944 .3962 m
.39033 .39582 L
s
.38977 .39618 m
.39067 .3958 L
s
.48072 .39091 m
.4817 .3912 L
s
.48054 .39092 m
.48152 .39121 L
s
.48023 .39093 m
.48121 .39122 L
s
.48083 .39087 m
.48181 .39116 L
s
.60941 .39041 m
.60972 .39083 L
s
.70661 .38426 m
.70677 .38463 L
s
.38958 .39611 m
.39047 .39572 L
s
.38982 .39612 m
.39071 .39574 L
s
.4803 .39087 m
.48128 .39116 L
s
.8162 .24194 m
.81642 .24215 L
s
.60918 .39036 m
.60949 .39079 L
s
.48006 .3909 m
.48104 .39119 L
s
.38988 .39606 m
.39077 .39568 L
s
.48022 .39087 m
.4812 .39116 L
s
.39018 .39606 m
.39108 .39568 L
s
.38991 .39602 m
.3908 .39564 L
s
.16556 .40463 m
.16566 .40426 L
s
.48028 .39079 m
.48126 .39108 L
s
.28375 .39462 m
.28404 .39416 L
s
.47976 .39084 m
.48074 .39113 L
s
.16553 .40457 m
.16563 .4042 L
s
.39014 .39596 m
.39103 .39557 L
s
.47982 .39081 m
.48081 .39109 L
s
.39047 .39591 m
.39137 .39553 L
s
.28373 .39453 m
.28402 .39407 L
s
.39035 .39592 m
.39124 .39554 L
s
.60899 .39015 m
.60931 .39058 L
s
.60907 .39016 m
.60939 .39058 L
s
.17354 .49327 m
.17354 .49281 L
s
.39033 .39582 m
.39123 .39544 L
s
.39067 .3958 m
.39157 .39542 L
s
.7065 .38398 m
.70666 .38435 L
s
.81598 .24173 m
.8162 .24194 L
s
.47974 .39063 m
.48072 .39091 L
s
.47924 .39065 m
.48023 .39093 L
s
.47955 .39064 m
.48054 .39092 L
s
.47985 .39058 m
.48083 .39087 L
s
.28381 .39438 m
.2841 .39392 L
s
.39047 .39572 m
.39137 .39534 L
s
.39071 .39574 m
.39161 .39536 L
s
.47931 .39058 m
.4803 .39087 L
s
.47907 .39062 m
.48006 .3909 L
s
.39077 .39568 m
.39167 .3953 L
s
.70645 .38389 m
.70661 .38426 L
s
.39108 .39568 m
.39198 .39531 L
s
.47923 .39059 m
.48022 .39087 L
s
.3908 .39564 m
.3917 .39526 L
s
.60909 .38999 m
.60941 .39041 L
s
.47929 .3905 m
.48028 .39079 L
s
.16566 .40426 m
.16576 .40389 L
s
.60886 .38994 m
.60918 .39036 L
s
.47876 .39056 m
.47976 .39084 L
s
.39103 .39557 m
.39193 .3952 L
s
.47883 .39053 m
.47982 .39081 L
s
.39137 .39553 m
.39227 .39516 L
s
.16563 .4042 m
.16573 .40383 L
s
.39124 .39554 m
.39215 .39517 L
s
.28404 .39416 m
.28433 .3937 L
s
.81576 .24152 m
.81598 .24173 L
s
.39123 .39544 m
.39213 .39506 L
s
.39157 .39542 m
.39247 .39505 L
s
.47875 .39035 m
.47974 .39063 L
s
.28402 .39407 m
.28432 .39361 L
s
.47825 .39037 m
.47924 .39065 L
s
.47856 .39036 m
.47955 .39064 L
s
.60867 .38973 m
.60899 .39015 L
s
.60875 .38973 m
.60907 .39016 L
s
.47886 .3903 m
.47985 .39058 L
s
.17354 .49281 m
.17354 .49236 L
s
.70633 .38361 m
.7065 .38398 L
s
.39137 .39534 m
.39227 .39497 L
s
.39161 .39536 m
.39252 .39499 L
s
.47832 .39031 m
.47931 .39058 L
s
.39167 .3953 m
.39258 .39493 L
s
.47807 .39034 m
.47907 .39062 L
s
.39198 .39531 m
.39289 .39494 L
s
.47824 .39032 m
.47923 .39059 L
s
.3917 .39526 m
.3926 .39489 L
s
.4783 .39023 m
.47929 .3905 L
s
.70628 .38352 m
.70645 .38389 L
s
.47777 .39029 m
.47876 .39056 L
s
.2841 .39392 m
.2844 .39346 L
s
.39193 .3952 m
.39284 .39483 L
s
.16576 .40389 m
.16586 .40352 L
s
.47784 .39026 m
.47883 .39053 L
s
.60877 .38956 m
.60909 .38999 L
s
.81553 .24131 m
.81576 .24152 L
s
.39227 .39516 m
.39319 .39479 L
s
.39215 .39517 m
.39306 .3948 L
s
.60853 .38952 m
.60886 .38994 L
s
.16573 .40383 m
.16583 .40346 L
s
.39247 .39505 m
.39339 .39468 L
s
.39213 .39506 m
.39304 .3947 L
s
.47775 .39008 m
.47875 .39035 L
s
.47725 .39011 m
.47825 .39037 L
s
.47756 .39009 m
.47856 .39036 L
s
.47787 .39003 m
.47886 .3903 L
s
.39252 .39499 m
.39343 .39463 L
s
.39227 .39497 m
.39318 .3946 L
s
.28433 .3937 m
.28463 .39324 L
s
.39258 .39493 m
.39349 .39457 L
s
.47732 .39004 m
.47832 .39031 L
s
.47707 .39008 m
.47807 .39034 L
s
.39289 .39494 m
.39381 .39457 L
s
.3926 .39489 m
.39352 .39453 L
s
.70617 .38325 m
.70633 .38361 L
s
.47724 .39005 m
.47824 .39032 L
s
.60835 .38931 m
.60867 .38973 L
s
.17354 .49236 m
.17354 .4919 L
s
.60843 .38931 m
.60875 .38973 L
s
.4773 .38996 m
.4783 .39023 L
s
.28432 .39361 m
.28462 .39315 L
s
.81531 .2411 m
.81553 .24131 L
s
.47676 .39003 m
.47777 .39029 L
s
.39284 .39483 m
.39376 .39447 L
s
.70612 .38316 m
.70628 .38352 L
s
.47683 .38999 m
.47784 .39026 L
s
.39319 .39479 m
.39411 .39443 L
s
.39306 .3948 m
.39398 .39444 L
s
.16586 .40352 m
.16596 .40315 L
s
.39339 .39468 m
.39431 .39433 L
s
.39304 .3947 m
.39396 .39434 L
s
.2844 .39346 m
.2847 .393 L
s
.60844 .38914 m
.60877 .38956 L
s
.16583 .40346 m
.16593 .40308 L
s
.47675 .38982 m
.47775 .39008 L
s
.60821 .3891 m
.60853 .38952 L
s
.47624 .38985 m
.47725 .39011 L
s
.47656 .38983 m
.47756 .39009 L
s
.39343 .39463 m
.39435 .39427 L
s
.39318 .3946 m
.3941 .39425 L
s
.47687 .38977 m
.47787 .39003 L
s
.39349 .39457 m
.39442 .39421 L
s
.47632 .38978 m
.47732 .39004 L
s
.39381 .39457 m
.39473 .39422 L
s
.47606 .38982 m
.47707 .39008 L
s
.39352 .39453 m
.39444 .39417 L
s
.81508 .24089 m
.81531 .2411 L
s
.47623 .38979 m
.47724 .39005 L
s
.4763 .38971 m
.4773 .38996 L
s
.47575 .38977 m
.47676 .39003 L
s
.706 .38288 m
.70617 .38325 L
s
.39376 .39447 m
.39468 .39411 L
s
.28463 .39324 m
.28493 .39278 L
s
.39411 .39443 m
.39503 .39408 L
s
.47583 .38974 m
.47683 .38999 L
s
.39398 .39444 m
.3949 .39409 L
s
.17354 .4919 m
.17354 .49144 L
s
.60802 .38889 m
.60835 .38931 L
s
.6081 .38889 m
.60843 .38931 L
s
.70595 .38279 m
.70612 .38316 L
s
.28462 .39315 m
.28492 .3927 L
s
.39431 .39433 m
.39524 .39397 L
s
.39396 .39434 m
.39488 .39398 L
s
.16596 .40315 m
.16606 .40278 L
s
.47575 .38956 m
.47675 .38982 L
s
.47523 .38959 m
.47624 .38985 L
s
.47555 .38958 m
.47656 .38983 L
s
.39435 .39427 m
.39528 .39392 L
s
.3941 .39425 m
.39503 .39389 L
s
.47586 .38952 m
.47687 .38977 L
s
.81485 .24069 m
.81508 .24089 L
s
.39442 .39421 m
.39535 .39386 L
s
.16593 .40308 m
.16603 .40271 L
s
.39473 .39422 m
.39567 .39387 L
s
.47531 .38953 m
.47632 .38978 L
s
.47505 .38957 m
.47606 .38982 L
s
.60811 .38872 m
.60844 .38914 L
s
.39444 .39417 m
.39537 .39382 L
s
.47522 .38954 m
.47623 .38979 L
s
.2847 .393 m
.28501 .39254 L
s
.60788 .38868 m
.60821 .3891 L
s
.47528 .38945 m
.4763 .38971 L
s
.47474 .38953 m
.47575 .38977 L
s
.39468 .39411 m
.39561 .39376 L
s
.39503 .39408 m
.39597 .39373 L
s
.47481 .38949 m
.47583 .38974 L
s
.3949 .39409 m
.39584 .39374 L
s
.70583 .38251 m
.706 .38288 L
s
.39524 .39397 m
.39617 .39363 L
s
.39488 .39398 m
.39582 .39363 L
s
.81463 .24048 m
.81485 .24069 L
s
.17354 .49144 m
.17354 .49099 L
s
.28493 .39278 m
.28524 .39232 L
s
.47473 .38932 m
.47575 .38956 L
s
.47421 .38935 m
.47523 .38959 L
s
.70578 .38242 m
.70595 .38279 L
s
.39528 .39392 m
.39622 .39357 L
s
.60769 .38847 m
.60802 .38889 L
s
.60777 .38847 m
.6081 .38889 L
s
.47454 .38933 m
.47555 .38958 L
s
.39503 .39389 m
.39596 .39355 L
s
.47485 .38927 m
.47586 .38952 L
s
.39535 .39386 m
.39628 .39352 L
s
.39567 .39387 m
.39661 .39353 L
s
.16606 .40278 m
.16617 .4024 L
s
.47429 .38929 m
.47531 .38953 L
s
.47403 .38933 m
.47505 .38957 L
s
.39537 .39382 m
.3963 .39348 L
s
.28492 .3927 m
.28523 .39224 L
s
.4742 .3893 m
.47522 .38954 L
s
.16603 .40271 m
.16614 .40234 L
s
.47427 .38921 m
.47528 .38945 L
s
.47372 .38929 m
.47474 .38953 L
s
.39561 .39376 m
.39655 .39342 L
s
.39597 .39373 m
.39691 .39339 L
s
.39584 .39374 m
.39678 .3934 L
s
.4738 .38925 m
.47481 .38949 L
s
.60778 .3883 m
.60811 .38872 L
s
.60755 .38826 m
.60788 .38868 L
s
.39617 .39363 m
.39712 .39329 L
s
.28501 .39254 m
.28531 .39209 L
s
.39582 .39363 m
.39676 .39329 L
s
.8144 .24027 m
.81463 .24048 L
s
.70566 .38214 m
.70583 .38251 L
s
.47319 .38912 m
.47421 .38935 L
s
.47372 .38908 m
.47473 .38932 L
s
.39622 .39357 m
.39716 .39323 L
s
.39596 .39355 m
.3969 .39321 L
s
.47352 .38909 m
.47454 .38933 L
s
.39628 .39352 m
.39722 .39318 L
s
.47383 .38903 m
.47485 .38927 L
s
.39661 .39353 m
.39755 .39319 L
s
.47327 .38905 m
.47429 .38929 L
s
.47301 .38909 m
.47403 .38933 L
s
.3963 .39348 m
.39725 .39314 L
s
.47318 .38906 m
.4742 .3893 L
s
.70561 .38205 m
.70578 .38242 L
s
.47325 .38898 m
.47427 .38921 L
s
.17354 .49099 m
.17355 .49053 L
s
.16617 .4024 m
.16627 .40203 L
s
.47269 .38906 m
.47372 .38929 L
s
.39655 .39342 m
.39749 .39309 L
s
.60736 .38805 m
.60769 .38847 L
s
.60744 .38805 m
.60777 .38847 L
s
.39691 .39339 m
.39786 .39306 L
s
.28524 .39232 m
.28555 .39186 L
s
.39678 .3934 m
.39772 .39307 L
s
.47277 .38901 m
.4738 .38925 L
s
.16614 .40234 m
.16625 .40197 L
s
.39712 .39329 m
.39807 .39296 L
s
.28523 .39224 m
.28554 .39178 L
s
.39676 .39329 m
.3977 .39296 L
s
.81417 .24006 m
.8144 .24027 L
s
.39716 .39323 m
.39811 .3929 L
s
.47216 .38889 m
.47319 .38912 L
s
.47269 .38885 m
.47372 .38908 L
s
.60745 .38788 m
.60778 .3883 L
s
.3969 .39321 m
.39785 .39287 L
s
.47249 .38886 m
.47352 .38909 L
s
.39722 .39318 m
.39817 .39285 L
s
.39755 .39319 m
.39851 .39287 L
s
.47281 .3888 m
.47383 .38903 L
s
.47198 .38887 m
.47301 .38909 L
s
.39725 .39314 m
.3982 .39281 L
s
.47224 .38882 m
.47327 .38905 L
s
.60721 .38784 m
.60755 .38826 L
s
.47216 .38884 m
.47318 .38906 L
s
.70549 .38178 m
.70566 .38214 L
s
.28531 .39209 m
.28562 .39163 L
s
.47222 .38875 m
.47325 .38898 L
s
.39749 .39309 m
.39845 .39276 L
s
.47166 .38883 m
.47269 .38906 L
s
.39786 .39306 m
.39882 .39273 L
s
.39772 .39307 m
.39868 .39274 L
s
.47175 .38879 m
.47277 .38901 L
s
.70544 .38169 m
.70561 .38205 L
s
.16627 .40203 m
.16638 .40166 L
s
.39807 .39296 m
.39902 .39264 L
s
.81394 .23986 m
.81417 .24006 L
s
.3977 .39296 m
.39866 .39263 L
s
.17355 .49053 m
.17356 .49007 L
s
.60702 .38763 m
.60736 .38805 L
s
.60711 .38763 m
.60744 .38805 L
s
.16625 .40197 m
.16635 .4016 L
s
.39811 .3929 m
.39906 .39258 L
s
.47113 .38867 m
.47216 .38889 L
s
.39785 .39287 m
.3988 .39255 L
s
.47167 .38862 m
.47269 .38885 L
s
.39817 .39285 m
.39913 .39253 L
s
.47147 .38864 m
.47249 .38886 L
s
.39851 .39287 m
.39947 .39254 L
s
.28555 .39186 m
.28586 .39141 L
s
.47178 .38858 m
.47281 .3888 L
s
.3982 .39281 m
.39915 .39249 L
s
.47094 .38865 m
.47198 .38887 L
s
.47121 .3886 m
.47224 .38882 L
s
.47113 .38862 m
.47216 .38884 L
s
.28554 .39178 m
.28585 .39133 L
s
.47119 .38853 m
.47222 .38875 L
s
.39845 .39276 m
.3994 .39244 L
s
.47063 .38862 m
.47166 .38883 L
s
.39882 .39273 m
.39978 .39241 L
s
.39868 .39274 m
.39964 .39242 L
s
.60711 .38746 m
.60745 .38788 L
s
.47071 .38857 m
.47175 .38879 L
s
.70532 .38141 m
.70549 .38178 L
s
.60688 .38742 m
.60721 .38784 L
s
.39902 .39264 m
.39998 .39232 L
s
.81371 .23965 m
.81394 .23986 L
s
.39866 .39263 m
.39961 .39231 L
s
.28562 .39163 m
.28594 .39117 L
s
.39906 .39258 m
.40003 .39226 L
s
.4701 .38846 m
.47113 .38867 L
s
.70526 .38132 m
.70544 .38169 L
s
.3988 .39255 m
.39976 .39223 L
s
.47063 .38841 m
.47167 .38862 L
s
.39913 .39253 m
.40009 .39221 L
s
.39947 .39254 m
.40043 .39223 L
s
.47043 .38843 m
.47147 .38864 L
s
.16638 .40166 m
.16649 .40129 L
s
.47075 .38836 m
.47178 .38858 L
s
.39915 .39249 m
.40011 .39217 L
s
.46991 .38844 m
.47094 .38865 L
s
.47018 .38839 m
.47121 .3886 L
s
.47009 .3884 m
.47113 .38862 L
s
.16635 .4016 m
.16646 .40123 L
s
.17356 .49007 m
.17356 .48961 L
s
.3994 .39244 m
.40037 .39212 L
s
.47016 .38832 m
.47119 .38853 L
s
.46959 .38841 m
.47063 .38862 L
s
.39978 .39241 m
.40075 .3921 L
s
.60668 .38721 m
.60702 .38763 L
s
.60677 .38721 m
.60711 .38763 L
s
.39964 .39242 m
.40061 .39211 L
s
.46968 .38836 m
.47071 .38857 L
s
.39998 .39232 m
.40095 .39201 L
s
.81348 .23944 m
.81371 .23965 L
s
.28586 .39141 m
.28618 .39095 L
s
.39961 .39231 m
.40058 .392 L
s
.40003 .39226 m
.401 .39195 L
s
.46906 .38825 m
.4701 .38846 L
s
.39976 .39223 m
.40072 .39192 L
s
.40043 .39223 m
.40141 .39192 L
s
.40009 .39221 m
.40106 .3919 L
s
.28585 .39133 m
.28617 .39087 L
s
.4696 .3882 m
.47063 .38841 L
s
.70514 .38104 m
.70532 .38141 L
s
.46939 .38822 m
.47043 .38843 L
s
.60677 .38705 m
.60711 .38746 L
s
.40011 .39217 m
.40108 .39186 L
s
.46971 .38816 m
.47075 .38836 L
s
.46886 .38824 m
.46991 .38844 L
s
.46914 .38819 m
.47018 .38839 L
s
.60654 .387 m
.60688 .38742 L
s
.46905 .3882 m
.47009 .3884 L
s
.40037 .39212 m
.40134 .39182 L
s
.40075 .3921 m
.40172 .3918 L
s
.46855 .38821 m
.46959 .38841 L
s
.46912 .38812 m
.47016 .38832 L
s
.70509 .38095 m
.70526 .38132 L
s
.40061 .39211 m
.40158 .3918 L
s
.16649 .40129 m
.1666 .40092 L
s
.46863 .38816 m
.46968 .38836 L
s
.28594 .39117 m
.28626 .39072 L
s
.40095 .39201 m
.40193 .39171 L
s
.81325 .23924 m
.81348 .23944 L
s
.40058 .392 m
.40155 .3917 L
s
.16646 .40123 m
.16657 .40086 L
s
.17356 .48961 m
.17357 .48915 L
s
.401 .39195 m
.40197 .39165 L
s
.40141 .39192 m
.40239 .39162 L
s
.46801 .38806 m
.46906 .38825 L
s
.40106 .3919 m
.40204 .3916 L
s
.40072 .39192 m
.4017 .39161 L
s
.60634 .38679 m
.60668 .38721 L
s
.60642 .38679 m
.60677 .38721 L
s
.46856 .388 m
.4696 .3882 L
s
.46835 .38802 m
.46939 .38822 L
s
.40108 .39186 m
.40206 .39156 L
s
.46782 .38804 m
.46886 .38824 L
s
.46867 .38796 m
.46971 .38816 L
s
.46809 .38799 m
.46914 .38819 L
s
.46801 .388 m
.46905 .3882 L
s
.40134 .39182 m
.40232 .39152 L
s
.40172 .3918 m
.4027 .3915 L
s
.4675 .38802 m
.46855 .38821 L
s
.46807 .38792 m
.46912 .38812 L
s
.28618 .39095 m
.2865 .3905 L
s
.40158 .3918 m
.40256 .3915 L
s
.70496 .38068 m
.70514 .38104 L
s
.46759 .38797 m
.46863 .38816 L
s
.40193 .39171 m
.40291 .39141 L
s
.60643 .38663 m
.60677 .38705 L
s
.40155 .3917 m
.40253 .3914 L
s
.28617 .39087 m
.28649 .39042 L
s
.81302 .23903 m
.81325 .23924 L
s
.60619 .38658 m
.60654 .387 L
s
.40197 .39165 m
.40295 .39136 L
s
.70491 .38059 m
.70509 .38095 L
s
.1666 .40092 m
.16671 .40055 L
s
.40239 .39162 m
.40337 .39133 L
s
.46696 .38787 m
.46801 .38806 L
s
.40204 .3916 m
.40302 .3913 L
s
.4017 .39161 m
.40267 .39131 L
s
.46751 .38781 m
.46856 .388 L
s
.46731 .38783 m
.46835 .38802 L
s
.40206 .39156 m
.40304 .39126 L
s
.46677 .38786 m
.46782 .38804 L
s
.46763 .38777 m
.46867 .38796 L
s
.46704 .3878 m
.46809 .38799 L
s
.16657 .40086 m
.16668 .40048 L
s
.46696 .38782 m
.46801 .388 L
s
.4027 .3915 m
.40369 .39121 L
s
.40232 .39152 m
.4033 .39122 L
s
.28626 .39072 m
.28658 .39027 L
s
.46645 .38783 m
.4675 .38802 L
s
.46703 .38773 m
.46807 .38792 L
s
.40256 .3915 m
.40354 .39121 L
s
.17357 .48915 m
.17358 .48869 L
s
.46654 .38779 m
.46759 .38797 L
s
.40291 .39141 m
.4039 .39112 L
s
.60599 .38637 m
.60634 .38679 L
s
.60608 .38638 m
.60642 .38679 L
s
.40253 .3914 m
.40351 .39111 L
s
.81279 .23882 m
.81302 .23903 L
s
.40295 .39136 m
.40394 .39107 L
s
.40337 .39133 m
.40436 .39104 L
s
.40302 .3913 m
.40401 .39102 L
s
.46591 .38769 m
.46696 .38787 L
s
.40267 .39131 m
.40366 .39102 L
s
.46646 .38763 m
.46751 .38781 L
s
.46625 .38765 m
.46731 .38783 L
s
.70479 .38031 m
.70496 .38068 L
s
.40304 .39126 m
.40403 .39097 L
s
.46571 .38768 m
.46677 .38786 L
s
.46658 .38758 m
.46763 .38777 L
s
.46599 .38762 m
.46704 .3878 L
s
.2865 .3905 m
.28682 .39004 L
s
.46591 .38764 m
.46696 .38782 L
s
.40369 .39121 m
.40468 .39093 L
s
.4033 .39122 m
.40429 .39094 L
s
.46539 .38766 m
.46645 .38783 L
s
.60608 .38621 m
.60643 .38663 L
s
.46597 .38755 m
.46703 .38773 L
s
.40354 .39121 m
.40453 .39093 L
s
.70473 .38022 m
.70491 .38059 L
s
.16671 .40055 m
.16682 .40018 L
s
.28649 .39042 m
.28681 .38997 L
s
.60584 .38617 m
.60619 .38658 L
s
.46548 .38761 m
.46654 .38779 L
s
.4039 .39112 m
.40489 .39084 L
s
.40351 .39111 m
.4045 .39082 L
s
.16668 .40048 m
.1668 .40011 L
s
.40394 .39107 m
.40493 .39079 L
s
.40436 .39104 m
.40536 .39077 L
s
.40401 .39102 m
.405 .39074 L
s
.46485 .38752 m
.46591 .38769 L
s
.40366 .39102 m
.40465 .39074 L
s
.81256 .23862 m
.81279 .23882 L
s
.46541 .38745 m
.46646 .38763 L
s
.4652 .38748 m
.46625 .38765 L
s
.40403 .39097 m
.40502 .39069 L
s
.46466 .38751 m
.46571 .38768 L
s
.46494 .38745 m
.46599 .38762 L
s
.46553 .38741 m
.46658 .38758 L
s
.28658 .39027 m
.28691 .38981 L
s
.17358 .48869 m
.1736 .48823 L
s
.46485 .38747 m
.46591 .38764 L
s
.40468 .39093 m
.40568 .39065 L
s
.40429 .39094 m
.40528 .39066 L
s
.46433 .38749 m
.46539 .38766 L
s
.40453 .39093 m
.40553 .39065 L
s
.46492 .38738 m
.46597 .38755 L
s
.60564 .38596 m
.60599 .38637 L
s
.60573 .38596 m
.60608 .38638 L
s
.40489 .39084 m
.40589 .39056 L
s
.46443 .38744 m
.46548 .38761 L
s
.70461 .37994 m
.70479 .38031 L
s
.4045 .39082 m
.4055 .39054 L
s
.40493 .39079 m
.40593 .39051 L
s
.40536 .39077 m
.40636 .39049 L
s
.405 .39074 m
.406 .39046 L
s
.46379 .38735 m
.46485 .38752 L
s
.40465 .39074 m
.40564 .39046 L
s
.40502 .39069 m
.40602 .39042 L
s
.46435 .38729 m
.46541 .38745 L
s
.46414 .38731 m
.4652 .38748 L
s
.46359 .38735 m
.46466 .38751 L
s
.16682 .40018 m
.16694 .3998 L
s
.70455 .37986 m
.70473 .38022 L
s
.28682 .39004 m
.28715 .38959 L
s
.60574 .3858 m
.60608 .38621 L
s
.81232 .23841 m
.81256 .23862 L
s
.46388 .38728 m
.46494 .38745 L
s
.46447 .38724 m
.46553 .38741 L
s
.40568 .39065 m
.40668 .39038 L
s
.46379 .3873 m
.46485 .38747 L
s
.40528 .39066 m
.40628 .39039 L
s
.46327 .38733 m
.46433 .38749 L
s
.60549 .38575 m
.60584 .38617 L
s
.40553 .39065 m
.40653 .39038 L
s
.1668 .40011 m
.16691 .39974 L
s
.46386 .38722 m
.46492 .38738 L
s
.28681 .38997 m
.28714 .38951 L
s
.40589 .39056 m
.40689 .3903 L
s
.46337 .38728 m
.46443 .38744 L
s
.4055 .39054 m
.4065 .39027 L
s
.40636 .39049 m
.40737 .39023 L
s
.40593 .39051 m
.40694 .39024 L
s
.406 .39046 m
.407 .39019 L
s
.46273 .3872 m
.46379 .38735 L
s
.40564 .39046 m
.40664 .39019 L
s
.40602 .39042 m
.40702 .39015 L
s
.46329 .38713 m
.46435 .38729 L
s
.46308 .38716 m
.46414 .38731 L
s
.46253 .38719 m
.46359 .38735 L
s
.1736 .48823 m
.17361 .48777 L
s
.46281 .38713 m
.46388 .38728 L
s
.28691 .38981 m
.28724 .38936 L
s
.46341 .38708 m
.46447 .38724 L
s
.40668 .39038 m
.40769 .39012 L
s
.46273 .38715 m
.46379 .3873 L
s
.40628 .39039 m
.40729 .39012 L
s
.60529 .38554 m
.60564 .38596 L
s
.60538 .38555 m
.60573 .38596 L
s
.4622 .38718 m
.46327 .38733 L
s
.40653 .39038 m
.40754 .39012 L
s
.81209 .23821 m
.81232 .23841 L
s
.70443 .37958 m
.70461 .37994 L
s
.4628 .38706 m
.46386 .38722 L
s
.40689 .3903 m
.4079 .39004 L
s
.4623 .38713 m
.46337 .38728 L
s
.4065 .39027 m
.40751 .39001 L
s
.40737 .39023 m
.40838 .38997 L
s
.16694 .3998 m
.16705 .39943 L
s
.40694 .39024 m
.40794 .38998 L
s
.70437 .37949 m
.70455 .37986 L
s
.407 .39019 m
.40801 .38994 L
s
.46166 .38705 m
.46273 .3872 L
s
.40664 .39019 m
.40765 .38993 L
s
.40702 .39015 m
.40803 .38989 L
s
.60538 .38538 m
.60574 .3858 L
s
.46146 .38705 m
.46253 .38719 L
s
.46202 .38701 m
.46308 .38716 L
s
.46223 .38698 m
.46329 .38713 L
s
.16691 .39974 m
.16703 .39937 L
s
.46175 .38698 m
.46281 .38713 L
s
.28715 .38959 m
.28748 .38914 L
s
.40769 .39012 m
.4087 .38986 L
s
.46235 .38693 m
.46341 .38708 L
s
.40729 .39012 m
.4083 .38986 L
s
.46166 .387 m
.46273 .38715 L
s
.60514 .38534 m
.60549 .38575 L
s
.46113 .38703 m
.4622 .38718 L
s
.40754 .39012 m
.40855 .38986 L
s
.46173 .38692 m
.4628 .38706 L
s
.4079 .39004 m
.40892 .38978 L
s
.46123 .38698 m
.4623 .38713 L
s
.28714 .38951 m
.28747 .38906 L
s
.81186 .238 m
.81209 .23821 L
s
.40751 .39001 m
.40852 .38976 L
s
.40838 .38997 m
.4094 .38972 L
s
.40794 .38998 m
.40896 .38973 L
s
.40801 .38994 m
.40903 .38968 L
s
.46059 .38691 m
.46166 .38705 L
s
.40765 .38993 m
.40866 .38968 L
s
.40803 .38989 m
.40904 .38964 L
s
.46039 .38691 m
.46146 .38705 L
s
.17361 .48777 m
.17363 .4873 L
s
.46095 .38686 m
.46202 .38701 L
s
.46116 .38683 m
.46223 .38698 L
s
.46068 .38684 m
.46175 .38698 L
s
.4087 .38986 m
.40972 .38962 L
s
.46128 .38679 m
.46235 .38693 L
s
.70424 .37921 m
.70443 .37958 L
s
.4083 .38986 m
.40931 .38961 L
s
.46059 .38686 m
.46166 .387 L
s
.60494 .38513 m
.60529 .38554 L
s
.46006 .3869 m
.46113 .38703 L
s
.60502 .38513 m
.60538 .38555 L
s
.28724 .38936 m
.28757 .38891 L
s
.40855 .38986 m
.40957 .38962 L
s
.46066 .38678 m
.46173 .38692 L
s
.40892 .38978 m
.40994 .38954 L
s
.46016 .38685 m
.46123 .38698 L
s
.16705 .39943 m
.16717 .39906 L
s
.40852 .38976 m
.40953 .38951 L
s
.70419 .37912 m
.70437 .37949 L
s
.4094 .38972 m
.41042 .38948 L
s
.40896 .38973 m
.40998 .38949 L
s
.40903 .38968 m
.41005 .38944 L
s
.45952 .38678 m
.46059 .38691 L
s
.40866 .38968 m
.40968 .38943 L
s
.16703 .39937 m
.16715 .399 L
s
.81162 .2378 m
.81186 .238 L
s
.40904 .38964 m
.41006 .3894 L
s
.45932 .38678 m
.46039 .38691 L
s
.45988 .38673 m
.46095 .38686 L
s
.46009 .3867 m
.46116 .38683 L
s
.60503 .38497 m
.60538 .38538 L
s
.40972 .38962 m
.41075 .38938 L
s
.45961 .38671 m
.46068 .38684 L
s
.40931 .38961 m
.41033 .38937 L
s
.46021 .38665 m
.46128 .38679 L
s
.45898 .38677 m
.46006 .3869 L
s
.45952 .38673 m
.46059 .38686 L
s
.40957 .38962 m
.41059 .38937 L
s
.60478 .38492 m
.60514 .38534 L
s
.28748 .38914 m
.28782 .38869 L
s
.40994 .38954 m
.41096 .3893 L
s
.45959 .38665 m
.46066 .38678 L
s
.45909 .38672 m
.46016 .38685 L
s
.40953 .38951 m
.41056 .38927 L
s
.41042 .38948 m
.41145 .38925 L
s
.28747 .38906 m
.28781 .38861 L
s
.40998 .38949 m
.411 .38925 L
s
.41005 .38944 m
.41107 .3892 L
s
.45844 .38666 m
.45952 .38678 L
s
.40968 .38943 m
.4107 .38919 L
s
.41006 .3894 m
.41109 .38916 L
s
.45824 .38666 m
.45932 .38678 L
s
.4588 .38661 m
.45988 .38673 L
s
.45902 .38657 m
.46009 .3867 L
s
.41075 .38938 m
.41178 .38915 L
s
.45853 .38659 m
.45961 .38671 L
s
.17363 .4873 m
.17364 .48684 L
s
.70406 .37885 m
.70424 .37921 L
s
.41033 .38937 m
.41136 .38914 L
s
.45791 .38665 m
.45898 .38677 L
s
.45914 .38652 m
.46021 .38665 L
s
.45845 .38661 m
.45952 .38673 L
s
.41059 .38937 m
.41162 .38914 L
s
.41096 .3893 m
.41199 .38907 L
s
.81138 .23759 m
.81162 .2378 L
s
.45852 .38652 m
.45959 .38665 L
s
.60458 .38472 m
.60494 .38513 L
s
.60467 .38472 m
.60502 .38513 L
s
.45801 .3866 m
.45909 .38672 L
s
.28757 .38891 m
.2879 .38846 L
s
.16717 .39906 m
.16729 .39869 L
s
.41056 .38927 m
.41158 .38903 L
s
.41145 .38925 m
.41248 .38902 L
s
.704 .37876 m
.70419 .37912 L
s
.411 .38925 m
.41203 .38902 L
s
.41107 .3892 m
.4121 .38897 L
s
.45736 .38654 m
.45844 .38666 L
s
.4107 .38919 m
.41173 .38896 L
s
.16715 .399 m
.16727 .39863 L
s
.45716 .38654 m
.45824 .38666 L
s
.41109 .38916 m
.41212 .38893 L
s
.41178 .38915 m
.41281 .38892 L
s
.45773 .38649 m
.4588 .38661 L
s
.45794 .38645 m
.45902 .38657 L
s
.45745 .38647 m
.45853 .38659 L
s
.45683 .38654 m
.45791 .38665 L
s
.41136 .38914 m
.41239 .38891 L
s
.41162 .38914 m
.41265 .38892 L
s
.45737 .38649 m
.45845 .38661 L
s
.45807 .38641 m
.45914 .38652 L
s
.60467 .38456 m
.60503 .38497 L
s
.41199 .38907 m
.41303 .38885 L
s
.45744 .38641 m
.45852 .38652 L
s
.45694 .38649 m
.45801 .3866 L
s
.60442 .38451 m
.60478 .38492 L
s
.41248 .38902 m
.41352 .3888 L
s
.41158 .38903 m
.41261 .38881 L
s
.41203 .38902 m
.41307 .3888 L
s
.28782 .38869 m
.28815 .38824 L
s
.4121 .38897 m
.41314 .38875 L
s
.45628 .38644 m
.45736 .38654 L
s
.81115 .23739 m
.81138 .23759 L
s
.45608 .38644 m
.45716 .38654 L
s
.41212 .38893 m
.41315 .38871 L
s
.41173 .38896 m
.41276 .38873 L
s
.41281 .38892 m
.41385 .3887 L
s
.45665 .38638 m
.45773 .38649 L
s
.45687 .38634 m
.45794 .38645 L
s
.45637 .38636 m
.45745 .38647 L
s
.45574 .38644 m
.45683 .38654 L
s
.41239 .38891 m
.41343 .38869 L
s
.41265 .38892 m
.41369 .3887 L
s
.28781 .38861 m
.28815 .38816 L
s
.45629 .38639 m
.45737 .38649 L
s
.45699 .3863 m
.45807 .38641 L
s
.41303 .38885 m
.41406 .38863 L
s
.70387 .37848 m
.70406 .37885 L
s
.45636 .3863 m
.45744 .38641 L
s
.45586 .38639 m
.45694 .38649 L
s
.17364 .48684 m
.17366 .48638 L
s
.41352 .3888 m
.41456 .38859 L
s
.41261 .38881 m
.41365 .38859 L
s
.41307 .3888 m
.4141 .38858 L
s
.16729 .39869 m
.16741 .39832 L
s
.41314 .38875 m
.41417 .38854 L
s
.60422 .3843 m
.60458 .38472 L
s
.4552 .38634 m
.45628 .38644 L
s
.6043 .38431 m
.60467 .38472 L
s
.45499 .38634 m
.45608 .38644 L
s
.70382 .37839 m
.704 .37876 L
s
.41315 .38871 m
.41419 .38849 L
s
.41385 .3887 m
.41489 .38849 L
s
.41276 .38873 m
.41379 .38852 L
s
.45557 .38628 m
.45665 .38638 L
s
.45529 .38626 m
.45637 .38636 L
s
.45578 .38624 m
.45687 .38634 L
s
.45466 .38635 m
.45574 .38644 L
s
.2879 .38846 m
.28824 .38801 L
s
.16727 .39863 m
.16739 .39826 L
s
.41343 .38869 m
.41446 .38848 L
s
.41369 .3887 m
.41473 .38849 L
s
.45521 .38629 m
.45629 .38639 L
s
.41406 .38863 m
.41511 .38843 L
s
.45591 .38619 m
.45699 .3863 L
s
.45528 .3862 m
.45636 .3863 L
s
.45477 .38629 m
.45586 .38639 L
s
.41456 .38859 m
.4156 .38839 L
s
.81091 .23719 m
.81115 .23739 L
s
.41365 .38859 m
.41469 .38838 L
s
.4141 .38858 m
.41515 .38837 L
s
.41417 .38854 m
.41522 .38833 L
s
.45411 .38625 m
.4552 .38634 L
s
.60431 .38414 m
.60467 .38456 L
s
.45391 .38625 m
.45499 .38634 L
s
.41489 .38849 m
.41594 .38829 L
s
.41419 .38849 m
.41523 .38829 L
s
.41379 .38852 m
.41483 .38831 L
s
.45448 .38619 m
.45557 .38628 L
s
.45357 .38626 m
.45466 .38635 L
s
.60406 .3841 m
.60442 .38451 L
s
.45421 .38617 m
.45529 .38626 L
s
.4547 .38615 m
.45578 .38624 L
s
.41446 .38848 m
.41551 .38827 L
s
.41473 .38849 m
.41577 .38829 L
s
.41511 .38843 m
.41615 .38823 L
s
.45412 .3862 m
.45521 .38629 L
s
.45483 .3861 m
.45591 .38619 L
s
.45419 .38611 m
.45528 .3862 L
s
.45369 .3862 m
.45477 .38629 L
s
.4156 .38839 m
.41665 .38819 L
s
.28815 .38824 m
.2885 .38779 L
s
.41469 .38838 m
.41573 .38818 L
s
.41515 .38837 m
.41619 .38818 L
s
.45303 .38616 m
.45411 .38625 L
s
.41522 .38833 m
.41626 .38813 L
s
.70369 .37812 m
.70387 .37848 L
s
.45282 .38617 m
.45391 .38625 L
s
.41594 .38829 m
.41699 .3881 L
s
.41523 .38829 m
.41627 .38809 L
s
.28815 .38816 m
.28849 .38772 L
s
.41483 .38831 m
.41587 .3881 L
s
.45248 .38618 m
.45357 .38626 L
s
.4534 .3861 m
.45448 .38619 L
s
.45312 .38609 m
.45421 .38617 L
s
.45362 .38606 m
.4547 .38615 L
s
.41577 .38829 m
.41682 .38809 L
s
.41551 .38827 m
.41655 .38808 L
s
.16741 .39832 m
.16753 .39795 L
s
.17366 .48638 m
.17368 .48591 L
s
.41615 .38823 m
.4172 .38803 L
s
.45304 .38612 m
.45412 .3862 L
s
.81067 .23698 m
.81091 .23719 L
s
.45375 .38601 m
.45483 .3861 L
s
.70363 .37803 m
.70382 .37839 L
s
.45311 .38603 m
.45419 .38611 L
s
.41665 .38819 m
.41771 .388 L
s
.60385 .38389 m
.60422 .3843 L
s
.4526 .38612 m
.45369 .3862 L
s
.60394 .3839 m
.6043 .38431 L
s
.16739 .39826 m
.16751 .39789 L
s
.41573 .38818 m
.41678 .38798 L
s
.41619 .38818 m
.41724 .38798 L
s
.45194 .38609 m
.45303 .38616 L
s
.41626 .38813 m
.41731 .38794 L
s
.45173 .3861 m
.45282 .38617 L
s
.41699 .3881 m
.41804 .38791 L
s
.41627 .38809 m
.41732 .38789 L
s
.45139 .38611 m
.45248 .38618 L
s
.41587 .3881 m
.41692 .38791 L
s
.28824 .38801 m
.28859 .38756 L
s
.45231 .38603 m
.4534 .3861 L
s
.45203 .38602 m
.45312 .38609 L
s
.41682 .38809 m
.41787 .3879 L
s
.4172 .38803 m
.41826 .38785 L
s
.41655 .38808 m
.41761 .38789 L
s
.45253 .38599 m
.45362 .38606 L
s
.45195 .38604 m
.45304 .38612 L
s
.45266 .38593 m
.45375 .38601 L
s
.41771 .388 m
.41876 .38782 L
s
.45202 .38596 m
.45311 .38603 L
s
.45151 .38605 m
.4526 .38612 L
s
.60394 .38373 m
.60431 .38414 L
s
.41724 .38798 m
.4183 .3878 L
s
.45085 .38603 m
.45194 .38609 L
s
.41678 .38798 m
.41783 .38779 L
s
.41731 .38794 m
.41837 .38776 L
s
.45064 .38604 m
.45173 .3861 L
s
.41804 .38791 m
.4191 .38773 L
s
.41732 .38789 m
.41838 .38771 L
s
.4503 .38605 m
.45139 .38611 L
s
.6037 .38369 m
.60406 .3841 L
s
.45122 .38596 m
.45231 .38603 L
s
.41692 .38791 m
.41797 .38772 L
s
.45094 .38595 m
.45203 .38602 L
s
.41826 .38785 m
.41932 .38767 L
s
.41787 .3879 m
.41893 .38772 L
s
.41761 .38789 m
.41866 .3877 L
s
.45144 .38592 m
.45253 .38599 L
s
.45086 .38598 m
.45195 .38604 L
s
.81043 .23678 m
.81067 .23698 L
s
.41876 .38782 m
.41982 .38765 L
s
.45042 .38599 m
.45151 .38605 L
s
.45157 .38586 m
.45266 .38593 L
s
.45093 .38589 m
.45202 .38596 L
s
.7035 .37775 m
.70369 .37812 L
s
.44975 .38597 m
.45085 .38603 L
s
.4183 .3878 m
.41935 .38762 L
s
.41783 .38779 m
.41889 .38761 L
s
.41837 .38776 m
.41943 .38758 L
s
.2885 .38779 m
.28884 .38734 L
s
.44954 .38598 m
.45064 .38604 L
s
.4191 .38773 m
.42016 .38756 L
s
.44921 .386 m
.4503 .38605 L
s
.41838 .38771 m
.41943 .38753 L
s
.16753 .39795 m
.16766 .39758 L
s
.41932 .38767 m
.42038 .3875 L
s
.44985 .38589 m
.45094 .38595 L
s
.45013 .3859 m
.45122 .38596 L
s
.41893 .38772 m
.41999 .38755 L
s
.41797 .38772 m
.41903 .38754 L
s
.41866 .3877 m
.41972 .38753 L
s
.45035 .38585 m
.45144 .38592 L
s
.44977 .38592 m
.45086 .38598 L
s
.41982 .38765 m
.42089 .38748 L
s
.17368 .48591 m
.1737 .48545 L
s
.70344 .37766 m
.70363 .37803 L
s
.28849 .38772 m
.28884 .38727 L
s
.44933 .38594 m
.45042 .38599 L
s
.44984 .38584 m
.45093 .38589 L
s
.45048 .3858 m
.45157 .38586 L
s
.16751 .39789 m
.16763 .39752 L
s
.44866 .38592 m
.44975 .38597 L
s
.60349 .38348 m
.60385 .38389 L
s
.60357 .38349 m
.60394 .3839 L
s
.41935 .38762 m
.42041 .38745 L
s
.41943 .38758 m
.42049 .38741 L
s
.44845 .38593 m
.44954 .38598 L
s
.42016 .38756 m
.42122 .3874 L
s
.41889 .38761 m
.41994 .38744 L
s
.44811 .38595 m
.44921 .386 L
s
.41943 .38753 m
.4205 .38737 L
s
.42038 .3875 m
.42144 .38734 L
s
.44876 .38584 m
.44985 .38589 L
s
.41999 .38755 m
.42105 .38739 L
s
.44904 .38585 m
.45013 .3859 L
s
.41972 .38753 m
.42078 .38736 L
s
.41903 .38754 m
.42009 .38737 L
s
.42089 .38748 m
.42196 .38732 L
s
.44868 .38587 m
.44977 .38592 L
s
.44926 .3858 m
.45035 .38585 L
s
.44824 .38589 m
.44933 .38594 L
s
.44875 .38579 m
.44984 .38584 L
s
.44939 .38575 m
.45048 .3858 L
s
.44757 .38588 m
.44866 .38592 L
s
.8102 .23658 m
.81043 .23678 L
s
.28859 .38756 m
.28894 .38712 L
s
.42041 .38745 m
.42148 .38729 L
s
.42122 .3874 m
.42229 .38725 L
s
.44736 .38589 m
.44845 .38593 L
s
.42049 .38741 m
.42155 .38725 L
s
.41994 .38744 m
.42101 .38728 L
s
.44702 .38592 m
.44811 .38595 L
s
.42144 .38734 m
.42251 .38719 L
s
.4205 .38737 m
.42156 .3872 L
s
.42105 .38739 m
.42212 .38723 L
s
.44766 .3858 m
.44876 .38584 L
s
.44795 .3858 m
.44904 .38585 L
s
.60358 .38332 m
.60394 .38373 L
s
.42196 .38732 m
.42303 .38717 L
s
.42078 .38736 m
.42185 .38721 L
s
.42009 .38737 m
.42115 .38721 L
s
.44758 .38583 m
.44868 .38587 L
s
.44817 .38576 m
.44926 .3858 L
s
.44714 .38585 m
.44824 .38589 L
s
.44647 .38585 m
.44757 .38588 L
s
.44766 .38575 m
.44875 .38579 L
s
.60333 .38328 m
.6037 .38369 L
s
.42229 .38725 m
.42336 .3871 L
s
.44626 .38586 m
.44736 .38589 L
s
.4483 .3857 m
.44939 .38575 L
s
.42148 .38729 m
.42255 .38714 L
s
.42155 .38725 m
.42262 .3871 L
s
.44592 .38589 m
.44702 .38592 L
s
.42101 .38728 m
.42207 .38712 L
s
.42251 .38719 m
.42358 .38704 L
s
.70331 .37739 m
.7035 .37775 L
s
.42156 .3872 m
.42263 .38705 L
s
.42212 .38723 m
.42319 .38708 L
s
.42303 .38717 m
.4241 .38703 L
s
.44657 .38577 m
.44766 .3858 L
s
.44686 .38577 m
.44795 .3858 L
s
.42185 .38721 m
.42291 .38706 L
s
.44649 .3858 m
.44758 .38583 L
s
.42115 .38721 m
.42221 .38705 L
s
.44708 .38572 m
.44817 .38576 L
s
.44605 .38582 m
.44714 .38585 L
s
.44538 .38582 m
.44647 .38585 L
s
.16766 .39758 m
.16778 .39721 L
s
.42336 .3871 m
.42444 .38696 L
s
.44516 .38584 m
.44626 .38586 L
s
.44656 .38571 m
.44766 .38575 L
s
.42255 .38714 m
.42362 .38699 L
s
.44482 .38587 m
.44592 .38589 L
s
.42262 .3871 m
.42369 .38695 L
s
.44721 .38567 m
.4483 .3857 L
s
.28884 .38734 m
.28919 .3869 L
s
.42358 .38704 m
.42466 .38691 L
s
.42207 .38712 m
.42314 .38697 L
s
.70325 .3773 m
.70344 .37766 L
s
.4241 .38703 m
.42518 .3869 L
s
.42319 .38708 m
.42426 .38694 L
s
.42263 .38705 m
.4237 .38691 L
s
.44548 .38574 m
.44657 .38577 L
s
.44576 .38574 m
.44686 .38577 L
s
.42291 .38706 m
.42398 .38691 L
s
.16763 .39752 m
.16776 .39715 L
s
.4454 .38577 m
.44649 .3858 L
s
.1737 .48545 m
.17373 .48499 L
s
.80996 .23637 m
.8102 .23658 L
s
.44428 .3858 m
.44538 .38582 L
s
.44496 .3858 m
.44605 .38582 L
s
.42221 .38705 m
.42328 .3869 L
s
.44599 .38569 m
.44708 .38572 L
s
.42444 .38696 m
.42551 .38683 L
s
.44407 .38583 m
.44516 .38584 L
s
.44373 .38585 m
.44482 .38587 L
s
.44547 .38569 m
.44656 .38571 L
s
.42362 .38699 m
.42469 .38686 L
s
.42369 .38695 m
.42476 .38682 L
s
.28884 .38727 m
.28919 .38682 L
s
.60312 .38307 m
.60349 .38348 L
s
.42466 .38691 m
.42573 .38678 L
s
.6032 .38308 m
.60357 .38349 L
s
.44612 .38564 m
.44721 .38567 L
s
.42518 .3869 m
.42625 .38677 L
s
.42314 .38697 m
.42421 .38683 L
s
.42426 .38694 m
.42533 .38681 L
s
.4237 .38691 m
.42477 .38677 L
s
.44438 .38573 m
.44548 .38574 L
s
.44467 .38572 m
.44576 .38574 L
s
.42398 .38691 m
.42506 .38678 L
s
.4443 .38576 m
.4454 .38577 L
s
.44318 .3858 m
.44428 .3858 L
s
.42551 .38683 m
.42659 .3867 L
s
.44297 .38582 m
.44407 .38583 L
s
.44386 .38579 m
.44496 .3858 L
s
.44263 .38585 m
.44373 .38585 L
s
.44489 .38567 m
.44599 .38569 L
s
.42328 .3869 m
.42435 .38676 L
s
.44437 .38567 m
.44547 .38569 L
s
.42469 .38686 m
.42577 .38673 L
s
.42476 .38682 m
.42584 .38669 L
s
.42573 .38678 m
.42681 .38665 L
s
.42625 .38677 m
.42733 .38665 L
s
.44503 .38562 m
.44612 .38564 L
s
.42421 .38683 m
.42528 .3867 L
s
.42533 .38681 m
.42641 .38669 L
s
.44328 .38572 m
.44438 .38573 L
s
.42477 .38677 m
.42584 .38664 L
s
.44209 .3858 m
.44318 .3858 L
s
.42659 .3867 m
.42767 .38659 L
s
.44357 .38571 m
.44467 .38572 L
s
.44187 .38582 m
.44297 .38582 L
s
.44321 .38575 m
.4443 .38576 L
s
.42506 .38678 m
.42613 .38665 L
s
.44153 .38585 m
.44263 .38585 L
s
.44276 .38578 m
.44386 .38579 L
s
.42681 .38665 m
.42789 .38654 L
s
.42733 .38665 m
.42842 .38654 L
s
.4438 .38566 m
.44489 .38567 L
s
.42584 .38669 m
.42692 .38657 L
s
.28894 .38712 m
.28929 .38667 L
s
.42577 .38673 m
.42684 .38661 L
s
.42435 .38676 m
.42543 .38663 L
s
.44328 .38566 m
.44437 .38567 L
s
.42641 .38669 m
.42749 .38657 L
s
.6032 .38291 m
.60358 .38332 L
s
.42767 .38659 m
.42876 .38648 L
s
.44219 .38572 m
.44328 .38572 L
s
.44099 .3858 m
.44209 .3858 L
s
.42528 .3867 m
.42636 .38657 L
s
.44078 .38583 m
.44187 .38582 L
s
.44044 .38587 m
.44153 .38585 L
s
.44393 .3856 m
.44503 .38562 L
s
.42584 .38664 m
.42692 .38652 L
s
.44211 .38575 m
.44321 .38575 L
s
.44248 .38571 m
.44357 .38571 L
s
.42613 .38665 m
.42721 .38653 L
s
.44167 .38579 m
.44276 .38578 L
s
.42842 .38654 m
.4295 .38644 L
s
.42789 .38654 m
.42898 .38643 L
s
.42692 .38657 m
.428 .38645 L
s
.42684 .38661 m
.42793 .38649 L
s
.4427 .38566 m
.4438 .38566 L
s
.60295 .38287 m
.60333 .38328 L
s
.44218 .38566 m
.44328 .38566 L
s
.70312 .37702 m
.70331 .37739 L
s
.42543 .38663 m
.4265 .38651 L
s
.43934 .38589 m
.44044 .38587 L
s
.42876 .38648 m
.42984 .38638 L
s
.43968 .38585 m
.44078 .38583 L
s
.43989 .38582 m
.44099 .3858 L
s
.42749 .38657 m
.42857 .38646 L
s
.44109 .38573 m
.44219 .38572 L
s
.4295 .38644 m
.43059 .38635 L
s
.80972 .23617 m
.80996 .23637 L
s
.42636 .38657 m
.42744 .38645 L
s
.42898 .38643 m
.43006 .38634 L
s
.42692 .38652 m
.428 .38641 L
s
.44101 .38576 m
.44211 .38575 L
s
.44057 .3858 m
.44167 .38579 L
s
.44138 .38572 m
.44248 .38571 L
s
.44284 .3856 m
.44393 .3856 L
s
.42721 .38653 m
.42829 .38642 L
s
.43824 .38592 m
.43934 .38589 L
s
.428 .38645 m
.42908 .38635 L
s
.42984 .38638 m
.43093 .38629 L
s
.43858 .38588 m
.43968 .38585 L
s
.42793 .38649 m
.42901 .38639 L
s
.16778 .39721 m
.16791 .39684 L
s
.4388 .38585 m
.43989 .38582 L
s
.43059 .38635 m
.43168 .38626 L
s
.44109 .38567 m
.44218 .38566 L
s
.42857 .38646 m
.42966 .38636 L
s
.44161 .38566 m
.4427 .38566 L
s
.43006 .38634 m
.43115 .38625 L
s
.44 .38574 m
.44109 .38573 L
s
.4265 .38651 m
.42758 .38639 L
s
.43715 .38595 m
.43824 .38592 L
s
.43948 .38582 m
.44057 .3858 L
s
.43992 .38577 m
.44101 .38576 L
s
.43093 .38629 m
.43202 .38621 L
s
.43749 .38591 m
.43858 .38588 L
s
.428 .38641 m
.42909 .3863 L
s
.43168 .38626 m
.43277 .38618 L
s
.42744 .38645 m
.42852 .38634 L
s
.44029 .38573 m
.44138 .38572 L
s
.4377 .38588 m
.4388 .38585 L
s
.42829 .38642 m
.42938 .38632 L
s
.42908 .38635 m
.43017 .38625 L
s
.44174 .3856 m
.44284 .3856 L
s
.43605 .386 m
.43715 .38595 L
s
.42901 .38639 m
.43009 .38629 L
s
.43115 .38625 m
.43224 .38617 L
s
.70306 .37693 m
.70325 .3773 L
s
.43277 .38618 m
.43386 .38611 L
s
.42966 .38636 m
.43074 .38627 L
s
.43202 .38621 m
.43311 .38613 L
s
.43639 .38595 m
.43749 .38591 L
s
.43999 .38569 m
.44109 .38567 L
s
.43496 .38605 m
.43605 .386 L
s
.43661 .38592 m
.4377 .38588 L
s
.4389 .38577 m
.44 .38574 L
s
.43386 .38611 m
.43496 .38605 L
s
.44051 .38567 m
.44161 .38566 L
s
.43838 .38585 m
.43948 .38582 L
s
.16776 .39715 m
.16788 .39678 L
s
.43224 .38617 m
.43333 .38609 L
s
.43311 .38613 m
.4342 .38606 L
s
.43882 .3858 m
.43992 .38577 L
s
.4353 .386 m
.43639 .38595 L
s
.42909 .3863 m
.43017 .3862 L
s
.43551 .38597 m
.43661 .38592 L
s
.4342 .38606 m
.4353 .386 L
s
.43919 .38575 m
.44029 .38573 L
s
.42758 .38639 m
.42866 .38628 L
s
.42938 .38632 m
.43046 .38622 L
s
.43017 .38625 m
.43126 .38616 L
s
.43333 .38609 m
.43442 .38603 L
s
.43009 .38629 m
.43118 .3862 L
s
.42852 .38634 m
.4296 .38624 L
s
.43074 .38627 m
.43183 .38618 L
s
.43442 .38603 m
.43551 .38597 L
s
.28919 .3869 m
.28954 .38645 L
s
.43781 .3858 m
.4389 .38577 L
s
.43729 .38588 m
.43838 .38585 L
s
.44065 .38562 m
.44174 .3856 L
s
.4389 .38571 m
.43999 .38569 L
s
.43773 .38583 m
.43882 .3858 L
s
.43942 .38569 m
.44051 .38567 L
s
.43183 .38618 m
.43292 .38611 L
s
.43126 .38616 m
.43234 .38608 L
s
.17373 .48499 m
.17375 .48452 L
s
.4381 .38578 m
.43919 .38575 L
s
.43118 .3862 m
.43227 .38612 L
s
.43046 .38622 m
.43155 .38614 L
s
.43017 .3862 m
.43126 .38611 L
s
.43619 .38593 m
.43729 .38588 L
s
.43671 .38584 m
.43781 .3858 L
s
.4296 .38624 m
.43069 .38615 L
s
.43292 .38611 m
.43401 .38604 L
s
.42866 .38628 m
.42974 .38618 L
s
.43663 .38587 m
.43773 .38583 L
s
.43234 .38608 m
.43343 .38601 L
s
.4351 .38598 m
.43619 .38593 L
s
.4378 .38575 m
.4389 .38571 L
s
.43227 .38612 m
.43336 .38604 L
s
.43401 .38604 m
.4351 .38598 L
s
.43562 .38589 m
.43671 .38584 L
s
.437 .38582 m
.4381 .38578 L
s
.43155 .38614 m
.43264 .38606 L
s
.60274 .38266 m
.60312 .38307 L
s
.43343 .38601 m
.43453 .38594 L
s
.43955 .38564 m
.44065 .38562 L
s
.43126 .38611 m
.43234 .38603 L
s
.43832 .38572 m
.43942 .38569 L
s
.43554 .38592 m
.43663 .38587 L
s
.60283 .38267 m
.6032 .38308 L
s
.43453 .38594 m
.43562 .38589 L
s
.43336 .38604 m
.43445 .38598 L
s
.43445 .38598 m
.43554 .38592 L
s
.43671 .38579 m
.4378 .38575 L
s
.43069 .38615 m
.43178 .38606 L
s
.43591 .38587 m
.437 .38582 L
s
.43264 .38606 m
.43373 .38599 L
s
.28919 .38682 m
.28954 .38638 L
s
.43234 .38603 m
.43343 .38596 L
s
.42974 .38618 m
.43083 .38609 L
s
.43482 .38592 m
.43591 .38587 L
s
.43373 .38599 m
.43482 .38592 L
s
.43723 .38576 m
.43832 .38572 L
s
.43562 .38584 m
.43671 .38579 L
s
.43343 .38596 m
.43452 .38589 L
s
.43846 .38566 m
.43955 .38564 L
s
.43178 .38606 m
.43286 .38599 L
s
.43452 .38589 m
.43562 .38584 L
s
.43614 .3858 m
.43723 .38576 L
s
.43083 .38609 m
.43192 .386 L
s
.43286 .38599 m
.43395 .38592 L
s
.43505 .38586 m
.43614 .3858 L
s
.43737 .3857 m
.43846 .38566 L
s
.43395 .38592 m
.43505 .38586 L
s
.43192 .386 m
.433 .38593 L
s
.43627 .38574 m
.43737 .3857 L
s
.80948 .23597 m
.80972 .23617 L
s
.433 .38593 m
.43409 .38586 L
s
.43518 .3858 m
.43627 .38574 L
s
.43409 .38586 m
.43518 .3858 L
s
.60283 .3825 m
.6032 .38291 L
s
.28929 .38667 m
.28964 .38623 L
s
.70292 .37666 m
.70312 .37702 L
s
.60258 .38246 m
.60295 .38287 L
s
.16791 .39684 m
.16804 .39647 L
s
.70287 .37657 m
.70306 .37693 L
s
.16788 .39678 m
.16801 .39641 L
s
.80923 .23577 m
.80948 .23597 L
s
.17375 .48452 m
.17378 .48406 L
s
.28954 .38645 m
.2899 .38601 L
s
.60237 .38225 m
.60274 .38266 L
s
.60245 .38226 m
.60283 .38267 L
s
.28954 .38638 m
.28989 .38593 L
s
.70273 .37629 m
.70292 .37666 L
s
.60245 .3821 m
.60283 .3825 L
s
.16804 .39647 m
.16817 .3961 L
s
.28964 .38623 m
.29 .38578 L
s
.6022 .38205 m
.60258 .38246 L
s
.80899 .23556 m
.80923 .23577 L
s
.70267 .37621 m
.70287 .37657 L
s
.16801 .39641 m
.16814 .39604 L
s
.17378 .48406 m
.17381 .48359 L
s
.60199 .38185 m
.60237 .38225 L
s
.2899 .38601 m
.29026 .38556 L
s
.60208 .38185 m
.60245 .38226 L
s
.28989 .38593 m
.29025 .38549 L
s
.80875 .23536 m
.80899 .23556 L
s
.70253 .37593 m
.70273 .37629 L
s
.16817 .3961 m
.1683 .39573 L
s
.60207 .38169 m
.60245 .3821 L
s
.60182 .38164 m
.6022 .38205 L
s
.29 .38578 m
.29036 .38534 L
s
.16814 .39604 m
.16827 .39567 L
s
.70247 .37584 m
.70267 .37621 L
s
.80851 .23516 m
.80875 .23536 L
s
.17381 .48359 m
.17383 .48313 L
s
.6016 .38144 m
.60199 .38185 L
s
.60169 .38145 m
.60208 .38185 L
s
.29026 .38556 m
.29062 .38512 L
s
.29025 .38549 m
.29062 .38505 L
s
.70234 .37557 m
.70253 .37593 L
s
.1683 .39573 m
.16843 .39536 L
s
.60169 .38128 m
.60207 .38169 L
s
.16827 .39567 m
.16841 .3953 L
s
.70228 .37548 m
.70247 .37584 L
s
.60144 .38124 m
.60182 .38164 L
s
.80826 .23496 m
.80851 .23516 L
s
.29036 .38534 m
.29072 .3849 L
s
.17383 .48313 m
.17387 .48266 L
s
.60122 .38104 m
.6016 .38144 L
s
.60131 .38104 m
.60169 .38145 L
s
.29062 .38512 m
.29098 .38468 L
s
.70214 .3752 m
.70234 .37557 L
s
.80802 .23476 m
.80826 .23496 L
s
.16843 .39536 m
.16857 .39499 L
s
.29062 .38505 m
.29098 .38461 L
s
.16841 .3953 m
.16854 .39493 L
s
.6013 .38088 m
.60169 .38128 L
s
.70208 .37512 m
.70228 .37548 L
s
.60105 .38083 m
.60144 .38124 L
s
.29072 .3849 m
.29109 .38446 L
s
.80777 .23456 m
.80802 .23476 L
s
.17387 .48266 m
.1739 .48219 L
s
.60083 .38063 m
.60122 .38104 L
s
.60092 .38064 m
.60131 .38104 L
s
.70194 .37484 m
.70214 .3752 L
s
.16857 .39499 m
.1687 .39462 L
s
.29098 .38468 m
.29135 .38424 L
s
.16854 .39493 m
.16868 .39456 L
s
.70188 .37475 m
.70208 .37512 L
s
.29098 .38461 m
.29136 .38417 L
s
.60092 .38048 m
.6013 .38088 L
s
.60066 .38043 m
.60105 .38083 L
s
.80753 .23436 m
.80777 .23456 L
s
.29109 .38446 m
.29146 .38402 L
s
.60044 .38023 m
.60083 .38063 L
s
.1739 .48219 m
.17393 .48173 L
s
.60053 .38023 m
.60092 .38064 L
s
.70173 .37448 m
.70194 .37484 L
s
.1687 .39462 m
.16884 .39425 L
s
.80728 .23416 m
.80753 .23436 L
s
.16868 .39456 m
.16881 .39419 L
s
.29135 .38424 m
.29173 .3838 L
s
.70167 .37439 m
.70188 .37475 L
s
.60052 .38007 m
.60092 .38048 L
s
.29136 .38417 m
.29173 .38373 L
s
.60027 .38003 m
.60066 .38043 L
s
.29146 .38402 m
.29184 .38358 L
s
.80703 .23396 m
.80728 .23416 L
s
.16884 .39425 m
.16898 .39388 L
s
.70153 .37411 m
.70173 .37448 L
s
.60004 .37983 m
.60044 .38023 L
s
.60013 .37983 m
.60053 .38023 L
s
.17393 .48173 m
.17397 .48126 L
s
.16881 .39419 m
.16895 .39382 L
s
.70147 .37403 m
.70167 .37439 L
s
.29173 .3838 m
.2921 .38336 L
s
.60013 .37967 m
.60052 .38007 L
s
.29173 .38373 m
.29211 .38329 L
s
.80678 .23376 m
.80703 .23396 L
s
.59987 .37962 m
.60027 .38003 L
s
.29184 .38358 m
.29222 .38314 L
s
.16898 .39388 m
.16912 .39351 L
s
.70132 .37375 m
.70153 .37411 L
s
.59965 .37942 m
.60004 .37983 L
s
.59974 .37943 m
.60013 .37983 L
s
.17397 .48126 m
.174 .48079 L
s
.16895 .39382 m
.16909 .39345 L
s
.70126 .37366 m
.70147 .37403 L
s
.80654 .23356 m
.80678 .23376 L
s
.59973 .37927 m
.60013 .37967 L
s
.2921 .38336 m
.29248 .38292 L
s
.59947 .37922 m
.59987 .37962 L
s
.29211 .38329 m
.29249 .38285 L
s
.16912 .39351 m
.16926 .39314 L
s
.80629 .23336 m
.80654 .23356 L
s
.70112 .37339 m
.70132 .37375 L
s
.29222 .38314 m
.2926 .3827 L
s
.59924 .37902 m
.59965 .37942 L
s
.59934 .37903 m
.59974 .37943 L
s
.16909 .39345 m
.16923 .39308 L
s
.174 .48079 m
.17404 .48032 L
s
.70106 .3733 m
.70126 .37366 L
s
.59933 .37887 m
.59973 .37927 L
s
.29248 .38292 m
.29287 .38249 L
s
.59907 .37882 m
.59947 .37922 L
s
.80604 .23316 m
.80629 .23336 L
s
.29249 .38285 m
.29287 .38242 L
s
.16926 .39314 m
.1694 .39277 L
s
.70091 .37303 m
.70112 .37339 L
s
.16923 .39308 m
.16938 .39271 L
s
.59884 .37862 m
.59924 .37902 L
s
.2926 .3827 m
.29299 .38227 L
s
.59893 .37863 m
.59934 .37903 L
s
.70085 .37294 m
.70106 .3733 L
s
.17404 .48032 m
.17408 .47985 L
s
.80579 .23297 m
.80604 .23316 L
s
.59892 .37847 m
.59933 .37887 L
s
.59866 .37842 m
.59907 .37882 L
s
.29287 .38249 m
.29325 .38205 L
s
.1694 .39277 m
.16955 .3924 L
s
.29287 .38242 m
.29326 .38198 L
s
.7007 .37267 m
.70091 .37303 L
s
.80554 .23277 m
.80579 .23297 L
s
.16938 .39271 m
.16952 .39234 L
s
.59843 .37823 m
.59884 .37862 L
s
.59853 .37823 m
.59893 .37863 L
s
.70064 .37258 m
.70085 .37294 L
s
.29299 .38227 m
.29337 .38183 L
s
.17408 .47985 m
.17412 .47938 L
s
.59852 .37807 m
.59892 .37847 L
s
.59825 .37802 m
.59866 .37842 L
s
.80528 .23257 m
.80554 .23277 L
s
.29325 .38205 m
.29365 .38162 L
s
.16955 .3924 m
.16969 .39203 L
s
.70049 .3723 m
.7007 .37267 L
s
.29326 .38198 m
.29365 .38155 L
s
.16952 .39234 m
.16967 .39197 L
s
.70043 .37222 m
.70064 .37258 L
s
.59802 .37783 m
.59843 .37823 L
s
.59812 .37783 m
.59853 .37823 L
s
.29337 .38183 m
.29377 .3814 L
s
.17412 .47938 m
.17417 .47891 L
s
.80503 .23237 m
.80528 .23257 L
s
.59811 .37767 m
.59852 .37807 L
s
.59784 .37763 m
.59825 .37802 L
s
.16969 .39203 m
.16984 .39166 L
s
.70028 .37194 m
.70049 .3723 L
s
.29365 .38162 m
.29404 .38119 L
s
.16967 .39197 m
.16982 .3916 L
s
.29365 .38155 m
.29405 .38112 L
s
.80478 .23217 m
.80503 .23237 L
s
.70021 .37186 m
.70043 .37222 L
s
.59761 .37743 m
.59802 .37783 L
s
.5977 .37743 m
.59812 .37783 L
s
.17417 .47891 m
.17421 .47844 L
s
.29377 .3814 m
.29416 .38097 L
s
.59769 .37728 m
.59811 .37767 L
s
.16984 .39166 m
.16999 .39129 L
s
.59743 .37723 m
.59784 .37763 L
s
.80453 .23198 m
.80478 .23217 L
s
.70006 .37158 m
.70028 .37194 L
s
.16982 .3916 m
.16996 .39123 L
s
.29404 .38119 m
.29444 .38075 L
s
.7 .37149 m
.70021 .37186 L
s
.29405 .38112 m
.29444 .38069 L
s
.5972 .37703 m
.59761 .37743 L
s
.59729 .37704 m
.5977 .37743 L
s
.17421 .47844 m
.17426 .47797 L
s
.80427 .23178 m
.80453 .23198 L
s
.29416 .38097 m
.29456 .38054 L
s
.59728 .37688 m
.59769 .37728 L
s
.16999 .39129 m
.17014 .39092 L
s
.59701 .37683 m
.59743 .37723 L
s
.69985 .37122 m
.70006 .37158 L
s
.16996 .39123 m
.17011 .39086 L
s
.29444 .38075 m
.29484 .38032 L
s
.69978 .37113 m
.7 .37149 L
s
.80402 .23158 m
.80427 .23178 L
s
.29444 .38069 m
.29484 .38026 L
s
.59678 .37664 m
.5972 .37703 L
s
.59687 .37664 m
.59729 .37704 L
s
.17426 .47797 m
.1743 .4775 L
s
.29456 .38054 m
.29496 .38011 L
s
.17014 .39092 m
.17029 .39056 L
s
.59686 .37649 m
.59728 .37688 L
s
.59659 .37644 m
.59701 .37683 L
s
.69963 .37086 m
.69985 .37122 L
s
.17011 .39086 m
.17027 .3905 L
s
.80376 .23139 m
.80402 .23158 L
s
.69957 .37077 m
.69978 .37113 L
s
.29484 .38032 m
.29524 .37989 L
s
.59635 .37625 m
.59678 .37664 L
s
.59645 .37625 m
.59687 .37664 L
s
.29484 .38026 m
.29525 .37983 L
s
.8035 .23119 m
.80376 .23139 L
s
.1743 .4775 m
.17435 .47703 L
s
.17029 .39056 m
.17044 .39019 L
s
.29496 .38011 m
.29537 .37968 L
s
.59644 .37609 m
.59686 .37649 L
s
.69941 .3705 m
.69963 .37086 L
s
.17027 .3905 m
.17042 .39013 L
s
.59617 .37605 m
.59659 .37644 L
s
.69935 .37041 m
.69957 .37077 L
s
.29524 .37989 m
.29565 .37947 L
s
.80325 .231 m
.8035 .23119 L
s
.59593 .37585 m
.59635 .37625 L
s
.59602 .37586 m
.59645 .37625 L
s
.29525 .37983 m
.29566 .3794 L
s
.17044 .39019 m
.1706 .38982 L
s
.17435 .47703 m
.1744 .47656 L
s
.59601 .3757 m
.59644 .37609 L
s
.17042 .39013 m
.17058 .38976 L
s
.69919 .37014 m
.69941 .3705 L
s
.29537 .37968 m
.29578 .37925 L
s
.59574 .37565 m
.59617 .37605 L
s
.80299 .2308 m
.80325 .231 L
s
.69913 .37005 m
.69935 .37041 L
s
.29565 .37947 m
.29606 .37904 L
s
.5955 .37546 m
.59593 .37585 L
s
.5956 .37547 m
.59602 .37586 L
s
.29566 .3794 m
.29607 .37897 L
s
.1706 .38982 m
.17075 .38945 L
s
.80273 .23061 m
.80299 .2308 L
s
.17058 .38976 m
.17073 .38939 L
s
.1744 .47656 m
.17445 .47609 L
s
.69897 .36978 m
.69919 .37014 L
s
.59558 .37531 m
.59601 .3757 L
s
.59531 .37526 m
.59574 .37565 L
s
.29578 .37925 m
.29619 .37883 L
s
.6989 .36969 m
.69913 .37005 L
s
.59507 .37507 m
.5955 .37546 L
s
.80247 .23041 m
.80273 .23061 L
s
.59517 .37507 m
.5956 .37547 L
s
.29606 .37904 m
.29647 .37861 L
s
.17075 .38945 m
.17091 .38908 L
s
.29607 .37897 m
.29648 .37855 L
s
.17073 .38939 m
.17089 .38902 L
s
.69875 .36942 m
.69897 .36978 L
s
.59515 .37492 m
.59558 .37531 L
s
.17445 .47609 m
.17451 .47561 L
s
.59488 .37487 m
.59531 .37526 L
s
.29619 .37883 m
.29661 .3784 L
s
.69868 .36933 m
.6989 .36969 L
s
.80221 .23022 m
.80247 .23041 L
s
.59464 .37468 m
.59507 .37507 L
s
.59473 .37469 m
.59517 .37507 L
s
.17091 .38908 m
.17107 .38871 L
s
.29647 .37861 m
.29689 .37819 L
s
.17089 .38902 m
.17105 .38865 L
s
.29648 .37855 m
.2969 .37812 L
s
.69852 .36906 m
.69875 .36942 L
s
.80195 .23002 m
.80221 .23022 L
s
.59472 .37453 m
.59515 .37492 L
s
.17451 .47561 m
.17456 .47514 L
s
.59445 .37448 m
.59488 .37487 L
s
.69845 .36897 m
.69868 .36933 L
s
.29661 .3784 m
.29703 .37798 L
s
.5942 .37429 m
.59464 .37468 L
s
.5943 .3743 m
.59473 .37469 L
s
.17107 .38871 m
.17123 .38835 L
s
.80169 .22983 m
.80195 .23002 L
s
.29689 .37819 m
.29731 .37776 L
s
.17105 .38865 m
.17121 .38829 L
s
.69829 .3687 m
.69852 .36906 L
s
.2969 .37812 m
.29732 .3777 L
s
.59428 .37414 m
.59472 .37453 L
s
.17456 .47514 m
.17462 .47467 L
s
.69823 .36861 m
.69845 .36897 L
s
.59401 .3741 m
.59445 .37448 L
s
.29703 .37798 m
.29745 .37755 L
s
.80143 .22964 m
.80169 .22983 L
s
.17123 .38835 m
.1714 .38798 L
s
.59376 .37391 m
.5942 .37429 L
s
.59386 .37391 m
.5943 .3743 L
s
.17121 .38829 m
.17137 .38792 L
s
.69807 .36834 m
.69829 .3687 L
s
.29731 .37776 m
.29774 .37734 L
s
.59384 .37376 m
.59428 .37414 L
s
.29732 .3777 m
.29775 .37728 L
s
.80117 .22944 m
.80143 .22964 L
s
.698 .36826 m
.69823 .36861 L
s
.59357 .37371 m
.59401 .3741 L
s
.17462 .47467 m
.17468 .47419 L
s
.29745 .37755 m
.29788 .37713 L
s
.1714 .38798 m
.17156 .38761 L
s
.59332 .37352 m
.59376 .37391 L
s
.59342 .37352 m
.59386 .37391 L
s
.17137 .38792 m
.17154 .38755 L
s
.80091 .22925 m
.80117 .22944 L
s
.69784 .36798 m
.69807 .36834 L
s
.29774 .37734 m
.29816 .37692 L
s
.5934 .37337 m
.59384 .37376 L
s
.69777 .3679 m
.698 .36826 L
s
.29775 .37728 m
.29818 .37686 L
s
.59312 .37332 m
.59357 .37371 L
s
.17468 .47419 m
.17474 .47372 L
s
.80064 .22906 m
.80091 .22925 L
s
.29788 .37713 m
.29831 .37671 L
s
.17156 .38761 m
.17172 .38724 L
s
.59287 .37313 m
.59332 .37352 L
s
.59297 .37314 m
.59342 .37352 L
s
.17154 .38755 m
.1717 .38718 L
s
.69761 .36762 m
.69784 .36798 L
s
.29816 .37692 m
.29859 .3765 L
s
.59295 .37299 m
.5934 .37337 L
s
.69754 .36754 m
.69777 .3679 L
s
.80038 .22886 m
.80064 .22906 L
s
.59268 .37294 m
.59312 .37332 L
s
.29818 .37686 m
.29861 .37644 L
s
.17474 .47372 m
.1748 .47325 L
s
.17172 .38724 m
.17189 .38688 L
s
.29831 .37671 m
.29874 .37629 L
s
.59243 .37275 m
.59287 .37313 L
s
.59252 .37275 m
.59297 .37314 L
s
.1717 .38718 m
.17187 .38682 L
s
.69737 .36727 m
.69761 .36762 L
s
.80012 .22867 m
.80038 .22886 L
s
.69731 .36718 m
.69754 .36754 L
s
.59251 .3726 m
.59295 .37299 L
s
.29859 .3765 m
.29903 .37608 L
s
.59223 .37255 m
.59268 .37294 L
s
.29861 .37644 m
.29904 .37602 L
s
.1748 .47325 m
.17486 .47277 L
s
.17189 .38688 m
.17206 .38651 L
s
.79985 .22848 m
.80012 .22867 L
s
.29874 .37629 m
.29918 .37588 L
s
.17187 .38682 m
.17204 .38645 L
s
.59197 .37237 m
.59243 .37275 L
s
.59207 .37237 m
.59252 .37275 L
s
.69714 .36691 m
.69737 .36727 L
s
.69707 .36682 m
.69731 .36718 L
s
.59205 .37222 m
.59251 .3726 L
s
.29903 .37608 m
.29947 .37567 L
s
.59177 .37217 m
.59223 .37255 L
s
.79958 .22829 m
.79985 .22848 L
s
.29904 .37602 m
.29948 .3756 L
s
.17206 .38651 m
.17223 .38614 L
s
.17486 .47277 m
.17492 .4723 L
s
.17204 .38645 m
.17221 .38608 L
s
.59152 .37198 m
.59197 .37237 L
s
.59162 .37199 m
.59207 .37237 L
s
.29918 .37588 m
.29962 .37546 L
s
.69691 .36655 m
.69714 .36691 L
s
.79932 .2281 m
.79958 .22829 L
s
.69684 .36647 m
.69707 .36682 L
s
.5916 .37184 m
.59205 .37222 L
s
.59132 .37179 m
.59177 .37217 L
s
.29947 .37567 m
.29991 .37525 L
s
.29948 .3756 m
.29992 .37519 L
s
.17223 .38614 m
.1724 .38577 L
s
.17492 .4723 m
.17499 .47182 L
s
.17221 .38608 m
.17238 .38572 L
s
.59106 .3716 m
.59152 .37198 L
s
.79905 .22791 m
.79932 .2281 L
s
.59116 .37161 m
.59162 .37199 L
s
.69667 .36619 m
.69691 .36655 L
s
.29962 .37546 m
.30006 .37504 L
s
.6966 .36611 m
.69684 .36647 L
s
.59114 .37146 m
.5916 .37184 L
s
.59086 .37141 m
.59132 .37179 L
s
.29991 .37525 m
.30035 .37483 L
s
.79878 .22771 m
.79905 .22791 L
s
.1724 .38577 m
.17257 .38541 L
s
.29992 .37519 m
.30037 .37477 L
s
.17238 .38572 m
.17255 .38535 L
s
.17499 .47182 m
.17506 .47134 L
s
.5906 .37122 m
.59106 .3716 L
s
.5907 .37123 m
.59116 .37161 L
s
.69643 .36584 m
.69667 .36619 L
s
.30006 .37504 m
.3005 .37463 L
s
.69636 .36575 m
.6966 .36611 L
s
.59068 .37108 m
.59114 .37146 L
s
.79851 .22752 m
.79878 .22771 L
s
.5904 .37103 m
.59086 .37141 L
s
.17257 .38541 m
.17275 .38504 L
s
.30035 .37483 m
.3008 .37442 L
s
.17255 .38535 m
.17273 .38498 L
s
.30037 .37477 m
.30082 .37436 L
s
.59014 .37085 m
.5906 .37122 L
s
.17506 .47134 m
.17513 .47087 L
s
.59024 .37085 m
.5907 .37123 L
s
.69619 .36548 m
.69643 .36584 L
s
.79825 .22733 m
.79851 .22752 L
s
.3005 .37463 m
.30095 .37422 L
s
.69612 .3654 m
.69636 .36575 L
s
.59022 .3707 m
.59068 .37108 L
s
.58994 .37065 m
.5904 .37103 L
s
.17275 .38504 m
.17292 .38467 L
s
.3008 .37442 m
.30125 .37401 L
s
.17273 .38498 m
.1729 .38462 L
s
.79798 .22714 m
.79825 .22733 L
s
.30082 .37436 m
.30127 .37395 L
s
.58968 .37047 m
.59014 .37085 L
s
.58978 .37047 m
.59024 .37085 L
s
.69595 .36512 m
.69619 .36548 L
s
.17513 .47087 m
.1752 .47039 L
s
.30095 .37422 m
.30141 .37381 L
s
.69588 .36504 m
.69612 .3654 L
s
.58975 .37032 m
.59022 .3707 L
s
.79771 .22695 m
.79798 .22714 L
s
.58947 .37027 m
.58994 .37065 L
s
.17292 .38467 m
.1731 .38431 L
s
.1729 .38462 m
.17308 .38425 L
s
.30125 .37401 m
.3017 .3736 L
s
.30127 .37395 m
.30172 .37354 L
s
.58921 .37009 m
.58968 .37047 L
s
.58931 .37009 m
.58978 .37047 L
s
.69571 .36477 m
.69595 .36512 L
s
.1752 .47039 m
.17527 .46991 L
s
.79743 .22677 m
.79771 .22695 L
s
.69564 .36468 m
.69588 .36504 L
s
.30141 .37381 m
.30186 .37339 L
s
.58929 .36995 m
.58975 .37032 L
s
.589 .3699 m
.58947 .37027 L
s
.1731 .38431 m
.17328 .38394 L
s
.17308 .38425 m
.17326 .38388 L
s
.3017 .3736 m
.30216 .37319 L
s
.79716 .22658 m
.79743 .22677 L
s
.58874 .36972 m
.58921 .37009 L
s
.69546 .36441 m
.69571 .36477 L
s
.58884 .36972 m
.58931 .37009 L
s
.30172 .37354 m
.30218 .37313 L
s
.17527 .46991 m
.17534 .46944 L
s
.69539 .36433 m
.69564 .36468 L
s
.30186 .37339 m
.30232 .37299 L
s
.58881 .36957 m
.58929 .36995 L
s
.58853 .36952 m
.589 .3699 L
s
.17328 .38394 m
.17346 .38358 L
s
.79689 .22639 m
.79716 .22658 L
s
.17326 .38388 m
.17344 .38352 L
s
.30216 .37319 m
.30262 .37278 L
s
.69522 .36406 m
.69546 .36441 L
s
.58826 .36934 m
.58874 .36972 L
s
.58836 .36934 m
.58884 .36972 L
s
.30218 .37313 m
.30264 .37272 L
s
.69514 .36397 m
.69539 .36433 L
s
.17534 .46944 m
.17542 .46896 L
s
.79662 .2262 m
.79689 .22639 L
s
.58834 .3692 m
.58881 .36957 L
s
.30232 .37299 m
.30278 .37258 L
s
.58805 .36915 m
.58853 .36952 L
s
.17346 .38358 m
.17364 .38321 L
s
.17344 .38352 m
.17362 .38315 L
s
.69497 .3637 m
.69522 .36406 L
s
.30262 .37278 m
.30308 .37237 L
s
.58779 .36897 m
.58826 .36934 L
s
.58789 .36897 m
.58836 .36934 L
s
.79634 .22601 m
.79662 .2262 L
s
.30264 .37272 m
.30311 .37231 L
s
.6949 .36362 m
.69514 .36397 L
s
.17542 .46896 m
.17549 .46848 L
s
.58786 .36883 m
.58834 .3692 L
s
.30278 .37258 m
.30325 .37217 L
s
.17364 .38321 m
.17383 .38284 L
s
.58757 .36878 m
.58805 .36915 L
s
.17362 .38315 m
.17381 .38279 L
s
.79607 .22582 m
.79634 .22601 L
s
.69472 .36334 m
.69497 .3637 L
s
.58731 .3686 m
.58779 .36897 L
s
.58741 .3686 m
.58789 .36897 L
s
.30308 .37237 m
.30355 .37197 L
s
.30311 .37231 m
.30357 .37191 L
s
.69465 .36326 m
.6949 .36362 L
s
.58738 .36845 m
.58786 .36883 L
s
.17549 .46848 m
.17557 .468 L
s
.17383 .38284 m
.17401 .38248 L
s
.7958 .22564 m
.79607 .22582 L
s
.58709 .36841 m
.58757 .36878 L
s
.30325 .37217 m
.30372 .37177 L
s
.17381 .38279 m
.17399 .38242 L
s
.69447 .36299 m
.69472 .36334 L
s
.58682 .36823 m
.58731 .3686 L
s
.58692 .36823 m
.58741 .3686 L
s
.30355 .37197 m
.30402 .37156 L
s
.79552 .22545 m
.7958 .22564 L
s
.6944 .36291 m
.69465 .36326 L
s
.30357 .37191 m
.30404 .3715 L
s
.5869 .36808 m
.58738 .36845 L
s
.17401 .38248 m
.1742 .38211 L
s
.58661 .36804 m
.58709 .36841 L
s
.17557 .468 m
.17565 .46752 L
s
.30372 .37177 m
.30419 .37136 L
s
.17399 .38242 m
.17418 .38206 L
s
.79524 .22526 m
.79552 .22545 L
s
.69422 .36264 m
.69447 .36299 L
s
.58634 .36786 m
.58682 .36823 L
s
.58644 .36786 m
.58692 .36823 L
s
.30402 .37156 m
.30449 .37116 L
s
.69415 .36255 m
.6944 .36291 L
s
.30404 .3715 m
.30452 .3711 L
s
.58641 .36772 m
.5869 .36808 L
s
.1742 .38211 m
.17438 .38175 L
s
.58612 .36767 m
.58661 .36804 L
s
.17418 .38206 m
.17437 .38169 L
s
.79497 .22507 m
.79524 .22526 L
s
.17565 .46752 m
.17573 .46704 L
s
.30419 .37136 m
.30466 .37096 L
s
.69397 .36228 m
.69422 .36264 L
s
.58585 .36749 m
.58634 .36786 L
s
.58595 .36749 m
.58644 .36786 L
s
.69389 .3622 m
.69415 .36255 L
s
.30449 .37116 m
.30497 .37076 L
s
.79469 .22489 m
.79497 .22507 L
s
.30452 .3711 m
.30499 .3707 L
s
.58593 .36735 m
.58641 .36772 L
s
.17438 .38175 m
.17457 .38138 L
s
.58563 .3673 m
.58612 .36767 L
s
.17437 .38169 m
.17455 .38133 L
s
.30466 .37096 m
.30514 .37056 L
s
.17573 .46704 m
.17582 .46656 L
s
.69371 .36193 m
.69397 .36228 L
s
.58536 .36712 m
.58585 .36749 L
s
.58546 .36712 m
.58595 .36749 L
s
.79441 .2247 m
.79469 .22489 L
s
.69364 .36185 m
.69389 .3622 L
s
.30497 .37076 m
.30545 .37036 L
s
.58543 .36698 m
.58593 .36735 L
s
.30499 .3707 m
.30547 .3703 L
s
.17457 .38138 m
.17476 .38102 L
s
.58514 .36693 m
.58563 .3673 L
s
.17455 .38133 m
.17475 .38096 L
s
.30514 .37056 m
.30562 .37016 L
s
.79413 .22452 m
.79441 .2247 L
s
.17582 .46656 m
.1759 .46608 L
s
.69346 .36157 m
.69371 .36193 L
s
.58486 .36676 m
.58536 .36712 L
s
.58497 .36676 m
.58546 .36712 L
s
.69338 .36149 m
.69364 .36185 L
s
.30545 .37036 m
.30593 .36996 L
s
.58494 .36662 m
.58543 .36698 L
s
.17476 .38102 m
.17496 .38065 L
s
.30547 .3703 m
.30596 .3699 L
s
.58464 .36657 m
.58514 .36693 L
s
.79385 .22433 m
.79413 .22452 L
s
.17475 .38096 m
.17494 .3806 L
s
.30562 .37016 m
.30611 .36976 L
s
.1759 .46608 m
.17599 .4656 L
s
.58437 .36639 m
.58486 .36676 L
s
.6932 .36122 m
.69346 .36157 L
s
.58447 .36639 m
.58497 .36676 L
s
.69312 .36114 m
.69338 .36149 L
s
.79357 .22415 m
.79385 .22433 L
s
.58444 .36625 m
.58494 .36662 L
s
.30593 .36996 m
.30642 .36956 L
s
.17496 .38065 m
.17515 .38029 L
s
.58415 .3662 m
.58464 .36657 L
s
.30596 .3699 m
.30644 .3695 L
s
.17494 .3806 m
.17513 .38023 L
s
.30611 .36976 m
.3066 .36937 L
s
.58387 .36603 m
.58437 .36639 L
s
.58397 .36603 m
.58447 .36639 L
s
.79329 .22396 m
.79357 .22415 L
s
.69294 .36087 m
.6932 .36122 L
s
.17599 .4656 m
.17607 .46512 L
s
.69286 .36079 m
.69312 .36114 L
s
.58394 .36589 m
.58444 .36625 L
s
.17515 .38029 m
.17535 .37993 L
s
.30642 .36956 m
.30691 .36916 L
s
.58364 .36584 m
.58415 .3662 L
s
.17513 .38023 m
.17533 .37987 L
s
.30644 .3695 m
.30693 .36911 L
s
.79301 .22378 m
.79329 .22396 L
s
.3066 .36937 m
.30709 .36897 L
s
.58337 .36567 m
.58387 .36603 L
s
.58347 .36567 m
.58397 .36603 L
s
.69268 .36052 m
.69294 .36087 L
s
.17607 .46512 m
.17616 .46464 L
s
.6926 .36043 m
.69286 .36079 L
s
.58344 .36553 m
.58394 .36589 L
s
.17535 .37993 m
.17554 .37956 L
s
.79273 .22359 m
.79301 .22378 L
s
.58314 .36548 m
.58364 .36584 L
s
.30691 .36916 m
.3074 .36877 L
s
.17533 .37987 m
.17552 .3795 L
s
.30693 .36911 m
.30743 .36871 L
s
.58286 .36531 m
.58337 .36567 L
s
.58297 .36531 m
.58347 .36567 L
s
.30709 .36897 m
.30758 .36858 L
s
.69242 .36016 m
.69268 .36052 L
s
.79245 .22341 m
.79273 .22359 L
s
.17616 .46464 m
.17625 .46416 L
s
.69234 .36008 m
.6926 .36043 L
s
.58294 .36517 m
.58344 .36553 L
s
.17554 .37956 m
.17574 .3792 L
s
.58264 .36512 m
.58314 .36548 L
s
.3074 .36877 m
.3079 .36837 L
s
.17552 .3795 m
.17572 .37914 L
s
.30743 .36871 m
.30792 .36832 L
s
.79216 .22322 m
.79245 .22341 L
s
.58235 .36495 m
.58286 .36531 L
s
.58246 .36495 m
.58297 .36531 L
s
.69215 .35981 m
.69242 .36016 L
s
.30758 .36858 m
.30808 .36818 L
s
.69207 .35973 m
.69234 .36008 L
s
.58243 .36481 m
.58294 .36517 L
s
.17625 .46416 m
.17634 .46368 L
s
.17574 .3792 m
.17594 .37883 L
s
.58213 .36476 m
.58264 .36512 L
s
.17572 .37914 m
.17592 .37878 L
s
.3079 .36837 m
.30839 .36798 L
s
.79188 .22304 m
.79216 .22322 L
s
.30792 .36832 m
.30842 .36793 L
s
.58184 .36459 m
.58235 .36495 L
s
.58195 .36459 m
.58246 .36495 L
s
.69189 .35946 m
.69215 .35981 L
s
.30808 .36818 m
.30858 .36779 L
s
.69181 .35938 m
.69207 .35973 L
s
.58192 .36445 m
.58243 .36481 L
s
.79159 .22286 m
.79188 .22304 L
s
.17594 .37883 m
.17614 .37847 L
s
.17634 .46368 m
.17644 .4632 L
s
.58161 .3644 m
.58213 .36476 L
s
.17592 .37878 m
.17612 .37841 L
s
.30839 .36798 m
.3089 .36759 L
s
.30842 .36793 m
.30892 .36754 L
s
.58133 .36423 m
.58184 .36459 L
s
.58144 .36423 m
.58195 .36459 L
s
.69162 .35911 m
.69189 .35946 L
s
.79131 .22267 m
.79159 .22286 L
s
.30858 .36779 m
.30908 .3674 L
s
.69154 .35903 m
.69181 .35938 L
s
.58141 .36409 m
.58192 .36445 L
s
.17614 .37847 m
.17634 .37811 L
s
.5811 .36405 m
.58161 .3644 L
s
.17612 .37841 m
.17633 .37805 L
s
.17644 .4632 m
.17653 .46271 L
s
.3089 .36759 m
.3094 .3672 L
s
.30892 .36754 m
.30943 .36715 L
s
.79102 .22249 m
.79131 .22267 L
s
.58081 .36388 m
.58133 .36423 L
s
.58092 .36388 m
.58144 .36423 L
s
.69135 .35876 m
.69162 .35911 L
s
.30908 .3674 m
.30959 .36702 L
s
.69127 .35868 m
.69154 .35903 L
s
.58089 .36374 m
.58141 .36409 L
s
.17634 .37811 m
.17655 .37774 L
s
.58058 .36369 m
.5811 .36405 L
s
.17633 .37805 m
.17653 .37769 L
s
.79074 .22231 m
.79102 .22249 L
s
.17653 .46271 m
.17663 .46223 L
s
.3094 .3672 m
.30991 .36682 L
s
.30943 .36715 m
.30994 .36676 L
s
.5803 .36352 m
.58081 .36388 L
s
.5804 .36352 m
.58092 .36388 L
s
.69108 .35841 m
.69135 .35876 L
s
.30959 .36702 m
.3101 .36663 L
s
.79045 .22213 m
.79074 .22231 L
s
.58037 .36338 m
.58089 .36374 L
s
.691 .35833 m
.69127 .35868 L
s
.17655 .37774 m
.17675 .37738 L
s
.58006 .36334 m
.58058 .36369 L
s
.17653 .37769 m
.17674 .37732 L
s
.30991 .36682 m
.31042 .36643 L
s
.17663 .46223 m
.17673 .46175 L
s
.57977 .36317 m
.5803 .36352 L
s
.57988 .36317 m
.5804 .36352 L
s
.30994 .36676 m
.31045 .36638 L
s
.79016 .22195 m
.79045 .22213 L
s
.69081 .35806 m
.69108 .35841 L
s
.3101 .36663 m
.31061 .36624 L
s
.57985 .36303 m
.58037 .36338 L
s
.69073 .35797 m
.691 .35833 L
s
.17675 .37738 m
.17696 .37702 L
s
.57954 .36298 m
.58006 .36334 L
s
.17674 .37732 m
.17694 .37696 L
s
.78987 .22177 m
.79016 .22195 L
s
.31042 .36643 m
.31093 .36604 L
s
.57925 .36282 m
.57977 .36317 L
s
.57936 .36282 m
.57988 .36317 L
s
.17673 .46175 m
.17683 .46126 L
s
.31045 .36638 m
.31096 .36599 L
s
.69054 .35771 m
.69081 .35806 L
s
.57933 .36268 m
.57985 .36303 L
s
.31061 .36624 m
.31112 .36586 L
s
.69046 .35763 m
.69073 .35797 L
s
.57902 .36263 m
.57954 .36298 L
s
.17696 .37702 m
.17717 .37666 L
s
.78958 .22158 m
.78987 .22177 L
s
.17694 .37696 m
.17715 .3766 L
s
.31093 .36604 m
.31145 .36566 L
s
.57872 .36247 m
.57925 .36282 L
s
.57883 .36247 m
.57936 .36282 L
s
.31096 .36599 m
.31148 .36561 L
s
.17683 .46126 m
.17693 .46078 L
s
.69027 .35736 m
.69054 .35771 L
s
.5788 .36233 m
.57933 .36268 L
s
.78929 .2214 m
.78958 .22158 L
s
.31112 .36586 m
.31164 .36548 L
s
.57849 .36228 m
.57902 .36263 L
s
.69019 .35728 m
.69046 .35763 L
s
.17717 .37666 m
.17738 .37629 L
s
.17715 .3766 m
.17736 .37624 L
s
.57819 .36212 m
.57872 .36247 L
s
.5783 .36212 m
.57883 .36247 L
s
.31145 .36566 m
.31197 .36528 L
s
.789 .22122 m
.78929 .2214 L
s
.31148 .36561 m
.312 .36523 L
s
.17693 .46078 m
.17703 .4603 L
s
.68999 .35701 m
.69027 .35736 L
s
.57827 .36198 m
.5788 .36233 L
s
.57796 .36193 m
.57849 .36228 L
s
.31164 .36548 m
.31216 .3651 L
s
.68991 .35693 m
.69019 .35728 L
s
.17738 .37629 m
.17759 .37593 L
s
.17736 .37624 m
.17757 .37588 L
s
.78871 .22104 m
.789 .22122 L
s
.57766 .36177 m
.57819 .36212 L
s
.57777 .36177 m
.5783 .36212 L
s
.31197 .36528 m
.31249 .3649 L
s
.312 .36523 m
.31252 .36485 L
s
.68971 .35666 m
.68999 .35701 L
s
.57774 .36163 m
.57827 .36198 L
s
.17703 .4603 m
.17714 .45981 L
s
.57742 .36159 m
.57796 .36193 L
s
.31216 .3651 m
.31269 .36472 L
s
.17759 .37593 m
.1778 .37557 L
s
.68963 .35658 m
.68991 .35693 L
s
.78842 .22086 m
.78871 .22104 L
s
.17757 .37588 m
.17779 .37551 L
s
.57713 .36142 m
.57766 .36177 L
s
.57724 .36142 m
.57777 .36177 L
s
.31249 .3649 m
.31302 .36452 L
s
.31252 .36485 m
.31305 .36447 L
s
.5772 .36129 m
.57774 .36163 L
s
.68943 .35631 m
.68971 .35666 L
s
.78813 .22069 m
.78842 .22086 L
s
.57689 .36124 m
.57742 .36159 L
s
.17714 .45981 m
.17724 .45933 L
s
.1778 .37557 m
.17802 .37521 L
s
.31269 .36472 m
.31322 .36434 L
s
.68935 .35623 m
.68963 .35658 L
s
.17779 .37551 m
.178 .37515 L
s
.57659 .36108 m
.57713 .36142 L
s
.5767 .36108 m
.57724 .36142 L
s
.78783 .22051 m
.78813 .22069 L
s
.31302 .36452 m
.31355 .36414 L
s
.31305 .36447 m
.31358 .36409 L
s
.57666 .36094 m
.5772 .36129 L
s
.68915 .35596 m
.68943 .35631 L
s
.57635 .3609 m
.57689 .36124 L
s
.17802 .37521 m
.17823 .37485 L
s
.31322 .36434 m
.31375 .36396 L
s
.68907 .35588 m
.68935 .35623 L
s
.17724 .45933 m
.17735 .45884 L
s
.178 .37515 m
.17822 .37479 L
s
.78754 .22033 m
.78783 .22051 L
s
.57605 .36073 m
.57659 .36108 L
s
.57616 .36073 m
.5767 .36108 L
s
.31355 .36414 m
.31408 .36377 L
s
.57612 .3606 m
.57666 .36094 L
s
.31358 .36409 m
.31411 .36372 L
s
.57581 .36055 m
.57635 .3609 L
s
.68887 .35561 m
.68915 .35596 L
s
.78725 .22015 m
.78754 .22033 L
s
.17823 .37485 m
.17845 .37449 L
s
.31375 .36396 m
.31428 .36359 L
s
.68879 .35553 m
.68907 .35588 L
s
.17822 .37479 m
.17844 .37443 L
s
.17735 .45884 m
.17746 .45836 L
s
.57551 .36039 m
.57605 .36073 L
s
.57562 .36039 m
.57616 .36073 L
s
.31408 .36377 m
.31461 .36339 L
s
.57558 .36026 m
.57612 .3606 L
s
.31411 .36372 m
.31465 .36334 L
s
.78695 .21997 m
.78725 .22015 L
s
.57526 .36021 m
.57581 .36055 L
s
.68859 .35526 m
.68887 .35561 L
s
.17845 .37449 m
.17867 .37413 L
s
.31428 .36359 m
.31482 .36321 L
s
.68851 .35519 m
.68879 .35553 L
s
.17844 .37443 m
.17865 .37407 L
s
.57496 .36005 m
.57551 .36039 L
s
.57507 .36005 m
.57562 .36039 L
s
.17746 .45836 m
.17757 .45787 L
s
.78666 .21979 m
.78695 .21997 L
s
.31461 .36339 m
.31515 .36302 L
s
.57504 .35992 m
.57558 .36026 L
s
.31465 .36334 m
.31518 .36297 L
s
.57472 .35987 m
.57526 .36021 L
s
.68831 .35492 m
.68859 .35526 L
s
.17867 .37413 m
.17889 .37376 L
s
.31482 .36321 m
.31536 .36284 L
s
.68822 .35484 m
.68851 .35519 L
s
.57442 .35971 m
.57496 .36005 L
s
.57453 .35971 m
.57507 .36005 L
s
.17865 .37407 m
.17888 .37371 L
s
.78636 .21962 m
.78666 .21979 L
s
.17757 .45787 m
.17768 .45739 L
s
.57449 .35958 m
.57504 .35992 L
s
.31515 .36302 m
.31569 .36265 L
s
.57417 .35953 m
.57472 .35987 L
s
.31518 .36297 m
.31573 .3626 L
s
.68802 .35457 m
.68831 .35492 L
s
.78606 .21944 m
.78636 .21962 L
s
.17889 .37376 m
.17911 .3734 L
s
.31536 .36284 m
.3159 .36247 L
s
.57386 .35937 m
.57442 .35971 L
s
.68794 .35449 m
.68822 .35484 L
s
.57398 .35937 m
.57453 .35971 L
s
.17888 .37371 m
.1791 .37335 L
s
.57394 .35924 m
.57449 .35958 L
s
.17768 .45739 m
.1778 .4569 L
s
.31569 .36265 m
.31623 .36228 L
s
.57362 .35919 m
.57417 .35953 L
s
.78576 .21926 m
.78606 .21944 L
s
.31573 .3626 m
.31627 .36223 L
s
.68773 .35422 m
.68802 .35457 L
s
.17911 .3734 m
.17934 .37304 L
s
.3159 .36247 m
.31644 .3621 L
s
.57331 .35903 m
.57386 .35937 L
s
.57342 .35903 m
.57398 .35937 L
s
.68765 .35414 m
.68794 .35449 L
s
.1791 .37335 m
.17932 .37299 L
s
.78547 .21909 m
.78576 .21926 L
s
.57338 .3589 m
.57394 .35924 L
s
.57306 .35886 m
.57362 .35919 L
s
.31623 .36228 m
.31678 .36191 L
s
.1778 .4569 m
.17791 .45641 L
s
.31627 .36223 m
.31682 .36186 L
s
.68744 .35388 m
.68773 .35422 L
s
.57276 .3587 m
.57331 .35903 L
s
.17934 .37304 m
.17956 .37268 L
s
.57287 .3587 m
.57342 .35903 L
s
.31644 .3621 m
.31699 .36174 L
s
.68736 .3538 m
.68765 .35414 L
s
.78517 .21891 m
.78547 .21909 L
s
.17932 .37299 m
.17955 .37263 L
s
.57283 .35857 m
.57338 .3589 L
s
.5725 .35852 m
.57306 .35886 L
s
.31678 .36191 m
.31733 .36154 L
s
.31682 .36186 m
.31737 .3615 L
s
.17791 .45641 m
.17803 .45593 L
s
.78487 .21873 m
.78517 .21891 L
s
.68715 .35353 m
.68744 .35388 L
s
.5722 .35836 m
.57276 .3587 L
s
.57231 .35836 m
.57287 .3587 L
s
.17956 .37268 m
.17979 .37232 L
s
.31699 .36174 m
.31754 .36137 L
s
.68707 .35345 m
.68736 .3538 L
s
.17955 .37263 m
.17977 .37227 L
s
.57227 .35823 m
.57283 .35857 L
s
.57194 .35819 m
.5725 .35852 L
s
.31733 .36154 m
.31788 .36118 L
s
.78457 .21856 m
.78487 .21873 L
s
.31737 .3615 m
.31792 .36113 L
s
.17803 .45593 m
.17815 .45544 L
s
.57164 .35803 m
.5722 .35836 L
s
.57175 .35803 m
.57231 .35836 L
s
.68686 .35319 m
.68715 .35353 L
s
.17979 .37232 m
.18002 .37196 L
s
.31754 .36137 m
.3181 .36101 L
s
.68678 .35311 m
.68707 .35345 L
s
.17977 .37227 m
.18 .37191 L
s
.57171 .3579 m
.57227 .35823 L
s
.57138 .35786 m
.57194 .35819 L
s
.78427 .21838 m
.78457 .21856 L
s
.31788 .36118 m
.31844 .36082 L
s
.31792 .36113 m
.31847 .36077 L
s
.57107 .3577 m
.57164 .35803 L
s
.57119 .3577 m
.57175 .35803 L
s
.68657 .35284 m
.68686 .35319 L
s
.17815 .45544 m
.17827 .45495 L
s
.18002 .37196 m
.18025 .3716 L
s
.3181 .36101 m
.31865 .36064 L
s
.78396 .21821 m
.78427 .21838 L
s
.18 .37191 m
.18023 .37155 L
s
.68648 .35276 m
.68678 .35311 L
s
.57115 .35757 m
.57171 .3579 L
s
.57082 .35753 m
.57138 .35786 L
s
.31844 .36082 m
.31899 .36045 L
s
.31847 .36077 m
.31903 .36041 L
s
.57051 .35737 m
.57107 .3577 L
s
.57062 .35737 m
.57119 .3577 L
s
.78366 .21803 m
.78396 .21821 L
s
.68627 .3525 m
.68657 .35284 L
s
.31865 .36064 m
.31921 .36028 L
s
.18025 .3716 m
.18048 .37125 L
s
.17827 .45495 m
.17839 .45447 L
s
.57058 .35724 m
.57115 .35757 L
s
.18023 .37155 m
.18046 .37119 L
s
.68619 .35242 m
.68648 .35276 L
s
.57025 .3572 m
.57082 .35753 L
s
.31899 .36045 m
.31955 .36009 L
s
.78336 .21786 m
.78366 .21803 L
s
.31903 .36041 m
.31959 .36005 L
s
.56994 .35704 m
.57051 .35737 L
s
.57005 .35704 m
.57062 .35737 L
s
.31921 .36028 m
.31977 .35992 L
s
.68598 .35215 m
.68627 .3525 L
s
.18048 .37125 m
.18071 .37089 L
s
.57001 .35691 m
.57058 .35724 L
s
.56968 .35687 m
.57025 .3572 L
s
.18046 .37119 m
.18069 .37083 L
s
.17839 .45447 m
.17851 .45398 L
s
.68589 .35207 m
.68619 .35242 L
s
.78306 .21769 m
.78336 .21786 L
s
.31955 .36009 m
.32012 .35974 L
s
.31959 .36005 m
.32016 .35969 L
s
.56937 .35671 m
.56994 .35704 L
s
.56948 .35671 m
.57005 .35704 L
s
.31977 .35992 m
.32034 .35957 L
s
.56944 .35659 m
.57001 .35691 L
s
.68568 .35181 m
.68598 .35215 L
s
.18071 .37089 m
.18094 .37053 L
s
.78275 .21751 m
.78306 .21769 L
s
.56911 .35654 m
.56968 .35687 L
s
.18069 .37083 m
.18093 .37047 L
s
.68559 .35173 m
.68589 .35207 L
s
.17851 .45398 m
.17864 .45349 L
s
.32012 .35974 m
.32068 .35938 L
s
.56879 .35639 m
.56937 .35671 L
s
.56891 .35639 m
.56948 .35671 L
s
.32016 .35969 m
.32073 .35934 L
s
.78245 .21734 m
.78275 .21751 L
s
.56887 .35626 m
.56944 .35659 L
s
.32034 .35957 m
.32091 .35921 L
s
.68538 .35146 m
.68568 .35181 L
s
.18094 .37053 m
.18118 .37017 L
s
.56853 .35622 m
.56911 .35654 L
s
.18093 .37047 m
.18116 .37011 L
s
.68529 .35139 m
.68559 .35173 L
s
.17864 .45349 m
.17876 .453 L
s
.32068 .35938 m
.32125 .35902 L
s
.56822 .35606 m
.56879 .35639 L
s
.56833 .35606 m
.56891 .35639 L
s
.32073 .35934 m
.32129 .35898 L
s
.78214 .21717 m
.78245 .21734 L
s
.56829 .35594 m
.56887 .35626 L
s
.32091 .35921 m
.32148 .35886 L
s
.56796 .35589 m
.56853 .35622 L
s
.18118 .37017 m
.18142 .36981 L
s
.68508 .35112 m
.68538 .35146 L
s
.18116 .37011 m
.1814 .36976 L
s
.68499 .35104 m
.68529 .35139 L
s
.78183 .21699 m
.78214 .21717 L
s
.56764 .35574 m
.56822 .35606 L
s
.56776 .35574 m
.56833 .35606 L
s
.32125 .35902 m
.32183 .35867 L
s
.32129 .35898 m
.32187 .35863 L
s
.17876 .453 m
.17889 .45251 L
s
.56771 .35561 m
.56829 .35594 L
s
.32148 .35886 m
.32205 .3585 L
s
.56738 .35557 m
.56796 .35589 L
s
.18142 .36981 m
.18165 .36945 L
s
.68478 .35078 m
.68508 .35112 L
s
.78153 .21682 m
.78183 .21699 L
s
.1814 .36976 m
.18164 .3694 L
s
.56706 .35542 m
.56764 .35574 L
s
.68469 .3507 m
.68499 .35104 L
s
.56717 .35542 m
.56776 .35574 L
s
.32183 .35867 m
.3224 .35832 L
s
.32187 .35863 m
.32244 .35828 L
s
.17889 .45251 m
.17902 .45202 L
s
.56713 .35529 m
.56771 .35561 L
s
.56679 .35525 m
.56738 .35557 L
s
.32205 .3585 m
.32263 .35815 L
s
.78122 .21665 m
.78153 .21682 L
s
.18165 .36945 m
.18189 .3691 L
s
.68448 .35043 m
.68478 .35078 L
s
.18164 .3694 m
.18188 .36904 L
s
.56648 .3551 m
.56706 .35542 L
s
.56659 .3551 m
.56717 .35542 L
s
.68439 .35036 m
.68469 .3507 L
s
.3224 .35832 m
.32298 .35797 L
s
.32244 .35828 m
.32302 .35793 L
s
.78091 .21648 m
.78122 .21665 L
s
.56655 .35497 m
.56713 .35529 L
s
.56621 .35493 m
.56679 .35525 L
s
.32263 .35815 m
.32321 .3578 L
s
.17902 .45202 m
.17915 .45154 L
s
.18189 .3691 m
.18213 .36874 L
s
.68417 .35009 m
.68448 .35043 L
s
.56589 .35478 m
.56648 .3551 L
s
.56601 .35478 m
.56659 .3551 L
s
.18188 .36904 m
.18212 .36868 L
s
.32298 .35797 m
.32356 .35762 L
s
.7806 .21631 m
.78091 .21648 L
s
.68408 .35001 m
.68439 .35036 L
s
.32302 .35793 m
.3236 .35758 L
s
.56596 .35466 m
.56655 .35497 L
s
.56562 .35461 m
.56621 .35493 L
s
.32321 .3578 m
.32379 .35746 L
s
.17915 .45154 m
.17928 .45105 L
s
.5653 .35446 m
.56589 .35478 L
s
.18213 .36874 m
.18238 .36838 L
s
.56542 .35446 m
.56601 .35478 L
s
.78029 .21614 m
.7806 .21631 L
s
.68386 .34975 m
.68417 .35009 L
s
.18212 .36868 m
.18236 .36833 L
s
.32356 .35762 m
.32414 .35727 L
s
.3236 .35758 m
.32418 .35723 L
s
.68378 .34967 m
.68408 .35001 L
s
.56537 .35434 m
.56596 .35466 L
s
.56503 .3543 m
.56562 .35461 L
s
.32379 .35746 m
.32437 .35711 L
s
.77998 .21597 m
.78029 .21614 L
s
.56471 .35415 m
.5653 .35446 L
s
.56483 .35415 m
.56542 .35446 L
s
.17928 .45105 m
.17942 .45056 L
s
.18238 .36838 m
.18262 .36802 L
s
.68356 .34941 m
.68386 .34975 L
s
.32414 .35727 m
.32473 .35693 L
s
.18236 .36833 m
.18261 .36797 L
s
.32418 .35723 m
.32477 .35689 L
s
.56478 .35402 m
.56537 .35434 L
s
.68347 .34933 m
.68378 .34967 L
s
.56444 .35398 m
.56503 .3543 L
s
.77967 .21579 m
.77998 .21597 L
s
.32437 .35711 m
.32496 .35677 L
s
.56412 .35384 m
.56471 .35415 L
s
.56423 .35384 m
.56483 .35415 L
s
.18262 .36802 m
.18287 .36767 L
s
.32473 .35693 m
.32531 .35658 L
s
.17942 .45056 m
.17955 .45007 L
s
.68325 .34907 m
.68356 .34941 L
s
.56419 .35371 m
.56478 .35402 L
s
.18261 .36797 m
.18285 .36761 L
s
.32477 .35689 m
.32536 .35654 L
s
.77936 .21563 m
.77967 .21579 L
s
.56385 .35367 m
.56444 .35398 L
s
.68316 .34899 m
.68347 .34933 L
s
.32496 .35677 m
.32555 .35642 L
s
.56352 .35352 m
.56412 .35384 L
s
.56364 .35352 m
.56423 .35384 L
s
.77905 .21546 m
.77936 .21563 L
s
.18287 .36767 m
.18311 .36731 L
s
.32531 .35658 m
.32591 .35624 L
s
.56359 .3534 m
.56419 .35371 L
s
.68294 .34873 m
.68325 .34907 L
s
.32536 .35654 m
.32595 .3562 L
s
.56325 .35336 m
.56385 .35367 L
s
.18285 .36761 m
.1831 .36726 L
s
.17955 .45007 m
.17969 .44958 L
s
.68285 .34865 m
.68316 .34899 L
s
.32555 .35642 m
.32614 .35608 L
s
.56292 .35321 m
.56352 .35352 L
s
.56304 .35321 m
.56364 .35352 L
s
.77874 .21529 m
.77905 .21546 L
s
.56299 .35309 m
.56359 .3534 L
s
.32591 .35624 m
.3265 .3559 L
s
.18311 .36731 m
.18336 .36696 L
s
.56265 .35305 m
.56325 .35336 L
s
.32595 .3562 m
.32655 .35586 L
s
.68262 .34839 m
.68294 .34873 L
s
.1831 .36726 m
.18335 .3669 L
s
.17969 .44958 m
.17983 .44909 L
s
.68253 .34831 m
.68285 .34865 L
s
.32614 .35608 m
.32674 .35574 L
s
.56232 .3529 m
.56292 .35321 L
s
.56244 .3529 m
.56304 .35321 L
s
.77842 .21512 m
.77874 .21529 L
s
.56239 .35278 m
.56299 .35309 L
s
.3265 .3559 m
.3271 .35556 L
s
.56205 .35274 m
.56265 .35305 L
s
.32655 .35586 m
.32714 .35552 L
s
.18336 .36696 m
.18361 .3666 L
s
.68231 .34805 m
.68262 .34839 L
s
.18335 .3669 m
.1836 .36654 L
s
.77811 .21495 m
.77842 .21512 L
s
.32674 .35574 m
.32734 .3554 L
s
.56172 .3526 m
.56232 .3529 L
s
.56184 .35259 m
.56244 .3529 L
s
.68222 .34797 m
.68253 .34831 L
s
.17983 .44909 m
.17997 .4486 L
s
.56179 .35247 m
.56239 .35278 L
s
.3271 .35556 m
.3277 .35522 L
s
.56144 .35243 m
.56205 .35274 L
s
.32714 .35552 m
.32774 .35519 L
s
.77779 .21478 m
.77811 .21495 L
s
.18361 .3666 m
.18386 .36624 L
s
.682 .34771 m
.68231 .34805 L
s
.1836 .36654 m
.18385 .36619 L
s
.56111 .35229 m
.56172 .3526 L
s
.32734 .3554 m
.32794 .35507 L
s
.56123 .35229 m
.56184 .35259 L
s
.6819 .34763 m
.68222 .34797 L
s
.17997 .4486 m
.18011 .4481 L
s
.56118 .35217 m
.56179 .35247 L
s
.56084 .35213 m
.56144 .35243 L
s
.77748 .21461 m
.77779 .21478 L
s
.3277 .35522 m
.3283 .35489 L
s
.32774 .35519 m
.32834 .35485 L
s
.18386 .36624 m
.18412 .36589 L
s
.56051 .35198 m
.56111 .35229 L
s
.56063 .35198 m
.56123 .35229 L
s
.32794 .35507 m
.32854 .35473 L
s
.18385 .36619 m
.1841 .36583 L
s
.68168 .34737 m
.682 .34771 L
s
.68159 .34729 m
.6819 .34763 L
s
.56057 .35186 m
.56118 .35217 L
s
.77716 .21445 m
.77748 .21461 L
s
.56023 .35182 m
.56084 .35213 L
s
.3283 .35489 m
.3289 .35456 L
s
.18011 .4481 m
.18025 .44761 L
s
.32834 .35485 m
.32895 .35452 L
s
.5599 .35168 m
.56051 .35198 L
s
.56002 .35168 m
.56063 .35198 L
s
.18412 .36589 m
.18437 .36553 L
s
.32854 .35473 m
.32915 .3544 L
s
.1841 .36583 m
.18436 .36548 L
s
.68136 .34703 m
.68168 .34737 L
s
.77685 .21428 m
.77716 .21445 L
s
.55996 .35156 m
.56057 .35186 L
s
.68127 .34695 m
.68159 .34729 L
s
.55962 .35152 m
.56023 .35182 L
s
.3289 .35456 m
.32951 .35422 L
s
.32895 .35452 m
.32956 .35419 L
s
.18025 .44761 m
.1804 .44712 L
s
.55928 .35138 m
.5599 .35168 L
s
.5594 .35138 m
.56002 .35168 L
s
.77653 .21411 m
.77685 .21428 L
s
.32915 .3544 m
.32975 .35407 L
s
.18437 .36553 m
.18463 .36518 L
s
.18436 .36548 m
.18461 .36512 L
s
.55935 .35126 m
.55996 .35156 L
s
.68104 .34669 m
.68136 .34703 L
s
.559 .35122 m
.55962 .35152 L
s
.68095 .34662 m
.68127 .34695 L
s
.32951 .35422 m
.33012 .35389 L
s
.32956 .35419 m
.33017 .35386 L
s
.55867 .35108 m
.55928 .35138 L
s
.77621 .21395 m
.77653 .21411 L
s
.55879 .35108 m
.5594 .35138 L
s
.32975 .35407 m
.33036 .35374 L
s
.1804 .44712 m
.18054 .44663 L
s
.18463 .36518 m
.18489 .36482 L
s
.55874 .35096 m
.55935 .35126 L
s
.55839 .35092 m
.559 .35122 L
s
.18461 .36512 m
.18487 .36477 L
s
.68072 .34635 m
.68104 .34669 L
s
.33012 .35389 m
.33073 .35357 L
s
.77589 .21378 m
.77621 .21395 L
s
.68063 .34628 m
.68095 .34662 L
s
.33017 .35386 m
.33078 .35353 L
s
.55805 .35078 m
.55867 .35108 L
s
.55817 .35078 m
.55879 .35108 L
s
.33036 .35374 m
.33098 .35342 L
s
.55812 .35066 m
.55874 .35096 L
s
.18489 .36482 m
.18514 .36447 L
s
.18054 .44663 m
.18069 .44614 L
s
.55777 .35062 m
.55839 .35092 L
s
.18487 .36477 m
.18513 .36442 L
s
.77557 .21361 m
.77589 .21378 L
s
.6804 .34601 m
.68072 .34635 L
s
.33073 .35357 m
.33134 .35324 L
s
.33078 .35353 m
.33139 .35321 L
s
.55743 .35048 m
.55805 .35078 L
s
.55755 .35048 m
.55817 .35078 L
s
.6803 .34594 m
.68063 .34628 L
s
.33098 .35342 m
.33159 .35309 L
s
.5575 .35037 m
.55812 .35066 L
s
.55715 .35033 m
.55777 .35062 L
s
.77525 .21345 m
.77557 .21361 L
s
.18514 .36447 m
.1854 .36412 L
s
.18069 .44614 m
.18084 .44565 L
s
.18513 .36442 m
.18539 .36406 L
s
.33134 .35324 m
.33196 .35291 L
s
.68007 .34568 m
.6804 .34601 L
s
.33139 .35321 m
.33201 .35288 L
s
.55681 .35019 m
.55743 .35048 L
s
.55693 .35019 m
.55755 .35048 L
s
.67998 .3456 m
.6803 .34594 L
s
.33159 .35309 m
.33221 .35277 L
s
.55688 .35007 m
.5575 .35037 L
s
.77493 .21328 m
.77525 .21345 L
s
.55652 .35003 m
.55715 .35033 L
s
.1854 .36412 m
.18567 .36376 L
s
.33196 .35291 m
.33258 .35259 L
s
.55618 .3499 m
.55681 .35019 L
s
.55631 .34989 m
.55693 .35019 L
s
.33201 .35288 m
.33263 .35256 L
s
.18539 .36406 m
.18565 .36371 L
s
.18084 .44565 m
.18099 .44515 L
s
.67975 .34534 m
.68007 .34568 L
s
.77461 .21312 m
.77493 .21328 L
s
.33221 .35277 m
.33283 .35244 L
s
.55625 .34978 m
.55688 .35007 L
s
.67966 .34527 m
.67998 .3456 L
s
.5559 .34974 m
.55652 .35003 L
s
.33258 .35259 m
.3332 .35227 L
s
.55556 .3496 m
.55618 .3499 L
s
.55568 .3496 m
.55631 .34989 L
s
.18567 .36376 m
.18593 .36341 L
s
.33263 .35256 m
.33326 .35224 L
s
.18565 .36371 m
.18592 .36336 L
s
.77429 .21295 m
.77461 .21312 L
s
.67942 .345 m
.67975 .34534 L
s
.55563 .34949 m
.55625 .34978 L
s
.33283 .35244 m
.33346 .35212 L
s
.18099 .44515 m
.18115 .44466 L
s
.55527 .34945 m
.5559 .34974 L
s
.67933 .34493 m
.67966 .34527 L
s
.55493 .34931 m
.55556 .3496 L
s
.55505 .34931 m
.55568 .3496 L
s
.3332 .35227 m
.33383 .35195 L
s
.33326 .35224 m
.33388 .35192 L
s
.77396 .21279 m
.77429 .21295 L
s
.18593 .36341 m
.18619 .36306 L
s
.555 .3492 m
.55563 .34949 L
s
.18592 .36336 m
.18618 .363 L
s
.33346 .35212 m
.33408 .35181 L
s
.55464 .34916 m
.55527 .34945 L
s
.67909 .34467 m
.67942 .345 L
s
.18115 .44466 m
.1813 .44417 L
s
.679 .34459 m
.67933 .34493 L
s
.5543 .34902 m
.55493 .34931 L
s
.55442 .34902 m
.55505 .34931 L
s
.77364 .21263 m
.77396 .21279 L
s
.33383 .35195 m
.33446 .35163 L
s
.33388 .35192 m
.33451 .3516 L
s
.18619 .36306 m
.18646 .3627 L
s
.55437 .34891 m
.555 .3492 L
s
.33408 .35181 m
.33471 .35149 L
s
.55401 .34887 m
.55464 .34916 L
s
.18618 .363 m
.18645 .36265 L
s
.67877 .34433 m
.67909 .34467 L
s
.77332 .21246 m
.77364 .21263 L
s
.55367 .34874 m
.5543 .34902 L
s
.55379 .34873 m
.55442 .34902 L
s
.67867 .34426 m
.679 .34459 L
s
.33446 .35163 m
.33509 .35132 L
s
.1813 .44417 m
.18145 .44368 L
s
.33451 .3516 m
.33514 .35129 L
s
.55373 .34862 m
.55437 .34891 L
s
.55338 .34858 m
.55401 .34887 L
s
.33471 .35149 m
.33534 .35117 L
s
.18646 .3627 m
.18673 .36235 L
s
.18645 .36265 m
.18672 .3623 L
s
.77299 .2123 m
.77332 .21246 L
s
.55303 .34845 m
.55367 .34874 L
s
.67843 .344 m
.67877 .34433 L
s
.55315 .34845 m
.55379 .34873 L
s
.33509 .35132 m
.33572 .351 L
s
.33514 .35129 m
.33577 .35097 L
s
.67834 .34392 m
.67867 .34426 L
s
.5531 .34834 m
.55373 .34862 L
s
.18145 .44368 m
.18161 .44318 L
s
.55274 .3483 m
.55338 .34858 L
s
.33534 .35117 m
.33598 .35086 L
s
.77267 .21214 m
.77299 .2123 L
s
.18673 .36235 m
.187 .362 L
s
.55239 .34817 m
.55303 .34845 L
s
.55252 .34817 m
.55315 .34845 L
s
.18672 .3623 m
.18699 .36195 L
s
.33572 .351 m
.33635 .35069 L
s
.6781 .34366 m
.67843 .344 L
s
.33577 .35097 m
.33641 .35066 L
s
.55246 .34805 m
.5531 .34834 L
s
.67801 .34359 m
.67834 .34392 L
s
.5521 .34801 m
.55274 .3483 L
s
.77234 .21197 m
.77267 .21214 L
s
.33598 .35086 m
.33661 .35055 L
s
.18161 .44318 m
.18177 .44269 L
s
.55175 .34789 m
.55239 .34817 L
s
.55188 .34788 m
.55252 .34817 L
s
.187 .362 m
.18727 .36165 L
s
.18699 .36195 m
.18726 .36159 L
s
.33635 .35069 m
.33699 .35038 L
s
.33641 .35066 m
.33704 .35035 L
s
.55182 .34777 m
.55246 .34805 L
s
.67777 .34333 m
.6781 .34366 L
s
.55146 .34773 m
.5521 .34801 L
s
.77201 .21181 m
.77234 .21197 L
s
.33661 .35055 m
.33725 .35024 L
s
.67767 .34326 m
.67801 .34359 L
s
.55111 .3476 m
.55175 .34789 L
s
.55124 .3476 m
.55188 .34788 L
s
.18177 .44269 m
.18193 .4422 L
s
.18727 .36165 m
.18754 .3613 L
s
.33699 .35038 m
.33763 .35007 L
s
.33704 .35035 m
.33768 .35004 L
s
.55118 .34749 m
.55182 .34777 L
s
.18726 .36159 m
.18753 .36124 L
s
.77169 .21165 m
.77201 .21181 L
s
.55082 .34745 m
.55146 .34773 L
s
.67743 .343 m
.67777 .34333 L
s
.33725 .35024 m
.33789 .34993 L
s
.67734 .34292 m
.67767 .34326 L
s
.55047 .34733 m
.55111 .3476 L
s
.55059 .34732 m
.55124 .3476 L
s
.33763 .35007 m
.33827 .34977 L
s
.77136 .21149 m
.77169 .21165 L
s
.55053 .34721 m
.55118 .34749 L
s
.33768 .35004 m
.33833 .34974 L
s
.18754 .3613 m
.18781 .36094 L
s
.55017 .34717 m
.55082 .34745 L
s
.18193 .4422 m
.18209 .4417 L
s
.18753 .36124 m
.1878 .36089 L
s
.33789 .34993 m
.33854 .34963 L
s
.6771 .34266 m
.67743 .343 L
s
.54982 .34705 m
.55047 .34733 L
s
.54995 .34705 m
.55059 .34732 L
s
.677 .34259 m
.67734 .34292 L
s
.77103 .21133 m
.77136 .21149 L
s
.33827 .34977 m
.33892 .34946 L
s
.54989 .34693 m
.55053 .34721 L
s
.33833 .34974 m
.33897 .34943 L
s
.54952 .3469 m
.55017 .34717 L
s
.18781 .36094 m
.18809 .36059 L
s
.33854 .34963 m
.33918 .34932 L
s
.1878 .36089 m
.18808 .36054 L
s
.18209 .4417 m
.18226 .44121 L
s
.54917 .34677 m
.54982 .34705 L
s
.5493 .34677 m
.54995 .34705 L
s
.67676 .34233 m
.6771 .34266 L
s
.7707 .21117 m
.77103 .21133 L
s
.54924 .34666 m
.54989 .34693 L
s
.33892 .34946 m
.33956 .34916 L
s
.67666 .34226 m
.677 .34259 L
s
.33897 .34943 m
.33962 .34913 L
s
.54887 .34662 m
.54952 .3469 L
s
.33918 .34932 m
.33983 .34902 L
s
.18809 .36059 m
.18837 .36024 L
s
.54852 .3465 m
.54917 .34677 L
s
.54865 .3465 m
.5493 .34677 L
s
.18808 .36054 m
.18835 .36019 L
s
.77037 .21101 m
.7707 .21117 L
s
.18226 .44121 m
.18242 .44071 L
s
.54859 .34639 m
.54924 .34666 L
s
.67642 .342 m
.67676 .34233 L
s
.33956 .34916 m
.34021 .34886 L
s
.54822 .34635 m
.54887 .34662 L
s
.33962 .34913 m
.34027 .34883 L
s
.67632 .34192 m
.67666 .34226 L
s
.33983 .34902 m
.34048 .34872 L
s
.54787 .34623 m
.54852 .3465 L
s
.54799 .34622 m
.54865 .3465 L
s
.77004 .21085 m
.77037 .21101 L
s
.18837 .36024 m
.18864 .35989 L
s
.18835 .36019 m
.18863 .35984 L
s
.54793 .34611 m
.54859 .34639 L
s
.34021 .34886 m
.34086 .34856 L
s
.54757 .34608 m
.54822 .34635 L
s
.34027 .34883 m
.34092 .34853 L
s
.67608 .34166 m
.67642 .342 L
s
.18242 .44071 m
.18259 .44022 L
s
.34048 .34872 m
.34113 .34842 L
s
.54721 .34596 m
.54787 .34623 L
s
.54734 .34595 m
.54799 .34622 L
s
.67598 .34159 m
.67632 .34192 L
s
.76971 .21069 m
.77004 .21085 L
s
.54728 .34584 m
.54793 .34611 L
s
.18864 .35989 m
.18892 .35954 L
s
.54691 .34581 m
.54757 .34608 L
s
.34086 .34856 m
.34152 .34826 L
s
.34092 .34853 m
.34157 .34823 L
s
.18863 .35984 m
.18891 .35949 L
s
.54655 .34569 m
.54721 .34596 L
s
.67573 .34133 m
.67608 .34166 L
s
.34113 .34842 m
.34179 .34813 L
s
.54668 .34568 m
.54734 .34595 L
s
.76938 .21053 m
.76971 .21069 L
s
.18259 .44022 m
.18276 .43973 L
s
.67564 .34126 m
.67598 .34159 L
s
.54662 .34558 m
.54728 .34584 L
s
.54625 .34554 m
.54691 .34581 L
s
.34152 .34826 m
.34217 .34796 L
s
.34157 .34823 m
.34223 .34794 L
s
.18892 .35954 m
.1892 .35919 L
s
.18891 .35949 m
.18919 .35914 L
s
.54589 .34542 m
.54655 .34569 L
s
.76904 .21037 m
.76938 .21053 L
s
.54602 .34542 m
.54668 .34568 L
s
.34179 .34813 m
.34245 .34783 L
s
.67539 .341 m
.67573 .34133 L
s
.54596 .34531 m
.54662 .34558 L
s
.54559 .34527 m
.54625 .34554 L
s
.18276 .43973 m
.18293 .43923 L
s
.67529 .34093 m
.67564 .34126 L
s
.34217 .34796 m
.34283 .34767 L
s
.34223 .34794 m
.34289 .34765 L
s
.76871 .21021 m
.76904 .21037 L
s
.54523 .34515 m
.54589 .34542 L
s
.1892 .35919 m
.18949 .35884 L
s
.54536 .34515 m
.54602 .34542 L
s
.34245 .34783 m
.34311 .34754 L
s
.18919 .35914 m
.18947 .35879 L
s
.5453 .34504 m
.54596 .34531 L
s
.54493 .34501 m
.54559 .34527 L
s
.67505 .34067 m
.67539 .341 L
s
.34283 .34767 m
.34349 .34738 L
s
.34289 .34765 m
.34355 .34736 L
s
.67495 .3406 m
.67529 .34093 L
s
.76838 .21006 m
.76871 .21021 L
s
.54457 .34489 m
.54523 .34515 L
s
.18293 .43923 m
.1831 .43874 L
s
.5447 .34489 m
.54536 .34515 L
s
.34311 .34754 m
.34377 .34725 L
s
.18949 .35884 m
.18977 .35849 L
s
.54464 .34478 m
.5453 .34504 L
s
.18947 .35879 m
.18976 .35844 L
s
.54426 .34475 m
.54493 .34501 L
s
.34349 .34738 m
.34415 .34709 L
s
.34355 .34736 m
.34421 .34707 L
s
.6747 .34034 m
.67505 .34067 L
s
.76804 .2099 m
.76838 .21006 L
s
.5439 .34463 m
.54457 .34489 L
s
.54403 .34462 m
.5447 .34489 L
s
.34377 .34725 m
.34443 .34696 L
s
.6746 .34027 m
.67495 .3406 L
s
.54397 .34452 m
.54464 .34478 L
s
.1831 .43874 m
.18327 .43824 L
s
.5436 .34448 m
.54426 .34475 L
s
.18977 .35849 m
.19006 .35815 L
s
.34415 .34709 m
.34482 .3468 L
s
.18976 .35844 m
.19004 .35809 L
s
.34421 .34707 m
.34488 .34678 L
s
.76771 .20974 m
.76804 .2099 L
s
.54323 .34437 m
.5439 .34463 L
s
.54337 .34436 m
.54403 .34462 L
s
.67435 .34001 m
.6747 .34034 L
s
.34443 .34696 m
.3451 .34667 L
s
.5433 .34426 m
.54397 .34452 L
s
.67425 .33994 m
.6746 .34027 L
s
.54293 .34422 m
.5436 .34448 L
s
.34482 .3468 m
.34549 .34651 L
s
.76737 .20958 m
.76771 .20974 L
s
.19006 .35815 m
.19034 .3578 L
s
.34488 .34678 m
.34555 .34649 L
s
.18327 .43824 m
.18345 .43775 L
s
.54256 .34411 m
.54323 .34437 L
s
.5427 .34411 m
.54337 .34436 L
s
.19004 .35809 m
.19033 .35774 L
s
.3451 .34667 m
.34577 .34639 L
s
.54263 .344 m
.5433 .34426 L
s
.674 .33968 m
.67435 .34001 L
s
.54226 .34397 m
.54293 .34422 L
s
.6739 .33961 m
.67425 .33994 L
s
.34549 .34651 m
.34616 .34623 L
s
.76703 .20943 m
.76737 .20958 L
s
.34555 .34649 m
.34622 .34621 L
s
.54189 .34385 m
.54256 .34411 L
s
.54202 .34385 m
.5427 .34411 L
s
.19034 .3578 m
.19063 .35745 L
s
.34577 .34639 m
.34644 .34611 L
s
.18345 .43775 m
.18362 .43725 L
s
.19033 .35774 m
.19062 .3574 L
s
.54196 .34374 m
.54263 .344 L
s
.54158 .34371 m
.54226 .34397 L
s
.7667 .20927 m
.76703 .20943 L
s
.67365 .33935 m
.674 .33968 L
s
.34616 .34623 m
.34683 .34595 L
s
.34622 .34621 m
.34689 .34593 L
s
.54122 .3436 m
.54189 .34385 L
s
.54135 .34359 m
.54202 .34385 L
s
.67355 .33928 m
.6739 .33961 L
s
.34644 .34611 m
.34711 .34582 L
s
.54129 .34349 m
.54196 .34374 L
s
.19063 .35745 m
.19092 .3571 L
s
.54091 .34346 m
.54158 .34371 L
s
.19062 .3574 m
.19091 .35705 L
s
.76636 .20911 m
.7667 .20927 L
s
.18362 .43725 m
.1838 .43676 L
s
.34683 .34595 m
.3475 .34567 L
s
.54054 .34334 m
.54122 .3436 L
s
.34689 .34593 m
.34756 .34565 L
s
.54068 .34334 m
.54135 .34359 L
s
.6733 .33902 m
.67365 .33935 L
s
.34711 .34582 m
.34779 .34555 L
s
.54061 .34324 m
.54129 .34349 L
s
.67319 .33895 m
.67355 .33928 L
s
.54023 .3432 m
.54091 .34346 L
s
.19092 .3571 m
.19121 .35675 L
s
.76602 .20896 m
.76636 .20911 L
s
.53986 .34309 m
.54054 .34334 L
s
.3475 .34567 m
.34818 .34539 L
s
.54 .34309 m
.54068 .34334 L
s
.34756 .34565 m
.34824 .34537 L
s
.19091 .35705 m
.1912 .3567 L
s
.1838 .43676 m
.18398 .43626 L
s
.34779 .34555 m
.34846 .34527 L
s
.53993 .34299 m
.54061 .34324 L
s
.53955 .34295 m
.54023 .3432 L
s
.67294 .3387 m
.6733 .33902 L
s
.67284 .33862 m
.67319 .33895 L
s
.76568 .2088 m
.76602 .20896 L
s
.53918 .34284 m
.53986 .34309 L
s
.53932 .34284 m
.54 .34309 L
s
.34818 .34539 m
.34886 .34511 L
s
.34824 .34537 m
.34892 .34509 L
s
.19121 .35675 m
.1915 .35641 L
s
.1912 .3567 m
.19149 .35635 L
s
.53925 .34274 m
.53993 .34299 L
s
.34846 .34527 m
.34914 .34499 L
s
.53887 .3427 m
.53955 .34295 L
s
.18398 .43626 m
.18416 .43576 L
s
.76534 .20865 m
.76568 .2088 L
s
.67259 .33837 m
.67294 .3387 L
s
.5385 .34259 m
.53918 .34284 L
s
.53864 .34259 m
.53932 .34284 L
s
.34886 .34511 m
.34954 .34484 L
s
.34892 .34509 m
.3496 .34482 L
s
.67249 .3383 m
.67284 .33862 L
s
.53857 .34249 m
.53925 .34274 L
s
.34914 .34499 m
.34982 .34472 L
s
.1915 .35641 m
.1918 .35606 L
s
.53819 .34246 m
.53887 .3427 L
s
.19149 .35635 m
.19179 .35601 L
s
.765 .2085 m
.76534 .20865 L
s
.53782 .34235 m
.5385 .34259 L
s
.53795 .34234 m
.53864 .34259 L
s
.34954 .34484 m
.35022 .34457 L
s
.3496 .34482 m
.35028 .34455 L
s
.67223 .33804 m
.67259 .33837 L
s
.18416 .43576 m
.18434 .43527 L
s
.53789 .34224 m
.53857 .34249 L
s
.34982 .34472 m
.35051 .34445 L
s
.5375 .34221 m
.53819 .34246 L
s
.67213 .33797 m
.67249 .3383 L
s
.1918 .35606 m
.19209 .35571 L
s
.76466 .20834 m
.765 .2085 L
s
.53713 .3421 m
.53782 .34235 L
s
.53727 .3421 m
.53795 .34234 L
s
.19179 .35601 m
.19208 .35566 L
s
.35022 .34457 m
.35091 .34429 L
s
.35028 .34455 m
.35097 .34428 L
s
.5372 .342 m
.53789 .34224 L
s
.53682 .34197 m
.5375 .34221 L
s
.35051 .34445 m
.35119 .34418 L
s
.67187 .33771 m
.67223 .33804 L
s
.18434 .43527 m
.18452 .43477 L
s
.53645 .34186 m
.53713 .3421 L
s
.76432 .20819 m
.76466 .20834 L
s
.67177 .33764 m
.67213 .33797 L
s
.53658 .34186 m
.53727 .3421 L
s
.35091 .34429 m
.35159 .34403 L
s
.35097 .34428 m
.35166 .34401 L
s
.19209 .35571 m
.19239 .35537 L
s
.53651 .34176 m
.5372 .342 L
s
.19208 .35566 m
.19238 .35532 L
s
.53613 .34173 m
.53682 .34197 L
s
.35119 .34418 m
.35188 .34391 L
s
.53576 .34162 m
.53645 .34186 L
s
.53589 .34162 m
.53658 .34186 L
s
.76398 .20803 m
.76432 .20819 L
s
.67151 .33739 m
.67187 .33771 L
s
.35159 .34403 m
.35228 .34376 L
s
.35166 .34401 m
.35234 .34374 L
s
.67141 .33732 m
.67177 .33764 L
s
.53582 .34152 m
.53651 .34176 L
s
.18452 .43477 m
.18471 .43427 L
s
.53544 .34149 m
.53613 .34173 L
s
.19239 .35537 m
.19269 .35502 L
s
.35188 .34391 m
.35257 .34365 L
s
.53506 .34138 m
.53576 .34162 L
s
.5352 .34138 m
.53589 .34162 L
s
.76363 .20788 m
.76398 .20803 L
s
.35228 .34376 m
.35297 .34349 L
s
.35234 .34374 m
.35304 .34348 L
s
.53513 .34128 m
.53582 .34152 L
s
.67115 .33706 m
.67151 .33739 L
s
.53474 .34125 m
.53544 .34149 L
s
.35257 .34365 m
.35326 .34338 L
s
.67105 .33699 m
.67141 .33732 L
s
.53437 .34114 m
.53506 .34138 L
s
.53451 .34114 m
.5352 .34138 L
s
.19269 .35502 m
.19299 .35468 L
s
.18471 .43427 m
.1849 .43378 L
s
.76329 .20773 m
.76363 .20788 L
s
.35297 .34349 m
.35366 .34323 L
s
.35304 .34348 m
.35373 .34322 L
s
.53444 .34104 m
.53513 .34128 L
s
.53405 .34101 m
.53474 .34125 L
s
.35326 .34338 m
.35396 .34312 L
s
.67079 .33674 m
.67115 .33706 L
s
.53367 .34091 m
.53437 .34114 L
s
.53381 .3409 m
.53451 .34114 L
s
.76294 .20758 m
.76329 .20773 L
s
.67069 .33667 m
.67105 .33699 L
s
.35366 .34323 m
.35436 .34297 L
s
.35373 .34322 m
.35442 .34296 L
s
.53374 .34081 m
.53444 .34104 L
s
.19299 .35468 m
.19329 .35433 L
s
.53335 .34078 m
.53405 .34101 L
s
.1849 .43378 m
.18508 .43328 L
s
.35396 .34312 m
.35465 .34286 L
s
.53298 .34068 m
.53367 .34091 L
s
.53311 .34067 m
.53381 .3409 L
s
.7626 .20743 m
.76294 .20758 L
s
.67043 .33641 m
.67079 .33674 L
s
.35436 .34297 m
.35506 .34271 L
s
.35442 .34296 m
.35512 .3427 L
s
.53304 .34057 m
.53374 .34081 L
s
.53266 .34054 m
.53335 .34078 L
s
.67032 .33634 m
.67069 .33667 L
s
.35465 .34286 m
.35535 .3426 L
s
.19329 .35433 m
.19359 .35399 L
s
.53228 .34044 m
.53298 .34068 L
s
.53242 .34044 m
.53311 .34067 L
s
.18508 .43328 m
.18527 .43278 L
s
.35506 .34271 m
.35576 .34246 L
s
.76225 .20727 m
.7626 .20743 L
s
.53234 .34034 m
.53304 .34057 L
s
.35512 .3427 m
.35582 .34244 L
s
.53196 .34031 m
.53266 .34054 L
s
.67006 .33609 m
.67043 .33641 L
s
.35535 .3426 m
.35605 .34235 L
s
.53158 .34021 m
.53228 .34044 L
s
.53171 .34021 m
.53242 .34044 L
s
.66996 .33602 m
.67032 .33634 L
s
.19359 .35399 m
.1939 .35364 L
s
.53164 .34011 m
.53234 .34034 L
s
.35576 .34246 m
.35646 .3422 L
s
.35582 .34244 m
.35652 .34219 L
s
.76191 .20712 m
.76225 .20727 L
s
.53125 .34008 m
.53196 .34031 L
s
.18527 .43278 m
.18547 .43229 L
s
.35605 .34235 m
.35676 .34209 L
s
.53087 .33999 m
.53158 .34021 L
s
.53101 .33998 m
.53171 .34021 L
s
.66969 .33576 m
.67006 .33609 L
s
.53094 .33988 m
.53164 .34011 L
s
.35646 .3422 m
.35716 .34195 L
s
.35652 .34219 m
.35723 .34193 L
s
.53055 .33986 m
.53125 .34008 L
s
.66959 .33569 m
.66996 .33602 L
s
.76156 .20697 m
.76191 .20712 L
s
.1939 .35364 m
.1942 .3533 L
s
.35676 .34209 m
.35746 .34184 L
s
.53017 .33976 m
.53087 .33999 L
s
.53031 .33975 m
.53101 .33998 L
s
.53024 .33966 m
.53094 .33988 L
s
.18547 .43229 m
.18566 .43179 L
s
.35716 .34195 m
.35786 .3417 L
s
.52984 .33963 m
.53055 .33986 L
s
.35723 .34193 m
.35793 .34168 L
s
.76121 .20682 m
.76156 .20697 L
s
.66933 .33544 m
.66969 .33576 L
s
.35746 .34184 m
.35817 .34159 L
s
.52946 .33954 m
.53017 .33976 L
s
.5296 .33953 m
.53031 .33975 L
s
.66922 .33537 m
.66959 .33569 L
s
.1942 .3533 m
.19451 .35295 L
s
.52953 .33943 m
.53024 .33966 L
s
.52914 .33941 m
.52984 .33963 L
s
.35786 .3417 m
.35857 .34145 L
s
.35793 .34168 m
.35864 .34143 L
s
.76086 .20667 m
.76121 .20682 L
s
.52875 .33931 m
.52946 .33954 L
s
.35817 .34159 m
.35887 .34134 L
s
.52889 .33931 m
.5296 .33953 L
s
.18566 .43179 m
.18585 .43129 L
s
.66896 .33512 m
.66933 .33544 L
s
.52882 .33921 m
.52953 .33943 L
s
.52843 .33919 m
.52914 .33941 L
s
.35857 .34145 m
.35928 .3412 L
s
.66885 .33505 m
.66922 .33537 L
s
.35864 .34143 m
.35935 .34119 L
s
.19451 .35295 m
.19482 .35261 L
s
.52804 .33909 m
.52875 .33931 L
s
.76051 .20652 m
.76086 .20667 L
s
.35887 .34134 m
.35958 .3411 L
s
.52818 .33908 m
.52889 .33931 L
s
.52811 .33899 m
.52882 .33921 L
s
.52772 .33897 m
.52843 .33919 L
s
.35928 .3412 m
.35999 .34096 L
s
.35935 .34119 m
.36006 .34094 L
s
.66859 .33479 m
.66896 .33512 L
s
.18585 .43129 m
.18605 .4308 L
s
.52733 .33887 m
.52804 .33909 L
s
.52747 .33887 m
.52818 .33908 L
s
.35958 .3411 m
.36029 .34085 L
s
.66848 .33473 m
.66885 .33505 L
s
.76016 .20637 m
.76051 .20652 L
s
.19482 .35261 m
.19513 .35227 L
s
.5274 .33877 m
.52811 .33899 L
s
.527 .33875 m
.52772 .33897 L
s
.35999 .34096 m
.3607 .34071 L
s
.36006 .34094 m
.36077 .3407 L
s
.52662 .33866 m
.52733 .33887 L
s
.52676 .33865 m
.52747 .33887 L
s
.36029 .34085 m
.36101 .34061 L
s
.75981 .20623 m
.76016 .20637 L
s
.66821 .33447 m
.66859 .33479 L
s
.52668 .33856 m
.5274 .33877 L
s
.18605 .4308 m
.18625 .4303 L
s
.52629 .33853 m
.527 .33875 L
s
.66811 .3344 m
.66848 .33473 L
s
.3607 .34071 m
.36142 .34047 L
s
.19513 .35227 m
.19544 .35193 L
s
.36077 .3407 m
.36149 .34046 L
s
.5259 .33844 m
.52662 .33866 L
s
.52604 .33843 m
.52676 .33865 L
s
.36101 .34061 m
.36172 .34037 L
s
.52597 .33834 m
.52668 .33856 L
s
.75946 .20608 m
.75981 .20623 L
s
.52557 .33832 m
.52629 .33853 L
s
.36142 .34047 m
.36213 .34023 L
s
.36149 .34046 m
.3622 .34022 L
s
.66784 .33415 m
.66821 .33447 L
s
.52519 .33823 m
.5259 .33844 L
s
.52533 .33822 m
.52604 .33843 L
s
.36172 .34037 m
.36244 .34014 L
s
.66773 .33408 m
.66811 .3344 L
s
.18625 .4303 m
.18645 .4298 L
s
.19544 .35193 m
.19575 .35158 L
s
.52525 .33813 m
.52597 .33834 L
s
.52485 .33811 m
.52557 .33832 L
s
.75911 .20593 m
.75946 .20608 L
s
.36213 .34023 m
.36285 .34 L
s
.3622 .34022 m
.36292 .33999 L
s
.52447 .33802 m
.52519 .33823 L
s
.52461 .33801 m
.52533 .33822 L
s
.36244 .34014 m
.36316 .3399 L
s
.66747 .33383 m
.66784 .33415 L
s
.52453 .33792 m
.52525 .33813 L
s
.52414 .3379 m
.52485 .33811 L
s
.66736 .33376 m
.66773 .33408 L
s
.19575 .35158 m
.19607 .35124 L
s
.36285 .34 m
.36357 .33976 L
s
.75876 .20578 m
.75911 .20593 L
s
.36292 .33999 m
.36364 .33975 L
s
.52375 .33781 m
.52447 .33802 L
s
.18645 .4298 m
.18665 .4293 L
s
.52389 .3378 m
.52461 .33801 L
s
.36316 .3399 m
.36388 .33967 L
s
.52381 .33771 m
.52453 .33792 L
s
.52341 .33769 m
.52414 .3379 L
s
.36357 .33976 m
.36429 .33953 L
s
.36364 .33975 m
.36436 .33952 L
s
.52302 .3376 m
.52375 .33781 L
s
.66709 .33351 m
.66747 .33383 L
s
.52317 .33759 m
.52389 .3378 L
s
.7584 .20564 m
.75876 .20578 L
s
.36388 .33967 m
.3646 .33944 L
s
.66698 .33344 m
.66736 .33376 L
s
.19607 .35124 m
.19638 .3509 L
s
.52309 .3375 m
.52381 .33771 L
s
.52269 .33748 m
.52341 .33769 L
s
.18665 .4293 m
.18685 .4288 L
s
.36429 .33953 m
.36502 .3393 L
s
.36436 .33952 m
.36509 .33929 L
s
.5223 .33739 m
.52302 .3376 L
s
.52244 .33739 m
.52317 .33759 L
s
.75805 .20549 m
.7584 .20564 L
s
.3646 .33944 m
.36533 .33921 L
s
.52237 .3373 m
.52309 .3375 L
s
.52197 .33728 m
.52269 .33748 L
s
.66671 .33319 m
.66709 .33351 L
s
.36502 .3393 m
.36574 .33907 L
s
.36509 .33929 m
.36581 .33906 L
s
.19638 .3509 m
.1967 .35056 L
s
.52158 .33719 m
.5223 .33739 L
s
.6666 .33312 m
.66698 .33344 L
s
.52172 .33718 m
.52244 .33739 L
s
.36533 .33921 m
.36605 .33898 L
s
.7577 .20534 m
.75805 .20549 L
s
.52164 .33709 m
.52237 .3373 L
s
.18685 .4288 m
.18705 .42831 L
s
.52124 .33707 m
.52197 .33728 L
s
.36574 .33907 m
.36647 .33884 L
s
.52085 .33699 m
.52158 .33719 L
s
.36581 .33906 m
.36654 .33884 L
s
.52099 .33698 m
.52172 .33718 L
s
.66633 .33287 m
.66671 .33319 L
s
.36605 .33898 m
.36678 .33875 L
s
.52091 .33689 m
.52164 .33709 L
s
.1967 .35056 m
.19702 .35022 L
s
.52051 .33687 m
.52124 .33707 L
s
.66622 .3328 m
.6666 .33312 L
s
.75734 .2052 m
.7577 .20534 L
s
.52012 .33679 m
.52085 .33699 L
s
.36647 .33884 m
.3672 .33862 L
s
.36654 .33884 m
.36727 .33861 L
s
.52026 .33678 m
.52099 .33698 L
s
.18705 .42831 m
.18726 .42781 L
s
.36678 .33875 m
.36751 .33853 L
s
.52019 .33669 m
.52091 .33689 L
s
.51978 .33667 m
.52051 .33687 L
s
.66595 .33255 m
.66633 .33287 L
s
.75698 .20505 m
.75734 .2052 L
s
.51939 .33659 m
.52012 .33679 L
s
.3672 .33862 m
.36793 .3384 L
s
.51953 .33658 m
.52026 .33678 L
s
.36727 .33861 m
.368 .33839 L
s
.19702 .35022 m
.19734 .34988 L
s
.66584 .33248 m
.66622 .3328 L
s
.36751 .33853 m
.36824 .33831 L
s
.51945 .3365 m
.52019 .33669 L
s
.51905 .33648 m
.51978 .33667 L
s
.51866 .3364 m
.51939 .33659 L
s
.5188 .33639 m
.51953 .33658 L
s
.36793 .3384 m
.36866 .33818 L
s
.368 .33839 m
.36873 .33817 L
s
.75663 .20491 m
.75698 .20505 L
s
.18726 .42781 m
.18747 .42731 L
s
.36824 .33831 m
.36898 .33809 L
s
.51872 .3363 m
.51945 .3365 L
s
.66557 .33223 m
.66595 .33255 L
s
.51832 .33628 m
.51905 .33648 L
s
.19734 .34988 m
.19766 .34954 L
s
.66546 .33217 m
.66584 .33248 L
s
.51792 .3362 m
.51866 .3364 L
s
.51807 .33619 m
.5188 .33639 L
s
.36866 .33818 m
.36939 .33796 L
s
.36873 .33817 m
.36947 .33795 L
s
.36898 .33809 m
.36971 .33787 L
s
.51799 .33611 m
.51872 .3363 L
s
.75627 .20476 m
.75663 .20491 L
s
.51758 .33609 m
.51832 .33628 L
s
.51719 .33601 m
.51792 .3362 L
s
.51733 .336 m
.51807 .33619 L
s
.18747 .42731 m
.18767 .42681 L
s
.36939 .33796 m
.37013 .33774 L
s
.36947 .33795 m
.3702 .33774 L
s
.66519 .33192 m
.66557 .33223 L
s
.51725 .33591 m
.51799 .33611 L
s
.36971 .33787 m
.37045 .33766 L
s
.19766 .34954 m
.19798 .3492 L
s
.51685 .3359 m
.51758 .33609 L
s
.66508 .33185 m
.66546 .33217 L
s
.75591 .20462 m
.75627 .20476 L
s
.51645 .33582 m
.51719 .33601 L
s
.5166 .33581 m
.51733 .336 L
s
.3702 .33774 m
.37094 .33752 L
s
.37013 .33774 m
.37087 .33753 L
s
.51652 .33572 m
.51725 .33591 L
s
.37045 .33766 m
.37119 .33745 L
s
.51611 .33571 m
.51685 .3359 L
s
.51571 .33563 m
.51645 .33582 L
s
.6648 .3316 m
.66519 .33192 L
s
.18767 .42681 m
.18788 .42631 L
s
.51586 .33562 m
.5166 .33581 L
s
.75555 .20447 m
.75591 .20462 L
s
.37094 .33752 m
.37168 .33731 L
s
.37087 .33753 m
.37161 .33732 L
s
.19798 .3492 m
.1983 .34886 L
s
.66469 .33153 m
.66508 .33185 L
s
.51578 .33554 m
.51652 .33572 L
s
.51537 .33552 m
.51611 .33571 L
s
.37119 .33745 m
.37193 .33723 L
s
.51497 .33544 m
.51571 .33563 L
s
.51512 .33544 m
.51586 .33562 L
s
.37168 .33731 m
.37242 .3371 L
s
.37161 .33732 m
.37235 .33711 L
s
.7552 .20433 m
.75555 .20447 L
s
.51504 .33535 m
.51578 .33554 L
s
.51463 .33533 m
.51537 .33552 L
s
.37193 .33723 m
.37267 .33703 L
s
.66442 .33128 m
.6648 .3316 L
s
.1983 .34886 m
.19863 .34852 L
s
.51423 .33526 m
.51497 .33544 L
s
.18788 .42631 m
.18809 .42581 L
s
.51438 .33525 m
.51512 .33544 L
s
.6643 .33121 m
.66469 .33153 L
s
.37242 .3371 m
.37316 .3369 L
s
.37235 .33711 m
.37309 .3369 L
s
.5143 .33517 m
.51504 .33535 L
s
.51389 .33515 m
.51463 .33533 L
s
.37267 .33703 m
.37341 .33682 L
s
.75484 .20419 m
.7552 .20433 L
s
.51349 .33508 m
.51423 .33526 L
s
.51363 .33507 m
.51438 .33525 L
s
.37316 .3369 m
.37391 .33669 L
s
.37309 .3369 m
.37383 .33669 L
s
.66403 .33096 m
.66442 .33128 L
s
.51356 .33499 m
.5143 .33517 L
s
.51314 .33497 m
.51389 .33515 L
s
.37341 .33682 m
.37415 .33662 L
s
.19863 .34852 m
.19896 .34818 L
s
.66392 .3309 m
.6643 .33121 L
s
.51274 .3349 m
.51349 .33508 L
s
.18809 .42581 m
.18831 .42531 L
s
.51289 .33489 m
.51363 .33507 L
s
.75447 .20404 m
.75484 .20419 L
s
.37391 .33669 m
.37465 .33649 L
s
.37383 .33669 m
.37458 .33649 L
s
.51281 .33481 m
.51356 .33499 L
s
.5124 .33479 m
.51314 .33497 L
s
.37415 .33662 m
.3749 .33641 L
s
.512 .33472 m
.51274 .3349 L
s
.51215 .33471 m
.51289 .33489 L
s
.66364 .33065 m
.66403 .33096 L
s
.37465 .33649 m
.3754 .33629 L
s
.37458 .33649 m
.37532 .33629 L
s
.19896 .34818 m
.19929 .34784 L
s
.51207 .33463 m
.51281 .33481 L
s
.75411 .2039 m
.75447 .20404 L
s
.51165 .33461 m
.5124 .33479 L
s
.66353 .33058 m
.66392 .3309 L
s
.3749 .33641 m
.37565 .33621 L
s
.51125 .33454 m
.512 .33472 L
s
.18831 .42531 m
.18852 .42482 L
s
.5114 .33453 m
.51215 .33471 L
s
.3754 .33629 m
.37615 .33609 L
s
.37532 .33629 m
.37607 .33609 L
s
.51132 .33445 m
.51207 .33463 L
s
.5109 .33444 m
.51165 .33461 L
s
.37565 .33621 m
.3764 .33601 L
s
.75375 .20376 m
.75411 .2039 L
s
.5105 .33437 m
.51125 .33454 L
s
.51065 .33436 m
.5114 .33453 L
s
.66325 .33033 m
.66364 .33065 L
s
.19929 .34784 m
.19962 .3475 L
s
.37615 .33609 m
.3769 .33589 L
s
.37607 .33609 m
.37682 .33589 L
s
.51057 .33428 m
.51132 .33445 L
s
.66314 .33027 m
.66353 .33058 L
s
.51016 .33426 m
.5109 .33444 L
s
.3764 .33601 m
.37715 .33582 L
s
.50975 .3342 m
.5105 .33437 L
s
.5099 .33419 m
.51065 .33436 L
s
.18852 .42482 m
.18874 .42432 L
s
.75339 .20362 m
.75375 .20376 L
s
.3769 .33589 m
.37765 .3357 L
s
.37682 .33589 m
.37757 .3357 L
s
.50982 .33411 m
.51057 .33428 L
s
.5094 .33409 m
.51016 .33426 L
s
.37715 .33582 m
.3779 .33563 L
s
.66286 .33002 m
.66325 .33033 L
s
.50915 .33402 m
.5099 .33419 L
s
.19962 .3475 m
.19995 .34717 L
s
.66274 .32995 m
.66314 .33027 L
s
.37765 .3357 m
.3784 .33551 L
s
.37757 .3357 m
.37833 .33551 L
s
.50907 .33394 m
.50982 .33411 L
s
.50865 .33392 m
.5094 .33409 L
s
.75303 .20348 m
.75339 .20362 L
s
.3779 .33563 m
.37865 .33543 L
s
.5084 .33385 m
.50915 .33402 L
s
.18874 .42432 m
.18896 .42382 L
s
.3784 .33551 m
.37915 .33532 L
s
.37833 .33551 m
.37908 .33531 L
s
.50831 .33377 m
.50907 .33394 L
s
.5079 .33376 m
.50865 .33392 L
s
.37865 .33543 m
.37941 .33524 L
s
.66246 .3297 m
.66286 .33002 L
s
.19995 .34717 m
.20028 .34683 L
s
.50764 .33368 m
.5084 .33385 L
s
.75266 .20333 m
.75303 .20348 L
s
.66235 .32964 m
.66274 .32995 L
s
.37915 .33532 m
.37991 .33513 L
s
.50756 .3336 m
.50831 .33377 L
s
.37908 .33531 m
.37983 .33513 L
s
.50714 .33359 m
.5079 .33376 L
s
.37941 .33524 m
.38016 .33506 L
s
.50689 .33352 m
.50764 .33368 L
s
.18896 .42382 m
.18918 .42332 L
s
.5068 .33344 m
.50756 .3336 L
s
.37991 .33513 m
.38067 .33494 L
s
.37983 .33513 m
.38059 .33494 L
s
.50639 .33343 m
.50714 .33359 L
s
.7523 .20319 m
.75266 .20333 L
s
.66207 .32939 m
.66246 .3297 L
s
.38016 .33506 m
.38092 .33487 L
s
.20028 .34683 m
.20061 .34649 L
s
.50613 .33335 m
.50689 .33352 L
s
.66196 .32932 m
.66235 .32964 L
s
.50605 .33328 m
.5068 .33344 L
s
.38067 .33494 m
.38143 .33476 L
s
.50563 .33327 m
.50639 .33343 L
s
.38059 .33494 m
.38135 .33476 L
s
.38092 .33487 m
.38168 .33469 L
s
.50537 .33319 m
.50613 .33335 L
s
.75193 .20305 m
.7523 .20319 L
s
.18918 .42332 m
.1894 .42282 L
s
.50529 .33312 m
.50605 .33328 L
s
.38143 .33476 m
.38219 .33458 L
s
.50487 .33311 m
.50563 .33327 L
s
.38135 .33476 m
.38211 .33457 L
s
.66167 .32908 m
.66207 .32939 L
s
.20061 .34649 m
.20095 .34616 L
s
.38168 .33469 m
.38244 .33451 L
s
.50461 .33304 m
.50537 .33319 L
s
.66156 .32901 m
.66196 .32932 L
s
.50453 .33296 m
.50529 .33312 L
s
.50411 .33295 m
.50487 .33311 L
s
.38219 .33458 m
.38295 .3344 L
s
.38211 .33457 m
.38287 .33439 L
s
.75157 .20291 m
.75193 .20305 L
s
.38244 .33451 m
.3832 .33433 L
s
.50385 .33288 m
.50461 .33304 L
s
.50377 .3328 m
.50453 .33296 L
s
.50335 .33279 m
.50411 .33295 L
s
.38295 .3344 m
.38371 .33422 L
s
.38287 .33439 m
.38363 .33422 L
s
.1894 .42282 m
.18962 .42232 L
s
.66128 .32876 m
.66167 .32908 L
s
.20095 .34616 m
.20129 .34582 L
s
.3832 .33433 m
.38397 .33415 L
s
.50309 .33273 m
.50385 .33288 L
s
.66116 .3287 m
.66156 .32901 L
s
.7512 .20277 m
.75157 .20291 L
s
.50301 .33265 m
.50377 .3328 L
s
.50259 .33264 m
.50335 .33279 L
s
.38371 .33422 m
.38447 .33404 L
s
.38363 .33422 m
.3844 .33404 L
s
.38397 .33415 m
.38473 .33398 L
s
.50233 .33257 m
.50309 .33273 L
s
.50224 .3325 m
.50301 .33265 L
s
.50182 .33249 m
.50259 .33264 L
s
.38447 .33404 m
.38524 .33387 L
s
.3844 .33404 m
.38516 .33387 L
s
.75083 .20264 m
.7512 .20277 L
s
.66088 .32845 m
.66128 .32876 L
s
.20129 .34582 m
.20163 .34549 L
s
.50156 .33242 m
.50233 .33257 L
s
.38473 .33398 m
.3855 .33381 L
s
.18962 .42232 m
.18984 .42182 L
s
.66076 .32839 m
.66116 .3287 L
s
.50148 .33235 m
.50224 .3325 L
s
.50106 .33234 m
.50182 .33249 L
s
.38524 .33387 m
.38601 .3337 L
s
.38516 .33387 m
.38593 .3337 L
s
.5008 .33227 m
.50156 .33242 L
s
.3855 .33381 m
.38626 .33364 L
s
.50071 .3322 m
.50148 .33235 L
s
.75047 .2025 m
.75083 .20264 L
s
.50029 .33219 m
.50106 .33234 L
s
.38601 .3337 m
.38677 .33353 L
s
.38593 .3337 m
.3867 .33353 L
s
.50003 .33213 m
.5008 .33227 L
s
.66048 .32814 m
.66088 .32845 L
s
.20163 .34549 m
.20197 .34515 L
s
.38626 .33364 m
.38703 .33347 L
s
.18984 .42182 m
.19007 .42132 L
s
.49995 .33205 m
.50071 .3322 L
s
.66036 .32807 m
.66076 .32839 L
s
.49952 .33205 m
.50029 .33219 L
s
.38677 .33353 m
.38754 .33337 L
s
.3867 .33353 m
.38746 .33336 L
s
.49926 .33198 m
.50003 .33213 L
s
.38703 .33347 m
.3878 .3333 L
s
.7501 .20236 m
.75047 .2025 L
s
.49918 .33191 m
.49995 .33205 L
s
.49875 .33191 m
.49952 .33205 L
s
.38754 .33337 m
.38831 .3332 L
s
.38746 .33336 m
.38823 .33319 L
s
.49849 .33184 m
.49926 .33198 L
s
.3878 .3333 m
.38857 .33314 L
s
.20197 .34515 m
.20231 .34482 L
s
.66008 .32783 m
.66048 .32814 L
s
.49841 .33177 m
.49918 .33191 L
s
.49798 .33176 m
.49875 .33191 L
s
.65996 .32776 m
.66036 .32807 L
s
.38831 .3332 m
.38908 .33304 L
s
.38823 .33319 m
.38901 .33303 L
s
.74973 .20222 m
.7501 .20236 L
s
.19007 .42132 m
.19029 .42082 L
s
.49772 .3317 m
.49849 .33184 L
s
.38857 .33314 m
.38934 .33298 L
s
.49764 .33163 m
.49841 .33177 L
s
.49721 .33163 m
.49798 .33176 L
s
.38908 .33304 m
.38986 .33288 L
s
.38901 .33303 m
.38978 .33287 L
s
.49695 .33156 m
.49772 .3317 L
s
.38934 .33298 m
.39012 .33282 L
s
.20231 .34482 m
.20265 .34448 L
s
.65968 .32752 m
.66008 .32783 L
s
.49686 .33149 m
.49764 .33163 L
s
.49644 .33149 m
.49721 .33163 L
s
.74936 .20208 m
.74973 .20222 L
s
.38986 .33288 m
.39063 .33272 L
s
.38978 .33287 m
.39055 .33271 L
s
.49618 .33143 m
.49695 .33156 L
s
.65956 .32745 m
.65996 .32776 L
s
.39012 .33282 m
.39089 .33266 L
s
.19029 .42082 m
.19052 .42032 L
s
.49609 .33136 m
.49686 .33149 L
s
.49566 .33135 m
.49644 .33149 L
s
.39063 .33272 m
.39141 .33257 L
s
.39055 .33271 m
.39133 .33256 L
s
.4954 .3313 m
.49618 .33143 L
s
.39089 .33266 m
.39167 .33251 L
s
.74899 .20195 m
.74936 .20208 L
s
.49532 .33122 m
.49609 .33136 L
s
.49489 .33122 m
.49566 .33135 L
s
.20265 .34448 m
.20299 .34415 L
s
.39141 .33257 m
.39218 .33241 L
s
.65927 .32721 m
.65968 .32752 L
s
.39133 .33256 m
.3921 .3324 L
s
.49463 .33116 m
.4954 .3313 L
s
.39167 .33251 m
.39244 .33235 L
s
.65916 .32714 m
.65956 .32745 L
s
.49411 .33109 m
.49489 .33122 L
s
.49454 .33109 m
.49532 .33122 L
s
.39218 .33241 m
.39296 .33226 L
s
.3921 .3324 m
.39288 .33225 L
s
.49385 .33103 m
.49463 .33116 L
s
.19052 .42032 m
.19075 .41982 L
s
.39244 .33235 m
.39322 .3322 L
s
.74862 .20181 m
.74899 .20195 L
s
.49334 .33096 m
.49411 .33109 L
s
.49377 .33096 m
.49454 .33109 L
s
.39296 .33226 m
.39374 .33211 L
s
.39288 .33225 m
.39366 .3321 L
s
.49307 .33091 m
.49385 .33103 L
s
.20299 .34415 m
.20334 .34382 L
s
.65887 .3269 m
.65927 .32721 L
s
.39322 .3322 m
.394 .33205 L
s
.49256 .33084 m
.49334 .33096 L
s
.49299 .33084 m
.49377 .33096 L
s
.65875 .32683 m
.65916 .32714 L
s
.39374 .33211 m
.39452 .33197 L
s
.4923 .33078 m
.49307 .33091 L
s
.39366 .3321 m
.39444 .33195 L
s
.74824 .20168 m
.74862 .20181 L
s
.394 .33205 m
.39478 .33191 L
s
.49178 .33071 m
.49256 .33084 L
s
.49221 .33071 m
.49299 .33084 L
s
.19075 .41982 m
.19098 .41932 L
s
.39452 .33197 m
.3953 .33182 L
s
.49152 .33066 m
.4923 .33078 L
s
.39444 .33195 m
.39522 .33181 L
s
.39478 .33191 m
.39556 .33177 L
s
.491 .33059 m
.49178 .33071 L
s
.49143 .33059 m
.49221 .33071 L
s
.20334 .34382 m
.20369 .34348 L
s
.65846 .32659 m
.65887 .3269 L
s
.3953 .33182 m
.39608 .33168 L
s
.49073 .33054 m
.49152 .33066 L
s
.74787 .20154 m
.74824 .20168 L
s
.39522 .33181 m
.396 .33167 L
s
.65834 .32652 m
.65875 .32683 L
s
.39556 .33177 m
.39634 .33162 L
s
.49022 .33047 m
.491 .33059 L
s
.49065 .33047 m
.49143 .33059 L
s
.39608 .33168 m
.39686 .33154 L
s
.48995 .33042 m
.49073 .33054 L
s
.396 .33167 m
.39678 .33153 L
s
.39634 .33162 m
.39713 .33148 L
s
.48944 .33035 m
.49022 .33047 L
s
.48987 .33035 m
.49065 .33047 L
s
.19098 .41932 m
.19122 .41882 L
s
.39686 .33154 m
.39765 .3314 L
s
.48917 .3303 m
.48995 .33042 L
s
.7475 .2014 m
.74787 .20154 L
s
.39678 .33153 m
.39757 .33139 L
s
.20369 .34348 m
.20403 .34315 L
s
.65805 .32628 m
.65846 .32659 L
s
.39713 .33148 m
.39791 .33135 L
s
.48865 .33024 m
.48944 .33035 L
s
.48908 .33023 m
.48987 .33035 L
s
.65793 .32622 m
.65834 .32652 L
s
.39765 .3314 m
.39843 .33126 L
s
.48839 .33019 m
.48917 .3303 L
s
.39757 .33139 m
.39835 .33125 L
s
.39791 .33135 m
.3987 .33121 L
s
.48787 .33012 m
.48865 .33024 L
s
.4883 .33012 m
.48908 .33023 L
s
.4876 .33007 m
.48839 .33019 L
s
.39843 .33126 m
.39922 .33113 L
s
.74712 .20127 m
.7475 .2014 L
s
.39835 .33125 m
.39914 .33112 L
s
.3987 .33121 m
.39948 .33108 L
s
.48708 .33001 m
.48787 .33012 L
s
.48752 .33001 m
.4883 .33012 L
s
.19122 .41882 m
.19145 .41832 L
s
.20403 .34315 m
.20438 .34282 L
s
.48682 .32996 m
.4876 .33007 L
s
.39922 .33113 m
.40001 .331 L
s
.65764 .32597 m
.65805 .32628 L
s
.39914 .33112 m
.39992 .33098 L
s
.39948 .33108 m
.40027 .33095 L
s
.4863 .3299 m
.48708 .33001 L
s
.48673 .3299 m
.48752 .33001 L
s
.65752 .32591 m
.65793 .32622 L
s
.48603 .32985 m
.48682 .32996 L
s
.40001 .331 m
.40079 .33087 L
s
.39992 .33098 m
.40071 .33085 L
s
.74675 .20114 m
.74712 .20127 L
s
.40027 .33095 m
.40106 .33082 L
s
.48551 .3298 m
.4863 .3299 L
s
.48594 .32979 m
.48673 .3299 L
s
.48524 .32975 m
.48603 .32985 L
s
.40079 .33087 m
.40158 .33074 L
s
.40071 .33085 m
.4015 .33073 L
s
.40106 .33082 m
.40185 .33069 L
s
.48472 .32969 m
.48551 .3298 L
s
.20438 .34282 m
.20473 .34249 L
s
.48516 .32968 m
.48594 .32979 L
s
.65723 .32566 m
.65764 .32597 L
s
.19145 .41832 m
.19169 .41782 L
s
.48445 .32964 m
.48524 .32975 L
s
.40158 .33074 m
.40237 .33062 L
s
.4015 .33073 m
.40229 .3306 L
s
.40185 .33069 m
.40264 .33057 L
s
.74638 .201 m
.74675 .20114 L
s
.65711 .3256 m
.65752 .32591 L
s
.48393 .32959 m
.48472 .32969 L
s
.48437 .32958 m
.48516 .32968 L
s
.48367 .32954 m
.48445 .32964 L
s
.40237 .33062 m
.40316 .3305 L
s
.40229 .3306 m
.40308 .33048 L
s
.40264 .33057 m
.40343 .33045 L
s
.48314 .32949 m
.48393 .32959 L
s
.48358 .32948 m
.48437 .32958 L
s
.48288 .32944 m
.48367 .32954 L
s
.40316 .3305 m
.40395 .33038 L
s
.40308 .33048 m
.40387 .33036 L
s
.40343 .33045 m
.40422 .33033 L
s
.20473 .34249 m
.20509 .34216 L
s
.48235 .32939 m
.48314 .32949 L
s
.48279 .32938 m
.48358 .32948 L
s
.746 .20087 m
.74638 .201 L
s
.65682 .32536 m
.65723 .32566 L
s
.48208 .32934 m
.48288 .32944 L
s
.40395 .33038 m
.40475 .33026 L
s
.19169 .41782 m
.19192 .41732 L
s
.40387 .33036 m
.40466 .33024 L
s
.40422 .33033 m
.40501 .33021 L
s
.6567 .32529 m
.65711 .3256 L
s
.48156 .32929 m
.48235 .32939 L
s
.482 .32928 m
.48279 .32938 L
s
.48129 .32925 m
.48208 .32934 L
s
.40475 .33026 m
.40554 .33014 L
s
.40466 .33024 m
.40545 .33012 L
s
.40501 .33021 m
.4058 .3301 L
s
.48077 .3292 m
.48156 .32929 L
s
.4812 .32919 m
.482 .32928 L
s
.4805 .32916 m
.48129 .32925 L
s
.40554 .33014 m
.40633 .33003 L
s
.74562 .20073 m
.746 .20087 L
s
.40545 .33012 m
.40625 .33001 L
s
.4058 .3301 m
.4066 .32998 L
s
.47997 .3291 m
.48077 .3292 L
s
.20509 .34216 m
.20544 .34183 L
s
.48041 .32909 m
.4812 .32919 L
s
.47971 .32906 m
.4805 .32916 L
s
.65641 .32505 m
.65682 .32536 L
s
.40633 .33003 m
.40713 .32992 L
s
.40625 .33001 m
.40704 .3299 L
s
.47918 .32901 m
.47997 .3291 L
s
.4066 .32998 m
.40739 .32987 L
s
.47962 .329 m
.48041 .32909 L
s
.65629 .32499 m
.6567 .32529 L
s
.19192 .41732 m
.19216 .41682 L
s
.47891 .32898 m
.47971 .32906 L
s
.40713 .32992 m
.40792 .32981 L
s
.40704 .3299 m
.40784 .32979 L
s
.47839 .32893 m
.47918 .32901 L
s
.40739 .32987 m
.40819 .32976 L
s
.47882 .32891 m
.47962 .329 L
s
.74525 .2006 m
.74562 .20073 L
s
.47812 .32889 m
.47891 .32898 L
s
.40792 .32981 m
.40872 .3297 L
s
.40784 .32979 m
.40863 .32968 L
s
.47759 .32884 m
.47839 .32893 L
s
.40819 .32976 m
.40899 .32966 L
s
.47803 .32883 m
.47882 .32891 L
s
.20544 .34183 m
.2058 .34149 L
s
.47732 .3288 m
.47812 .32889 L
s
.40872 .3297 m
.40952 .3296 L
s
.65599 .32474 m
.65641 .32505 L
s
.40863 .32968 m
.40943 .32958 L
s
.47679 .32876 m
.47759 .32884 L
s
.40899 .32966 m
.40978 .32955 L
s
.47723 .32874 m
.47803 .32883 L
s
.47652 .32872 m
.47732 .3288 L
s
.65587 .32468 m
.65629 .32499 L
s
.40952 .3296 m
.41031 .32949 L
s
.74487 .20047 m
.74525 .2006 L
s
.40943 .32958 m
.41023 .32947 L
s
.476 .32868 m
.47679 .32876 L
s
.40978 .32955 m
.41058 .32945 L
s
.47644 .32866 m
.47723 .32874 L
s
.19216 .41682 m
.1924 .41632 L
s
.47573 .32864 m
.47652 .32872 L
s
.41031 .32949 m
.41111 .32939 L
s
.41023 .32947 m
.41103 .32937 L
s
.4752 .3286 m
.476 .32868 L
s
.41058 .32945 m
.41138 .32935 L
s
.47564 .32858 m
.47644 .32866 L
s
.47493 .32856 m
.47573 .32864 L
s
.41111 .32939 m
.41191 .32929 L
s
.2058 .34149 m
.20615 .34116 L
s
.4744 .32852 m
.4752 .3286 L
s
.41103 .32937 m
.41183 .32927 L
s
.41138 .32935 m
.41218 .32926 L
s
.47484 .3285 m
.47564 .32858 L
s
.47413 .32849 m
.47493 .32856 L
s
.65558 .32444 m
.65599 .32474 L
s
.41191 .32929 m
.41271 .3292 L
s
.74449 .20034 m
.74487 .20047 L
s
.4736 .32844 m
.4744 .32852 L
s
.41183 .32927 m
.41263 .32918 L
s
.41218 .32926 m
.41298 .32916 L
s
.47404 .32843 m
.47484 .3285 L
s
.65546 .32438 m
.65587 .32468 L
s
.47333 .32841 m
.47413 .32849 L
s
.41271 .3292 m
.41351 .32911 L
s
.4728 .32837 m
.4736 .32844 L
s
.41263 .32918 m
.41343 .32908 L
s
.41298 .32916 m
.41378 .32907 L
s
.47324 .32835 m
.47404 .32843 L
s
.47253 .32834 m
.47333 .32841 L
s
.1924 .41632 m
.19265 .41582 L
s
.41351 .32911 m
.41431 .32901 L
s
.472 .3283 m
.4728 .32837 L
s
.41343 .32908 m
.41423 .32899 L
s
.41378 .32907 m
.41458 .32898 L
s
.47244 .32828 m
.47324 .32835 L
s
.47173 .32827 m
.47253 .32834 L
s
.41431 .32901 m
.41511 .32892 L
s
.20615 .34116 m
.20651 .34084 L
s
.74411 .20021 m
.74449 .20034 L
s
.4712 .32823 m
.472 .3283 L
s
.41423 .32899 m
.41503 .3289 L
s
.41458 .32898 m
.41538 .32889 L
s
.47164 .32821 m
.47244 .32828 L
s
.47093 .3282 m
.47173 .32827 L
s
.65516 .32413 m
.65558 .32444 L
s
.41511 .32892 m
.41592 .32884 L
s
.4704 .32817 m
.4712 .32823 L
s
.41503 .3289 m
.41583 .32881 L
s
.41538 .32889 m
.41619 .3288 L
s
.47084 .32815 m
.47164 .32821 L
s
.47013 .32814 m
.47093 .3282 L
s
.65504 .32407 m
.65546 .32438 L
s
.41592 .32884 m
.41672 .32875 L
s
.4696 .3281 m
.4704 .32817 L
s
.41619 .3288 m
.41699 .32872 L
s
.41583 .32881 m
.41663 .32873 L
s
.47004 .32808 m
.47084 .32815 L
s
.46933 .32807 m
.47013 .32814 L
s
.41672 .32875 m
.41752 .32867 L
s
.46879 .32804 m
.4696 .3281 L
s
.41699 .32872 m
.41779 .32864 L
s
.41663 .32873 m
.41744 .32865 L
s
.74373 .20008 m
.74411 .20021 L
s
.46924 .32802 m
.47004 .32808 L
s
.19265 .41582 m
.19289 .41532 L
s
.46852 .32801 m
.46933 .32807 L
s
.41752 .32867 m
.41833 .32859 L
s
.46799 .32798 m
.46879 .32804 L
s
.41779 .32864 m
.4186 .32856 L
s
.41744 .32865 m
.41824 .32857 L
s
.20651 .34084 m
.20687 .34051 L
s
.46843 .32796 m
.46924 .32802 L
s
.46772 .32796 m
.46852 .32801 L
s
.41833 .32859 m
.41913 .32851 L
s
.46718 .32792 m
.46799 .32798 L
s
.65474 .32383 m
.65516 .32413 L
s
.4186 .32856 m
.4194 .32848 L
s
.41824 .32857 m
.41905 .32849 L
s
.46763 .3279 m
.46843 .32796 L
s
.46691 .3279 m
.46772 .32796 L
s
.41913 .32851 m
.41994 .32844 L
s
.46638 .32787 m
.46718 .32792 L
s
.65462 .32377 m
.65504 .32407 L
s
.4194 .32848 m
.42021 .32841 L
s
.41905 .32849 m
.41985 .32841 L
s
.46682 .32784 m
.46763 .3279 L
s
.46611 .32784 m
.46691 .3279 L
s
.41994 .32844 m
.42074 .32836 L
s
.46558 .32781 m
.46638 .32787 L
s
.74335 .19995 m
.74373 .20008 L
s
.42021 .32841 m
.42101 .32834 L
s
.41985 .32841 m
.42066 .32834 L
s
.46602 .32779 m
.46682 .32784 L
s
.4653 .32779 m
.46611 .32784 L
s
.42074 .32836 m
.42155 .32829 L
s
.46477 .32776 m
.46558 .32781 L
s
.42101 .32834 m
.42182 .32827 L
s
.42066 .32834 m
.42146 .32827 L
s
.46521 .32774 m
.46602 .32779 L
s
.4645 .32774 m
.4653 .32779 L
s
.42155 .32829 m
.42236 .32822 L
s
.19289 .41532 m
.19313 .41482 L
s
.46396 .32772 m
.46477 .32776 L
s
.42182 .32827 m
.42263 .3282 L
s
.20687 .34051 m
.20723 .34018 L
s
.42146 .32827 m
.42227 .3282 L
s
.46441 .32769 m
.46521 .32774 L
s
.46369 .32769 m
.4645 .32774 L
s
.42236 .32822 m
.42316 .32816 L
s
.46316 .32767 m
.46396 .32772 L
s
.42263 .3282 m
.42343 .32813 L
s
.65432 .32353 m
.65474 .32383 L
s
.42227 .3282 m
.42308 .32813 L
s
.46289 .32765 m
.46369 .32769 L
s
.4636 .32764 m
.46441 .32769 L
s
.42316 .32816 m
.42397 .32809 L
s
.46235 .32762 m
.46316 .32767 L
s
.42343 .32813 m
.42424 .32807 L
s
.74297 .19981 m
.74335 .19995 L
s
.46208 .32761 m
.46289 .32765 L
s
.42308 .32813 m
.42388 .32806 L
s
.4628 .3276 m
.4636 .32764 L
s
.6542 .32347 m
.65462 .32377 L
s
.42397 .32809 m
.42478 .32803 L
s
.46154 .32758 m
.46235 .32762 L
s
.42424 .32807 m
.42505 .32801 L
s
.46127 .32757 m
.46208 .32761 L
s
.42388 .32806 m
.42469 .328 L
s
.46199 .32756 m
.4628 .3276 L
s
.42478 .32803 m
.42559 .32797 L
s
.46073 .32754 m
.46154 .32758 L
s
.42505 .32801 m
.42586 .32795 L
s
.46046 .32753 m
.46127 .32757 L
s
.46118 .32751 m
.46199 .32756 L
s
.42469 .328 m
.4255 .32794 L
s
.42559 .32797 m
.4264 .32791 L
s
.45993 .32751 m
.46073 .32754 L
s
.42586 .32795 m
.42667 .32789 L
s
.45965 .32749 m
.46046 .32753 L
s
.46037 .32748 m
.46118 .32751 L
s
.4255 .32794 m
.42631 .32788 L
s
.4264 .32791 m
.42721 .32786 L
s
.45912 .32747 m
.45993 .32751 L
s
.42667 .32789 m
.42748 .32784 L
s
.45885 .32746 m
.45965 .32749 L
s
.20723 .34018 m
.20759 .33985 L
s
.45956 .32744 m
.46037 .32748 L
s
.42631 .32788 m
.42712 .32783 L
s
.42721 .32786 m
.42801 .32781 L
s
.45831 .32744 m
.45912 .32747 L
s
.19313 .41482 m
.19338 .41432 L
s
.42748 .32784 m
.42829 .32778 L
s
.45804 .32742 m
.45885 .32746 L
s
.74259 .19969 m
.74297 .19981 L
s
.45876 .32741 m
.45956 .32744 L
s
.42712 .32783 m
.42793 .32777 L
s
.42801 .32781 m
.42882 .32775 L
s
.4575 .32741 m
.45831 .32744 L
s
.6539 .32322 m
.65432 .32353 L
s
.42829 .32778 m
.4291 .32773 L
s
.45723 .32739 m
.45804 .32742 L
s
.45795 .32737 m
.45876 .32741 L
s
.42793 .32777 m
.42874 .32772 L
s
.42882 .32775 m
.42963 .32771 L
s
.45669 .32738 m
.4575 .32741 L
s
.4291 .32773 m
.42991 .32769 L
s
.45642 .32737 m
.45723 .32739 L
s
.45714 .32735 m
.45795 .32737 L
s
.42874 .32772 m
.42955 .32767 L
s
.42963 .32771 m
.43044 .32766 L
s
.45588 .32735 m
.45669 .32738 L
s
.65378 .32316 m
.6542 .32347 L
s
.42991 .32769 m
.43072 .32764 L
s
.45561 .32734 m
.45642 .32737 L
s
.45633 .32732 m
.45714 .32735 L
s
.43044 .32766 m
.43126 .32762 L
s
.42955 .32767 m
.43036 .32763 L
s
.45507 .32733 m
.45588 .32735 L
s
.43072 .32764 m
.43153 .3276 L
s
.4548 .32732 m
.45561 .32734 L
s
.43126 .32762 m
.43207 .32757 L
s
.45426 .3273 m
.45507 .32733 L
s
.45552 .32729 m
.45633 .32732 L
s
.43036 .32763 m
.43117 .32758 L
s
.43153 .3276 m
.43234 .32756 L
s
.45399 .3273 m
.4548 .32732 L
s
.43207 .32757 m
.43288 .32753 L
s
.45345 .32728 m
.45426 .3273 L
s
.45471 .32727 m
.45552 .32729 L
s
.43117 .32758 m
.43198 .32754 L
s
.43234 .32756 m
.43315 .32752 L
s
.45318 .32728 m
.45399 .3273 L
s
.43288 .32753 m
.43369 .3275 L
s
.45264 .32727 m
.45345 .32728 L
s
.4539 .32725 m
.45471 .32727 L
s
.43198 .32754 m
.43279 .3275 L
s
.43315 .32752 m
.43396 .32748 L
s
.45237 .32726 m
.45318 .32728 L
s
.43369 .3275 m
.4345 .32746 L
s
.45183 .32725 m
.45264 .32727 L
s
.7422 .19956 m
.74259 .19969 L
s
.43396 .32748 m
.43477 .32745 L
s
.45309 .32723 m
.4539 .32725 L
s
.43279 .3275 m
.4336 .32746 L
s
.45155 .32725 m
.45237 .32726 L
s
.4345 .32746 m
.43531 .32743 L
s
.45102 .32724 m
.45183 .32725 L
s
.20759 .33985 m
.20796 .33952 L
s
.43477 .32745 m
.43558 .32742 L
s
.45074 .32723 m
.45155 .32725 L
s
.45228 .32722 m
.45309 .32723 L
s
.4336 .32746 m
.43441 .32743 L
s
.43531 .32743 m
.43612 .3274 L
s
.4502 .32723 m
.45102 .32724 L
s
.43558 .32742 m
.4364 .32739 L
s
.44993 .32722 m
.45074 .32723 L
s
.45146 .3272 m
.45228 .32722 L
s
.43441 .32743 m
.43522 .32739 L
s
.44939 .32722 m
.4502 .32723 L
s
.43612 .3274 m
.43694 .32737 L
s
.4364 .32739 m
.43721 .32736 L
s
.44912 .32722 m
.44993 .32722 L
s
.45065 .32719 m
.45146 .3272 L
s
.44858 .32721 m
.44939 .32722 L
s
.43694 .32737 m
.43775 .32734 L
s
.43522 .32739 m
.43603 .32736 L
s
.43721 .32736 m
.43802 .32733 L
s
.19338 .41432 m
.19363 .41382 L
s
.44831 .32721 m
.44912 .32722 L
s
.65347 .32292 m
.6539 .32322 L
s
.44777 .32721 m
.44858 .32721 L
s
.43775 .32734 m
.43856 .32732 L
s
.43802 .32733 m
.43883 .32731 L
s
.44984 .32718 m
.45065 .32719 L
s
.43603 .32736 m
.43685 .32733 L
s
.4475 .32721 m
.44831 .32721 L
s
.44696 .32721 m
.44777 .32721 L
s
.43856 .32732 m
.43937 .3273 L
s
.43883 .32731 m
.43964 .32729 L
s
.44668 .32721 m
.4475 .32721 L
s
.44903 .32717 m
.44984 .32718 L
s
.44614 .32721 m
.44696 .32721 L
s
.43685 .32733 m
.43766 .32731 L
s
.43937 .3273 m
.44018 .32728 L
s
.43964 .32729 m
.44046 .32727 L
s
.44587 .32721 m
.44668 .32721 L
s
.44533 .32721 m
.44614 .32721 L
s
.44018 .32728 m
.441 .32726 L
s
.44046 .32727 m
.44127 .32726 L
s
.44506 .32721 m
.44587 .32721 L
s
.44822 .32717 m
.44903 .32717 L
s
.44452 .32721 m
.44533 .32721 L
s
.43766 .32731 m
.43847 .32728 L
s
.441 .32726 m
.44181 .32725 L
s
.44127 .32726 m
.44208 .32724 L
s
.44425 .32722 m
.44506 .32721 L
s
.44371 .32722 m
.44452 .32721 L
s
.44208 .32724 m
.44289 .32723 L
s
.44181 .32725 m
.44262 .32724 L
s
.44289 .32723 m
.44371 .32722 L
s
.44343 .32723 m
.44425 .32722 L
s
.44262 .32724 m
.44343 .32723 L
s
.44741 .32717 m
.44822 .32717 L
s
.43847 .32728 m
.43928 .32726 L
s
.44659 .32716 m
.44741 .32717 L
s
.65335 .32286 m
.65378 .32316 L
s
.43928 .32726 m
.44009 .32724 L
s
.44578 .32717 m
.44659 .32716 L
s
.44009 .32724 m
.44091 .32722 L
s
.44497 .32717 m
.44578 .32717 L
s
.44091 .32722 m
.44172 .32721 L
s
.44416 .32718 m
.44497 .32717 L
s
.44172 .32721 m
.44253 .3272 L
s
.44334 .32719 m
.44416 .32718 L
s
.44253 .3272 m
.44334 .32719 L
s
.74182 .19943 m
.7422 .19956 L
s
.20796 .33952 m
.20832 .33919 L
s
.65305 .32262 m
.65347 .32292 L
s
.19363 .41382 m
.19388 .41332 L
s
.65293 .32256 m
.65335 .32286 L
s
.74144 .1993 m
.74182 .19943 L
s
.20832 .33919 m
.20869 .33887 L
s
.65263 .32232 m
.65305 .32262 L
s
.74105 .19917 m
.74144 .1993 L
s
.6525 .32226 m
.65293 .32256 L
s
.19388 .41332 m
.19413 .41282 L
s
.20869 .33887 m
.20906 .33854 L
s
.74067 .19904 m
.74105 .19917 L
s
.6522 .32202 m
.65263 .32232 L
s
.65208 .32196 m
.6525 .32226 L
s
.19413 .41282 m
.19438 .41232 L
s
.74028 .19892 m
.74067 .19904 L
s
.20906 .33854 m
.20943 .33822 L
s
.65177 .32172 m
.6522 .32202 L
s
.65165 .32166 m
.65208 .32196 L
s
.7399 .19879 m
.74028 .19892 L
s
.19438 .41232 m
.19464 .41182 L
s
.20943 .33822 m
.2098 .33789 L
s
.65134 .32142 m
.65177 .32172 L
s
.73951 .19866 m
.7399 .19879 L
s
.65122 .32136 m
.65165 .32166 L
s
.19464 .41182 m
.19489 .41132 L
s
.2098 .33789 m
.21017 .33756 L
s
.73912 .19854 m
.73951 .19866 L
s
.65091 .32112 m
.65134 .32142 L
s
.65079 .32106 m
.65122 .32136 L
s
.21017 .33756 m
.21054 .33724 L
s
.73873 .19841 m
.73912 .19854 L
s
.19489 .41132 m
.19515 .41082 L
s
.65048 .32082 m
.65091 .32112 L
s
.65036 .32076 m
.65079 .32106 L
s
.73834 .19829 m
.73873 .19841 L
s
.21054 .33724 m
.21092 .33692 L
s
.19515 .41082 m
.19541 .41032 L
s
.65005 .32052 m
.65048 .32082 L
s
.64992 .32046 m
.65036 .32076 L
s
.73795 .19816 m
.73834 .19829 L
s
.21092 .33692 m
.21129 .33659 L
s
.19541 .41032 m
.19567 .40982 L
s
.64961 .32022 m
.65005 .32052 L
s
.73756 .19804 m
.73795 .19816 L
s
.64949 .32017 m
.64992 .32046 L
s
.21129 .33659 m
.21167 .33627 L
s
.73717 .19791 m
.73756 .19804 L
s
.64917 .31993 m
.64961 .32022 L
s
.19567 .40982 m
.19593 .40932 L
s
.64905 .31987 m
.64949 .32017 L
s
.73678 .19779 m
.73717 .19791 L
s
.21167 .33627 m
.21205 .33595 L
s
.64874 .31963 m
.64917 .31993 L
s
.64861 .31957 m
.64905 .31987 L
s
.19593 .40932 m
.19619 .40882 L
s
.73639 .19767 m
.73678 .19779 L
s
.21205 .33595 m
.21243 .33562 L
s
.6483 .31934 m
.64874 .31963 L
s
.73599 .19754 m
.73639 .19767 L
s
.64817 .31928 m
.64861 .31957 L
s
.19619 .40882 m
.19646 .40832 L
s
.21243 .33562 m
.21281 .3353 L
s
.7356 .19742 m
.73599 .19754 L
s
.64786 .31904 m
.6483 .31934 L
s
.64773 .31898 m
.64817 .31928 L
s
.19646 .40832 m
.19672 .40782 L
s
.21281 .3353 m
.2132 .33498 L
s
.73521 .1973 m
.7356 .19742 L
s
.64742 .31875 m
.64786 .31904 L
s
.64729 .31869 m
.64773 .31898 L
s
.73481 .19718 m
.73521 .1973 L
s
.2132 .33498 m
.21358 .33466 L
s
.19672 .40782 m
.19699 .40732 L
s
.64698 .31845 m
.64742 .31875 L
s
.64685 .3184 m
.64729 .31869 L
s
.73442 .19706 m
.73481 .19718 L
s
.21358 .33466 m
.21397 .33434 L
s
.19699 .40732 m
.19726 .40682 L
s
.64653 .31816 m
.64698 .31845 L
s
.73402 .19694 m
.73442 .19706 L
s
.64641 .3181 m
.64685 .3184 L
s
.21397 .33434 m
.21435 .33402 L
s
.19726 .40682 m
.19753 .40631 L
s
.73362 .19682 m
.73402 .19694 L
s
.64609 .31787 m
.64653 .31816 L
s
.64596 .31781 m
.64641 .3181 L
s
.21435 .33402 m
.21474 .3337 L
s
.73322 .1967 m
.73362 .19682 L
s
.64564 .31758 m
.64609 .31787 L
s
.19753 .40631 m
.1978 .40581 L
s
.64551 .31752 m
.64596 .31781 L
s
.73283 .19658 m
.73322 .1967 L
s
.21474 .3337 m
.21513 .33338 L
s
.64519 .31728 m
.64564 .31758 L
s
.1978 .40581 m
.19808 .40531 L
s
.64507 .31723 m
.64551 .31752 L
s
.73243 .19646 m
.73283 .19658 L
s
.21513 .33338 m
.21552 .33306 L
s
.64474 .31699 m
.64519 .31728 L
s
.73203 .19634 m
.73243 .19646 L
s
.64462 .31694 m
.64507 .31723 L
s
.19808 .40531 m
.19835 .40481 L
s
.21552 .33306 m
.21592 .33275 L
s
.73163 .19623 m
.73203 .19634 L
s
.64429 .3167 m
.64474 .31699 L
s
.64417 .31665 m
.64462 .31694 L
s
.19835 .40481 m
.19863 .40431 L
s
.21592 .33275 m
.21631 .33243 L
s
.73123 .19611 m
.73163 .19623 L
s
.64384 .31641 m
.64429 .3167 L
s
.64371 .31636 m
.64417 .31665 L
s
.73082 .19599 m
.73123 .19611 L
s
.21631 .33243 m
.2167 .33211 L
s
.19863 .40431 m
.19891 .40381 L
s
.64339 .31612 m
.64384 .31641 L
s
.64326 .31607 m
.64371 .31636 L
s
.73042 .19588 m
.73082 .19599 L
s
.2167 .33211 m
.2171 .33179 L
s
.19891 .40381 m
.19919 .40331 L
s
.64294 .31584 m
.64339 .31612 L
s
.73002 .19576 m
.73042 .19588 L
s
.64281 .31578 m
.64326 .31607 L
s
.2171 .33179 m
.2175 .33148 L
s
.19919 .40331 m
.19947 .40281 L
s
.72962 .19564 m
.73002 .19576 L
s
.64248 .31555 m
.64294 .31584 L
s
.64235 .31549 m
.64281 .31578 L
s
.2175 .33148 m
.2179 .33116 L
s
.72921 .19553 m
.72962 .19564 L
s
.19947 .40281 m
.19975 .40231 L
s
.64202 .31526 m
.64248 .31555 L
s
.64189 .31521 m
.64235 .31549 L
s
.72881 .19541 m
.72921 .19553 L
s
.2179 .33116 m
.2183 .33085 L
s
.64157 .31498 m
.64202 .31526 L
s
.19975 .40231 m
.20003 .40181 L
s
.64144 .31492 m
.64189 .31521 L
s
.7284 .1953 m
.72881 .19541 L
s
.2183 .33085 m
.2187 .33053 L
s
.64111 .31469 m
.64157 .31498 L
s
.72799 .19519 m
.7284 .1953 L
s
.64098 .31463 m
.64144 .31492 L
s
.20003 .40181 m
.20032 .40131 L
s
.2187 .33053 m
.21911 .33022 L
s
.72759 .19507 m
.72799 .19519 L
s
.64065 .3144 m
.64111 .31469 L
s
.64052 .31435 m
.64098 .31463 L
s
.20032 .40131 m
.20061 .40081 L
s
.21911 .33022 m
.21951 .32991 L
s
.72718 .19496 m
.72759 .19507 L
s
.64018 .31412 m
.64065 .3144 L
s
.64005 .31407 m
.64052 .31435 L
s
.21951 .32991 m
.21992 .32959 L
s
.72677 .19485 m
.72718 .19496 L
s
.20061 .40081 m
.2009 .40031 L
s
.63972 .31384 m
.64018 .31412 L
s
.63959 .31378 m
.64005 .31407 L
s
.72636 .19474 m
.72677 .19485 L
s
.21992 .32959 m
.22032 .32928 L
s
.2009 .40031 m
.20119 .39981 L
s
.63926 .31355 m
.63972 .31384 L
s
.72595 .19463 m
.72636 .19474 L
s
.63913 .3135 m
.63959 .31378 L
s
.22032 .32928 m
.22073 .32897 L
s
.20119 .39981 m
.20148 .39931 L
s
.72554 .19452 m
.72595 .19463 L
s
.63879 .31327 m
.63926 .31355 L
s
.63866 .31322 m
.63913 .3135 L
s
.22073 .32897 m
.22114 .32866 L
s
.72513 .1944 m
.72554 .19452 L
s
.20148 .39931 m
.20177 .39881 L
s
.63833 .31299 m
.63879 .31327 L
s
.63819 .31293 m
.63866 .31322 L
s
.22114 .32866 m
.22155 .32835 L
s
.72472 .19429 m
.72513 .1944 L
s
.63786 .31271 m
.63833 .31299 L
s
.20177 .39881 m
.20206 .39831 L
s
.63772 .31265 m
.63819 .31293 L
s
.72431 .19419 m
.72472 .19429 L
s
.22155 .32835 m
.22197 .32804 L
s
.63739 .31243 m
.63786 .31271 L
s
.72389 .19408 m
.72431 .19419 L
s
.63726 .31237 m
.63772 .31265 L
s
.20206 .39831 m
.20236 .39781 L
s
.22197 .32804 m
.22238 .32773 L
s
.72348 .19397 m
.72389 .19408 L
s
.63692 .31215 m
.63739 .31243 L
s
.63678 .31209 m
.63726 .31237 L
s
.22238 .32773 m
.2228 .32742 L
s
.20236 .39781 m
.20266 .39731 L
s
.72307 .19386 m
.72348 .19397 L
s
.63645 .31187 m
.63692 .31215 L
s
.63631 .31181 m
.63678 .31209 L
s
.2228 .32742 m
.22321 .32711 L
s
.72265 .19375 m
.72307 .19386 L
s
.20266 .39731 m
.20296 .39681 L
s
.63597 .31159 m
.63645 .31187 L
s
.63584 .31153 m
.63631 .31181 L
s
.72224 .19365 m
.72265 .19375 L
s
.22321 .32711 m
.22363 .3268 L
s
.20296 .39681 m
.20326 .39631 L
s
.6355 .31131 m
.63597 .31159 L
s
.72182 .19354 m
.72224 .19365 L
s
.63536 .31126 m
.63584 .31153 L
s
.22363 .3268 m
.22405 .32649 L
s
.20326 .39631 m
.20356 .39581 L
s
.7214 .19343 m
.72182 .19354 L
s
.63502 .31103 m
.6355 .31131 L
s
.63489 .31098 m
.63536 .31126 L
s
.22405 .32649 m
.22447 .32619 L
s
.72098 .19333 m
.7214 .19343 L
s
.20356 .39581 m
.20386 .39531 L
s
.63455 .31075 m
.63502 .31103 L
s
.63441 .3107 m
.63489 .31098 L
s
.22447 .32619 m
.22489 .32588 L
s
.72057 .19322 m
.72098 .19333 L
s
.63407 .31048 m
.63455 .31075 L
s
.20386 .39531 m
.20417 .39482 L
s
.63393 .31043 m
.63441 .3107 L
s
.22489 .32588 m
.22532 .32557 L
s
.72015 .19312 m
.72057 .19322 L
s
.63359 .3102 m
.63407 .31048 L
s
.71973 .19301 m
.72015 .19312 L
s
.63345 .31015 m
.63393 .31043 L
s
.22532 .32557 m
.22574 .32527 L
s
.20417 .39482 m
.20447 .39432 L
s
.71931 .19291 m
.71973 .19301 L
s
.63311 .30993 m
.63359 .3102 L
s
.63297 .30988 m
.63345 .31015 L
s
.22574 .32527 m
.22617 .32496 L
s
.20447 .39432 m
.20478 .39382 L
s
.71889 .1928 m
.71931 .19291 L
s
.63263 .30965 m
.63311 .30993 L
s
.63249 .3096 m
.63297 .30988 L
s
.22617 .32496 m
.22659 .32466 L
s
.20478 .39382 m
.20509 .39332 L
s
.71847 .1927 m
.71889 .1928 L
s
.63214 .30938 m
.63263 .30965 L
s
.22659 .32466 m
.22702 .32435 L
s
.63201 .30933 m
.63249 .3096 L
s
.71804 .1926 m
.71847 .1927 L
s
.20509 .39332 m
.2054 .39282 L
s
.63166 .30911 m
.63214 .30938 L
s
.71762 .1925 m
.71804 .1926 L
s
.22702 .32435 m
.22745 .32405 L
s
.63152 .30906 m
.63201 .30933 L
s
.2054 .39282 m
.20571 .39232 L
s
.7172 .1924 m
.71762 .1925 L
s
.63118 .30884 m
.63166 .30911 L
s
.22745 .32405 m
.22788 .32375 L
s
.63104 .30879 m
.63152 .30906 L
s
.71677 .19229 m
.7172 .1924 L
s
.20571 .39232 m
.20602 .39182 L
s
.63069 .30856 m
.63118 .30884 L
s
.22788 .32375 m
.22832 .32345 L
s
.63055 .30851 m
.63104 .30879 L
s
.71635 .19219 m
.71677 .19229 L
s
.6302 .30829 m
.63069 .30856 L
s
.20602 .39182 m
.20634 .39132 L
s
.22832 .32345 m
.22875 .32314 L
s
.63006 .30824 m
.63055 .30851 L
s
.71592 .19209 m
.71635 .19219 L
s
.62971 .30802 m
.6302 .30829 L
s
.22875 .32314 m
.22919 .32284 L
s
.62957 .30797 m
.63006 .30824 L
s
.7155 .19199 m
.71592 .19209 L
s
.20634 .39132 m
.20665 .39082 L
s
.62922 .30775 m
.62971 .30802 L
s
.71507 .1919 m
.7155 .19199 L
s
.22919 .32284 m
.22962 .32254 L
s
.62908 .3077 m
.62957 .30797 L
s
.20665 .39082 m
.20697 .39033 L
s
.71464 .1918 m
.71507 .1919 L
s
.62873 .30748 m
.62922 .30775 L
s
.22962 .32254 m
.23006 .32224 L
s
.62859 .30744 m
.62908 .3077 L
s
.20697 .39033 m
.20729 .38983 L
s
.71421 .1917 m
.71464 .1918 L
s
.62824 .30722 m
.62873 .30748 L
s
.23006 .32224 m
.2305 .32194 L
s
.6281 .30717 m
.62859 .30744 L
s
.71379 .1916 m
.71421 .1917 L
s
.20729 .38983 m
.20761 .38933 L
s
.62775 .30695 m
.62824 .30722 L
s
.2305 .32194 m
.23094 .32164 L
s
.62761 .3069 m
.6281 .30717 L
s
.71336 .1915 m
.71379 .1916 L
s
.20761 .38933 m
.20793 .38883 L
s
.62725 .30668 m
.62775 .30695 L
s
.23094 .32164 m
.23138 .32135 L
s
.71293 .19141 m
.71336 .1915 L
s
.62711 .30663 m
.62761 .3069 L
s
.62675 .30642 m
.62725 .30668 L
s
.7125 .19131 m
.71293 .19141 L
s
.20793 .38883 m
.20826 .38833 L
s
.23138 .32135 m
.23182 .32105 L
s
.62661 .30637 m
.62711 .30663 L
s
.71206 .19121 m
.7125 .19131 L
s
.62626 .30615 m
.62675 .30642 L
s
.23182 .32105 m
.23227 .32075 L
s
.62612 .3061 m
.62661 .30637 L
s
.20826 .38833 m
.20858 .38784 L
s
.71163 .19112 m
.71206 .19121 L
s
.62576 .30589 m
.62626 .30615 L
s
.23227 .32075 m
.23271 .32045 L
s
.62562 .30584 m
.62612 .3061 L
s
.20858 .38784 m
.20891 .38734 L
s
.7112 .19102 m
.71163 .19112 L
s
.62526 .30562 m
.62576 .30589 L
s
.23271 .32045 m
.23316 .32016 L
s
.62512 .30557 m
.62562 .30584 L
s
.71077 .19093 m
.7112 .19102 L
s
.20891 .38734 m
.20923 .38684 L
s
.62476 .30536 m
.62526 .30562 L
s
.23316 .32016 m
.23361 .31986 L
s
.71033 .19084 m
.71077 .19093 L
s
.62462 .30531 m
.62512 .30557 L
s
.20923 .38684 m
.20956 .38634 L
s
.7099 .19074 m
.71033 .19084 L
s
.62426 .3051 m
.62476 .30536 L
s
.23361 .31986 m
.23406 .31957 L
s
.62412 .30505 m
.62462 .30531 L
s
.70946 .19065 m
.7099 .19074 L
s
.20956 .38634 m
.20989 .38585 L
s
.62375 .30483 m
.62426 .3051 L
s
.23406 .31957 m
.23451 .31927 L
s
.62361 .30479 m
.62412 .30505 L
s
.70903 .19056 m
.70946 .19065 L
s
.23451 .31927 m
.23496 .31898 L
s
.62325 .30457 m
.62375 .30483 L
s
.20989 .38585 m
.21023 .38535 L
s
.70903 .19039 m
.70947 .19048 L
s
.62311 .30453 m
.62361 .30479 L
s
.70859 .19047 m
.70903 .19056 L
s
.7086 .1903 m
.70903 .19039 L
s
.23496 .31898 m
.23541 .31869 L
s
.62274 .30431 m
.62325 .30457 L
s
.21023 .38535 m
.21056 .38485 L
s
.6226 .30427 m
.62311 .30453 L
s
.70815 .19038 m
.70859 .19047 L
s
.70816 .1902 m
.7086 .1903 L
s
.23541 .31869 m
.23587 .3184 L
s
.62224 .30405 m
.62274 .30431 L
s
.70771 .19028 m
.70815 .19038 L
s
.62209 .30401 m
.6226 .30427 L
s
.21056 .38485 m
.21089 .38436 L
s
.70772 .19011 m
.70816 .1902 L
s
.70728 .19019 m
.70771 .19028 L
s
.23587 .3184 m
.23632 .3181 L
s
.62173 .30379 m
.62224 .30405 L
s
.62159 .30375 m
.62209 .30401 L
s
.70728 .19002 m
.70772 .19011 L
s
.21089 .38436 m
.21123 .38386 L
s
.70684 .1901 m
.70728 .19019 L
s
.23632 .3181 m
.23678 .31781 L
s
.62122 .30353 m
.62173 .30379 L
s
.62108 .30349 m
.62159 .30375 L
s
.70684 .18993 m
.70728 .19002 L
s
.7064 .19001 m
.70684 .1901 L
s
.21123 .38386 m
.21157 .38336 L
s
.23678 .31781 m
.23724 .31752 L
s
.62071 .30328 m
.62122 .30353 L
s
.7064 .18985 m
.70684 .18993 L
s
.62057 .30323 m
.62108 .30349 L
s
.70596 .18993 m
.7064 .19001 L
s
.21157 .38336 m
.21191 .38287 L
s
.23724 .31752 m
.2377 .31723 L
s
.70596 .18976 m
.7064 .18985 L
s
.6202 .30302 m
.62071 .30328 L
s
.62005 .30297 m
.62057 .30323 L
s
.70551 .18984 m
.70596 .18993 L
s
.70552 .18967 m
.70596 .18976 L
s
.2377 .31723 m
.23816 .31694 L
s
.61969 .30276 m
.6202 .30302 L
s
.21191 .38287 m
.21225 .38237 L
s
.70507 .18975 m
.70551 .18984 L
s
.61954 .30272 m
.62005 .30297 L
s
.70508 .18958 m
.70552 .18967 L
s
.23816 .31694 m
.23862 .31665 L
s
.70463 .18966 m
.70507 .18975 L
s
.61917 .30251 m
.61969 .30276 L
s
.21225 .38237 m
.21259 .38187 L
s
.61903 .30246 m
.61954 .30272 L
s
.70464 .18949 m
.70508 .18958 L
s
.70419 .18958 m
.70463 .18966 L
s
.23862 .31665 m
.23908 .31636 L
s
.61866 .30225 m
.61917 .30251 L
s
.61851 .30221 m
.61903 .30246 L
s
.70419 .18941 m
.70464 .18949 L
s
.21259 .38187 m
.21293 .38138 L
s
.70374 .18949 m
.70419 .18958 L
s
.23908 .31636 m
.23955 .31608 L
s
.61814 .302 m
.61866 .30225 L
s
.70375 .18932 m
.70419 .18941 L
s
.618 .30195 m
.61851 .30221 L
s
.7033 .1894 m
.70374 .18949 L
s
.21293 .38138 m
.21328 .38088 L
s
.23955 .31608 m
.24001 .31579 L
s
.61762 .30174 m
.61814 .302 L
s
.7033 .18924 m
.70375 .18932 L
s
.61748 .3017 m
.618 .30195 L
s
.70285 .18932 m
.7033 .1894 L
s
.21328 .38088 m
.21362 .38039 L
s
.70286 .18915 m
.7033 .18924 L
s
.24001 .31579 m
.24048 .3155 L
s
.61711 .30149 m
.61762 .30174 L
s
.70241 .18923 m
.70285 .18932 L
s
.61696 .30145 m
.61748 .3017 L
s
.70241 .18907 m
.70286 .18915 L
s
.24048 .3155 m
.24095 .31522 L
s
.21362 .38039 m
.21397 .37989 L
s
.61659 .30124 m
.61711 .30149 L
s
.70196 .18915 m
.70241 .18923 L
s
.61644 .3012 m
.61696 .30145 L
s
.70197 .18898 m
.70241 .18907 L
s
.24095 .31522 m
.24142 .31493 L
s
.70152 .18906 m
.70196 .18915 L
s
.61607 .30099 m
.61659 .30124 L
s
.21397 .37989 m
.21432 .3794 L
s
.61592 .30095 m
.61644 .3012 L
s
.70152 .1889 m
.70197 .18898 L
s
.70107 .18898 m
.70152 .18906 L
s
.24142 .31493 m
.24189 .31465 L
s
.61554 .30074 m
.61607 .30099 L
s
.6154 .30069 m
.61592 .30095 L
s
.21432 .3794 m
.21467 .3789 L
s
.70107 .18882 m
.70152 .1889 L
s
.70062 .1889 m
.70107 .18898 L
s
.24189 .31465 m
.24236 .31436 L
s
.61502 .30049 m
.61554 .30074 L
s
.70062 .18873 m
.70107 .18882 L
s
.61488 .30045 m
.6154 .30069 L
s
.21467 .3789 m
.21502 .37841 L
s
.70017 .18882 m
.70062 .1889 L
s
.24236 .31436 m
.24283 .31408 L
s
.70017 .18865 m
.70062 .18873 L
s
.6145 .30024 m
.61502 .30049 L
s
.61435 .3002 m
.61488 .30045 L
s
.69972 .18873 m
.70017 .18882 L
s
.21502 .37841 m
.21537 .37791 L
s
.69972 .18857 m
.70017 .18865 L
s
.24283 .31408 m
.24331 .3138 L
s
.61397 .29999 m
.6145 .30024 L
s
.69927 .18865 m
.69972 .18873 L
s
.61383 .29995 m
.61435 .3002 L
s
.69927 .18849 m
.69972 .18857 L
s
.21537 .37791 m
.21573 .37742 L
s
.24331 .3138 m
.24378 .31351 L
s
.69882 .18857 m
.69927 .18865 L
s
.61345 .29974 m
.61397 .29999 L
s
.6133 .2997 m
.61383 .29995 L
s
.69882 .18841 m
.69927 .18849 L
s
.24378 .31351 m
.24426 .31323 L
s
.69837 .18849 m
.69882 .18857 L
s
.21573 .37742 m
.21608 .37692 L
s
.61292 .2995 m
.61345 .29974 L
s
.61277 .29945 m
.6133 .2997 L
s
.69837 .18833 m
.69882 .18841 L
s
.69792 .18841 m
.69837 .18849 L
s
.24426 .31323 m
.24474 .31295 L
s
.61239 .29925 m
.61292 .2995 L
s
.21608 .37692 m
.21644 .37643 L
s
.61224 .29921 m
.61277 .29945 L
s
.69792 .18825 m
.69837 .18833 L
s
.69746 .18833 m
.69792 .18841 L
s
.24474 .31295 m
.24522 .31267 L
s
.61186 .299 m
.61239 .29925 L
s
.69746 .18817 m
.69792 .18825 L
s
.61171 .29896 m
.61224 .29921 L
s
.21644 .37643 m
.2168 .37594 L
s
.69701 .18825 m
.69746 .18833 L
s
.24522 .31267 m
.2457 .31239 L
s
.69701 .18809 m
.69746 .18817 L
s
.61133 .29876 m
.61186 .299 L
s
.61118 .29872 m
.61171 .29896 L
s
.69656 .18818 m
.69701 .18825 L
s
.2168 .37594 m
.21716 .37544 L
s
.2457 .31239 m
.24618 .31211 L
s
.69656 .18801 m
.69701 .18809 L
s
.6108 .29852 m
.61133 .29876 L
s
.6961 .1881 m
.69656 .18818 L
s
.61065 .29847 m
.61118 .29872 L
s
.6961 .18794 m
.69656 .18801 L
s
.21716 .37544 m
.21752 .37495 L
s
.24618 .31211 m
.24666 .31184 L
s
.69564 .18802 m
.6961 .1881 L
s
.61027 .29827 m
.6108 .29852 L
s
.61012 .29823 m
.61065 .29847 L
s
.69565 .18786 m
.6961 .18794 L
s
.24666 .31184 m
.24714 .31156 L
s
.69519 .18795 m
.69564 .18802 L
s
.21752 .37495 m
.21788 .37446 L
s
.60973 .29803 m
.61027 .29827 L
s
.60958 .29799 m
.61012 .29823 L
s
.69519 .18778 m
.69565 .18786 L
s
.69473 .18787 m
.69519 .18795 L
s
.24714 .31156 m
.24763 .31128 L
s
.6092 .29779 m
.60973 .29803 L
s
.21788 .37446 m
.21824 .37396 L
s
.60905 .29775 m
.60958 .29799 L
s
.69473 .18771 m
.69519 .18778 L
s
.69427 .18779 m
.69473 .18787 L
s
.24763 .31128 m
.24812 .311 L
s
.60866 .29755 m
.6092 .29779 L
s
.69427 .18763 m
.69473 .18771 L
s
.60851 .29751 m
.60905 .29775 L
s
.21824 .37396 m
.21861 .37347 L
s
.69382 .18772 m
.69427 .18779 L
s
.24812 .311 m
.2486 .31073 L
s
.69382 .18756 m
.69427 .18763 L
s
.60812 .29731 m
.60866 .29755 L
s
.60797 .29727 m
.60851 .29751 L
s
.69336 .18764 m
.69382 .18772 L
s
.21861 .37347 m
.21898 .37298 L
s
.2486 .31073 m
.24909 .31045 L
s
.69336 .18748 m
.69382 .18756 L
s
.60759 .29707 m
.60812 .29731 L
s
.6929 .18757 m
.69336 .18764 L
s
.60744 .29703 m
.60797 .29727 L
s
.21898 .37298 m
.21934 .37249 L
s
.24909 .31045 m
.24958 .31018 L
s
.6929 .18741 m
.69336 .18748 L
s
.60705 .29683 m
.60759 .29707 L
s
.69244 .1875 m
.6929 .18757 L
s
.6069 .29679 m
.60744 .29703 L
s
.69244 .18734 m
.6929 .18741 L
s
.24958 .31018 m
.25007 .3099 L
s
.21934 .37249 m
.21971 .37199 L
s
.69198 .18742 m
.69244 .1875 L
s
.60651 .29659 m
.60705 .29683 L
s
.60636 .29655 m
.6069 .29679 L
s
.69198 .18726 m
.69244 .18734 L
s
.25007 .3099 m
.25057 .30963 L
s
.69152 .18735 m
.69198 .18742 L
s
.60596 .29635 m
.60651 .29659 L
s
.21971 .37199 m
.22008 .3715 L
s
.60581 .29632 m
.60636 .29655 L
s
.69152 .18719 m
.69198 .18726 L
s
.69106 .18728 m
.69152 .18735 L
s
.25057 .30963 m
.25106 .30936 L
s
.60542 .29612 m
.60596 .29635 L
s
.69105 .18712 m
.69152 .18719 L
s
.60527 .29608 m
.60581 .29632 L
s
.22008 .3715 m
.22046 .37101 L
s
.69059 .18721 m
.69106 .18728 L
s
.25106 .30936 m
.25156 .30909 L
s
.60488 .29588 m
.60542 .29612 L
s
.69059 .18705 m
.69105 .18712 L
s
.60473 .29584 m
.60527 .29608 L
s
.69013 .18714 m
.69059 .18721 L
s
.22046 .37101 m
.22083 .37052 L
s
.25156 .30909 m
.25205 .30882 L
s
.69013 .18698 m
.69059 .18705 L
s
.60433 .29565 m
.60488 .29588 L
s
.60418 .29561 m
.60473 .29584 L
s
.68967 .18707 m
.69013 .18714 L
s
.22083 .37052 m
.2212 .37003 L
s
.25205 .30882 m
.25255 .30855 L
s
.68966 .18691 m
.69013 .18698 L
s
.60379 .29541 m
.60433 .29565 L
s
.6892 .187 m
.68967 .18707 L
s
.60364 .29538 m
.60418 .29561 L
s
.25255 .30855 m
.25305 .30828 L
s
.6892 .18684 m
.68966 .18691 L
s
.2212 .37003 m
.22158 .36954 L
s
.68874 .18693 m
.6892 .187 L
s
.60324 .29518 m
.60379 .29541 L
s
.60309 .29514 m
.60364 .29538 L
s
.68873 .18677 m
.6892 .18684 L
s
.25305 .30828 m
.25355 .30801 L
s
.68827 .18686 m
.68874 .18693 L
s
.22158 .36954 m
.22196 .36905 L
s
.60269 .29495 m
.60324 .29518 L
s
.60254 .29491 m
.60309 .29514 L
s
.68827 .1867 m
.68873 .18677 L
s
.25355 .30801 m
.25405 .30774 L
s
.6878 .18679 m
.68827 .18686 L
s
.60214 .29472 m
.60269 .29495 L
s
.60199 .29468 m
.60254 .29491 L
s
.22196 .36905 m
.22234 .36856 L
s
.6878 .18663 m
.68827 .1867 L
s
.25405 .30774 m
.25455 .30747 L
s
.68734 .18672 m
.6878 .18679 L
s
.60159 .29448 m
.60214 .29472 L
s
.68733 .18656 m
.6878 .18663 L
s
.60144 .29445 m
.60199 .29468 L
s
.22234 .36856 m
.22272 .36807 L
s
.68687 .18666 m
.68734 .18672 L
s
.25455 .30747 m
.25505 .3072 L
s
.60104 .29425 m
.60159 .29448 L
s
.68687 .1865 m
.68733 .18656 L
s
.60089 .29422 m
.60144 .29445 L
s
.6864 .18659 m
.68687 .18666 L
s
.25505 .3072 m
.25556 .30694 L
s
.22272 .36807 m
.2231 .36758 L
s
.6864 .18643 m
.68687 .1865 L
s
.60049 .29402 m
.60104 .29425 L
s
.60034 .29399 m
.60089 .29422 L
s
.68593 .18652 m
.6864 .18659 L
s
.25556 .30694 m
.25606 .30667 L
s
.68593 .18637 m
.6864 .18643 L
s
.2231 .36758 m
.22348 .36709 L
s
.59994 .2938 m
.60049 .29402 L
s
.68546 .18646 m
.68593 .18652 L
s
.59979 .29376 m
.60034 .29399 L
s
.25606 .30667 m
.25657 .30641 L
s
.68546 .1863 m
.68593 .18637 L
s
.59938 .29357 m
.59994 .2938 L
s
.22348 .36709 m
.22386 .3666 L
s
.68499 .18639 m
.68546 .18646 L
s
.59923 .29353 m
.59979 .29376 L
s
.25657 .30641 m
.25708 .30614 L
s
.68499 .18624 m
.68546 .1863 L
s
.68452 .18633 m
.68499 .18639 L
s
.59883 .29334 m
.59938 .29357 L
s
.59868 .29331 m
.59923 .29353 L
s
.22386 .3666 m
.22425 .36611 L
s
.68452 .18617 m
.68499 .18624 L
s
.25708 .30614 m
.25758 .30588 L
s
.68405 .18626 m
.68452 .18633 L
s
.59827 .29311 m
.59883 .29334 L
s
.59812 .29308 m
.59868 .29331 L
s
.68405 .18611 m
.68452 .18617 L
s
.22425 .36611 m
.22464 .36562 L
s
.25758 .30588 m
.25809 .30561 L
s
.68358 .1862 m
.68405 .18626 L
s
.59772 .29289 m
.59827 .29311 L
s
.59756 .29285 m
.59812 .29308 L
s
.68357 .18604 m
.68405 .18611 L
s
.25809 .30561 m
.25861 .30535 L
s
.68311 .18614 m
.68358 .1862 L
s
.22464 .36562 m
.22502 .36513 L
s
.59716 .29266 m
.59772 .29289 L
s
.6831 .18598 m
.68357 .18604 L
s
.597 .29263 m
.59756 .29285 L
s
.25861 .30535 m
.25912 .30509 L
s
.68263 .18608 m
.68311 .18614 L
s
.22502 .36513 m
.22541 .36464 L
s
.5966 .29244 m
.59716 .29266 L
s
.68263 .18592 m
.6831 .18598 L
s
.59644 .29241 m
.597 .29263 L
s
.68216 .18601 m
.68263 .18608 L
s
.25912 .30509 m
.25963 .30483 L
s
.68215 .18586 m
.68263 .18592 L
s
.59604 .29222 m
.5966 .29244 L
s
.22541 .36464 m
.2258 .36416 L
s
.59588 .29218 m
.59644 .29241 L
s
.68168 .18595 m
.68216 .18601 L
s
.22543 .3646 m
.22582 .36411 L
s
.25963 .30483 m
.26015 .30457 L
s
.68168 .1858 m
.68215 .18586 L
s
.59548 .292 m
.59604 .29222 L
s
.59532 .29196 m
.59588 .29218 L
s
.68121 .18589 m
.68168 .18595 L
s
.2258 .36416 m
.2262 .36367 L
s
.26015 .30457 m
.26066 .30431 L
s
.22582 .36411 m
.22621 .36362 L
s
.6812 .18574 m
.68168 .1858 L
s
.59491 .29177 m
.59548 .292 L
s
.68073 .18583 m
.68121 .18589 L
s
.59476 .29174 m
.59532 .29196 L
s
.26066 .30431 m
.26118 .30405 L
s
.2262 .36367 m
.22659 .36318 L
s
.68073 .18568 m
.6812 .18574 L
s
.22621 .36362 m
.2266 .36313 L
s
.68026 .18577 m
.68073 .18583 L
s
.59435 .29155 m
.59491 .29177 L
s
.5942 .29152 m
.59476 .29174 L
s
.26118 .30405 m
.2617 .30379 L
s
.68025 .18562 m
.68073 .18568 L
s
.22659 .36318 m
.22698 .36269 L
s
.67978 .18571 m
.68026 .18577 L
s
.2266 .36313 m
.227 .36265 L
s
.59379 .29133 m
.59435 .29155 L
s
.59363 .2913 m
.5942 .29152 L
s
.2617 .30379 m
.26221 .30353 L
s
.67977 .18556 m
.68025 .18562 L
s
.6793 .18566 m
.67978 .18571 L
s
.22698 .36269 m
.22738 .36221 L
s
.59322 .29111 m
.59379 .29133 L
s
.59306 .29108 m
.59363 .2913 L
s
.227 .36265 m
.2274 .36216 L
s
.67929 .1855 m
.67977 .18556 L
s
.26221 .30353 m
.26274 .30328 L
s
.67882 .1856 m
.6793 .18566 L
s
.59265 .2909 m
.59322 .29111 L
s
.5925 .29086 m
.59306 .29108 L
s
.22738 .36221 m
.22778 .36172 L
s
.67882 .18544 m
.67929 .1855 L
s
.26274 .30328 m
.26326 .30302 L
s
.2274 .36216 m
.22779 .36167 L
s
.67834 .18554 m
.67882 .1856 L
s
.59209 .29068 m
.59265 .2909 L
s
.67834 .18539 m
.67882 .18544 L
s
.59193 .29065 m
.5925 .29086 L
s
.26326 .30302 m
.26378 .30277 L
s
.22778 .36172 m
.22818 .36123 L
s
.67786 .18548 m
.67834 .18554 L
s
.22779 .36167 m
.22819 .36119 L
s
.59152 .29046 m
.59209 .29068 L
s
.67786 .18533 m
.67834 .18539 L
s
.59136 .29043 m
.59193 .29065 L
s
.26378 .30277 m
.2643 .30251 L
s
.67738 .18543 m
.67786 .18548 L
s
.22818 .36123 m
.22858 .36075 L
s
.22819 .36119 m
.22859 .3607 L
s
.67738 .18527 m
.67786 .18533 L
s
.59095 .29025 m
.59152 .29046 L
s
.59079 .29021 m
.59136 .29043 L
s
.6769 .18537 m
.67738 .18543 L
s
.2643 .30251 m
.26483 .30226 L
s
.67689 .18522 m
.67738 .18527 L
s
.22858 .36075 m
.22898 .36026 L
s
.59038 .29003 m
.59095 .29025 L
s
.22859 .3607 m
.22899 .36022 L
s
.59022 .29 m
.59079 .29021 L
s
.67642 .18532 m
.6769 .18537 L
s
.26483 .30226 m
.26535 .302 L
s
.67641 .18516 m
.67689 .18522 L
s
.58981 .28982 m
.59038 .29003 L
s
.22898 .36026 m
.22938 .35978 L
s
.67594 .18526 m
.67642 .18532 L
s
.58965 .28978 m
.59022 .29 L
s
.22899 .36022 m
.2294 .35973 L
s
.26535 .302 m
.26588 .30175 L
s
.67593 .18511 m
.67641 .18516 L
s
.58924 .2896 m
.58981 .28982 L
s
.67546 .18521 m
.67594 .18526 L
s
.58908 .28957 m
.58965 .28978 L
s
.26588 .30175 m
.26641 .3015 L
s
.22938 .35978 m
.22978 .35929 L
s
.2294 .35973 m
.2298 .35925 L
s
.67545 .18506 m
.67593 .18511 L
s
.67497 .18516 m
.67546 .18521 L
s
.58866 .28939 m
.58924 .2896 L
s
.5885 .28936 m
.58908 .28957 L
s
.26641 .3015 m
.26694 .30125 L
s
.67496 .185 m
.67545 .18506 L
s
.22978 .35929 m
.23019 .35881 L
s
.2298 .35925 m
.2302 .35876 L
s
.67449 .1851 m
.67497 .18516 L
s
.58809 .28918 m
.58866 .28939 L
s
.58793 .28915 m
.5885 .28936 L
s
.26694 .30125 m
.26747 .301 L
s
.67448 .18495 m
.67496 .185 L
s
.674 .18505 m
.67449 .1851 L
s
.23019 .35881 m
.23059 .35832 L
s
.58751 .28897 m
.58809 .28918 L
s
.2302 .35876 m
.23061 .35828 L
s
.58735 .28894 m
.58793 .28915 L
s
.26747 .301 m
.268 .30075 L
s
.67399 .1849 m
.67448 .18495 L
s
.67352 .185 m
.674 .18505 L
s
.58694 .28876 m
.58751 .28897 L
s
.23059 .35832 m
.231 .35784 L
s
.58678 .28873 m
.58735 .28894 L
s
.23061 .35828 m
.23102 .35779 L
s
.67351 .18485 m
.67399 .1849 L
s
.268 .30075 m
.26853 .3005 L
s
.67303 .18495 m
.67352 .185 L
s
.58636 .28855 m
.58694 .28876 L
s
.5862 .28852 m
.58678 .28873 L
s
.67302 .1848 m
.67351 .18485 L
s
.26853 .3005 m
.26906 .30025 L
s
.231 .35784 m
.23141 .35735 L
s
.23102 .35779 m
.23143 .35731 L
s
.67255 .1849 m
.67303 .18495 L
s
.58578 .28834 m
.58636 .28855 L
s
.67254 .18475 m
.67302 .1848 L
s
.58562 .28831 m
.5862 .28852 L
s
.26906 .30025 m
.2696 .3 L
s
.67206 .18485 m
.67255 .1849 L
s
.23141 .35735 m
.23182 .35687 L
s
.23143 .35731 m
.23184 .35683 L
s
.5852 .28813 m
.58578 .28834 L
s
.67205 .1847 m
.67254 .18475 L
s
.58504 .2881 m
.58562 .28831 L
s
.2696 .3 m
.27013 .29976 L
s
.67157 .1848 m
.67206 .18485 L
s
.23182 .35687 m
.23223 .35639 L
s
.58462 .28792 m
.5852 .28813 L
s
.67156 .18465 m
.67205 .1847 L
s
.23184 .35683 m
.23225 .35634 L
s
.58446 .28789 m
.58504 .2881 L
s
.27013 .29976 m
.27067 .29951 L
s
.67108 .18475 m
.67157 .1848 L
s
.67107 .1846 m
.67156 .18465 L
s
.58404 .28772 m
.58462 .28792 L
s
.23223 .35639 m
.23264 .3559 L
s
.58388 .28769 m
.58446 .28789 L
s
.27067 .29951 m
.27121 .29926 L
s
.23225 .35634 m
.23266 .35586 L
s
.67059 .1847 m
.67108 .18475 L
s
.67058 .18455 m
.67107 .1846 L
s
.58346 .28751 m
.58404 .28772 L
s
.5833 .28748 m
.58388 .28769 L
s
.67011 .18465 m
.67059 .1847 L
s
.27121 .29926 m
.27175 .29902 L
s
.23264 .3559 m
.23306 .35542 L
s
.23266 .35586 m
.23308 .35538 L
s
.67009 .1845 m
.67058 .18455 L
s
.58288 .28731 m
.58346 .28751 L
s
.58272 .28728 m
.5833 .28748 L
s
.66961 .18461 m
.67011 .18465 L
s
.27175 .29902 m
.27229 .29878 L
s
.23306 .35542 m
.23347 .35494 L
s
.6696 .18446 m
.67009 .1845 L
s
.23308 .35538 m
.23349 .3549 L
s
.58229 .2871 m
.58288 .28731 L
s
.66912 .18456 m
.66961 .18461 L
s
.58213 .28708 m
.58272 .28728 L
s
.27229 .29878 m
.27283 .29853 L
s
.66911 .18441 m
.6696 .18446 L
s
.23347 .35494 m
.23389 .35446 L
s
.58171 .2869 m
.58229 .2871 L
s
.23349 .3549 m
.23391 .35441 L
s
.66863 .18451 m
.66912 .18456 L
s
.58155 .28687 m
.58213 .28708 L
s
.27283 .29853 m
.27337 .29829 L
s
.66862 .18436 m
.66911 .18441 L
s
.58112 .2867 m
.58171 .2869 L
s
.66814 .18447 m
.66863 .18451 L
s
.23389 .35446 m
.23431 .35398 L
s
.58096 .28667 m
.58155 .28687 L
s
.27337 .29829 m
.27391 .29805 L
s
.23391 .35441 m
.23433 .35393 L
s
.66813 .18432 m
.66862 .18436 L
s
.66765 .18442 m
.66814 .18447 L
s
.58054 .2865 m
.58112 .2867 L
s
.58038 .28647 m
.58096 .28667 L
s
.27391 .29805 m
.27446 .29781 L
s
.23431 .35398 m
.23472 .35349 L
s
.66763 .18427 m
.66813 .18432 L
s
.23433 .35393 m
.23475 .35345 L
s
.66715 .18438 m
.66765 .18442 L
s
.57995 .2863 m
.58054 .2865 L
s
.57979 .28627 m
.58038 .28647 L
s
.27446 .29781 m
.275 .29757 L
s
.66714 .18423 m
.66763 .18427 L
s
.23472 .35349 m
.23515 .35301 L
s
.66666 .18433 m
.66715 .18438 L
s
.23475 .35345 m
.23517 .35297 L
s
.57936 .2861 m
.57995 .2863 L
s
.5792 .28607 m
.57979 .28627 L
s
.275 .29757 m
.27555 .29733 L
s
.66665 .18419 m
.66714 .18423 L
s
.66617 .18429 m
.66666 .18433 L
s
.23515 .35301 m
.23557 .35253 L
s
.57877 .2859 m
.57936 .2861 L
s
.23517 .35297 m
.23559 .35249 L
s
.57861 .28587 m
.5792 .28607 L
s
.27555 .29733 m
.2761 .29709 L
s
.66615 .18414 m
.66665 .18419 L
s
.66567 .18425 m
.66617 .18429 L
s
.57818 .2857 m
.57877 .2859 L
s
.57802 .28568 m
.57861 .28587 L
s
.23557 .35253 m
.23599 .35205 L
s
.2761 .29709 m
.27665 .29685 L
s
.66566 .1841 m
.66615 .18414 L
s
.23559 .35249 m
.23601 .35201 L
s
.66517 .18421 m
.66567 .18425 L
s
.57759 .28551 m
.57818 .2857 L
s
.57743 .28548 m
.57802 .28568 L
s
.27665 .29685 m
.2772 .29661 L
s
.66516 .18406 m
.66566 .1841 L
s
.23599 .35205 m
.23641 .35157 L
s
.66468 .18417 m
.66517 .18421 L
s
.23601 .35201 m
.23643 .35153 L
s
.577 .28531 m
.57759 .28551 L
s
.57684 .28528 m
.57743 .28548 L
s
.2772 .29661 m
.27775 .29638 L
s
.66466 .18402 m
.66516 .18406 L
s
.66418 .18412 m
.66468 .18417 L
s
.23641 .35157 m
.23684 .35109 L
s
.23643 .35153 m
.23686 .35105 L
s
.57641 .28511 m
.577 .28531 L
s
.27775 .29638 m
.2783 .29614 L
s
.57624 .28509 m
.57684 .28528 L
s
.66417 .18398 m
.66466 .18402 L
s
.66368 .18408 m
.66418 .18412 L
s
.57581 .28492 m
.57641 .28511 L
s
.23684 .35109 m
.23726 .35061 L
s
.66367 .18394 m
.66417 .18398 L
s
.2783 .29614 m
.27885 .29591 L
s
.57565 .28489 m
.57624 .28509 L
s
.23686 .35105 m
.23729 .35057 L
s
.66319 .18404 m
.66368 .18408 L
s
.57522 .28473 m
.57581 .28492 L
s
.66317 .1839 m
.66367 .18394 L
s
.27885 .29591 m
.2794 .29567 L
s
.57505 .2847 m
.57565 .28489 L
s
.23726 .35061 m
.23769 .35014 L
s
.66269 .18401 m
.66319 .18404 L
s
.23729 .35057 m
.23771 .35009 L
s
.57462 .28453 m
.57522 .28473 L
s
.66267 .18386 m
.66317 .1839 L
s
.2794 .29567 m
.27996 .29544 L
s
.57446 .28451 m
.57505 .2847 L
s
.66219 .18397 m
.66269 .18401 L
s
.23769 .35014 m
.23812 .34966 L
s
.23771 .35009 m
.23814 .34962 L
s
.57403 .28434 m
.57462 .28453 L
s
.66217 .18382 m
.66267 .18386 L
s
.27996 .29544 m
.28051 .29521 L
s
.57386 .28432 m
.57446 .28451 L
s
.66169 .18393 m
.66219 .18397 L
s
.23812 .34966 m
.23855 .34918 L
s
.66167 .18378 m
.66217 .18382 L
s
.57343 .28415 m
.57403 .28434 L
s
.23814 .34962 m
.23857 .34914 L
s
.28051 .29521 m
.28107 .29497 L
s
.57326 .28413 m
.57386 .28432 L
s
.66119 .18389 m
.66169 .18393 L
s
.66117 .18375 m
.66167 .18378 L
s
.57283 .28396 m
.57343 .28415 L
s
.28107 .29497 m
.28163 .29474 L
s
.23855 .34918 m
.23898 .3487 L
s
.57267 .28394 m
.57326 .28413 L
s
.23857 .34914 m
.239 .34866 L
s
.66068 .18386 m
.66119 .18389 L
s
.66067 .18371 m
.66117 .18375 L
s
.57223 .28377 m
.57283 .28396 L
s
.28163 .29474 m
.28219 .29451 L
s
.57207 .28375 m
.57267 .28394 L
s
.66018 .18382 m
.66068 .18386 L
s
.23898 .3487 m
.23941 .34822 L
s
.239 .34866 m
.23944 .34818 L
s
.66017 .18367 m
.66067 .18371 L
s
.57163 .28358 m
.57223 .28377 L
s
.28219 .29451 m
.28275 .29428 L
s
.57147 .28356 m
.57207 .28375 L
s
.65968 .18378 m
.66018 .18382 L
s
.23941 .34822 m
.23985 .34775 L
s
.65966 .18364 m
.66017 .18367 L
s
.23944 .34818 m
.23987 .34771 L
s
.57103 .2834 m
.57163 .28358 L
s
.28275 .29428 m
.28331 .29405 L
s
.57087 .28337 m
.57147 .28356 L
s
.65918 .18375 m
.65968 .18378 L
s
.65916 .1836 m
.65966 .18364 L
s
.57043 .28321 m
.57103 .2834 L
s
.23985 .34775 m
.24028 .34727 L
s
.28331 .29405 m
.28387 .29383 L
s
.57026 .28318 m
.57087 .28337 L
s
.23987 .34771 m
.24031 .34723 L
s
.65867 .18371 m
.65918 .18375 L
s
.65866 .18357 m
.65916 .1836 L
s
.56983 .28302 m
.57043 .28321 L
s
.28387 .29383 m
.28443 .2936 L
s
.56966 .283 m
.57026 .28318 L
s
.65817 .18368 m
.65867 .18371 L
s
.24028 .34727 m
.24072 .34679 L
s
.24031 .34723 m
.24074 .34675 L
s
.65815 .18354 m
.65866 .18357 L
s
.56922 .28284 m
.56983 .28302 L
s
.28443 .2936 m
.285 .29337 L
s
.56906 .28281 m
.56966 .283 L
s
.65766 .18365 m
.65817 .18368 L
s
.24072 .34679 m
.24116 .34632 L
s
.65765 .1835 m
.65815 .18354 L
s
.24074 .34675 m
.24118 .34628 L
s
.56862 .28265 m
.56922 .28284 L
s
.285 .29337 m
.28556 .29315 L
s
.56845 .28263 m
.56906 .28281 L
s
.65716 .18361 m
.65766 .18365 L
s
.65714 .18347 m
.65765 .1835 L
s
.24116 .34632 m
.24159 .34584 L
s
.56801 .28247 m
.56862 .28265 L
s
.28556 .29315 m
.28613 .29292 L
s
.24118 .34628 m
.24162 .3458 L
s
.56785 .28245 m
.56845 .28263 L
s
.65665 .18358 m
.65716 .18361 L
s
.65663 .18344 m
.65714 .18347 L
s
.56741 .28229 m
.56801 .28247 L
s
.28613 .29292 m
.28669 .2927 L
s
.56724 .28227 m
.56785 .28245 L
s
.65614 .18355 m
.65665 .18358 L
s
.24159 .34584 m
.24203 .34537 L
s
.24162 .3458 m
.24206 .34533 L
s
.65613 .18341 m
.65663 .18344 L
s
.5668 .28211 m
.56741 .28229 L
s
.28669 .2927 m
.28726 .29247 L
s
.56663 .28208 m
.56724 .28227 L
s
.65564 .18352 m
.65614 .18355 L
s
.24203 .34537 m
.24247 .34489 L
s
.24206 .34533 m
.2425 .34485 L
s
.65562 .18338 m
.65613 .18341 L
s
.56619 .28193 m
.5668 .28211 L
s
.28726 .29247 m
.28783 .29225 L
s
.56603 .2819 m
.56663 .28208 L
s
.65513 .18349 m
.65564 .18352 L
s
.65511 .18335 m
.65562 .18338 L
s
.24247 .34489 m
.24292 .34442 L
s
.56558 .28175 m
.56619 .28193 L
s
.28783 .29225 m
.2884 .29203 L
s
.2425 .34485 m
.24294 .34438 L
s
.56542 .28172 m
.56603 .2819 L
s
.65462 .18346 m
.65513 .18349 L
s
.6546 .18332 m
.65511 .18335 L
s
.2884 .29203 m
.28897 .29181 L
s
.56497 .28157 m
.56558 .28175 L
s
.56481 .28155 m
.56542 .28172 L
s
.65411 .18343 m
.65462 .18346 L
s
.24292 .34442 m
.24336 .34394 L
s
.24294 .34438 m
.24338 .34391 L
s
.65409 .18329 m
.6546 .18332 L
s
.28897 .29181 m
.28954 .29159 L
s
.56436 .28139 m
.56497 .28157 L
s
.5642 .28137 m
.56481 .28155 L
s
.6536 .1834 m
.65411 .18343 L
s
.24336 .34394 m
.2438 .34347 L
s
.24338 .34391 m
.24383 .34343 L
s
.65358 .18326 m
.65409 .18329 L
s
.28954 .29159 m
.29011 .29137 L
s
.56375 .28121 m
.56436 .28139 L
s
.56359 .28119 m
.5642 .28137 L
s
.65309 .18337 m
.6536 .1834 L
s
.65307 .18323 m
.65358 .18326 L
s
.2438 .34347 m
.24425 .343 L
s
.29011 .29137 m
.29069 .29115 L
s
.56314 .28104 m
.56375 .28121 L
s
.24383 .34343 m
.24428 .34296 L
s
.56298 .28102 m
.56359 .28119 L
s
.65258 .18335 m
.65309 .18337 L
s
.65256 .18321 m
.65307 .18323 L
s
.29069 .29115 m
.29126 .29093 L
s
.56253 .28086 m
.56314 .28104 L
s
.56236 .28084 m
.56298 .28102 L
s
.24425 .343 m
.2447 .34252 L
s
.65207 .18332 m
.65258 .18335 L
s
.24428 .34296 m
.24472 .34249 L
s
.65205 .18318 m
.65256 .18321 L
s
.29126 .29093 m
.29184 .29071 L
s
.56192 .28069 m
.56253 .28086 L
s
.56175 .28067 m
.56236 .28084 L
s
.65156 .18329 m
.65207 .18332 L
s
.2447 .34252 m
.24514 .34205 L
s
.24472 .34249 m
.24517 .34201 L
s
.65154 .18315 m
.65205 .18318 L
s
.29184 .29071 m
.29241 .2905 L
s
.5613 .28051 m
.56192 .28069 L
s
.56113 .28049 m
.56175 .28067 L
s
.65104 .18327 m
.65156 .18329 L
s
.65102 .18313 m
.65154 .18315 L
s
.24514 .34205 m
.24559 .34158 L
s
.29241 .2905 m
.29299 .29028 L
s
.56069 .28034 m
.5613 .28051 L
s
.24517 .34201 m
.24562 .34154 L
s
.56052 .28032 m
.56113 .28049 L
s
.65053 .18324 m
.65104 .18327 L
s
.65051 .1831 m
.65102 .18313 L
s
.29299 .29028 m
.29357 .29007 L
s
.56007 .28017 m
.56069 .28034 L
s
.5599 .28015 m
.56052 .28032 L
s
.24559 .34158 m
.24604 .34111 L
s
.65002 .18322 m
.65053 .18324 L
s
.24562 .34154 m
.24607 .34107 L
s
.65 .18308 m
.65051 .1831 L
s
.29357 .29007 m
.29415 .28985 L
s
.55945 .28 m
.56007 .28017 L
s
.55929 .27998 m
.5599 .28015 L
s
.6495 .1832 m
.65002 .18322 L
s
.24604 .34111 m
.2465 .34064 L
s
.24607 .34107 m
.24652 .3406 L
s
.29415 .28985 m
.29473 .28964 L
s
.64948 .18306 m
.65 .18308 L
s
.55884 .27983 m
.55945 .28 L
s
.55867 .27981 m
.55929 .27998 L
s
.64899 .18317 m
.6495 .1832 L
s
.29473 .28964 m
.29531 .28943 L
s
.2465 .34064 m
.24695 .34017 L
s
.64897 .18303 m
.64948 .18306 L
s
.55822 .27966 m
.55884 .27983 L
s
.24652 .3406 m
.24698 .34013 L
s
.55805 .27964 m
.55867 .27981 L
s
.64847 .18315 m
.64899 .18317 L
s
.29531 .28943 m
.29589 .28922 L
s
.5576 .27949 m
.55822 .27966 L
s
.64845 .18301 m
.64897 .18303 L
s
.55743 .27947 m
.55805 .27964 L
s
.24695 .34017 m
.2474 .3397 L
s
.64795 .18313 m
.64847 .18315 L
s
.24698 .34013 m
.24743 .33966 L
s
.29589 .28922 m
.29648 .28901 L
s
.55698 .27932 m
.5576 .27949 L
s
.64793 .18299 m
.64845 .18301 L
s
.55681 .27931 m
.55743 .27947 L
s
.64744 .18311 m
.64795 .18313 L
s
.2474 .3397 m
.24786 .33923 L
s
.24743 .33966 m
.24788 .33919 L
s
.29648 .28901 m
.29706 .2888 L
s
.55636 .27916 m
.55698 .27932 L
s
.64742 .18297 m
.64793 .18299 L
s
.55619 .27914 m
.55681 .27931 L
s
.64692 .18309 m
.64744 .18311 L
s
.29706 .2888 m
.29764 .28859 L
s
.55574 .27899 m
.55636 .27916 L
s
.24786 .33923 m
.24831 .33876 L
s
.55557 .27897 m
.55619 .27914 L
s
.6469 .18295 m
.64742 .18297 L
s
.24788 .33919 m
.24834 .33872 L
s
.6464 .18307 m
.64692 .18309 L
s
.29764 .28859 m
.29823 .28838 L
s
.55512 .27883 m
.55574 .27899 L
s
.55495 .27881 m
.55557 .27897 L
s
.64638 .18293 m
.6469 .18295 L
s
.24831 .33876 m
.24877 .33829 L
s
.24834 .33872 m
.2488 .33825 L
s
.64588 .18305 m
.6464 .18307 L
s
.29823 .28838 m
.29882 .28817 L
s
.55449 .27866 m
.55512 .27883 L
s
.55432 .27865 m
.55495 .27881 L
s
.64586 .18291 m
.64638 .18293 L
s
.64536 .18303 m
.64588 .18305 L
s
.24877 .33829 m
.24923 .33782 L
s
.29882 .28817 m
.2994 .28797 L
s
.2488 .33825 m
.24926 .33778 L
s
.55387 .2785 m
.55449 .27866 L
s
.5537 .27848 m
.55432 .27865 L
s
.64534 .18289 m
.64586 .18291 L
s
.64484 .18301 m
.64536 .18303 L
s
.2994 .28797 m
.29999 .28776 L
s
.55325 .27834 m
.55387 .2785 L
s
.24923 .33782 m
.24969 .33735 L
s
.55308 .27832 m
.5537 .27848 L
s
.24926 .33778 m
.24972 .33732 L
s
.64482 .18287 m
.64534 .18289 L
s
.64432 .18299 m
.64484 .18301 L
s
.29999 .28776 m
.30058 .28756 L
s
.55262 .27818 m
.55325 .27834 L
s
.55245 .27816 m
.55308 .27832 L
s
.6443 .18286 m
.64482 .18287 L
s
.24969 .33735 m
.25015 .33688 L
s
.24972 .33732 m
.25018 .33685 L
s
.30058 .28756 m
.30117 .28735 L
s
.6438 .18298 m
.64432 .18299 L
s
.552 .27802 m
.55262 .27818 L
s
.55183 .278 m
.55245 .27816 L
s
.64378 .18284 m
.6443 .18286 L
s
.30117 .28735 m
.30176 .28715 L
s
.25015 .33688 m
.25061 .33642 L
s
.64328 .18296 m
.6438 .18298 L
s
.55137 .27786 m
.552 .27802 L
s
.25018 .33685 m
.25064 .33638 L
s
.5512 .27784 m
.55183 .278 L
s
.64326 .18282 m
.64378 .18284 L
s
.30176 .28715 m
.30236 .28695 L
s
.64276 .18294 m
.64328 .18296 L
s
.55074 .2777 m
.55137 .27786 L
s
.55057 .27768 m
.5512 .27784 L
s
.25061 .33642 m
.25107 .33595 L
s
.25064 .33638 m
.2511 .33591 L
s
.64273 .18281 m
.64326 .18282 L
s
.30236 .28695 m
.30295 .28674 L
s
.55011 .27754 m
.55074 .2777 L
s
.64223 .18293 m
.64276 .18294 L
s
.54994 .27753 m
.55057 .27768 L
s
.25107 .33595 m
.25154 .33548 L
s
.64221 .18279 m
.64273 .18281 L
s
.30295 .28674 m
.30354 .28654 L
s
.2511 .33591 m
.25157 .33545 L
s
.54948 .27739 m
.55011 .27754 L
s
.54931 .27737 m
.54994 .27753 L
s
.64171 .18292 m
.64223 .18293 L
s
.64169 .18278 m
.64221 .18279 L
s
.30354 .28654 m
.30414 .28634 L
s
.54885 .27723 m
.54948 .27739 L
s
.25154 .33548 m
.252 .33502 L
s
.54868 .27722 m
.54931 .27737 L
s
.64119 .1829 m
.64171 .18292 L
s
.25157 .33545 m
.25203 .33498 L
s
.30414 .28634 m
.30473 .28614 L
s
.64116 .18277 m
.64169 .18278 L
s
.54822 .27708 m
.54885 .27723 L
s
.54805 .27706 m
.54868 .27722 L
s
.64066 .18289 m
.64119 .1829 L
s
.252 .33502 m
.25247 .33455 L
s
.25203 .33498 m
.2525 .33452 L
s
.30473 .28614 m
.30533 .28595 L
s
.64064 .18275 m
.64116 .18277 L
s
.54759 .27692 m
.54822 .27708 L
s
.54742 .27691 m
.54805 .27706 L
s
.64014 .18288 m
.64066 .18289 L
s
.30533 .28595 m
.30593 .28575 L
s
.25247 .33455 m
.25294 .33409 L
s
.54696 .27677 m
.54759 .27692 L
s
.64011 .18274 m
.64064 .18275 L
s
.2525 .33452 m
.25297 .33405 L
s
.54679 .27675 m
.54742 .27691 L
s
.63961 .18286 m
.64014 .18288 L
s
.30593 .28575 m
.30653 .28555 L
s
.54633 .27662 m
.54696 .27677 L
s
.54616 .2766 m
.54679 .27675 L
s
.63959 .18273 m
.64011 .18274 L
s
.25294 .33409 m
.25341 .33362 L
s
.25297 .33405 m
.25344 .33359 L
s
.63908 .18285 m
.63961 .18286 L
s
.30653 .28555 m
.30713 .28536 L
s
.5457 .27647 m
.54633 .27662 L
s
.54553 .27645 m
.54616 .2766 L
s
.63906 .18272 m
.63959 .18273 L
s
.63856 .18284 m
.63908 .18285 L
s
.30713 .28536 m
.30773 .28516 L
s
.25341 .33362 m
.25388 .33316 L
s
.25344 .33359 m
.25391 .33312 L
s
.54506 .27632 m
.5457 .27647 L
s
.54489 .2763 m
.54553 .27645 L
s
.63853 .18271 m
.63906 .18272 L
s
.30773 .28516 m
.30833 .28497 L
s
.63803 .18283 m
.63856 .18284 L
s
.54443 .27617 m
.54506 .27632 L
s
.54426 .27615 m
.54489 .2763 L
s
.25388 .33316 m
.25435 .33269 L
s
.25391 .33312 m
.25438 .33266 L
s
.63801 .1827 m
.63853 .18271 L
s
.30833 .28497 m
.30893 .28477 L
s
.6375 .18282 m
.63803 .18283 L
s
.54379 .27602 m
.54443 .27617 L
s
.54362 .27601 m
.54426 .27615 L
s
.63748 .18269 m
.63801 .1827 L
s
.25435 .33269 m
.25482 .33223 L
s
.30893 .28477 m
.30953 .28458 L
s
.25438 .33266 m
.25485 .3322 L
s
.54316 .27587 m
.54379 .27602 L
s
.63697 .18281 m
.6375 .18282 L
s
.54299 .27586 m
.54362 .27601 L
s
.63695 .18268 m
.63748 .18269 L
s
.30953 .28458 m
.31014 .28439 L
s
.54252 .27572 m
.54316 .27587 L
s
.25482 .33223 m
.25529 .33177 L
s
.54235 .27571 m
.54299 .27586 L
s
.63644 .18281 m
.63697 .18281 L
s
.25485 .3322 m
.25532 .33173 L
s
.31014 .28439 m
.31074 .2842 L
s
.63642 .18267 m
.63695 .18268 L
s
.54188 .27558 m
.54252 .27572 L
s
.54171 .27557 m
.54235 .27571 L
s
.63591 .1828 m
.63644 .18281 L
s
.25529 .33177 m
.25577 .3313 L
s
.31074 .2842 m
.31134 .28401 L
s
.25532 .33173 m
.2558 .33127 L
s
.63589 .18266 m
.63642 .18267 L
s
.54125 .27543 m
.54188 .27558 L
s
.54107 .27542 m
.54171 .27557 L
s
.63538 .18279 m
.63591 .1828 L
s
.31134 .28401 m
.31195 .28382 L
s
.25577 .3313 m
.25624 .33084 L
s
.54061 .27529 m
.54125 .27543 L
s
.63536 .18266 m
.63589 .18266 L
s
.54043 .27528 m
.54107 .27542 L
s
.2558 .33127 m
.25627 .33081 L
s
.63485 .18278 m
.63538 .18279 L
s
.31195 .28382 m
.31256 .28363 L
s
.53997 .27515 m
.54061 .27529 L
s
.5398 .27514 m
.54043 .27528 L
s
.63483 .18265 m
.63536 .18266 L
s
.25624 .33084 m
.25672 .33038 L
s
.63432 .18278 m
.63485 .18278 L
s
.25627 .33081 m
.25675 .33035 L
s
.31256 .28363 m
.31317 .28344 L
s
.53933 .27501 m
.53997 .27515 L
s
.53916 .27499 m
.5398 .27514 L
s
.6343 .18265 m
.63483 .18265 L
s
.31317 .28344 m
.31377 .28326 L
s
.63379 .18277 m
.63432 .18278 L
s
.25672 .33038 m
.25719 .32992 L
s
.53869 .27486 m
.53933 .27501 L
s
.53851 .27485 m
.53916 .27499 L
s
.25675 .33035 m
.25723 .32989 L
s
.63376 .18264 m
.6343 .18265 L
s
.31377 .28326 m
.31438 .28307 L
s
.63326 .18277 m
.63379 .18277 L
s
.53805 .27472 m
.53869 .27486 L
s
.53787 .27471 m
.53851 .27485 L
s
.25719 .32992 m
.25767 .32946 L
s
.25723 .32989 m
.25771 .32943 L
s
.63323 .18264 m
.63376 .18264 L
s
.31438 .28307 m
.31499 .28289 L
s
.5374 .27459 m
.53805 .27472 L
s
.63272 .18277 m
.63326 .18277 L
s
.53723 .27458 m
.53787 .27471 L
s
.31499 .28289 m
.3156 .2827 L
s
.6327 .18263 m
.63323 .18264 L
s
.25767 .32946 m
.25815 .329 L
s
.53676 .27445 m
.5374 .27459 L
s
.25771 .32943 m
.25819 .32897 L
s
.53659 .27444 m
.53723 .27458 L
s
.63219 .18276 m
.63272 .18277 L
s
.3156 .2827 m
.31622 .28252 L
s
.63216 .18263 m
.6327 .18263 L
s
.53612 .27431 m
.53676 .27445 L
s
.53595 .2743 m
.53659 .27444 L
s
.25815 .329 m
.25863 .32854 L
s
.63165 .18276 m
.63219 .18276 L
s
.25819 .32897 m
.25867 .32851 L
s
.31622 .28252 m
.31683 .28234 L
s
.53548 .27417 m
.53612 .27431 L
s
.63163 .18263 m
.63216 .18263 L
s
.5353 .27417 m
.53595 .2743 L
s
.63112 .18276 m
.63165 .18276 L
s
.31683 .28234 m
.31744 .28216 L
s
.25863 .32854 m
.25911 .32808 L
s
.53483 .27404 m
.53548 .27417 L
s
.25867 .32851 m
.25915 .32805 L
s
.53466 .27403 m
.5353 .27417 L
s
.63109 .18263 m
.63163 .18263 L
s
.31744 .28216 m
.31806 .28198 L
s
.63058 .18276 m
.63112 .18276 L
s
.53419 .2739 m
.53483 .27404 L
s
.53401 .2739 m
.53466 .27403 L
s
.25911 .32808 m
.2596 .32762 L
s
.63056 .18263 m
.63109 .18263 L
s
.25915 .32805 m
.25963 .32759 L
s
.31806 .28198 m
.31867 .2818 L
s
.63005 .18276 m
.63058 .18276 L
s
.53354 .27377 m
.53419 .2739 L
s
.53337 .27376 m
.53401 .2739 L
s
.63002 .18263 m
.63056 .18263 L
s
.31867 .2818 m
.31929 .28162 L
s
.2596 .32762 m
.26008 .32716 L
s
.53289 .27364 m
.53354 .27377 L
s
.53272 .27363 m
.53337 .27376 L
s
.62951 .18276 m
.63005 .18276 L
s
.25963 .32759 m
.26012 .32713 L
s
.31929 .28162 m
.3199 .28144 L
s
.62948 .18263 m
.63002 .18263 L
s
.53225 .27351 m
.53289 .27364 L
s
.53207 .2735 m
.53272 .27363 L
s
.62897 .18276 m
.62951 .18276 L
s
.26008 .32716 m
.26057 .32671 L
s
.3199 .28144 m
.32052 .28126 L
s
.26012 .32713 m
.2606 .32668 L
s
.5316 .27338 m
.53225 .27351 L
s
.62895 .18263 m
.62948 .18263 L
s
.53142 .27337 m
.53207 .2735 L
s
.62844 .18276 m
.62897 .18276 L
s
.32052 .28126 m
.32114 .28109 L
s
.26057 .32671 m
.26105 .32625 L
s
.53095 .27325 m
.5316 .27338 L
s
.53078 .27324 m
.53142 .27337 L
s
.2606 .32668 m
.26109 .32622 L
s
.62841 .18263 m
.62895 .18263 L
s
.32114 .28109 m
.32176 .28091 L
s
.6279 .18276 m
.62844 .18276 L
s
.5303 .27312 m
.53095 .27325 L
s
.53013 .27311 m
.53078 .27324 L
s
.62787 .18263 m
.62841 .18263 L
s
.26105 .32625 m
.26154 .32579 L
s
.32176 .28091 m
.32238 .28074 L
s
.26109 .32622 m
.26157 .32576 L
s
.62736 .18276 m
.6279 .18276 L
s
.52965 .27299 m
.5303 .27312 L
s
.52948 .27298 m
.53013 .27311 L
s
.32238 .28074 m
.323 .28057 L
s
.62733 .18263 m
.62787 .18263 L
s
.529 .27286 m
.52965 .27299 L
s
.26154 .32579 m
.26203 .32534 L
s
.52883 .27286 m
.52948 .27298 L
s
.62682 .18277 m
.62736 .18276 L
s
.26157 .32576 m
.26206 .32531 L
s
.323 .28057 m
.32362 .28039 L
s
.62679 .18264 m
.62733 .18263 L
s
.52835 .27274 m
.529 .27286 L
s
.52818 .27273 m
.52883 .27286 L
s
.62628 .18277 m
.62682 .18277 L
s
.32362 .28039 m
.32424 .28022 L
s
.26203 .32534 m
.26252 .32488 L
s
.26206 .32531 m
.26255 .32485 L
s
.5277 .27261 m
.52835 .27274 L
s
.62625 .18264 m
.62679 .18264 L
s
.52753 .27261 m
.52818 .27273 L
s
.62574 .18278 m
.62628 .18277 L
s
.32424 .28022 m
.32487 .28005 L
s
.52705 .27249 m
.5277 .27261 L
s
.52687 .27248 m
.52753 .27261 L
s
.26252 .32488 m
.26301 .32442 L
s
.62571 .18265 m
.62625 .18264 L
s
.26255 .32485 m
.26304 .3244 L
s
.32487 .28005 m
.32549 .27988 L
s
.6252 .18278 m
.62574 .18278 L
s
.5264 .27237 m
.52705 .27249 L
s
.52622 .27236 m
.52687 .27248 L
s
.62517 .18265 m
.62571 .18265 L
s
.32549 .27988 m
.32611 .27971 L
s
.26301 .32442 m
.2635 .32397 L
s
.26304 .3244 m
.26353 .32394 L
s
.52574 .27224 m
.5264 .27237 L
s
.62466 .18279 m
.6252 .18278 L
s
.52557 .27224 m
.52622 .27236 L
s
.32611 .27971 m
.32674 .27954 L
s
.62463 .18266 m
.62517 .18265 L
s
.52509 .27212 m
.52574 .27224 L
s
.52491 .27212 m
.52557 .27224 L
s
.62411 .18279 m
.62466 .18279 L
s
.2635 .32397 m
.26399 .32352 L
s
.32674 .27954 m
.32736 .27938 L
s
.26353 .32394 m
.26403 .32349 L
s
.52444 .272 m
.52509 .27212 L
s
.62408 .18267 m
.62463 .18266 L
s
.52426 .272 m
.52491 .27212 L
s
.32736 .27938 m
.32799 .27921 L
s
.62357 .1828 m
.62411 .18279 L
s
.26399 .32352 m
.26448 .32306 L
s
.52378 .27188 m
.52444 .272 L
s
.52361 .27188 m
.52426 .272 L
s
.26403 .32349 m
.26452 .32303 L
s
.62354 .18267 m
.62408 .18267 L
s
.32799 .27921 m
.32862 .27904 L
s
.62303 .18281 m
.62357 .1828 L
s
.52313 .27177 m
.52378 .27188 L
s
.52295 .27176 m
.52361 .27188 L
s
.32862 .27904 m
.32925 .27888 L
s
.623 .18268 m
.62354 .18267 L
s
.26448 .32306 m
.26498 .32261 L
s
.26452 .32303 m
.26501 .32258 L
s
.52247 .27165 m
.52313 .27177 L
s
.52229 .27164 m
.52295 .27176 L
s
.62248 .18282 m
.62303 .18281 L
s
.32925 .27888 m
.32987 .27872 L
s
.62245 .18269 m
.623 .18268 L
s
.52182 .27153 m
.52247 .27165 L
s
.52164 .27153 m
.52229 .27164 L
s
.26498 .32261 m
.26547 .32216 L
s
.62194 .18283 m
.62248 .18282 L
s
.26501 .32258 m
.26551 .32213 L
s
.32987 .27872 m
.3305 .27855 L
s
.52116 .27142 m
.52182 .27153 L
s
.52098 .27141 m
.52164 .27153 L
s
.62191 .1827 m
.62245 .18269 L
s
.3305 .27855 m
.33113 .27839 L
s
.62139 .18284 m
.62194 .18283 L
s
.26547 .32216 m
.26597 .3217 L
s
.5205 .2713 m
.52116 .27142 L
s
.26551 .32213 m
.26601 .32168 L
s
.52032 .2713 m
.52098 .27141 L
s
.62136 .18271 m
.62191 .1827 L
s
.33113 .27839 m
.33176 .27823 L
s
.62085 .18285 m
.62139 .18284 L
s
.51984 .27119 m
.5205 .2713 L
s
.51967 .27119 m
.52032 .2713 L
s
.26597 .3217 m
.26647 .32125 L
s
.33176 .27823 m
.3324 .27807 L
s
.26601 .32168 m
.2665 .32122 L
s
.62082 .18272 m
.62136 .18271 L
s
.51918 .27108 m
.51984 .27119 L
s
.51901 .27107 m
.51967 .27119 L
s
.6203 .18286 m
.62085 .18285 L
s
.3324 .27807 m
.33303 .27791 L
s
.51853 .27096 m
.51918 .27108 L
s
.62027 .18273 m
.62082 .18272 L
s
.51835 .27096 m
.51901 .27107 L
s
.26647 .32125 m
.26697 .3208 L
s
.2665 .32122 m
.267 .32077 L
s
.33303 .27791 m
.33366 .27775 L
s
.61975 .18287 m
.6203 .18286 L
s
.51787 .27085 m
.51853 .27096 L
s
.51769 .27085 m
.51835 .27096 L
s
.61972 .18274 m
.62027 .18273 L
s
.33366 .27775 m
.3343 .2776 L
s
.26697 .3208 m
.26747 .32035 L
s
.61921 .18288 m
.61975 .18287 L
s
.51721 .27074 m
.51787 .27085 L
s
.267 .32077 m
.2675 .32032 L
s
.51703 .27074 m
.51769 .27085 L
s
.3343 .2776 m
.33493 .27744 L
s
.61918 .18276 m
.61972 .18274 L
s
.51655 .27064 m
.51721 .27074 L
s
.51637 .27063 m
.51703 .27074 L
s
.61866 .18289 m
.61921 .18288 L
s
.33493 .27744 m
.33557 .27728 L
s
.26747 .32035 m
.26797 .3199 L
s
.2675 .32032 m
.268 .31987 L
s
.51588 .27053 m
.51655 .27064 L
s
.61863 .18277 m
.61918 .18276 L
s
.51571 .27053 m
.51637 .27063 L
s
.33557 .27728 m
.3362 .27713 L
s
.61811 .18291 m
.61866 .18289 L
s
.51522 .27042 m
.51588 .27053 L
s
.51504 .27042 m
.51571 .27053 L
s
.26797 .3199 m
.26847 .31945 L
s
.61808 .18278 m
.61863 .18277 L
s
.268 .31987 m
.26851 .31942 L
s
.3362 .27713 m
.33684 .27698 L
s
.61756 .18292 m
.61811 .18291 L
s
.51456 .27032 m
.51522 .27042 L
s
.51438 .27031 m
.51504 .27042 L
s
.33684 .27698 m
.33747 .27682 L
s
.61753 .1828 m
.61808 .18278 L
s
.26847 .31945 m
.26897 .319 L
s
.5139 .27021 m
.51456 .27032 L
s
.51372 .27021 m
.51438 .27031 L
s
.26851 .31942 m
.26901 .31898 L
s
.61701 .18294 m
.61756 .18292 L
s
.33747 .27682 m
.33811 .27667 L
s
.51324 .27011 m
.5139 .27021 L
s
.51306 .27011 m
.51372 .27021 L
s
.61698 .18281 m
.61753 .1828 L
s
.33811 .27667 m
.33875 .27652 L
s
.61646 .18295 m
.61701 .18294 L
s
.26897 .319 m
.26948 .31855 L
s
.26901 .31898 m
.26951 .31853 L
s
.51257 .27 m
.51324 .27011 L
s
.51239 .27 m
.51306 .27011 L
s
.33875 .27652 m
.33939 .27637 L
s
.61643 .18283 m
.61698 .18281 L
s
.51191 .2699 m
.51257 .27 L
s
.61591 .18297 m
.61646 .18295 L
s
.51173 .2699 m
.51239 .27 L
s
.26948 .31855 m
.26998 .3181 L
s
.33939 .27637 m
.34003 .27622 L
s
.26951 .31853 m
.27002 .31808 L
s
.61588 .18285 m
.61643 .18283 L
s
.51124 .2698 m
.51191 .2699 L
s
.51106 .2698 m
.51173 .2699 L
s
.34003 .27622 m
.34067 .27607 L
s
.61536 .18299 m
.61591 .18297 L
s
.51058 .2697 m
.51124 .2698 L
s
.5104 .2697 m
.51106 .2698 L
s
.26998 .3181 m
.27049 .31766 L
s
.61533 .18286 m
.61588 .18285 L
s
.27002 .31808 m
.27052 .31763 L
s
.34067 .27607 m
.34131 .27592 L
s
.61481 .183 m
.61536 .18299 L
s
.50991 .2696 m
.51058 .2697 L
s
.50973 .2696 m
.5104 .2697 L
s
.34131 .27592 m
.34195 .27578 L
s
.61478 .18288 m
.61533 .18286 L
s
.50925 .2695 m
.50991 .2696 L
s
.27049 .31766 m
.27099 .31721 L
s
.50907 .2695 m
.50973 .2696 L
s
.27052 .31763 m
.27103 .31719 L
s
.61426 .18302 m
.61481 .183 L
s
.34195 .27578 m
.3426 .27563 L
s
.50858 .26941 m
.50925 .2695 L
s
.5084 .26941 m
.50907 .2695 L
s
.61422 .1829 m
.61478 .18288 L
s
.3426 .27563 m
.34324 .27549 L
s
.6137 .18304 m
.61426 .18302 L
s
.27099 .31721 m
.2715 .31676 L
s
.50791 .26931 m
.50858 .26941 L
s
.27103 .31719 m
.27154 .31674 L
s
.50773 .26931 m
.5084 .26941 L
s
.34324 .27549 m
.34388 .27534 L
s
.61367 .18292 m
.61422 .1829 L
s
.50725 .26922 m
.50791 .26931 L
s
.50707 .26922 m
.50773 .26931 L
s
.61315 .18306 m
.6137 .18304 L
s
.34388 .27534 m
.34453 .2752 L
s
.2715 .31676 m
.27201 .31632 L
s
.27154 .31674 m
.27205 .31629 L
s
.50658 .26912 m
.50725 .26922 L
s
.61312 .18294 m
.61367 .18292 L
s
.5064 .26912 m
.50707 .26922 L
s
.34453 .2752 m
.34517 .27506 L
s
.6126 .18308 m
.61315 .18306 L
s
.50591 .26903 m
.50658 .26912 L
s
.50573 .26903 m
.5064 .26912 L
s
.34517 .27506 m
.34582 .27492 L
s
.27201 .31632 m
.27252 .31587 L
s
.61256 .18296 m
.61312 .18294 L
s
.27205 .31629 m
.27256 .31585 L
s
.50524 .26894 m
.50591 .26903 L
s
.50506 .26894 m
.50573 .26903 L
s
.61204 .1831 m
.6126 .18308 L
s
.34582 .27492 m
.34646 .27478 L
s
.61201 .18298 m
.61256 .18296 L
s
.50457 .26884 m
.50524 .26894 L
s
.50439 .26885 m
.50506 .26894 L
s
.27252 .31587 m
.27303 .31543 L
s
.34646 .27478 m
.34711 .27464 L
s
.27256 .31585 m
.27307 .3154 L
s
.61149 .18312 m
.61204 .1831 L
s
.5039 .26875 m
.50457 .26884 L
s
.50372 .26876 m
.50439 .26885 L
s
.34711 .27464 m
.34776 .2745 L
s
.61145 .183 m
.61201 .18298 L
s
.50323 .26867 m
.5039 .26875 L
s
.50305 .26867 m
.50372 .26876 L
s
.61093 .18315 m
.61149 .18312 L
s
.27303 .31543 m
.27354 .31498 L
s
.34776 .2745 m
.34841 .27436 L
s
.27307 .3154 m
.27358 .31496 L
s
.6109 .18303 m
.61145 .183 L
s
.50256 .26858 m
.50323 .26867 L
s
.50238 .26858 m
.50305 .26867 L
s
.34841 .27436 m
.34905 .27423 L
s
.61038 .18317 m
.61093 .18315 L
s
.50189 .26849 m
.50256 .26858 L
s
.50171 .26849 m
.50238 .26858 L
s
.27354 .31498 m
.27405 .31454 L
s
.27358 .31496 m
.27409 .31452 L
s
.34905 .27423 m
.3497 .27409 L
s
.61034 .18305 m
.6109 .18303 L
s
.50122 .2684 m
.50189 .26849 L
s
.50104 .26841 m
.50171 .26849 L
s
.60982 .18319 m
.61038 .18317 L
s
.3497 .27409 m
.35035 .27396 L
s
.50055 .26832 m
.50122 .2684 L
s
.50037 .26832 m
.50104 .26841 L
s
.27405 .31454 m
.27457 .3141 L
s
.60978 .18307 m
.61034 .18305 L
s
.27409 .31452 m
.27461 .31407 L
s
.35035 .27396 m
.351 .27382 L
s
.60926 .18322 m
.60982 .18319 L
s
.49988 .26823 m
.50055 .26832 L
s
.4997 .26824 m
.50037 .26832 L
s
.351 .27382 m
.35166 .27369 L
s
.60923 .1831 m
.60978 .18307 L
s
.4992 .26815 m
.49988 .26823 L
s
.27457 .3141 m
.27508 .31365 L
s
.49902 .26816 m
.4997 .26824 L
s
.27461 .31407 m
.27512 .31363 L
s
.6087 .18324 m
.60926 .18322 L
s
.35166 .27369 m
.35231 .27356 L
s
.49853 .26807 m
.4992 .26815 L
s
.49835 .26807 m
.49902 .26816 L
s
.60867 .18312 m
.60923 .1831 L
s
.35231 .27356 m
.35296 .27343 L
s
.60815 .18327 m
.6087 .18324 L
s
.49786 .26799 m
.49853 .26807 L
s
.27508 .31365 m
.2756 .31321 L
s
.49768 .26799 m
.49835 .26807 L
s
.27512 .31363 m
.27564 .31319 L
s
.35296 .27343 m
.35361 .2733 L
s
.60811 .18315 m
.60867 .18312 L
s
.49718 .26791 m
.49786 .26799 L
s
.497 .26791 m
.49768 .26799 L
s
.35361 .2733 m
.35427 .27317 L
s
.60759 .1833 m
.60815 .18327 L
s
.49651 .26783 m
.49718 .26791 L
s
.2756 .31321 m
.27611 .31277 L
s
.49633 .26783 m
.497 .26791 L
s
.27564 .31319 m
.27615 .31275 L
s
.35427 .27317 m
.35492 .27304 L
s
.60755 .18318 m
.60811 .18315 L
s
.49584 .26775 m
.49651 .26783 L
s
.49565 .26775 m
.49633 .26783 L
s
.60703 .18332 m
.60759 .1833 L
s
.35492 .27304 m
.35557 .27292 L
s
.49516 .26767 m
.49584 .26775 L
s
.49498 .26768 m
.49565 .26775 L
s
.60699 .1832 m
.60755 .18318 L
s
.27611 .31277 m
.27663 .31233 L
s
.27615 .31275 m
.27667 .31231 L
s
.35557 .27292 m
.35623 .27279 L
s
.60647 .18335 m
.60703 .18332 L
s
.49449 .26759 m
.49516 .26767 L
s
.4943 .2676 m
.49498 .26768 L
s
.35623 .27279 m
.35688 .27266 L
s
.60643 .18323 m
.60699 .1832 L
s
.49381 .26752 m
.49449 .26759 L
s
.49363 .26753 m
.4943 .2676 L
s
.27663 .31233 m
.27715 .31189 L
s
.35688 .27266 m
.35754 .27254 L
s
.27667 .31231 m
.27719 .31187 L
s
.60591 .18338 m
.60647 .18335 L
s
.49313 .26744 m
.49381 .26752 L
s
.49295 .26745 m
.49363 .26753 L
s
.35754 .27254 m
.3582 .27242 L
s
.60587 .18326 m
.60643 .18323 L
s
.49246 .26737 m
.49313 .26744 L
s
.49228 .26738 m
.49295 .26745 L
s
.60535 .18341 m
.60591 .18338 L
s
.27715 .31189 m
.27767 .31145 L
s
.3582 .27242 m
.35885 .27229 L
s
.27719 .31187 m
.27771 .31143 L
s
.49178 .2673 m
.49246 .26737 L
s
.4916 .26731 m
.49228 .26738 L
s
.60531 .18329 m
.60587 .18326 L
s
.35885 .27229 m
.35951 .27217 L
s
.60479 .18344 m
.60535 .18341 L
s
.4911 .26723 m
.49178 .2673 L
s
.49092 .26723 m
.4916 .26731 L
s
.35951 .27217 m
.36017 .27205 L
s
.27767 .31145 m
.27819 .31101 L
s
.27771 .31143 m
.27823 .31099 L
s
.60475 .18332 m
.60531 .18329 L
s
.49043 .26716 m
.4911 .26723 L
s
.49025 .26716 m
.49092 .26723 L
s
.36017 .27205 m
.36083 .27193 L
s
.60422 .18347 m
.60479 .18344 L
s
.48975 .26709 m
.49043 .26716 L
s
.48957 .2671 m
.49025 .26716 L
s
.36083 .27193 m
.36149 .27182 L
s
.27819 .31101 m
.27871 .31057 L
s
.60419 .18335 m
.60475 .18332 L
s
.27823 .31099 m
.27875 .31055 L
s
.48907 .26702 m
.48975 .26709 L
s
.48889 .26703 m
.48957 .2671 L
s
.36149 .27182 m
.36215 .2717 L
s
.60366 .1835 m
.60422 .18347 L
s
.48839 .26695 m
.48907 .26702 L
s
.48821 .26696 m
.48889 .26703 L
s
.36215 .2717 m
.36281 .27158 L
s
.60363 .18338 m
.60419 .18335 L
s
.27871 .31057 m
.27923 .31013 L
s
.48753 .26689 m
.48821 .26696 L
s
.48771 .26688 m
.48839 .26695 L
s
.27875 .31055 m
.27927 .31011 L
s
.6031 .18353 m
.60366 .1835 L
s
.36281 .27158 m
.36347 .27147 L
s
.48685 .26683 m
.48753 .26689 L
s
.48704 .26682 m
.48771 .26688 L
s
.60306 .18341 m
.60363 .18338 L
s
.36347 .27147 m
.36413 .27135 L
s
.60254 .18356 m
.6031 .18353 L
s
.48617 .26676 m
.48685 .26683 L
s
.48636 .26675 m
.48704 .26682 L
s
.27923 .31013 m
.27975 .30969 L
s
.36413 .27135 m
.36479 .27124 L
s
.27927 .31011 m
.27979 .30967 L
s
.4855 .2667 m
.48617 .26676 L
s
.48568 .26669 m
.48636 .26675 L
s
.6025 .18345 m
.60306 .18341 L
s
.36479 .27124 m
.36546 .27112 L
s
.60197 .1836 m
.60254 .18356 L
s
.48482 .26664 m
.4855 .2667 L
s
.485 .26663 m
.48568 .26669 L
s
.36546 .27112 m
.36612 .27101 L
s
.27975 .30969 m
.28028 .30926 L
s
.27979 .30967 m
.28032 .30924 L
s
.60194 .18348 m
.6025 .18345 L
s
.48413 .26658 m
.48482 .26664 L
s
.48432 .26657 m
.485 .26663 L
s
.36612 .27101 m
.36678 .2709 L
s
.60141 .18363 m
.60197 .1836 L
s
.48345 .26652 m
.48413 .26658 L
s
.48364 .26651 m
.48432 .26657 L
s
.36678 .2709 m
.36745 .27079 L
s
.28028 .30926 m
.2808 .30882 L
s
.60137 .18352 m
.60194 .18348 L
s
.48277 .26646 m
.48345 .26652 L
s
.48296 .26645 m
.48364 .26651 L
s
.28032 .30924 m
.28084 .3088 L
s
.36745 .27079 m
.36811 .27068 L
s
.60084 .18367 m
.60141 .18363 L
s
.48209 .2664 m
.48277 .26646 L
s
.48227 .26639 m
.48296 .26645 L
s
.36811 .27068 m
.36878 .27057 L
s
.60081 .18355 m
.60137 .18352 L
s
.48141 .26634 m
.48209 .2664 L
s
.48159 .26633 m
.48227 .26639 L
s
.2808 .30882 m
.28133 .30839 L
s
.36878 .27057 m
.36944 .27047 L
s
.28084 .3088 m
.28137 .30837 L
s
.60028 .1837 m
.60084 .18367 L
s
.48073 .26629 m
.48141 .26634 L
s
.48091 .26627 m
.48159 .26633 L
s
.36944 .27047 m
.37011 .27036 L
s
.60024 .18359 m
.60081 .18355 L
s
.48005 .26623 m
.48073 .26629 L
s
.48023 .26622 m
.48091 .26627 L
s
.37011 .27036 m
.37077 .27026 L
s
.59971 .18374 m
.60028 .1837 L
s
.28133 .30839 m
.28185 .30795 L
s
.47937 .26618 m
.48005 .26623 L
s
.28137 .30837 m
.2819 .30793 L
s
.47955 .26616 m
.48023 .26622 L
s
.37077 .27026 m
.37144 .27015 L
s
.59967 .18362 m
.60024 .18359 L
s
.47868 .26612 m
.47937 .26618 L
s
.47887 .26611 m
.47955 .26616 L
s
.37144 .27015 m
.37211 .27005 L
s
.59915 .18377 m
.59971 .18374 L
s
.478 .26607 m
.47868 .26612 L
s
.47818 .26606 m
.47887 .26611 L
s
.37211 .27005 m
.37278 .26995 L
s
.28185 .30795 m
.28238 .30752 L
s
.2819 .30793 m
.28242 .3075 L
s
.47732 .26602 m
.478 .26607 L
s
.59911 .18366 m
.59967 .18362 L
s
.4775 .26601 m
.47818 .26606 L
s
.37278 .26995 m
.37344 .26985 L
s
.59858 .18381 m
.59915 .18377 L
s
.47663 .26597 m
.47732 .26602 L
s
.47682 .26596 m
.4775 .26601 L
s
.37344 .26985 m
.37411 .26975 L
s
.28238 .30752 m
.28291 .30708 L
s
.47595 .26592 m
.47663 .26597 L
s
.47613 .26591 m
.47682 .26596 L
s
.59854 .1837 m
.59911 .18366 L
s
.28242 .3075 m
.28295 .30706 L
s
.37411 .26975 m
.37478 .26965 L
s
.47527 .26587 m
.47595 .26592 L
s
.59801 .18385 m
.59858 .18381 L
s
.47545 .26586 m
.47613 .26591 L
s
.37478 .26965 m
.37545 .26955 L
s
.47458 .26582 m
.47527 .26587 L
s
.47476 .26581 m
.47545 .26586 L
s
.37545 .26955 m
.37612 .26945 L
s
.59797 .18373 m
.59854 .1837 L
s
.28291 .30708 m
.28344 .30665 L
s
.28295 .30706 m
.28348 .30663 L
s
.47408 .26576 m
.47476 .26581 L
s
.59744 .18389 m
.59801 .18385 L
s
.37612 .26945 m
.37679 .26935 L
s
.4734 .26572 m
.47408 .26576 L
s
.37679 .26935 m
.37746 .26926 L
s
.59741 .18377 m
.59797 .18373 L
s
.47271 .26567 m
.4734 .26572 L
s
.37746 .26926 m
.37813 .26916 L
s
.28344 .30665 m
.28397 .30621 L
s
.59687 .18393 m
.59744 .18389 L
s
.28348 .30663 m
.28401 .3062 L
s
.47203 .26563 m
.47271 .26567 L
s
.37813 .26916 m
.3788 .26907 L
s
.59684 .18381 m
.59741 .18377 L
s
.47134 .26559 m
.47203 .26563 L
s
.3788 .26907 m
.37948 .26898 L
s
.59631 .18397 m
.59687 .18393 L
s
.47066 .26554 m
.47134 .26559 L
s
.37948 .26898 m
.38015 .26889 L
s
.28397 .30621 m
.2845 .30578 L
s
.28401 .3062 m
.28454 .30576 L
s
.46997 .2655 m
.47066 .26554 L
s
.38015 .26889 m
.38082 .2688 L
s
.59627 .18385 m
.59684 .18381 L
s
.46929 .26546 m
.46997 .2655 L
s
.38082 .2688 m
.38149 .26871 L
s
.59574 .18401 m
.59631 .18397 L
s
.4686 .26543 m
.46929 .26546 L
s
.38149 .26871 m
.38217 .26862 L
s
.2845 .30578 m
.28503 .30535 L
s
.28454 .30576 m
.28508 .30533 L
s
.5957 .1839 m
.59627 .18385 L
s
.46791 .26539 m
.4686 .26543 L
s
.38217 .26862 m
.38284 .26853 L
s
.59517 .18405 m
.59574 .18401 L
s
.46723 .26535 m
.46791 .26539 L
s
.38284 .26853 m
.38352 .26844 L
s
.46654 .26532 m
.46723 .26535 L
s
.38352 .26844 m
.38419 .26836 L
s
.59513 .18394 m
.5957 .1839 L
s
.28503 .30535 m
.28557 .30492 L
s
.28508 .30533 m
.28561 .3049 L
s
.46585 .26528 m
.46654 .26532 L
s
.38419 .26836 m
.38487 .26827 L
s
.5946 .18409 m
.59517 .18405 L
s
.46517 .26525 m
.46585 .26528 L
s
.38487 .26827 m
.38554 .26819 L
s
.46448 .26522 m
.46517 .26525 L
s
.59456 .18398 m
.59513 .18394 L
s
.38554 .26819 m
.38622 .26811 L
s
.28557 .30492 m
.2861 .30449 L
s
.46379 .26518 m
.46448 .26522 L
s
.59402 .18414 m
.5946 .18409 L
s
.38622 .26811 m
.38689 .26803 L
s
.28561 .3049 m
.28614 .30447 L
s
.46311 .26515 m
.46379 .26518 L
s
.38689 .26803 m
.38757 .26794 L
s
.59399 .18402 m
.59456 .18398 L
s
.46242 .26512 m
.46311 .26515 L
s
.38757 .26794 m
.38825 .26786 L
s
.59345 .18418 m
.59402 .18414 L
s
.46173 .2651 m
.46242 .26512 L
s
.38825 .26786 m
.38892 .26779 L
s
.2861 .30449 m
.28664 .30406 L
s
.28614 .30447 m
.28668 .30404 L
s
.46104 .26507 m
.46173 .2651 L
s
.38892 .26779 m
.3896 .26771 L
s
.59341 .18407 m
.59399 .18402 L
s
.46035 .26504 m
.46104 .26507 L
s
.3896 .26771 m
.39028 .26763 L
s
.59288 .18422 m
.59345 .18418 L
s
.45967 .26502 m
.46035 .26504 L
s
.39028 .26763 m
.39096 .26756 L
s
.45898 .26499 m
.45967 .26502 L
s
.28664 .30406 m
.28717 .30363 L
s
.39096 .26756 m
.39164 .26748 L
s
.28668 .30404 m
.28721 .30361 L
s
.59284 .18411 m
.59341 .18407 L
s
.45829 .26497 m
.45898 .26499 L
s
.39164 .26748 m
.39231 .26741 L
s
.4576 .26495 m
.45829 .26497 L
s
.59231 .18427 m
.59288 .18422 L
s
.39231 .26741 m
.39299 .26733 L
s
.45691 .26492 m
.4576 .26495 L
s
.39299 .26733 m
.39367 .26726 L
s
.45622 .2649 m
.45691 .26492 L
s
.28717 .30363 m
.28771 .3032 L
s
.39367 .26726 m
.39435 .26719 L
s
.59227 .18416 m
.59284 .18411 L
s
.28721 .30361 m
.28775 .30318 L
s
.45554 .26488 m
.45622 .2649 L
s
.39435 .26719 m
.39503 .26712 L
s
.59174 .18431 m
.59231 .18427 L
s
.45485 .26487 m
.45554 .26488 L
s
.39503 .26712 m
.39571 .26705 L
s
.45416 .26485 m
.45485 .26487 L
s
.39571 .26705 m
.39639 .26698 L
s
.5917 .1842 m
.59227 .18416 L
s
.45347 .26483 m
.45416 .26485 L
s
.39639 .26698 m
.39707 .26692 L
s
.28771 .3032 m
.28825 .30277 L
s
.45278 .26482 m
.45347 .26483 L
s
.28775 .30318 m
.28829 .30276 L
s
.39707 .26692 m
.39776 .26685 L
s
.59116 .18436 m
.59174 .18431 L
s
.45209 .2648 m
.45278 .26482 L
s
.39776 .26685 m
.39844 .26679 L
s
.4514 .26479 m
.45209 .2648 L
s
.39844 .26679 m
.39912 .26672 L
s
.59112 .18425 m
.5917 .1842 L
s
.45071 .26478 m
.4514 .26479 L
s
.39912 .26672 m
.3998 .26666 L
s
.45002 .26477 m
.45071 .26478 L
s
.3998 .26666 m
.40048 .2666 L
s
.59059 .18441 m
.59116 .18436 L
s
.28825 .30277 m
.28878 .30234 L
s
.44933 .26476 m
.45002 .26477 L
s
.28829 .30276 m
.28883 .30233 L
s
.40048 .2666 m
.40117 .26654 L
s
.44864 .26475 m
.44933 .26476 L
s
.40117 .26654 m
.40185 .26648 L
s
.59055 .1843 m
.59112 .18425 L
s
.44795 .26474 m
.44864 .26475 L
s
.40185 .26648 m
.40253 .26642 L
s
.44726 .26473 m
.44795 .26474 L
s
.40253 .26642 m
.40322 .26636 L
s
.59001 .18446 m
.59059 .18441 L
s
.44657 .26472 m
.44726 .26473 L
s
.40322 .26636 m
.4039 .2663 L
s
.44588 .26472 m
.44657 .26472 L
s
.28878 .30234 m
.28932 .30192 L
s
.4039 .2663 m
.40458 .26625 L
s
.28883 .30233 m
.28937 .3019 L
s
.44519 .26471 m
.44588 .26472 L
s
.40458 .26625 m
.40527 .26619 L
s
.58997 .18434 m
.59055 .1843 L
s
.4445 .26471 m
.44519 .26471 L
s
.40527 .26619 m
.40595 .26614 L
s
.44381 .26471 m
.4445 .26471 L
s
.40595 .26614 m
.40664 .26608 L
s
.58944 .18451 m
.59001 .18446 L
s
.44312 .26471 m
.44381 .26471 L
s
.40664 .26608 m
.40732 .26603 L
s
.44243 .26471 m
.44312 .26471 L
s
.40732 .26603 m
.40801 .26598 L
s
.44174 .26471 m
.44243 .26471 L
s
.40801 .26598 m
.40869 .26593 L
s
.44105 .26471 m
.44174 .26471 L
s
.28932 .30192 m
.28986 .30149 L
s
.40869 .26593 m
.40938 .26588 L
s
.5894 .18439 m
.58997 .18434 L
s
.28937 .3019 m
.28991 .30148 L
s
.44036 .26471 m
.44105 .26471 L
s
.40938 .26588 m
.41006 .26583 L
s
.43967 .26472 m
.44036 .26471 L
s
.41006 .26583 m
.41075 .26579 L
s
.43898 .26472 m
.43967 .26472 L
s
.41075 .26579 m
.41143 .26574 L
s
.58886 .18455 m
.58944 .18451 L
s
.43829 .26473 m
.43898 .26472 L
s
.41143 .26574 m
.41212 .26569 L
s
.4376 .26473 m
.43829 .26473 L
s
.41212 .26569 m
.41281 .26565 L
s
.43691 .26474 m
.4376 .26473 L
s
.41281 .26565 m
.41349 .26561 L
s
.43622 .26475 m
.43691 .26474 L
s
.41349 .26561 m
.41418 .26557 L
s
.43553 .26476 m
.43622 .26475 L
s
.41418 .26557 m
.41487 .26552 L
s
.58882 .18444 m
.5894 .18439 L
s
.43484 .26477 m
.43553 .26476 L
s
.41487 .26552 m
.41555 .26548 L
s
.28986 .30149 m
.2904 .30107 L
s
.43415 .26478 m
.43484 .26477 L
s
.41555 .26548 m
.41624 .26545 L
s
.43346 .2648 m
.43415 .26478 L
s
.41624 .26545 m
.41693 .26541 L
s
.28991 .30148 m
.29045 .30105 L
s
.43277 .26481 m
.43346 .2648 L
s
.41693 .26541 m
.41762 .26537 L
s
.43208 .26482 m
.43277 .26481 L
s
.41762 .26537 m
.4183 .26533 L
s
.58829 .1846 m
.58886 .18455 L
s
.43139 .26484 m
.43208 .26482 L
s
.4183 .26533 m
.41899 .2653 L
s
.4307 .26486 m
.43139 .26484 L
s
.41899 .2653 m
.41968 .26527 L
s
.43001 .26488 m
.4307 .26486 L
s
.41968 .26527 m
.42037 .26523 L
s
.42932 .26489 m
.43001 .26488 L
s
.42037 .26523 m
.42106 .2652 L
s
.42864 .26491 m
.42932 .26489 L
s
.42106 .2652 m
.42175 .26517 L
s
.42795 .26494 m
.42864 .26491 L
s
.42175 .26517 m
.42243 .26514 L
s
.42726 .26496 m
.42795 .26494 L
s
.42243 .26514 m
.42312 .26511 L
s
.42657 .26498 m
.42726 .26496 L
s
.42312 .26511 m
.42381 .26508 L
s
.42588 .265 m
.42657 .26498 L
s
.42381 .26508 m
.4245 .26506 L
s
.42519 .26503 m
.42588 .265 L
s
.4245 .26506 m
.42519 .26503 L
s
.58825 .18449 m
.58882 .18444 L
s
.2904 .30107 m
.29095 .30064 L
s
.58771 .18465 m
.58829 .1846 L
s
.29045 .30105 m
.29099 .30063 L
s
.58767 .18454 m
.58825 .18449 L
s
.58713 .18471 m
.58771 .18465 L
s
.29095 .30064 m
.29149 .30022 L
s
.29099 .30063 m
.29153 .3002 L
s
.58709 .1846 m
.58767 .18454 L
s
.58656 .18476 m
.58713 .18471 L
s
.29149 .30022 m
.29203 .29979 L
s
.29153 .3002 m
.29208 .29978 L
s
.58652 .18465 m
.58709 .1846 L
s
.58598 .18481 m
.58656 .18476 L
s
.58594 .1847 m
.58652 .18465 L
s
.29203 .29979 m
.29258 .29937 L
s
.29208 .29978 m
.29262 .29935 L
s
.5854 .18486 m
.58598 .18481 L
s
.58536 .18476 m
.58594 .1847 L
s
.29258 .29937 m
.29312 .29895 L
s
.29262 .29935 m
.29317 .29893 L
s
.58482 .18492 m
.5854 .18486 L
s
.58478 .18481 m
.58536 .18476 L
s
.58424 .18497 m
.58482 .18492 L
s
.29312 .29895 m
.29367 .29852 L
s
.29317 .29893 m
.29371 .29851 L
s
.5842 .18487 m
.58478 .18481 L
s
.58366 .18503 m
.58424 .18497 L
s
.29367 .29852 m
.29421 .2981 L
s
.29371 .29851 m
.29426 .29809 L
s
.58362 .18492 m
.5842 .18487 L
s
.58308 .18509 m
.58366 .18503 L
s
.29421 .2981 m
.29476 .29768 L
s
.29426 .29809 m
.29481 .29767 L
s
.58304 .18498 m
.58362 .18492 L
s
.5825 .18514 m
.58308 .18509 L
s
.58246 .18503 m
.58304 .18498 L
s
.29476 .29768 m
.29531 .29726 L
s
.29481 .29767 m
.29536 .29725 L
s
.58192 .1852 m
.5825 .18514 L
s
.58188 .18509 m
.58246 .18503 L
s
.29531 .29726 m
.29586 .29684 L
s
.58134 .18526 m
.58192 .1852 L
s
.29536 .29725 m
.29591 .29683 L
s
.5813 .18515 m
.58188 .18509 L
s
.58076 .18532 m
.58134 .18526 L
s
.29586 .29684 m
.29641 .29642 L
s
.29591 .29683 m
.29646 .29641 L
s
.58072 .18521 m
.5813 .18515 L
s
.58017 .18538 m
.58076 .18532 L
s
.29641 .29642 m
.29696 .29601 L
s
.29646 .29641 m
.29701 .29599 L
s
.58013 .18527 m
.58072 .18521 L
s
.57959 .18544 m
.58017 .18538 L
s
.29696 .29601 m
.29751 .29559 L
s
.57955 .18533 m
.58013 .18527 L
s
.29701 .29599 m
.29756 .29558 L
s
.57901 .1855 m
.57959 .18544 L
s
.57897 .18539 m
.57955 .18533 L
s
.29751 .29559 m
.29806 .29517 L
s
.29756 .29558 m
.29811 .29516 L
s
.57842 .18556 m
.57901 .1855 L
s
.57838 .18546 m
.57897 .18539 L
s
.29806 .29517 m
.29862 .29475 L
s
.57784 .18563 m
.57842 .18556 L
s
.29811 .29516 m
.29866 .29474 L
s
.5778 .18552 m
.57838 .18546 L
s
.57725 .18569 m
.57784 .18563 L
s
.29862 .29475 m
.29917 .29434 L
s
.29866 .29474 m
.29922 .29433 L
s
.57721 .18558 m
.5778 .18552 L
s
.57667 .18575 m
.57725 .18569 L
s
.29917 .29434 m
.29973 .29392 L
s
.29922 .29433 m
.29977 .29391 L
s
.57663 .18565 m
.57721 .18558 L
s
.57608 .18582 m
.57667 .18575 L
s
.29973 .29392 m
.30028 .29351 L
s
.57604 .18571 m
.57663 .18565 L
s
.29977 .29391 m
.30033 .2935 L
s
.5755 .18588 m
.57608 .18582 L
s
.57545 .18578 m
.57604 .18571 L
s
.30028 .29351 m
.30084 .2931 L
s
.30033 .2935 m
.30089 .29308 L
s
.57491 .18595 m
.5755 .18588 L
s
.57487 .18585 m
.57545 .18578 L
s
.30084 .2931 m
.3014 .29268 L
s
.57432 .18602 m
.57491 .18595 L
s
.30089 .29308 m
.30144 .29267 L
s
.57428 .18591 m
.57487 .18585 L
s
.57373 .18609 m
.57432 .18602 L
s
.3014 .29268 m
.30195 .29227 L
s
.30144 .29267 m
.302 .29226 L
s
.57369 .18598 m
.57428 .18591 L
s
.57315 .18615 m
.57373 .18609 L
s
.30195 .29227 m
.30251 .29186 L
s
.302 .29226 m
.30256 .29185 L
s
.5731 .18605 m
.57369 .18598 L
s
.57256 .18622 m
.57315 .18615 L
s
.30251 .29186 m
.30307 .29145 L
s
.57251 .18612 m
.5731 .18605 L
s
.30256 .29185 m
.30312 .29144 L
s
.57197 .18629 m
.57256 .18622 L
s
.57192 .18619 m
.57251 .18612 L
s
.30307 .29145 m
.30363 .29104 L
s
.30312 .29144 m
.30368 .29103 L
s
.57138 .18636 m
.57197 .18629 L
s
.57134 .18626 m
.57192 .18619 L
s
.30363 .29104 m
.30419 .29063 L
s
.57079 .18644 m
.57138 .18636 L
s
.30368 .29103 m
.30424 .29062 L
s
.57075 .18633 m
.57134 .18626 L
s
.5702 .18651 m
.57079 .18644 L
s
.30419 .29063 m
.30476 .29022 L
s
.30424 .29062 m
.3048 .29021 L
s
.57015 .18641 m
.57075 .18633 L
s
.56961 .18658 m
.5702 .18651 L
s
.30476 .29022 m
.30532 .28981 L
s
.3048 .29021 m
.30537 .2898 L
s
.56956 .18648 m
.57015 .18641 L
s
.56902 .18665 m
.56961 .18658 L
s
.30532 .28981 m
.30588 .2894 L
s
.56897 .18655 m
.56956 .18648 L
s
.30537 .2898 m
.30593 .28939 L
s
.56842 .18673 m
.56902 .18665 L
s
.56838 .18663 m
.56897 .18655 L
s
.30588 .2894 m
.30645 .28899 L
s
.30593 .28939 m
.3065 .28898 L
s
.56783 .1868 m
.56842 .18673 L
s
.56779 .1867 m
.56838 .18663 L
s
.30645 .28899 m
.30701 .28859 L
s
.56724 .18688 m
.56783 .1868 L
s
.3065 .28898 m
.30706 .28858 L
s
.5672 .18678 m
.56779 .1867 L
s
.56665 .18696 m
.56724 .18688 L
s
.30701 .28859 m
.30758 .28818 L
s
.30706 .28858 m
.30763 .28817 L
s
.5666 .18686 m
.5672 .18678 L
s
.56605 .18703 m
.56665 .18696 L
s
.30758 .28818 m
.30814 .28778 L
s
.30763 .28817 m
.30819 .28777 L
s
.56601 .18693 m
.5666 .18686 L
s
.56546 .18711 m
.56605 .18703 L
s
.30814 .28778 m
.30871 .28737 L
s
.30819 .28777 m
.30876 .28736 L
s
.56541 .18701 m
.56601 .18693 L
s
.56486 .18719 m
.56546 .18711 L
s
.56482 .18709 m
.56541 .18701 L
s
.30871 .28737 m
.30928 .28697 L
s
.30876 .28736 m
.30933 .28696 L
s
.56427 .18727 m
.56486 .18719 L
s
.56423 .18717 m
.56482 .18709 L
s
.30928 .28697 m
.30985 .28656 L
s
.30933 .28696 m
.3099 .28656 L
s
.56367 .18735 m
.56427 .18727 L
s
.56363 .18725 m
.56423 .18717 L
s
.56308 .18743 m
.56367 .18735 L
s
.30985 .28656 m
.31042 .28616 L
s
.3099 .28656 m
.31047 .28615 L
s
.56303 .18733 m
.56363 .18725 L
s
.56248 .18751 m
.56308 .18743 L
s
.31042 .28616 m
.31099 .28576 L
s
.31047 .28615 m
.31104 .28575 L
s
.56244 .18742 m
.56303 .18733 L
s
.56189 .1876 m
.56248 .18751 L
s
.31099 .28576 m
.31156 .28536 L
s
.31104 .28575 m
.31161 .28535 L
s
.56184 .1875 m
.56244 .18742 L
s
.56129 .18768 m
.56189 .1876 L
s
.56124 .18758 m
.56184 .1875 L
s
.31156 .28536 m
.31213 .28496 L
s
.31161 .28535 m
.31218 .28495 L
s
.56069 .18776 m
.56129 .18768 L
s
.56065 .18767 m
.56124 .18758 L
s
.31213 .28496 m
.3127 .28456 L
s
.31218 .28495 m
.31275 .28455 L
s
.56009 .18785 m
.56069 .18776 L
s
.56005 .18775 m
.56065 .18767 L
s
.5595 .18793 m
.56009 .18785 L
s
.3127 .28456 m
.31327 .28416 L
s
.31275 .28455 m
.31332 .28415 L
s
.55945 .18784 m
.56005 .18775 L
s
.5589 .18802 m
.5595 .18793 L
s
.31327 .28416 m
.31385 .28376 L
s
.31332 .28415 m
.3139 .28376 L
s
.55885 .18792 m
.55945 .18784 L
s
.5583 .18811 m
.5589 .18802 L
s
.31385 .28376 m
.31442 .28336 L
s
.3139 .28376 m
.31447 .28336 L
s
.55825 .18801 m
.55885 .18792 L
s
.5577 .1882 m
.5583 .18811 L
s
.31442 .28336 m
.315 .28297 L
s
.31447 .28336 m
.31505 .28296 L
s
.55765 .1881 m
.55825 .18801 L
s
.5571 .18828 m
.5577 .1882 L
s
.55705 .18819 m
.55765 .1881 L
s
.315 .28297 m
.31557 .28257 L
s
.31505 .28296 m
.31562 .28256 L
s
.5565 .18837 m
.5571 .18828 L
s
.55645 .18828 m
.55705 .18819 L
s
.31557 .28257 m
.31615 .28217 L
s
.31562 .28256 m
.3162 .28217 L
s
.5559 .18846 m
.5565 .18837 L
s
.55585 .18837 m
.55645 .18828 L
s
.5553 .18855 m
.5559 .18846 L
s
.31615 .28217 m
.31673 .28178 L
s
.3162 .28217 m
.31678 .28177 L
s
.55525 .18846 m
.55585 .18837 L
s
.5547 .18865 m
.5553 .18855 L
s
.31673 .28178 m
.3173 .28138 L
s
.31678 .28177 m
.31736 .28138 L
s
.55465 .18855 m
.55525 .18846 L
s
.55409 .18874 m
.5547 .18865 L
s
.3173 .28138 m
.31788 .28099 L
s
.31736 .28138 m
.31793 .28099 L
s
.55405 .18864 m
.55465 .18855 L
s
.55349 .18883 m
.55409 .18874 L
s
.31788 .28099 m
.31846 .2806 L
s
.55344 .18874 m
.55405 .18864 L
s
.31793 .28099 m
.31851 .28059 L
s
.55289 .18893 m
.55349 .18883 L
s
.55284 .18883 m
.55344 .18874 L
s
.31846 .2806 m
.31904 .28021 L
s
.31851 .28059 m
.31909 .2802 L
s
.55229 .18902 m
.55289 .18893 L
s
.55224 .18893 m
.55284 .18883 L
s
.31904 .28021 m
.31962 .27981 L
s
.31909 .2802 m
.31967 .27981 L
s
.55168 .18912 m
.55229 .18902 L
s
.55163 .18902 m
.55224 .18893 L
s
.55108 .18921 m
.55168 .18912 L
s
.31962 .27981 m
.3202 .27942 L
s
.31967 .27981 m
.32026 .27942 L
s
.55103 .18912 m
.55163 .18902 L
s
.55047 .18931 m
.55108 .18921 L
s
.3202 .27942 m
.32079 .27903 L
s
.32026 .27942 m
.32084 .27903 L
s
.55043 .18921 m
.55103 .18912 L
s
.54987 .18941 m
.55047 .18931 L
s
.32079 .27903 m
.32137 .27864 L
s
.32084 .27903 m
.32142 .27864 L
s
.54982 .18931 m
.55043 .18921 L
s
.54926 .1895 m
.54987 .18941 L
s
.32137 .27864 m
.32195 .27825 L
s
.54922 .18941 m
.54982 .18931 L
s
.32142 .27864 m
.322 .27825 L
s
.54866 .1896 m
.54926 .1895 L
s
.54861 .18951 m
.54922 .18941 L
s
.32195 .27825 m
.32253 .27787 L
s
.322 .27825 m
.32259 .27787 L
s
.54805 .1897 m
.54866 .1896 L
s
.548 .18961 m
.54861 .18951 L
s
.32253 .27787 m
.32312 .27748 L
s
.32259 .27787 m
.32317 .27748 L
s
.54745 .1898 m
.54805 .1897 L
s
.5474 .18971 m
.548 .18961 L
s
.54684 .1899 m
.54745 .1898 L
s
.32312 .27748 m
.3237 .27709 L
s
.32317 .27748 m
.32376 .27709 L
s
.54679 .18981 m
.5474 .18971 L
s
.54623 .19001 m
.54684 .1899 L
s
.3237 .27709 m
.32429 .27671 L
s
.32376 .27709 m
.32434 .27671 L
s
.54618 .18991 m
.54679 .18981 L
s
.54563 .19011 m
.54623 .19001 L
s
.32429 .27671 m
.32488 .27632 L
s
.32434 .27671 m
.32493 .27632 L
s
.54558 .19002 m
.54618 .18991 L
s
.54502 .19021 m
.54563 .19011 L
s
.32488 .27632 m
.32546 .27594 L
s
.32493 .27632 m
.32552 .27594 L
s
.54497 .19012 m
.54558 .19002 L
s
.54441 .19032 m
.54502 .19021 L
s
.54436 .19023 m
.54497 .19012 L
s
.32546 .27594 m
.32605 .27555 L
s
.32552 .27594 m
.3261 .27555 L
s
.5438 .19042 m
.54441 .19032 L
s
.54375 .19033 m
.54436 .19023 L
s
.32605 .27555 m
.32664 .27517 L
s
.3261 .27555 m
.32669 .27517 L
s
.54319 .19053 m
.5438 .19042 L
s
.54314 .19044 m
.54375 .19033 L
s
.54258 .19064 m
.54319 .19053 L
s
.32664 .27517 m
.32723 .27479 L
s
.32669 .27517 m
.32728 .27479 L
s
.54253 .19055 m
.54314 .19044 L
s
.54197 .19074 m
.54258 .19064 L
s
.32723 .27479 m
.32782 .27441 L
s
.32728 .27479 m
.32787 .27441 L
s
.54192 .19065 m
.54253 .19055 L
s
.54136 .19085 m
.54197 .19074 L
s
.32782 .27441 m
.32841 .27403 L
s
.32787 .27441 m
.32846 .27403 L
s
.54131 .19076 m
.54192 .19065 L
s
.54075 .19096 m
.54136 .19085 L
s
.32841 .27403 m
.329 .27365 L
s
.32846 .27403 m
.32905 .27365 L
s
.5407 .19087 m
.54131 .19076 L
s
.54014 .19107 m
.54075 .19096 L
s
.54009 .19098 m
.5407 .19087 L
s
.329 .27365 m
.32959 .27327 L
s
.32905 .27365 m
.32964 .27327 L
s
.53953 .19118 m
.54014 .19107 L
s
.53948 .19109 m
.54009 .19098 L
s
.32959 .27327 m
.33018 .27289 L
s
.32964 .27327 m
.33023 .27289 L
s
.53892 .19129 m
.53953 .19118 L
s
.53887 .1912 m
.53948 .19109 L
s
.33018 .27289 m
.33077 .27251 L
s
.53831 .1914 m
.53892 .19129 L
s
.33023 .27289 m
.33083 .27251 L
s
.53826 .19132 m
.53887 .1912 L
s
.5377 .19152 m
.53831 .1914 L
s
.33077 .27251 m
.33137 .27213 L
s
.33083 .27251 m
.33142 .27213 L
s
.53764 .19143 m
.53826 .19132 L
s
.53708 .19163 m
.5377 .19152 L
s
.33137 .27213 m
.33196 .27176 L
s
.33142 .27213 m
.33201 .27176 L
s
.53703 .19154 m
.53764 .19143 L
s
.53647 .19174 m
.53708 .19163 L
s
.33196 .27176 m
.33255 .27138 L
s
.33201 .27176 m
.33261 .27138 L
s
.53642 .19166 m
.53703 .19154 L
s
.53586 .19186 m
.53647 .19174 L
s
.33255 .27138 m
.33315 .271 L
s
.33261 .27138 m
.3332 .27101 L
s
.53581 .19177 m
.53642 .19166 L
s
.53524 .19198 m
.53586 .19186 L
s
.53519 .19189 m
.53581 .19177 L
s
.33315 .271 m
.33374 .27063 L
s
.3332 .27101 m
.3338 .27063 L
s
.53463 .19209 m
.53524 .19198 L
s
.53458 .19201 m
.53519 .19189 L
s
.33374 .27063 m
.33434 .27026 L
s
.3338 .27063 m
.33439 .27026 L
s
.53401 .19221 m
.53463 .19209 L
s
.53396 .19212 m
.53458 .19201 L
s
.5334 .19233 m
.53401 .19221 L
s
.33434 .27026 m
.33494 .26988 L
s
.33439 .27026 m
.33499 .26989 L
s
.53335 .19224 m
.53396 .19212 L
s
.53278 .19245 m
.5334 .19233 L
s
.33499 .26989 m
.33559 .26952 L
s
.33494 .26988 m
.33553 .26951 L
s
.53273 .19236 m
.53335 .19224 L
s
.53217 .19257 m
.53278 .19245 L
s
.33559 .26952 m
.33618 .26914 L
s
.33553 .26951 m
.33613 .26914 L
s
.53212 .19248 m
.53273 .19236 L
s
.53155 .19269 m
.53217 .19257 L
s
.33618 .26914 m
.33678 .26877 L
s
.33613 .26914 m
.33673 .26877 L
s
.5315 .1926 m
.53212 .19248 L
s
.53094 .19281 m
.53155 .19269 L
s
.33678 .26877 m
.33738 .2684 L
s
.33673 .26877 m
.33733 .2684 L
s
.53089 .19272 m
.5315 .1926 L
s
.53032 .19293 m
.53094 .19281 L
s
.53027 .19285 m
.53089 .19272 L
s
.33738 .2684 m
.33798 .26804 L
s
.33733 .2684 m
.33793 .26803 L
s
.5297 .19305 m
.53032 .19293 L
s
.52965 .19297 m
.53027 .19285 L
s
.33798 .26804 m
.33858 .26767 L
s
.33793 .26803 m
.33853 .26766 L
s
.52909 .19318 m
.5297 .19305 L
s
.52904 .19309 m
.52965 .19297 L
s
.52847 .1933 m
.52909 .19318 L
s
.33858 .26767 m
.33918 .2673 L
s
.33853 .26766 m
.33913 .26729 L
s
.52842 .19322 m
.52904 .19309 L
s
.52785 .19343 m
.52847 .1933 L
s
.33918 .2673 m
.33978 .26693 L
s
.33913 .26729 m
.33973 .26693 L
s
.5278 .19334 m
.52842 .19322 L
s
.52723 .19355 m
.52785 .19343 L
s
.33978 .26693 m
.34038 .26657 L
s
.33973 .26693 m
.34033 .26656 L
s
.52718 .19347 m
.5278 .19334 L
s
.52662 .19368 m
.52723 .19355 L
s
.34038 .26657 m
.34099 .2662 L
s
.34033 .26656 m
.34093 .2662 L
s
.52656 .1936 m
.52718 .19347 L
s
.526 .19381 m
.52662 .19368 L
s
.34099 .2662 m
.34159 .26584 L
s
.34093 .2662 m
.34153 .26583 L
s
.52594 .19372 m
.52656 .1936 L
s
.52538 .19394 m
.526 .19381 L
s
.34159 .26584 m
.34219 .26547 L
s
.34153 .26583 m
.34214 .26547 L
s
.52533 .19385 m
.52594 .19372 L
s
.52476 .19407 m
.52538 .19394 L
s
.52471 .19398 m
.52533 .19385 L
s
.34219 .26547 m
.34279 .26511 L
s
.34214 .26547 m
.34274 .2651 L
s
.52414 .1942 m
.52476 .19407 L
s
.52409 .19411 m
.52471 .19398 L
s
.34279 .26511 m
.3434 .26475 L
s
.34274 .2651 m
.34334 .26474 L
s
.52352 .19433 m
.52414 .1942 L
s
.52347 .19424 m
.52409 .19411 L
s
.5229 .19446 m
.52352 .19433 L
s
.3434 .26475 m
.344 .26439 L
s
.34334 .26474 m
.34395 .26438 L
s
.52285 .19438 m
.52347 .19424 L
s
.52228 .19459 m
.5229 .19446 L
s
.344 .26439 m
.34461 .26403 L
s
.34395 .26438 m
.34455 .26402 L
s
.52223 .19451 m
.52285 .19438 L
s
.52166 .19472 m
.52228 .19459 L
s
.34461 .26403 m
.34521 .26367 L
s
.34455 .26402 m
.34516 .26366 L
s
.5216 .19464 m
.52223 .19451 L
s
.52104 .19486 m
.52166 .19472 L
s
.34521 .26367 m
.34582 .26331 L
s
.34516 .26366 m
.34576 .2633 L
s
.52098 .19478 m
.5216 .19464 L
s
.52041 .19499 m
.52104 .19486 L
s
.34582 .26331 m
.34643 .26295 L
s
.34576 .2633 m
.34637 .26294 L
s
.52036 .19491 m
.52098 .19478 L
s
.51979 .19513 m
.52041 .19499 L
s
.34643 .26295 m
.34703 .26259 L
s
.51974 .19505 m
.52036 .19491 L
s
.34637 .26294 m
.34698 .26258 L
s
.51917 .19526 m
.51979 .19513 L
s
.51912 .19518 m
.51974 .19505 L
s
.34703 .26259 m
.34764 .26223 L
s
.34698 .26258 m
.34759 .26222 L
s
.51855 .1954 m
.51917 .19526 L
s
.51849 .19532 m
.51912 .19518 L
s
.34764 .26223 m
.34825 .26188 L
s
.34759 .26222 m
.34819 .26187 L
s
.51792 .19554 m
.51855 .1954 L
s
.51787 .19546 m
.51849 .19532 L
s
.5173 .19568 m
.51792 .19554 L
s
.34825 .26188 m
.34886 .26152 L
s
.34819 .26187 m
.3488 .26151 L
s
.51725 .1956 m
.51787 .19546 L
s
.51668 .19582 m
.5173 .19568 L
s
.34886 .26152 m
.34947 .26117 L
s
.3488 .26151 m
.34941 .26116 L
s
.51662 .19574 m
.51725 .1956 L
s
.51605 .19596 m
.51668 .19582 L
s
.34947 .26117 m
.35008 .26081 L
s
.34941 .26116 m
.35002 .2608 L
s
.516 .19588 m
.51662 .19574 L
s
.51543 .1961 m
.51605 .19596 L
s
.35008 .26081 m
.35069 .26046 L
s
.35002 .2608 m
.35063 .26045 L
s
.51538 .19602 m
.516 .19588 L
s
.51481 .19624 m
.51543 .1961 L
s
.35069 .26046 m
.3513 .26011 L
s
.35063 .26045 m
.35124 .2601 L
s
.51475 .19616 m
.51538 .19602 L
s
.51418 .19638 m
.51481 .19624 L
s
.3513 .26011 m
.35191 .25976 L
s
.35124 .2601 m
.35185 .25975 L
s
.51413 .1963 m
.51475 .19616 L
s
.51356 .19653 m
.51418 .19638 L
s
.5135 .19645 m
.51413 .1963 L
s
.35191 .25976 m
.35252 .25941 L
s
.35185 .25975 m
.35246 .25939 L
s
.51293 .19667 m
.51356 .19653 L
s
.51288 .19659 m
.5135 .19645 L
s
.35252 .25941 m
.35313 .25906 L
s
.35246 .25939 m
.35307 .25904 L
s
.51231 .19681 m
.51293 .19667 L
s
.51225 .19674 m
.51288 .19659 L
s
.35313 .25906 m
.35374 .25871 L
s
.51168 .19696 m
.51231 .19681 L
s
.35307 .25904 m
.35369 .25869 L
s
.51163 .19688 m
.51225 .19674 L
s
.51105 .19711 m
.51168 .19696 L
s
.35374 .25871 m
.35436 .25836 L
s
.35369 .25869 m
.3543 .25835 L
s
.511 .19703 m
.51163 .19688 L
s
.51043 .19725 m
.51105 .19711 L
s
.35436 .25836 m
.35497 .25801 L
s
.3543 .25835 m
.35491 .258 L
s
.51037 .19718 m
.511 .19703 L
s
.5098 .1974 m
.51043 .19725 L
s
.35497 .25801 m
.35558 .25766 L
s
.35491 .258 m
.35553 .25765 L
s
.50975 .19733 m
.51037 .19718 L
s
.50918 .19755 m
.5098 .1974 L
s
.35558 .25766 m
.3562 .25732 L
s
.35553 .25765 m
.35614 .2573 L
s
.50912 .19748 m
.50975 .19733 L
s
.50855 .1977 m
.50918 .19755 L
s
.3562 .25732 m
.35681 .25697 L
s
.35614 .2573 m
.35675 .25696 L
s
.50849 .19763 m
.50912 .19748 L
s
.50792 .19785 m
.50855 .1977 L
s
.35681 .25697 m
.35743 .25663 L
s
.35675 .25696 m
.35737 .25661 L
s
.50787 .19778 m
.50849 .19763 L
s
.50729 .198 m
.50792 .19785 L
s
.35743 .25663 m
.35804 .25628 L
s
.50724 .19793 m
.50787 .19778 L
s
.35737 .25661 m
.35798 .25627 L
s
.50667 .19816 m
.50729 .198 L
s
.50661 .19808 m
.50724 .19793 L
s
.35804 .25628 m
.35866 .25594 L
s
.35798 .25627 m
.3586 .25593 L
s
.50604 .19831 m
.50667 .19816 L
s
.50598 .19823 m
.50661 .19808 L
s
.35866 .25594 m
.35927 .2556 L
s
.50541 .19846 m
.50604 .19831 L
s
.3586 .25593 m
.35922 .25558 L
s
.50535 .19839 m
.50598 .19823 L
s
.50478 .19862 m
.50541 .19846 L
s
.35927 .2556 m
.35989 .25526 L
s
.35922 .25558 m
.35983 .25524 L
s
.50473 .19854 m
.50535 .19839 L
s
.50415 .19877 m
.50478 .19862 L
s
.35989 .25526 m
.36051 .25492 L
s
.35983 .25524 m
.36045 .2549 L
s
.5041 .1987 m
.50473 .19854 L
s
.50352 .19893 m
.50415 .19877 L
s
.36051 .25492 m
.36112 .25458 L
s
.36045 .2549 m
.36107 .25456 L
s
.50347 .19885 m
.5041 .1987 L
s
.50289 .19909 m
.50352 .19893 L
s
.36112 .25458 m
.36174 .25424 L
s
.36107 .25456 m
.36168 .25422 L
s
.50284 .19901 m
.50347 .19885 L
s
.50226 .19924 m
.50289 .19909 L
s
.36174 .25424 m
.36236 .2539 L
s
.36168 .25422 m
.3623 .25388 L
s
.50221 .19917 m
.50284 .19901 L
s
.50163 .1994 m
.50226 .19924 L
s
.36236 .2539 m
.36298 .25356 L
s
.3623 .25388 m
.36292 .25354 L
s
.50158 .19933 m
.50221 .19917 L
s
.501 .19956 m
.50163 .1994 L
s
.36298 .25356 m
.3636 .25322 L
s
.36292 .25354 m
.36354 .25321 L
s
.50095 .19949 m
.50158 .19933 L
s
.50037 .19972 m
.501 .19956 L
s
.3636 .25322 m
.36422 .25289 L
s
.50032 .19965 m
.50095 .19949 L
s
.36354 .25321 m
.36416 .25287 L
s
.49974 .19988 m
.50037 .19972 L
s
.49969 .19981 m
.50032 .19965 L
s
.36422 .25289 m
.36484 .25255 L
s
.36416 .25287 m
.36478 .25254 L
s
.49911 .20004 m
.49974 .19988 L
s
.49906 .19997 m
.49969 .19981 L
s
.36484 .25255 m
.36546 .25222 L
s
.49848 .20021 m
.49911 .20004 L
s
.36478 .25254 m
.3654 .2522 L
s
.49843 .20013 m
.49906 .19997 L
s
.49785 .20037 m
.49848 .20021 L
s
.36546 .25222 m
.36608 .25188 L
s
.3654 .2522 m
.36602 .25187 L
s
.49779 .2003 m
.49843 .20013 L
s
.49722 .20053 m
.49785 .20037 L
s
.36608 .25188 m
.3667 .25155 L
s
.36602 .25187 m
.36664 .25153 L
s
.49716 .20046 m
.49779 .2003 L
s
.49659 .2007 m
.49722 .20053 L
s
.3667 .25155 m
.36732 .25122 L
s
.36664 .25153 m
.36726 .2512 L
s
.49653 .20063 m
.49716 .20046 L
s
.49596 .20087 m
.49659 .2007 L
s
.36732 .25122 m
.36794 .25089 L
s
.36726 .2512 m
.36788 .25087 L
s
.4959 .20079 m
.49653 .20063 L
s
.49532 .20103 m
.49596 .20087 L
s
.36794 .25089 m
.36856 .25056 L
s
.36788 .25087 m
.36851 .25054 L
s
.49527 .20096 m
.4959 .20079 L
s
.49469 .2012 m
.49532 .20103 L
s
.36856 .25056 m
.36919 .25023 L
s
.36851 .25054 m
.36913 .25021 L
s
.49463 .20113 m
.49527 .20096 L
s
.49406 .20137 m
.49469 .2012 L
s
.36919 .25023 m
.36981 .2499 L
s
.36913 .25021 m
.36975 .24988 L
s
.494 .2013 m
.49463 .20113 L
s
.49343 .20154 m
.49406 .20137 L
s
.36981 .2499 m
.37043 .24957 L
s
.36975 .24988 m
.37037 .24955 L
s
.49337 .20147 m
.494 .2013 L
s
.49279 .20171 m
.49343 .20154 L
s
.37043 .24957 m
.37106 .24924 L
s
.49274 .20164 m
.49337 .20147 L
s
.37037 .24955 m
.371 .24922 L
s
.49216 .20188 m
.49279 .20171 L
s
.37106 .24924 m
.37168 .24892 L
s
.4921 .20181 m
.49274 .20164 L
s
.49153 .20205 m
.49216 .20188 L
s
.371 .24922 m
.37162 .2489 L
s
.49147 .20198 m
.4921 .20181 L
s
.37168 .24892 m
.3723 .24859 L
s
.49089 .20222 m
.49153 .20205 L
s
.37162 .2489 m
.37225 .24857 L
s
.49084 .20215 m
.49147 .20198 L
s
.3723 .24859 m
.37293 .24827 L
s
.49026 .20239 m
.49089 .20222 L
s
.37225 .24857 m
.37287 .24825 L
s
.4902 .20233 m
.49084 .20215 L
s
.48962 .20257 m
.49026 .20239 L
s
.37293 .24827 m
.37355 .24794 L
s
.37287 .24825 m
.3735 .24792 L
s
.48957 .2025 m
.4902 .20233 L
s
.48899 .20274 m
.48962 .20257 L
s
.37355 .24794 m
.37418 .24762 L
s
.3735 .24792 m
.37412 .2476 L
s
.48893 .20267 m
.48957 .2025 L
s
.48836 .20292 m
.48899 .20274 L
s
.37418 .24762 m
.3748 .24729 L
s
.37412 .2476 m
.37475 .24727 L
s
.4883 .20285 m
.48893 .20267 L
s
.48772 .20309 m
.48836 .20292 L
s
.3748 .24729 m
.37543 .24697 L
s
.37475 .24727 m
.37537 .24695 L
s
.48766 .20303 m
.4883 .20285 L
s
.48709 .20327 m
.48772 .20309 L
s
.37543 .24697 m
.37606 .24665 L
s
.37537 .24695 m
.376 .24663 L
s
.48703 .2032 m
.48766 .20303 L
s
.48645 .20345 m
.48709 .20327 L
s
.37606 .24665 m
.37668 .24633 L
s
.376 .24663 m
.37662 .24631 L
s
.48639 .20338 m
.48703 .2032 L
s
.48582 .20363 m
.48645 .20345 L
s
.37668 .24633 m
.37731 .24601 L
s
.37662 .24631 m
.37725 .24599 L
s
.48576 .20356 m
.48639 .20338 L
s
.48518 .20381 m
.48582 .20363 L
s
.37731 .24601 m
.37794 .24569 L
s
.37725 .24599 m
.37788 .24567 L
s
.48512 .20374 m
.48576 .20356 L
s
.48454 .20399 m
.48518 .20381 L
s
.37794 .24569 m
.37856 .24538 L
s
.48449 .20392 m
.48512 .20374 L
s
.37788 .24567 m
.37851 .24535 L
s
.48391 .20417 m
.48454 .20399 L
s
.37856 .24538 m
.37919 .24506 L
s
.48385 .2041 m
.48449 .20392 L
s
.48327 .20435 m
.48391 .20417 L
s
.37851 .24535 m
.37913 .24504 L
s
.37919 .24506 m
.37982 .24474 L
s
.48322 .20429 m
.48385 .2041 L
s
.48264 .20453 m
.48327 .20435 L
s
.37913 .24504 m
.37976 .24472 L
s
.37982 .24474 m
.38045 .24443 L
s
.48258 .20447 m
.48322 .20429 L
s
.482 .20472 m
.48264 .20453 L
s
.37976 .24472 m
.38039 .2444 L
s
.48194 .20465 m
.48258 .20447 L
s
.38045 .24443 m
.38108 .24411 L
s
.48136 .2049 m
.482 .20472 L
s
.38039 .2444 m
.38102 .24409 L
s
.48131 .20484 m
.48194 .20465 L
s
.48073 .20509 m
.48136 .2049 L
s
.38108 .24411 m
.38171 .2438 L
s
.38102 .24409 m
.38165 .24377 L
s
.48067 .20502 m
.48131 .20484 L
s
.48009 .20527 m
.48073 .20509 L
s
.38171 .2438 m
.38234 .24349 L
s
.38165 .24377 m
.38228 .24346 L
s
.48003 .20521 m
.48067 .20502 L
s
.47945 .20546 m
.48009 .20527 L
s
.38234 .24349 m
.38297 .24317 L
s
.38228 .24346 m
.38291 .24315 L
s
.4794 .2054 m
.48003 .20521 L
s
.47882 .20565 m
.47945 .20546 L
s
.38297 .24317 m
.3836 .24286 L
s
.38291 .24315 m
.38354 .24284 L
s
.47876 .20559 m
.4794 .2054 L
s
.47818 .20584 m
.47882 .20565 L
s
.3836 .24286 m
.38423 .24255 L
s
.38354 .24284 m
.38417 .24253 L
s
.47754 .20603 m
.47818 .20584 L
s
.47812 .20577 m
.47876 .20559 L
s
.38423 .24255 m
.38486 .24224 L
s
.38417 .24253 m
.3848 .24222 L
s
.4769 .20622 m
.47754 .20603 L
s
.47748 .20596 m
.47812 .20577 L
s
.38486 .24224 m
.38549 .24193 L
s
.3848 .24222 m
.38543 .24191 L
s
.47627 .20641 m
.4769 .20622 L
s
.47685 .20615 m
.47748 .20596 L
s
.38549 .24193 m
.38612 .24162 L
s
.38543 .24191 m
.38606 .2416 L
s
.47563 .2066 m
.47627 .20641 L
s
.47621 .20635 m
.47685 .20615 L
s
.38612 .24162 m
.38675 .24132 L
s
.38606 .2416 m
.38669 .24129 L
s
.47499 .20679 m
.47563 .2066 L
s
.47557 .20654 m
.47621 .20635 L
s
.38675 .24132 m
.38738 .24101 L
s
.47435 .20699 m
.47499 .20679 L
s
.38669 .24129 m
.38732 .24098 L
s
.47493 .20673 m
.47557 .20654 L
s
.38738 .24101 m
.38801 .2407 L
s
.47371 .20718 m
.47435 .20699 L
s
.47429 .20692 m
.47493 .20673 L
s
.38732 .24098 m
.38795 .24068 L
s
.38801 .2407 m
.38864 .2404 L
s
.47308 .20738 m
.47371 .20718 L
s
.47366 .20712 m
.47429 .20692 L
s
.38795 .24068 m
.38858 .24037 L
s
.38864 .2404 m
.38928 .2401 L
s
.47244 .20757 m
.47308 .20738 L
s
.47302 .20732 m
.47366 .20712 L
s
.38858 .24037 m
.38922 .24007 L
s
.38928 .2401 m
.38991 .23979 L
s
.4718 .20777 m
.47244 .20757 L
s
.47238 .20751 m
.47302 .20732 L
s
.38922 .24007 m
.38985 .23977 L
s
.38991 .23979 m
.39054 .23949 L
s
.47116 .20797 m
.4718 .20777 L
s
.47174 .20771 m
.47238 .20751 L
s
.38985 .23977 m
.39048 .23946 L
s
.39054 .23949 m
.39117 .23919 L
s
.47052 .20817 m
.47116 .20797 L
s
.4711 .20791 m
.47174 .20771 L
s
.39048 .23946 m
.39112 .23916 L
s
.46988 .20836 m
.47052 .20817 L
s
.39117 .23919 m
.39181 .23889 L
s
.47046 .20811 m
.4711 .20791 L
s
.39112 .23916 m
.39175 .23886 L
s
.46924 .20857 m
.46988 .20836 L
s
.39181 .23889 m
.39244 .23859 L
s
.46982 .2083 m
.47046 .20811 L
s
.39175 .23886 m
.39238 .23856 L
s
.4686 .20877 m
.46924 .20857 L
s
.46918 .20851 m
.46982 .2083 L
s
.39244 .23859 m
.39307 .23829 L
s
.39238 .23856 m
.39302 .23826 L
s
.46796 .20897 m
.4686 .20877 L
s
.46854 .20871 m
.46918 .20851 L
s
.39307 .23829 m
.39371 .23799 L
s
.39302 .23826 m
.39365 .23796 L
s
.46732 .20917 m
.46796 .20897 L
s
.4679 .20891 m
.46854 .20871 L
s
.39371 .23799 m
.39434 .23769 L
s
.39365 .23796 m
.39428 .23766 L
s
.46668 .20937 m
.46732 .20917 L
s
.46727 .20911 m
.4679 .20891 L
s
.39434 .23769 m
.39498 .2374 L
s
.39428 .23766 m
.39492 .23737 L
s
.46604 .20958 m
.46668 .20937 L
s
.46663 .20931 m
.46727 .20911 L
s
.39498 .2374 m
.39561 .2371 L
s
.39492 .23737 m
.39555 .23707 L
s
.4654 .20978 m
.46604 .20958 L
s
.46599 .20952 m
.46663 .20931 L
s
.39561 .2371 m
.39625 .2368 L
s
.39555 .23707 m
.39619 .23677 L
s
.46476 .20999 m
.4654 .20978 L
s
.46535 .20972 m
.46599 .20952 L
s
.39625 .2368 m
.39688 .23651 L
s
.46412 .2102 m
.46476 .20999 L
s
.39619 .23677 m
.39682 .23648 L
s
.46471 .20993 m
.46535 .20972 L
s
.39688 .23651 m
.39752 .23622 L
s
.46348 .2104 m
.46412 .2102 L
s
.39682 .23648 m
.39746 .23619 L
s
.46407 .21014 m
.46471 .20993 L
s
.39752 .23622 m
.39815 .23592 L
s
.46284 .21061 m
.46348 .2104 L
s
.39746 .23619 m
.39809 .23589 L
s
.46342 .21035 m
.46407 .21014 L
s
.39815 .23592 m
.39879 .23563 L
s
.4622 .21082 m
.46284 .21061 L
s
.39809 .23589 m
.39873 .2356 L
s
.46278 .21055 m
.46342 .21035 L
s
.39879 .23563 m
.39942 .23534 L
s
.46156 .21103 m
.4622 .21082 L
s
.39873 .2356 m
.39936 .23531 L
s
.46214 .21076 m
.46278 .21055 L
s
.39942 .23534 m
.40006 .23505 L
s
.46092 .21124 m
.46156 .21103 L
s
.4615 .21097 m
.46214 .21076 L
s
.39936 .23531 m
.4 .23502 L
s
.40006 .23505 m
.4007 .23476 L
s
.46028 .21145 m
.46092 .21124 L
s
.46086 .21119 m
.4615 .21097 L
s
.4 .23502 m
.40064 .23473 L
s
.4007 .23476 m
.40133 .23447 L
s
.45964 .21167 m
.46028 .21145 L
s
.46022 .2114 m
.46086 .21119 L
s
.40064 .23473 m
.40127 .23444 L
s
.40133 .23447 m
.40197 .23418 L
s
.459 .21188 m
.45964 .21167 L
s
.45958 .21161 m
.46022 .2114 L
s
.40127 .23444 m
.40191 .23415 L
s
.40197 .23418 m
.40261 .2339 L
s
.45836 .21209 m
.459 .21188 L
s
.45894 .21182 m
.45958 .21161 L
s
.40191 .23415 m
.40255 .23386 L
s
.40261 .2339 m
.40324 .23361 L
s
.45772 .21231 m
.45836 .21209 L
s
.4583 .21204 m
.45894 .21182 L
s
.40255 .23386 m
.40318 .23358 L
s
.40324 .23361 m
.40388 .23333 L
s
.45708 .21252 m
.45772 .21231 L
s
.45766 .21225 m
.4583 .21204 L
s
.40318 .23358 m
.40382 .23329 L
s
.40388 .23333 m
.40452 .23304 L
s
.45643 .21274 m
.45708 .21252 L
s
.45702 .21247 m
.45766 .21225 L
s
.40382 .23329 m
.40446 .23301 L
s
.40452 .23304 m
.40515 .23276 L
s
.45579 .21296 m
.45643 .21274 L
s
.45638 .21269 m
.45702 .21247 L
s
.40446 .23301 m
.4051 .23272 L
s
.45515 .21318 m
.45579 .21296 L
s
.40515 .23276 m
.40579 .23247 L
s
.45573 .2129 m
.45638 .21269 L
s
.4051 .23272 m
.40573 .23244 L
s
.45451 .2134 m
.45515 .21318 L
s
.40579 .23247 m
.40643 .23219 L
s
.45509 .21312 m
.45573 .2129 L
s
.45387 .21362 m
.45451 .2134 L
s
.40573 .23244 m
.40637 .23216 L
s
.40643 .23219 m
.40707 .23191 L
s
.45445 .21334 m
.45509 .21312 L
s
.45323 .21384 m
.45387 .21362 L
s
.40637 .23216 m
.40701 .23188 L
s
.40707 .23191 m
.40771 .23163 L
s
.45381 .21356 m
.45445 .21334 L
s
.45259 .21406 m
.45323 .21384 L
s
.40771 .23163 m
.40834 .23135 L
s
.40701 .23188 m
.40765 .2316 L
s
.45317 .21378 m
.45381 .21356 L
s
.45194 .21428 m
.45259 .21406 L
s
.40834 .23135 m
.40898 .23107 L
s
.40765 .2316 m
.40829 .23132 L
s
.45253 .214 m
.45317 .21378 L
s
.4513 .2145 m
.45194 .21428 L
s
.40898 .23107 m
.40962 .23079 L
s
.40829 .23132 m
.40892 .23104 L
s
.45189 .21423 m
.45253 .214 L
s
.45066 .21473 m
.4513 .2145 L
s
.40962 .23079 m
.41026 .23052 L
s
.40892 .23104 m
.40956 .23076 L
s
.45124 .21445 m
.45189 .21423 L
s
.45002 .21495 m
.45066 .21473 L
s
.41026 .23052 m
.4109 .23024 L
s
.40956 .23076 m
.4102 .23048 L
s
.4506 .21468 m
.45124 .21445 L
s
.44938 .21518 m
.45002 .21495 L
s
.4109 .23024 m
.41154 .22997 L
s
.4102 .23048 m
.41084 .23021 L
s
.44996 .2149 m
.4506 .21468 L
s
.44874 .2154 m
.44938 .21518 L
s
.41154 .22997 m
.41218 .22969 L
s
.41084 .23021 m
.41148 .22993 L
s
.44932 .21513 m
.44996 .2149 L
s
.44809 .21563 m
.44874 .2154 L
s
.41218 .22969 m
.41282 .22942 L
s
.41148 .22993 m
.41212 .22965 L
s
.44745 .21586 m
.44809 .21563 L
s
.44868 .21535 m
.44932 .21513 L
s
.41282 .22942 m
.41346 .22914 L
s
.41212 .22965 m
.41276 .22938 L
s
.44681 .21609 m
.44745 .21586 L
s
.44803 .21558 m
.44868 .21535 L
s
.41346 .22914 m
.4141 .22887 L
s
.41276 .22938 m
.4134 .22911 L
s
.44617 .21632 m
.44681 .21609 L
s
.44739 .21581 m
.44803 .21558 L
s
.4141 .22887 m
.41474 .2286 L
s
.4134 .22911 m
.41404 .22883 L
s
.44553 .21655 m
.44617 .21632 L
s
.44675 .21604 m
.44739 .21581 L
s
.41474 .2286 m
.41538 .22833 L
s
.44488 .21678 m
.44553 .21655 L
s
.41404 .22883 m
.41468 .22856 L
s
.44611 .21627 m
.44675 .21604 L
s
.41538 .22833 m
.41602 .22806 L
s
.44424 .21701 m
.44488 .21678 L
s
.41468 .22856 m
.41532 .22829 L
s
.44547 .2165 m
.44611 .21627 L
s
.41602 .22806 m
.41666 .22779 L
s
.4436 .21725 m
.44424 .21701 L
s
.41532 .22829 m
.41596 .22802 L
s
.44482 .21673 m
.44547 .2165 L
s
.41666 .22779 m
.4173 .22752 L
s
.44296 .21748 m
.4436 .21725 L
s
.41596 .22802 m
.4166 .22775 L
s
.4173 .22752 m
.41794 .22726 L
s
.44418 .21696 m
.44482 .21673 L
s
.44232 .21772 m
.44296 .21748 L
s
.41794 .22726 m
.41858 .22699 L
s
.4166 .22775 m
.41724 .22749 L
s
.44354 .2172 m
.44418 .21696 L
s
.44167 .21795 m
.44232 .21772 L
s
.41858 .22699 m
.41922 .22672 L
s
.41724 .22749 m
.41788 .22722 L
s
.4429 .21743 m
.44354 .2172 L
s
.44103 .21819 m
.44167 .21795 L
s
.41922 .22672 m
.41986 .22646 L
s
.41788 .22722 m
.41852 .22695 L
s
.44226 .21767 m
.4429 .21743 L
s
.44039 .21843 m
.44103 .21819 L
s
.41986 .22646 m
.4205 .2262 L
s
.43975 .21866 m
.44039 .21843 L
s
.41852 .22695 m
.41916 .22669 L
s
.44161 .2179 m
.44226 .21767 L
s
.4205 .2262 m
.42114 .22593 L
s
.4391 .2189 m
.43975 .21866 L
s
.41916 .22669 m
.4198 .22642 L
s
.44097 .21814 m
.44161 .2179 L
s
.42114 .22593 m
.42178 .22567 L
s
.43846 .21914 m
.4391 .2189 L
s
.4198 .22642 m
.42044 .22616 L
s
.44033 .21838 m
.44097 .21814 L
s
.42178 .22567 m
.42242 .22541 L
s
.43782 .21938 m
.43846 .21914 L
s
.42242 .22541 m
.42306 .22515 L
s
.42044 .22616 m
.42108 .22589 L
s
.43969 .21862 m
.44033 .21838 L
s
.43718 .21963 m
.43782 .21938 L
s
.42306 .22515 m
.4237 .22489 L
s
.43654 .21987 m
.43718 .21963 L
s
.42108 .22589 m
.42172 .22563 L
s
.43905 .21886 m
.43969 .21862 L
s
.4237 .22489 m
.42434 .22463 L
s
.43589 .22011 m
.43654 .21987 L
s
.42172 .22563 m
.42236 .22537 L
s
.4384 .2191 m
.43905 .21886 L
s
.42434 .22463 m
.42499 .22437 L
s
.43525 .22035 m
.43589 .22011 L
s
.42499 .22437 m
.42563 .22411 L
s
.43461 .2206 m
.43525 .22035 L
s
.42236 .22537 m
.423 .22511 L
s
.43776 .21934 m
.4384 .2191 L
s
.42563 .22411 m
.42627 .22386 L
s
.43397 .22085 m
.43461 .2206 L
s
.42627 .22386 m
.42691 .2236 L
s
.43712 .21958 m
.43776 .21934 L
s
.423 .22511 m
.42364 .22485 L
s
.43333 .22109 m
.43397 .22085 L
s
.42691 .2236 m
.42755 .22335 L
s
.43268 .22134 m
.43333 .22109 L
s
.42755 .22335 m
.42819 .22309 L
s
.43204 .22159 m
.43268 .22134 L
s
.43648 .21982 m
.43712 .21958 L
s
.42364 .22485 m
.42428 .22459 L
s
.42819 .22309 m
.42883 .22284 L
s
.4314 .22184 m
.43204 .22159 L
s
.42883 .22284 m
.42948 .22259 L
s
.43076 .22209 m
.4314 .22184 L
s
.42948 .22259 m
.43012 .22234 L
s
.43012 .22234 m
.43076 .22209 L
s
.43583 .22006 m
.43648 .21982 L
s
.42428 .22459 m
.42493 .22433 L
s
.43519 .22031 m
.43583 .22006 L
s
.42493 .22433 m
.42557 .22407 L
s
.43455 .22055 m
.43519 .22031 L
s
.42557 .22407 m
.42621 .22382 L
s
.43391 .2208 m
.43455 .22055 L
s
.42621 .22382 m
.42685 .22356 L
s
.43327 .22105 m
.43391 .2208 L
s
.42685 .22356 m
.42749 .2233 L
s
.43262 .22129 m
.43327 .22105 L
s
.42749 .2233 m
.42813 .22305 L
s
.43198 .22154 m
.43262 .22129 L
s
.42813 .22305 m
.42877 .2228 L
s
.43134 .22179 m
.43198 .22154 L
s
.42877 .2228 m
.42942 .22254 L
s
.4307 .22204 m
.43134 .22179 L
s
.42942 .22254 m
.43006 .22229 L
s
.43006 .22229 m
.4307 .22204 L
s
.25 Mabswid
.68363 0 m
.97692 .43869 L
s
.97692 .43869 m
1 .61171 L
s
1 .61171 m
.69379 .18935 L
s
.69379 .18935 m
.68363 0 L
s
.02819 .25327 m
0 .43447 L
s
0 .43447 m
.69379 .18935 L
s
.69379 .18935 m
.68363 0 L
s
.68363 0 m
.02819 .25327 L
s
.02819 .25327 m
.68363 0 L
s
.14819 .2069 m
.15283 .21155 L
s
gsave
.13891 .19759 -50.9489 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.28114 .15552 m
.28557 .16038 L
s
[(0)] .2723 .1458 .91013 1 Mshowa
.42095 .1015 m
.42512 .10658 L
s
gsave
.4126 .09135 -41.0009 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.56814 .04462 m
.57203 .04992 L
s
gsave
.56036 .03403 -28.6176 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.125 Mabswid
.17426 .19682 m
.17702 .19964 L
s
.20058 .18665 m
.20332 .18949 L
s
.22717 .17638 m
.22988 .17924 L
s
.25402 .166 m
.2567 .16889 L
s
.30854 .14494 m
.31116 .14788 L
s
.33621 .13424 m
.33881 .13721 L
s
.36417 .12344 m
.36673 .12643 L
s
.39241 .11253 m
.39495 .11555 L
s
.44977 .09036 m
.45225 .09343 L
s
.4789 .07911 m
.48134 .0822 L
s
.50834 .06773 m
.51074 .07086 L
s
.53808 .05624 m
.54045 .05939 L
s
.12238 .21687 m
.12519 .21964 L
s
.09682 .22675 m
.09965 .22949 L
s
.0715 .23653 m
.07436 .23925 L
s
.04643 .24622 m
.04931 .24891 L
s
.59852 .03289 m
.60082 .03609 L
s
.62922 .02102 m
.63148 .02425 L
s
.66026 .00903 m
.66248 .01229 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 221.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00015B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00ooooool7ooooo`;ok^k^0oooool2onk^kU_ooooo003oooooo`7ooooo00goA4A4o`000?l0
003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^C?ooool00?oooooo1?ooool02OmgMgOo<S8boooooooo
ooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`1<ooooo`00moooool6o`0000Oooooo00Oo0000ooooooooooooooooomgMgOl0003o
gMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@04cooooo003o
ooooo`Cooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000C?ooool00;?ooooo0_o^k^h3ooooo`;o
k^k^A_ooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^
k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000C?ooool00:go
oooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^=oooool00ol0003ooooooooo
o`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@04cooooo002`ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool3o`000003ooooool0003o000000;o0000@Oooool00;7ooooo00Oo0000ooooooooooooooooomgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Oo
oooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`05o`000?ooooooooooooooool00000@oooool00;3ooooo00WoMgMgoc8b<_ooooooooooonk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000:?ooool2o`0002gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`00
[Oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000009Oooool5o`0002go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`00[Oooool00ol0003ooooo
ooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@02;ooooo0ol00004ooooo`;o0000;?ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo03oooooo002]ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg023ooooo0_l000000ooooooo0000ooooo`04oooo
o`03o`000?oooooo000002[ooooo0_l00003ooooo`;o0000@_ooool00:gooooo1?l0000<ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?oooooo`00
0?l000000_l0000Booooo`?o00002Oooool00ol0003oooooo`00001cooooo`00cOooool01Ol0003o
oooooooooooooooo000001;ooooo0_l0000<ooooo`04o`000?ooooooooooo`0007;ooooo003=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool3o`0000kooooo00Go0000oooo
ooooooooooooo`00001aooooo`00cOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo0ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00ol0001`oooo
o`00cOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo0_l0000Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0K_ooool00<cooooo0_l00003ooooo`;o
00001_ooool3o`0001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1]ooooo`00
eoooool2o`000003ooooool0003ooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1]ooooo`00e?ooool3o`0001cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1/ooooo`00dOooool3o`0001oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1[
ooooo`00ROooool2onk^kP?ooooo0_o^k^hoooooo`?o00008Oooool00ol0003oooooooooo`04oooo
o`;o0000K?ooool007;ooooo1Ol00005ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgM
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h]ooooo`?o00000oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0J_ooool007;ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`;o00009oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Wooooo001cooooo`03oiRHV?lQ8B7ok^k^
017ooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Sooooo0ol0000Yooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0JOooool007Cooooo00?oV9RHob4Q8Oo^k^h03oooool02OmgMgOo<S8boooo
ooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Uooooo`?o00000_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0J?ooool007Gooooo00?oMgMgofIVI_ooool02oooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000008oooool2o`0002oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Wooooo`00M_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41008?ooool3o`00037ooooo00?o0000ooooooooool02?ooool2
o`0006Sooooo001booooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o000000?o
ooooo`000?l000000_l0000Booooo`?o000000?oooooo`000?ooool0<Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo06Kooooo001booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00Go0000ooooooooooooooooo`00000Booooo`;o0000=oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02Oooooo0_o^k^h3ooooo`;ok^k^=oooool00:?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0<ooooo`?o0000>Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo013ooooo1Ol00005ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMoooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hXooooo`00Xoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo0_l000000ooooooo0000ooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`09ogMgMolb<S;o
ooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Sooooo002Sooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01_ooool3o`0003kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`07o`000?oooooooooooooooooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Xooooo`00X_oo
ool2o`0000?ooooo0_l00006ooooo`?o0000@Oooool00ol0003oooooooooo`0<ooooo`;o00004Ooo
ool00onHV9So8B4Qonk^kP0?ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002Sooooo002]oooo
o`;o000000?oooooo`000?ooool0@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
013ooooo00?oMgMgofIVI_ooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000:?ooool00:[ooooo0ol00016ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3oooo
o`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?ooool0
0:Sooooo0_l0001:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool01Ol0
003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool00:Gooooo0ol0001<ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o0000
00?oooooo`000?l000000_l0000Mooooo`00X_ooool3o`0000?ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo00Go0000oooooooooooooooo
o`00000Oooooo`00X?ooool2o`0005;ooooo00?o0000ooooooooool03oooool2o`0003cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`00MOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^02?ooooo0ol0001Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooool00000??oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo001eooooo`05ogMgMonHV9So
oooooiRHV?mgMgL08Oooool2o`0000;ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0Kooooo`00MOooool01Ol@413ooooooooooooooooo410@01kooooo0ol0001Iooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0=oooool2o`0000?ooooo0_l0000Nooooo`00MOoo
ool01Ol0003ooooooooooooooooo000001_ooooo0ol0001Looooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0G?ooool007Gooooo00Go0000ooooooooooooooooo`00000Iooooo`;o0000
0_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
Foooool007Gooooo00Go410@oooooooooooooooooa0@400Fooooo`?o0000HOooool00ol0003ooooo
ooooo`0Booooo`?o0000G?ooool007Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`?o0000
I?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05[ooooo001eooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04Oooool2o`0000;ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05Wooooo0028ooooo`?o0000JOooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo05Sooooo0026ooooo`;o0000K?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo05Sooooo0023ooooo`?o000000?oooooo`000?ooool0Joooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo05Oooooo000fooooo`;ok^k^0oooool2onk^kT?o
oooo0ol0001aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool00000F?ooool001oooooo
1Ol00005ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hb
ooooo`;o0000M?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05Kooooo000Ooooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0;oooool3o`0000;ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo05Gooooo000Gooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`07
o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400]ooooo`;o0000N_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo05Cooooo000Qooooo`03oiRHV?lQ8B7ok^k^00oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000:_ooool3o`0007cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Doooo
o`008_ooool00omgMgOoIVIVooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Wooooo`?o00000_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
01Wooooo0_l0001Eooooo`008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?o
oooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41009Oooool2o`0008;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Boooo
o`007oooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`000003ooooool0003o
000000;o00005oooool3o`0008Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1B
ooooo`007oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000<ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05o`000?ooooooooooooooool00000
5oooool2o`0000;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo057ooooo001@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Ooo
ool3o`0006Wooooo7?l00004ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0D?oo
ool0053ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`?o0000I?ooool9
o`0001Wooooo2?l0000Nooooo`;o00001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Gooooo001@
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02oooool2o`0000;ooooo00?o
0000ooooooooool0G?ooool7o`0002Kooooo2?l0000Iooooo`;o00001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg04Gooooo001?ooooo`;o00000oooool2o`0000_ooooo0ol0001Nooooo`Ko0000:Ooo
ool3o`000003ooooool0003ooooo00Cooooo1Ol0000Gooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4015ooooo`00G_ooool3o`0005gooooo1Ol0000[ooooo`?o00001Ooo
ool00ol0003oooooooooo`06ooooo`Co00005?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool00000AOooool005cooooo0_l00003ooooo`03o`000?oooooooooo05Kooooo1Ol0
000/ooooo`?o00002Oooool00ol0003oooooooooo`08ooooo`Co00004_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool00000AOooool005Wooooo0ol0001Kooooo`Co0000;Ooo
ool3o`0000gooooo00?o0000ooooooooool02_ooool3o`00017ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@04Gooooo001Gooooo`?o0000F_ooool4o`0002gooooo0ol0
000@ooooo`03o`000?oooooooooo00gooooo0ol0000<ooooo`?o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg04Gooooo001Dooooo`?o00000oooool00ol0003oooooooooo`1Cooooo`Co0000;ooo
ool2o`0001Cooooo00?o0000ooooooooool03_ooool3o`0000gooooo00Wo0000oooooooooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h0AOooool0057ooooo0ol0001Jooooo`?o0000;oooool3o`0001Oo
oooo00?o0000ooooooooool03oooool3o`0000cooooo00?o0000ooooooooool0B_ooool004oooooo
1?l0001Hooooo`?o0000;oooool3o`0001[ooooo00?o0000ooooooooool04Oooool2o`0000_ooooo
00?o0000ooooooooool0B_ooool004cooooo0ol0001Iooooo`Co0000;_ooool3o`0001kooooo00?o
0000ooooooooool04Oooool3o`0000[ooooo00?o0000ooooooooool0BOooool004[ooooo0_l0001J
ooooo`?o0000;_ooool3o`0002;ooooo00?o0000ooooooooool04_ooool2o`0000Wooooo0_l0001:
ooooo`00Aoooool3o`000003ooooool0003ooooo05Oooooo0ol0000]ooooo`?o00009_ooool00ol0
003oooooooooo`0Booooo`?o00002?ooool00ol0003oooooooooo`18ooooo`00A?ooool3o`0005[o
oooo0ol0000]ooooo`?o0000:Oooool00ol0003oooooooooo`0Dooooo`;o00002?ooool00ol0003o
ooooooooo`17ooooo`00@_ooool2o`0005_ooooo0ol0000]ooooo`;o0000;Oooool00ol0003ooooo
ooooo`0Dooooo`;o00002?ooool00ol0003oooooooooo`16ooooo`00?oooool3o`0000;ooooo00?o
0000ooooooooool0E_ooool3o`0002cooooo0ol0000`ooooo`03o`000?oooooooooo01Cooooo0_l0
0007ooooo`03o`000?oooooooooo04Kooooo000mooooo`;o0000G?ooool3o`0002_ooooo0ol0000d
ooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`;o0000Aoooool003[ooooo0ol0001Loooo
o`?o0000:_ooool3o`0003Oooooo00?o0000ooooooooool05Oooool2o`0000Oooooo00?o0000oooo
ooooool0A?ooool003Oooooo0ol00002ooooo`03o`000?oooooooooo05Sooooo0ol0000Yooooo`?o
0000>oooool00ol0003oooooooooo`0Eooooo`;o00001_ooool00ol0003oooooooooo`14ooooo`00
=_ooool2o`0005gooooo0ol0000Xooooo`?o0000?oooool00ol0003oooooooooo`0Eooooo`;o0000
1_ooool00ol0003oooooooooo`13ooooo`00=_ooool00ol0003oooooo`00001Kooooo`;o0000:?oo
ool2o`0004;ooooo00?o0000ooooooooool05_ooool2o`0000Kooooo00?o0000ooooooooool0@_oo
ool001;ooooo0_o^k^h3ooooo`;ok^k^7Oooool4o`0005Sooooo0_l0000Wooooo`?o0000AOooool0
0ol0003oooooooooo`0Fooooo`;o00001?ooool3o`0004?ooooo000;ooooo`Go00000_ooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h>ooooo`05o`000?ooooooooooooooool00000EOooool3o`0001;ooooo4Ol00002
ooooo`?o0000BOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07oooool2onk^kP?ooooo0_o^k^hKooooo`002oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
DOooool2o`0000[ooooo2ol0000?ooooo`_o0000AOooool00ol0003oooooooooo`0Eooooo`;o0000
1_ooool00ol0003oooooooooo`07ooooo`Go00001Oooool2ob4Q8@Gooooo00goA4A4o`000?l0003o
<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool000?ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool3o`0000Cooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo1_l0000G
ooooo`?o00002_ooool7o`0003oooooo00?o0000ooooooooool05_ooool2o`0000Gooooo00?o0000
ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo000=ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool3o`0000;ooooo1Ol0
000Jooooo`?o00004oooool6o`0003_ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h04Oooool01ol0003ooooooooo
oooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool000kooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0BOooool7o`0001cooooo0_l0000Kooooo`Go
0000>?ooool00ol0003oooooooooo`0Eooooo`;o00001Oooool2o`0000Wooooo00?oV9RHob4Q8Oo^
k^h03oooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000<ooooo`003oooool00ol0003ooooooooo
o`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`;o00002?ooool00ol0003oooooooooo`16ooooo`Go00007Oooool3o`00027ooooo
1?l0000eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`03ogMgMomVIVKooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000cooooo000;ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo04;ooooo1?l0000Nooooo`?o00009oooool4o`0003?ooooo00?o0000oooo
ooooool05Oooool2o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003?ooool000_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?o
ooooo`000?l000000_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?_oo
ool6o`0001cooooo0ol0000]ooooo`Co0000<Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool01Ol0003o^[ZjoooooonHV9So410@00cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool3o`000003ooooool0003o000000;o00000Oooool002cooooo00Go0000oooooooooooo
ooooo`000003ooooo`?o00002oooool2o`0003cooooo0ol000000ooooooo0000o`00000Kooooo`?o
0000<oooool4o`0002oooooo00?o0000ooooooooool05?ooool2o`0000Kooooo00?o0000oooooooo
ool00oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000<ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05o`000?ooooooooooooooool000000ooo
ool002cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000?ooooo`03o`000?oo
oooooooo03Kooooo1?l00002ooooo`;o00006Oooool3o`0003Wooooo0ol0000]ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool3o`0003Gooooo00?o0000ooooooooool00_oo
ool1o`00007ooooo0Oooool002cooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l0
000?ooooo`03o`000?oooooooooo03?ooooo0ol00004ooooo`;o00005oooool3o`0003kooooo0ol0
000/ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00;?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0<?ooool3o`0000Cooooo0_l0
000Gooooo`;o0000@oooool3o`0002_ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00000_ooool1o`00007ooooo
000[ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0]ooooo`?o00001Oooool2o`0001Gooooo0ol00017ooooo`?o0000:_ooool00ol0003ooooooooo
o`0Booooo`;o00002?ooool00ol0003oooooooooo`0`ooooo`;o00000oooool2o`0000;ooooo000@
ooooo`;ok^k^0oooool2onk^kQgooooo0ol0000Aooooo`03o`000?oooooooooo02[ooooo0ol00006
ooooo`;o00004oooool3o`0004cooooo0ol0000Xooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0hooooo`002_ooool4o`000009oa0@4?ooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3Oooool2o`0001Cooooo00?o0000ooooooooool0:?ooool2o`0000Oooooo0_l0000A
ooooo`?o0000DOooool2o`0002Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06
ooooo`;o0000>_ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`;o00002?ooool2o`0000oooooo0ol0
001Fooooo`;o00009oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0=oooool00003ooooool0003o000000Co00001Oooool00ol0003oooooooooo`03
ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00gooooo0_l0000Fooooo`03o`000?oooooooooo02;ooooo0ol00007ooooo`?o00003Ooo
ool3o`0005[ooooo0ol0000Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0fooooo`003?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo023ooooo0_l00008ooooo`;o0000
3Oooool2o`0005oooooo0_l0000Uooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`03o`00
0?oooooooooo03Kooooo000<ooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01kooooo0_l00008ooooo`;o00002ooo
ool3o`0001kooooo4Ol0000cooooo`;o00009Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Wooooo0_l0000fooooo`003?ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o0000
6Oooool2o`0001cooooo0ol00008ooooo`;o00002Oooool3o`0001[ooooo2?l0000?ooooo`So0000
;Oooool2o`0002Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000003Kooooo000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol000000ooooooo0000o`000002o`0000;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`;o00002Oooool2o`0000Oooooo
0ol0000Hooooo`Ko00007Oooool6o`0002[ooooo0_l0000Sooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`002_ooool00omEEEGoIVIVo`00
000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Ko
oooo0_l00009ooooo`;o00001Oooool3o`0001Sooooo1?l0000Wooooo`Co0000:?ooool2o`0002?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?o
oooo000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ol0000Mooooo`03o`00
0?oooooooooo01Cooooo0_l00009ooooo`;o00000oooool3o`0001Sooooo1?l0000]ooooo`Co0000
9_ooool2o`0002?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo03;ooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000008?oo
ool00ol0003oooooooooo`0Booooo`;o00002Oooool2o`000004ooooool0003o0000o`0001Sooooo
1?l0000cooooo`Co00009?ooool2o`0002?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`;o00004?ooool2onk^kP?ooooo0_o^k^hLooooo`00:_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool04?ooool2o`0000[ooooo
0ol0000Iooooo`?o0000>Oooool3o`0002?ooooo0_l0000Rooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`0=odA4A?l0003o0000oc8b<_oM
gMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kPgooooo000Yooooo`;o00000oooool2o`0000;ooooo0_l0000Qoooo
o`03o`000?oooooooooo00kooooo0_l00009ooooo`?o00006Oooool3o`0003gooooo0ol0000Roooo
o`;o00008_ooool00ol0003oooooooooo`0:ooooo`;o00004?ooool00ol0003oooooooooo`0:oooo
o`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo000booooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool03?ooool2o`0000Oooooo1?l0000Iooooo`?o0000@Oooool3o`00027ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02_ooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool0037ooooo00?o0000oooo
ool000008oooool00ol0003oooooooooo`0:ooooo`;o00001Oooool3o`0000;ooooo0_l0000Hoooo
o`;o0000AOooool3o`0001oooooo0_l0000Rooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`09ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000go
oooo000aooooo`;o00009Oooool00ol0003oooooooooo`08ooooo`;o00000oooool3o`0000Cooooo
0_l0000Gooooo`?o0000B?ooool2o`0001oooooo0_l0000Rooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04?ooool2o`0000Oooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000gooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000_l00006ooooo`;o
00005oooool2o`0004_ooooo0ol0000Nooooo`;o00008_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0002Oooooo00?o0000oooo
ooooool01Oooool3o`0000Sooooo0_l0000Gooooo`;o0000C_ooool2o`0001kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0=ooooo`009oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool09oooool2o`0000?ooooo0ol0000:ooooo`03o`000?oooooooooo01Cooooo0ol0001@
ooooo`;o00007Oooool2o`0002;ooooo00?o0000ooooooooool01Oooool2o`0001Gooooo00?o0000
ooooooooool00oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo0ol000000ooooooo0000o`000002o`0000;ooooo000Wooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0Yooooo`?o000000?oooooo`000?ooool02Ooo
ool2o`0001Gooooo0_l0001Cooooo`;o00007Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05?ooool2o`0002Cooooo00Go0000oooooooooooooooo
o`000004ooooo`009oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Wooooo`?o0000
00?oooooo`000?ooool00_l00009ooooo`;o00005Oooool2o`0005Gooooo0_l0000Looooo`;o0000
8oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000
9?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo007ooooo000Wooooo`05oa0@4?oo
ooooooooooooool@41001?ooool2o`0002Gooooo0ol00005ooooo`;o00002_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo05Gooooo0_l0000Looooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`04ooooo`03o`000?oooooooooo027ooooo0ol00008ooooo`;o00002Oooool2o`0001Gooooo
00?o0000ooooooooool08Oooool@o`0002Kooooo0_l0000Kooooo`;o00008oooool01?l0003ooooo
ooooooooool2o`0001Wooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00002oooo
o`7o00000Oooool1ooooo`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l0000Poooo
o`;o00002oooool00ol0003oooooo`000007ooooo`;o00005Oooool2o`0001oooooo1_l0000=oooo
o`Go00008oooool2o`0001_ooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0000J
ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`;o00000oooool0033ooooo00?o0000oooo
ooooool07?ooool3o`0000cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04oooool2o`0001gooooo1?l0000Fooooo`Co00008Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooool000006_ooool2o`0002[ooooo000`ooooo`03
o`000?oooooooooo01Wooooo0ol0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool2o`0001Gooooo00?o0000ooooooooool06_ooool4o`0001_ooooo0ol0000Oooooo`;o
00006_ooool2o`0002Cooooo0ol0000Looooo`03o`000?oooooooooo02Oooooo000`ooooo`;o0000
5oooool3o`0001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`0001Gooooo
0_l0000Kooooo`;o00008?ooool3o`0001kooooo0_l0000Jooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`00;oooool2o`0001Gooooo0ol0
000Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000005_ooool00ol0003ooooooooo
o`0Hooooo`?o00008oooool2o`0001kooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Rooooo`?o00007Oooool00ol0003oooooooooo`0Vooooo`002oooool2onk^kP?ooooo0_o^k^hM
ooooo`03o`000?oooooooooo017ooooo0ol0000Gooooo`;o00001oooool2o`0001Gooooo0_l0000I
ooooo`;o00009_ooool2o`0001gooooo0_l0000Iooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00006oooool3o`0002Oooooo0005ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h>ooooo`?o00003_ooool3o`0001[ooooo00?o0000ooooooooool01_ooool3o`0001Cooooo00?o
0000ooooooooool05oooool2o`0002Sooooo0_l0000Mooooo`03o`000?oooooooooo01Oooooo0_l0
000Sooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool09Oooool000Oooooo00?o
0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool03?ooool2o`0001go
oooo00?o0000ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Fooooo`;o00003_ooool=o`0000oooooo0_l0000Looooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09?ooool000Oooooo00?o0000ooooooooool00oooool00ooMgMgo0000
omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00Wooooo0ol0000Oooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo0_l0000=ooooo`?o
00002oooool4o`0000gooooo0_l0000Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool08oooool000Oooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo0_l00007oooo
o`?o00008_ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`0>oooo
o`;o00005_ooool2o`0000cooooo0ol0000@ooooo`;o00003Oooool00ol0003oooooooooo`0Ioooo
o`;o00006Oooool00ol0003oooooooooo`0Oooooo`;o00001Oooool00ol0003oooooooooo`0Joooo
o`;o00009Oooool000Oooooo00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00?ooooo0ol0000Uooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02_ooool2o`0001?ooooo0ol0000;ooooo`;o00006oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01kooooo0_l00007ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool08_ooool000Oooooo00Co0000oooooooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool01?l0003oooooooooooooool3
o`0002Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`;o00005_ooool2
o`0000_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo027ooooo0007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00gooooo1?l0000[ooooo`03o`000?oooooooooo00?ooooo0_l00009
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool2o`0000[ooooo0_l0000H
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01gooooo0_l0000:ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool08Oooool000Gooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003ooooool0003o000000;o00000_ooool2
o`0002gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo2?l00008ooooo`;o00002_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool08?ooool002Gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0F
ooooo`;o00007_ooool2o`0000cooooo00?o0000ooooooooool06Oooool3o`00027ooooo000Uoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08oooo
o`;o00005Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`000002ooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Looooo`;o00003_ooool0
0ol0003oooooooooo`0Eooooo`?o00000_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`;o00001oooool2o`0000[ooooo00?o0000ooooooooool06?ooool2o`00
01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
017ooooo0ol00005ooooo`03o`000?oooooooooo01oooooo000Uooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool2o`0000Sooooo00?o0000ooooooooool04oooool2o`00
00[ooooo00?o0000ooooooooool01oooool8o`0000Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Iooooo`;o00006?ooool00ol0003oooooooooo`0Kooooo`;o00004?ooool00ol0
003oooooooooo`0=ooooo`Co00002?ooool00ol0003oooooooooo`0Oooooo`009?ooool2o`0000?o
oooo0_l00009ooooo`;o00009oooool2o`0000;ooooo0_l0000Booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`;o00005oooool2o`0000[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`;o00007?ooool2o`0001;o
oooo00?o0000ooooooooool02Oooool3o`0000cooooo00?o0000ooooooooool07oooool003Kooooo
00?o0000ooooooooool09Oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Co
oooo0_l0000Eooooo`;o00002_ooool2o`0001Gooooo0_l0000:ooooo`;o00006oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`Co00004?ooool00ol0003oooooooooo`0Nooooo`00=oooool00ol0003ooooo
ooooo`0Tooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Dooooo`;o00002_ooool2o`0001?ooooo0_l0000:ooooo`;o00006oooool2o`0001So
oooo00?o0000ooooooooool06_ooool2o`0001Cooooo00Co0000oooooooooooooooo0ol0000Doooo
o`03o`000?oooooooooo01kooooo000hooooo`03o`000?oooooooooo02?ooooo0_l000000ooooooo
0000ooooo`0Eooooo`03o`000?oooooooooo00?ooooo0_l0000Fooooo`03o`000?oooooooooo00Wo
oooo1?l0000>ooooo`?o00002_ooool2o`0001cooooo00?o0000ooooooooool05_ooool2o`0001_o
oooo0_l0000Fooooo`?o00005oooool00ol0003oooooooooo`0Nooooo`00>Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Dooooo`?o00002oooool5o`0000Oooooo1Ol0000;ooooo`;o00007?ooool2o`0001Sooooo
00?o0000ooooooooool06Oooool2o`0001?ooooo1?l000000ooooooo0000ooooo`0Gooooo`03o`00
0?oooooooooo01kooooo000jooooo`;o00008oooool2o`0001Wooooo00?o0000ooooooooool00_oo
ool2o`0001Oooooo0_l0000>ooooo`Wo00003Oooool3o`0001gooooo00?o0000ooooooooool05_oo
ool2o`0001[ooooo0_l0000Aooooo`?o00001_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01kooooo000looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`02ooooo`;o00005oooool2o`0002;ooooo0_l0000Nooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`?o00002Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo000mooooo`03o`000?oooooooooo
023ooooo0_l0000Jooooo`03o`000?oooooooooo00;ooooo0_l0000Gooooo`?o00007_ooool3o`00
01kooooo0_l0000Hooooo`;o00006_ooool2o`0000_ooooo1?l0000=ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool07_ooool003kooooo00?o0000ooooooooool07oooool2o`0001_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`Co00006?ooool4o`0001oo
oooo0_l0000Iooooo`03o`000?oooooooooo01Sooooo0_l00009ooooo`?o00004_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01kooooo000oooooo`;o00007oooool3o`0001_ooooo
00Co0000oooooooooooooooo0_l0000Kooooo`Co00004_ooool4o`00027ooooo0_l0000Iooooo`;o
00006Oooool2o`0000Kooooo1?l0000Fooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool07Oooool0047ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00000Looooo`;o0000
0_ooool2o`0001gooooo2?l00004ooooo`So00008oooool2o`0001Wooooo0_l0000Iooooo`;o0000
1?ooool3o`0001[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Mooooo`00@_oo
ool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool0
0ol0000Rooooo`Ko0000:Oooool2o`0001[ooooo00?o0000ooooooooool05oooool2o`0000;ooooo
0ol0000Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool004?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02o`0001gooooo00Co0000oooooooooooooooo
0_l0001?ooooo`;o00006_ooool00ol0003oooooooooo`0Gooooo`Go00008_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01gooooo0014ooooo`03o`000?oooooooooo01Wooooo00Co
0000oooooooooooooooo0_l0000Mooooo`04o`000?ooooooooooooooo`;o0000COooool2o`0001[o
oooo0_l0000Gooooo`?o00009_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01go
oooo0015ooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`;o00007Oooool01?l0003ooooo
ooooooooool3o`0004Wooooo0ol0000Jooooo`;o00005Oooool5o`0002Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Mooooo`00Aoooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00?ooooo0_l0000Mooooo`03o`000?oooooooooo00;ooooo0_l00017ooooo`;o0000
6oooool2o`0001;ooooo1?l00002ooooo`;o0000:_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01gooooo0018ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?oo
ool2o`0001gooooo00?o0000ooooooooool00_ooool3o`0004?ooooo0ol0000Kooooo`;o00004?oo
ool3o`0000Gooooo0_l0000/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Ooo
ool004Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`;o00007Oooool0
0ol0003oooooooooo`03ooooo`?o0000?oooool3o`0001cooooo0_l0000=ooooo`Co00001oooool2
o`0002gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`00B_ooool00ol0
003oooooooooo`0Cooooo`;o00001oooool2o`0001gooooo00?o0000ooooooooool01?ooool3o`00
03_ooooo0ol0000Mooooo`;o00002oooool3o`0000Wooooo0_l0000`ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool07?ooool004_ooooo0_l0000Dooooo`03o`000?oooooooooo00Ko
oooo0_l0000Mooooo`03o`000?oooooooooo00Gooooo1?l0000fooooo`?o00007_ooool2o`0000Wo
oooo0ol0000;ooooo`;o0000<_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01co
oooo001=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool2o`0001gooooo
00?o0000ooooooooool01oooool3o`00037ooooo0ol0000Oooooo`?o00001_ooool4o`0000gooooo
0_l0000dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool004kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`;o00007Oooool00ol0003ooooooooo
o`08ooooo`Go0000:_ooool4o`00023ooooo0_l00005ooooo`?o00004?ooool2o`0003Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`00Coooool00ol0003oooooooooo`0?
ooooo`;o00002_ooool3o`0001cooooo0_l0000<ooooo`Go00008_ooool5o`0002;ooooo0_l00003
ooooo`?o00004Oooool3o`0003Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0L
ooooo`00D?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo0_l0000Moooo
o`03o`000?oooooooooo00gooooo1_l0000Gooooo`Oo00009?ooool2o`000003ooooool0003o0000
00;o00004oooool2o`0003[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Loooo
o`00DOooool2o`0000oooooo00?o0000ooooooooool02oooool3o`0001cooooo00?o0000oooooooo
ool04OoooolIo`0002Sooooo1Ol0000Fooooo`;o0000>oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01cooooo001Cooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`;o0000
7?ooool00ol0003oooooooooo`1?ooooo`Co00005oooool3o`0003gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`00E?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo0ol0000Kooooo`03o`000?oooooooooo04_ooooo1Ol0000Hooooo`;o0000@?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo001Eooooo`03o`000?oooooo
oooo00_ooooo0_l0000@ooooo`?o00006_ooool00ol0003oooooooooo`17ooooo`Ko00006Oooool2
o`0004;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`00E_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo0ol0000Iooooo`03o`000?oooooooooo
04;ooooo1?l000001?oooooo0000o`000?l0000Iooooo`;o0000A?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01_ooooo001Gooooo`;o00002oooool2o`0001?ooooo0ol0000Hoooo
o`03o`000?oooooooooo03kooooo0ol00003ooooo`?o00006_ooool2o`0004Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Kooooo`00FOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01?ooooo0ol0000Gooooo`03o`000?oooooooooo03[ooooo0ol00003ooooo`Co
00006_ooool3o`0004Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`00
F_ooool00ol0003oooooooooo`08ooooo`;o00005_ooool4o`0001Gooooo00?o0000ooooooooool0
=Oooool4o`0000Cooooo0ol0000Kooooo`?o0000B_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01_ooooo001Kooooo`03o`000?oooooooooo00Sooooo0_l0000Hooooo`Co00004ooo
ool00ol0003oooooooooo`0aooooo`?o00001Oooool4o`0001cooooo0_l0001=ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06oooool005cooooo0_l00009ooooo`03o`000?oooooo
oooo01Wooooo1?l0000Aooooo`;o0000;Oooool4o`0000Gooooo1?l0000Mooooo`?o0000Coooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo001Nooooo`03o`000?oooooooooo
00Kooooo0_l0000Mooooo`Co00004?ooool00ol0003oooooooooo`0Wooooo`?o00001_ooool4o`00
01kooooo0ol0001Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool005oo
oooo00?o0000ooooooooool01_ooool2o`0001oooooo1Ol0000=ooooo`03o`000?oooooooooo02?o
oooo0ol00005ooooo`Go00007oooool3o`0005Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Jooooo`00H?ooool00ol0003oooooooooo`06ooooo`;o00008_ooool5o`0000[ooooo
00?o0000ooooooooool07_ooool4o`0000?ooooo1_l0000Rooooo`;o0000Eoooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01[ooooo001Qooooo`03o`000?oooooooooo00Kooooo0_l0
000Vooooo`Ko00001Oooool00ol0003oooooooooo`0Jooooo`?o000000?oooooo`000?l000001Ol0
000Uooooo`;o0000F_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo001R
ooooo`;o00001oooool2o`0002[ooooo2_l0000Eooooo`Wo0000:Oooool3o`0005cooooo00Go0000
ooooooooooooooooo`00000Looooo`00I?ooool00ol0003oooooooooo`05ooooo`;o0000<OoooolH
o`0002oooooo0ol0001Nooooo`05o`000?ooooooooooooooool000007?ooool006Gooooo00?o0000
ooooooooool01Oooool2o`00037ooooo00?o0000ooooooooool03Oooool3o`00037ooooo0_l0001R
ooooo`04o`000?ooooooooooo`0001cooooo001Vooooo`03o`000?oooooooooo00Gooooo0_l0000a
ooooo`03o`000?oooooooooo00Sooooo1?l0000aooooo`?o0000IOooool00ol0003oooooo`00000L
ooooo`00Ioooool00ol0003oooooooooo`05ooooo`;o0000<Oooool00ol0003oooooooooo`04oooo
o`?o0000<oooool3o`0006Oooooo00Co0000oooooooooooo00006oooool006Sooooo0_l00007oooo
o`;o0000<?ooool00ol0003oooooooooo`03o`0003?ooooo1?l0001Zooooo`03o`000?oooooo0000
01_ooooo001Zooooo`03o`000?oooooooooo00Gooooo0_l0000`ooooo`;o0000=?ooool3o`0006ko
oooo0_l0000Kooooo`00Joooool00ol0003oooooooooo`06ooooo`;o0000;_ooool00ol0003ooooo
ooooo`0`ooooo`Co0000Koooool3o`0001_ooooo001/ooooo`03o`000?oooooooooo00Kooooo0ol0
000/ooooo`03o`000?oooooooooo02kooooo0ol0001^ooooo`Co00007_ooool006gooooo00?o0000
ooooooooool01oooool3o`0002[ooooo00?o0000ooooooooool0:oooool4o`0006gooooo0ol0000R
ooooo`00K_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo02Sooooo1?l0001/oooo
o`Co00009Oooool0073ooooo00?o0000ooooooooool02?ooool3o`0002Kooooo00?o0000oooooooo
ool09?ooool4o`0006cooooo1?l0000Yooooo`00LOooool00ol0003oooooooooo`0:ooooo`?o0000
8oooool00ol0003oooooooooo`0Pooooo`Go0000K?ooool3o`0002gooooo001booooo`03o`000?oo
oooooooo00_ooooo1?l0000Pooooo`03o`000?oooooooooo01cooooo1Ol0001/ooooo`Co0000<?oo
ool007?ooooo00?o0000ooooooooool03Oooool5o`0001cooooo00?o0000ooooooooool06?ooool5
o`0006cooooo1?l0000dooooo`00M?ooool2o`00017ooooo1Ol0000Hooooo`03o`000?oooooooooo
01?ooooo1_l0001]ooooo`?o0000>?ooool007Kooooo00?o0000ooooooooool04_ooool7o`0001;o
oooo00?o0000ooooooooool03?ooool8o`0006kooooo1?l0000kooooo`00Moooool00ol0003ooooo
ooooo`0Gooooo`_o00002?ooool01?l0003oooooooooooooool<o`00077ooooo1?l0000oooooo`00
N?ooool00ol0003oooooooooo`0Pooooo`go0000NOooool4o`0004?ooooo001iooooo`;o0000:?oo
ool00ol0003oooooooooo`1hooooo`?o0000Aoooool007_ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1dooooo`Co0000B_ooool007cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1`ooooo`Co0000C_ooool007gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1]ooooo`?o0000D_ooool007kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`1Yooooo`Co0000EOooool007oooooo0_l0000Rooooo`03o`000?oooooooooo06Gooooo1?l0
001Iooooo`00POooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06;ooooo0ol0001M
ooooo`00P_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05kooooo1?l0001Poooo
o`00Poooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05[ooooo1?l0001Tooooo`00
Q?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Oooooo0ol0001Xooooo`00QOoo
ool2o`0001cooooo00?o0000ooooooooool0Doooool4o`0006_ooooo0027ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0Coooool4o`0006oooooo0028ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0Boooool4o`0007?ooooo0029ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0B?ooool3o`0007Oooooo002:ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A?ooool4o`0007[ooooo002;ooooo`;o00005_ooool00ol0003ooooooooo
o`10ooooo`Co0000O_ooool008gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0m
ooooo`?o0000P_ooool008kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0ioooo
o`Co0000QOooool008oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0eooooo`Co
0000ROooool0093ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`?o0000
SOooool0097ooooo0_l0000@ooooo`03o`000?oooooooooo02kooooo1?l0002@ooooo`00Toooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02[ooooo1?l0002Dooooo`00U?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo1?l0002Hooooo`00UOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo0ol0002Looooo`00U_ooool2o`0000[ooooo
00?o0000ooooooooool08?ooool4o`0009oooooo002Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07?ooool4o`000:?ooooo002Iooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06Oooool3o`000:Oooooo002Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05Oooool4o`000:[ooooo002Kooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04Oooool4o`000:kooooo002Looooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`?o0000
/_ooool009kooooo00Go0000ooooooooooooooooo`00000<ooooo`Co0000]Oooool009oooooo00Co
0000oooooooooooo00002?ooool4o`000;Wooooo002Pooooo`03o`000?oooooo000000Gooooo0ol0
002mooooo`00XOooool2o`000003ooooool0003o000000;o0000`?ooool00:;ooooo0_l00034oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00^oooool01?l@
413o0000o`000?l0001cooooo`?o000000?o410@ooooooooool0<?ooool00;cooooo00?o0000oooo
ooooool0MOooool00ol@413o^[Zjooooo`0aooooo`00_?ooool00ol0003oooooooooo`1eooooo`03
oiRHV?lb<S;ooooo037ooooo000Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00_ooool00ol@413o
0000o`000003o`0000?ooooo00?o410@o`000?n7QhL00_l000001?mVIVKok^k^ooooooooool5o`00
00?ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY
1_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00?o410@o`000?l000000_l000000ol@
413oooooooooo`08ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01?l@413o0000o`000?oo
ool2o`000004oa0@4?ooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool01oooool01_o^k^koEEEE
o`000?l0003oEEEEonk^kP?ooooo00KoV9RHo`000?l0003oMgMgo`000?l@4102ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00009
ooooo`07o`000?mgMgOo0000o`000?mEEEGok^k^ooooo`05o`0000?ooooo00KoV9RHo`000?l0003o
MgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l0
00000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01_l@413o<S8b
o`000?l0003o410@ojVYZ@Kooooo00?o410@o`000?l000000_l000001Ol@413oooooooooooo^k^ko
EEEE00;o000000CoEEEEonk^k_oooooo410@1Ol00009ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:oooo
o`03omgMgOl0003o^[Zj00Cooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`08oiRHV?l0
003o0000ogMgMol@413o0000ooooool@4105o`0000?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nY
ZJT?ooooo`009?ooool01onYZJWo8B4QokZj^_oooooo^[Zjob4Q8OnYZJT00oooool00ol0003ooooo
ooooo`05ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV1?ooool00ol0003oooooooooo`03oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Kooooo
00KoEEEEogMgMoooooooooooogMgMomEEED4ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4003ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgoooo
ooo^k^koMgMgoa0@40Sooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`05o`000?nYZJWo
ooooohN7Qol000000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMooooooo
k^k^ogMgMol@4103ooooo`03o`000?oooooooooo00[ooooo00Ko0000oeEEEOo^k^koooooogMgMomE
EED3ooooo`03o`000?oooooooooo00?ooooo00Go0000olc<c?o^k^koQhN7o`000004ooooo`05o`00
0?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go410@
okZj^_o^k^koMgMgoa0@4002ooooo`06o`000?nYZJWooooooooooonj^[[o00002?ooool00ol0003o
ooooooooo`03ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003oooooooooo`0:
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03oeEEEOmgMgOoA4A400Cooooo00KoEEEEogMgMooo
ooook^k^ogMgMol@4102ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool00ol0003ooooooooo
o`04ooooo`06o`000?nYZJWooooooooooonj^[[o00003oooool002Cooooo00?o8B4QojVYZOooool0
0_ooool00onYZJWo8B4Qooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000onk^k_ooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?o^k^kooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`05okZj^_n7QhOoIVIVofIVI_l@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000@ooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01oooool01OoMgMgo
410@oooooolQ8B7ogMgM00?ooooo00?o0000ooooooooool01Oooool01Ol@413oQhN7ooooooo^k^ko
000000Cooooo00?o0000ooooooooool01Oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00oooooo000T
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?o^
k^kooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h6ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo1_l0
0003ooooo`03o`000?oooooooooo00[ooooo00?o0000onk^k_ooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o^[Zjoa0@4?l000000_l00004ooooo`05o`000?ooooooooooooooool0
00000_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_lb<S;o8B4QogMgMomgMgOoQhN7
onk^kPSooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000003oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Wooooo00GoIVIVohN7QoooooooV9RHoeEEE@03oooo
o`Ko00000_ooool00onj^[[o410@o`000002o`0000Cooooo00?o0000ooooooooool01?ooool01_lb
<S;o8B4QogMgMomgMgOoQhN7onk^kPoooooo000Tooooo`03o`000?oooooooooo00?ooooo00Oo0000
ooooooooooooooooo`000?lb<S;ogMgM00Gooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED4oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Kooooo00KoEEEEogMgMoooooooooooogMgMomEEED4ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01Oooool01Ol0003oMgMgoooooonYZJWo000000;ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S88ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_oooooo
QhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd02_ooool01_l0003oEEEEonk^k_ooooooMgMgofIVIP?o
oooo00?o0000ooooooooool01_ooool00oo<c<co0000ooooo`03ooooo`05o`000?n7QhOoooooojVY
ZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000ooooooooool01?oo
ool01_l0003o^[Zjooooooo^k^koMgMgo`0000Sooooo00?o0000ooooooooool00oooool01_mEEEGo
MgMgooooooooooooMgMgoeEEE@?ooooo00?o0000oc8b<_oMgMd03?ooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?ok^k^o`000?o^k^h00_ooool02_l0003ogMgMooooooooooooEEEEohN7Qoo^k^koooooohN7Qolb
<S85ooooo`03olc<c?l0003ooooo00?ooooo00?o0000oc8b<_oMgMd01?ooool01_l0003o^[Zjoooo
ooo^k^koMgMgo`0000oooooo000Tooooo`03ob4Q8OnYZJWooooo00;ooooo00CoZJVYob4Q8Ooooooo
oooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`06o`000?o<c<co410@o`000?mEEEGok^k^0_oo
ool00ol@413o0000o`000003ooooo`03oa0@4?l0003o000000?o00000oooool01_nYZJWo8B4Qo`00
0?l0003o<S8bo`0000Kooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0003o
000000?o00002?ooool00ol@413o0000o`000003o`0000Cooooo00Go0000ogMgMol0003o0000oiRH
V002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^2?ooool01_o^k^koEEEEo`000?l0003oEEEE
onk^kP;ooooo00Co410@o`000?oooooooooo0_l000000ooooooo410@o`000004o`0000?ooooo00Ko
k^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q1oooool00ol@
413o0000ogMgM`02o`000003ofIVI_o^k^kooooo00;ooooo00?o0000ooooooooool01?ooool01?lb
<S;o0000o`000?nHV9P3ooooo`03oa0@4?l0003oMgMg00;o000000GoV9RHooooooooooook^k^oeEE
E@02o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_nYZJWo8B4Qo`000?l0003o<S8bo`00
00Kooooo00?o410@o`000?l000000ol00002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_oo
ool2o`000004ojVYZOlQ8B7o0000ob4Q8@_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`04oa0@4?l0003o0000
ooooo`;o000000Go410@ooooooooooook^k^oeEEE@02o`000003odA4A?o^k^kooooo00;ooooo00Co
<S8bo`000?l0003oV9RH0oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00KoZJVYob4Q8Ol0
003o0000oc8b<_l0000?ooooo`009?ooool01onYZJWo8B4QokZj^_oooooo^[Zjob4Q8OnYZJT02ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Ooo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0?_ooool002Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Joooo
o`03oa0@4?nj^[[ooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Boooo
o`03oa0@4?nj^[[ooooo01Wooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03kooooo000eooooo`03oa0@4?l0
003ooooo00Sooooo00?o410@ooooooooool08?ooool01?nj^[[o410@o`000?l@410Aooooo`03oa0@
4?l0003ooooo04Sooooo00?o410@o`000?l00000<oooool01?nj^[[o410@o`000?l@411[ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {276.312, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
\tEvidently, the outer planets are stable, at least for the next \
300 years!    (If nothing else, this plot shows the huge scale of the outer \
planet's orbits compared to that of Mars, the innermost orbit in the plot. \
Earth's orbit would barely even show up as a spot at the center. Distances \
are in meters.)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 1.4", "Subsubtitle",
  CellTags->{"Ex. 1.4", "c:28"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " The drag force ",
  StyleBox["F",
    FontSlant->"Italic"],
  " on a blunt  object moving through air is not linear in the velocity ",
  StyleBox["v",
    FontSlant->"Italic"],
  " except at very low speeds. A somewhat more realistic model for the drag \
in the regime where the wake is turbulent is ",
  Cell[BoxData[
      \(TraditionalForm\`F = \(-c\)\ v\^3\)]],
  ", where ",
  StyleBox["c",
    FontSlant->"Italic"],
  " is a constant proportional to the cross-sectional area of the object and \
the mass density of air. If we use this model for the drag force in the \
problem of a man throwing a pebble vertically [c.f. ",
  ButtonBox["Sec. 1.3",
    ButtonData:>"Ex. 1.3",
    ButtonStyle->"Hyperlink"],
  ", Exercise (4)] , the equation for the height is now nonlinear:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\^2 y\), \(\[DifferentialD]t\^2\),
              MultilineFunction->None], "+", 
            RowBox[{\(\(\(c\)\(\ \)\)\/m\), 
              SuperscriptBox[
                RowBox[{"(", 
                  FractionBox[\(\[DifferentialD]y\), \(\[DifferentialD]t\),
                    MultilineFunction->None], ")"}], "3"]}]}], "=", \(-g\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Solve this equation numerically using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and plot the solution. Take ",
  Cell[BoxData[
      \(TraditionalForm\`m\  = \ 1\ kg\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", " ", "=", " ", 
          RowBox[{"1", " ", "kg", " ", 
            RowBox[{
              StyleBox["s",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y(0)\  = \ 0\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(v(0)\), " ", "=", " ", 
          RowBox[{"6", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Numerically determine the maximum height, and the time required for the \
rock to fall back to ",
  Cell[BoxData[
      \(TraditionalForm\`y(0)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2) ",
    FontWeight->"Bold"],
  "Use ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to find the trajectories ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[Prime]\)(t)\)]],
  " for the Van der Pol oscillator, which satisfies ",
  ButtonBox["Eq. (1.2.20)",
    ButtonData:>"(1.2.20)",
    ButtonStyle->"Hyperlink"],
  ", for initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, x\^\[Prime])\) = \((1, 1)\), \((0.1, 0.3)\), \ 
      and\ \((3, 2)\)\)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  ". Use a parametric plot to plot the trajectories in phase-space ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, x\^\[Prime])\)\)]],
  ". Note how the trajectories converge onto a single curve, called a ",
  StyleBox["limit cycle",
    FontSlant->"Italic"],
  ". [See ",
  ButtonBox["Sec. 1.2",
    ButtonData:>"Ex. 1.2",
    ButtonStyle->"Hyperlink"],
  " Exercise (6), for the direction field associated with this oscillator.]"
}], "Text",
  CellTags->"i:55"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Ming the Merciless drops Flash Gordon out the back of his spaceship (in a \
spacesuit, fortunately). The evil Ming has contrived to leave Flash initially \
motionless with respect to the earth, whose surface is 5,000 km below. Use \
Newton's ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\^2\)]],
  " force law and ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to determine how long Flash has to be rescued before he makes a lovely \
display in the evening sky. ",
  StyleBox["(Hint: ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  Cell[BoxData[
      \(TraditionalForm\`M\_earth\)]],
  StyleBox[" = 5.98 \[Times] ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  Cell[BoxData[
      \(TraditionalForm\`10\^24\)]],
  StyleBox[" kg. The radius of the earth is roughly 6,370 km, and the height \
of the atmosphere is about 100 km.  The gravitational constant is ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  Cell[BoxData[
      FormBox[
        RowBox[{"G", " ", "=", " ", 
          RowBox[{"6.67", "\[Times]", 
            FormBox[\(10\^\(-11\)\),
              "TraditionalForm"], " ", 
            StyleBox["N",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              FormBox[\(kg\^2\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  StyleBox[". Remember that the ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", 
          FormBox[\(r\^2\),
            "TraditionalForm"]}], TraditionalForm]]],
  StyleBox[" force is measured with respect to the center of the earth.)",
    FontColor->RGBColor[0, 0, 0.00389105]]
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " ",
  ButtonBox["Einstein",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Einstein.\
html"], None},
    ButtonStyle->"Hyperlink"],
  "'s general theory of relativity generalizes Newton's theory of gravitation \
to encompass the situation where masses have large kinetic and/or potential \
energies (on the order of or larger than their rest masses). Even at low \
energies, the theory predicts a small correction to Newton's ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", 
          FormBox[\(r\^2\),
            "TraditionalForm"]}], TraditionalForm]]],
  " force law:"
}], "Text",
  CellTags->"i:127"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(r)\), "=", 
          RowBox[{\(-G\), " ", 
            RowBox[{"M", "(", 
              RowBox[{
                StyleBox[\(1\/r\^2\),
                  FontSize->15], "+", \(\(3\ L\^2\)\/\(c\^2\ r\^4\)\)}], 
              ")"}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is the specific angular momentum-- see Eq. ",
  ButtonBox["(1.2.22)",
    ButtonData:>"(1.2.22)",
    ButtonStyle->"Hyperlink"],
  ". This force per unit mass replaces that which appears on the ",
  "right-hand",
  " side of the orbit equation ",
  ButtonBox["(1.3.5)",
    ButtonData:>"(1.3.5)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "Use ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to determine the new orbit ",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta])\)]],
  " predicted by this equation, and plot it for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Theta]\  < \ 4  \[Pi]\)]],
  ", taking orbital parameters for the planet Mercury: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(r(0)\), " ", "=", "  ", 
          RowBox[{"46.00", "\[Times]", 
            FormBox[\(10\^6\),
              "TraditionalForm"], " ", "km"}]}], TraditionalForm]]],
  ", (perihelion distance) ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(r\^\[Prime]\)(0) = 0\), ",", "  ", 
          RowBox[{"L", " ", "=", " ", 
            RowBox[{"2.713", "\[Times]", 
              FormBox[\(10\^15\),
                "TraditionalForm"], " ", 
              RowBox[{
                FormBox[
                  SuperscriptBox[
                    StyleBox["m",
                      FontSlant->"Plain"], "2"],
                  "TraditionalForm"], "/", 
                StyleBox["s",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  ". The mass of the sun is ",
  Cell[BoxData[
      \(TraditionalForm\`1.9891`*^30\ kg\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show numerically  that the orbit no longer closes, and that each \
successive perihelion precesses by an amount ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Theta]\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  ". Find a numerical value for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Theta]\)]],
  ".   Be careful: the numerical integration must be performed very \
accurately! (The precession of Mercury's perihelion has been measured, and \
after successive refinements, removing extraneous effects, it was found to be \
in reasonable agreement with this result.)"
}], "Text",
  CellTags->"i:56"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " A cubic cavity has perfectly conducting walls of unit length, and \
supports electromagnetic standing waves. The magnetic field in the modes \
(assumed to be TE modes) is \t"
}], "Text",
  CellTags->"i:57"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["B",
                  FontSlant->"Plain"], 
                StyleBox[\(l\ m\ n\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "(", \(x, y, z\), ")"}], 
          "=", \(\(B\_o\) \(\({\(-\(\(\(l\)\(\ \)\)\/\((l\^2 + 
                            m\^2)\)\)\) \(sin(l\ \[Pi]\ x)\)\ \(cos(
                    m\ \[Pi]\ y)\) \(cos(
                    n\ \[Pi]\ z)\), \(-\(m\/\((l\^2 + m\^2)\)\)\) \(cos(
                    l\ \[Pi]\ x)\)\ \(sin(m\ \[Pi]\ y)\) \(cos(
                    n\ \[Pi]\ z)\), \(cos(l\ \[Pi]\ x)\)\ \(cos(
                    m\ \[Pi]\ y)\)\ \(sin(n\ \[Pi]\ z)\)}\)\(.\)\)\)}], 
        TraditionalForm]]],
  " "
}], "Text"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`\((l, m, n)\)\  = \ \((1, 1, 1)\)\)]],
  " solve Eqs. ",
  ButtonBox["(1.2.24)",
    ButtonData:>"(1.2.24)",
    ButtonStyle->"Hyperlink"],
  " numerically for the field lines ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["s",
              FontWeight->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["o",
                  FontWeight->"Plain"]],
              FontWeight->"Bold",
              FontSlant->"Italic"]}], ")"}], TraditionalForm]]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) < s < 2\)]],
  " and initial conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"], 
            "=", \({0.25\ i, 0.25\ j, \ 0.25\ k}\)}], ","}], 
        TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`i, j, k, \(\(=\)\(1\)\), 2, 3\)]],
  ". Use ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to plot and superimpose the solutions. [The solution is shown in Fig. ",
  ButtonBox["1.12",
    ButtonData:>"Fig. 1.12",
    ButtonStyle->"Hyperlink"],
  " for the mode with  ",
  Cell[BoxData[
      \(TraditionalForm\`\((l, m, n)\)\  = \((1, 2, 1)\)\)]],
  ".] "
}], "Text"],

Cell[BoxData[
  Graphics3D[{
    Line[{{0.231019, 0.143954, 0.595507},{0.234833, 0.155600, 0.648111}}],
    Line[{{0.234833, 0.155600, 0.648111},{0.240385, 0.176113, 0.697684}}],
    Line[{{0.240385, 0.176113, 0.697684},{0.246648, 0.211282, 0.737624}}],
    Line[{{0.246648, 0.211282, 0.737624},{0.248745, 0.262633, 0.748728}}],
    Line[{{0.248745, 0.262633, 0.748728},{0.243793, 0.307549, 0.720866}}],
    Line[{{0.243793, 0.307549, 0.720866},{0.237573, 0.334939, 0.674965}}],
    Line[{{0.237573, 0.334939, 0.674965},{0.232817, 0.350748, 0.623568}}],
    Line[{{0.232817, 0.350748, 0.623568},{0.229833, 0.359390, 0.570323}}],
    Line[{{0.229833, 0.359390, 0.570323},{0.228533, 0.362920, 0.516419}}],
    Line[{{0.228533, 0.362920, 0.516419},{0.228849, 0.362076, 0.462388}}],
    Line[{{0.228849, 0.362076, 0.462388},{0.230797, 0.356685, 0.408660}}],
    Line[{{0.230797, 0.356685, 0.408660},{0.234472, 0.345576, 0.355927}}],
    Line[{{0.234472, 0.345576, 0.355927},{0.239899, 0.325926, 0.305981}}],
    Line[{{0.239899, 0.325926, 0.305981},{0.246214, 0.292150, 0.264797}}],
    Line[{{0.246214, 0.292150, 0.264797},{0.248884, 0.241530, 0.250574}}],
    Line[{{0.248884, 0.241530, 0.250574},{0.244297, 0.195280, 0.276030}}],
    Line[{{0.244297, 0.195280, 0.276030},{0.238020, 0.166704, 0.321163}}],
    Line[{{0.238020, 0.166704, 0.321163},{0.233126, 0.150189, 0.372318}}],
    Line[{{0.233126, 0.150189, 0.372318},{0.230006, 0.141081, 0.425475}}],
    Line[{{0.230006, 0.141081, 0.425475},{0.228578, 0.137191, 0.479350}}],
    Line[{{0.228578, 0.137191, 0.479350},{0.228767, 0.137699, 0.533385}}],
    Line[{{0.228767, 0.137699, 0.533385},{0.230585, 0.142706, 0.587155}}],
    Line[{{0.230585, 0.142706, 0.587155},{0.234120, 0.153293, 0.640006}}],
    Line[{{0.234120, 0.153293, 0.640006},{0.239419, 0.172113, 0.690294}}],
    Line[{{0.239419, 0.172113, 0.690294},{0.245758, 0.204528, 0.732611}}],
    Line[{{0.245758, 0.204528, 0.732611},{0.248970, 0.254251, 0.749853}}],
    Line[{{0.248970, 0.254251, 0.749853},{0.244794, 0.301765, 0.726972}}],
    Line[{{0.244794, 0.301765, 0.726972},{0.238477, 0.331572, 0.682689}}],
    Line[{{0.238477, 0.331572, 0.682689},{0.233447, 0.348825, 0.631800}}],
    Line[{{0.233447, 0.348825, 0.631800},{0.230189, 0.358412, 0.578738}}],
    Line[{{0.230189, 0.358412, 0.578738},{0.228632, 0.362669, 0.524894}}],
    Line[{{0.228632, 0.362669, 0.524894},{0.228695, 0.362499, 0.470857}}],
    Line[{{0.228695, 0.362499, 0.470857},{0.230382, 0.357870, 0.417048}}],
    Line[{{0.230382, 0.357870, 0.417048},{0.233779, 0.347791, 0.364087}}],
    Line[{{0.233779, 0.347791, 0.364087},{0.238945, 0.329771, 0.313484}}],
    Line[{{0.238945, 0.329771, 0.313484},{0.245285, 0.298680, 0.270135}}],
    Line[{{0.245285, 0.298680, 0.270135},{0.249000, 0.250000, 0.250000}}],
    Line[{{0.249000, 0.250000, 0.250000},{0.245285, 0.201320, 0.270135}}],
    Line[{{0.245285, 0.201320, 0.270135},{0.238945, 0.170229, 0.313484}}],
    Line[{{0.238945, 0.170229, 0.313484},{0.233779, 0.152209, 0.364087}}],
    Line[{{0.233779, 0.152209, 0.364087},{0.230382, 0.142130, 0.417048}}],
    Line[{{0.230382, 0.142130, 0.417048},{0.228695, 0.137501, 0.470857}}],
    Line[{{0.228695, 0.137501, 0.470857},{0.228632, 0.137331, 0.524894}}],
    Line[{{0.228632, 0.137331, 0.524894},{0.230189, 0.141588, 0.578738}}],
    Line[{{0.230189, 0.141588, 0.578738},{0.233447, 0.151175, 0.631800}}],
    Line[{{0.233447, 0.151175, 0.631800},{0.238478, 0.168427, 0.682690}}],
    Line[{{0.238478, 0.168427, 0.682690},{0.244795, 0.198237, 0.726973}}],
    Line[{{0.244795, 0.198237, 0.726973},{0.248970, 0.245750, 0.749852}}],
    Line[{{0.248970, 0.245750, 0.749852},{0.245758, 0.295474, 0.732610}}],
    Line[{{0.245758, 0.295474, 0.732610},{0.239418, 0.327888, 0.690292}}],
    Line[{{0.239418, 0.327888, 0.690292},{0.234120, 0.346707, 0.640004}}],
    Line[{{0.234120, 0.346707, 0.640004},{0.230585, 0.357294, 0.587154}}],
    Line[{{0.230585, 0.357294, 0.587154},{0.228767, 0.362301, 0.533383}}],
    Line[{{0.228767, 0.362301, 0.533383},{0.228578, 0.362809, 0.479349}}],
    Line[{{0.228578, 0.362809, 0.479349},{0.230006, 0.358918, 0.425473}}],
    Line[{{0.230006, 0.358918, 0.425473},{0.233126, 0.349810, 0.372316}}],
    Line[{{0.233126, 0.349810, 0.372316},{0.238020, 0.333295, 0.321162}}],
    Line[{{0.238020, 0.333295, 0.321162},{0.244297, 0.304719, 0.276029}}],
    Line[{{0.244297, 0.304719, 0.276029},{0.248885, 0.258468, 0.250574}}],
    Line[{{0.248885, 0.258468, 0.250574},{0.246214, 0.207848, 0.264798}}],
    Line[{{0.246214, 0.207848, 0.264798},{0.239899, 0.174073, 0.305982}}],
    Line[{{0.239899, 0.174073, 0.305982},{0.234472, 0.154423, 0.355928}}],
    Line[{{0.234472, 0.154423, 0.355928},{0.230798, 0.143314, 0.408660}}],
    Line[{{0.230798, 0.143314, 0.408660},{0.228850, 0.137923, 0.462388}}],
    Line[{{0.228850, 0.137923, 0.462388},{0.228534, 0.137078, 0.516418}}],
    Line[{{0.228534, 0.137078, 0.516418},{0.229834, 0.140608, 0.570321}}],
    Line[{{0.229834, 0.140608, 0.570321},{0.232817, 0.149251, 0.623565}}],
    Line[{{0.232817, 0.149251, 0.623565},{0.237574, 0.165059, 0.674962}}],
    Line[{{0.237574, 0.165059, 0.674962},{0.243793, 0.192450, 0.720863}}],
    Line[{{0.243793, 0.192450, 0.720863},{0.248745, 0.237363, 0.748724}}],
    Line[{{0.248745, 0.237363, 0.748724},{0.246649, 0.288717, 0.737625}}],
    Line[{{0.246649, 0.288717, 0.737625},{0.240385, 0.323886, 0.697684}}],
    Line[{{0.240385, 0.323886, 0.697684},{0.234834, 0.344399, 0.648112}}],
    Line[{{0.234834, 0.344399, 0.648112},{0.231021, 0.356045, 0.595509}}],
    Line[{{0.249000, 0.249999, 0.500002},{0.249000, 0.250000, 0.500003}}],
    Line[{{0.249000, 0.250000, 0.500003},{0.249000, 0.250000, 0.500003}}],
    Line[{{0.249000, 0.250000, 0.500003},{0.249000, 0.250001, 0.500002}}],
    Line[{{0.249000, 0.250001, 0.500002},{0.249000, 0.250001, 0.500000}}],
    Line[{{0.249000, 0.250001, 0.500000},{0.249000, 0.250001, 0.499999}}],
    Line[{{0.249000, 0.250001, 0.499999},{0.249000, 0.250001, 0.499997}}],
    Line[{{0.249000, 0.250001, 0.499997},{0.249000, 0.250000, 0.499997}}],
    Line[{{0.249000, 0.250000, 0.499997},{0.249000, 0.249999, 0.499997}}],
    Line[{{0.249000, 0.249999, 0.499997},{0.249000, 0.250001, 0.500004}}],
    Line[{{0.249000, 0.250001, 0.500004},{0.249000, 0.250000, 0.500000}}],
    Line[{{0.249000, 0.250000, 0.500000},{0.249000, 0.249998, 0.500004}}],
    Line[{{0.249000, 0.249998, 0.500004},{0.249000, 0.250007, 0.500003}}],
    Line[{{0.249000, 0.250007, 0.500003},{0.249000, 0.250006, 0.499990}}],
    Line[{{0.249000, 0.250006, 0.499990},{0.249000, 0.250000, 0.500020}}],
    Line[{{0.249000, 0.250000, 0.500020},{0.249000, 0.249991, 0.500012}}],
    Line[{{0.249000, 0.249991, 0.500012},{0.249000, 0.249990, 0.499995}}],
    Line[{{0.249000, 0.249990, 0.499995},{0.249000, 0.249991, 0.499987}}],
    Line[{{0.249000, 0.249991, 0.499987},{0.249000, 0.250010, 0.499989}}],
    Line[{{0.249000, 0.250010, 0.499989},{0.249000, 0.249993, 0.500021}}],
    Line[{{0.249000, 0.249993, 0.500021},{0.249000, 0.250001, 0.500030}}],
    Line[{{0.249000, 0.250001, 0.500030},{0.249000, 0.249984, 0.499998}}],
    Line[{{0.249000, 0.249984, 0.499998},{0.249000, 0.250016, 0.500007}}],
    Line[{{0.249000, 0.250016, 0.500007},{0.249000, 0.249985, 0.499983}}],
    Line[{{0.249000, 0.249985, 0.499983},{0.249000, 0.250007, 0.500033}}],
    Line[{{0.249000, 0.250007, 0.500033},{0.249000, 0.250020, 0.500001}}],
    Line[{{0.249000, 0.250020, 0.500001},{0.249000, 0.250020, 0.499997}}],
    Line[{{0.249000, 0.250020, 0.499997},{0.249000, 0.250019, 0.499989}}],
    Line[{{0.249000, 0.250019, 0.499989},{0.249000, 0.250016, 0.499976}}],
    Line[{{0.249000, 0.250016, 0.499976},{0.249000, 0.250018, 0.499973}}],
    Line[{{0.249000, 0.250018, 0.499973},{0.249000, 0.250021, 0.499991}}],
    Line[{{0.249000, 0.250021, 0.499991},{0.249000, 0.250021, 0.500006}}],
    Line[{{0.249000, 0.250021, 0.500006},{0.249000, 0.250020, 0.500020}}],
    Line[{{0.249000, 0.250020, 0.500020},{0.249000, 0.249980, 0.500032}}],
    Line[{{0.249000, 0.249980, 0.500032},{0.249000, 0.250006, 0.499945}}],
    Line[{{0.249000, 0.250006, 0.499945},{0.249000, 0.249993, 0.500058}}],
    Line[{{0.249000, 0.249993, 0.500058},{0.249000, 0.250025, 0.499965}}],
    Line[{{0.249000, 0.250025, 0.499965},{0.249000, 0.249970, 0.499989}}],
    Line[{{0.249000, 0.249970, 0.499989},{0.249000, 0.250010, 0.500063}}],
    Line[{{0.249000, 0.250010, 0.500063},{0.249000, 0.250031, 0.499980}}],
    Line[{{0.249000, 0.250031, 0.499980},{0.249000, 0.249984, 0.499938}}],
    Line[{{0.249000, 0.249984, 0.499938},{0.249000, 0.249966, 0.500008}}],
    Line[{{0.249000, 0.249966, 0.500008},{0.249000, 0.249980, 0.500064}}],
    Line[{{0.249000, 0.249980, 0.500064},{0.249000, 0.250017, 0.500070}}],
    Line[{{0.249000, 0.250017, 0.500070},{0.249000, 0.250032, 0.500042}}],
    Line[{{0.249000, 0.250032, 0.500042},{0.249000, 0.250038, 0.500020}}],
    Line[{{0.249000, 0.250038, 0.500020},{0.249000, 0.250039, 0.500009}}],
    Line[{{0.249000, 0.250039, 0.500009},{0.249000, 0.250040, 0.500003}}],
    Line[{{0.249000, 0.250040, 0.500003},{0.249000, 0.250041, 0.500005}}],
    Line[{{0.249000, 0.250041, 0.500005},{0.249000, 0.250041, 0.500017}}],
    Line[{{0.249000, 0.250041, 0.500017},{0.249000, 0.250039, 0.500034}}],
    Line[{{0.249000, 0.250039, 0.500034},{0.249000, 0.250033, 0.500057}}],
    Line[{{0.249000, 0.250033, 0.500057},{0.249000, 0.250023, 0.500081}}],
    Line[{{0.249000, 0.250023, 0.500081},{0.249000, 0.249994, 0.500092}}],
    Line[{{0.249000, 0.249994, 0.500092},{0.249000, 0.249973, 0.500075}}],
    Line[{{0.249000, 0.249973, 0.500075},{0.249000, 0.249959, 0.500037}}],
    Line[{{0.249000, 0.249959, 0.500037},{0.249000, 0.249957, 0.500000}}],
    Line[{{0.249000, 0.249957, 0.500000},{0.249000, 0.249959, 0.499996}}],
    Line[{{0.249000, 0.249959, 0.499996},{0.249000, 0.249960, 0.500005}}],
    Line[{{0.249000, 0.249960, 0.500005},{0.249000, 0.249960, 0.500010}}],
    Line[{{0.249000, 0.249960, 0.500010},{0.249000, 0.249959, 0.500002}}],
    Line[{{0.249000, 0.249959, 0.500002},{0.249000, 0.249966, 0.500027}}],
    Line[{{0.249000, 0.249966, 0.500027},{0.249000, 0.249971, 0.500056}}],
    Line[{{0.249000, 0.249971, 0.500056},{0.249000, 0.249977, 0.500070}}],
    Line[{{0.249000, 0.249977, 0.500070},{0.249000, 0.249981, 0.500077}}],
    Line[{{0.249000, 0.249981, 0.500077},{0.249000, 0.249980, 0.500078}}],
    Line[{{0.249000, 0.249980, 0.500078},{0.249000, 0.249975, 0.500071}}],
    Line[{{0.249000, 0.249975, 0.500071},{0.249000, 0.249969, 0.500061}}],
    Line[{{0.249000, 0.249969, 0.500061},{0.249000, 0.249963, 0.500042}}],
    Line[{{0.249000, 0.249963, 0.500042},{0.249000, 0.249965, 0.500043}}],
    Line[{{0.249000, 0.249965, 0.500043},{0.249000, 0.249962, 0.500034}}],
    Line[{{0.249000, 0.249962, 0.500034},{0.249000, 0.249957, 0.500015}}],
    Line[{{0.249000, 0.249957, 0.500015},{0.249000, 0.249957, 0.499981}}],
    Line[{{0.249000, 0.249957, 0.499981},{0.249000, 0.249964, 0.499948}}],
    Line[{{0.249000, 0.249964, 0.499948},{0.249000, 0.249974, 0.499929}}],
    Line[{{0.231019, 0.356048, 0.404490},{0.234832, 0.344402, 0.351886}}],
    Line[{{0.234832, 0.344402, 0.351886},{0.240385, 0.323889, 0.302313}}],
    Line[{{0.240385, 0.323889, 0.302313},{0.246648, 0.288720, 0.262372}}],
    Line[{{0.246648, 0.288720, 0.262372},{0.248745, 0.237368, 0.251268}}],
    Line[{{0.248745, 0.237368, 0.251268},{0.243793, 0.192451, 0.279127}}],
    Line[{{0.243793, 0.192451, 0.279127},{0.237574, 0.165060, 0.325028}}],
    Line[{{0.237574, 0.165060, 0.325028},{0.232816, 0.149251, 0.376425}}],
    Line[{{0.232816, 0.149251, 0.376425},{0.229833, 0.140608, 0.429670}}],
    Line[{{0.229833, 0.140608, 0.429670},{0.228533, 0.137078, 0.483574}}],
    Line[{{0.228533, 0.137078, 0.483574},{0.228848, 0.137922, 0.537605}}],
    Line[{{0.228848, 0.137922, 0.537605},{0.230796, 0.143311, 0.591333}}],
    Line[{{0.230796, 0.143311, 0.591333},{0.234470, 0.154419, 0.644066}}],
    Line[{{0.234470, 0.154419, 0.644066},{0.239898, 0.174067, 0.694014}}],
    Line[{{0.239898, 0.174067, 0.694014},{0.246213, 0.207841, 0.735199}}],
    Line[{{0.246213, 0.207841, 0.735199},{0.248884, 0.258458, 0.749430}}],
    Line[{{0.248884, 0.258458, 0.749430},{0.244297, 0.304714, 0.723980}}],
    Line[{{0.244297, 0.304714, 0.723980},{0.238021, 0.333292, 0.678849}}],
    Line[{{0.238021, 0.333292, 0.678849},{0.233126, 0.349809, 0.627695}}],
    Line[{{0.233126, 0.349809, 0.627695},{0.230005, 0.358917, 0.574537}}],
    Line[{{0.230005, 0.358917, 0.574537},{0.228577, 0.362808, 0.520661}}],
    Line[{{0.228577, 0.362808, 0.520661},{0.228766, 0.362302, 0.466625}}],
    Line[{{0.228766, 0.362302, 0.466625},{0.230584, 0.357296, 0.412854}}],
    Line[{{0.230584, 0.357296, 0.412854},{0.234119, 0.346710, 0.360002}}],
    Line[{{0.234119, 0.346710, 0.360002},{0.239417, 0.327892, 0.309712}}],
    Line[{{0.239417, 0.327892, 0.309712},{0.245757, 0.295478, 0.267394}}],
    Line[{{0.245757, 0.295478, 0.267394},{0.248970, 0.245757, 0.250145}}],
    Line[{{0.248970, 0.245757, 0.250145},{0.244795, 0.198240, 0.273020}}],
    Line[{{0.244795, 0.198240, 0.273020},{0.238478, 0.168430, 0.317303}}],
    Line[{{0.238478, 0.168430, 0.317303},{0.233446, 0.151177, 0.368194}}],
    Line[{{0.233446, 0.151177, 0.368194},{0.230189, 0.141590, 0.421257}}],
    Line[{{0.230189, 0.141590, 0.421257},{0.228631, 0.137333, 0.475101}}],
    Line[{{0.228631, 0.137333, 0.475101},{0.228694, 0.137501, 0.529139}}],
    Line[{{0.228694, 0.137501, 0.529139},{0.230382, 0.142130, 0.582948}}],
    Line[{{0.230382, 0.142130, 0.582948},{0.233778, 0.152208, 0.635911}}],
    Line[{{0.233778, 0.152208, 0.635911},{0.238945, 0.170228, 0.686515}}],
    Line[{{0.238945, 0.170228, 0.686515},{0.245285, 0.201320, 0.729865}}],
    Line[{{0.245285, 0.201320, 0.729865},{0.249000, 0.250000, 0.750000}}],
    Line[{{0.249000, 0.250000, 0.750000},{0.245285, 0.298680, 0.729864}}],
    Line[{{0.245285, 0.298680, 0.729864},{0.238945, 0.329771, 0.686515}}],
    Line[{{0.238945, 0.329771, 0.686515},{0.233779, 0.347791, 0.635912}}],
    Line[{{0.233779, 0.347791, 0.635912},{0.230382, 0.357870, 0.582951}}],
    Line[{{0.230382, 0.357870, 0.582951},{0.228695, 0.362499, 0.529142}}],
    Line[{{0.228695, 0.362499, 0.529142},{0.228632, 0.362669, 0.475105}}],
    Line[{{0.228632, 0.362669, 0.475105},{0.230189, 0.358412, 0.421262}}],
    Line[{{0.230189, 0.358412, 0.421262},{0.233447, 0.348824, 0.368200}}],
    Line[{{0.233447, 0.348824, 0.368200},{0.238478, 0.331572, 0.317310}}],
    Line[{{0.238478, 0.331572, 0.317310},{0.244795, 0.301762, 0.273027}}],
    Line[{{0.244795, 0.301762, 0.273027},{0.248970, 0.254249, 0.250148}}],
    Line[{{0.248970, 0.254249, 0.250148},{0.245758, 0.204526, 0.267392}}],
    Line[{{0.245758, 0.204526, 0.267392},{0.239418, 0.172112, 0.309709}}],
    Line[{{0.239418, 0.172112, 0.309709},{0.234120, 0.153293, 0.359998}}],
    Line[{{0.234120, 0.153293, 0.359998},{0.230585, 0.142706, 0.412849}}],
    Line[{{0.230585, 0.142706, 0.412849},{0.228767, 0.137699, 0.466619}}],
    Line[{{0.228767, 0.137699, 0.466619},{0.228578, 0.137192, 0.520653}}],
    Line[{{0.228578, 0.137192, 0.520653},{0.230006, 0.141082, 0.574529}}],
    Line[{{0.230006, 0.141082, 0.574529},{0.233126, 0.150190, 0.627686}}],
    Line[{{0.233126, 0.150190, 0.627686},{0.238021, 0.166706, 0.678840}}],
    Line[{{0.238021, 0.166706, 0.678840},{0.244297, 0.195283, 0.723972}}],
    Line[{{0.244297, 0.195283, 0.723972},{0.248885, 0.241535, 0.749427}}],
    Line[{{0.248885, 0.241535, 0.749427},{0.246214, 0.292154, 0.735200}}],
    Line[{{0.246214, 0.292154, 0.735200},{0.239899, 0.325928, 0.694015}}],
    Line[{{0.239899, 0.325928, 0.694015},{0.234472, 0.345578, 0.644069}}],
    Line[{{0.234472, 0.345578, 0.644069},{0.230798, 0.356687, 0.591338}}],
    Line[{{0.230798, 0.356687, 0.591338},{0.228850, 0.362077, 0.537610}}],
    Line[{{0.228850, 0.362077, 0.537610},{0.228534, 0.362922, 0.483580}}],
    Line[{{0.228534, 0.362922, 0.483580},{0.229834, 0.359392, 0.429676}}],
    Line[{{0.229834, 0.359392, 0.429676},{0.232817, 0.350748, 0.376433}}],
    Line[{{0.232817, 0.350748, 0.376433},{0.237574, 0.334940, 0.325036}}],
    Line[{{0.237574, 0.334940, 0.325036},{0.243794, 0.307548, 0.279135}}],
    Line[{{0.243794, 0.307548, 0.279135},{0.248745, 0.262635, 0.251275}}],
    Line[{{0.248745, 0.262635, 0.251275},{0.246648, 0.211282, 0.262376}}],
    Line[{{0.246648, 0.211282, 0.262376},{0.240385, 0.176114, 0.302318}}],
    Line[{{0.240385, 0.176114, 0.302318},{0.234833, 0.155601, 0.351890}}],
    Line[{{0.234833, 0.155601, 0.351890},{0.231020, 0.143955, 0.404493}}],
    Line[{{0.606635, 0.500000, 0.052378},{0.656007, 0.500000, 0.073936}}],
    Line[{{0.656007, 0.500000, 0.073936},{0.695858, 0.500000, 0.110059}}],
    Line[{{0.695858, 0.500000, 0.110059},{0.723145, 0.500000, 0.156557}}],
    Line[{{0.723145, 0.500000, 0.156557},{0.740998, 0.500000, 0.207525}}],
    Line[{{0.740998, 0.500000, 0.207525},{0.752946, 0.500000, 0.260224}}],
    Line[{{0.752946, 0.500000, 0.260224},{0.761069, 0.500000, 0.313655}}],
    Line[{{0.761069, 0.500000, 0.313655},{0.766486, 0.500000, 0.367432}}],
    Line[{{0.766486, 0.500000, 0.367432},{0.769811, 0.500000, 0.421381}}],
    Line[{{0.769811, 0.500000, 0.421381},{0.771367, 0.500000, 0.475411}}],
    Line[{{0.771367, 0.500000, 0.475411},{0.771295, 0.500000, 0.529463}}],
    Line[{{0.771295, 0.500000, 0.529463},{0.769587, 0.500000, 0.583488}}],
    Line[{{0.769587, 0.500000, 0.583488},{0.766092, 0.500000, 0.637426}}],
    Line[{{0.766092, 0.500000, 0.637426},{0.760462, 0.500000, 0.691182}}],
    Line[{{0.760462, 0.500000, 0.691182},{0.752052, 0.500000, 0.744570}}],
    Line[{{0.752052, 0.500000, 0.744570},{0.739676, 0.500000, 0.797169}}],
    Line[{{0.739676, 0.500000, 0.797169},{0.721138, 0.500000, 0.847888}}],
    Line[{{0.721138, 0.500000, 0.847888},{0.692795, 0.500000, 0.893735}}],
    Line[{{0.692795, 0.500000, 0.893735},{0.651847, 0.500000, 0.928606}}],
    Line[{{0.651847, 0.500000, 0.928606},{0.601938, 0.500000, 0.948932}}],
    Line[{{0.601938, 0.500000, 0.948932},{0.548767, 0.500000, 0.958332}}],
    Line[{{0.548767, 0.500000, 0.958332},{0.494793, 0.500000, 0.960702}}],
    Line[{{0.494793, 0.500000, 0.960702},{0.440887, 0.500000, 0.957150}}],
    Line[{{0.440887, 0.500000, 0.957150},{0.388063, 0.500000, 0.946027}}],
    Line[{{0.388063, 0.500000, 0.946027},{0.339358, 0.500000, 0.923031}}],
    Line[{{0.339358, 0.500000, 0.923031},{0.300788, 0.500000, 0.885534}}],
    Line[{{0.300788, 0.500000, 0.885534},{0.274662, 0.500000, 0.838360}}],
    Line[{{0.274662, 0.500000, 0.838360},{0.257549, 0.500000, 0.787134}}],
    Line[{{0.257549, 0.500000, 0.787134},{0.246066, 0.500000, 0.734331}}],
    Line[{{0.246066, 0.500000, 0.734331},{0.238261, 0.500000, 0.680851}}],
    Line[{{0.238261, 0.500000, 0.680851},{0.233080, 0.500000, 0.627051}}],
    Line[{{0.233080, 0.500000, 0.627051},{0.229948, 0.500000, 0.573090}}],
    Line[{{0.229948, 0.500000, 0.573090},{0.228562, 0.500000, 0.519056}}],
    Line[{{0.228562, 0.500000, 0.519056},{0.228799, 0.500000, 0.465005}}],
    Line[{{0.228799, 0.500000, 0.465005},{0.230680, 0.500000, 0.410986}}],
    Line[{{0.230680, 0.500000, 0.410986},{0.234375, 0.500000, 0.357062}}],
    Line[{{0.234375, 0.500000, 0.357062},{0.240253, 0.500000, 0.303333}}],
    Line[{{0.240253, 0.500000, 0.303333},{0.249000, 0.500000, 0.250000}}],
    Line[{{0.249000, 0.500000, 0.250000},{0.261886, 0.500000, 0.197526}}],
    Line[{{0.261886, 0.500000, 0.197526},{0.281237, 0.500000, 0.147119}}],
    Line[{{0.281237, 0.500000, 0.147119},{0.310810, 0.500000, 0.102074}}],
    Line[{{0.310810, 0.500000, 0.102074},{0.352957, 0.500000, 0.068663}}],
    Line[{{0.352957, 0.500000, 0.068663},{0.403411, 0.500000, 0.049687}}],
    Line[{{0.403411, 0.500000, 0.049687},{0.456732, 0.500000, 0.041140}}],
    Line[{{0.456732, 0.500000, 0.041140},{0.510730, 0.500000, 0.039380}}],
    Line[{{0.510730, 0.500000, 0.039380},{0.564587, 0.500000, 0.043581}}],
    Line[{{0.564587, 0.500000, 0.043581},{0.617185, 0.500000, 0.055687}}],
    Line[{{0.617185, 0.500000, 0.055687},{0.665148, 0.500000, 0.080150}}],
    Line[{{0.665148, 0.500000, 0.080150},{0.702420, 0.500000, 0.118951}}],
    Line[{{0.702420, 0.500000, 0.118951},{0.727435, 0.500000, 0.166741}}],
    Line[{{0.727435, 0.500000, 0.166741},{0.743843, 0.500000, 0.218204}}],
    Line[{{0.743843, 0.500000, 0.218204},{0.754879, 0.500000, 0.271104}}],
    Line[{{0.754879, 0.500000, 0.271104},{0.762378, 0.500000, 0.324628}}],
    Line[{{0.762378, 0.500000, 0.324628},{0.767329, 0.500000, 0.378451}}],
    Line[{{0.767329, 0.500000, 0.378451},{0.770272, 0.500000, 0.432422}}],
    Line[{{0.770272, 0.500000, 0.432422},{0.771490, 0.500000, 0.486460}}],
    Line[{{0.771490, 0.500000, 0.486460},{0.771088, 0.500000, 0.540510}}],
    Line[{{0.771088, 0.500000, 0.540510},{0.769032, 0.500000, 0.594523}}],
    Line[{{0.769032, 0.500000, 0.594523},{0.765134, 0.500000, 0.648432}}],
    Line[{{0.765134, 0.500000, 0.648432},{0.759000, 0.500000, 0.702132}}],
    Line[{{0.759000, 0.500000, 0.702132},{0.749899, 0.500000, 0.755403}}],
    Line[{{0.749899, 0.500000, 0.755403},{0.736484, 0.500000, 0.807740}}],
    Line[{{0.736484, 0.500000, 0.807740},{0.716282, 0.500000, 0.857804}}],
    Line[{{0.716282, 0.500000, 0.857804},{0.685452, 0.500000, 0.901976}}],
    Line[{{0.685452, 0.500000, 0.901976},{0.642159, 0.500000, 0.933896}}],
    Line[{{0.642159, 0.500000, 0.933896},{0.591221, 0.500000, 0.951577}}],
    Line[{{0.591221, 0.500000, 0.951577},{0.537772, 0.500000, 0.959312}}],
    Line[{{0.537772, 0.500000, 0.959312},{0.483757, 0.500000, 0.960472}}],
    Line[{{0.483757, 0.500000, 0.960472},{0.429957, 0.500000, 0.955602}}],
    Line[{{0.429957, 0.500000, 0.955602},{0.377615, 0.500000, 0.942464}}],
    Line[{{0.377615, 0.500000, 0.942464},{0.330463, 0.500000, 0.916500}}],
    Line[{{0.330463, 0.500000, 0.916500},{0.294512, 0.500000, 0.876459}}],
    Line[{{0.294512, 0.500000, 0.876459},{0.270564, 0.500000, 0.828114}}],
    Line[{{0.270564, 0.500000, 0.828114},{0.254825, 0.500000, 0.776438}}],
    Line[{{0.254825, 0.500000, 0.776438},{0.244216, 0.500000, 0.723449}}],
    Line[{{0.296844, 0.500000, 0.174359},{0.323861, 0.500000, 0.127687}}],
    Line[{{0.323861, 0.500000, 0.127687},{0.362895, 0.500000, 0.090647}}],
    Line[{{0.362895, 0.500000, 0.090647},{0.411685, 0.500000, 0.067835}}],
    Line[{{0.411685, 0.500000, 0.067835},{0.464643, 0.500000, 0.057448}}],
    Line[{{0.464643, 0.500000, 0.057448},{0.518630, 0.500000, 0.056166}}],
    Line[{{0.518630, 0.500000, 0.056166},{0.572117, 0.500000, 0.063474}}],
    Line[{{0.572117, 0.500000, 0.063474},{0.622727, 0.500000, 0.082012}}],
    Line[{{0.622727, 0.500000, 0.082012},{0.665346, 0.500000, 0.114850}}],
    Line[{{0.665346, 0.500000, 0.114850},{0.695917, 0.500000, 0.159228}}],
    Line[{{0.695917, 0.500000, 0.159228},{0.716284, 0.500000, 0.209228}}],
    Line[{{0.716284, 0.500000, 0.209228},{0.729933, 0.500000, 0.261506}}],
    Line[{{0.729933, 0.500000, 0.261506},{0.739183, 0.500000, 0.314751}}],
    Line[{{0.739183, 0.500000, 0.314751},{0.745328, 0.500000, 0.368448}}],
    Line[{{0.745328, 0.500000, 0.368448},{0.749081, 0.500000, 0.422368}}],
    Line[{{0.749081, 0.500000, 0.422368},{0.750819, 0.500000, 0.476391}}],
    Line[{{0.750819, 0.500000, 0.476391},{0.750703, 0.500000, 0.530443}}],
    Line[{{0.750703, 0.500000, 0.530443},{0.748723, 0.500000, 0.584458}}],
    Line[{{0.748723, 0.500000, 0.584458},{0.744696, 0.500000, 0.638358}}],
    Line[{{0.744696, 0.500000, 0.638358},{0.738208, 0.500000, 0.692016}}],
    Line[{{0.738208, 0.500000, 0.692016},{0.728491, 0.500000, 0.745178}}],
    Line[{{0.728491, 0.500000, 0.745178},{0.714146, 0.500000, 0.797267}}],
    Line[{{0.714146, 0.500000, 0.797267},{0.692695, 0.500000, 0.846803}}],
    Line[{{0.692695, 0.500000, 0.846803},{0.660599, 0.500000, 0.890070}}],
    Line[{{0.660599, 0.500000, 0.890070},{0.616637, 0.500000, 0.921096}}],
    Line[{{0.616637, 0.500000, 0.921096},{0.565439, 0.500000, 0.937990}}],
    Line[{{0.565439, 0.500000, 0.937990},{0.511799, 0.500000, 0.944125}}],
    Line[{{0.511799, 0.500000, 0.944125},{0.457850, 0.500000, 0.941788}}],
    Line[{{0.457850, 0.500000, 0.941788},{0.405184, 0.500000, 0.930051}}],
    Line[{{0.405184, 0.500000, 0.930051},{0.357304, 0.500000, 0.905419}}],
    Line[{{0.357304, 0.500000, 0.905419},{0.319814, 0.500000, 0.866804}}],
    Line[{{0.319814, 0.500000, 0.866804},{0.294154, 0.500000, 0.819358}}],
    Line[{{0.294154, 0.500000, 0.819358},{0.277091, 0.500000, 0.768112}}],
    Line[{{0.277091, 0.500000, 0.768112},{0.265577, 0.500000, 0.715315}}],
    Line[{{0.265577, 0.500000, 0.715315},{0.257801, 0.500000, 0.661832}}],
    Line[{{0.257801, 0.500000, 0.661832},{0.252764, 0.500000, 0.608018}}],
    Line[{{0.252764, 0.500000, 0.608018},{0.249921, 0.500000, 0.554042}}],
    Line[{{0.249921, 0.500000, 0.554042},{0.249000, 0.500000, 0.500000}}],
    Line[{{0.249000, 0.500000, 0.500000},{0.249921, 0.500000, 0.445958}}],
    Line[{{0.249921, 0.500000, 0.445958},{0.252764, 0.500000, 0.391982}}],
    Line[{{0.252764, 0.500000, 0.391982},{0.257801, 0.500000, 0.338168}}],
    Line[{{0.257801, 0.500000, 0.338168},{0.265577, 0.500000, 0.284685}}],
    Line[{{0.265577, 0.500000, 0.284685},{0.277091, 0.500000, 0.231888}}],
    Line[{{0.277091, 0.500000, 0.231888},{0.294154, 0.500000, 0.180642}}],
    Line[{{0.294154, 0.500000, 0.180642},{0.319815, 0.500000, 0.133195}}],
    Line[{{0.319815, 0.500000, 0.133195},{0.357306, 0.500000, 0.094581}}],
    Line[{{0.357306, 0.500000, 0.094581},{0.405187, 0.500000, 0.069949}}],
    Line[{{0.405187, 0.500000, 0.069949},{0.457852, 0.500000, 0.058213}}],
    Line[{{0.457852, 0.500000, 0.058213},{0.511801, 0.500000, 0.055876}}],
    Line[{{0.511801, 0.500000, 0.055876},{0.565440, 0.500000, 0.062011}}],
    Line[{{0.565440, 0.500000, 0.062011},{0.616639, 0.500000, 0.078906}}],
    Line[{{0.616639, 0.500000, 0.078906},{0.660598, 0.500000, 0.109933}}],
    Line[{{0.660598, 0.500000, 0.109933},{0.692694, 0.500000, 0.153200}}],
    Line[{{0.692694, 0.500000, 0.153200},{0.714145, 0.500000, 0.202737}}],
    Line[{{0.714145, 0.500000, 0.202737},{0.728490, 0.500000, 0.254826}}],
    Line[{{0.728490, 0.500000, 0.254826},{0.738206, 0.500000, 0.307988}}],
    Line[{{0.738206, 0.500000, 0.307988},{0.744694, 0.500000, 0.361646}}],
    Line[{{0.744694, 0.500000, 0.361646},{0.748722, 0.500000, 0.415546}}],
    Line[{{0.748722, 0.500000, 0.415546},{0.750701, 0.500000, 0.469561}}],
    Line[{{0.750701, 0.500000, 0.469561},{0.750816, 0.500000, 0.523612}}],
    Line[{{0.750816, 0.500000, 0.523612},{0.749078, 0.500000, 0.577636}}],
    Line[{{0.749078, 0.500000, 0.577636},{0.745326, 0.500000, 0.631556}}],
    Line[{{0.745326, 0.500000, 0.631556},{0.739181, 0.500000, 0.685254}}],
    Line[{{0.739181, 0.500000, 0.685254},{0.729932, 0.500000, 0.738499}}],
    Line[{{0.729932, 0.500000, 0.738499},{0.716280, 0.500000, 0.790775}}],
    Line[{{0.716280, 0.500000, 0.790775},{0.695912, 0.500000, 0.840775}}],
    Line[{{0.695912, 0.500000, 0.840775},{0.665341, 0.500000, 0.885153}}],
    Line[{{0.665341, 0.500000, 0.885153},{0.622720, 0.500000, 0.917990}}],
    Line[{{0.622720, 0.500000, 0.917990},{0.572109, 0.500000, 0.936525}}],
    Line[{{0.572109, 0.500000, 0.936525},{0.518622, 0.500000, 0.943833}}],
    Line[{{0.518622, 0.500000, 0.943833},{0.464636, 0.500000, 0.942549}}],
    Line[{{0.464636, 0.500000, 0.942549},{0.411678, 0.500000, 0.932161}}],
    Line[{{0.411678, 0.500000, 0.932161},{0.362888, 0.500000, 0.909349}}],
    Line[{{0.362888, 0.500000, 0.909349},{0.323857, 0.500000, 0.872306}}],
    Line[{{0.323857, 0.500000, 0.872306},{0.296841, 0.500000, 0.825633}}],
    Line[{{0.244219, 0.500000, 0.276580},{0.254827, 0.500000, 0.223591}}],
    Line[{{0.254827, 0.500000, 0.223591},{0.270563, 0.500000, 0.171914}}],
    Line[{{0.270563, 0.500000, 0.171914},{0.294504, 0.500000, 0.123565}}],
    Line[{{0.294504, 0.500000, 0.123565},{0.330453, 0.500000, 0.083519}}],
    Line[{{0.330453, 0.500000, 0.083519},{0.377600, 0.500000, 0.057548}}],
    Line[{{0.377600, 0.500000, 0.057548},{0.429938, 0.500000, 0.044406}}],
    Line[{{0.429938, 0.500000, 0.044406},{0.483737, 0.500000, 0.039532}}],
    Line[{{0.483737, 0.500000, 0.039532},{0.537752, 0.500000, 0.040690}}],
    Line[{{0.537752, 0.500000, 0.040690},{0.591201, 0.500000, 0.048423}}],
    Line[{{0.591201, 0.500000, 0.048423},{0.642141, 0.500000, 0.066100}}],
    Line[{{0.642141, 0.500000, 0.066100},{0.685437, 0.500000, 0.098016}}],
    Line[{{0.685437, 0.500000, 0.098016},{0.716273, 0.500000, 0.142186}}],
    Line[{{0.716273, 0.500000, 0.142186},{0.736477, 0.500000, 0.192249}}],
    Line[{{0.736477, 0.500000, 0.192249},{0.749892, 0.500000, 0.244587}}],
    Line[{{0.749892, 0.500000, 0.244587},{0.758995, 0.500000, 0.297858}}],
    Line[{{0.758995, 0.500000, 0.297858},{0.765129, 0.500000, 0.351557}}],
    Line[{{0.765129, 0.500000, 0.351557},{0.769027, 0.500000, 0.405467}}],
    Line[{{0.769027, 0.500000, 0.405467},{0.771084, 0.500000, 0.459480}}],
    Line[{{0.771084, 0.500000, 0.459480},{0.771486, 0.500000, 0.513530}}],
    Line[{{0.771486, 0.500000, 0.513530},{0.770269, 0.500000, 0.567569}}],
    Line[{{0.770269, 0.500000, 0.567569},{0.767327, 0.500000, 0.621540}}],
    Line[{{0.767327, 0.500000, 0.621540},{0.762377, 0.500000, 0.675363}}],
    Line[{{0.762377, 0.500000, 0.675363},{0.754880, 0.500000, 0.728888}}],
    Line[{{0.754880, 0.500000, 0.728888},{0.743844, 0.500000, 0.781789}}],
    Line[{{0.743844, 0.500000, 0.781789},{0.727436, 0.500000, 0.833253}}],
    Line[{{0.727436, 0.500000, 0.833253},{0.702420, 0.500000, 0.881041}}],
    Line[{{0.702420, 0.500000, 0.881041},{0.665152, 0.500000, 0.919846}}],
    Line[{{0.665152, 0.500000, 0.919846},{0.617189, 0.500000, 0.944311}}],
    Line[{{0.617189, 0.500000, 0.944311},{0.564590, 0.500000, 0.956416}}],
    Line[{{0.564590, 0.500000, 0.956416},{0.510732, 0.500000, 0.960619}}],
    Line[{{0.510732, 0.500000, 0.960619},{0.456734, 0.500000, 0.958858}}],
    Line[{{0.456734, 0.500000, 0.958858},{0.403413, 0.500000, 0.950312}}],
    Line[{{0.403413, 0.500000, 0.950312},{0.352959, 0.500000, 0.931336}}],
    Line[{{0.352959, 0.500000, 0.931336},{0.310810, 0.500000, 0.897925}}],
    Line[{{0.310810, 0.500000, 0.897925},{0.281237, 0.500000, 0.852881}}],
    Line[{{0.281237, 0.500000, 0.852881},{0.261887, 0.500000, 0.802473}}],
    Line[{{0.261887, 0.500000, 0.802473},{0.249000, 0.500000, 0.750000}}],
    Line[{{0.249000, 0.500000, 0.750000},{0.240254, 0.500000, 0.696667}}],
    Line[{{0.240254, 0.500000, 0.696667},{0.234376, 0.500000, 0.642938}}],
    Line[{{0.234376, 0.500000, 0.642938},{0.230681, 0.500000, 0.589014}}],
    Line[{{0.230681, 0.500000, 0.589014},{0.228800, 0.500000, 0.534995}}],
    Line[{{0.228800, 0.500000, 0.534995},{0.228563, 0.500000, 0.480943}}],
    Line[{{0.228563, 0.500000, 0.480943},{0.229948, 0.500000, 0.426909}}],
    Line[{{0.229948, 0.500000, 0.426909},{0.233081, 0.500000, 0.372949}}],
    Line[{{0.233081, 0.500000, 0.372949},{0.238262, 0.500000, 0.319149}}],
    Line[{{0.238262, 0.500000, 0.319149},{0.246067, 0.500000, 0.265668}}],
    Line[{{0.246067, 0.500000, 0.265668},{0.257550, 0.500000, 0.212866}}],
    Line[{{0.257550, 0.500000, 0.212866},{0.274662, 0.500000, 0.161638}}],
    Line[{{0.274662, 0.500000, 0.161638},{0.300790, 0.500000, 0.114465}}],
    Line[{{0.300790, 0.500000, 0.114465},{0.339359, 0.500000, 0.076969}}],
    Line[{{0.339359, 0.500000, 0.076969},{0.388062, 0.500000, 0.053972}}],
    Line[{{0.388062, 0.500000, 0.053972},{0.440887, 0.500000, 0.042849}}],
    Line[{{0.440887, 0.500000, 0.042849},{0.494793, 0.500000, 0.039297}}],
    Line[{{0.494793, 0.500000, 0.039297},{0.548767, 0.500000, 0.041666}}],
    Line[{{0.548767, 0.500000, 0.041666},{0.601937, 0.500000, 0.051067}}],
    Line[{{0.601937, 0.500000, 0.051067},{0.651843, 0.500000, 0.071392}}],
    Line[{{0.651843, 0.500000, 0.071392},{0.692793, 0.500000, 0.106261}}],
    Line[{{0.692793, 0.500000, 0.106261},{0.721137, 0.500000, 0.152108}}],
    Line[{{0.721137, 0.500000, 0.152108},{0.739674, 0.500000, 0.202828}}],
    Line[{{0.739674, 0.500000, 0.202828},{0.752051, 0.500000, 0.255426}}],
    Line[{{0.752051, 0.500000, 0.255426},{0.760462, 0.500000, 0.308813}}],
    Line[{{0.760462, 0.500000, 0.308813},{0.766092, 0.500000, 0.362568}}],
    Line[{{0.766092, 0.500000, 0.362568},{0.769588, 0.500000, 0.416506}}],
    Line[{{0.769588, 0.500000, 0.416506},{0.771297, 0.500000, 0.470530}}],
    Line[{{0.771297, 0.500000, 0.470530},{0.771370, 0.500000, 0.524582}}],
    Line[{{0.771370, 0.500000, 0.524582},{0.769814, 0.500000, 0.578612}}],
    Line[{{0.769814, 0.500000, 0.578612},{0.766488, 0.500000, 0.632560}}],
    Line[{{0.766488, 0.500000, 0.632560},{0.761071, 0.500000, 0.686337}}],
    Line[{{0.761071, 0.500000, 0.686337},{0.752948, 0.500000, 0.739768}}],
    Line[{{0.752948, 0.500000, 0.739768},{0.740998, 0.500000, 0.792465}}],
    Line[{{0.740998, 0.500000, 0.792465},{0.723146, 0.500000, 0.843433}}],
    Line[{{0.723146, 0.500000, 0.843433},{0.695861, 0.500000, 0.889931}}],
    Line[{{0.695861, 0.500000, 0.889931},{0.656014, 0.500000, 0.926059}}],
    Line[{{0.656014, 0.500000, 0.926059},{0.606640, 0.500000, 0.947619}}],
    Line[{{0.231019, 0.856046, 0.595499},{0.234832, 0.844401, 0.648103}}],
    Line[{{0.234832, 0.844401, 0.648103},{0.240384, 0.823889, 0.697677}}],
    Line[{{0.240384, 0.823889, 0.697677},{0.246646, 0.788722, 0.737618}}],
    Line[{{0.246646, 0.788722, 0.737618},{0.248745, 0.737371, 0.748726}}],
    Line[{{0.248745, 0.737371, 0.748726},{0.243793, 0.692455, 0.720868}}],
    Line[{{0.243793, 0.692455, 0.720868},{0.237574, 0.665063, 0.674967}}],
    Line[{{0.237574, 0.665063, 0.674967},{0.232817, 0.649254, 0.623571}}],
    Line[{{0.232817, 0.649254, 0.623571},{0.229833, 0.640611, 0.570327}}],
    Line[{{0.229833, 0.640611, 0.570327},{0.228533, 0.637081, 0.516422}}],
    Line[{{0.228533, 0.637081, 0.516422},{0.228849, 0.637925, 0.462391}}],
    Line[{{0.228849, 0.637925, 0.462391},{0.230797, 0.643315, 0.408663}}],
    Line[{{0.230797, 0.643315, 0.408663},{0.234471, 0.654424, 0.355930}}],
    Line[{{0.234471, 0.654424, 0.355930},{0.239899, 0.674074, 0.305984}}],
    Line[{{0.239899, 0.674074, 0.305984},{0.246214, 0.707849, 0.264800}}],
    Line[{{0.246214, 0.707849, 0.264800},{0.248884, 0.758468, 0.250575}}],
    Line[{{0.248884, 0.758468, 0.250575},{0.244297, 0.804719, 0.276031}}],
    Line[{{0.244297, 0.804719, 0.276031},{0.238020, 0.833295, 0.321163}}],
    Line[{{0.238020, 0.833295, 0.321163},{0.233126, 0.849810, 0.372318}}],
    Line[{{0.233126, 0.849810, 0.372318},{0.230006, 0.858918, 0.425474}}],
    Line[{{0.230006, 0.858918, 0.425474},{0.228578, 0.862808, 0.479350}}],
    Line[{{0.228578, 0.862808, 0.479350},{0.228767, 0.862301, 0.533385}}],
    Line[{{0.228767, 0.862301, 0.533385},{0.230585, 0.857293, 0.587154}}],
    Line[{{0.230585, 0.857293, 0.587154},{0.234120, 0.846706, 0.640005}}],
    Line[{{0.234120, 0.846706, 0.640005},{0.239418, 0.827887, 0.690293}}],
    Line[{{0.239418, 0.827887, 0.690293},{0.245758, 0.795472, 0.732610}}],
    Line[{{0.245758, 0.795472, 0.732610},{0.248970, 0.745748, 0.749853}}],
    Line[{{0.248970, 0.745748, 0.749853},{0.244794, 0.698236, 0.726972}}],
    Line[{{0.244794, 0.698236, 0.726972},{0.238478, 0.668428, 0.682689}}],
    Line[{{0.238478, 0.668428, 0.682689},{0.233447, 0.651174, 0.631801}}],
    Line[{{0.233447, 0.651174, 0.631801},{0.230189, 0.641588, 0.578738}}],
    Line[{{0.230189, 0.641588, 0.578738},{0.228632, 0.637331, 0.524894}}],
    Line[{{0.228632, 0.637331, 0.524894},{0.228695, 0.637501, 0.470857}}],
    Line[{{0.228695, 0.637501, 0.470857},{0.230382, 0.642130, 0.417048}}],
    Line[{{0.230382, 0.642130, 0.417048},{0.233779, 0.652209, 0.364087}}],
    Line[{{0.233779, 0.652209, 0.364087},{0.238945, 0.670229, 0.313484}}],
    Line[{{0.238945, 0.670229, 0.313484},{0.245285, 0.701320, 0.270135}}],
    Line[{{0.245285, 0.701320, 0.270135},{0.249000, 0.750000, 0.250000}}],
    Line[{{0.249000, 0.750000, 0.250000},{0.245285, 0.798680, 0.270135}}],
    Line[{{0.245285, 0.798680, 0.270135},{0.238945, 0.829771, 0.313484}}],
    Line[{{0.238945, 0.829771, 0.313484},{0.233779, 0.847791, 0.364087}}],
    Line[{{0.233779, 0.847791, 0.364087},{0.230382, 0.857870, 0.417048}}],
    Line[{{0.230382, 0.857870, 0.417048},{0.228695, 0.862499, 0.470857}}],
    Line[{{0.228695, 0.862499, 0.470857},{0.228632, 0.862669, 0.524894}}],
    Line[{{0.228632, 0.862669, 0.524894},{0.230189, 0.858412, 0.578738}}],
    Line[{{0.230189, 0.858412, 0.578738},{0.233447, 0.848825, 0.631800}}],
    Line[{{0.233447, 0.848825, 0.631800},{0.238478, 0.831572, 0.682689}}],
    Line[{{0.238478, 0.831572, 0.682689},{0.244794, 0.801764, 0.726972}}],
    Line[{{0.244794, 0.801764, 0.726972},{0.248970, 0.754252, 0.749853}}],
    Line[{{0.248970, 0.754252, 0.749853},{0.245758, 0.704528, 0.732610}}],
    Line[{{0.245758, 0.704528, 0.732610},{0.239418, 0.672113, 0.690293}}],
    Line[{{0.239418, 0.672113, 0.690293},{0.234120, 0.653294, 0.640005}}],
    Line[{{0.234120, 0.653294, 0.640005},{0.230585, 0.642707, 0.587154}}],
    Line[{{0.230585, 0.642707, 0.587154},{0.228767, 0.637699, 0.533384}}],
    Line[{{0.228767, 0.637699, 0.533384},{0.228578, 0.637192, 0.479350}}],
    Line[{{0.228578, 0.637192, 0.479350},{0.230006, 0.641082, 0.425474}}],
    Line[{{0.230006, 0.641082, 0.425474},{0.233126, 0.650190, 0.372318}}],
    Line[{{0.233126, 0.650190, 0.372318},{0.238020, 0.666706, 0.321164}}],
    Line[{{0.238020, 0.666706, 0.321164},{0.244297, 0.695282, 0.276031}}],
    Line[{{0.244297, 0.695282, 0.276031},{0.248884, 0.741532, 0.250575}}],
    Line[{{0.248884, 0.741532, 0.250575},{0.246214, 0.792152, 0.264800}}],
    Line[{{0.246214, 0.792152, 0.264800},{0.239899, 0.825927, 0.305985}}],
    Line[{{0.239899, 0.825927, 0.305985},{0.234471, 0.845576, 0.355931}}],
    Line[{{0.234471, 0.845576, 0.355931},{0.230797, 0.856685, 0.408663}}],
    Line[{{0.230797, 0.856685, 0.408663},{0.228849, 0.862075, 0.462392}}],
    Line[{{0.228849, 0.862075, 0.462392},{0.228534, 0.862919, 0.516422}}],
    Line[{{0.228534, 0.862919, 0.516422},{0.229833, 0.859389, 0.570327}}],
    Line[{{0.229833, 0.859389, 0.570327},{0.232817, 0.850745, 0.623571}}],
    Line[{{0.232817, 0.850745, 0.623571},{0.237574, 0.834936, 0.674967}}],
    Line[{{0.237574, 0.834936, 0.674967},{0.243793, 0.807544, 0.720868}}],
    Line[{{0.243793, 0.807544, 0.720868},{0.248745, 0.762628, 0.748726}}],
    Line[{{0.248745, 0.762628, 0.748726},{0.246646, 0.711278, 0.737617}}],
    Line[{{0.246646, 0.711278, 0.737617},{0.240384, 0.676111, 0.697676}}],
    Line[{{0.240384, 0.676111, 0.697676},{0.234832, 0.655599, 0.648102}}],
    Line[{{0.234832, 0.655599, 0.648102},{0.231019, 0.643954, 0.595498}}],
    Line[{{0.249000, 0.749964, 0.499958},{0.249000, 0.749968, 0.500053}}],
    Line[{{0.249000, 0.749968, 0.500053},{0.249000, 0.750023, 0.500070}}],
    Line[{{0.249000, 0.750023, 0.500070},{0.249000, 0.750038, 0.499989}}],
    Line[{{0.249000, 0.750038, 0.499989},{0.249000, 0.750009, 0.499913}}],
    Line[{{0.249000, 0.750009, 0.499913},{0.249000, 0.749959, 0.500015}}],
    Line[{{0.249000, 0.749959, 0.500015},{0.249000, 0.750033, 0.500060}}],
    Line[{{0.249000, 0.750033, 0.500060},{0.249000, 0.750030, 0.499944}}],
    Line[{{0.249000, 0.750030, 0.499944},{0.249000, 0.749976, 0.499928}}],
    Line[{{0.249000, 0.749976, 0.499928},{0.249000, 0.749962, 0.500009}}],
    Line[{{0.249000, 0.749962, 0.500009},{0.249000, 0.749971, 0.500047}}],
    Line[{{0.249000, 0.749971, 0.500047},{0.249000, 0.749969, 0.500043}}],
    Line[{{0.249000, 0.749969, 0.500043},{0.249000, 0.749994, 0.500083}}],
    Line[{{0.249000, 0.749994, 0.500083},{0.249000, 0.750030, 0.500050}}],
    Line[{{0.249000, 0.750030, 0.500050},{0.249000, 0.750031, 0.500036}}],
    Line[{{0.249000, 0.750031, 0.500036},{0.249000, 0.750027, 0.500047}}],
    Line[{{0.249000, 0.750027, 0.500047},{0.249000, 0.749997, 0.500073}}],
    Line[{{0.249000, 0.749997, 0.500073},{0.249000, 0.749969, 0.500035}}],
    Line[{{0.249000, 0.749969, 0.500035},{0.249000, 0.749970, 0.500049}}],
    Line[{{0.249000, 0.749970, 0.500049},{0.249000, 0.749987, 0.500074}}],
    Line[{{0.249000, 0.749987, 0.500074},{0.249000, 0.749981, 0.500063}}],
    Line[{{0.249000, 0.749981, 0.500063},{0.249000, 0.750009, 0.500080}}],
    Line[{{0.249000, 0.750009, 0.500080},{0.249000, 0.750040, 0.500024}}],
    Line[{{0.249000, 0.750040, 0.500024},{0.249000, 0.750023, 0.499931}}],
    Line[{{0.249000, 0.750023, 0.499931},{0.249000, 0.749978, 0.499932}}],
    Line[{{0.249000, 0.749978, 0.499932},{0.249000, 0.749971, 0.499955}}],
    Line[{{0.249000, 0.749971, 0.499955},{0.249000, 0.750012, 0.499939}}],
    Line[{{0.249000, 0.750012, 0.499939},{0.249000, 0.749990, 0.500055}}],
    Line[{{0.249000, 0.749990, 0.500055},{0.249000, 0.750023, 0.500023}}],
    Line[{{0.249000, 0.750023, 0.500023},{0.249000, 0.750025, 0.499998}}],
    Line[{{0.249000, 0.750025, 0.499998},{0.249000, 0.750025, 0.499998}}],
    Line[{{0.249000, 0.750025, 0.499998},{0.249000, 0.750019, 0.500027}}],
    Line[{{0.249000, 0.750019, 0.500027},{0.249000, 0.749981, 0.500004}}],
    Line[{{0.249000, 0.749981, 0.500004},{0.249000, 0.750015, 0.499970}}],
    Line[{{0.249000, 0.750015, 0.499970},{0.249000, 0.750002, 0.499967}}],
    Line[{{0.249000, 0.750002, 0.499967},{0.249000, 0.750014, 0.500020}}],
    Line[{{0.249000, 0.750014, 0.500020},{0.249000, 0.750003, 0.500037}}],
    Line[{{0.249000, 0.750003, 0.500037},{0.249000, 0.749986, 0.499994}}],
    Line[{{0.249000, 0.749986, 0.499994},{0.249000, 0.749996, 0.500026}}],
    Line[{{0.249000, 0.749996, 0.500026},{0.249000, 0.750010, 0.499995}}],
    Line[{{0.249000, 0.750010, 0.499995},{0.249000, 0.750006, 0.499995}}],
    Line[{{0.249000, 0.750006, 0.499995},{0.249000, 0.749998, 0.500011}}],
    Line[{{0.249000, 0.749998, 0.500011},{0.249000, 0.750000, 0.500000}}],
    Line[{{0.249000, 0.750000, 0.500000},{0.249000, 0.749997, 0.500015}}],
    Line[{{0.249000, 0.749997, 0.500015},{0.249000, 0.749991, 0.499982}}],
    Line[{{0.249000, 0.749991, 0.499982},{0.249000, 0.750007, 0.499969}}],
    Line[{{0.249000, 0.750007, 0.499969},{0.249000, 0.750004, 0.500030}}],
    Line[{{0.249000, 0.750004, 0.500030},{0.249000, 0.749985, 0.499981}}],
    Line[{{0.249000, 0.749985, 0.499981},{0.249000, 0.749983, 0.500022}}],
    Line[{{0.249000, 0.749983, 0.500022},{0.249000, 0.750017, 0.499973}}],
    Line[{{0.249000, 0.750017, 0.499973},{0.249000, 0.750024, 0.499984}}],
    Line[{{0.249000, 0.750024, 0.499984},{0.249000, 0.749989, 0.499947}}],
    Line[{{0.249000, 0.749989, 0.499947},{0.249000, 0.749990, 0.500055}}],
    Line[{{0.249000, 0.749990, 0.500055},{0.249000, 0.750024, 0.499970}}],
    Line[{{0.249000, 0.750024, 0.499970},{0.249000, 0.749975, 0.500036}}],
    Line[{{0.249000, 0.749975, 0.500036},{0.249000, 0.749975, 0.499957}}],
    Line[{{0.249000, 0.749975, 0.499957},{0.249000, 0.750014, 0.499937}}],
    Line[{{0.249000, 0.750014, 0.499937},{0.249000, 0.750034, 0.500000}}],
    Line[{{0.249000, 0.750034, 0.500000},{0.249000, 0.750008, 0.500067}}],
    Line[{{0.249000, 0.750008, 0.500067},{0.249000, 0.749975, 0.500050}}],
    Line[{{0.249000, 0.749975, 0.500050},{0.249000, 0.749969, 0.500036}}],
    Line[{{0.249000, 0.749969, 0.500036},{0.249000, 0.749971, 0.499971}}],
    Line[{{0.249000, 0.749971, 0.499971},{0.249000, 0.750028, 0.499967}}],
    Line[{{0.249000, 0.750028, 0.499967},{0.249000, 0.750031, 0.500027}}],
    Line[{{0.249000, 0.750031, 0.500027},{0.249000, 0.750025, 0.500049}}],
    Line[{{0.249000, 0.750025, 0.500049},{0.249000, 0.749996, 0.500072}}],
    Line[{{0.249000, 0.749996, 0.500072},{0.249000, 0.749980, 0.500063}}],
    Line[{{0.249000, 0.749980, 0.500063},{0.249000, 0.749974, 0.500052}}],
    Line[{{0.249000, 0.749974, 0.500052},{0.249000, 0.749971, 0.500041}}],
    Line[{{0.249000, 0.749971, 0.500041},{0.249000, 0.749966, 0.500026}}],
    Line[{{0.249000, 0.749966, 0.500026},{0.249000, 0.749965, 0.500024}}],
    Line[{{0.249000, 0.749965, 0.500024},{0.249000, 0.749967, 0.500023}}],
    Line[{{0.249000, 0.749967, 0.500023},{0.249000, 0.749965, 0.500008}}],
    Line[{{0.249000, 0.749965, 0.500008},{0.249000, 0.749986, 0.499941}}],
    Line[{{0.249000, 0.749986, 0.499941},{0.249000, 0.750030, 0.500024}}],
    Line[{{0.231018, 0.643952, 0.404511},{0.234831, 0.655596, 0.351906}}],
    Line[{{0.234831, 0.655596, 0.351906},{0.240382, 0.676105, 0.302332}}],
    Line[{{0.240382, 0.676105, 0.302332},{0.246645, 0.711270, 0.262386}}],
    Line[{{0.246645, 0.711270, 0.262386},{0.248745, 0.762620, 0.251272}}],
    Line[{{0.248745, 0.762620, 0.251272},{0.243794, 0.807540, 0.279125}}],
    Line[{{0.243794, 0.807540, 0.279125},{0.237574, 0.834934, 0.325024}}],
    Line[{{0.237574, 0.834934, 0.325024},{0.232817, 0.850744, 0.376421}}],
    Line[{{0.232817, 0.850744, 0.376421},{0.229833, 0.859389, 0.429665}}],
    Line[{{0.229833, 0.859389, 0.429665},{0.228533, 0.862919, 0.483569}}],
    Line[{{0.228533, 0.862919, 0.483569},{0.228848, 0.862076, 0.537600}}],
    Line[{{0.228848, 0.862076, 0.537600},{0.230796, 0.856687, 0.591328}}],
    Line[{{0.230796, 0.856687, 0.591328},{0.234470, 0.845579, 0.644061}}],
    Line[{{0.234470, 0.845579, 0.644061},{0.239897, 0.825931, 0.694009}}],
    Line[{{0.239897, 0.825931, 0.694009},{0.246212, 0.792157, 0.735193}}],
    Line[{{0.246212, 0.792157, 0.735193},{0.248884, 0.741541, 0.749427}}],
    Line[{{0.248884, 0.741541, 0.749427},{0.244297, 0.695287, 0.723975}}],
    Line[{{0.244297, 0.695287, 0.723975},{0.238020, 0.666709, 0.678843}}],
    Line[{{0.238020, 0.666709, 0.678843},{0.233126, 0.650193, 0.627690}}],
    Line[{{0.233126, 0.650193, 0.627690},{0.230006, 0.641085, 0.574532}}],
    Line[{{0.230006, 0.641085, 0.574532},{0.228578, 0.637194, 0.520656}}],
    Line[{{0.228578, 0.637194, 0.520656},{0.228767, 0.637700, 0.466621}}],
    Line[{{0.228767, 0.637700, 0.466621},{0.230585, 0.642707, 0.412850}}],
    Line[{{0.230585, 0.642707, 0.412850},{0.234120, 0.653293, 0.359998}}],
    Line[{{0.234120, 0.653293, 0.359998},{0.239418, 0.672112, 0.309709}}],
    Line[{{0.239418, 0.672112, 0.309709},{0.245758, 0.704526, 0.267392}}],
    Line[{{0.245758, 0.704526, 0.267392},{0.248970, 0.754249, 0.250147}}],
    Line[{{0.248970, 0.754249, 0.250147},{0.244795, 0.801762, 0.273026}}],
    Line[{{0.244795, 0.801762, 0.273026},{0.238478, 0.831572, 0.317310}}],
    Line[{{0.238478, 0.831572, 0.317310},{0.233447, 0.848825, 0.368199}}],
    Line[{{0.233447, 0.848825, 0.368199},{0.230189, 0.858412, 0.421262}}],
    Line[{{0.230189, 0.858412, 0.421262},{0.228632, 0.862669, 0.475105}}],
    Line[{{0.228632, 0.862669, 0.475105},{0.228695, 0.862499, 0.529142}}],
    Line[{{0.228695, 0.862499, 0.529142},{0.230382, 0.857870, 0.582951}}],
    Line[{{0.230382, 0.857870, 0.582951},{0.233779, 0.847791, 0.635913}}],
    Line[{{0.233779, 0.847791, 0.635913},{0.238945, 0.829771, 0.686516}}],
    Line[{{0.238945, 0.829771, 0.686516},{0.245285, 0.798680, 0.729864}}],
    Line[{{0.245285, 0.798680, 0.729864},{0.249000, 0.750000, 0.750000}}],
    Line[{{0.249000, 0.750000, 0.750000},{0.245285, 0.701320, 0.729864}}],
    Line[{{0.245285, 0.701320, 0.729864},{0.238945, 0.670229, 0.686516}}],
    Line[{{0.238945, 0.670229, 0.686516},{0.233779, 0.652209, 0.635913}}],
    Line[{{0.233779, 0.652209, 0.635913},{0.230382, 0.642130, 0.582951}}],
    Line[{{0.230382, 0.642130, 0.582951},{0.228695, 0.637501, 0.529142}}],
    Line[{{0.228695, 0.637501, 0.529142},{0.228632, 0.637331, 0.475105}}],
    Line[{{0.228632, 0.637331, 0.475105},{0.230189, 0.641588, 0.421262}}],
    Line[{{0.230189, 0.641588, 0.421262},{0.233447, 0.651175, 0.368199}}],
    Line[{{0.233447, 0.651175, 0.368199},{0.238478, 0.668428, 0.317310}}],
    Line[{{0.238478, 0.668428, 0.317310},{0.244795, 0.698238, 0.273026}}],
    Line[{{0.244795, 0.698238, 0.273026},{0.248970, 0.745751, 0.250148}}],
    Line[{{0.248970, 0.745751, 0.250148},{0.245758, 0.795474, 0.267392}}],
    Line[{{0.245758, 0.795474, 0.267392},{0.239418, 0.827888, 0.309709}}],
    Line[{{0.239418, 0.827888, 0.309709},{0.234120, 0.846707, 0.359998}}],
    Line[{{0.234120, 0.846707, 0.359998},{0.230585, 0.857293, 0.412850}}],
    Line[{{0.230585, 0.857293, 0.412850},{0.228767, 0.862300, 0.466621}}],
    Line[{{0.228767, 0.862300, 0.466621},{0.228578, 0.862806, 0.520656}}],
    Line[{{0.228578, 0.862806, 0.520656},{0.230006, 0.858915, 0.574532}}],
    Line[{{0.230006, 0.858915, 0.574532},{0.233126, 0.849807, 0.627690}}],
    Line[{{0.233126, 0.849807, 0.627690},{0.238020, 0.833291, 0.678843}}],
    Line[{{0.238020, 0.833291, 0.678843},{0.244297, 0.804713, 0.723974}}],
    Line[{{0.244297, 0.804713, 0.723974},{0.248884, 0.758459, 0.749426}}],
    Line[{{0.248884, 0.758459, 0.749426},{0.246212, 0.707843, 0.735193}}],
    Line[{{0.246212, 0.707843, 0.735193},{0.239897, 0.674069, 0.694009}}],
    Line[{{0.239897, 0.674069, 0.694009},{0.234470, 0.654421, 0.644061}}],
    Line[{{0.234470, 0.654421, 0.644061},{0.230796, 0.643313, 0.591328}}],
    Line[{{0.230796, 0.643313, 0.591328},{0.228848, 0.637924, 0.537599}}],
    Line[{{0.228848, 0.637924, 0.537599},{0.228533, 0.637081, 0.483569}}],
    Line[{{0.228533, 0.637081, 0.483569},{0.229833, 0.640611, 0.429664}}],
    Line[{{0.229833, 0.640611, 0.429664},{0.232817, 0.649256, 0.376420}}],
    Line[{{0.232817, 0.649256, 0.376420},{0.237574, 0.665066, 0.325023}}],
    Line[{{0.237574, 0.665066, 0.325023},{0.243794, 0.692460, 0.279125}}],
    Line[{{0.243794, 0.692460, 0.279125},{0.248745, 0.737381, 0.251272}}],
    Line[{{0.248745, 0.737381, 0.251272},{0.246645, 0.788731, 0.262386}}],
    Line[{{0.246645, 0.788731, 0.262386},{0.240382, 0.823895, 0.302332}}],
    Line[{{0.240382, 0.823895, 0.302332},{0.234830, 0.844405, 0.351907}}],
    Line[{{0.234830, 0.844405, 0.351907},{0.231018, 0.856048, 0.404511}}],
    Line[{{0.488260, 0.238322, 0.748936},{0.472916, 0.277012, 0.744148}}],
    Line[{{0.472916, 0.277012, 0.744148},{0.439480, 0.309962, 0.718072}}],
    Line[{{0.439480, 0.309962, 0.718072},{0.414344, 0.334086, 0.677038}}],
    Line[{{0.414344, 0.334086, 0.677038},{0.397613, 0.349701, 0.628189}}],
    Line[{{0.397613, 0.349701, 0.628189},{0.387685, 0.358764, 0.575893}}],
    Line[{{0.387685, 0.358764, 0.575893},{0.383242, 0.362766, 0.522207}}],
    Line[{{0.383242, 0.362766, 0.522207},{0.383668, 0.362384, 0.468188}}],
    Line[{{0.383668, 0.362384, 0.468188},{0.389023, 0.357552, 0.414656}}],
    Line[{{0.389023, 0.357552, 0.414656},{0.400046, 0.347456, 0.362775}}],
    Line[{{0.400046, 0.347456, 0.362775},{0.418168, 0.330462, 0.314909}}],
    Line[{{0.418168, 0.330462, 0.314909},{0.444890, 0.304685, 0.275967}}],
    Line[{{0.444890, 0.304685, 0.275967},{0.479493, 0.270456, 0.253323}}],
    Line[{{0.479493, 0.270456, 0.253323},{0.481629, 0.231675, 0.252658}}],
    Line[{{0.481629, 0.231675, 0.252658},{0.446681, 0.197067, 0.274163}}],
    Line[{{0.446681, 0.197067, 0.274163},{0.419454, 0.170760, 0.312382}}],
    Line[{{0.419454, 0.170760, 0.312382},{0.400876, 0.153312, 0.359902}}],
    Line[{{0.400876, 0.153312, 0.359902},{0.389492, 0.142873, 0.411633}}],
    Line[{{0.389492, 0.142873, 0.411633},{0.383840, 0.137770, 0.465108}}],
    Line[{{0.383840, 0.137770, 0.465108},{0.383140, 0.137142, 0.519122}}],
    Line[{{0.383140, 0.137142, 0.519122},{0.387295, 0.140883, 0.572851}}],
    Line[{{0.387295, 0.140883, 0.572851},{0.396882, 0.149625, 0.625269}}],
    Line[{{0.396882, 0.149625, 0.625269},{0.413179, 0.164814, 0.674403}}],
    Line[{{0.413179, 0.164814, 0.674403},{0.437811, 0.188415, 0.716055}}],
    Line[{{0.437811, 0.188415, 0.716055},{0.470844, 0.220925, 0.743183}}],
    Line[{{0.470844, 0.220925, 0.743183},{0.490521, 0.259421, 0.749305}}],
    Line[{{0.490521, 0.259421, 0.749305},{0.454346, 0.295407, 0.732677}}],
    Line[{{0.454346, 0.295407, 0.732677},{0.425065, 0.323883, 0.697716}}],
    Line[{{0.425065, 0.323883, 0.697716},{0.404543, 0.343283, 0.651808}}],
    Line[{{0.404543, 0.343283, 0.651808},{0.391617, 0.355195, 0.600774}}],
    Line[{{0.391617, 0.355195, 0.600774},{0.384710, 0.361448, 0.547573}}],
    Line[{{0.384710, 0.361448, 0.547573},{0.382877, 0.363093, 0.493608}}],
    Line[{{0.382877, 0.363093, 0.493608},{0.385863, 0.360410, 0.439736}}],
    Line[{{0.385863, 0.360410, 0.439736},{0.394080, 0.352946, 0.386884}}],
    Line[{{0.394080, 0.352946, 0.386884},{0.408648, 0.339447, 0.336705}}],
    Line[{{0.408648, 0.339447, 0.336705},{0.431203, 0.317982, 0.292745}}],
    Line[{{0.431203, 0.317982, 0.292745},{0.462445, 0.287410, 0.261500}}],
    Line[{{0.462445, 0.287410, 0.261500},{0.499000, 0.250000, 0.250000}}],
    Line[{{0.499000, 0.250000, 0.250000},{0.462445, 0.212590, 0.261500}}],
    Line[{{0.462445, 0.212590, 0.261500},{0.431203, 0.182018, 0.292745}}],
    Line[{{0.431203, 0.182018, 0.292745},{0.408648, 0.160553, 0.336705}}],
    Line[{{0.408648, 0.160553, 0.336705},{0.394080, 0.147055, 0.386884}}],
    Line[{{0.394080, 0.147055, 0.386884},{0.385863, 0.139590, 0.439736}}],
    Line[{{0.385863, 0.139590, 0.439736},{0.382877, 0.136907, 0.493608}}],
    Line[{{0.382877, 0.136907, 0.493608},{0.384710, 0.138552, 0.547573}}],
    Line[{{0.384710, 0.138552, 0.547573},{0.391617, 0.144805, 0.600774}}],
    Line[{{0.391617, 0.144805, 0.600774},{0.404543, 0.156717, 0.651807}}],
    Line[{{0.404543, 0.156717, 0.651807},{0.425065, 0.176117, 0.697716}}],
    Line[{{0.425065, 0.176117, 0.697716},{0.454346, 0.204592, 0.732677}}],
    Line[{{0.454346, 0.204592, 0.732677},{0.490519, 0.240577, 0.749305}}],
    Line[{{0.490519, 0.240577, 0.749305},{0.470847, 0.279072, 0.743185}}],
    Line[{{0.470847, 0.279072, 0.743185},{0.437811, 0.311584, 0.716060}}],
    Line[{{0.437811, 0.311584, 0.716060},{0.413179, 0.335185, 0.674408}}],
    Line[{{0.413179, 0.335185, 0.674408},{0.396882, 0.350374, 0.625274}}],
    Line[{{0.396882, 0.350374, 0.625274},{0.387296, 0.359116, 0.572857}}],
    Line[{{0.387296, 0.359116, 0.572857},{0.383139, 0.362858, 0.519129}}],
    Line[{{0.383139, 0.362858, 0.519129},{0.383839, 0.362230, 0.465115}}],
    Line[{{0.383839, 0.362230, 0.465115},{0.389490, 0.357129, 0.411639}}],
    Line[{{0.389490, 0.357129, 0.411639},{0.400874, 0.346690, 0.359907}}],
    Line[{{0.400874, 0.346690, 0.359907},{0.419450, 0.329244, 0.312387}}],
    Line[{{0.419450, 0.329244, 0.312387},{0.446676, 0.302938, 0.274166}}],
    Line[{{0.446676, 0.302938, 0.274166},{0.481621, 0.268332, 0.252658}}],
    Line[{{0.481621, 0.268332, 0.252658},{0.479493, 0.229544, 0.253321}}],
    Line[{{0.479493, 0.229544, 0.253321},{0.444891, 0.195316, 0.275966}}],
    Line[{{0.444891, 0.195316, 0.275966},{0.418168, 0.169538, 0.314907}}],
    Line[{{0.418168, 0.169538, 0.314907},{0.400046, 0.152544, 0.362773}}],
    Line[{{0.400046, 0.152544, 0.362773},{0.389022, 0.142447, 0.414654}}],
    Line[{{0.389022, 0.142447, 0.414654},{0.383667, 0.137616, 0.468186}}],
    Line[{{0.383667, 0.137616, 0.468186},{0.383241, 0.137234, 0.522205}}],
    Line[{{0.383241, 0.137234, 0.522205},{0.387685, 0.141236, 0.575891}}],
    Line[{{0.387685, 0.141236, 0.575891},{0.397612, 0.150298, 0.628188}}],
    Line[{{0.397612, 0.150298, 0.628188},{0.414341, 0.165912, 0.677036}}],
    Line[{{0.414341, 0.165912, 0.677036},{0.439478, 0.190037, 0.718071}}],
    Line[{{0.439478, 0.190037, 0.718071},{0.472915, 0.222987, 0.744148}}],
    Line[{{0.472915, 0.222987, 0.744148},{0.488288, 0.261652, 0.748941}}],
    Line[{{0.499000, 0.250012, 0.500035},{0.499000, 0.249981, 0.500016}}],
    Line[{{0.499000, 0.249981, 0.500016},{0.499000, 0.249989, 0.499962}}],
    Line[{{0.499000, 0.249989, 0.499962},{0.499000, 0.250019, 0.499986}}],
    Line[{{0.499000, 0.250019, 0.499986},{0.499000, 0.250009, 0.500039}}],
    Line[{{0.499000, 0.250009, 0.500039},{0.499000, 0.249982, 0.500015}}],
    Line[{{0.499000, 0.249982, 0.500015},{0.499000, 0.249985, 0.499973}}],
    Line[{{0.499000, 0.249985, 0.499973},{0.499000, 0.250017, 0.499974}}],
    Line[{{0.499000, 0.250017, 0.499974},{0.499000, 0.250003, 0.500046}}],
    Line[{{0.499000, 0.250003, 0.500046},{0.499000, 0.249984, 0.499964}}],
    Line[{{0.499000, 0.249984, 0.499964},{0.499000, 0.250020, 0.500022}}],
    Line[{{0.499000, 0.250020, 0.500022},{0.499000, 0.249977, 0.499999}}],
    Line[{{0.499000, 0.249977, 0.499999},{0.499000, 0.250023, 0.499998}}],
    Line[{{0.499000, 0.250023, 0.499998},{0.499000, 0.249979, 0.500019}}],
    Line[{{0.499000, 0.249979, 0.500019},{0.499000, 0.250009, 0.499956}}],
    Line[{{0.499000, 0.250009, 0.499956},{0.499000, 0.250018, 0.500020}}],
    Line[{{0.499000, 0.250018, 0.500020},{0.499000, 0.249985, 0.500033}}],
    Line[{{0.499000, 0.249985, 0.500033},{0.499000, 0.249982, 0.499972}}],
    Line[{{0.499000, 0.249982, 0.499972},{0.499000, 0.250022, 0.500000}}],
    Line[{{0.499000, 0.250022, 0.500000},{0.499000, 0.249982, 0.500025}}],
    Line[{{0.499000, 0.249982, 0.500025},{0.499000, 0.250000, 0.499954}}],
    Line[{{0.499000, 0.250000, 0.499954},{0.499000, 0.250018, 0.500027}}],
    Line[{{0.499000, 0.250018, 0.500027},{0.499000, 0.249977, 0.500001}}],
    Line[{{0.499000, 0.249977, 0.500001},{0.499000, 0.250017, 0.499969}}],
    Line[{{0.499000, 0.250017, 0.499969},{0.499000, 0.249998, 0.500045}}],
    Line[{{0.499000, 0.249998, 0.500045},{0.499000, 0.249980, 0.500000}}],
    Line[{{0.499000, 0.249980, 0.500000},{0.499000, 0.249992, 0.499960}}],
    Line[{{0.499000, 0.249992, 0.499960},{0.499000, 0.250021, 0.499997}}],
    Line[{{0.499000, 0.250021, 0.499997},{0.499000, 0.249994, 0.500043}}],
    Line[{{0.499000, 0.249994, 0.500043},{0.499000, 0.249981, 0.499983}}],
    Line[{{0.499000, 0.249981, 0.499983},{0.499000, 0.250013, 0.499967}}],
    Line[{{0.499000, 0.250013, 0.499967},{0.499000, 0.250018, 0.499991}}],
    Line[{{0.499000, 0.250018, 0.499991},{0.499000, 0.250017, 0.500003}}],
    Line[{{0.499000, 0.250017, 0.500003},{0.499000, 0.250009, 0.499974}}],
    Line[{{0.499000, 0.250009, 0.499974},{0.499000, 0.249988, 0.500015}}],
    Line[{{0.499000, 0.249988, 0.500015},{0.499000, 0.250016, 0.500009}}],
    Line[{{0.499000, 0.250016, 0.500009},{0.499000, 0.249994, 0.499972}}],
    Line[{{0.499000, 0.249994, 0.499972},{0.499000, 0.249997, 0.500029}}],
    Line[{{0.499000, 0.249997, 0.500029},{0.499000, 0.249990, 0.499985}}],
    Line[{{0.499000, 0.249990, 0.499985},{0.499000, 0.249991, 0.499986}}],
    Line[{{0.499000, 0.249991, 0.499986},{0.499000, 0.249999, 0.500020}}],
    Line[{{0.499000, 0.249999, 0.500020},{0.499000, 0.249993, 0.499984}}],
    Line[{{0.499000, 0.249993, 0.499984},{0.499000, 0.249989, 0.500007}}],
    Line[{{0.499000, 0.249989, 0.500007},{0.499000, 0.249990, 0.500017}}],
    Line[{{0.499000, 0.249990, 0.500017},{0.499000, 0.249989, 0.500010}}],
    Line[{{0.499000, 0.249989, 0.500010},{0.499000, 0.250006, 0.500019}}],
    Line[{{0.499000, 0.250006, 0.500019},{0.499000, 0.250011, 0.499997}}],
    Line[{{0.499000, 0.250011, 0.499997},{0.499000, 0.250007, 0.499981}}],
    Line[{{0.499000, 0.250007, 0.499981},{0.499000, 0.250006, 0.500015}}],
    Line[{{0.499000, 0.250006, 0.500015},{0.499000, 0.250009, 0.500011}}],
    Line[{{0.499000, 0.250009, 0.500011},{0.499000, 0.249989, 0.500000}}],
    Line[{{0.499000, 0.249989, 0.500000},{0.499000, 0.250004, 0.500020}}],
    Line[{{0.499000, 0.250004, 0.500020},{0.499000, 0.250005, 0.499983}}],
    Line[{{0.499000, 0.250005, 0.499983},{0.499000, 0.249990, 0.500006}}],
    Line[{{0.499000, 0.249990, 0.500006},{0.499000, 0.250006, 0.499986}}],
    Line[{{0.499000, 0.250006, 0.499986},{0.499000, 0.250001, 0.500008}}],
    Line[{{0.499000, 0.250001, 0.500008},{0.499000, 0.250000, 0.500001}}],
    Line[{{0.499000, 0.250000, 0.500001},{0.499000, 0.249999, 0.500001}}],
    Line[{{0.499000, 0.249999, 0.500001},{0.499000, 0.250001, 0.500002}}],
    Line[{{0.499000, 0.250001, 0.500002},{0.499000, 0.250000, 0.499997}}],
    Line[{{0.499000, 0.250000, 0.499997},{0.499000, 0.249999, 0.500001}}],
    Line[{{0.499000, 0.249999, 0.500001},{0.499000, 0.250001, 0.500002}}],
    Line[{{0.499000, 0.250001, 0.500002},{0.499000, 0.250000, 0.499997}}],
    Line[{{0.499000, 0.250000, 0.499997},{0.499000, 0.249999, 0.500001}}],
    Line[{{0.499000, 0.249999, 0.500001},{0.499000, 0.250001, 0.500003}}],
    Line[{{0.499000, 0.250001, 0.500003},{0.499000, 0.250000, 0.499997}}],
    Line[{{0.499000, 0.250000, 0.499997},{0.499000, 0.249998, 0.500000}}],
    Line[{{0.499000, 0.249998, 0.500000},{0.499000, 0.250001, 0.500003}}],
    Line[{{0.499000, 0.250001, 0.500003},{0.499000, 0.250001, 0.499997}}],
    Line[{{0.499000, 0.250001, 0.499997},{0.499000, 0.249998, 0.500000}}],
    Line[{{0.499000, 0.249998, 0.500000},{0.499000, 0.250001, 0.500003}}],
    Line[{{0.499000, 0.250001, 0.500003},{0.499000, 0.250001, 0.499997}}],
    Line[{{0.499000, 0.250001, 0.499997},{0.499000, 0.249998, 0.500000}}],
    Line[{{0.499000, 0.249998, 0.500000},{0.499000, 0.250000, 0.500003}}],
    Line[{{0.499000, 0.250000, 0.500003},{0.499000, 0.250001, 0.499998}}],
    Line[{{0.488214, 0.261723, 0.251078},{0.472944, 0.223015, 0.255845}}],
    Line[{{0.472944, 0.223015, 0.255845},{0.439502, 0.190061, 0.281906}}],
    Line[{{0.439502, 0.190061, 0.281906},{0.414358, 0.165929, 0.322933}}],
    Line[{{0.414358, 0.165929, 0.322933},{0.397624, 0.150309, 0.371777}}],
    Line[{{0.397624, 0.150309, 0.371777},{0.387692, 0.141243, 0.424073}}],
    Line[{{0.387692, 0.141243, 0.424073},{0.383245, 0.137237, 0.477758}}],
    Line[{{0.383245, 0.137237, 0.477758},{0.383668, 0.137617, 0.531778}}],
    Line[{{0.383668, 0.137617, 0.531778},{0.389020, 0.142445, 0.585310}}],
    Line[{{0.389020, 0.142445, 0.585310},{0.400039, 0.152538, 0.637192}}],
    Line[{{0.400039, 0.152538, 0.637192},{0.418155, 0.169526, 0.685063}}],
    Line[{{0.418155, 0.169526, 0.685063},{0.444872, 0.195297, 0.724012}}],
    Line[{{0.444872, 0.195297, 0.724012},{0.479473, 0.229523, 0.746666}}],
    Line[{{0.479473, 0.229523, 0.746666},{0.481643, 0.268311, 0.747342}}],
    Line[{{0.481643, 0.268311, 0.747342},{0.446694, 0.302921, 0.725844}}],
    Line[{{0.446694, 0.302921, 0.725844},{0.419464, 0.329231, 0.687629}}],
    Line[{{0.419464, 0.329231, 0.687629},{0.400883, 0.346682, 0.640112}}],
    Line[{{0.400883, 0.346682, 0.640112},{0.389496, 0.357123, 0.588382}}],
    Line[{{0.389496, 0.357123, 0.588382},{0.383842, 0.362227, 0.534908}}],
    Line[{{0.383842, 0.362227, 0.534908},{0.383141, 0.362856, 0.480893}}],
    Line[{{0.383141, 0.362856, 0.480893},{0.387296, 0.359117, 0.427165}}],
    Line[{{0.387296, 0.359117, 0.427165},{0.396880, 0.350376, 0.374746}}],
    Line[{{0.396880, 0.350376, 0.374746},{0.413176, 0.335189, 0.325611}}],
    Line[{{0.413176, 0.335189, 0.325611},{0.437805, 0.311590, 0.283957}}],
    Line[{{0.437805, 0.311590, 0.283957},{0.470838, 0.279082, 0.256824}}],
    Line[{{0.470838, 0.279082, 0.256824},{0.490524, 0.240582, 0.250698}}],
    Line[{{0.490524, 0.240582, 0.250698},{0.454350, 0.204596, 0.267324}}],
    Line[{{0.454350, 0.204596, 0.267324},{0.425068, 0.176120, 0.302285}}],
    Line[{{0.425068, 0.176120, 0.302285},{0.404545, 0.156719, 0.348192}}],
    Line[{{0.404545, 0.156719, 0.348192},{0.391618, 0.144806, 0.399227}}],
    Line[{{0.391618, 0.144806, 0.399227},{0.384712, 0.138554, 0.452429}}],
    Line[{{0.384712, 0.138554, 0.452429},{0.382878, 0.136908, 0.506394}}],
    Line[{{0.382878, 0.136908, 0.506394},{0.385864, 0.139591, 0.560264}}],
    Line[{{0.385864, 0.139591, 0.560264},{0.394082, 0.147056, 0.613116}}],
    Line[{{0.394082, 0.147056, 0.613116},{0.408649, 0.160553, 0.663294}}],
    Line[{{0.408649, 0.160553, 0.663294},{0.431203, 0.182018, 0.707255}}],
    Line[{{0.431203, 0.182018, 0.707255},{0.462445, 0.212590, 0.738500}}],
    Line[{{0.462445, 0.212590, 0.738500},{0.499000, 0.250000, 0.750000}}],
    Line[{{0.499000, 0.250000, 0.750000},{0.462445, 0.287410, 0.738500}}],
    Line[{{0.462445, 0.287410, 0.738500},{0.431203, 0.317982, 0.707255}}],
    Line[{{0.431203, 0.317982, 0.707255},{0.408649, 0.339447, 0.663294}}],
    Line[{{0.408649, 0.339447, 0.663294},{0.394082, 0.352944, 0.613116}}],
    Line[{{0.394082, 0.352944, 0.613116},{0.385864, 0.360409, 0.560264}}],
    Line[{{0.385864, 0.360409, 0.560264},{0.382878, 0.363092, 0.506394}}],
    Line[{{0.382878, 0.363092, 0.506394},{0.384712, 0.361446, 0.452429}}],
    Line[{{0.384712, 0.361446, 0.452429},{0.391618, 0.355194, 0.399227}}],
    Line[{{0.391618, 0.355194, 0.399227},{0.404545, 0.343281, 0.348192}}],
    Line[{{0.404545, 0.343281, 0.348192},{0.425068, 0.323880, 0.302285}}],
    Line[{{0.425068, 0.323880, 0.302285},{0.454348, 0.295405, 0.267324}}],
    Line[{{0.454348, 0.295405, 0.267324},{0.490522, 0.259420, 0.250698}}],
    Line[{{0.490522, 0.259420, 0.250698},{0.470843, 0.220923, 0.256821}}],
    Line[{{0.470843, 0.220923, 0.256821},{0.437808, 0.188413, 0.283948}}],
    Line[{{0.437808, 0.188413, 0.283948},{0.413178, 0.164813, 0.325602}}],
    Line[{{0.413178, 0.164813, 0.325602},{0.396882, 0.149626, 0.374737}}],
    Line[{{0.396882, 0.149626, 0.374737},{0.387297, 0.140884, 0.427155}}],
    Line[{{0.387297, 0.140884, 0.427155},{0.383141, 0.137144, 0.480883}}],
    Line[{{0.383141, 0.137144, 0.480883},{0.383842, 0.137772, 0.534897}}],
    Line[{{0.383842, 0.137772, 0.534897},{0.389495, 0.142875, 0.588372}}],
    Line[{{0.389495, 0.142875, 0.588372},{0.400880, 0.153316, 0.640103}}],
    Line[{{0.400880, 0.153316, 0.640103},{0.419458, 0.170764, 0.687621}}],
    Line[{{0.419458, 0.170764, 0.687621},{0.446687, 0.197072, 0.725839}}],
    Line[{{0.446687, 0.197072, 0.725839},{0.481634, 0.231681, 0.747341}}],
    Line[{{0.481634, 0.231681, 0.747341},{0.479460, 0.270487, 0.746664}}],
    Line[{{0.479460, 0.270487, 0.746664},{0.444863, 0.304711, 0.724003}}],
    Line[{{0.444863, 0.304711, 0.724003},{0.418148, 0.330481, 0.685050}}],
    Line[{{0.418148, 0.330481, 0.685050},{0.400034, 0.347467, 0.637178}}],
    Line[{{0.400034, 0.347467, 0.637178},{0.389017, 0.357558, 0.585296}}],
    Line[{{0.389017, 0.357558, 0.585296},{0.383666, 0.362385, 0.531763}}],
    Line[{{0.383666, 0.362385, 0.531763},{0.383244, 0.362763, 0.477743}}],
    Line[{{0.383244, 0.362763, 0.477743},{0.387693, 0.358756, 0.424058}}],
    Line[{{0.387693, 0.358756, 0.424058},{0.397626, 0.349688, 0.371764}}],
    Line[{{0.397626, 0.349688, 0.371764},{0.414363, 0.334067, 0.322920}}],
    Line[{{0.414363, 0.334067, 0.322920},{0.439508, 0.309933, 0.281896}}],
    Line[{{0.439508, 0.309933, 0.281896},{0.472951, 0.276977, 0.255839}}],
    Line[{{0.472951, 0.276977, 0.255839},{0.488207, 0.238269, 0.251076}}],
    Line[{{0.608794, 0.500000, 0.598475},{0.595753, 0.500000, 0.650887}}],
    Line[{{0.595753, 0.500000, 0.650887},{0.573518, 0.500000, 0.700023}}],
    Line[{{0.573518, 0.500000, 0.700023},{0.536747, 0.500000, 0.738990}}],
    Line[{{0.536747, 0.500000, 0.738990},{0.484950, 0.500000, 0.748205}}],
    Line[{{0.484950, 0.500000, 0.748205},{0.440419, 0.500000, 0.719127}}],
    Line[{{0.440419, 0.500000, 0.719127},{0.412602, 0.500000, 0.673033}}],
    Line[{{0.412602, 0.500000, 0.673033},{0.396018, 0.500000, 0.621657}}],
    Line[{{0.396018, 0.500000, 0.621657},{0.386767, 0.500000, 0.568432}}],
    Line[{{0.386767, 0.500000, 0.568432},{0.383022, 0.500000, 0.514527}}],
    Line[{{0.383022, 0.500000, 0.514527},{0.384132, 0.500000, 0.460502}}],
    Line[{{0.384132, 0.500000, 0.460502},{0.390284, 0.500000, 0.406822}}],
    Line[{{0.390284, 0.500000, 0.406822},{0.402600, 0.500000, 0.354232}}],
    Line[{{0.402600, 0.500000, 0.354232},{0.423723, 0.500000, 0.304594}}],
    Line[{{0.423723, 0.500000, 0.304594},{0.458773, 0.500000, 0.263986}}],
    Line[{{0.458773, 0.500000, 0.263986},{0.509771, 0.500000, 0.250753}}],
    Line[{{0.509771, 0.500000, 0.250753},{0.555964, 0.500000, 0.276884}}],
    Line[{{0.555964, 0.500000, 0.276884},{0.585222, 0.500000, 0.322040}}],
    Line[{{0.585222, 0.500000, 0.322040},{0.602705, 0.500000, 0.373110}}],
    Line[{{0.602705, 0.500000, 0.373110},{0.612581, 0.500000, 0.426220}}],
    Line[{{0.612581, 0.500000, 0.426220},{0.616830, 0.500000, 0.480086}}],
    Line[{{0.616830, 0.500000, 0.480086},{0.616199, 0.500000, 0.534118}}],
    Line[{{0.616199, 0.500000, 0.534118},{0.610582, 0.500000, 0.587857}}],
    Line[{{0.610582, 0.500000, 0.587857},{0.598967, 0.500000, 0.640608}}],
    Line[{{0.598967, 0.500000, 0.640608},{0.578907, 0.500000, 0.690697}}],
    Line[{{0.578907, 0.500000, 0.690697},{0.545531, 0.500000, 0.732763}}],
    Line[{{0.545531, 0.500000, 0.732763},{0.495592, 0.500000, 0.749851}}],
    Line[{{0.495592, 0.500000, 0.749851},{0.447845, 0.500000, 0.726943}}],
    Line[{{0.447845, 0.500000, 0.726943},{0.417076, 0.500000, 0.682849}}],
    Line[{{0.417076, 0.500000, 0.682849},{0.398649, 0.500000, 0.632122}}],
    Line[{{0.398649, 0.500000, 0.632122},{0.388130, 0.500000, 0.579138}}],
    Line[{{0.388130, 0.500000, 0.579138},{0.383368, 0.500000, 0.525315}}],
    Line[{{0.383368, 0.500000, 0.525315},{0.383519, 0.500000, 0.471280}}],
    Line[{{0.383519, 0.500000, 0.471280},{0.388609, 0.500000, 0.417487}}],
    Line[{{0.388609, 0.500000, 0.417487},{0.399545, 0.500000, 0.364588}}],
    Line[{{0.399545, 0.500000, 0.364588},{0.418587, 0.500000, 0.314093}}],
    Line[{{0.418587, 0.500000, 0.314093},{0.450345, 0.500000, 0.270733}}],
    Line[{{0.450345, 0.500000, 0.270733},{0.499000, 0.500000, 0.250000}}],
    Line[{{0.499000, 0.500000, 0.250000},{0.548152, 0.500000, 0.269413}}],
    Line[{{0.548152, 0.500000, 0.269413},{0.580502, 0.500000, 0.312312}}],
    Line[{{0.580502, 0.500000, 0.312312},{0.599914, 0.500000, 0.362662}}],
    Line[{{0.599914, 0.500000, 0.362662},{0.611099, 0.500000, 0.415508}}],
    Line[{{0.611099, 0.500000, 0.415508},{0.616383, 0.500000, 0.469282}}],
    Line[{{0.616383, 0.500000, 0.469282},{0.616712, 0.500000, 0.523317}}],
    Line[{{0.616712, 0.500000, 0.523317},{0.612140, 0.500000, 0.577156}}],
    Line[{{0.612140, 0.500000, 0.577156},{0.601862, 0.500000, 0.630189}}],
    Line[{{0.601862, 0.500000, 0.630189},{0.583789, 0.500000, 0.681046}}],
    Line[{{0.583789, 0.500000, 0.681046},{0.553588, 0.500000, 0.725548}}],
    Line[{{0.553588, 0.500000, 0.725548},{0.506401, 0.500000, 0.749681}}],
    Line[{{0.506401, 0.500000, 0.749681},{0.456042, 0.500000, 0.733998}}],
    Line[{{0.456042, 0.500000, 0.733998},{0.422051, 0.500000, 0.692453}}],
    Line[{{0.422051, 0.500000, 0.692453},{0.401604, 0.500000, 0.642525}}],
    Line[{{0.401604, 0.500000, 0.642525},{0.389731, 0.500000, 0.589832}}],
    Line[{{0.389731, 0.500000, 0.589832},{0.383917, 0.500000, 0.536115}}],
    Line[{{0.383917, 0.500000, 0.536115},{0.383108, 0.500000, 0.482085}}],
    Line[{{0.383108, 0.500000, 0.482085},{0.387169, 0.500000, 0.428204}}],
    Line[{{0.387169, 0.500000, 0.428204},{0.396811, 0.500000, 0.375050}}],
    Line[{{0.396811, 0.500000, 0.375050},{0.413956, 0.500000, 0.323864}}],
    Line[{{0.413956, 0.500000, 0.323864},{0.442671, 0.500000, 0.278346}}],
    Line[{{0.442671, 0.500000, 0.278346},{0.488257, 0.500000, 0.251089}}],
    Line[{{0.488257, 0.500000, 0.251089},{0.539583, 0.500000, 0.262844}}],
    Line[{{0.539583, 0.500000, 0.262844},{0.575268, 0.500000, 0.302866}}],
    Line[{{0.575268, 0.500000, 0.302866},{0.596798, 0.500000, 0.352323}}],
    Line[{{0.596798, 0.500000, 0.352323},{0.609381, 0.500000, 0.404847}}],
    Line[{{0.609381, 0.500000, 0.404847},{0.615735, 0.500000, 0.458503}}],
    Line[{{0.615735, 0.500000, 0.458503},{0.617024, 0.500000, 0.512523}}],
    Line[{{0.617024, 0.500000, 0.512523},{0.613465, 0.500000, 0.566440}}],
    Line[{{0.613465, 0.500000, 0.566440},{0.604441, 0.500000, 0.619705}}],
    Line[{{0.604441, 0.500000, 0.619705},{0.588183, 0.500000, 0.671186}}],
    Line[{{0.588183, 0.500000, 0.671186},{0.560885, 0.500000, 0.717602}}],
    Line[{{0.560885, 0.500000, 0.717602},{0.516996, 0.500000, 0.747709}}],
    Line[{{0.516996, 0.500000, 0.747709},{0.464970, 0.500000, 0.740032}}],
    Line[{{0.464970, 0.500000, 0.740032},{0.427547, 0.500000, 0.701723}}],
    Line[{{0.427547, 0.500000, 0.701723},{0.404884, 0.500000, 0.652791}}],
    Line[{{0.404884, 0.500000, 0.652791},{0.391565, 0.500000, 0.600452}}],
    Line[{{0.500291, 0.500000, 0.501494},{0.499879, 0.500000, 0.498377}}],
    Line[{{0.499879, 0.500000, 0.498377},{0.500045, 0.500000, 0.501660}}],
    Line[{{0.500045, 0.500000, 0.501660},{0.499916, 0.500000, 0.498328}}],
    Line[{{0.499916, 0.500000, 0.498328},{0.500226, 0.500000, 0.501619}}],
    Line[{{0.500226, 0.500000, 0.501619},{0.499601, 0.500000, 0.498540}}],
    Line[{{0.499601, 0.500000, 0.498540},{0.500571, 0.500000, 0.501159}}],
    Line[{{0.500571, 0.500000, 0.501159},{0.499298, 0.500000, 0.499258}}],
    Line[{{0.499298, 0.500000, 0.499258},{0.500775, 0.500000, 0.500229}}],
    Line[{{0.500775, 0.500000, 0.500229},{0.499232, 0.500000, 0.500386}}],
    Line[{{0.499232, 0.500000, 0.500386},{0.500627, 0.500000, 0.498920}}],
    Line[{{0.500627, 0.500000, 0.498920},{0.499818, 0.500000, 0.501738}}],
    Line[{{0.499818, 0.500000, 0.501738},{0.499472, 0.500000, 0.498634}}],
    Line[{{0.499472, 0.500000, 0.498634},{0.500794, 0.500000, 0.500400}}],
    Line[{{0.500794, 0.500000, 0.500400},{0.499249, 0.500000, 0.500754}}],
    Line[{{0.499249, 0.500000, 0.500754},{0.500113, 0.500000, 0.498162}}],
    Line[{{0.500113, 0.500000, 0.498162},{0.500744, 0.500000, 0.500873}}],
    Line[{{0.500744, 0.500000, 0.500873},{0.499210, 0.500000, 0.500697}}],
    Line[{{0.499210, 0.500000, 0.500697},{0.499829, 0.500000, 0.498121}}],
    Line[{{0.499829, 0.500000, 0.498121},{0.500859, 0.500000, 0.500266}}],
    Line[{{0.500859, 0.500000, 0.500266},{0.499512, 0.500000, 0.501616}}],
    Line[{{0.499512, 0.500000, 0.501616},{0.499218, 0.500000, 0.499105}}],
    Line[{{0.499218, 0.500000, 0.499105},{0.500701, 0.500000, 0.498801}}],
    Line[{{0.500701, 0.500000, 0.498801},{0.500717, 0.500000, 0.501185}}],
    Line[{{0.500717, 0.500000, 0.501185},{0.499261, 0.500000, 0.501147}}],
    Line[{{0.499261, 0.500000, 0.501147},{0.499230, 0.500000, 0.498925}}],
    Line[{{0.499230, 0.500000, 0.498925},{0.500615, 0.500000, 0.498486}}],
    Line[{{0.500615, 0.500000, 0.498486},{0.500895, 0.500000, 0.500515}}],
    Line[{{0.500895, 0.500000, 0.500515},{0.499939, 0.500000, 0.502077}}],
    Line[{{0.499939, 0.500000, 0.502077},{0.499086, 0.500000, 0.500507}}],
    Line[{{0.499086, 0.500000, 0.500507},{0.499246, 0.500000, 0.498711}}],
    Line[{{0.499246, 0.500000, 0.498711},{0.500452, 0.500000, 0.498119}}],
    Line[{{0.500452, 0.500000, 0.498119},{0.500954, 0.500000, 0.499740}}],
    Line[{{0.500954, 0.500000, 0.499740},{0.500754, 0.500000, 0.501348}}],
    Line[{{0.500754, 0.500000, 0.501348},{0.499660, 0.500000, 0.502036}}],
    Line[{{0.499660, 0.500000, 0.502036},{0.499074, 0.500000, 0.500733}}],
    Line[{{0.499074, 0.500000, 0.500733},{0.499052, 0.500000, 0.499359}}],
    Line[{{0.499052, 0.500000, 0.499359},{0.499452, 0.500000, 0.498141}}],
    Line[{{0.499452, 0.500000, 0.498141},{0.500517, 0.500000, 0.498118}}],
    Line[{{0.500517, 0.500000, 0.498118},{0.500948, 0.500000, 0.499451}}],
    Line[{{0.500948, 0.500000, 0.499451},{0.500877, 0.500000, 0.500935}}],
    Line[{{0.500877, 0.500000, 0.500935},{0.500031, 0.500000, 0.502148}}],
    Line[{{0.500031, 0.500000, 0.502148},{0.499129, 0.500000, 0.500879}}],
    Line[{{0.499129, 0.500000, 0.500879},{0.499132, 0.500000, 0.499148}}],
    Line[{{0.499132, 0.500000, 0.499148},{0.500190, 0.500000, 0.497943}}],
    Line[{{0.500190, 0.500000, 0.497943},{0.500918, 0.500000, 0.499648}}],
    Line[{{0.500918, 0.500000, 0.499648},{0.500585, 0.500000, 0.501593}}],
    Line[{{0.500585, 0.500000, 0.501593},{0.499227, 0.500000, 0.501092}}],
    Line[{{0.499227, 0.500000, 0.501092},{0.499229, 0.500000, 0.498938}}],
    Line[{{0.499229, 0.500000, 0.498938},{0.500653, 0.500000, 0.498622}}],
    Line[{{0.500653, 0.500000, 0.498622},{0.500786, 0.500000, 0.500945}}],
    Line[{{0.500786, 0.500000, 0.500945},{0.499322, 0.500000, 0.501288}}],
    Line[{{0.499322, 0.500000, 0.501288},{0.499275, 0.500000, 0.498869}}],
    Line[{{0.499275, 0.500000, 0.498869},{0.500766, 0.500000, 0.499037}}],
    Line[{{0.500766, 0.500000, 0.499037},{0.500536, 0.500000, 0.501539}}],
    Line[{{0.500536, 0.500000, 0.501539},{0.499147, 0.500000, 0.500357}}],
    Line[{{0.499147, 0.500000, 0.500357},{0.500078, 0.500000, 0.498086}}],
    Line[{{0.500078, 0.500000, 0.498086},{0.500811, 0.500000, 0.500580}}],
    Line[{{0.500811, 0.500000, 0.500580},{0.499289, 0.500000, 0.501009}}],
    Line[{{0.499289, 0.500000, 0.501009},{0.499746, 0.500000, 0.498230}}],
    Line[{{0.499746, 0.500000, 0.498230},{0.500783, 0.500000, 0.500579}}],
    Line[{{0.500783, 0.500000, 0.500579},{0.499230, 0.500000, 0.500598}}],
    Line[{{0.499230, 0.500000, 0.500598},{0.500410, 0.500000, 0.498444}}],
    Line[{{0.500410, 0.500000, 0.498444},{0.500365, 0.500000, 0.501589}}],
    Line[{{0.500365, 0.500000, 0.501589},{0.499298, 0.500000, 0.499170}}],
    Line[{{0.499298, 0.500000, 0.499170},{0.500787, 0.500000, 0.500106}}],
    Line[{{0.500787, 0.500000, 0.500106},{0.499253, 0.500000, 0.500529}}],
    Line[{{0.499253, 0.500000, 0.500529},{0.500620, 0.500000, 0.498949}}],
    Line[{{0.500620, 0.500000, 0.498949},{0.499593, 0.500000, 0.501470}}],
    Line[{{0.499593, 0.500000, 0.501470},{0.500101, 0.500000, 0.498299}}],
    Line[{{0.500101, 0.500000, 0.498299},{0.500186, 0.500000, 0.501647}}],
    Line[{{0.500186, 0.500000, 0.501647},{0.499666, 0.500000, 0.498485}}],
    Line[{{0.499666, 0.500000, 0.498485},{0.500393, 0.500000, 0.501418}}],
    Line[{{0.500393, 0.500000, 0.501418},{0.499636, 0.500000, 0.498564}}],
    Line[{{0.499636, 0.500000, 0.498564},{0.500254, 0.500000, 0.501529}}],
    Line[{{0.391565, 0.500000, 0.399562},{0.404881, 0.500000, 0.347221}}],
    Line[{{0.404881, 0.500000, 0.347221},{0.427542, 0.500000, 0.298287}}],
    Line[{{0.427542, 0.500000, 0.298287},{0.464962, 0.500000, 0.259975}}],
    Line[{{0.464962, 0.500000, 0.259975},{0.516987, 0.500000, 0.252291}}],
    Line[{{0.516987, 0.500000, 0.252291},{0.560879, 0.500000, 0.282393}}],
    Line[{{0.560879, 0.500000, 0.282393},{0.588179, 0.500000, 0.328808}}],
    Line[{{0.588179, 0.500000, 0.328808},{0.604439, 0.500000, 0.380290}}],
    Line[{{0.604439, 0.500000, 0.380290},{0.613464, 0.500000, 0.433553}}],
    Line[{{0.613464, 0.500000, 0.433553},{0.617023, 0.500000, 0.487470}}],
    Line[{{0.617023, 0.500000, 0.487470},{0.615735, 0.500000, 0.541490}}],
    Line[{{0.615735, 0.500000, 0.541490},{0.609382, 0.500000, 0.595146}}],
    Line[{{0.609382, 0.500000, 0.595146},{0.596799, 0.500000, 0.647671}}],
    Line[{{0.596799, 0.500000, 0.647671},{0.575270, 0.500000, 0.697128}}],
    Line[{{0.575270, 0.500000, 0.697128},{0.539587, 0.500000, 0.737152}}],
    Line[{{0.539587, 0.500000, 0.737152},{0.488261, 0.500000, 0.748911}}],
    Line[{{0.488261, 0.500000, 0.748911},{0.442674, 0.500000, 0.721656}}],
    Line[{{0.442674, 0.500000, 0.721656},{0.413958, 0.500000, 0.676139}}],
    Line[{{0.413958, 0.500000, 0.676139},{0.396812, 0.500000, 0.624953}}],
    Line[{{0.396812, 0.500000, 0.624953},{0.387170, 0.500000, 0.571799}}],
    Line[{{0.387170, 0.500000, 0.571799},{0.383109, 0.500000, 0.517918}}],
    Line[{{0.383109, 0.500000, 0.517918},{0.383917, 0.500000, 0.463889}}],
    Line[{{0.383917, 0.500000, 0.463889},{0.389731, 0.500000, 0.410171}}],
    Line[{{0.389731, 0.500000, 0.410171},{0.401603, 0.500000, 0.357478}}],
    Line[{{0.401603, 0.500000, 0.357478},{0.422050, 0.500000, 0.307550}}],
    Line[{{0.422050, 0.500000, 0.307550},{0.456041, 0.500000, 0.266004}}],
    Line[{{0.456041, 0.500000, 0.266004},{0.506399, 0.500000, 0.250320}}],
    Line[{{0.506399, 0.500000, 0.250320},{0.553586, 0.500000, 0.274451}}],
    Line[{{0.553586, 0.500000, 0.274451},{0.583788, 0.500000, 0.318954}}],
    Line[{{0.583788, 0.500000, 0.318954},{0.601861, 0.500000, 0.369811}}],
    Line[{{0.601861, 0.500000, 0.369811},{0.612140, 0.500000, 0.422844}}],
    Line[{{0.612140, 0.500000, 0.422844},{0.616711, 0.500000, 0.476683}}],
    Line[{{0.616711, 0.500000, 0.476683},{0.616383, 0.500000, 0.530718}}],
    Line[{{0.616383, 0.500000, 0.530718},{0.611099, 0.500000, 0.584491}}],
    Line[{{0.611099, 0.500000, 0.584491},{0.599914, 0.500000, 0.637337}}],
    Line[{{0.599914, 0.500000, 0.637337},{0.580502, 0.500000, 0.687687}}],
    Line[{{0.580502, 0.500000, 0.687687},{0.548152, 0.500000, 0.730586}}],
    Line[{{0.548152, 0.500000, 0.730586},{0.499000, 0.500000, 0.750000}}],
    Line[{{0.499000, 0.500000, 0.750000},{0.450345, 0.500000, 0.729266}}],
    Line[{{0.450345, 0.500000, 0.729266},{0.418587, 0.500000, 0.685907}}],
    Line[{{0.418587, 0.500000, 0.685907},{0.399545, 0.500000, 0.635412}}],
    Line[{{0.399545, 0.500000, 0.635412},{0.388609, 0.500000, 0.582512}}],
    Line[{{0.388609, 0.500000, 0.582512},{0.383519, 0.500000, 0.528720}}],
    Line[{{0.383519, 0.500000, 0.528720},{0.383368, 0.500000, 0.474684}}],
    Line[{{0.383368, 0.500000, 0.474684},{0.388131, 0.500000, 0.420862}}],
    Line[{{0.388131, 0.500000, 0.420862},{0.398650, 0.500000, 0.367878}}],
    Line[{{0.398650, 0.500000, 0.367878},{0.417077, 0.500000, 0.317150}}],
    Line[{{0.417077, 0.500000, 0.317150},{0.447847, 0.500000, 0.273054}}],
    Line[{{0.447847, 0.500000, 0.273054},{0.495594, 0.500000, 0.250149}}],
    Line[{{0.495594, 0.500000, 0.250149},{0.545532, 0.500000, 0.267237}}],
    Line[{{0.545532, 0.500000, 0.267237},{0.578908, 0.500000, 0.309303}}],
    Line[{{0.578908, 0.500000, 0.309303},{0.598967, 0.500000, 0.359392}}],
    Line[{{0.598967, 0.500000, 0.359392},{0.610582, 0.500000, 0.412144}}],
    Line[{{0.610582, 0.500000, 0.412144},{0.616199, 0.500000, 0.465883}}],
    Line[{{0.616199, 0.500000, 0.465883},{0.616830, 0.500000, 0.519915}}],
    Line[{{0.616830, 0.500000, 0.519915},{0.612581, 0.500000, 0.573781}}],
    Line[{{0.612581, 0.500000, 0.573781},{0.602706, 0.500000, 0.626891}}],
    Line[{{0.602706, 0.500000, 0.626891},{0.585222, 0.500000, 0.677961}}],
    Line[{{0.585222, 0.500000, 0.677961},{0.555964, 0.500000, 0.723116}}],
    Line[{{0.555964, 0.500000, 0.723116},{0.509772, 0.500000, 0.749248}}],
    Line[{{0.509772, 0.500000, 0.749248},{0.458774, 0.500000, 0.736016}}],
    Line[{{0.458774, 0.500000, 0.736016},{0.423723, 0.500000, 0.695407}}],
    Line[{{0.423723, 0.500000, 0.695407},{0.402600, 0.500000, 0.645770}}],
    Line[{{0.402600, 0.500000, 0.645770},{0.390283, 0.500000, 0.593181}}],
    Line[{{0.390283, 0.500000, 0.593181},{0.384131, 0.500000, 0.539502}}],
    Line[{{0.384131, 0.500000, 0.539502},{0.383020, 0.500000, 0.485477}}],
    Line[{{0.383020, 0.500000, 0.485477},{0.386764, 0.500000, 0.431573}}],
    Line[{{0.386764, 0.500000, 0.431573},{0.396015, 0.500000, 0.378349}}],
    Line[{{0.396015, 0.500000, 0.378349},{0.412598, 0.500000, 0.326973}}],
    Line[{{0.412598, 0.500000, 0.326973},{0.440414, 0.500000, 0.280878}}],
    Line[{{0.440414, 0.500000, 0.280878},{0.484942, 0.500000, 0.251796}}],
    Line[{{0.484942, 0.500000, 0.251796},{0.536741, 0.500000, 0.261003}}],
    Line[{{0.536741, 0.500000, 0.261003},{0.573514, 0.500000, 0.299971}}],
    Line[{{0.573514, 0.500000, 0.299971},{0.595750, 0.500000, 0.349104}}],
    Line[{{0.595750, 0.500000, 0.349104},{0.608793, 0.500000, 0.401515}}],
    Line[{{0.488127, 0.761808, 0.748908},{0.473030, 0.723103, 0.744195}}],
    Line[{{0.473030, 0.723103, 0.744195},{0.439571, 0.690129, 0.718177}}],
    Line[{{0.439571, 0.690129, 0.718177},{0.414407, 0.665975, 0.677176}}],
    Line[{{0.414407, 0.665975, 0.677176},{0.397654, 0.650338, 0.628343}}],
    Line[{{0.397654, 0.650338, 0.628343},{0.387708, 0.641257, 0.576054}}],
    Line[{{0.387708, 0.641257, 0.576054},{0.383249, 0.637241, 0.522370}}],
    Line[{{0.383249, 0.637241, 0.522370},{0.383661, 0.637610, 0.468351}}],
    Line[{{0.383661, 0.637610, 0.468351},{0.389000, 0.642427, 0.414816}}],
    Line[{{0.389000, 0.642427, 0.414816},{0.400005, 0.652507, 0.362927}}],
    Line[{{0.400005, 0.652507, 0.362927},{0.418103, 0.669477, 0.315043}}],
    Line[{{0.418103, 0.669477, 0.315043},{0.444799, 0.695227, 0.276065}}],
    Line[{{0.444799, 0.695227, 0.276065},{0.479383, 0.729436, 0.253362}}],
    Line[{{0.479383, 0.729436, 0.253362},{0.481663, 0.768288, 0.252650}}],
    Line[{{0.481663, 0.768288, 0.252650},{0.446712, 0.802902, 0.274136}}],
    Line[{{0.446712, 0.802902, 0.274136},{0.419476, 0.829219, 0.312343}}],
    Line[{{0.419476, 0.829219, 0.312343},{0.400891, 0.846673, 0.359857}}],
    Line[{{0.400891, 0.846673, 0.359857},{0.389501, 0.857118, 0.411585}}],
    Line[{{0.389501, 0.857118, 0.411585},{0.383844, 0.862226, 0.465059}}],
    Line[{{0.383844, 0.862226, 0.465059},{0.383139, 0.862858, 0.519073}}],
    Line[{{0.383139, 0.862858, 0.519073},{0.387291, 0.859121, 0.572802}}],
    Line[{{0.387291, 0.859121, 0.572802},{0.396872, 0.850383, 0.625222}}],
    Line[{{0.396872, 0.850383, 0.625222},{0.413163, 0.835201, 0.674360}}],
    Line[{{0.413163, 0.835201, 0.674360},{0.437786, 0.811607, 0.716022}}],
    Line[{{0.437786, 0.811607, 0.716022},{0.470814, 0.779104, 0.743166}}],
    Line[{{0.470814, 0.779104, 0.743166},{0.490523, 0.740582, 0.749303}}],
    Line[{{0.490523, 0.740582, 0.749303},{0.454348, 0.704594, 0.732676}}],
    Line[{{0.454348, 0.704594, 0.732676},{0.425067, 0.676119, 0.697715}}],
    Line[{{0.425067, 0.676119, 0.697715},{0.404545, 0.656719, 0.651808}}],
    Line[{{0.404545, 0.656719, 0.651808},{0.391618, 0.644806, 0.600773}}],
    Line[{{0.391618, 0.644806, 0.600773},{0.384712, 0.638554, 0.547571}}],
    Line[{{0.384712, 0.638554, 0.547571},{0.382878, 0.636908, 0.493606}}],
    Line[{{0.382878, 0.636908, 0.493606},{0.385864, 0.639591, 0.439736}}],
    Line[{{0.385864, 0.639591, 0.439736},{0.394082, 0.647056, 0.386884}}],
    Line[{{0.394082, 0.647056, 0.386884},{0.408649, 0.660553, 0.336706}}],
    Line[{{0.408649, 0.660553, 0.336706},{0.431203, 0.682018, 0.292745}}],
    Line[{{0.431203, 0.682018, 0.292745},{0.462445, 0.712590, 0.261500}}],
    Line[{{0.462445, 0.712590, 0.261500},{0.499000, 0.750000, 0.250000}}],
    Line[{{0.499000, 0.750000, 0.250000},{0.462445, 0.787410, 0.261500}}],
    Line[{{0.462445, 0.787410, 0.261500},{0.431203, 0.817982, 0.292745}}],
    Line[{{0.431203, 0.817982, 0.292745},{0.408649, 0.839447, 0.336706}}],
    Line[{{0.408649, 0.839447, 0.336706},{0.394082, 0.852944, 0.386884}}],
    Line[{{0.394082, 0.852944, 0.386884},{0.385864, 0.860409, 0.439736}}],
    Line[{{0.385864, 0.860409, 0.439736},{0.382878, 0.863092, 0.493606}}],
    Line[{{0.382878, 0.863092, 0.493606},{0.384712, 0.861446, 0.547571}}],
    Line[{{0.384712, 0.861446, 0.547571},{0.391618, 0.855194, 0.600773}}],
    Line[{{0.391618, 0.855194, 0.600773},{0.404545, 0.843281, 0.651808}}],
    Line[{{0.404545, 0.843281, 0.651808},{0.425067, 0.823882, 0.697715}}],
    Line[{{0.425067, 0.823882, 0.697715},{0.454348, 0.795406, 0.732676}}],
    Line[{{0.454348, 0.795406, 0.732676},{0.490523, 0.759418, 0.749302}}],
    Line[{{0.490523, 0.759418, 0.749302},{0.470833, 0.720913, 0.743175}}],
    Line[{{0.470833, 0.720913, 0.743175},{0.437801, 0.688406, 0.716042}}],
    Line[{{0.437801, 0.688406, 0.716042},{0.413173, 0.664809, 0.674385}}],
    Line[{{0.413173, 0.664809, 0.674385},{0.396879, 0.649623, 0.625249}}],
    Line[{{0.396879, 0.649623, 0.625249},{0.387295, 0.640883, 0.572831}}],
    Line[{{0.387295, 0.640883, 0.572831},{0.383141, 0.637144, 0.519102}}],
    Line[{{0.383141, 0.637144, 0.519102},{0.383843, 0.637774, 0.465088}}],
    Line[{{0.383843, 0.637774, 0.465088},{0.389497, 0.642878, 0.411613}}],
    Line[{{0.389497, 0.642878, 0.411613},{0.400884, 0.653320, 0.359883}}],
    Line[{{0.400884, 0.653320, 0.359883},{0.419466, 0.670772, 0.312366}}],
    Line[{{0.419466, 0.670772, 0.312366},{0.446697, 0.697083, 0.274153}}],
    Line[{{0.446697, 0.697083, 0.274153},{0.481646, 0.731693, 0.252656}}],
    Line[{{0.481646, 0.731693, 0.252656},{0.479403, 0.770544, 0.253357}}],
    Line[{{0.479403, 0.770544, 0.253357},{0.444816, 0.804757, 0.276049}}],
    Line[{{0.444816, 0.804757, 0.276049},{0.418115, 0.830512, 0.315021}}],
    Line[{{0.418115, 0.830512, 0.315021},{0.400014, 0.847485, 0.362902}}],
    Line[{{0.400014, 0.847485, 0.362902},{0.389007, 0.857567, 0.414789}}],
    Line[{{0.389007, 0.857567, 0.414789},{0.383664, 0.862386, 0.468323}}],
    Line[{{0.383664, 0.862386, 0.468323},{0.383250, 0.862758, 0.522342}}],
    Line[{{0.383250, 0.862758, 0.522342},{0.387707, 0.858744, 0.576025}}],
    Line[{{0.387707, 0.858744, 0.576025},{0.397650, 0.849666, 0.628317}}],
    Line[{{0.397650, 0.849666, 0.628317},{0.414400, 0.834032, 0.677153}}],
    Line[{{0.414400, 0.834032, 0.677153},{0.439560, 0.809883, 0.718159}}],
    Line[{{0.439560, 0.809883, 0.718159},{0.473015, 0.776913, 0.744184}}],
    Line[{{0.473015, 0.776913, 0.744184},{0.488101, 0.738168, 0.748899}}],
    Line[{{0.499000, 0.750002, 0.499997},{0.499000, 0.749998, 0.499998}}],
    Line[{{0.499000, 0.749998, 0.499998},{0.499000, 0.750000, 0.500005}}],
    Line[{{0.499000, 0.750000, 0.500005},{0.499000, 0.750002, 0.500000}}],
    Line[{{0.499000, 0.750002, 0.500000},{0.499000, 0.749999, 0.499995}}],
    Line[{{0.499000, 0.749999, 0.499995},{0.499000, 0.749998, 0.500003}}],
    Line[{{0.499000, 0.749998, 0.500003},{0.499000, 0.750002, 0.500002}}],
    Line[{{0.499000, 0.750002, 0.500002},{0.499000, 0.750001, 0.499995}}],
    Line[{{0.499000, 0.750001, 0.499995},{0.499000, 0.749998, 0.500000}}],
    Line[{{0.499000, 0.749998, 0.500000},{0.499000, 0.750000, 0.500005}}],
    Line[{{0.499000, 0.750000, 0.500005},{0.499000, 0.750002, 0.499998}}],
    Line[{{0.499000, 0.750002, 0.499998},{0.499000, 0.749998, 0.499997}}],
    Line[{{0.499000, 0.749998, 0.499997},{0.499000, 0.749999, 0.500005}}],
    Line[{{0.499000, 0.749999, 0.500005},{0.499000, 0.750002, 0.500000}}],
    Line[{{0.499000, 0.750002, 0.500000},{0.499000, 0.750000, 0.499995}}],
    Line[{{0.499000, 0.750000, 0.499995},{0.499000, 0.749998, 0.500002}}],
    Line[{{0.499000, 0.749998, 0.500002},{0.499000, 0.750001, 0.500003}}],
    Line[{{0.499000, 0.750001, 0.500003},{0.499000, 0.750001, 0.499996}}],
    Line[{{0.499000, 0.750001, 0.499996},{0.499000, 0.749998, 0.499999}}],
    Line[{{0.499000, 0.749998, 0.499999},{0.499000, 0.750000, 0.500005}}],
    Line[{{0.499000, 0.750000, 0.500005},{0.499000, 0.750002, 0.499998}}],
    Line[{{0.499000, 0.750002, 0.499998},{0.499000, 0.749999, 0.499996}}],
    Line[{{0.499000, 0.749999, 0.499996},{0.499000, 0.749999, 0.500004}}],
    Line[{{0.499000, 0.749999, 0.500004},{0.499000, 0.750002, 0.500001}}],
    Line[{{0.499000, 0.750002, 0.500001},{0.499000, 0.750000, 0.499995}}],
    Line[{{0.499000, 0.750000, 0.499995},{0.499000, 0.749998, 0.500001}}],
    Line[{{0.499000, 0.749998, 0.500001},{0.499000, 0.750001, 0.500004}}],
    Line[{{0.499000, 0.750001, 0.500004},{0.499000, 0.750001, 0.499996}}],
    Line[{{0.499000, 0.750001, 0.499996},{0.499000, 0.749998, 0.499998}}],
    Line[{{0.499000, 0.749998, 0.499998},{0.499000, 0.750000, 0.500005}}],
    Line[{{0.499000, 0.750000, 0.500005},{0.499000, 0.750002, 0.499999}}],
    Line[{{0.499000, 0.750002, 0.499999},{0.499000, 0.749999, 0.499996}}],
    Line[{{0.499000, 0.749999, 0.499996},{0.499000, 0.749998, 0.500003}}],
    Line[{{0.499000, 0.749998, 0.500003},{0.499000, 0.750002, 0.500002}}],
    Line[{{0.499000, 0.750002, 0.500002},{0.499000, 0.750000, 0.499995}}],
    Line[{{0.499000, 0.750000, 0.499995},{0.499000, 0.749998, 0.500000}}],
    Line[{{0.499000, 0.749998, 0.500000},{0.499000, 0.750001, 0.500005}}],
    Line[{{0.499000, 0.750001, 0.500005},{0.499000, 0.750002, 0.499997}}],
    Line[{{0.499000, 0.750002, 0.499997},{0.499000, 0.749999, 0.499999}}],
    Line[{{0.499000, 0.749999, 0.499999},{0.499000, 0.750002, 0.499998}}],
    Line[{{0.499000, 0.750002, 0.499998},{0.499000, 0.750002, 0.499998}}],
    Line[{{0.499000, 0.750002, 0.499998},{0.499000, 0.750002, 0.499997}}],
    Line[{{0.499000, 0.750002, 0.499997},{0.499000, 0.750001, 0.499997}}],
    Line[{{0.499000, 0.750001, 0.499997},{0.499000, 0.750001, 0.499996}}],
    Line[{{0.499000, 0.750001, 0.499996},{0.499000, 0.750001, 0.499995}}],
    Line[{{0.499000, 0.750001, 0.499995},{0.499000, 0.750001, 0.499995}}],
    Line[{{0.499000, 0.750001, 0.499995},{0.499000, 0.750000, 0.499995}}],
    Line[{{0.499000, 0.750000, 0.499995},{0.499000, 0.750000, 0.499995}}],
    Line[{{0.499000, 0.750000, 0.499995},{0.499000, 0.750000, 0.499995}}],
    Line[{{0.499000, 0.750000, 0.499995},{0.499000, 0.749999, 0.499995}}],
    Line[{{0.499000, 0.749999, 0.499995},{0.499000, 0.749999, 0.499995}}],
    Line[{{0.499000, 0.749999, 0.499995},{0.499000, 0.749999, 0.499995}}],
    Line[{{0.499000, 0.749999, 0.499995},{0.499000, 0.749999, 0.499996}}],
    Line[{{0.499000, 0.749999, 0.499996},{0.499000, 0.749998, 0.499997}}],
    Line[{{0.499000, 0.749998, 0.499997},{0.499000, 0.749998, 0.499997}}],
    Line[{{0.499000, 0.749998, 0.499997},{0.499000, 0.749998, 0.499998}}],
    Line[{{0.499000, 0.749998, 0.499998},{0.499000, 0.749998, 0.499999}}],
    Line[{{0.499000, 0.749998, 0.499999},{0.499000, 0.749998, 0.499999}}],
    Line[{{0.499000, 0.749998, 0.499999},{0.499000, 0.749998, 0.500000}}],
    Line[{{0.499000, 0.749998, 0.500000},{0.499000, 0.749998, 0.500000}}],
    Line[{{0.499000, 0.749998, 0.500000},{0.499000, 0.749998, 0.500001}}],
    Line[{{0.499000, 0.749998, 0.500001},{0.499000, 0.749998, 0.500002}}],
    Line[{{0.499000, 0.749998, 0.500002},{0.499000, 0.749998, 0.500003}}],
    Line[{{0.499000, 0.749998, 0.500003},{0.499000, 0.749999, 0.500003}}],
    Line[{{0.499000, 0.749999, 0.500003},{0.499000, 0.749999, 0.500004}}],
    Line[{{0.499000, 0.749999, 0.500004},{0.499000, 0.749999, 0.500004}}],
    Line[{{0.499000, 0.749999, 0.500004},{0.499000, 0.749999, 0.500005}}],
    Line[{{0.499000, 0.749999, 0.500005},{0.499000, 0.750000, 0.500005}}],
    Line[{{0.499000, 0.750000, 0.500005},{0.499000, 0.750000, 0.500005}}],
    Line[{{0.499000, 0.750000, 0.500005},{0.499000, 0.750000, 0.500005}}],
    Line[{{0.499000, 0.750000, 0.500005},{0.499000, 0.750001, 0.500005}}],
    Line[{{0.499000, 0.750001, 0.500005},{0.499000, 0.750001, 0.500005}}],
    Line[{{0.499000, 0.750001, 0.500005},{0.499000, 0.750001, 0.500005}}],
    Line[{{0.499000, 0.750001, 0.500005},{0.499000, 0.750001, 0.500004}}],
    Line[{{0.499000, 0.750001, 0.500004},{0.499000, 0.750002, 0.500003}}],
    Line[{{0.488170, 0.738235, 0.251086},{0.472957, 0.776971, 0.255839}}],
    Line[{{0.472957, 0.776971, 0.255839},{0.439513, 0.809929, 0.281893}}],
    Line[{{0.439513, 0.809929, 0.281893},{0.414366, 0.834064, 0.322917}}],
    Line[{{0.414366, 0.834064, 0.322917},{0.397629, 0.849686, 0.371759}}],
    Line[{{0.397629, 0.849686, 0.371759},{0.387695, 0.858755, 0.424054}}],
    Line[{{0.387695, 0.858755, 0.424054},{0.383246, 0.862762, 0.477739}}],
    Line[{{0.383246, 0.862762, 0.477739},{0.383667, 0.862384, 0.531759}}],
    Line[{{0.383667, 0.862384, 0.531759},{0.389017, 0.857557, 0.585291}}],
    Line[{{0.389017, 0.857557, 0.585291},{0.400034, 0.847467, 0.637174}}],
    Line[{{0.400034, 0.847467, 0.637174},{0.418147, 0.830482, 0.685046}}],
    Line[{{0.418147, 0.830482, 0.685046},{0.444860, 0.804714, 0.724001}}],
    Line[{{0.444860, 0.804714, 0.724001},{0.479458, 0.770491, 0.746663}}],
    Line[{{0.479458, 0.770491, 0.746663},{0.481634, 0.731681, 0.747341}}],
    Line[{{0.481634, 0.731681, 0.747341},{0.446686, 0.697071, 0.725839}}],
    Line[{{0.446686, 0.697071, 0.725839},{0.419457, 0.670762, 0.687620}}],
    Line[{{0.419457, 0.670762, 0.687620},{0.400879, 0.653315, 0.640101}}],
    Line[{{0.400879, 0.653315, 0.640101},{0.389494, 0.642875, 0.588371}}],
    Line[{{0.389494, 0.642875, 0.588371},{0.383841, 0.637772, 0.534896}}],
    Line[{{0.383841, 0.637772, 0.534896},{0.383141, 0.637143, 0.480882}}],
    Line[{{0.383141, 0.637143, 0.480882},{0.387296, 0.640884, 0.427153}}],
    Line[{{0.387296, 0.640884, 0.427153},{0.396882, 0.649626, 0.374735}}],
    Line[{{0.396882, 0.649626, 0.374735},{0.413180, 0.664815, 0.325601}}],
    Line[{{0.413180, 0.664815, 0.325601},{0.437811, 0.688416, 0.283948}}],
    Line[{{0.437811, 0.688416, 0.283948},{0.470845, 0.720925, 0.256819}}],
    Line[{{0.470845, 0.720925, 0.256819},{0.490522, 0.759421, 0.250698}}],
    Line[{{0.490522, 0.759421, 0.250698},{0.454348, 0.795406, 0.267325}}],
    Line[{{0.454348, 0.795406, 0.267325},{0.425067, 0.823881, 0.302285}}],
    Line[{{0.425067, 0.823881, 0.302285},{0.404545, 0.843281, 0.348193}}],
    Line[{{0.404545, 0.843281, 0.348193},{0.391618, 0.855194, 0.399227}}],
    Line[{{0.391618, 0.855194, 0.399227},{0.384712, 0.861446, 0.452429}}],
    Line[{{0.384712, 0.861446, 0.452429},{0.382878, 0.863092, 0.506394}}],
    Line[{{0.382878, 0.863092, 0.506394},{0.385864, 0.860409, 0.560264}}],
    Line[{{0.385864, 0.860409, 0.560264},{0.394082, 0.852944, 0.613116}}],
    Line[{{0.394082, 0.852944, 0.613116},{0.408649, 0.839447, 0.663294}}],
    Line[{{0.408649, 0.839447, 0.663294},{0.431203, 0.817982, 0.707255}}],
    Line[{{0.431203, 0.817982, 0.707255},{0.462445, 0.787410, 0.738500}}],
    Line[{{0.462445, 0.787410, 0.738500},{0.499000, 0.750000, 0.750000}}],
    Line[{{0.499000, 0.750000, 0.750000},{0.462445, 0.712590, 0.738500}}],
    Line[{{0.462445, 0.712590, 0.738500},{0.431203, 0.682018, 0.707255}}],
    Line[{{0.431203, 0.682018, 0.707255},{0.408649, 0.660553, 0.663294}}],
    Line[{{0.408649, 0.660553, 0.663294},{0.394082, 0.647056, 0.613116}}],
    Line[{{0.394082, 0.647056, 0.613116},{0.385864, 0.639591, 0.560264}}],
    Line[{{0.385864, 0.639591, 0.560264},{0.382878, 0.636908, 0.506394}}],
    Line[{{0.382878, 0.636908, 0.506394},{0.384712, 0.638554, 0.452429}}],
    Line[{{0.384712, 0.638554, 0.452429},{0.391618, 0.644806, 0.399227}}],
    Line[{{0.391618, 0.644806, 0.399227},{0.404545, 0.656719, 0.348193}}],
    Line[{{0.404545, 0.656719, 0.348193},{0.425067, 0.676119, 0.302285}}],
    Line[{{0.425067, 0.676119, 0.302285},{0.454348, 0.704594, 0.267325}}],
    Line[{{0.454348, 0.704594, 0.267325},{0.490519, 0.740583, 0.250698}}],
    Line[{{0.490519, 0.740583, 0.250698},{0.470824, 0.779095, 0.256830}}],
    Line[{{0.470824, 0.779095, 0.256830},{0.437795, 0.811600, 0.283969}}],
    Line[{{0.437795, 0.811600, 0.283969},{0.413168, 0.835195, 0.325628}}],
    Line[{{0.413168, 0.835195, 0.325628},{0.396875, 0.850380, 0.374765}}],
    Line[{{0.396875, 0.850380, 0.374765},{0.387293, 0.859119, 0.427184}}],
    Line[{{0.387293, 0.859119, 0.427184},{0.383140, 0.862857, 0.480913}}],
    Line[{{0.383140, 0.862857, 0.480913},{0.383843, 0.862226, 0.534927}}],
    Line[{{0.383843, 0.862226, 0.534927},{0.389499, 0.857120, 0.588401}}],
    Line[{{0.389499, 0.857120, 0.588401},{0.400887, 0.846677, 0.640129}}],
    Line[{{0.400887, 0.846677, 0.640129},{0.419470, 0.829224, 0.687645}}],
    Line[{{0.419470, 0.829224, 0.687645},{0.446704, 0.802911, 0.725856}}],
    Line[{{0.446704, 0.802911, 0.725856},{0.481655, 0.768296, 0.747347}}],
    Line[{{0.481655, 0.768296, 0.747347},{0.479421, 0.729474, 0.746650}}],
    Line[{{0.479421, 0.729474, 0.746650},{0.444831, 0.695258, 0.723967}}],
    Line[{{0.444831, 0.695258, 0.723967},{0.418126, 0.669499, 0.685001}}],
    Line[{{0.418126, 0.669499, 0.685001},{0.400020, 0.652520, 0.637124}}],
    Line[{{0.400020, 0.652520, 0.637124},{0.389009, 0.642435, 0.585238}}],
    Line[{{0.389009, 0.642435, 0.585238},{0.383664, 0.637613, 0.531704}}],
    Line[{{0.383664, 0.637613, 0.531704},{0.383247, 0.637240, 0.477684}}],
    Line[{{0.383247, 0.637240, 0.477684},{0.387701, 0.641251, 0.424000}}],
    Line[{{0.387701, 0.641251, 0.424000},{0.397642, 0.650326, 0.371708}}],
    Line[{{0.397642, 0.650326, 0.371708},{0.414387, 0.665956, 0.322870}}],
    Line[{{0.414387, 0.665956, 0.322870},{0.439542, 0.690100, 0.281858}}],
    Line[{{0.439542, 0.690100, 0.281858},{0.472993, 0.723066, 0.255822}}],
    Line[{{0.472993, 0.723066, 0.255822},{0.488143, 0.761792, 0.251090}}],
    Line[{{0.767186, 0.356021, 0.595661},{0.763325, 0.344356, 0.648256}}],
    Line[{{0.763325, 0.344356, 0.648256},{0.757704, 0.323815, 0.697808}}],
    Line[{{0.757704, 0.323815, 0.697808},{0.751367, 0.288606, 0.737700}}],
    Line[{{0.751367, 0.288606, 0.737700},{0.749263, 0.237233, 0.748698}}],
    Line[{{0.749263, 0.237233, 0.748698},{0.754287, 0.192367, 0.720768}}],
    Line[{{0.754287, 0.192367, 0.720768},{0.760578, 0.165014, 0.674853}}],
    Line[{{0.760578, 0.165014, 0.674853},{0.765386, 0.149226, 0.623455}}],
    Line[{{0.765386, 0.149226, 0.623455},{0.768399, 0.140596, 0.570211}}],
    Line[{{0.768399, 0.140596, 0.570211},{0.769710, 0.137075, 0.516307}}],
    Line[{{0.769710, 0.137075, 0.516307},{0.769388, 0.137929, 0.462277}}],
    Line[{{0.769388, 0.137929, 0.462277},{0.767414, 0.143330, 0.408552}}],
    Line[{{0.767414, 0.143330, 0.408552},{0.763695, 0.154452, 0.355826}}],
    Line[{{0.763695, 0.154452, 0.355826},{0.758201, 0.174120, 0.305895}}],
    Line[{{0.758201, 0.174120, 0.305895},{0.751811, 0.207921, 0.264744}}],
    Line[{{0.751811, 0.207921, 0.264744},{0.749119, 0.258556, 0.250585}}],
    Line[{{0.749119, 0.258556, 0.250585},{0.753771, 0.304776, 0.276089}}],
    Line[{{0.753771, 0.304776, 0.276089},{0.760122, 0.333325, 0.321229}}],
    Line[{{0.760122, 0.333325, 0.321229},{0.765070, 0.349826, 0.372383}}],
    Line[{{0.765070, 0.349826, 0.372383},{0.768224, 0.358926, 0.425539}}],
    Line[{{0.768224, 0.358926, 0.425539},{0.769666, 0.362811, 0.479415}}],
    Line[{{0.769666, 0.362811, 0.479415},{0.769472, 0.362298, 0.533450}}],
    Line[{{0.769472, 0.362298, 0.533450},{0.767632, 0.357285, 0.587218}}],
    Line[{{0.767632, 0.357285, 0.587218},{0.764055, 0.346691, 0.640065}}],
    Line[{{0.764055, 0.346691, 0.640065},{0.758693, 0.327862, 0.690343}}],
    Line[{{0.758693, 0.327862, 0.690343},{0.752277, 0.295437, 0.732640}}],
    Line[{{0.752277, 0.295437, 0.732640},{0.749031, 0.245706, 0.749849}}],
    Line[{{0.749031, 0.245706, 0.749849},{0.753262, 0.198209, 0.726946}}],
    Line[{{0.753262, 0.198209, 0.726946},{0.759654, 0.168415, 0.682663}}],
    Line[{{0.759654, 0.168415, 0.682663},{0.764743, 0.151169, 0.631776}}],
    Line[{{0.764743, 0.151169, 0.631776},{0.768037, 0.141585, 0.578716}}],
    Line[{{0.768037, 0.141585, 0.578716},{0.769611, 0.137330, 0.524872}}],
    Line[{{0.769611, 0.137330, 0.524872},{0.769546, 0.137502, 0.470835}}],
    Line[{{0.769546, 0.137502, 0.470835},{0.767839, 0.142133, 0.417027}}],
    Line[{{0.767839, 0.142133, 0.417027},{0.764404, 0.152214, 0.364069}}],
    Line[{{0.764404, 0.152214, 0.364069},{0.759177, 0.170234, 0.313472}}],
    Line[{{0.759177, 0.170234, 0.313472},{0.752761, 0.201323, 0.270132}}],
    Line[{{0.752761, 0.201323, 0.270132},{0.749000, 0.250000, 0.250000}}],
    Line[{{0.749000, 0.250000, 0.250000},{0.752761, 0.298677, 0.270132}}],
    Line[{{0.752761, 0.298677, 0.270132},{0.759177, 0.329765, 0.313472}}],
    Line[{{0.759177, 0.329765, 0.313472},{0.764404, 0.347786, 0.364069}}],
    Line[{{0.764404, 0.347786, 0.364069},{0.767839, 0.357867, 0.417027}}],
    Line[{{0.767839, 0.357867, 0.417027},{0.769546, 0.362498, 0.470835}}],
    Line[{{0.769546, 0.362498, 0.470835},{0.769611, 0.362670, 0.524872}}],
    Line[{{0.769611, 0.362670, 0.524872},{0.768037, 0.358415, 0.578715}}],
    Line[{{0.768037, 0.358415, 0.578715},{0.764743, 0.348831, 0.631776}}],
    Line[{{0.764743, 0.348831, 0.631776},{0.759655, 0.331585, 0.682662}}],
    Line[{{0.759655, 0.331585, 0.682662},{0.753263, 0.301793, 0.726945}}],
    Line[{{0.753263, 0.301793, 0.726945},{0.749031, 0.254295, 0.749850}}],
    Line[{{0.749031, 0.254295, 0.749850},{0.752277, 0.204564, 0.732641}}],
    Line[{{0.752277, 0.204564, 0.732641},{0.758693, 0.172139, 0.690344}}],
    Line[{{0.758693, 0.172139, 0.690344},{0.764055, 0.153310, 0.640066}}],
    Line[{{0.764055, 0.153310, 0.640066},{0.767632, 0.142715, 0.587220}}],
    Line[{{0.767632, 0.142715, 0.587220},{0.769472, 0.137702, 0.533451}}],
    Line[{{0.769472, 0.137702, 0.533451},{0.769666, 0.137189, 0.479417}}],
    Line[{{0.769666, 0.137189, 0.479417},{0.768224, 0.141074, 0.425541}}],
    Line[{{0.768224, 0.141074, 0.425541},{0.765071, 0.150174, 0.372385}}],
    Line[{{0.765071, 0.150174, 0.372385},{0.760122, 0.166675, 0.321230}}],
    Line[{{0.760122, 0.166675, 0.321230},{0.753772, 0.195223, 0.276090}}],
    Line[{{0.753772, 0.195223, 0.276090},{0.749120, 0.241442, 0.250586}}],
    Line[{{0.749120, 0.241442, 0.250586},{0.751811, 0.292077, 0.264743}}],
    Line[{{0.751811, 0.292077, 0.264743},{0.758201, 0.325879, 0.305893}}],
    Line[{{0.758201, 0.325879, 0.305893},{0.763695, 0.345547, 0.355825}}],
    Line[{{0.763695, 0.345547, 0.355825},{0.767415, 0.356669, 0.408551}}],
    Line[{{0.767415, 0.356669, 0.408551},{0.769389, 0.362069, 0.462278}}],
    Line[{{0.769389, 0.362069, 0.462278},{0.769711, 0.362923, 0.516308}}],
    Line[{{0.769711, 0.362923, 0.516308},{0.768400, 0.359402, 0.570213}}],
    Line[{{0.768400, 0.359402, 0.570213},{0.765386, 0.350772, 0.623458}}],
    Line[{{0.765386, 0.350772, 0.623458},{0.760578, 0.334984, 0.674857}}],
    Line[{{0.760578, 0.334984, 0.674857},{0.754287, 0.307632, 0.720772}}],
    Line[{{0.754287, 0.307632, 0.720772},{0.749263, 0.262763, 0.748702}}],
    Line[{{0.749263, 0.262763, 0.748702},{0.751368, 0.211394, 0.737698}}],
    Line[{{0.751368, 0.211394, 0.737698},{0.757704, 0.176184, 0.697808}}],
    Line[{{0.757704, 0.176184, 0.697808},{0.763326, 0.155642, 0.648254}}],
    Line[{{0.763326, 0.155642, 0.648254},{0.767188, 0.143978, 0.595658}}],
    Line[{{0.749000, 0.249983, 0.500053},{0.749000, 0.250005, 0.499944}}],
    Line[{{0.749000, 0.250005, 0.499944},{0.749000, 0.249993, 0.500057}}],
    Line[{{0.749000, 0.249993, 0.500057},{0.749000, 0.249996, 0.499941}}],
    Line[{{0.749000, 0.249996, 0.499941},{0.749000, 0.250013, 0.500053}}],
    Line[{{0.749000, 0.250013, 0.500053},{0.749000, 0.249991, 0.499946}}],
    Line[{{0.749000, 0.249991, 0.499946},{0.749000, 0.249997, 0.500053}}],
    Line[{{0.749000, 0.249997, 0.500053},{0.749000, 0.250022, 0.499976}}],
    Line[{{0.749000, 0.250022, 0.499976},{0.749000, 0.249980, 0.499973}}],
    Line[{{0.749000, 0.249980, 0.499973},{0.749000, 0.249980, 0.500021}}],
    Line[{{0.749000, 0.249980, 0.500021},{0.749000, 0.250002, 0.500047}}],
    Line[{{0.749000, 0.250002, 0.500047},{0.749000, 0.250021, 0.500017}}],
    Line[{{0.749000, 0.250021, 0.500017},{0.749000, 0.250014, 0.499959}}],
    Line[{{0.749000, 0.250014, 0.499959},{0.749000, 0.249977, 0.499990}}],
    Line[{{0.749000, 0.249977, 0.499990},{0.749000, 0.249988, 0.500039}}],
    Line[{{0.749000, 0.249988, 0.500039},{0.749000, 0.249986, 0.500026}}],
    Line[{{0.749000, 0.249986, 0.500026},{0.749000, 0.249980, 0.500004}}],
    Line[{{0.749000, 0.249980, 0.500004},{0.749000, 0.249980, 0.500004}}],
    Line[{{0.749000, 0.249980, 0.500004},{0.749000, 0.249983, 0.499984}}],
    Line[{{0.749000, 0.249983, 0.499984},{0.749000, 0.249989, 0.499964}}],
    Line[{{0.749000, 0.249989, 0.499964},{0.749000, 0.249994, 0.499958}}],
    Line[{{0.749000, 0.249994, 0.499958},{0.749000, 0.249986, 0.499967}}],
    Line[{{0.749000, 0.249986, 0.499967},{0.749000, 0.249981, 0.499978}}],
    Line[{{0.749000, 0.249981, 0.499978},{0.749000, 0.249980, 0.499990}}],
    Line[{{0.749000, 0.249980, 0.499990},{0.749000, 0.249980, 0.499987}}],
    Line[{{0.749000, 0.249980, 0.499987},{0.749000, 0.249980, 0.499991}}],
    Line[{{0.749000, 0.249980, 0.499991},{0.749000, 0.249980, 0.499997}}],
    Line[{{0.749000, 0.249980, 0.499997},{0.749000, 0.249981, 0.499990}}],
    Line[{{0.749000, 0.249981, 0.499990},{0.749000, 0.249983, 0.499978}}],
    Line[{{0.749000, 0.249983, 0.499978},{0.749000, 0.249999, 0.499961}}],
    Line[{{0.749000, 0.249999, 0.499961},{0.749000, 0.250014, 0.499972}}],
    Line[{{0.749000, 0.250014, 0.499972},{0.749000, 0.250020, 0.499993}}],
    Line[{{0.749000, 0.250020, 0.499993},{0.749000, 0.250019, 0.500008}}],
    Line[{{0.749000, 0.250019, 0.500008},{0.749000, 0.250009, 0.500038}}],
    Line[{{0.749000, 0.250009, 0.500038},{0.749000, 0.250006, 0.500042}}],
    Line[{{0.749000, 0.250006, 0.500042},{0.749000, 0.250013, 0.500035}}],
    Line[{{0.749000, 0.250013, 0.500035},{0.749000, 0.250008, 0.500037}}],
    Line[{{0.749000, 0.250008, 0.500037},{0.749000, 0.249992, 0.500039}}],
    Line[{{0.749000, 0.249992, 0.500039},{0.749000, 0.249986, 0.500028}}],
    Line[{{0.749000, 0.249986, 0.500028},{0.749000, 0.249980, 0.500022}}],
    Line[{{0.749000, 0.249980, 0.500022},{0.749000, 0.250000, 0.500047}}],
    Line[{{0.749000, 0.250000, 0.500047},{0.749000, 0.250018, 0.500027}}],
    Line[{{0.749000, 0.250018, 0.500027},{0.749000, 0.250022, 0.500000}}],
    Line[{{0.749000, 0.250022, 0.500000},{0.749000, 0.250011, 0.499955}}],
    Line[{{0.749000, 0.250011, 0.499955},{0.749000, 0.249980, 0.499982}}],
    Line[{{0.749000, 0.249980, 0.499982},{0.749000, 0.249978, 0.500012}}],
    Line[{{0.749000, 0.249978, 0.500012},{0.749000, 0.249993, 0.500044}}],
    Line[{{0.749000, 0.249993, 0.500044},{0.749000, 0.249994, 0.500037}}],
    Line[{{0.749000, 0.249994, 0.500037},{0.749000, 0.249984, 0.499989}}],
    Line[{{0.749000, 0.249984, 0.499989},{0.749000, 0.250000, 0.500029}}],
    Line[{{0.749000, 0.250000, 0.500029},{0.749000, 0.250015, 0.499988}}],
    Line[{{0.749000, 0.250015, 0.499988},{0.749000, 0.249992, 0.499975}}],
    Line[{{0.749000, 0.249992, 0.499975},{0.749000, 0.249989, 0.499985}}],
    Line[{{0.749000, 0.249989, 0.499985},{0.749000, 0.249996, 0.500020}}],
    Line[{{0.749000, 0.249996, 0.500020},{0.749000, 0.249998, 0.499985}}],
    Line[{{0.749000, 0.249998, 0.499985},{0.749000, 0.249995, 0.500003}}],
    Line[{{0.749000, 0.249995, 0.500003},{0.749000, 0.250000, 0.500000}}],
    Line[{{0.749000, 0.250000, 0.500000},{0.749000, 0.249999, 0.499999}}],
    Line[{{0.749000, 0.249999, 0.499999},{0.749000, 0.249999, 0.499997}}],
    Line[{{0.749000, 0.249999, 0.499997},{0.749000, 0.249998, 0.500000}}],
    Line[{{0.749000, 0.249998, 0.500000},{0.749000, 0.249999, 0.500003}}],
    Line[{{0.749000, 0.249999, 0.500003},{0.749000, 0.250001, 0.500003}}],
    Line[{{0.749000, 0.250001, 0.500003},{0.749000, 0.250002, 0.500000}}],
    Line[{{0.749000, 0.250002, 0.500000},{0.749000, 0.250001, 0.499997}}],
    Line[{{0.749000, 0.250001, 0.499997},{0.749000, 0.250000, 0.499997}}],
    Line[{{0.749000, 0.250000, 0.499997},{0.749000, 0.249999, 0.499999}}],
    Line[{{0.749000, 0.249999, 0.499999},{0.749000, 0.249999, 0.500002}}],
    Line[{{0.749000, 0.249999, 0.500002},{0.749000, 0.250000, 0.500003}}],
    Line[{{0.749000, 0.250000, 0.500003},{0.749000, 0.250001, 0.500001}}],
    Line[{{0.749000, 0.250001, 0.500001},{0.749000, 0.250001, 0.499998}}],
    Line[{{0.749000, 0.250001, 0.499998},{0.749000, 0.250000, 0.499997}}],
    Line[{{0.749000, 0.250000, 0.499997},{0.749000, 0.249999, 0.499998}}],
    Line[{{0.749000, 0.249999, 0.499998},{0.749000, 0.249999, 0.500001}}],
    Line[{{0.749000, 0.249999, 0.500001},{0.749000, 0.250000, 0.500003}}],
    Line[{{0.749000, 0.250000, 0.500003},{0.749000, 0.250001, 0.500002}}],
    Line[{{0.767187, 0.143979, 0.404341},{0.763325, 0.155644, 0.351746}}],
    Line[{{0.763325, 0.155644, 0.351746},{0.757704, 0.176185, 0.302194}}],
    Line[{{0.757704, 0.176185, 0.302194},{0.751367, 0.211393, 0.262301}}],
    Line[{{0.751367, 0.211393, 0.262301},{0.749263, 0.262765, 0.251301}}],
    Line[{{0.749263, 0.262765, 0.251301},{0.754286, 0.307631, 0.279229}}],
    Line[{{0.754286, 0.307631, 0.279229},{0.760578, 0.334985, 0.325145}}],
    Line[{{0.760578, 0.334985, 0.325145},{0.765386, 0.350772, 0.376543}}],
    Line[{{0.765386, 0.350772, 0.376543},{0.768399, 0.359405, 0.429786}}],
    Line[{{0.768399, 0.359405, 0.429786},{0.769710, 0.362925, 0.483691}}],
    Line[{{0.769710, 0.362925, 0.483691},{0.769388, 0.362071, 0.537721}}],
    Line[{{0.769388, 0.362071, 0.537721},{0.767414, 0.356670, 0.591446}}],
    Line[{{0.767414, 0.356670, 0.591446},{0.763695, 0.345549, 0.644172}}],
    Line[{{0.763695, 0.345549, 0.644172},{0.758201, 0.325881, 0.694103}}],
    Line[{{0.758201, 0.325881, 0.694103},{0.751811, 0.292081, 0.735254}}],
    Line[{{0.751811, 0.292081, 0.735254},{0.749119, 0.241447, 0.749415}}],
    Line[{{0.749119, 0.241447, 0.749415},{0.753772, 0.195226, 0.723912}}],
    Line[{{0.753772, 0.195226, 0.723912},{0.760121, 0.166677, 0.678773}}],
    Line[{{0.760121, 0.166677, 0.678773},{0.765070, 0.150175, 0.627619}}],
    Line[{{0.765070, 0.150175, 0.627619},{0.768223, 0.141074, 0.574463}}],
    Line[{{0.768223, 0.141074, 0.574463},{0.769665, 0.137190, 0.520587}}],
    Line[{{0.769665, 0.137190, 0.520587},{0.769472, 0.137702, 0.466553}}],
    Line[{{0.769472, 0.137702, 0.466553},{0.767632, 0.142715, 0.412784}}],
    Line[{{0.767632, 0.142715, 0.412784},{0.764055, 0.153309, 0.359937}}],
    Line[{{0.764055, 0.153309, 0.359937},{0.758693, 0.172137, 0.309659}}],
    Line[{{0.758693, 0.172137, 0.309659},{0.752277, 0.204562, 0.267362}}],
    Line[{{0.752277, 0.204562, 0.267362},{0.749031, 0.254293, 0.250151}}],
    Line[{{0.749031, 0.254293, 0.250151},{0.753262, 0.301790, 0.273054}}],
    Line[{{0.753262, 0.301790, 0.273054},{0.759655, 0.331584, 0.317338}}],
    Line[{{0.759655, 0.331584, 0.317338},{0.764743, 0.348830, 0.368224}}],
    Line[{{0.764743, 0.348830, 0.368224},{0.768036, 0.358414, 0.421284}}],
    Line[{{0.768036, 0.358414, 0.421284},{0.769611, 0.362670, 0.475127}}],
    Line[{{0.769611, 0.362670, 0.475127},{0.769546, 0.362498, 0.529164}}],
    Line[{{0.769546, 0.362498, 0.529164},{0.767839, 0.357867, 0.582972}}],
    Line[{{0.767839, 0.357867, 0.582972},{0.764404, 0.347786, 0.635931}}],
    Line[{{0.764404, 0.347786, 0.635931},{0.759177, 0.329765, 0.686527}}],
    Line[{{0.759177, 0.329765, 0.686527},{0.752761, 0.298678, 0.729867}}],
    Line[{{0.752761, 0.298678, 0.729867},{0.749000, 0.250000, 0.750000}}],
    Line[{{0.749000, 0.250000, 0.750000},{0.752761, 0.201322, 0.729867}}],
    Line[{{0.752761, 0.201322, 0.729867},{0.759177, 0.170233, 0.686527}}],
    Line[{{0.759177, 0.170233, 0.686527},{0.764404, 0.152213, 0.635929}}],
    Line[{{0.764404, 0.152213, 0.635929},{0.767840, 0.142133, 0.582970}}],
    Line[{{0.767840, 0.142133, 0.582970},{0.769547, 0.137502, 0.529161}}],
    Line[{{0.769547, 0.137502, 0.529161},{0.769611, 0.137332, 0.475123}}],
    Line[{{0.769611, 0.137332, 0.475123},{0.768037, 0.141587, 0.421279}}],
    Line[{{0.768037, 0.141587, 0.421279},{0.764743, 0.151171, 0.368218}}],
    Line[{{0.764743, 0.151171, 0.368218},{0.759654, 0.168417, 0.317331}}],
    Line[{{0.759654, 0.168417, 0.317331},{0.753262, 0.198212, 0.273048}}],
    Line[{{0.753262, 0.198212, 0.273048},{0.749031, 0.245713, 0.250148}}],
    Line[{{0.749031, 0.245713, 0.250148},{0.752278, 0.295442, 0.267364}}],
    Line[{{0.752278, 0.295442, 0.267364},{0.758694, 0.327866, 0.309662}}],
    Line[{{0.758694, 0.327866, 0.309662},{0.764056, 0.346694, 0.359942}}],
    Line[{{0.764056, 0.346694, 0.359942},{0.767633, 0.357287, 0.412790}}],
    Line[{{0.767633, 0.357287, 0.412790},{0.769473, 0.362298, 0.466559}}],
    Line[{{0.769473, 0.362298, 0.466559},{0.769667, 0.362810, 0.520594}}],
    Line[{{0.769667, 0.362810, 0.520594},{0.768224, 0.358924, 0.574471}}],
    Line[{{0.768224, 0.358924, 0.574471},{0.765071, 0.349824, 0.627628}}],
    Line[{{0.765071, 0.349824, 0.627628},{0.760122, 0.333321, 0.678781}}],
    Line[{{0.760122, 0.333321, 0.678781},{0.753771, 0.304771, 0.723920}}],
    Line[{{0.753771, 0.304771, 0.723920},{0.749120, 0.258546, 0.749418}}],
    Line[{{0.749120, 0.258546, 0.749418},{0.751812, 0.207914, 0.735253}}],
    Line[{{0.751812, 0.207914, 0.735253},{0.758202, 0.174115, 0.694101}}],
    Line[{{0.758202, 0.174115, 0.694101},{0.763696, 0.154448, 0.644168}}],
    Line[{{0.763696, 0.154448, 0.644168},{0.767416, 0.143327, 0.591442}}],
    Line[{{0.767416, 0.143327, 0.591442},{0.769389, 0.137928, 0.537715}}],
    Line[{{0.769389, 0.137928, 0.537715},{0.769711, 0.137075, 0.483685}}],
    Line[{{0.769711, 0.137075, 0.483685},{0.768401, 0.140596, 0.429780}}],
    Line[{{0.768401, 0.140596, 0.429780},{0.765387, 0.149226, 0.376534}}],
    Line[{{0.765387, 0.149226, 0.376534},{0.760578, 0.165015, 0.325136}}],
    Line[{{0.760578, 0.165015, 0.325136},{0.754287, 0.192368, 0.279221}}],
    Line[{{0.754287, 0.192368, 0.279221},{0.749263, 0.237238, 0.251294}}],
    Line[{{0.749263, 0.237238, 0.251294},{0.751368, 0.288609, 0.262298}}],
    Line[{{0.751368, 0.288609, 0.262298},{0.757705, 0.323819, 0.302189}}],
    Line[{{0.757705, 0.323819, 0.302189},{0.763326, 0.344359, 0.351743}}],
    Line[{{0.763326, 0.344359, 0.351743},{0.767188, 0.356024, 0.404339}}],
    Line[{{0.755734, 0.500000, 0.711470},{0.745886, 0.500000, 0.764608}}],
    Line[{{0.745886, 0.500000, 0.764608},{0.731333, 0.500000, 0.816637}}],
    Line[{{0.731333, 0.500000, 0.816637},{0.709321, 0.500000, 0.865916}}],
    Line[{{0.709321, 0.500000, 0.865916},{0.675977, 0.500000, 0.908189}}],
    Line[{{0.675977, 0.500000, 0.908189},{0.630677, 0.500000, 0.937224}}],
    Line[{{0.630677, 0.500000, 0.937224},{0.578974, 0.500000, 0.952603}}],
    Line[{{0.578974, 0.500000, 0.952603},{0.525320, 0.500000, 0.958818}}],
    Line[{{0.525320, 0.500000, 0.958818},{0.471294, 0.500000, 0.958631}}],
    Line[{{0.471294, 0.500000, 0.958631},{0.417699, 0.500000, 0.951952}}],
    Line[{{0.417699, 0.500000, 0.951952},{0.366225, 0.500000, 0.935845}}],
    Line[{{0.366225, 0.500000, 0.935845},{0.321548, 0.500000, 0.905872}}],
    Line[{{0.321548, 0.500000, 0.905872},{0.289006, 0.500000, 0.862967}}],
    Line[{{0.289006, 0.500000, 0.862967},{0.267574, 0.500000, 0.813428}}],
    Line[{{0.267574, 0.500000, 0.813428},{0.253379, 0.500000, 0.761301}}],
    Line[{{0.253379, 0.500000, 0.761301},{0.243764, 0.500000, 0.708121}}],
    Line[{{0.243764, 0.500000, 0.708121},{0.237267, 0.500000, 0.654465}}],
    Line[{{0.237267, 0.500000, 0.654465},{0.233096, 0.500000, 0.600576}}],
    Line[{{0.233096, 0.500000, 0.600576},{0.230821, 0.500000, 0.546572}}],
    Line[{{0.230821, 0.500000, 0.546572},{0.230232, 0.500000, 0.492524}}],
    Line[{{0.230232, 0.500000, 0.492524},{0.231276, 0.500000, 0.438482}}],
    Line[{{0.231276, 0.500000, 0.438482},{0.234047, 0.500000, 0.384502}}],
    Line[{{0.234047, 0.500000, 0.384502},{0.238805, 0.500000, 0.330661}}],
    Line[{{0.238805, 0.500000, 0.330661},{0.246063, 0.500000, 0.277104}}],
    Line[{{0.246063, 0.500000, 0.277104},{0.256758, 0.500000, 0.224132}}],
    Line[{{0.256758, 0.500000, 0.224132},{0.272620, 0.500000, 0.172496}}],
    Line[{{0.272620, 0.500000, 0.172496},{0.296730, 0.500000, 0.124231}}],
    Line[{{0.296730, 0.500000, 0.124231},{0.332835, 0.500000, 0.084325}}],
    Line[{{0.332835, 0.500000, 0.084325},{0.380051, 0.500000, 0.058477}}],
    Line[{{0.380051, 0.500000, 0.058477},{0.432414, 0.500000, 0.045433}}],
    Line[{{0.432414, 0.500000, 0.045433},{0.486226, 0.500000, 0.040719}}],
    Line[{{0.486226, 0.500000, 0.040719},{0.540231, 0.500000, 0.042193}}],
    Line[{{0.540231, 0.500000, 0.042193},{0.593584, 0.500000, 0.050540}}],
    Line[{{0.593584, 0.500000, 0.050540},{0.644126, 0.500000, 0.069285}}],
    Line[{{0.644126, 0.500000, 0.069285},{0.686500, 0.500000, 0.102410}}],
    Line[{{0.686500, 0.500000, 0.102410},{0.716371, 0.500000, 0.147252}}],
    Line[{{0.716371, 0.500000, 0.147252},{0.735956, 0.500000, 0.197566}}],
    Line[{{0.735956, 0.500000, 0.197566},{0.749000, 0.500000, 0.250000}}],
    Line[{{0.749000, 0.500000, 0.250000},{0.757853, 0.500000, 0.303315}}],
    Line[{{0.757853, 0.500000, 0.303315},{0.763799, 0.500000, 0.357036}}],
    Line[{{0.763799, 0.500000, 0.357036},{0.767537, 0.500000, 0.410958}}],
    Line[{{0.767537, 0.500000, 0.410958},{0.769440, 0.500000, 0.464976}}],
    Line[{{0.769440, 0.500000, 0.464976},{0.769681, 0.500000, 0.519027}}],
    Line[{{0.769681, 0.500000, 0.519027},{0.768281, 0.500000, 0.573061}}],
    Line[{{0.768281, 0.500000, 0.573061},{0.765114, 0.500000, 0.627019}}],
    Line[{{0.765114, 0.500000, 0.627019},{0.759873, 0.500000, 0.680813}}],
    Line[{{0.759873, 0.500000, 0.680813},{0.751979, 0.500000, 0.734280}}],
    Line[{{0.751979, 0.500000, 0.734280},{0.740360, 0.500000, 0.787052}}],
    Line[{{0.740360, 0.500000, 0.787052},{0.723046, 0.500000, 0.838209}}],
    Line[{{0.723046, 0.500000, 0.838209},{0.696646, 0.500000, 0.885227}}],
    Line[{{0.696646, 0.500000, 0.885227},{0.657822, 0.500000, 0.922462}}],
    Line[{{0.657822, 0.500000, 0.922462},{0.609001, 0.500000, 0.945217}}],
    Line[{{0.609001, 0.500000, 0.945217},{0.556137, 0.500000, 0.956152}}],
    Line[{{0.556137, 0.500000, 0.956152},{0.502216, 0.500000, 0.959463}}],
    Line[{{0.502216, 0.500000, 0.959463},{0.448265, 0.500000, 0.956671}}],
    Line[{{0.448265, 0.500000, 0.956671},{0.395246, 0.500000, 0.946488}}],
    Line[{{0.395246, 0.500000, 0.946488},{0.345893, 0.500000, 0.924883}}],
    Line[{{0.345893, 0.500000, 0.924883},{0.306050, 0.500000, 0.888748}}],
    Line[{{0.306050, 0.500000, 0.888748},{0.278718, 0.500000, 0.842276}}],
    Line[{{0.278718, 0.500000, 0.842276},{0.260808, 0.500000, 0.791326}}],
    Line[{{0.260808, 0.500000, 0.791326},{0.248815, 0.500000, 0.738637}}],
    Line[{{0.248815, 0.500000, 0.738637},{0.240665, 0.500000, 0.685209}}],
    Line[{{0.240665, 0.500000, 0.685209},{0.235236, 0.500000, 0.631432}}],
    Line[{{0.235236, 0.500000, 0.631432},{0.231915, 0.500000, 0.577483}}],
    Line[{{0.231915, 0.500000, 0.577483},{0.230377, 0.500000, 0.523453}}],
    Line[{{0.230377, 0.500000, 0.523453},{0.230484, 0.500000, 0.469401}}],
    Line[{{0.230484, 0.500000, 0.469401},{0.232247, 0.500000, 0.415378}}],
    Line[{{0.232247, 0.500000, 0.415378},{0.235825, 0.500000, 0.361445}}],
    Line[{{0.235825, 0.500000, 0.361445},{0.241571, 0.500000, 0.307703}}],
    Line[{{0.241571, 0.500000, 0.307703},{0.250152, 0.500000, 0.254344}}],
    Line[{{0.250152, 0.500000, 0.254344},{0.262781, 0.500000, 0.201807}}],
    Line[{{0.262781, 0.500000, 0.201807},{0.281703, 0.500000, 0.151234}}],
    Line[{{0.281703, 0.500000, 0.151234},{0.310585, 0.500000, 0.105731}}],
    Line[{{0.310585, 0.500000, 0.105731},{0.352018, 0.500000, 0.071436}}],
    Line[{{0.352018, 0.500000, 0.071436},{0.402138, 0.500000, 0.051621}}],
    Line[{{0.706104, 0.500000, 0.812193},{0.681553, 0.500000, 0.860238}}],
    Line[{{0.681553, 0.500000, 0.860238},{0.645440, 0.500000, 0.900163}}],
    Line[{{0.645440, 0.500000, 0.900163},{0.598461, 0.500000, 0.926448}}],
    Line[{{0.598461, 0.500000, 0.926448},{0.546089, 0.500000, 0.939380}}],
    Line[{{0.546089, 0.500000, 0.939380},{0.492179, 0.500000, 0.942433}}],
    Line[{{0.492179, 0.500000, 0.942433},{0.438487, 0.500000, 0.936786}}],
    Line[{{0.438487, 0.500000, 0.936786},{0.387136, 0.500000, 0.920357}}],
    Line[{{0.387136, 0.500000, 0.920357},{0.342827, 0.500000, 0.889828}}],
    Line[{{0.342827, 0.500000, 0.889828},{0.310284, 0.500000, 0.846900}}],
    Line[{{0.310284, 0.500000, 0.846900},{0.288479, 0.500000, 0.797522}}],
    Line[{{0.288479, 0.500000, 0.797522},{0.273895, 0.500000, 0.745503}}],
    Line[{{0.273895, 0.500000, 0.745503},{0.264018, 0.500000, 0.692372}}],
    Line[{{0.264018, 0.500000, 0.692372},{0.257425, 0.500000, 0.638728}}],
    Line[{{0.257425, 0.500000, 0.638728},{0.253329, 0.500000, 0.584833}}],
    Line[{{0.253329, 0.500000, 0.584833},{0.251310, 0.500000, 0.530820}}],
    Line[{{0.251310, 0.500000, 0.530820},{0.251179, 0.500000, 0.476768}}],
    Line[{{0.251179, 0.500000, 0.476768},{0.252926, 0.500000, 0.422745}}],
    Line[{{0.252926, 0.500000, 0.422745},{0.256710, 0.500000, 0.368828}}],
    Line[{{0.256710, 0.500000, 0.368828},{0.262916, 0.500000, 0.315136}}],
    Line[{{0.262916, 0.500000, 0.315136},{0.272263, 0.500000, 0.261907}}],
    Line[{{0.272263, 0.500000, 0.261907},{0.286064, 0.500000, 0.209670}}],
    Line[{{0.286064, 0.500000, 0.209670},{0.306655, 0.500000, 0.159760}}],
    Line[{{0.306655, 0.500000, 0.159760},{0.337505, 0.500000, 0.115578}}],
    Line[{{0.337505, 0.500000, 0.115578},{0.380349, 0.500000, 0.083029}}],
    Line[{{0.380349, 0.500000, 0.083029},{0.431067, 0.500000, 0.064784}}],
    Line[{{0.431067, 0.500000, 0.064784},{0.484598, 0.500000, 0.057820}}],
    Line[{{0.484598, 0.500000, 0.057820},{0.538564, 0.500000, 0.059658}}],
    Line[{{0.538564, 0.500000, 0.059658},{0.591312, 0.500000, 0.071015}}],
    Line[{{0.591312, 0.500000, 0.071015},{0.639396, 0.500000, 0.095252}}],
    Line[{{0.639396, 0.500000, 0.095252},{0.677236, 0.500000, 0.133522}}],
    Line[{{0.677236, 0.500000, 0.133522},{0.703231, 0.500000, 0.180783}}],
    Line[{{0.703231, 0.500000, 0.180783},{0.720531, 0.500000, 0.231948}}],
    Line[{{0.720531, 0.500000, 0.231948},{0.732205, 0.500000, 0.284709}}],
    Line[{{0.732205, 0.500000, 0.284709},{0.740085, 0.500000, 0.338177}}],
    Line[{{0.740085, 0.500000, 0.338177},{0.745187, 0.500000, 0.391985}}],
    Line[{{0.745187, 0.500000, 0.391985},{0.748067, 0.500000, 0.445958}}],
    Line[{{0.748067, 0.500000, 0.445958},{0.749000, 0.500000, 0.500000}}],
    Line[{{0.749000, 0.500000, 0.500000},{0.748067, 0.500000, 0.554042}}],
    Line[{{0.748067, 0.500000, 0.554042},{0.745187, 0.500000, 0.608015}}],
    Line[{{0.745187, 0.500000, 0.608015},{0.740085, 0.500000, 0.661823}}],
    Line[{{0.740085, 0.500000, 0.661823},{0.732205, 0.500000, 0.715291}}],
    Line[{{0.732205, 0.500000, 0.715291},{0.720531, 0.500000, 0.768052}}],
    Line[{{0.720531, 0.500000, 0.768052},{0.703231, 0.500000, 0.819217}}],
    Line[{{0.703231, 0.500000, 0.819217},{0.677236, 0.500000, 0.866477}}],
    Line[{{0.677236, 0.500000, 0.866477},{0.639397, 0.500000, 0.904748}}],
    Line[{{0.639397, 0.500000, 0.904748},{0.591311, 0.500000, 0.928986}}],
    Line[{{0.591311, 0.500000, 0.928986},{0.538563, 0.500000, 0.940342}}],
    Line[{{0.538563, 0.500000, 0.940342},{0.484598, 0.500000, 0.942180}}],
    Line[{{0.484598, 0.500000, 0.942180},{0.431067, 0.500000, 0.935216}}],
    Line[{{0.431067, 0.500000, 0.935216},{0.380350, 0.500000, 0.916972}}],
    Line[{{0.380350, 0.500000, 0.916972},{0.337507, 0.500000, 0.884424}}],
    Line[{{0.337507, 0.500000, 0.884424},{0.306658, 0.500000, 0.840241}}],
    Line[{{0.306658, 0.500000, 0.840241},{0.286066, 0.500000, 0.790333}}],
    Line[{{0.286066, 0.500000, 0.790333},{0.272265, 0.500000, 0.738096}}],
    Line[{{0.272265, 0.500000, 0.738096},{0.262917, 0.500000, 0.684866}}],
    Line[{{0.262917, 0.500000, 0.684866},{0.256711, 0.500000, 0.631175}}],
    Line[{{0.256711, 0.500000, 0.631175},{0.252927, 0.500000, 0.577257}}],
    Line[{{0.252927, 0.500000, 0.577257},{0.251180, 0.500000, 0.523234}}],
    Line[{{0.251180, 0.500000, 0.523234},{0.251311, 0.500000, 0.469183}}],
    Line[{{0.251311, 0.500000, 0.469183},{0.253329, 0.500000, 0.415169}}],
    Line[{{0.253329, 0.500000, 0.415169},{0.257425, 0.500000, 0.361275}}],
    Line[{{0.257425, 0.500000, 0.361275},{0.264018, 0.500000, 0.307630}}],
    Line[{{0.264018, 0.500000, 0.307630},{0.273894, 0.500000, 0.254498}}],
    Line[{{0.273894, 0.500000, 0.254498},{0.288478, 0.500000, 0.202479}}],
    Line[{{0.288478, 0.500000, 0.202479},{0.310281, 0.500000, 0.153100}}],
    Line[{{0.310281, 0.500000, 0.153100},{0.342826, 0.500000, 0.110173}}],
    Line[{{0.342826, 0.500000, 0.110173},{0.387135, 0.500000, 0.079643}}],
    Line[{{0.387135, 0.500000, 0.079643},{0.438486, 0.500000, 0.063213}}],
    Line[{{0.438486, 0.500000, 0.063213},{0.492178, 0.500000, 0.057566}}],
    Line[{{0.492178, 0.500000, 0.057566},{0.546088, 0.500000, 0.060620}}],
    Line[{{0.546088, 0.500000, 0.060620},{0.598460, 0.500000, 0.073553}}],
    Line[{{0.598460, 0.500000, 0.073553},{0.645437, 0.500000, 0.099840}}],
    Line[{{0.645437, 0.500000, 0.099840},{0.681551, 0.500000, 0.139760}}],
    Line[{{0.681551, 0.500000, 0.139760},{0.706102, 0.500000, 0.187806}}],
    Line[{{0.402137, 0.500000, 0.948377},{0.352016, 0.500000, 0.928562}}],
    Line[{{0.352016, 0.500000, 0.928562},{0.310584, 0.500000, 0.894264}}],
    Line[{{0.310584, 0.500000, 0.894264},{0.281704, 0.500000, 0.848762}}],
    Line[{{0.281704, 0.500000, 0.848762},{0.262781, 0.500000, 0.798190}}],
    Line[{{0.262781, 0.500000, 0.798190},{0.250151, 0.500000, 0.745654}}],
    Line[{{0.250151, 0.500000, 0.745654},{0.241570, 0.500000, 0.692295}}],
    Line[{{0.241570, 0.500000, 0.692295},{0.235824, 0.500000, 0.638553}}],
    Line[{{0.235824, 0.500000, 0.638553},{0.232246, 0.500000, 0.584621}}],
    Line[{{0.232246, 0.500000, 0.584621},{0.230483, 0.500000, 0.530598}}],
    Line[{{0.230483, 0.500000, 0.530598},{0.230376, 0.500000, 0.476546}}],
    Line[{{0.230376, 0.500000, 0.476546},{0.231914, 0.500000, 0.422516}}],
    Line[{{0.231914, 0.500000, 0.422516},{0.235236, 0.500000, 0.368567}}],
    Line[{{0.235236, 0.500000, 0.368567},{0.240666, 0.500000, 0.314791}}],
    Line[{{0.240666, 0.500000, 0.314791},{0.248816, 0.500000, 0.261363}}],
    Line[{{0.248816, 0.500000, 0.261363},{0.260809, 0.500000, 0.208675}}],
    Line[{{0.260809, 0.500000, 0.208675},{0.278718, 0.500000, 0.157725}}],
    Line[{{0.278718, 0.500000, 0.157725},{0.306049, 0.500000, 0.111251}}],
    Line[{{0.306049, 0.500000, 0.111251},{0.345895, 0.500000, 0.075117}}],
    Line[{{0.345895, 0.500000, 0.075117},{0.395246, 0.500000, 0.053512}}],
    Line[{{0.395246, 0.500000, 0.053512},{0.448264, 0.500000, 0.043328}}],
    Line[{{0.448264, 0.500000, 0.043328},{0.502215, 0.500000, 0.040537}}],
    Line[{{0.502215, 0.500000, 0.040537},{0.556135, 0.500000, 0.043847}}],
    Line[{{0.556135, 0.500000, 0.043847},{0.608999, 0.500000, 0.054783}}],
    Line[{{0.608999, 0.500000, 0.054783},{0.657819, 0.500000, 0.077538}}],
    Line[{{0.657819, 0.500000, 0.077538},{0.696644, 0.500000, 0.114772}}],
    Line[{{0.696644, 0.500000, 0.114772},{0.723045, 0.500000, 0.161790}}],
    Line[{{0.723045, 0.500000, 0.161790},{0.740359, 0.500000, 0.212948}}],
    Line[{{0.740359, 0.500000, 0.212948},{0.751978, 0.500000, 0.265720}}],
    Line[{{0.751978, 0.500000, 0.265720},{0.759873, 0.500000, 0.319187}}],
    Line[{{0.759873, 0.500000, 0.319187},{0.765113, 0.500000, 0.372981}}],
    Line[{{0.765113, 0.500000, 0.372981},{0.768280, 0.500000, 0.426939}}],
    Line[{{0.768280, 0.500000, 0.426939},{0.769681, 0.500000, 0.480973}}],
    Line[{{0.769681, 0.500000, 0.480973},{0.769440, 0.500000, 0.535024}}],
    Line[{{0.769440, 0.500000, 0.535024},{0.767537, 0.500000, 0.589042}}],
    Line[{{0.767537, 0.500000, 0.589042},{0.763798, 0.500000, 0.642964}}],
    Line[{{0.763798, 0.500000, 0.642964},{0.757852, 0.500000, 0.696685}}],
    Line[{{0.757852, 0.500000, 0.696685},{0.749000, 0.500000, 0.750000}}],
    Line[{{0.749000, 0.500000, 0.750000},{0.735955, 0.500000, 0.802434}}],
    Line[{{0.735955, 0.500000, 0.802434},{0.716371, 0.500000, 0.852749}}],
    Line[{{0.716371, 0.500000, 0.852749},{0.686500, 0.500000, 0.897594}}],
    Line[{{0.686500, 0.500000, 0.897594},{0.644121, 0.500000, 0.930716}}],
    Line[{{0.644121, 0.500000, 0.930716},{0.593577, 0.500000, 0.949460}}],
    Line[{{0.593577, 0.500000, 0.949460},{0.540225, 0.500000, 0.957805}}],
    Line[{{0.540225, 0.500000, 0.957805},{0.486219, 0.500000, 0.959279}}],
    Line[{{0.486219, 0.500000, 0.959279},{0.432408, 0.500000, 0.954563}}],
    Line[{{0.432408, 0.500000, 0.954563},{0.380044, 0.500000, 0.941517}}],
    Line[{{0.380044, 0.500000, 0.941517},{0.332828, 0.500000, 0.915665}}],
    Line[{{0.332828, 0.500000, 0.915665},{0.296728, 0.500000, 0.875756}}],
    Line[{{0.296728, 0.500000, 0.875756},{0.272619, 0.500000, 0.827493}}],
    Line[{{0.272619, 0.500000, 0.827493},{0.256757, 0.500000, 0.775855}}],
    Line[{{0.256757, 0.500000, 0.775855},{0.246063, 0.500000, 0.722883}}],
    Line[{{0.246063, 0.500000, 0.722883},{0.238806, 0.500000, 0.669324}}],
    Line[{{0.238806, 0.500000, 0.669324},{0.234049, 0.500000, 0.615483}}],
    Line[{{0.234049, 0.500000, 0.615483},{0.231280, 0.500000, 0.561503}}],
    Line[{{0.231280, 0.500000, 0.561503},{0.230236, 0.500000, 0.507461}}],
    Line[{{0.230236, 0.500000, 0.507461},{0.230826, 0.500000, 0.453412}}],
    Line[{{0.230826, 0.500000, 0.453412},{0.233102, 0.500000, 0.399408}}],
    Line[{{0.233102, 0.500000, 0.399408},{0.237273, 0.500000, 0.345519}}],
    Line[{{0.237273, 0.500000, 0.345519},{0.243770, 0.500000, 0.291863}}],
    Line[{{0.243770, 0.500000, 0.291863},{0.253386, 0.500000, 0.238683}}],
    Line[{{0.253386, 0.500000, 0.238683},{0.267581, 0.500000, 0.186555}}],
    Line[{{0.267581, 0.500000, 0.186555},{0.289016, 0.500000, 0.137017}}],
    Line[{{0.289016, 0.500000, 0.137017},{0.321563, 0.500000, 0.094115}}],
    Line[{{0.321563, 0.500000, 0.094115},{0.366243, 0.500000, 0.064149}}],
    Line[{{0.366243, 0.500000, 0.064149},{0.417717, 0.500000, 0.048043}}],
    Line[{{0.417717, 0.500000, 0.048043},{0.471313, 0.500000, 0.041367}}],
    Line[{{0.471313, 0.500000, 0.041367},{0.525340, 0.500000, 0.041182}}],
    Line[{{0.525340, 0.500000, 0.041182},{0.578994, 0.500000, 0.047400}}],
    Line[{{0.578994, 0.500000, 0.047400},{0.630696, 0.500000, 0.062783}}],
    Line[{{0.630696, 0.500000, 0.062783},{0.675990, 0.500000, 0.091823}}],
    Line[{{0.675990, 0.500000, 0.091823},{0.709331, 0.500000, 0.134099}}],
    Line[{{0.709331, 0.500000, 0.134099},{0.731340, 0.500000, 0.183381}}],
    Line[{{0.731340, 0.500000, 0.183381},{0.745890, 0.500000, 0.235410}}],
    Line[{{0.745890, 0.500000, 0.235410},{0.755737, 0.500000, 0.288548}}],
    Line[{{0.767188, 0.643978, 0.595650},{0.763327, 0.655642, 0.648246}}],
    Line[{{0.763327, 0.655642, 0.648246},{0.757706, 0.676182, 0.697800}}],
    Line[{{0.757706, 0.676182, 0.697800},{0.751370, 0.711390, 0.737692}}],
    Line[{{0.751370, 0.711390, 0.737692},{0.749264, 0.762758, 0.748700}}],
    Line[{{0.749264, 0.762758, 0.748700},{0.754287, 0.807627, 0.720774}}],
    Line[{{0.754287, 0.807627, 0.720774},{0.760578, 0.834981, 0.674859}}],
    Line[{{0.760578, 0.834981, 0.674859},{0.765386, 0.850770, 0.623461}}],
    Line[{{0.765386, 0.850770, 0.623461},{0.768400, 0.859401, 0.570217}}],
    Line[{{0.768400, 0.859401, 0.570217},{0.769711, 0.862922, 0.516312}}],
    Line[{{0.769711, 0.862922, 0.516312},{0.769389, 0.862069, 0.462281}}],
    Line[{{0.769389, 0.862069, 0.462281},{0.767415, 0.856669, 0.408555}}],
    Line[{{0.767415, 0.856669, 0.408555},{0.763695, 0.845547, 0.355828}}],
    Line[{{0.763695, 0.845547, 0.355828},{0.758202, 0.825879, 0.305897}}],
    Line[{{0.758202, 0.825879, 0.305897},{0.751811, 0.792079, 0.264746}}],
    Line[{{0.751811, 0.792079, 0.264746},{0.749120, 0.741445, 0.250587}}],
    Line[{{0.749120, 0.741445, 0.250587},{0.753772, 0.695225, 0.276090}}],
    Line[{{0.753772, 0.695225, 0.276090},{0.760122, 0.666676, 0.321231}}],
    Line[{{0.760122, 0.666676, 0.321231},{0.765071, 0.650175, 0.372385}}],
    Line[{{0.765071, 0.650175, 0.372385},{0.768224, 0.641074, 0.425541}}],
    Line[{{0.768224, 0.641074, 0.425541},{0.769666, 0.637190, 0.479416}}],
    Line[{{0.769666, 0.637190, 0.479416},{0.769472, 0.637702, 0.533451}}],
    Line[{{0.769472, 0.637702, 0.533451},{0.767632, 0.642716, 0.587219}}],
    Line[{{0.767632, 0.642716, 0.587219},{0.764055, 0.653310, 0.640066}}],
    Line[{{0.764055, 0.653310, 0.640066},{0.758693, 0.672139, 0.690343}}],
    Line[{{0.758693, 0.672139, 0.690343},{0.752277, 0.704564, 0.732640}}],
    Line[{{0.752277, 0.704564, 0.732640},{0.749031, 0.754296, 0.749850}}],
    Line[{{0.749031, 0.754296, 0.749850},{0.753263, 0.801792, 0.726944}}],
    Line[{{0.753263, 0.801792, 0.726944},{0.759655, 0.831585, 0.682662}}],
    Line[{{0.759655, 0.831585, 0.682662},{0.764743, 0.848831, 0.631776}}],
    Line[{{0.764743, 0.848831, 0.631776},{0.768036, 0.858415, 0.578716}}],
    Line[{{0.768036, 0.858415, 0.578716},{0.769611, 0.862669, 0.524872}}],
    Line[{{0.769611, 0.862669, 0.524872},{0.769546, 0.862498, 0.470835}}],
    Line[{{0.769546, 0.862498, 0.470835},{0.767839, 0.857867, 0.417027}}],
    Line[{{0.767839, 0.857867, 0.417027},{0.764404, 0.847786, 0.364069}}],
    Line[{{0.764404, 0.847786, 0.364069},{0.759177, 0.829765, 0.313472}}],
    Line[{{0.759177, 0.829765, 0.313472},{0.752761, 0.798677, 0.270132}}],
    Line[{{0.752761, 0.798677, 0.270132},{0.749000, 0.750000, 0.250000}}],
    Line[{{0.749000, 0.750000, 0.250000},{0.752761, 0.701323, 0.270132}}],
    Line[{{0.752761, 0.701323, 0.270132},{0.759177, 0.670235, 0.313472}}],
    Line[{{0.759177, 0.670235, 0.313472},{0.764404, 0.652214, 0.364069}}],
    Line[{{0.764404, 0.652214, 0.364069},{0.767839, 0.642133, 0.417027}}],
    Line[{{0.767839, 0.642133, 0.417027},{0.769546, 0.637502, 0.470835}}],
    Line[{{0.769546, 0.637502, 0.470835},{0.769611, 0.637330, 0.524872}}],
    Line[{{0.769611, 0.637330, 0.524872},{0.768037, 0.641585, 0.578716}}],
    Line[{{0.768037, 0.641585, 0.578716},{0.764743, 0.651168, 0.631776}}],
    Line[{{0.764743, 0.651168, 0.631776},{0.759655, 0.668415, 0.682662}}],
    Line[{{0.759655, 0.668415, 0.682662},{0.753263, 0.698208, 0.726944}}],
    Line[{{0.753263, 0.698208, 0.726944},{0.749031, 0.745704, 0.749850}}],
    Line[{{0.749031, 0.745704, 0.749850},{0.752277, 0.795435, 0.732640}}],
    Line[{{0.752277, 0.795435, 0.732640},{0.758693, 0.827861, 0.690343}}],
    Line[{{0.758693, 0.827861, 0.690343},{0.764055, 0.846690, 0.640066}}],
    Line[{{0.764055, 0.846690, 0.640066},{0.767632, 0.857284, 0.587219}}],
    Line[{{0.767632, 0.857284, 0.587219},{0.769472, 0.862298, 0.533451}}],
    Line[{{0.769472, 0.862298, 0.533451},{0.769666, 0.862810, 0.479416}}],
    Line[{{0.769666, 0.862810, 0.479416},{0.768224, 0.858926, 0.425541}}],
    Line[{{0.768224, 0.858926, 0.425541},{0.765071, 0.849825, 0.372385}}],
    Line[{{0.765071, 0.849825, 0.372385},{0.760122, 0.833324, 0.321231}}],
    Line[{{0.760122, 0.833324, 0.321231},{0.753772, 0.804775, 0.276090}}],
    Line[{{0.753772, 0.804775, 0.276090},{0.749120, 0.758556, 0.250587}}],
    Line[{{0.749120, 0.758556, 0.250587},{0.751811, 0.707921, 0.264746}}],
    Line[{{0.751811, 0.707921, 0.264746},{0.758202, 0.674121, 0.305896}}],
    Line[{{0.758202, 0.674121, 0.305896},{0.763695, 0.654453, 0.355828}}],
    Line[{{0.763695, 0.654453, 0.355828},{0.767415, 0.643331, 0.408554}}],
    Line[{{0.767415, 0.643331, 0.408554},{0.769389, 0.637931, 0.462281}}],
    Line[{{0.769389, 0.637931, 0.462281},{0.769711, 0.637078, 0.516311}}],
    Line[{{0.769711, 0.637078, 0.516311},{0.768400, 0.640598, 0.570216}}],
    Line[{{0.768400, 0.640598, 0.570216},{0.765386, 0.649230, 0.623461}}],
    Line[{{0.765386, 0.649230, 0.623461},{0.760578, 0.665018, 0.674859}}],
    Line[{{0.760578, 0.665018, 0.674859},{0.754287, 0.692372, 0.720774}}],
    Line[{{0.754287, 0.692372, 0.720774},{0.749264, 0.737241, 0.748700}}],
    Line[{{0.749264, 0.737241, 0.748700},{0.751370, 0.788610, 0.737693}}],
    Line[{{0.751370, 0.788610, 0.737693},{0.757705, 0.823818, 0.697801}}],
    Line[{{0.757705, 0.823818, 0.697801},{0.763327, 0.844358, 0.648247}}],
    Line[{{0.763327, 0.844358, 0.648247},{0.767188, 0.856022, 0.595651}}],
    Line[{{0.749000, 0.749981, 0.500021},{0.749000, 0.749993, 0.499952}}],
    Line[{{0.749000, 0.749993, 0.499952},{0.749000, 0.750020, 0.500015}}],
    Line[{{0.749000, 0.750020, 0.500015},{0.749000, 0.750000, 0.500054}}],
    Line[{{0.749000, 0.750000, 0.500054},{0.749000, 0.749983, 0.499976}}],
    Line[{{0.749000, 0.749983, 0.499976},{0.749000, 0.750022, 0.499994}}],
    Line[{{0.749000, 0.750022, 0.499994},{0.749000, 0.750020, 0.500015}}],
    Line[{{0.749000, 0.750020, 0.500015},{0.749000, 0.750006, 0.500040}}],
    Line[{{0.749000, 0.750006, 0.500040},{0.749000, 0.750017, 0.500013}}],
    Line[{{0.749000, 0.750017, 0.500013},{0.749000, 0.749989, 0.499971}}],
    Line[{{0.749000, 0.749989, 0.499971},{0.749000, 0.750007, 0.499958}}],
    Line[{{0.749000, 0.750007, 0.499958},{0.749000, 0.750024, 0.500011}}],
    Line[{{0.749000, 0.750024, 0.500011},{0.749000, 0.749982, 0.499955}}],
    Line[{{0.749000, 0.749982, 0.499955},{0.749000, 0.749973, 0.500012}}],
    Line[{{0.749000, 0.749973, 0.500012},{0.749000, 0.750023, 0.500025}}],
    Line[{{0.749000, 0.750023, 0.500025},{0.749000, 0.749978, 0.499978}}],
    Line[{{0.749000, 0.749978, 0.499978},{0.749000, 0.750019, 0.499976}}],
    Line[{{0.749000, 0.750019, 0.499976},{0.749000, 0.750018, 0.500024}}],
    Line[{{0.749000, 0.750018, 0.500024},{0.749000, 0.750010, 0.499973}}],
    Line[{{0.749000, 0.750010, 0.499973},{0.749000, 0.750014, 0.500012}}],
    Line[{{0.749000, 0.750014, 0.500012},{0.749000, 0.750006, 0.500018}}],
    Line[{{0.749000, 0.750006, 0.500018},{0.749000, 0.750006, 0.499995}}],
    Line[{{0.749000, 0.750006, 0.499995},{0.749000, 0.750006, 0.499996}}],
    Line[{{0.749000, 0.750006, 0.499996},{0.749000, 0.750003, 0.499998}}],
    Line[{{0.749000, 0.750003, 0.499998},{0.749000, 0.750000, 0.500000}}],
    Line[{{0.749000, 0.750000, 0.500000},{0.749000, 0.750004, 0.500002}}],
    Line[{{0.749000, 0.750004, 0.500002},{0.749000, 0.749995, 0.499991}}],
    Line[{{0.749000, 0.749995, 0.499991},{0.749000, 0.750003, 0.499977}}],
    Line[{{0.749000, 0.750003, 0.499977},{0.749000, 0.750003, 0.500022}}],
    Line[{{0.749000, 0.750003, 0.500022},{0.749000, 0.749991, 0.499976}}],
    Line[{{0.749000, 0.749991, 0.499976},{0.749000, 0.749984, 0.499999}}],
    Line[{{0.749000, 0.749984, 0.499999},{0.749000, 0.750012, 0.499975}}],
    Line[{{0.749000, 0.750012, 0.499975},{0.749000, 0.749982, 0.499985}}],
    Line[{{0.749000, 0.749982, 0.499985},{0.749000, 0.750008, 0.499953}}],
    Line[{{0.749000, 0.750008, 0.499953},{0.749000, 0.750018, 0.500033}}],
    Line[{{0.749000, 0.750018, 0.500033},{0.749000, 0.749990, 0.499949}}],
    Line[{{0.749000, 0.749990, 0.499949},{0.749000, 0.749973, 0.500013}}],
    Line[{{0.749000, 0.749973, 0.500013},{0.749000, 0.749970, 0.500021}}],
    Line[{{0.749000, 0.749970, 0.500021},{0.749000, 0.749972, 0.500018}}],
    Line[{{0.749000, 0.749972, 0.500018},{0.749000, 0.749968, 0.499999}}],
    Line[{{0.749000, 0.749968, 0.499999},{0.749000, 0.749976, 0.499961}}],
    Line[{{0.749000, 0.749976, 0.499961},{0.749000, 0.749971, 0.499996}}],
    Line[{{0.749000, 0.749971, 0.499996},{0.749000, 0.749975, 0.500031}}],
    Line[{{0.749000, 0.749975, 0.500031},{0.749000, 0.749984, 0.500053}}],
    Line[{{0.749000, 0.749984, 0.500053},{0.749000, 0.749991, 0.500064}}],
    Line[{{0.749000, 0.749991, 0.500064},{0.749000, 0.749985, 0.500052}}],
    Line[{{0.749000, 0.749985, 0.500052},{0.749000, 0.750017, 0.500046}}],
    Line[{{0.749000, 0.750017, 0.500046},{0.749000, 0.750028, 0.500007}}],
    Line[{{0.749000, 0.750028, 0.500007},{0.749000, 0.750027, 0.499981}}],
    Line[{{0.749000, 0.750027, 0.499981},{0.749000, 0.750015, 0.499946}}],
    Line[{{0.749000, 0.750015, 0.499946},{0.749000, 0.750024, 0.499955}}],
    Line[{{0.749000, 0.750024, 0.499955},{0.749000, 0.750032, 0.499991}}],
    Line[{{0.749000, 0.750032, 0.499991},{0.749000, 0.750031, 0.500011}}],
    Line[{{0.749000, 0.750031, 0.500011},{0.749000, 0.750025, 0.500043}}],
    Line[{{0.749000, 0.750025, 0.500043},{0.749000, 0.749990, 0.500068}}],
    Line[{{0.749000, 0.749990, 0.500068},{0.749000, 0.749966, 0.500005}}],
    Line[{{0.749000, 0.749966, 0.500005},{0.749000, 0.749996, 0.499924}}],
    Line[{{0.749000, 0.749996, 0.499924},{0.749000, 0.750035, 0.500027}}],
    Line[{{0.749000, 0.750035, 0.500027},{0.749000, 0.749962, 0.500009}}],
    Line[{{0.749000, 0.749962, 0.500009},{0.749000, 0.750038, 0.499973}}],
    Line[{{0.749000, 0.750038, 0.499973},{0.749000, 0.749967, 0.500045}}],
    Line[{{0.749000, 0.749967, 0.500045},{0.749000, 0.749977, 0.499946}}],
    Line[{{0.749000, 0.749977, 0.499946},{0.749000, 0.750034, 0.499980}}],
    Line[{{0.749000, 0.750034, 0.499980},{0.749000, 0.749979, 0.500066}}],
    Line[{{0.749000, 0.749979, 0.500066},{0.749000, 0.750001, 0.499917}}],
    Line[{{0.749000, 0.750001, 0.499917},{0.749000, 0.750029, 0.500054}}],
    Line[{{0.749000, 0.750029, 0.500054},{0.749000, 0.749963, 0.499987}}],
    Line[{{0.749000, 0.749963, 0.499987},{0.749000, 0.750039, 0.499988}}],
    Line[{{0.749000, 0.750039, 0.499988},{0.749000, 0.749959, 0.500007}}],
    Line[{{0.749000, 0.749959, 0.500007},{0.749000, 0.750041, 0.500027}}],
    Line[{{0.749000, 0.750041, 0.500027},{0.749000, 0.749979, 0.499913}}],
    Line[{{0.749000, 0.749979, 0.499913},{0.749000, 0.749962, 0.500056}}],
    Line[{{0.749000, 0.749962, 0.500056},{0.749000, 0.750044, 0.500018}}],
    Line[{{0.749000, 0.750044, 0.500018},{0.749000, 0.749970, 0.499937}}],
    Line[{{0.749000, 0.749970, 0.499937},{0.749000, 0.750020, 0.500081}}],
    Line[{{0.767189, 0.856024, 0.404360},{0.763328, 0.844362, 0.351763}}],
    Line[{{0.763328, 0.844362, 0.351763},{0.757707, 0.823824, 0.302208}}],
    Line[{{0.757707, 0.823824, 0.302208},{0.751371, 0.788619, 0.262312}}],
    Line[{{0.751371, 0.788619, 0.262312},{0.749264, 0.737251, 0.251298}}],
    Line[{{0.749264, 0.737251, 0.251298},{0.754286, 0.692377, 0.279219}}],
    Line[{{0.754286, 0.692377, 0.279219},{0.760578, 0.665021, 0.325132}}],
    Line[{{0.760578, 0.665021, 0.325132},{0.765386, 0.649231, 0.376530}}],
    Line[{{0.765386, 0.649231, 0.376530},{0.768400, 0.640599, 0.429774}}],
    Line[{{0.768400, 0.640599, 0.429774},{0.769711, 0.637078, 0.483679}}],
    Line[{{0.769711, 0.637078, 0.483679},{0.769389, 0.637930, 0.537710}}],
    Line[{{0.769389, 0.637930, 0.537710},{0.767416, 0.643329, 0.591436}}],
    Line[{{0.767416, 0.643329, 0.591436},{0.763697, 0.654450, 0.644163}}],
    Line[{{0.763697, 0.654450, 0.644163},{0.758203, 0.674117, 0.694096}}],
    Line[{{0.758203, 0.674117, 0.694096},{0.751813, 0.707916, 0.735247}}],
    Line[{{0.751813, 0.707916, 0.735247},{0.749120, 0.758546, 0.749415}}],
    Line[{{0.749120, 0.758546, 0.749415},{0.753772, 0.804769, 0.723915}}],
    Line[{{0.753772, 0.804769, 0.723915},{0.760122, 0.833320, 0.678775}}],
    Line[{{0.760122, 0.833320, 0.678775},{0.765070, 0.849823, 0.627623}}],
    Line[{{0.765070, 0.849823, 0.627623},{0.768224, 0.858923, 0.574466}}],
    Line[{{0.768224, 0.858923, 0.574466},{0.769666, 0.862808, 0.520590}}],
    Line[{{0.769666, 0.862808, 0.520590},{0.769472, 0.862297, 0.466554}}],
    Line[{{0.769472, 0.862297, 0.466554},{0.767632, 0.857284, 0.412785}}],
    Line[{{0.767632, 0.857284, 0.412785},{0.764055, 0.846691, 0.359937}}],
    Line[{{0.764055, 0.846691, 0.359937},{0.758693, 0.827862, 0.309659}}],
    Line[{{0.758693, 0.827862, 0.309659},{0.752277, 0.795437, 0.267362}}],
    Line[{{0.752277, 0.795437, 0.267362},{0.749031, 0.745706, 0.250150}}],
    Line[{{0.749031, 0.745706, 0.250150},{0.753262, 0.698210, 0.273053}}],
    Line[{{0.753262, 0.698210, 0.273053},{0.759654, 0.668415, 0.317337}}],
    Line[{{0.759654, 0.668415, 0.317337},{0.764743, 0.651169, 0.368224}}],
    Line[{{0.764743, 0.651169, 0.368224},{0.768036, 0.641586, 0.421284}}],
    Line[{{0.768036, 0.641586, 0.421284},{0.769611, 0.637331, 0.475128}}],
    Line[{{0.769611, 0.637331, 0.475128},{0.769546, 0.637502, 0.529165}}],
    Line[{{0.769546, 0.637502, 0.529165},{0.767839, 0.642133, 0.582973}}],
    Line[{{0.767839, 0.642133, 0.582973},{0.764404, 0.652214, 0.635931}}],
    Line[{{0.764404, 0.652214, 0.635931},{0.759177, 0.670235, 0.686527}}],
    Line[{{0.759177, 0.670235, 0.686527},{0.752761, 0.701322, 0.729867}}],
    Line[{{0.752761, 0.701322, 0.729867},{0.749000, 0.750000, 0.750000}}],
    Line[{{0.749000, 0.750000, 0.750000},{0.752761, 0.798678, 0.729867}}],
    Line[{{0.752761, 0.798678, 0.729867},{0.759177, 0.829765, 0.686527}}],
    Line[{{0.759177, 0.829765, 0.686527},{0.764404, 0.847786, 0.635931}}],
    Line[{{0.764404, 0.847786, 0.635931},{0.767839, 0.857867, 0.582973}}],
    Line[{{0.767839, 0.857867, 0.582973},{0.769546, 0.862498, 0.529165}}],
    Line[{{0.769546, 0.862498, 0.529165},{0.769611, 0.862669, 0.475128}}],
    Line[{{0.769611, 0.862669, 0.475128},{0.768036, 0.858414, 0.421284}}],
    Line[{{0.768036, 0.858414, 0.421284},{0.764743, 0.848831, 0.368223}}],
    Line[{{0.764743, 0.848831, 0.368223},{0.759654, 0.831585, 0.317337}}],
    Line[{{0.759654, 0.831585, 0.317337},{0.753262, 0.801790, 0.273053}}],
    Line[{{0.753262, 0.801790, 0.273053},{0.749031, 0.754294, 0.250150}}],
    Line[{{0.749031, 0.754294, 0.250150},{0.752277, 0.704563, 0.267362}}],
    Line[{{0.752277, 0.704563, 0.267362},{0.758693, 0.672138, 0.309659}}],
    Line[{{0.758693, 0.672138, 0.309659},{0.764055, 0.653309, 0.359937}}],
    Line[{{0.764055, 0.653309, 0.359937},{0.767632, 0.642716, 0.412785}}],
    Line[{{0.767632, 0.642716, 0.412785},{0.769472, 0.637703, 0.466554}}],
    Line[{{0.769472, 0.637703, 0.466554},{0.769666, 0.637192, 0.520590}}],
    Line[{{0.769666, 0.637192, 0.520590},{0.768224, 0.641077, 0.574466}}],
    Line[{{0.768224, 0.641077, 0.574466},{0.765070, 0.650177, 0.627623}}],
    Line[{{0.765070, 0.650177, 0.627623},{0.760122, 0.666680, 0.678776}}],
    Line[{{0.760122, 0.666680, 0.678776},{0.753772, 0.695230, 0.723915}}],
    Line[{{0.753772, 0.695230, 0.723915},{0.749120, 0.741454, 0.749415}}],
    Line[{{0.749120, 0.741454, 0.749415},{0.751813, 0.792084, 0.735248}}],
    Line[{{0.751813, 0.792084, 0.735248},{0.758203, 0.825883, 0.694097}}],
    Line[{{0.758203, 0.825883, 0.694097},{0.763697, 0.845550, 0.644163}}],
    Line[{{0.763697, 0.845550, 0.644163},{0.767416, 0.856671, 0.591437}}],
    Line[{{0.767416, 0.856671, 0.591437},{0.769389, 0.862070, 0.537710}}],
    Line[{{0.769389, 0.862070, 0.537710},{0.769711, 0.862922, 0.483680}}],
    Line[{{0.769711, 0.862922, 0.483680},{0.768400, 0.859401, 0.429775}}],
    Line[{{0.768400, 0.859401, 0.429775},{0.765386, 0.850769, 0.376530}}],
    Line[{{0.765386, 0.850769, 0.376530},{0.760578, 0.834979, 0.325132}}],
    Line[{{0.760578, 0.834979, 0.325132},{0.754286, 0.807623, 0.279219}}],
    Line[{{0.754286, 0.807623, 0.279219},{0.749264, 0.762750, 0.251298}}],
    Line[{{0.749264, 0.762750, 0.251298},{0.751370, 0.711381, 0.262311}}],
    Line[{{0.751370, 0.711381, 0.262311},{0.757707, 0.676176, 0.302208}}],
    Line[{{0.757707, 0.676176, 0.302208},{0.763328, 0.655638, 0.351763}}],
    Line[{{0.763328, 0.655638, 0.351763},{0.767189, 0.643976, 0.404359}}],
    Line[{{0.232812, 0.143978, 0.595658},{0.236674, 0.155642, 0.648254}}],
    Line[{{0.236674, 0.155642, 0.648254},{0.242296, 0.176184, 0.697808}}],
    Line[{{0.242296, 0.176184, 0.697808},{0.248632, 0.211394, 0.737698}}],
    Line[{{0.248632, 0.211394, 0.737698},{0.250737, 0.262763, 0.748702}}],
    Line[{{0.250737, 0.262763, 0.748702},{0.245713, 0.307632, 0.720772}}],
    Line[{{0.245713, 0.307632, 0.720772},{0.239422, 0.334984, 0.674857}}],
    Line[{{0.239422, 0.334984, 0.674857},{0.234614, 0.350772, 0.623458}}],
    Line[{{0.234614, 0.350772, 0.623458},{0.231600, 0.359402, 0.570213}}],
    Line[{{0.231600, 0.359402, 0.570213},{0.230289, 0.362923, 0.516308}}],
    Line[{{0.230289, 0.362923, 0.516308},{0.230611, 0.362069, 0.462278}}],
    Line[{{0.230611, 0.362069, 0.462278},{0.232585, 0.356669, 0.408551}}],
    Line[{{0.232585, 0.356669, 0.408551},{0.236305, 0.345547, 0.355825}}],
    Line[{{0.236305, 0.345547, 0.355825},{0.241799, 0.325879, 0.305893}}],
    Line[{{0.241799, 0.325879, 0.305893},{0.248189, 0.292077, 0.264743}}],
    Line[{{0.248189, 0.292077, 0.264743},{0.250880, 0.241442, 0.250586}}],
    Line[{{0.250880, 0.241442, 0.250586},{0.246228, 0.195223, 0.276090}}],
    Line[{{0.246228, 0.195223, 0.276090},{0.239878, 0.166675, 0.321230}}],
    Line[{{0.239878, 0.166675, 0.321230},{0.234929, 0.150174, 0.372385}}],
    Line[{{0.234929, 0.150174, 0.372385},{0.231776, 0.141074, 0.425541}}],
    Line[{{0.231776, 0.141074, 0.425541},{0.230334, 0.137189, 0.479417}}],
    Line[{{0.230334, 0.137189, 0.479417},{0.230528, 0.137702, 0.533451}}],
    Line[{{0.230528, 0.137702, 0.533451},{0.232368, 0.142715, 0.587220}}],
    Line[{{0.232368, 0.142715, 0.587220},{0.235945, 0.153310, 0.640066}}],
    Line[{{0.235945, 0.153310, 0.640066},{0.241307, 0.172139, 0.690344}}],
    Line[{{0.241307, 0.172139, 0.690344},{0.247723, 0.204564, 0.732641}}],
    Line[{{0.247723, 0.204564, 0.732641},{0.250969, 0.254295, 0.749850}}],
    Line[{{0.250969, 0.254295, 0.749850},{0.246737, 0.301793, 0.726945}}],
    Line[{{0.246737, 0.301793, 0.726945},{0.240345, 0.331585, 0.682662}}],
    Line[{{0.240345, 0.331585, 0.682662},{0.235257, 0.348831, 0.631776}}],
    Line[{{0.235257, 0.348831, 0.631776},{0.231963, 0.358415, 0.578715}}],
    Line[{{0.231963, 0.358415, 0.578715},{0.230389, 0.362670, 0.524872}}],
    Line[{{0.230389, 0.362670, 0.524872},{0.230454, 0.362498, 0.470835}}],
    Line[{{0.230454, 0.362498, 0.470835},{0.232161, 0.357867, 0.417027}}],
    Line[{{0.232161, 0.357867, 0.417027},{0.235596, 0.347786, 0.364069}}],
    Line[{{0.235596, 0.347786, 0.364069},{0.240823, 0.329765, 0.313472}}],
    Line[{{0.240823, 0.329765, 0.313472},{0.247239, 0.298677, 0.270132}}],
    Line[{{0.247239, 0.298677, 0.270132},{0.251000, 0.250000, 0.250000}}],
    Line[{{0.251000, 0.250000, 0.250000},{0.247239, 0.201323, 0.270132}}],
    Line[{{0.247239, 0.201323, 0.270132},{0.240823, 0.170234, 0.313472}}],
    Line[{{0.240823, 0.170234, 0.313472},{0.235596, 0.152214, 0.364069}}],
    Line[{{0.235596, 0.152214, 0.364069},{0.232161, 0.142133, 0.417027}}],
    Line[{{0.232161, 0.142133, 0.417027},{0.230454, 0.137502, 0.470835}}],
    Line[{{0.230454, 0.137502, 0.470835},{0.230389, 0.137330, 0.524872}}],
    Line[{{0.230389, 0.137330, 0.524872},{0.231963, 0.141585, 0.578716}}],
    Line[{{0.231963, 0.141585, 0.578716},{0.235257, 0.151169, 0.631776}}],
    Line[{{0.235257, 0.151169, 0.631776},{0.240346, 0.168415, 0.682663}}],
    Line[{{0.240346, 0.168415, 0.682663},{0.246738, 0.198209, 0.726946}}],
    Line[{{0.246738, 0.198209, 0.726946},{0.250969, 0.245706, 0.749849}}],
    Line[{{0.250969, 0.245706, 0.749849},{0.247723, 0.295437, 0.732640}}],
    Line[{{0.247723, 0.295437, 0.732640},{0.241307, 0.327862, 0.690343}}],
    Line[{{0.241307, 0.327862, 0.690343},{0.235945, 0.346691, 0.640065}}],
    Line[{{0.235945, 0.346691, 0.640065},{0.232368, 0.357285, 0.587218}}],
    Line[{{0.232368, 0.357285, 0.587218},{0.230528, 0.362298, 0.533450}}],
    Line[{{0.230528, 0.362298, 0.533450},{0.230334, 0.362811, 0.479415}}],
    Line[{{0.230334, 0.362811, 0.479415},{0.231776, 0.358926, 0.425539}}],
    Line[{{0.231776, 0.358926, 0.425539},{0.234930, 0.349826, 0.372383}}],
    Line[{{0.234930, 0.349826, 0.372383},{0.239878, 0.333325, 0.321229}}],
    Line[{{0.239878, 0.333325, 0.321229},{0.246229, 0.304776, 0.276089}}],
    Line[{{0.246229, 0.304776, 0.276089},{0.250881, 0.258556, 0.250585}}],
    Line[{{0.250881, 0.258556, 0.250585},{0.248189, 0.207921, 0.264744}}],
    Line[{{0.248189, 0.207921, 0.264744},{0.241799, 0.174120, 0.305895}}],
    Line[{{0.241799, 0.174120, 0.305895},{0.236305, 0.154452, 0.355826}}],
    Line[{{0.236305, 0.154452, 0.355826},{0.232586, 0.143330, 0.408552}}],
    Line[{{0.232586, 0.143330, 0.408552},{0.230612, 0.137929, 0.462277}}],
    Line[{{0.230612, 0.137929, 0.462277},{0.230290, 0.137075, 0.516307}}],
    Line[{{0.230290, 0.137075, 0.516307},{0.231601, 0.140596, 0.570211}}],
    Line[{{0.231601, 0.140596, 0.570211},{0.234614, 0.149226, 0.623455}}],
    Line[{{0.234614, 0.149226, 0.623455},{0.239422, 0.165014, 0.674853}}],
    Line[{{0.239422, 0.165014, 0.674853},{0.245713, 0.192367, 0.720768}}],
    Line[{{0.245713, 0.192367, 0.720768},{0.250737, 0.237233, 0.748698}}],
    Line[{{0.250737, 0.237233, 0.748698},{0.248633, 0.288606, 0.737700}}],
    Line[{{0.248633, 0.288606, 0.737700},{0.242296, 0.323815, 0.697808}}],
    Line[{{0.242296, 0.323815, 0.697808},{0.236675, 0.344356, 0.648256}}],
    Line[{{0.236675, 0.344356, 0.648256},{0.232814, 0.356021, 0.595661}}],
    Line[{{0.251000, 0.249999, 0.499998},{0.251000, 0.249999, 0.499999}}],
    Line[{{0.251000, 0.249999, 0.499999},{0.251000, 0.249999, 0.500001}}],
    Line[{{0.251000, 0.249999, 0.500001},{0.251000, 0.249999, 0.500003}}],
    Line[{{0.251000, 0.249999, 0.500003},{0.251000, 0.250000, 0.500003}}],
    Line[{{0.251000, 0.250000, 0.500003},{0.251000, 0.250001, 0.500003}}],
    Line[{{0.251000, 0.250001, 0.500003},{0.251000, 0.250001, 0.500001}}],
    Line[{{0.251000, 0.250001, 0.500001},{0.251000, 0.250001, 0.500000}}],
    Line[{{0.251000, 0.250001, 0.500000},{0.251000, 0.250001, 0.499998}}],
    Line[{{0.251000, 0.250001, 0.499998},{0.251000, 0.250000, 0.499997}}],
    Line[{{0.251000, 0.250000, 0.499997},{0.251000, 0.250000, 0.499997}}],
    Line[{{0.251000, 0.250000, 0.499997},{0.251000, 0.250000, 0.499999}}],
    Line[{{0.251000, 0.250000, 0.499999},{0.251000, 0.250000, 0.499999}}],
    Line[{{0.251000, 0.250000, 0.499999},{0.251000, 0.249999, 0.500003}}],
    Line[{{0.251000, 0.249999, 0.500003},{0.251000, 0.250005, 0.499995}}],
    Line[{{0.251000, 0.250005, 0.499995},{0.251000, 0.249996, 0.500014}}],
    Line[{{0.251000, 0.249996, 0.500014},{0.251000, 0.250001, 0.499977}}],
    Line[{{0.251000, 0.250001, 0.499977},{0.251000, 0.249995, 0.500019}}],
    Line[{{0.251000, 0.249995, 0.500019},{0.251000, 0.250008, 0.500018}}],
    Line[{{0.251000, 0.250008, 0.500018},{0.251000, 0.249997, 0.499994}}],
    Line[{{0.251000, 0.249997, 0.499994},{0.251000, 0.250003, 0.500009}}],
    Line[{{0.251000, 0.250003, 0.500009},{0.251000, 0.249992, 0.499997}}],
    Line[{{0.251000, 0.249992, 0.499997},{0.251000, 0.249991, 0.499993}}],
    Line[{{0.251000, 0.249991, 0.499993},{0.251000, 0.250006, 0.500017}}],
    Line[{{0.251000, 0.250006, 0.500017},{0.251000, 0.250010, 0.499996}}],
    Line[{{0.251000, 0.250010, 0.499996},{0.251000, 0.250012, 0.499992}}],
    Line[{{0.251000, 0.250012, 0.499992},{0.251000, 0.249986, 0.500009}}],
    Line[{{0.251000, 0.249986, 0.500009},{0.251000, 0.249998, 0.500035}}],
    Line[{{0.251000, 0.249998, 0.500035},{0.251000, 0.250009, 0.500029}}],
    Line[{{0.251000, 0.250009, 0.500029},{0.251000, 0.250015, 0.500011}}],
    Line[{{0.251000, 0.250015, 0.500011},{0.251000, 0.250012, 0.499977}}],
    Line[{{0.251000, 0.250012, 0.499977},{0.251000, 0.250012, 0.499973}}],
    Line[{{0.251000, 0.250012, 0.499973},{0.251000, 0.250014, 0.499975}}],
    Line[{{0.251000, 0.250014, 0.499975},{0.251000, 0.250019, 0.500005}}],
    Line[{{0.251000, 0.250019, 0.500005},{0.251000, 0.250001, 0.500041}}],
    Line[{{0.251000, 0.250001, 0.500041},{0.251000, 0.249982, 0.500010}}],
    Line[{{0.251000, 0.249982, 0.500010},{0.251000, 0.249985, 0.499973}}],
    Line[{{0.251000, 0.249985, 0.499973},{0.251000, 0.250014, 0.499972}}],
    Line[{{0.251000, 0.250014, 0.499972},{0.251000, 0.250019, 0.500003}}],
    Line[{{0.251000, 0.250019, 0.500003},{0.251000, 0.250005, 0.500039}}],
    Line[{{0.251000, 0.250005, 0.500039},{0.251000, 0.249989, 0.500029}}],
    Line[{{0.251000, 0.249989, 0.500029},{0.251000, 0.249982, 0.500005}}],
    Line[{{0.251000, 0.249982, 0.500005},{0.251000, 0.249991, 0.499960}}],
    Line[{{0.251000, 0.249991, 0.499960},{0.251000, 0.250020, 0.500007}}],
    Line[{{0.251000, 0.250020, 0.500007},{0.251000, 0.249985, 0.500030}}],
    Line[{{0.251000, 0.249985, 0.500030},{0.251000, 0.249985, 0.499973}}],
    Line[{{0.251000, 0.249985, 0.499973},{0.251000, 0.250017, 0.499977}}],
    Line[{{0.251000, 0.250017, 0.499977},{0.251000, 0.250014, 0.500030}}],
    Line[{{0.251000, 0.250014, 0.500030},{0.251000, 0.249981, 0.500016}}],
    Line[{{0.251000, 0.249981, 0.500016},{0.251000, 0.249995, 0.499959}}],
    Line[{{0.251000, 0.249995, 0.499959},{0.251000, 0.250020, 0.500019}}],
    Line[{{0.251000, 0.250020, 0.500019},{0.251000, 0.249976, 0.499994}}],
    Line[{{0.251000, 0.249976, 0.499994},{0.251000, 0.250021, 0.500033}}],
    Line[{{0.251000, 0.250021, 0.500033},{0.251000, 0.250016, 0.499952}}],
    Line[{{0.251000, 0.250016, 0.499952},{0.251000, 0.249975, 0.499969}}],
    Line[{{0.251000, 0.249975, 0.499969},{0.251000, 0.249973, 0.500023}}],
    Line[{{0.251000, 0.249973, 0.500023},{0.251000, 0.249997, 0.500065}}],
    Line[{{0.251000, 0.249997, 0.500065},{0.251000, 0.250024, 0.500048}}],
    Line[{{0.251000, 0.250024, 0.500048},{0.251000, 0.250030, 0.500022}}],
    Line[{{0.251000, 0.250030, 0.500022},{0.251000, 0.250033, 0.500002}}],
    Line[{{0.251000, 0.250033, 0.500002},{0.251000, 0.250032, 0.499985}}],
    Line[{{0.251000, 0.250032, 0.499985},{0.251000, 0.250030, 0.499969}}],
    Line[{{0.251000, 0.250030, 0.499969},{0.251000, 0.250029, 0.499964}}],
    Line[{{0.251000, 0.250029, 0.499964},{0.251000, 0.250031, 0.499965}}],
    Line[{{0.251000, 0.250031, 0.499965},{0.251000, 0.250036, 0.499983}}],
    Line[{{0.251000, 0.250036, 0.499983},{0.251000, 0.250037, 0.500024}}],
    Line[{{0.251000, 0.250037, 0.500024},{0.251000, 0.250022, 0.500071}}],
    Line[{{0.251000, 0.250022, 0.500071},{0.251000, 0.249977, 0.500072}}],
    Line[{{0.251000, 0.249977, 0.500072},{0.251000, 0.249959, 0.500008}}],
    Line[{{0.251000, 0.249959, 0.500008},{0.251000, 0.249972, 0.499931}}],
    Line[{{0.251000, 0.249972, 0.499931},{0.251000, 0.250031, 0.499936}}],
    Line[{{0.251000, 0.250031, 0.499936},{0.251000, 0.250041, 0.500026}}],
    Line[{{0.251000, 0.250041, 0.500026},{0.251000, 0.249994, 0.500090}}],
    Line[{{0.251000, 0.249994, 0.500090},{0.251000, 0.249964, 0.500038}}],
    Line[{{0.251000, 0.249964, 0.500038},{0.251000, 0.249961, 0.499984}}],
    Line[{{0.232812, 0.356024, 0.404339},{0.236674, 0.344359, 0.351743}}],
    Line[{{0.236674, 0.344359, 0.351743},{0.242295, 0.323819, 0.302189}}],
    Line[{{0.242295, 0.323819, 0.302189},{0.248632, 0.288609, 0.262298}}],
    Line[{{0.248632, 0.288609, 0.262298},{0.250737, 0.237238, 0.251294}}],
    Line[{{0.250737, 0.237238, 0.251294},{0.245713, 0.192368, 0.279221}}],
    Line[{{0.245713, 0.192368, 0.279221},{0.239422, 0.165015, 0.325136}}],
    Line[{{0.239422, 0.165015, 0.325136},{0.234613, 0.149226, 0.376534}}],
    Line[{{0.234613, 0.149226, 0.376534},{0.231599, 0.140596, 0.429780}}],
    Line[{{0.231599, 0.140596, 0.429780},{0.230289, 0.137075, 0.483685}}],
    Line[{{0.230289, 0.137075, 0.483685},{0.230611, 0.137928, 0.537715}}],
    Line[{{0.230611, 0.137928, 0.537715},{0.232584, 0.143327, 0.591442}}],
    Line[{{0.232584, 0.143327, 0.591442},{0.236304, 0.154448, 0.644168}}],
    Line[{{0.236304, 0.154448, 0.644168},{0.241798, 0.174115, 0.694101}}],
    Line[{{0.241798, 0.174115, 0.694101},{0.248188, 0.207914, 0.735253}}],
    Line[{{0.248188, 0.207914, 0.735253},{0.250880, 0.258546, 0.749418}}],
    Line[{{0.250880, 0.258546, 0.749418},{0.246229, 0.304771, 0.723920}}],
    Line[{{0.246229, 0.304771, 0.723920},{0.239878, 0.333321, 0.678781}}],
    Line[{{0.239878, 0.333321, 0.678781},{0.234929, 0.349824, 0.627628}}],
    Line[{{0.234929, 0.349824, 0.627628},{0.231776, 0.358924, 0.574471}}],
    Line[{{0.231776, 0.358924, 0.574471},{0.230333, 0.362810, 0.520594}}],
    Line[{{0.230333, 0.362810, 0.520594},{0.230527, 0.362298, 0.466559}}],
    Line[{{0.230527, 0.362298, 0.466559},{0.232367, 0.357287, 0.412790}}],
    Line[{{0.232367, 0.357287, 0.412790},{0.235944, 0.346694, 0.359942}}],
    Line[{{0.235944, 0.346694, 0.359942},{0.241306, 0.327866, 0.309662}}],
    Line[{{0.241306, 0.327866, 0.309662},{0.247722, 0.295442, 0.267364}}],
    Line[{{0.247722, 0.295442, 0.267364},{0.250969, 0.245713, 0.250148}}],
    Line[{{0.250969, 0.245713, 0.250148},{0.246738, 0.198212, 0.273048}}],
    Line[{{0.246738, 0.198212, 0.273048},{0.240346, 0.168417, 0.317331}}],
    Line[{{0.240346, 0.168417, 0.317331},{0.235257, 0.151171, 0.368218}}],
    Line[{{0.235257, 0.151171, 0.368218},{0.231963, 0.141587, 0.421279}}],
    Line[{{0.231963, 0.141587, 0.421279},{0.230389, 0.137332, 0.475123}}],
    Line[{{0.230389, 0.137332, 0.475123},{0.230453, 0.137502, 0.529161}}],
    Line[{{0.230453, 0.137502, 0.529161},{0.232160, 0.142133, 0.582970}}],
    Line[{{0.232160, 0.142133, 0.582970},{0.235596, 0.152213, 0.635929}}],
    Line[{{0.235596, 0.152213, 0.635929},{0.240823, 0.170233, 0.686527}}],
    Line[{{0.240823, 0.170233, 0.686527},{0.247239, 0.201322, 0.729867}}],
    Line[{{0.247239, 0.201322, 0.729867},{0.251000, 0.250000, 0.750000}}],
    Line[{{0.251000, 0.250000, 0.750000},{0.247239, 0.298678, 0.729867}}],
    Line[{{0.247239, 0.298678, 0.729867},{0.240823, 0.329765, 0.686527}}],
    Line[{{0.240823, 0.329765, 0.686527},{0.235596, 0.347786, 0.635931}}],
    Line[{{0.235596, 0.347786, 0.635931},{0.232161, 0.357867, 0.582972}}],
    Line[{{0.232161, 0.357867, 0.582972},{0.230454, 0.362498, 0.529164}}],
    Line[{{0.230454, 0.362498, 0.529164},{0.230389, 0.362670, 0.475127}}],
    Line[{{0.230389, 0.362670, 0.475127},{0.231964, 0.358414, 0.421284}}],
    Line[{{0.231964, 0.358414, 0.421284},{0.235257, 0.348830, 0.368224}}],
    Line[{{0.235257, 0.348830, 0.368224},{0.240345, 0.331584, 0.317338}}],
    Line[{{0.240345, 0.331584, 0.317338},{0.246738, 0.301790, 0.273054}}],
    Line[{{0.246738, 0.301790, 0.273054},{0.250969, 0.254293, 0.250151}}],
    Line[{{0.250969, 0.254293, 0.250151},{0.247723, 0.204562, 0.267362}}],
    Line[{{0.247723, 0.204562, 0.267362},{0.241307, 0.172137, 0.309659}}],
    Line[{{0.241307, 0.172137, 0.309659},{0.235945, 0.153309, 0.359937}}],
    Line[{{0.235945, 0.153309, 0.359937},{0.232368, 0.142715, 0.412784}}],
    Line[{{0.232368, 0.142715, 0.412784},{0.230528, 0.137702, 0.466553}}],
    Line[{{0.230528, 0.137702, 0.466553},{0.230335, 0.137190, 0.520587}}],
    Line[{{0.230335, 0.137190, 0.520587},{0.231777, 0.141074, 0.574463}}],
    Line[{{0.231777, 0.141074, 0.574463},{0.234930, 0.150175, 0.627619}}],
    Line[{{0.234930, 0.150175, 0.627619},{0.239879, 0.166677, 0.678773}}],
    Line[{{0.239879, 0.166677, 0.678773},{0.246228, 0.195226, 0.723912}}],
    Line[{{0.246228, 0.195226, 0.723912},{0.250881, 0.241447, 0.749415}}],
    Line[{{0.250881, 0.241447, 0.749415},{0.248189, 0.292081, 0.735254}}],
    Line[{{0.248189, 0.292081, 0.735254},{0.241799, 0.325881, 0.694103}}],
    Line[{{0.241799, 0.325881, 0.694103},{0.236305, 0.345549, 0.644172}}],
    Line[{{0.236305, 0.345549, 0.644172},{0.232586, 0.356670, 0.591446}}],
    Line[{{0.232586, 0.356670, 0.591446},{0.230612, 0.362071, 0.537721}}],
    Line[{{0.230612, 0.362071, 0.537721},{0.230290, 0.362925, 0.483691}}],
    Line[{{0.230290, 0.362925, 0.483691},{0.231601, 0.359405, 0.429786}}],
    Line[{{0.231601, 0.359405, 0.429786},{0.234614, 0.350772, 0.376543}}],
    Line[{{0.234614, 0.350772, 0.376543},{0.239422, 0.334985, 0.325145}}],
    Line[{{0.239422, 0.334985, 0.325145},{0.245714, 0.307631, 0.279229}}],
    Line[{{0.245714, 0.307631, 0.279229},{0.250737, 0.262765, 0.251301}}],
    Line[{{0.250737, 0.262765, 0.251301},{0.248633, 0.211393, 0.262301}}],
    Line[{{0.248633, 0.211393, 0.262301},{0.242296, 0.176185, 0.302194}}],
    Line[{{0.242296, 0.176185, 0.302194},{0.236675, 0.155644, 0.351746}}],
    Line[{{0.236675, 0.155644, 0.351746},{0.232813, 0.143979, 0.404341}}],
    Line[{{0.597867, 0.500000, 0.051621},{0.647985, 0.500000, 0.071436}}],
    Line[{{0.647985, 0.500000, 0.071436},{0.689419, 0.500000, 0.105732}}],
    Line[{{0.689419, 0.500000, 0.105732},{0.718300, 0.500000, 0.151236}}],
    Line[{{0.718300, 0.500000, 0.151236},{0.737222, 0.500000, 0.201808}}],
    Line[{{0.737222, 0.500000, 0.201808},{0.749851, 0.500000, 0.254345}}],
    Line[{{0.749851, 0.500000, 0.254345},{0.758431, 0.500000, 0.307704}}],
    Line[{{0.758431, 0.500000, 0.307704},{0.764177, 0.500000, 0.361447}}],
    Line[{{0.764177, 0.500000, 0.361447},{0.767754, 0.500000, 0.415379}}],
    Line[{{0.767754, 0.500000, 0.415379},{0.769517, 0.500000, 0.469403}}],
    Line[{{0.769517, 0.500000, 0.469403},{0.769625, 0.500000, 0.523455}}],
    Line[{{0.769625, 0.500000, 0.523455},{0.768087, 0.500000, 0.577485}}],
    Line[{{0.768087, 0.500000, 0.577485},{0.764766, 0.500000, 0.631434}}],
    Line[{{0.764766, 0.500000, 0.631434},{0.759336, 0.500000, 0.685210}}],
    Line[{{0.759336, 0.500000, 0.685210},{0.751187, 0.500000, 0.738639}}],
    Line[{{0.751187, 0.500000, 0.738639},{0.739194, 0.500000, 0.791328}}],
    Line[{{0.739194, 0.500000, 0.791328},{0.721283, 0.500000, 0.842278}}],
    Line[{{0.721283, 0.500000, 0.842278},{0.693951, 0.500000, 0.888750}}],
    Line[{{0.693951, 0.500000, 0.888750},{0.654106, 0.500000, 0.924884}}],
    Line[{{0.654106, 0.500000, 0.924884},{0.604754, 0.500000, 0.946490}}],
    Line[{{0.604754, 0.500000, 0.946490},{0.551734, 0.500000, 0.956672}}],
    Line[{{0.551734, 0.500000, 0.956672},{0.497783, 0.500000, 0.959464}}],
    Line[{{0.497783, 0.500000, 0.959464},{0.443863, 0.500000, 0.956153}}],
    Line[{{0.443863, 0.500000, 0.956153},{0.390999, 0.500000, 0.945218}}],
    Line[{{0.390999, 0.500000, 0.945218},{0.342178, 0.500000, 0.922464}}],
    Line[{{0.342178, 0.500000, 0.922464},{0.303353, 0.500000, 0.885229}}],
    Line[{{0.303353, 0.500000, 0.885229},{0.276952, 0.500000, 0.838210}}],
    Line[{{0.276952, 0.500000, 0.838210},{0.259638, 0.500000, 0.787053}}],
    Line[{{0.259638, 0.500000, 0.787053},{0.248020, 0.500000, 0.734280}}],
    Line[{{0.248020, 0.500000, 0.734280},{0.240126, 0.500000, 0.680814}}],
    Line[{{0.240126, 0.500000, 0.680814},{0.234886, 0.500000, 0.627019}}],
    Line[{{0.234886, 0.500000, 0.627019},{0.231719, 0.500000, 0.573061}}],
    Line[{{0.231719, 0.500000, 0.573061},{0.230319, 0.500000, 0.519027}}],
    Line[{{0.230319, 0.500000, 0.519027},{0.230560, 0.500000, 0.464976}}],
    Line[{{0.230560, 0.500000, 0.464976},{0.232463, 0.500000, 0.410958}}],
    Line[{{0.232463, 0.500000, 0.410958},{0.236201, 0.500000, 0.357036}}],
    Line[{{0.236201, 0.500000, 0.357036},{0.242148, 0.500000, 0.303315}}],
    Line[{{0.242148, 0.500000, 0.303315},{0.251000, 0.500000, 0.250000}}],
    Line[{{0.251000, 0.500000, 0.250000},{0.264044, 0.500000, 0.197566}}],
    Line[{{0.264044, 0.500000, 0.197566},{0.283627, 0.500000, 0.147250}}],
    Line[{{0.283627, 0.500000, 0.147250},{0.313499, 0.500000, 0.102405}}],
    Line[{{0.313499, 0.500000, 0.102405},{0.355877, 0.500000, 0.069283}}],
    Line[{{0.355877, 0.500000, 0.069283},{0.406420, 0.500000, 0.050539}}],
    Line[{{0.406420, 0.500000, 0.050539},{0.459772, 0.500000, 0.042193}}],
    Line[{{0.459772, 0.500000, 0.042193},{0.513777, 0.500000, 0.040719}}],
    Line[{{0.513777, 0.500000, 0.040719},{0.567589, 0.500000, 0.045434}}],
    Line[{{0.567589, 0.500000, 0.045434},{0.619952, 0.500000, 0.058479}}],
    Line[{{0.619952, 0.500000, 0.058479},{0.667168, 0.500000, 0.084329}}],
    Line[{{0.667168, 0.500000, 0.084329},{0.703272, 0.500000, 0.124236}}],
    Line[{{0.703272, 0.500000, 0.124236},{0.727381, 0.500000, 0.172501}}],
    Line[{{0.727381, 0.500000, 0.172501},{0.743243, 0.500000, 0.224137}}],
    Line[{{0.743243, 0.500000, 0.224137},{0.753937, 0.500000, 0.277109}}],
    Line[{{0.753937, 0.500000, 0.277109},{0.761195, 0.500000, 0.330666}}],
    Line[{{0.761195, 0.500000, 0.330666},{0.765953, 0.500000, 0.384507}}],
    Line[{{0.765953, 0.500000, 0.384507},{0.768724, 0.500000, 0.438487}}],
    Line[{{0.768724, 0.500000, 0.438487},{0.769768, 0.500000, 0.492529}}],
    Line[{{0.769768, 0.500000, 0.492529},{0.769179, 0.500000, 0.546577}}],
    Line[{{0.769179, 0.500000, 0.546577},{0.766904, 0.500000, 0.600581}}],
    Line[{{0.766904, 0.500000, 0.600581},{0.762731, 0.500000, 0.654470}}],
    Line[{{0.762731, 0.500000, 0.654470},{0.756235, 0.500000, 0.708126}}],
    Line[{{0.756235, 0.500000, 0.708126},{0.746618, 0.500000, 0.761305}}],
    Line[{{0.746618, 0.500000, 0.761305},{0.732423, 0.500000, 0.813433}}],
    Line[{{0.732423, 0.500000, 0.813433},{0.710991, 0.500000, 0.862970}}],
    Line[{{0.710991, 0.500000, 0.862970},{0.678448, 0.500000, 0.905874}}],
    Line[{{0.678448, 0.500000, 0.905874},{0.633772, 0.500000, 0.935847}}],
    Line[{{0.633772, 0.500000, 0.935847},{0.582298, 0.500000, 0.951954}}],
    Line[{{0.582298, 0.500000, 0.951954},{0.528702, 0.500000, 0.958632}}],
    Line[{{0.528702, 0.500000, 0.958632},{0.474677, 0.500000, 0.958819}}],
    Line[{{0.474677, 0.500000, 0.958819},{0.421023, 0.500000, 0.952604}}],
    Line[{{0.421023, 0.500000, 0.952604},{0.369319, 0.500000, 0.937226}}],
    Line[{{0.369319, 0.500000, 0.937226},{0.324021, 0.500000, 0.908191}}],
    Line[{{0.324021, 0.500000, 0.908191},{0.290676, 0.500000, 0.865917}}],
    Line[{{0.290676, 0.500000, 0.865917},{0.268664, 0.500000, 0.816638}}],
    Line[{{0.268664, 0.500000, 0.816638},{0.254112, 0.500000, 0.764608}}],
    Line[{{0.254112, 0.500000, 0.764608},{0.244264, 0.500000, 0.711470}}],
    Line[{{0.293902, 0.500000, 0.187781},{0.318457, 0.500000, 0.139737}}],
    Line[{{0.318457, 0.500000, 0.139737},{0.354576, 0.500000, 0.099819}}],
    Line[{{0.354576, 0.500000, 0.099819},{0.401557, 0.500000, 0.073541}}],
    Line[{{0.401557, 0.500000, 0.073541},{0.453931, 0.500000, 0.060614}}],
    Line[{{0.453931, 0.500000, 0.060614},{0.507840, 0.500000, 0.057564}}],
    Line[{{0.507840, 0.500000, 0.057564},{0.561532, 0.500000, 0.063214}}],
    Line[{{0.561532, 0.500000, 0.063214},{0.612882, 0.500000, 0.079647}}],
    Line[{{0.612882, 0.500000, 0.079647},{0.657189, 0.500000, 0.110182}}],
    Line[{{0.657189, 0.500000, 0.110182},{0.689727, 0.500000, 0.153112}}],
    Line[{{0.689727, 0.500000, 0.153112},{0.711530, 0.500000, 0.202491}}],
    Line[{{0.711530, 0.500000, 0.202491},{0.726111, 0.500000, 0.254512}}],
    Line[{{0.726111, 0.500000, 0.254512},{0.735988, 0.500000, 0.307643}}],
    Line[{{0.735988, 0.500000, 0.307643},{0.742581, 0.500000, 0.361286}}],
    Line[{{0.742581, 0.500000, 0.361286},{0.746677, 0.500000, 0.415181}}],
    Line[{{0.746677, 0.500000, 0.415181},{0.748695, 0.500000, 0.469194}}],
    Line[{{0.748695, 0.500000, 0.469194},{0.748825, 0.500000, 0.523245}}],
    Line[{{0.748825, 0.500000, 0.523245},{0.747079, 0.500000, 0.577269}}],
    Line[{{0.747079, 0.500000, 0.577269},{0.743294, 0.500000, 0.631186}}],
    Line[{{0.743294, 0.500000, 0.631186},{0.737088, 0.500000, 0.684877}}],
    Line[{{0.737088, 0.500000, 0.684877},{0.727740, 0.500000, 0.738106}}],
    Line[{{0.727740, 0.500000, 0.738106},{0.713937, 0.500000, 0.790344}}],
    Line[{{0.713937, 0.500000, 0.790344},{0.693345, 0.500000, 0.840252}}],
    Line[{{0.693345, 0.500000, 0.840252},{0.662493, 0.500000, 0.884432}}],
    Line[{{0.662493, 0.500000, 0.884432},{0.619649, 0.500000, 0.916979}}],
    Line[{{0.619649, 0.500000, 0.916979},{0.568929, 0.500000, 0.935220}}],
    Line[{{0.568929, 0.500000, 0.935220},{0.515399, 0.500000, 0.942182}}],
    Line[{{0.515399, 0.500000, 0.942182},{0.461434, 0.500000, 0.940345}}],
    Line[{{0.461434, 0.500000, 0.940345},{0.408685, 0.500000, 0.928988}}],
    Line[{{0.408685, 0.500000, 0.928988},{0.360600, 0.500000, 0.904751}}],
    Line[{{0.360600, 0.500000, 0.904751},{0.322761, 0.500000, 0.866478}}],
    Line[{{0.322761, 0.500000, 0.866478},{0.296767, 0.500000, 0.819218}}],
    Line[{{0.296767, 0.500000, 0.819218},{0.279467, 0.500000, 0.768053}}],
    Line[{{0.279467, 0.500000, 0.768053},{0.267794, 0.500000, 0.715291}}],
    Line[{{0.267794, 0.500000, 0.715291},{0.259914, 0.500000, 0.661823}}],
    Line[{{0.259914, 0.500000, 0.661823},{0.254812, 0.500000, 0.608015}}],
    Line[{{0.254812, 0.500000, 0.608015},{0.251933, 0.500000, 0.554042}}],
    Line[{{0.251933, 0.500000, 0.554042},{0.251000, 0.500000, 0.500000}}],
    Line[{{0.251000, 0.500000, 0.500000},{0.251933, 0.500000, 0.445958}}],
    Line[{{0.251933, 0.500000, 0.445958},{0.254812, 0.500000, 0.391985}}],
    Line[{{0.254812, 0.500000, 0.391985},{0.259914, 0.500000, 0.338177}}],
    Line[{{0.259914, 0.500000, 0.338177},{0.267794, 0.500000, 0.284709}}],
    Line[{{0.267794, 0.500000, 0.284709},{0.279467, 0.500000, 0.231947}}],
    Line[{{0.279467, 0.500000, 0.231947},{0.296767, 0.500000, 0.180782}}],
    Line[{{0.296767, 0.500000, 0.180782},{0.322762, 0.500000, 0.133521}}],
    Line[{{0.322762, 0.500000, 0.133521},{0.360602, 0.500000, 0.095251}}],
    Line[{{0.360602, 0.500000, 0.095251},{0.408687, 0.500000, 0.071014}}],
    Line[{{0.408687, 0.500000, 0.071014},{0.461436, 0.500000, 0.059657}}],
    Line[{{0.461436, 0.500000, 0.059657},{0.515401, 0.500000, 0.057820}}],
    Line[{{0.515401, 0.500000, 0.057820},{0.568932, 0.500000, 0.064784}}],
    Line[{{0.568932, 0.500000, 0.064784},{0.619648, 0.500000, 0.083029}}],
    Line[{{0.619648, 0.500000, 0.083029},{0.662493, 0.500000, 0.115574}}],
    Line[{{0.662493, 0.500000, 0.115574},{0.693344, 0.500000, 0.159757}}],
    Line[{{0.693344, 0.500000, 0.159757},{0.713933, 0.500000, 0.209667}}],
    Line[{{0.713933, 0.500000, 0.209667},{0.727735, 0.500000, 0.261903}}],
    Line[{{0.727735, 0.500000, 0.261903},{0.737083, 0.500000, 0.315132}}],
    Line[{{0.737083, 0.500000, 0.315132},{0.743289, 0.500000, 0.368822}}],
    Line[{{0.743289, 0.500000, 0.368822},{0.747075, 0.500000, 0.422740}}],
    Line[{{0.747075, 0.500000, 0.422740},{0.748821, 0.500000, 0.476763}}],
    Line[{{0.748821, 0.500000, 0.476763},{0.748692, 0.500000, 0.530814}}],
    Line[{{0.748692, 0.500000, 0.530814},{0.746674, 0.500000, 0.584827}}],
    Line[{{0.746674, 0.500000, 0.584827},{0.742578, 0.500000, 0.638722}}],
    Line[{{0.742578, 0.500000, 0.638722},{0.735983, 0.500000, 0.692364}}],
    Line[{{0.735983, 0.500000, 0.692364},{0.726105, 0.500000, 0.745495}}],
    Line[{{0.726105, 0.500000, 0.745495},{0.711521, 0.500000, 0.797514}}],
    Line[{{0.711521, 0.500000, 0.797514},{0.689717, 0.500000, 0.846892}}],
    Line[{{0.689717, 0.500000, 0.846892},{0.657177, 0.500000, 0.889820}}],
    Line[{{0.657177, 0.500000, 0.889820},{0.612869, 0.500000, 0.920354}}],
    Line[{{0.612869, 0.500000, 0.920354},{0.561517, 0.500000, 0.936783}}],
    Line[{{0.561517, 0.500000, 0.936783},{0.507825, 0.500000, 0.942430}}],
    Line[{{0.507825, 0.500000, 0.942430},{0.453917, 0.500000, 0.939377}}],
    Line[{{0.453917, 0.500000, 0.939377},{0.401546, 0.500000, 0.926445}}],
    Line[{{0.401546, 0.500000, 0.926445},{0.354568, 0.500000, 0.900164}}],
    Line[{{0.354568, 0.500000, 0.900164},{0.318452, 0.500000, 0.860242}}],
    Line[{{0.318452, 0.500000, 0.860242},{0.293902, 0.500000, 0.812195}}],
    Line[{{0.244262, 0.500000, 0.288536},{0.254110, 0.500000, 0.235398}}],
    Line[{{0.254110, 0.500000, 0.235398},{0.268661, 0.500000, 0.183368}}],
    Line[{{0.268661, 0.500000, 0.183368},{0.290672, 0.500000, 0.134088}}],
    Line[{{0.290672, 0.500000, 0.134088},{0.324016, 0.500000, 0.091814}}],
    Line[{{0.324016, 0.500000, 0.091814},{0.369312, 0.500000, 0.062777}}],
    Line[{{0.369312, 0.500000, 0.062777},{0.421015, 0.500000, 0.047397}}],
    Line[{{0.421015, 0.500000, 0.047397},{0.474669, 0.500000, 0.041180}}],
    Line[{{0.474669, 0.500000, 0.041180},{0.528695, 0.500000, 0.041366}}],
    Line[{{0.528695, 0.500000, 0.041366},{0.582292, 0.500000, 0.048044}}],
    Line[{{0.582292, 0.500000, 0.048044},{0.633765, 0.500000, 0.064151}}],
    Line[{{0.633765, 0.500000, 0.064151},{0.678444, 0.500000, 0.094118}}],
    Line[{{0.678444, 0.500000, 0.094118},{0.710989, 0.500000, 0.137021}}],
    Line[{{0.710989, 0.500000, 0.137021},{0.732423, 0.500000, 0.186559}}],
    Line[{{0.732423, 0.500000, 0.186559},{0.746617, 0.500000, 0.238688}}],
    Line[{{0.746617, 0.500000, 0.238688},{0.756233, 0.500000, 0.291867}}],
    Line[{{0.756233, 0.500000, 0.291867},{0.762730, 0.500000, 0.345524}}],
    Line[{{0.762730, 0.500000, 0.345524},{0.766901, 0.500000, 0.399413}}],
    Line[{{0.766901, 0.500000, 0.399413},{0.769177, 0.500000, 0.453417}}],
    Line[{{0.769177, 0.500000, 0.453417},{0.769767, 0.500000, 0.507466}}],
    Line[{{0.769767, 0.500000, 0.507466},{0.768723, 0.500000, 0.561508}}],
    Line[{{0.768723, 0.500000, 0.561508},{0.765953, 0.500000, 0.615488}}],
    Line[{{0.765953, 0.500000, 0.615488},{0.761195, 0.500000, 0.669329}}],
    Line[{{0.761195, 0.500000, 0.669329},{0.753939, 0.500000, 0.722888}}],
    Line[{{0.753939, 0.500000, 0.722888},{0.743245, 0.500000, 0.775860}}],
    Line[{{0.743245, 0.500000, 0.775860},{0.727382, 0.500000, 0.827497}}],
    Line[{{0.727382, 0.500000, 0.827497},{0.703273, 0.500000, 0.875761}}],
    Line[{{0.703273, 0.500000, 0.875761},{0.667171, 0.500000, 0.915669}}],
    Line[{{0.667171, 0.500000, 0.915669},{0.619954, 0.500000, 0.941521}}],
    Line[{{0.619954, 0.500000, 0.941521},{0.567590, 0.500000, 0.954565}}],
    Line[{{0.567590, 0.500000, 0.954565},{0.513778, 0.500000, 0.959280}}],
    Line[{{0.513778, 0.500000, 0.959280},{0.459773, 0.500000, 0.957807}}],
    Line[{{0.459773, 0.500000, 0.957807},{0.406421, 0.500000, 0.949461}}],
    Line[{{0.406421, 0.500000, 0.949461},{0.355877, 0.500000, 0.930718}}],
    Line[{{0.355877, 0.500000, 0.930718},{0.313497, 0.500000, 0.897595}}],
    Line[{{0.313497, 0.500000, 0.897595},{0.283626, 0.500000, 0.852750}}],
    Line[{{0.283626, 0.500000, 0.852750},{0.264043, 0.500000, 0.802434}}],
    Line[{{0.264043, 0.500000, 0.802434},{0.251000, 0.500000, 0.750000}}],
    Line[{{0.251000, 0.500000, 0.750000},{0.242148, 0.500000, 0.696685}}],
    Line[{{0.242148, 0.500000, 0.696685},{0.236202, 0.500000, 0.642964}}],
    Line[{{0.236202, 0.500000, 0.642964},{0.232463, 0.500000, 0.589042}}],
    Line[{{0.232463, 0.500000, 0.589042},{0.230560, 0.500000, 0.535024}}],
    Line[{{0.230560, 0.500000, 0.535024},{0.230319, 0.500000, 0.480973}}],
    Line[{{0.230319, 0.500000, 0.480973},{0.231720, 0.500000, 0.426939}}],
    Line[{{0.231720, 0.500000, 0.426939},{0.234886, 0.500000, 0.372981}}],
    Line[{{0.234886, 0.500000, 0.372981},{0.240126, 0.500000, 0.319186}}],
    Line[{{0.240126, 0.500000, 0.319186},{0.248021, 0.500000, 0.265719}}],
    Line[{{0.248021, 0.500000, 0.265719},{0.259639, 0.500000, 0.212947}}],
    Line[{{0.259639, 0.500000, 0.212947},{0.276953, 0.500000, 0.161788}}],
    Line[{{0.276953, 0.500000, 0.161788},{0.303354, 0.500000, 0.114770}}],
    Line[{{0.303354, 0.500000, 0.114770},{0.342179, 0.500000, 0.077537}}],
    Line[{{0.342179, 0.500000, 0.077537},{0.390998, 0.500000, 0.054781}}],
    Line[{{0.390998, 0.500000, 0.054781},{0.443862, 0.500000, 0.043845}}],
    Line[{{0.443862, 0.500000, 0.043845},{0.497783, 0.500000, 0.040535}}],
    Line[{{0.497783, 0.500000, 0.040535},{0.551734, 0.500000, 0.043326}}],
    Line[{{0.551734, 0.500000, 0.043326},{0.604753, 0.500000, 0.053509}}],
    Line[{{0.604753, 0.500000, 0.053509},{0.654103, 0.500000, 0.075113}}],
    Line[{{0.654103, 0.500000, 0.075113},{0.693950, 0.500000, 0.111245}}],
    Line[{{0.693950, 0.500000, 0.111245},{0.721283, 0.500000, 0.157718}}],
    Line[{{0.721283, 0.500000, 0.157718},{0.739192, 0.500000, 0.208667}}],
    Line[{{0.739192, 0.500000, 0.208667},{0.751186, 0.500000, 0.261356}}],
    Line[{{0.751186, 0.500000, 0.261356},{0.759336, 0.500000, 0.314784}}],
    Line[{{0.759336, 0.500000, 0.314784},{0.764765, 0.500000, 0.368561}}],
    Line[{{0.764765, 0.500000, 0.368561},{0.768086, 0.500000, 0.422510}}],
    Line[{{0.768086, 0.500000, 0.422510},{0.769625, 0.500000, 0.476540}}],
    Line[{{0.769625, 0.500000, 0.476540},{0.769517, 0.500000, 0.530592}}],
    Line[{{0.769517, 0.500000, 0.530592},{0.767755, 0.500000, 0.584615}}],
    Line[{{0.767755, 0.500000, 0.584615},{0.764177, 0.500000, 0.638548}}],
    Line[{{0.764177, 0.500000, 0.638548},{0.758429, 0.500000, 0.692290}}],
    Line[{{0.758429, 0.500000, 0.692290},{0.749849, 0.500000, 0.745649}}],
    Line[{{0.749849, 0.500000, 0.745649},{0.737219, 0.500000, 0.798185}}],
    Line[{{0.737219, 0.500000, 0.798185},{0.718296, 0.500000, 0.848757}}],
    Line[{{0.718296, 0.500000, 0.848757},{0.689419, 0.500000, 0.894260}}],
    Line[{{0.689419, 0.500000, 0.894260},{0.647988, 0.500000, 0.928560}}],
    Line[{{0.647988, 0.500000, 0.928560},{0.597866, 0.500000, 0.948375}}],
    Line[{{0.232812, 0.856022, 0.595651},{0.236673, 0.844358, 0.648247}}],
    Line[{{0.236673, 0.844358, 0.648247},{0.242295, 0.823818, 0.697801}}],
    Line[{{0.242295, 0.823818, 0.697801},{0.248630, 0.788610, 0.737693}}],
    Line[{{0.248630, 0.788610, 0.737693},{0.250736, 0.737241, 0.748700}}],
    Line[{{0.250736, 0.737241, 0.748700},{0.245713, 0.692372, 0.720774}}],
    Line[{{0.245713, 0.692372, 0.720774},{0.239422, 0.665018, 0.674859}}],
    Line[{{0.239422, 0.665018, 0.674859},{0.234614, 0.649230, 0.623461}}],
    Line[{{0.234614, 0.649230, 0.623461},{0.231600, 0.640598, 0.570216}}],
    Line[{{0.231600, 0.640598, 0.570216},{0.230289, 0.637078, 0.516311}}],
    Line[{{0.230289, 0.637078, 0.516311},{0.230611, 0.637931, 0.462281}}],
    Line[{{0.230611, 0.637931, 0.462281},{0.232585, 0.643331, 0.408554}}],
    Line[{{0.232585, 0.643331, 0.408554},{0.236305, 0.654453, 0.355828}}],
    Line[{{0.236305, 0.654453, 0.355828},{0.241798, 0.674121, 0.305896}}],
    Line[{{0.241798, 0.674121, 0.305896},{0.248189, 0.707921, 0.264746}}],
    Line[{{0.248189, 0.707921, 0.264746},{0.250880, 0.758556, 0.250587}}],
    Line[{{0.250880, 0.758556, 0.250587},{0.246228, 0.804775, 0.276090}}],
    Line[{{0.246228, 0.804775, 0.276090},{0.239878, 0.833324, 0.321231}}],
    Line[{{0.239878, 0.833324, 0.321231},{0.234929, 0.849825, 0.372385}}],
    Line[{{0.234929, 0.849825, 0.372385},{0.231776, 0.858926, 0.425541}}],
    Line[{{0.231776, 0.858926, 0.425541},{0.230334, 0.862810, 0.479416}}],
    Line[{{0.230334, 0.862810, 0.479416},{0.230528, 0.862298, 0.533451}}],
    Line[{{0.230528, 0.862298, 0.533451},{0.232368, 0.857284, 0.587219}}],
    Line[{{0.232368, 0.857284, 0.587219},{0.235945, 0.846690, 0.640066}}],
    Line[{{0.235945, 0.846690, 0.640066},{0.241307, 0.827861, 0.690343}}],
    Line[{{0.241307, 0.827861, 0.690343},{0.247723, 0.795435, 0.732640}}],
    Line[{{0.247723, 0.795435, 0.732640},{0.250969, 0.745704, 0.749850}}],
    Line[{{0.250969, 0.745704, 0.749850},{0.246737, 0.698208, 0.726944}}],
    Line[{{0.246737, 0.698208, 0.726944},{0.240345, 0.668415, 0.682662}}],
    Line[{{0.240345, 0.668415, 0.682662},{0.235257, 0.651168, 0.631776}}],
    Line[{{0.235257, 0.651168, 0.631776},{0.231963, 0.641585, 0.578716}}],
    Line[{{0.231963, 0.641585, 0.578716},{0.230389, 0.637330, 0.524872}}],
    Line[{{0.230389, 0.637330, 0.524872},{0.230454, 0.637502, 0.470835}}],
    Line[{{0.230454, 0.637502, 0.470835},{0.232161, 0.642133, 0.417027}}],
    Line[{{0.232161, 0.642133, 0.417027},{0.235596, 0.652214, 0.364069}}],
    Line[{{0.235596, 0.652214, 0.364069},{0.240823, 0.670235, 0.313472}}],
    Line[{{0.240823, 0.670235, 0.313472},{0.247239, 0.701323, 0.270132}}],
    Line[{{0.247239, 0.701323, 0.270132},{0.251000, 0.750000, 0.250000}}],
    Line[{{0.251000, 0.750000, 0.250000},{0.247239, 0.798677, 0.270132}}],
    Line[{{0.247239, 0.798677, 0.270132},{0.240823, 0.829765, 0.313472}}],
    Line[{{0.240823, 0.829765, 0.313472},{0.235596, 0.847786, 0.364069}}],
    Line[{{0.235596, 0.847786, 0.364069},{0.232161, 0.857867, 0.417027}}],
    Line[{{0.232161, 0.857867, 0.417027},{0.230454, 0.862498, 0.470835}}],
    Line[{{0.230454, 0.862498, 0.470835},{0.230389, 0.862669, 0.524872}}],
    Line[{{0.230389, 0.862669, 0.524872},{0.231963, 0.858415, 0.578716}}],
    Line[{{0.231963, 0.858415, 0.578716},{0.235257, 0.848831, 0.631776}}],
    Line[{{0.235257, 0.848831, 0.631776},{0.240345, 0.831585, 0.682662}}],
    Line[{{0.240345, 0.831585, 0.682662},{0.246737, 0.801792, 0.726944}}],
    Line[{{0.246737, 0.801792, 0.726944},{0.250969, 0.754296, 0.749850}}],
    Line[{{0.250969, 0.754296, 0.749850},{0.247723, 0.704564, 0.732640}}],
    Line[{{0.247723, 0.704564, 0.732640},{0.241307, 0.672139, 0.690343}}],
    Line[{{0.241307, 0.672139, 0.690343},{0.235945, 0.653310, 0.640066}}],
    Line[{{0.235945, 0.653310, 0.640066},{0.232368, 0.642716, 0.587219}}],
    Line[{{0.232368, 0.642716, 0.587219},{0.230528, 0.637702, 0.533451}}],
    Line[{{0.230528, 0.637702, 0.533451},{0.230334, 0.637190, 0.479416}}],
    Line[{{0.230334, 0.637190, 0.479416},{0.231776, 0.641074, 0.425541}}],
    Line[{{0.231776, 0.641074, 0.425541},{0.234929, 0.650175, 0.372385}}],
    Line[{{0.234929, 0.650175, 0.372385},{0.239878, 0.666676, 0.321231}}],
    Line[{{0.239878, 0.666676, 0.321231},{0.246228, 0.695225, 0.276090}}],
    Line[{{0.246228, 0.695225, 0.276090},{0.250880, 0.741445, 0.250587}}],
    Line[{{0.250880, 0.741445, 0.250587},{0.248189, 0.792079, 0.264746}}],
    Line[{{0.248189, 0.792079, 0.264746},{0.241798, 0.825879, 0.305897}}],
    Line[{{0.241798, 0.825879, 0.305897},{0.236305, 0.845547, 0.355828}}],
    Line[{{0.236305, 0.845547, 0.355828},{0.232585, 0.856669, 0.408555}}],
    Line[{{0.232585, 0.856669, 0.408555},{0.230611, 0.862069, 0.462281}}],
    Line[{{0.230611, 0.862069, 0.462281},{0.230289, 0.862922, 0.516312}}],
    Line[{{0.230289, 0.862922, 0.516312},{0.231600, 0.859401, 0.570217}}],
    Line[{{0.231600, 0.859401, 0.570217},{0.234614, 0.850770, 0.623461}}],
    Line[{{0.234614, 0.850770, 0.623461},{0.239422, 0.834981, 0.674859}}],
    Line[{{0.239422, 0.834981, 0.674859},{0.245713, 0.807627, 0.720774}}],
    Line[{{0.245713, 0.807627, 0.720774},{0.250736, 0.762758, 0.748700}}],
    Line[{{0.250736, 0.762758, 0.748700},{0.248630, 0.711390, 0.737692}}],
    Line[{{0.248630, 0.711390, 0.737692},{0.242294, 0.676182, 0.697800}}],
    Line[{{0.242294, 0.676182, 0.697800},{0.236673, 0.655642, 0.648246}}],
    Line[{{0.236673, 0.655642, 0.648246},{0.232812, 0.643978, 0.595650}}],
    Line[{{0.251000, 0.750010, 0.499918},{0.251000, 0.749974, 0.500063}}],
    Line[{{0.251000, 0.749974, 0.500063},{0.251000, 0.750036, 0.499982}}],
    Line[{{0.251000, 0.750036, 0.499982},{0.251000, 0.749977, 0.499940}}],
    Line[{{0.251000, 0.749977, 0.499940},{0.251000, 0.749999, 0.500085}}],
    Line[{{0.251000, 0.749999, 0.500085},{0.251000, 0.750023, 0.499933}}],
    Line[{{0.251000, 0.750023, 0.499933},{0.251000, 0.749965, 0.500018}}],
    Line[{{0.251000, 0.749965, 0.500018},{0.251000, 0.750024, 0.500060}}],
    Line[{{0.251000, 0.750024, 0.500060},{0.251000, 0.750026, 0.499948}}],
    Line[{{0.251000, 0.750026, 0.499948},{0.251000, 0.749970, 0.499965}}],
    Line[{{0.251000, 0.749970, 0.499965},{0.251000, 0.749975, 0.500063}}],
    Line[{{0.251000, 0.749975, 0.500063},{0.251000, 0.750036, 0.499985}}],
    Line[{{0.251000, 0.750036, 0.499985},{0.251000, 0.749974, 0.499946}}],
    Line[{{0.251000, 0.749974, 0.499946},{0.251000, 0.749967, 0.500025}}],
    Line[{{0.251000, 0.749967, 0.500025},{0.251000, 0.750035, 0.500037}}],
    Line[{{0.251000, 0.750035, 0.500037},{0.251000, 0.749976, 0.499933}}],
    Line[{{0.251000, 0.749976, 0.499933},{0.251000, 0.749994, 0.500079}}],
    Line[{{0.251000, 0.749994, 0.500079},{0.251000, 0.750033, 0.499973}}],
    Line[{{0.251000, 0.750033, 0.499973},{0.251000, 0.749980, 0.499938}}],
    Line[{{0.251000, 0.749980, 0.499938},{0.251000, 0.749967, 0.500003}}],
    Line[{{0.251000, 0.749967, 0.500003},{0.251000, 0.749976, 0.500048}}],
    Line[{{0.251000, 0.749976, 0.500048},{0.251000, 0.749993, 0.500067}}],
    Line[{{0.251000, 0.749993, 0.500067},{0.251000, 0.750000, 0.500066}}],
    Line[{{0.251000, 0.750000, 0.500066},{0.251000, 0.750015, 0.500058}}],
    Line[{{0.251000, 0.750015, 0.500058},{0.251000, 0.750024, 0.500043}}],
    Line[{{0.251000, 0.750024, 0.500043},{0.251000, 0.749996, 0.500059}}],
    Line[{{0.251000, 0.749996, 0.500059},{0.251000, 0.749974, 0.500027}}],
    Line[{{0.251000, 0.749974, 0.500027},{0.251000, 0.749974, 0.499981}}],
    Line[{{0.251000, 0.749974, 0.499981},{0.251000, 0.750008, 0.499943}}],
    Line[{{0.251000, 0.750008, 0.499943},{0.251000, 0.750020, 0.499947}}],
    Line[{{0.251000, 0.750020, 0.499947},{0.251000, 0.750024, 0.499964}}],
    Line[{{0.251000, 0.750024, 0.499964},{0.251000, 0.750029, 0.499999}}],
    Line[{{0.251000, 0.750029, 0.499999},{0.251000, 0.750020, 0.500041}}],
    Line[{{0.251000, 0.750020, 0.500041},{0.251000, 0.749985, 0.500050}}],
    Line[{{0.251000, 0.749985, 0.500050},{0.251000, 0.749995, 0.500069}}],
    Line[{{0.251000, 0.749995, 0.500069},{0.251000, 0.750008, 0.500062}}],
    Line[{{0.251000, 0.750008, 0.500062},{0.251000, 0.749995, 0.500067}}],
    Line[{{0.251000, 0.749995, 0.500067},{0.251000, 0.749986, 0.500053}}],
    Line[{{0.251000, 0.749986, 0.500053},{0.251000, 0.749977, 0.499976}}],
    Line[{{0.251000, 0.749977, 0.499976},{0.251000, 0.750022, 0.500016}}],
    Line[{{0.251000, 0.750022, 0.500016},{0.251000, 0.750004, 0.499951}}],
    Line[{{0.251000, 0.750004, 0.499951},{0.251000, 0.749983, 0.499977}}],
    Line[{{0.251000, 0.749983, 0.499977},{0.251000, 0.750016, 0.499995}}],
    Line[{{0.251000, 0.750016, 0.499995},{0.251000, 0.749996, 0.499970}}],
    Line[{{0.251000, 0.749996, 0.499970},{0.251000, 0.750014, 0.499997}}],
    Line[{{0.251000, 0.750014, 0.499997},{0.251000, 0.749997, 0.499978}}],
    Line[{{0.251000, 0.749997, 0.499978},{0.251000, 0.749991, 0.500013}}],
    Line[{{0.251000, 0.749991, 0.500013},{0.251000, 0.750005, 0.499994}}],
    Line[{{0.251000, 0.750005, 0.499994},{0.251000, 0.749997, 0.499999}}],
    Line[{{0.251000, 0.749997, 0.499999},{0.251000, 0.750002, 0.499999}}],
    Line[{{0.251000, 0.750002, 0.499999},{0.251000, 0.749999, 0.499995}}],
    Line[{{0.251000, 0.749999, 0.499995},{0.251000, 0.750005, 0.500005}}],
    Line[{{0.251000, 0.750005, 0.500005},{0.251000, 0.749993, 0.499996}}],
    Line[{{0.251000, 0.749993, 0.499996},{0.251000, 0.750013, 0.499991}}],
    Line[{{0.251000, 0.750013, 0.499991},{0.251000, 0.750011, 0.500017}}],
    Line[{{0.251000, 0.750011, 0.500017},{0.251000, 0.749998, 0.500029}}],
    Line[{{0.251000, 0.749998, 0.500029},{0.251000, 0.749985, 0.500007}}],
    Line[{{0.251000, 0.749985, 0.500007},{0.251000, 0.749985, 0.500006}}],
    Line[{{0.251000, 0.749985, 0.500006},{0.251000, 0.749988, 0.500026}}],
    Line[{{0.251000, 0.749988, 0.500026},{0.251000, 0.750005, 0.500034}}],
    Line[{{0.251000, 0.750005, 0.500034},{0.251000, 0.749993, 0.499964}}],
    Line[{{0.251000, 0.749993, 0.499964},{0.251000, 0.750017, 0.500010}}],
    Line[{{0.251000, 0.750017, 0.500010},{0.251000, 0.749983, 0.500017}}],
    Line[{{0.251000, 0.749983, 0.500017},{0.251000, 0.749986, 0.499972}}],
    Line[{{0.251000, 0.749986, 0.499972},{0.251000, 0.749986, 0.499967}}],
    Line[{{0.251000, 0.749986, 0.499967},{0.251000, 0.749980, 0.499987}}],
    Line[{{0.251000, 0.749980, 0.499987},{0.251000, 0.749983, 0.500033}}],
    Line[{{0.251000, 0.749983, 0.500033},{0.251000, 0.750020, 0.500026}}],
    Line[{{0.251000, 0.750020, 0.500026},{0.251000, 0.749980, 0.499967}}],
    Line[{{0.251000, 0.749980, 0.499967},{0.251000, 0.750025, 0.500009}}],
    Line[{{0.251000, 0.750025, 0.500009},{0.251000, 0.749992, 0.500059}}],
    Line[{{0.251000, 0.749992, 0.500059},{0.251000, 0.749981, 0.500052}}],
    Line[{{0.251000, 0.749981, 0.500052},{0.251000, 0.749990, 0.500068}}],
    Line[{{0.251000, 0.749990, 0.500068},{0.251000, 0.750021, 0.500056}}],
    Line[{{0.251000, 0.750021, 0.500056},{0.251000, 0.750034, 0.500001}}],
    Line[{{0.232811, 0.643976, 0.404359},{0.236672, 0.655638, 0.351763}}],
    Line[{{0.236672, 0.655638, 0.351763},{0.242293, 0.676176, 0.302208}}],
    Line[{{0.242293, 0.676176, 0.302208},{0.248629, 0.711381, 0.262311}}],
    Line[{{0.248629, 0.711381, 0.262311},{0.250736, 0.762750, 0.251298}}],
    Line[{{0.250736, 0.762750, 0.251298},{0.245714, 0.807623, 0.279219}}],
    Line[{{0.245714, 0.807623, 0.279219},{0.239422, 0.834979, 0.325132}}],
    Line[{{0.239422, 0.834979, 0.325132},{0.234614, 0.850769, 0.376530}}],
    Line[{{0.234614, 0.850769, 0.376530},{0.231600, 0.859401, 0.429775}}],
    Line[{{0.231600, 0.859401, 0.429775},{0.230289, 0.862922, 0.483680}}],
    Line[{{0.230289, 0.862922, 0.483680},{0.230611, 0.862070, 0.537710}}],
    Line[{{0.230611, 0.862070, 0.537710},{0.232584, 0.856671, 0.591437}}],
    Line[{{0.232584, 0.856671, 0.591437},{0.236303, 0.845550, 0.644163}}],
    Line[{{0.236303, 0.845550, 0.644163},{0.241797, 0.825883, 0.694097}}],
    Line[{{0.241797, 0.825883, 0.694097},{0.248187, 0.792084, 0.735248}}],
    Line[{{0.248187, 0.792084, 0.735248},{0.250880, 0.741454, 0.749415}}],
    Line[{{0.250880, 0.741454, 0.749415},{0.246228, 0.695230, 0.723915}}],
    Line[{{0.246228, 0.695230, 0.723915},{0.239878, 0.666680, 0.678776}}],
    Line[{{0.239878, 0.666680, 0.678776},{0.234930, 0.650177, 0.627623}}],
    Line[{{0.234930, 0.650177, 0.627623},{0.231776, 0.641077, 0.574466}}],
    Line[{{0.231776, 0.641077, 0.574466},{0.230334, 0.637192, 0.520590}}],
    Line[{{0.230334, 0.637192, 0.520590},{0.230528, 0.637703, 0.466554}}],
    Line[{{0.230528, 0.637703, 0.466554},{0.232368, 0.642716, 0.412785}}],
    Line[{{0.232368, 0.642716, 0.412785},{0.235945, 0.653309, 0.359937}}],
    Line[{{0.235945, 0.653309, 0.359937},{0.241307, 0.672138, 0.309659}}],
    Line[{{0.241307, 0.672138, 0.309659},{0.247723, 0.704563, 0.267362}}],
    Line[{{0.247723, 0.704563, 0.267362},{0.250969, 0.754294, 0.250150}}],
    Line[{{0.250969, 0.754294, 0.250150},{0.246738, 0.801790, 0.273053}}],
    Line[{{0.246738, 0.801790, 0.273053},{0.240346, 0.831585, 0.317337}}],
    Line[{{0.240346, 0.831585, 0.317337},{0.235257, 0.848831, 0.368223}}],
    Line[{{0.235257, 0.848831, 0.368223},{0.231964, 0.858414, 0.421284}}],
    Line[{{0.231964, 0.858414, 0.421284},{0.230389, 0.862669, 0.475128}}],
    Line[{{0.230389, 0.862669, 0.475128},{0.230454, 0.862498, 0.529165}}],
    Line[{{0.230454, 0.862498, 0.529165},{0.232161, 0.857867, 0.582973}}],
    Line[{{0.232161, 0.857867, 0.582973},{0.235596, 0.847786, 0.635931}}],
    Line[{{0.235596, 0.847786, 0.635931},{0.240823, 0.829765, 0.686527}}],
    Line[{{0.240823, 0.829765, 0.686527},{0.247239, 0.798678, 0.729867}}],
    Line[{{0.247239, 0.798678, 0.729867},{0.251000, 0.750000, 0.750000}}],
    Line[{{0.251000, 0.750000, 0.750000},{0.247239, 0.701322, 0.729867}}],
    Line[{{0.247239, 0.701322, 0.729867},{0.240823, 0.670235, 0.686527}}],
    Line[{{0.240823, 0.670235, 0.686527},{0.235596, 0.652214, 0.635931}}],
    Line[{{0.235596, 0.652214, 0.635931},{0.232161, 0.642133, 0.582973}}],
    Line[{{0.232161, 0.642133, 0.582973},{0.230454, 0.637502, 0.529165}}],
    Line[{{0.230454, 0.637502, 0.529165},{0.230389, 0.637331, 0.475128}}],
    Line[{{0.230389, 0.637331, 0.475128},{0.231964, 0.641586, 0.421284}}],
    Line[{{0.231964, 0.641586, 0.421284},{0.235257, 0.651169, 0.368224}}],
    Line[{{0.235257, 0.651169, 0.368224},{0.240346, 0.668415, 0.317337}}],
    Line[{{0.240346, 0.668415, 0.317337},{0.246738, 0.698210, 0.273053}}],
    Line[{{0.246738, 0.698210, 0.273053},{0.250969, 0.745706, 0.250150}}],
    Line[{{0.250969, 0.745706, 0.250150},{0.247723, 0.795437, 0.267362}}],
    Line[{{0.247723, 0.795437, 0.267362},{0.241307, 0.827862, 0.309659}}],
    Line[{{0.241307, 0.827862, 0.309659},{0.235945, 0.846691, 0.359937}}],
    Line[{{0.235945, 0.846691, 0.359937},{0.232368, 0.857284, 0.412785}}],
    Line[{{0.232368, 0.857284, 0.412785},{0.230528, 0.862297, 0.466554}}],
    Line[{{0.230528, 0.862297, 0.466554},{0.230334, 0.862808, 0.520590}}],
    Line[{{0.230334, 0.862808, 0.520590},{0.231776, 0.858923, 0.574466}}],
    Line[{{0.231776, 0.858923, 0.574466},{0.234930, 0.849823, 0.627623}}],
    Line[{{0.234930, 0.849823, 0.627623},{0.239878, 0.833320, 0.678775}}],
    Line[{{0.239878, 0.833320, 0.678775},{0.246228, 0.804769, 0.723915}}],
    Line[{{0.246228, 0.804769, 0.723915},{0.250880, 0.758546, 0.749415}}],
    Line[{{0.250880, 0.758546, 0.749415},{0.248187, 0.707916, 0.735247}}],
    Line[{{0.248187, 0.707916, 0.735247},{0.241797, 0.674117, 0.694096}}],
    Line[{{0.241797, 0.674117, 0.694096},{0.236303, 0.654450, 0.644163}}],
    Line[{{0.236303, 0.654450, 0.644163},{0.232584, 0.643329, 0.591436}}],
    Line[{{0.232584, 0.643329, 0.591436},{0.230611, 0.637930, 0.537710}}],
    Line[{{0.230611, 0.637930, 0.537710},{0.230289, 0.637078, 0.483679}}],
    Line[{{0.230289, 0.637078, 0.483679},{0.231600, 0.640599, 0.429774}}],
    Line[{{0.231600, 0.640599, 0.429774},{0.234614, 0.649231, 0.376530}}],
    Line[{{0.234614, 0.649231, 0.376530},{0.239422, 0.665021, 0.325132}}],
    Line[{{0.239422, 0.665021, 0.325132},{0.245714, 0.692377, 0.279219}}],
    Line[{{0.245714, 0.692377, 0.279219},{0.250736, 0.737251, 0.251298}}],
    Line[{{0.250736, 0.737251, 0.251298},{0.248629, 0.788619, 0.262312}}],
    Line[{{0.248629, 0.788619, 0.262312},{0.242293, 0.823824, 0.302208}}],
    Line[{{0.242293, 0.823824, 0.302208},{0.236672, 0.844362, 0.351763}}],
    Line[{{0.236672, 0.844362, 0.351763},{0.232811, 0.856024, 0.404360}}],
    Line[{{0.511722, 0.261663, 0.748940},{0.527086, 0.222985, 0.744147}}],
    Line[{{0.527086, 0.222985, 0.744147},{0.560523, 0.190036, 0.718071}}],
    Line[{{0.560523, 0.190036, 0.718071},{0.585659, 0.165912, 0.677035}}],
    Line[{{0.585659, 0.165912, 0.677035},{0.602388, 0.150298, 0.628186}}],
    Line[{{0.602388, 0.150298, 0.628186},{0.612316, 0.141235, 0.575890}}],
    Line[{{0.612316, 0.141235, 0.575890},{0.616759, 0.137233, 0.522204}}],
    Line[{{0.616759, 0.137233, 0.522204},{0.616333, 0.137616, 0.468185}}],
    Line[{{0.616333, 0.137616, 0.468185},{0.610977, 0.142447, 0.414653}}],
    Line[{{0.610977, 0.142447, 0.414653},{0.599954, 0.152544, 0.362772}}],
    Line[{{0.599954, 0.152544, 0.362772},{0.581832, 0.169538, 0.314906}}],
    Line[{{0.581832, 0.169538, 0.314906},{0.555109, 0.195316, 0.275965}}],
    Line[{{0.555109, 0.195316, 0.275965},{0.520506, 0.229545, 0.253321}}],
    Line[{{0.520506, 0.229545, 0.253321},{0.518379, 0.268332, 0.252658}}],
    Line[{{0.518379, 0.268332, 0.252658},{0.553324, 0.302939, 0.274167}}],
    Line[{{0.553324, 0.302939, 0.274167},{0.580550, 0.329244, 0.312388}}],
    Line[{{0.580550, 0.329244, 0.312388},{0.599126, 0.346690, 0.359908}}],
    Line[{{0.599126, 0.346690, 0.359908},{0.610510, 0.357129, 0.411640}}],
    Line[{{0.610510, 0.357129, 0.411640},{0.616162, 0.362231, 0.465115}}],
    Line[{{0.616162, 0.362231, 0.465115},{0.616861, 0.362858, 0.519130}}],
    Line[{{0.616861, 0.362858, 0.519130},{0.612704, 0.359116, 0.572858}}],
    Line[{{0.612704, 0.359116, 0.572858},{0.603118, 0.350374, 0.625275}}],
    Line[{{0.603118, 0.350374, 0.625275},{0.586820, 0.335185, 0.674409}}],
    Line[{{0.586820, 0.335185, 0.674409},{0.562188, 0.311584, 0.716060}}],
    Line[{{0.562188, 0.311584, 0.716060},{0.529152, 0.279072, 0.743185}}],
    Line[{{0.529152, 0.279072, 0.743185},{0.509481, 0.240577, 0.749305}}],
    Line[{{0.509481, 0.240577, 0.749305},{0.545654, 0.204592, 0.732677}}],
    Line[{{0.545654, 0.204592, 0.732677},{0.574935, 0.176117, 0.697716}}],
    Line[{{0.574935, 0.176117, 0.697716},{0.595457, 0.156717, 0.651807}}],
    Line[{{0.595457, 0.156717, 0.651807},{0.608383, 0.144805, 0.600774}}],
    Line[{{0.608383, 0.144805, 0.600774},{0.615290, 0.138552, 0.547573}}],
    Line[{{0.615290, 0.138552, 0.547573},{0.617123, 0.136907, 0.493608}}],
    Line[{{0.617123, 0.136907, 0.493608},{0.614137, 0.139590, 0.439736}}],
    Line[{{0.614137, 0.139590, 0.439736},{0.605920, 0.147055, 0.386884}}],
    Line[{{0.605920, 0.147055, 0.386884},{0.591352, 0.160553, 0.336705}}],
    Line[{{0.591352, 0.160553, 0.336705},{0.568797, 0.182018, 0.292745}}],
    Line[{{0.568797, 0.182018, 0.292745},{0.537555, 0.212590, 0.261500}}],
    Line[{{0.537555, 0.212590, 0.261500},{0.501000, 0.250000, 0.250000}}],
    Line[{{0.501000, 0.250000, 0.250000},{0.537555, 0.287410, 0.261500}}],
    Line[{{0.537555, 0.287410, 0.261500},{0.568797, 0.317982, 0.292745}}],
    Line[{{0.568797, 0.317982, 0.292745},{0.591352, 0.339447, 0.336705}}],
    Line[{{0.591352, 0.339447, 0.336705},{0.605920, 0.352946, 0.386884}}],
    Line[{{0.605920, 0.352946, 0.386884},{0.614137, 0.360410, 0.439736}}],
    Line[{{0.614137, 0.360410, 0.439736},{0.617123, 0.363093, 0.493608}}],
    Line[{{0.617123, 0.363093, 0.493608},{0.615290, 0.361448, 0.547573}}],
    Line[{{0.615290, 0.361448, 0.547573},{0.608383, 0.355195, 0.600774}}],
    Line[{{0.608383, 0.355195, 0.600774},{0.595457, 0.343283, 0.651808}}],
    Line[{{0.595457, 0.343283, 0.651808},{0.574935, 0.323883, 0.697716}}],
    Line[{{0.574935, 0.323883, 0.697716},{0.545654, 0.295407, 0.732677}}],
    Line[{{0.545654, 0.295407, 0.732677},{0.509479, 0.259421, 0.749305}}],
    Line[{{0.509479, 0.259421, 0.749305},{0.529156, 0.220925, 0.743183}}],
    Line[{{0.529156, 0.220925, 0.743183},{0.562189, 0.188415, 0.716055}}],
    Line[{{0.562189, 0.188415, 0.716055},{0.586820, 0.164815, 0.674402}}],
    Line[{{0.586820, 0.164815, 0.674402},{0.603117, 0.149627, 0.625268}}],
    Line[{{0.603117, 0.149627, 0.625268},{0.612703, 0.140885, 0.572851}}],
    Line[{{0.612703, 0.140885, 0.572851},{0.616859, 0.137144, 0.519123}}],
    Line[{{0.616859, 0.137144, 0.519123},{0.616159, 0.137772, 0.465109}}],
    Line[{{0.616159, 0.137772, 0.465109},{0.610507, 0.142874, 0.411634}}],
    Line[{{0.610507, 0.142874, 0.411634},{0.599122, 0.153314, 0.359902}}],
    Line[{{0.599122, 0.153314, 0.359902},{0.580544, 0.170762, 0.312382}}],
    Line[{{0.580544, 0.170762, 0.312382},{0.553315, 0.197070, 0.274165}}],
    Line[{{0.553315, 0.197070, 0.274165},{0.518368, 0.231679, 0.252660}}],
    Line[{{0.518368, 0.231679, 0.252660},{0.520534, 0.270484, 0.253335}}],
    Line[{{0.520534, 0.270484, 0.253335},{0.555133, 0.304707, 0.275996}}],
    Line[{{0.555133, 0.304707, 0.275996},{0.581848, 0.330477, 0.314947}}],
    Line[{{0.581848, 0.330477, 0.314947},{0.599963, 0.347465, 0.362817}}],
    Line[{{0.599963, 0.347465, 0.362817},{0.610982, 0.357557, 0.414701}}],
    Line[{{0.610982, 0.357557, 0.414701},{0.616333, 0.362384, 0.468233}}],
    Line[{{0.616333, 0.362384, 0.468233},{0.616755, 0.362763, 0.522253}}],
    Line[{{0.616755, 0.362763, 0.522253},{0.612306, 0.358756, 0.575938}}],
    Line[{{0.612306, 0.358756, 0.575938},{0.602373, 0.349688, 0.628233}}],
    Line[{{0.602373, 0.349688, 0.628233},{0.585639, 0.334069, 0.677075}}],
    Line[{{0.585639, 0.334069, 0.677075},{0.560493, 0.309935, 0.718101}}],
    Line[{{0.560493, 0.309935, 0.718101},{0.527050, 0.276980, 0.744159}}],
    Line[{{0.527050, 0.276980, 0.744159},{0.511750, 0.238307, 0.748930}}],
    Line[{{0.501000, 0.250001, 0.499998},{0.501000, 0.249999, 0.500003}}],
    Line[{{0.501000, 0.249999, 0.500003},{0.501000, 0.250001, 0.499997}}],
    Line[{{0.501000, 0.250001, 0.499997},{0.501000, 0.250000, 0.500003}}],
    Line[{{0.501000, 0.250000, 0.500003},{0.501000, 0.250000, 0.499997}}],
    Line[{{0.501000, 0.250000, 0.499997},{0.501000, 0.250000, 0.500003}}],
    Line[{{0.501000, 0.250000, 0.500003},{0.501000, 0.250000, 0.499997}}],
    Line[{{0.501000, 0.250000, 0.499997},{0.501000, 0.250000, 0.500003}}],
    Line[{{0.501000, 0.250000, 0.500003},{0.501000, 0.250000, 0.499997}}],
    Line[{{0.501000, 0.250000, 0.499997},{0.501000, 0.250000, 0.500003}}],
    Line[{{0.501000, 0.250000, 0.500003},{0.501000, 0.249999, 0.499997}}],
    Line[{{0.501000, 0.249999, 0.499997},{0.501000, 0.250001, 0.500003}}],
    Line[{{0.501000, 0.250001, 0.500003},{0.501000, 0.249999, 0.499997}}],
    Line[{{0.501000, 0.249999, 0.499997},{0.501000, 0.250001, 0.500002}}],
    Line[{{0.501000, 0.250001, 0.500002},{0.501000, 0.249999, 0.499998}}],
    Line[{{0.501000, 0.249999, 0.499998},{0.501000, 0.250001, 0.500002}}],
    Line[{{0.501000, 0.250001, 0.500002},{0.501000, 0.249999, 0.499999}}],
    Line[{{0.501000, 0.249999, 0.499999},{0.501000, 0.250001, 0.500001}}],
    Line[{{0.501000, 0.250001, 0.500001},{0.501000, 0.250001, 0.499999}}],
    Line[{{0.501000, 0.250001, 0.499999},{0.501000, 0.250000, 0.499999}}],
    Line[{{0.501000, 0.250000, 0.499999},{0.501000, 0.250002, 0.500010}}],
    Line[{{0.501000, 0.250002, 0.500010},{0.501000, 0.250006, 0.500015}}],
    Line[{{0.501000, 0.250006, 0.500015},{0.501000, 0.249990, 0.499992}}],
    Line[{{0.501000, 0.249990, 0.499992},{0.501000, 0.250003, 0.499981}}],
    Line[{{0.501000, 0.250003, 0.499981},{0.501000, 0.250011, 0.500004}}],
    Line[{{0.501000, 0.250011, 0.500004},{0.501000, 0.250005, 0.500020}}],
    Line[{{0.501000, 0.250005, 0.500020},{0.501000, 0.249991, 0.499986}}],
    Line[{{0.501000, 0.249991, 0.499986},{0.501000, 0.249992, 0.500007}}],
    Line[{{0.501000, 0.249992, 0.500007},{0.501000, 0.250010, 0.500006}}],
    Line[{{0.501000, 0.250010, 0.500006},{0.501000, 0.250006, 0.500016}}],
    Line[{{0.501000, 0.250006, 0.500016},{0.501000, 0.249990, 0.499993}}],
    Line[{{0.501000, 0.249990, 0.499993},{0.501000, 0.250007, 0.499989}}],
    Line[{{0.501000, 0.250007, 0.499989},{0.501000, 0.250004, 0.499985}}],
    Line[{{0.501000, 0.250004, 0.499985},{0.501000, 0.250006, 0.500001}}],
    Line[{{0.501000, 0.250006, 0.500001},{0.501000, 0.250005, 0.500014}}],
    Line[{{0.501000, 0.250005, 0.500014},{0.501000, 0.249989, 0.500006}}],
    Line[{{0.501000, 0.249989, 0.500006},{0.501000, 0.250002, 0.500028}}],
    Line[{{0.501000, 0.250002, 0.500028},{0.501000, 0.250002, 0.499972}}],
    Line[{{0.501000, 0.250002, 0.499972},{0.501000, 0.250012, 0.500020}}],
    Line[{{0.501000, 0.250012, 0.500020},{0.501000, 0.249988, 0.500016}}],
    Line[{{0.501000, 0.249988, 0.500016},{0.501000, 0.250013, 0.500008}}],
    Line[{{0.501000, 0.250013, 0.500008},{0.501000, 0.249985, 0.499994}}],
    Line[{{0.501000, 0.249985, 0.499994},{0.501000, 0.250011, 0.499978}}],
    Line[{{0.501000, 0.250011, 0.499978},{0.501000, 0.250007, 0.500027}}],
    Line[{{0.501000, 0.250007, 0.500027},{0.501000, 0.249986, 0.499993}}],
    Line[{{0.501000, 0.249986, 0.499993},{0.501000, 0.250013, 0.500008}}],
    Line[{{0.501000, 0.250013, 0.500008},{0.501000, 0.249985, 0.500012}}],
    Line[{{0.501000, 0.249985, 0.500012},{0.501000, 0.249987, 0.499980}}],
    Line[{{0.501000, 0.249987, 0.499980},{0.501000, 0.249991, 0.499970}}],
    Line[{{0.501000, 0.249991, 0.499970},{0.501000, 0.249991, 0.499970}}],
    Line[{{0.501000, 0.249991, 0.499970},{0.501000, 0.249988, 0.499972}}],
    Line[{{0.501000, 0.249988, 0.499972},{0.501000, 0.249983, 0.499984}}],
    Line[{{0.501000, 0.249983, 0.499984},{0.501000, 0.249983, 0.500019}}],
    Line[{{0.501000, 0.249983, 0.500019},{0.501000, 0.250012, 0.500032}}],
    Line[{{0.501000, 0.250012, 0.500032},{0.501000, 0.250018, 0.499996}}],
    Line[{{0.501000, 0.250018, 0.499996},{0.501000, 0.250014, 0.499973}}],
    Line[{{0.501000, 0.250014, 0.499973},{0.501000, 0.249978, 0.499998}}],
    Line[{{0.501000, 0.249978, 0.499998},{0.501000, 0.250017, 0.500026}}],
    Line[{{0.501000, 0.250017, 0.500026},{0.501000, 0.250000, 0.499958}}],
    Line[{{0.501000, 0.250000, 0.499958},{0.501000, 0.249980, 0.500009}}],
    Line[{{0.501000, 0.249980, 0.500009},{0.501000, 0.250016, 0.500028}}],
    Line[{{0.501000, 0.250016, 0.500028},{0.501000, 0.250000, 0.499957}}],
    Line[{{0.501000, 0.250000, 0.499957},{0.501000, 0.249983, 0.500026}}],
    Line[{{0.501000, 0.249983, 0.500026},{0.501000, 0.250020, 0.500010}}],
    Line[{{0.501000, 0.250020, 0.500010},{0.501000, 0.249990, 0.499962}}],
    Line[{{0.501000, 0.249990, 0.499962},{0.501000, 0.249982, 0.500017}}],
    Line[{{0.501000, 0.249982, 0.500017},{0.501000, 0.250013, 0.500031}}],
    Line[{{0.501000, 0.250013, 0.500031},{0.501000, 0.250017, 0.499978}}],
    Line[{{0.501000, 0.250017, 0.499978},{0.501000, 0.249991, 0.499967}}],
    Line[{{0.501000, 0.249991, 0.499967},{0.501000, 0.249981, 0.500007}}],
    Line[{{0.501000, 0.249981, 0.500007},{0.501000, 0.250004, 0.500040}}],
    Line[{{0.501000, 0.250004, 0.500040},{0.501000, 0.250019, 0.499984}}],
    Line[{{0.501000, 0.250019, 0.499984},{0.501000, 0.249984, 0.499974}}],
    Line[{{0.501000, 0.249984, 0.499974},{0.501000, 0.249994, 0.500045}}],
    Line[{{0.501000, 0.249994, 0.500045},{0.501000, 0.250017, 0.499973}}],
    Line[{{0.511759, 0.238301, 0.251070},{0.527041, 0.276970, 0.255836}}],
    Line[{{0.527041, 0.276970, 0.255836},{0.560486, 0.309928, 0.281889}}],
    Line[{{0.560486, 0.309928, 0.281889},{0.585632, 0.334063, 0.322911}}],
    Line[{{0.585632, 0.334063, 0.322911},{0.602371, 0.349686, 0.371754}}],
    Line[{{0.602371, 0.349686, 0.371754},{0.612306, 0.358755, 0.424048}}],
    Line[{{0.612306, 0.358755, 0.424048},{0.616755, 0.362763, 0.477733}}],
    Line[{{0.616755, 0.362763, 0.477733},{0.616334, 0.362385, 0.531753}}],
    Line[{{0.616334, 0.362385, 0.531753},{0.610985, 0.357559, 0.585285}}],
    Line[{{0.610985, 0.357559, 0.585285},{0.599969, 0.347470, 0.637168}}],
    Line[{{0.599969, 0.347470, 0.637168},{0.581857, 0.330486, 0.685041}}],
    Line[{{0.581857, 0.330486, 0.685041},{0.555144, 0.304718, 0.723996}}],
    Line[{{0.555144, 0.304718, 0.723996},{0.520547, 0.270495, 0.746661}}],
    Line[{{0.520547, 0.270495, 0.746661},{0.518366, 0.231682, 0.747341}}],
    Line[{{0.518366, 0.231682, 0.747341},{0.553313, 0.197072, 0.725838}}],
    Line[{{0.553313, 0.197072, 0.725838},{0.580542, 0.170764, 0.687620}}],
    Line[{{0.580542, 0.170764, 0.687620},{0.599121, 0.153315, 0.640102}}],
    Line[{{0.599121, 0.153315, 0.640102},{0.610506, 0.142875, 0.588372}}],
    Line[{{0.610506, 0.142875, 0.588372},{0.616159, 0.137772, 0.534897}}],
    Line[{{0.616159, 0.137772, 0.534897},{0.616859, 0.137144, 0.480882}}],
    Line[{{0.616859, 0.137144, 0.480882},{0.612704, 0.140884, 0.427154}}],
    Line[{{0.612704, 0.140884, 0.427154},{0.603118, 0.149626, 0.374736}}],
    Line[{{0.603118, 0.149626, 0.374736},{0.586821, 0.164815, 0.325601}}],
    Line[{{0.586821, 0.164815, 0.325601},{0.562190, 0.188415, 0.283949}}],
    Line[{{0.562190, 0.188415, 0.283949},{0.529156, 0.220924, 0.256820}}],
    Line[{{0.529156, 0.220924, 0.256820},{0.509478, 0.259420, 0.250698}}],
    Line[{{0.509478, 0.259420, 0.250698},{0.545652, 0.295405, 0.267324}}],
    Line[{{0.545652, 0.295405, 0.267324},{0.574932, 0.323880, 0.302285}}],
    Line[{{0.574932, 0.323880, 0.302285},{0.595455, 0.343281, 0.348192}}],
    Line[{{0.595455, 0.343281, 0.348192},{0.608382, 0.355194, 0.399227}}],
    Line[{{0.608382, 0.355194, 0.399227},{0.615288, 0.361446, 0.452429}}],
    Line[{{0.615288, 0.361446, 0.452429},{0.617122, 0.363092, 0.506394}}],
    Line[{{0.617122, 0.363092, 0.506394},{0.614136, 0.360409, 0.560264}}],
    Line[{{0.614136, 0.360409, 0.560264},{0.605918, 0.352944, 0.613116}}],
    Line[{{0.605918, 0.352944, 0.613116},{0.591351, 0.339447, 0.663294}}],
    Line[{{0.591351, 0.339447, 0.663294},{0.568797, 0.317982, 0.707255}}],
    Line[{{0.568797, 0.317982, 0.707255},{0.537555, 0.287410, 0.738500}}],
    Line[{{0.537555, 0.287410, 0.738500},{0.501000, 0.250000, 0.750000}}],
    Line[{{0.501000, 0.250000, 0.750000},{0.537555, 0.212590, 0.738500}}],
    Line[{{0.537555, 0.212590, 0.738500},{0.568797, 0.182018, 0.707255}}],
    Line[{{0.568797, 0.182018, 0.707255},{0.591351, 0.160553, 0.663294}}],
    Line[{{0.591351, 0.160553, 0.663294},{0.605918, 0.147056, 0.613116}}],
    Line[{{0.605918, 0.147056, 0.613116},{0.614136, 0.139591, 0.560264}}],
    Line[{{0.614136, 0.139591, 0.560264},{0.617122, 0.136908, 0.506394}}],
    Line[{{0.617122, 0.136908, 0.506394},{0.615288, 0.138554, 0.452429}}],
    Line[{{0.615288, 0.138554, 0.452429},{0.608382, 0.144806, 0.399227}}],
    Line[{{0.608382, 0.144806, 0.399227},{0.595455, 0.156719, 0.348192}}],
    Line[{{0.595455, 0.156719, 0.348192},{0.574932, 0.176120, 0.302285}}],
    Line[{{0.574932, 0.176120, 0.302285},{0.545650, 0.204596, 0.267324}}],
    Line[{{0.545650, 0.204596, 0.267324},{0.509476, 0.240582, 0.250698}}],
    Line[{{0.509476, 0.240582, 0.250698},{0.529153, 0.279072, 0.256819}}],
    Line[{{0.529153, 0.279072, 0.256819},{0.562187, 0.311582, 0.283947}}],
    Line[{{0.562187, 0.311582, 0.283947},{0.586819, 0.335184, 0.325599}}],
    Line[{{0.586819, 0.335184, 0.325599},{0.603116, 0.350373, 0.374732}}],
    Line[{{0.603116, 0.350373, 0.374732},{0.612703, 0.359115, 0.427151}}],
    Line[{{0.612703, 0.359115, 0.427151},{0.616859, 0.362856, 0.480879}}],
    Line[{{0.616859, 0.362856, 0.480879},{0.616158, 0.362228, 0.534893}}],
    Line[{{0.616158, 0.362228, 0.534893},{0.610506, 0.357125, 0.588368}}],
    Line[{{0.610506, 0.357125, 0.588368},{0.599121, 0.346685, 0.640099}}],
    Line[{{0.599121, 0.346685, 0.640099},{0.580543, 0.329237, 0.687618}}],
    Line[{{0.580543, 0.329237, 0.687618},{0.553314, 0.302929, 0.725836}}],
    Line[{{0.553314, 0.302929, 0.725836},{0.518367, 0.268320, 0.747340}}],
    Line[{{0.518367, 0.268320, 0.747340},{0.520519, 0.229532, 0.746670}}],
    Line[{{0.520519, 0.229532, 0.746670},{0.555120, 0.195305, 0.724020}}],
    Line[{{0.555120, 0.195305, 0.724020},{0.581840, 0.169530, 0.685074}}],
    Line[{{0.581840, 0.169530, 0.685074},{0.599958, 0.152540, 0.637205}}],
    Line[{{0.599958, 0.152540, 0.637205},{0.610979, 0.142446, 0.585324}}],
    Line[{{0.610979, 0.142446, 0.585324},{0.616332, 0.137617, 0.531792}}],
    Line[{{0.616332, 0.137617, 0.531792},{0.616756, 0.137236, 0.477772}}],
    Line[{{0.616756, 0.137236, 0.477772},{0.612310, 0.141240, 0.424087}}],
    Line[{{0.612310, 0.141240, 0.424087},{0.602380, 0.150305, 0.371791}}],
    Line[{{0.602380, 0.150305, 0.371791},{0.585647, 0.165923, 0.322945}}],
    Line[{{0.585647, 0.165923, 0.322945},{0.560507, 0.190052, 0.281915}}],
    Line[{{0.560507, 0.190052, 0.281915},{0.527067, 0.223004, 0.255848}}],
    Line[{{0.527067, 0.223004, 0.255848},{0.511779, 0.261716, 0.251075}}],
    Line[{{0.608436, 0.500000, 0.600439},{0.595119, 0.500000, 0.652780}}],
    Line[{{0.595119, 0.500000, 0.652780},{0.572458, 0.500000, 0.701715}}],
    Line[{{0.572458, 0.500000, 0.701715},{0.535037, 0.500000, 0.740023}}],
    Line[{{0.535037, 0.500000, 0.740023},{0.483014, 0.500000, 0.747710}}],
    Line[{{0.483014, 0.500000, 0.747710},{0.439121, 0.500000, 0.717608}}],
    Line[{{0.439121, 0.500000, 0.717608},{0.411822, 0.500000, 0.671193}}],
    Line[{{0.411822, 0.500000, 0.671193},{0.395562, 0.500000, 0.619711}}],
    Line[{{0.395562, 0.500000, 0.619711},{0.386538, 0.500000, 0.566446}}],
    Line[{{0.386538, 0.500000, 0.566446},{0.382979, 0.500000, 0.512529}}],
    Line[{{0.382979, 0.500000, 0.512529},{0.384266, 0.500000, 0.458508}}],
    Line[{{0.384266, 0.500000, 0.458508},{0.390619, 0.500000, 0.404852}}],
    Line[{{0.390619, 0.500000, 0.404852},{0.403202, 0.500000, 0.352326}}],
    Line[{{0.403202, 0.500000, 0.352326},{0.424731, 0.500000, 0.302868}}],
    Line[{{0.424731, 0.500000, 0.302868},{0.460416, 0.500000, 0.262846}}],
    Line[{{0.460416, 0.500000, 0.262846},{0.511743, 0.500000, 0.251089}}],
    Line[{{0.511743, 0.500000, 0.251089},{0.557329, 0.500000, 0.278346}}],
    Line[{{0.557329, 0.500000, 0.278346},{0.586044, 0.500000, 0.323864}}],
    Line[{{0.586044, 0.500000, 0.323864},{0.603189, 0.500000, 0.375050}}],
    Line[{{0.603189, 0.500000, 0.375050},{0.612831, 0.500000, 0.428204}}],
    Line[{{0.612831, 0.500000, 0.428204},{0.616892, 0.500000, 0.482085}}],
    Line[{{0.616892, 0.500000, 0.482085},{0.616083, 0.500000, 0.536115}}],
    Line[{{0.616083, 0.500000, 0.536115},{0.610269, 0.500000, 0.589832}}],
    Line[{{0.610269, 0.500000, 0.589832},{0.598396, 0.500000, 0.642525}}],
    Line[{{0.598396, 0.500000, 0.642525},{0.577949, 0.500000, 0.692453}}],
    Line[{{0.577949, 0.500000, 0.692453},{0.543958, 0.500000, 0.733998}}],
    Line[{{0.543958, 0.500000, 0.733998},{0.493599, 0.500000, 0.749681}}],
    Line[{{0.493599, 0.500000, 0.749681},{0.446412, 0.500000, 0.725548}}],
    Line[{{0.446412, 0.500000, 0.725548},{0.416211, 0.500000, 0.681046}}],
    Line[{{0.416211, 0.500000, 0.681046},{0.398138, 0.500000, 0.630189}}],
    Line[{{0.398138, 0.500000, 0.630189},{0.387860, 0.500000, 0.577156}}],
    Line[{{0.387860, 0.500000, 0.577156},{0.383288, 0.500000, 0.523317}}],
    Line[{{0.383288, 0.500000, 0.523317},{0.383617, 0.500000, 0.469282}}],
    Line[{{0.383617, 0.500000, 0.469282},{0.388901, 0.500000, 0.415508}}],
    Line[{{0.388901, 0.500000, 0.415508},{0.400086, 0.500000, 0.362662}}],
    Line[{{0.400086, 0.500000, 0.362662},{0.419498, 0.500000, 0.312312}}],
    Line[{{0.419498, 0.500000, 0.312312},{0.451848, 0.500000, 0.269413}}],
    Line[{{0.451848, 0.500000, 0.269413},{0.501000, 0.500000, 0.250000}}],
    Line[{{0.501000, 0.500000, 0.250000},{0.549655, 0.500000, 0.270733}}],
    Line[{{0.549655, 0.500000, 0.270733},{0.581413, 0.500000, 0.314093}}],
    Line[{{0.581413, 0.500000, 0.314093},{0.600455, 0.500000, 0.364588}}],
    Line[{{0.600455, 0.500000, 0.364588},{0.611391, 0.500000, 0.417487}}],
    Line[{{0.611391, 0.500000, 0.417487},{0.616481, 0.500000, 0.471279}}],
    Line[{{0.616481, 0.500000, 0.471279},{0.616632, 0.500000, 0.525315}}],
    Line[{{0.616632, 0.500000, 0.525315},{0.611870, 0.500000, 0.579138}}],
    Line[{{0.611870, 0.500000, 0.579138},{0.601350, 0.500000, 0.632122}}],
    Line[{{0.601350, 0.500000, 0.632122},{0.582924, 0.500000, 0.682849}}],
    Line[{{0.582924, 0.500000, 0.682849},{0.552155, 0.500000, 0.726943}}],
    Line[{{0.552155, 0.500000, 0.726943},{0.504408, 0.500000, 0.749851}}],
    Line[{{0.504408, 0.500000, 0.749851},{0.454469, 0.500000, 0.732763}}],
    Line[{{0.454469, 0.500000, 0.732763},{0.421093, 0.500000, 0.690697}}],
    Line[{{0.421093, 0.500000, 0.690697},{0.401033, 0.500000, 0.640608}}],
    Line[{{0.401033, 0.500000, 0.640608},{0.389418, 0.500000, 0.587857}}],
    Line[{{0.389418, 0.500000, 0.587857},{0.383801, 0.500000, 0.534118}}],
    Line[{{0.383801, 0.500000, 0.534118},{0.383170, 0.500000, 0.480086}}],
    Line[{{0.383170, 0.500000, 0.480086},{0.387419, 0.500000, 0.426220}}],
    Line[{{0.387419, 0.500000, 0.426220},{0.397295, 0.500000, 0.373110}}],
    Line[{{0.397295, 0.500000, 0.373110},{0.414778, 0.500000, 0.322040}}],
    Line[{{0.414778, 0.500000, 0.322040},{0.444036, 0.500000, 0.276884}}],
    Line[{{0.444036, 0.500000, 0.276884},{0.490229, 0.500000, 0.250753}}],
    Line[{{0.490229, 0.500000, 0.250753},{0.541227, 0.500000, 0.263986}}],
    Line[{{0.541227, 0.500000, 0.263986},{0.576277, 0.500000, 0.304594}}],
    Line[{{0.576277, 0.500000, 0.304594},{0.597400, 0.500000, 0.354232}}],
    Line[{{0.597400, 0.500000, 0.354232},{0.609716, 0.500000, 0.406822}}],
    Line[{{0.609716, 0.500000, 0.406822},{0.615868, 0.500000, 0.460502}}],
    Line[{{0.615868, 0.500000, 0.460502},{0.616978, 0.500000, 0.514527}}],
    Line[{{0.616978, 0.500000, 0.514527},{0.613233, 0.500000, 0.568432}}],
    Line[{{0.613233, 0.500000, 0.568432},{0.603982, 0.500000, 0.621657}}],
    Line[{{0.603982, 0.500000, 0.621657},{0.587398, 0.500000, 0.673032}}],
    Line[{{0.587398, 0.500000, 0.673032},{0.559581, 0.500000, 0.719127}}],
    Line[{{0.559581, 0.500000, 0.719127},{0.515050, 0.500000, 0.748205}}],
    Line[{{0.515050, 0.500000, 0.748205},{0.463254, 0.500000, 0.738990}}],
    Line[{{0.463254, 0.500000, 0.738990},{0.426482, 0.500000, 0.700022}}],
    Line[{{0.426482, 0.500000, 0.700022},{0.404247, 0.500000, 0.650886}}],
    Line[{{0.404247, 0.500000, 0.650886},{0.391206, 0.500000, 0.598475}}],
    Line[{{0.500444, 0.500000, 0.498699},{0.499495, 0.500000, 0.501210}}],
    Line[{{0.499495, 0.500000, 0.501210},{0.500507, 0.500000, 0.498770}}],
    Line[{{0.500507, 0.500000, 0.498770},{0.499537, 0.500000, 0.501330}}],
    Line[{{0.499537, 0.500000, 0.501330},{0.500345, 0.500000, 0.498483}}],
    Line[{{0.500345, 0.500000, 0.498483},{0.499912, 0.500000, 0.501707}}],
    Line[{{0.499912, 0.500000, 0.501707},{0.499711, 0.500000, 0.498393}}],
    Line[{{0.499711, 0.500000, 0.498393},{0.500567, 0.500000, 0.501196}}],
    Line[{{0.500567, 0.500000, 0.501196},{0.499269, 0.500000, 0.499361}}],
    Line[{{0.499269, 0.500000, 0.499361},{0.500791, 0.500000, 0.499967}}],
    Line[{{0.500791, 0.500000, 0.499967},{0.499288, 0.500000, 0.500799}}],
    Line[{{0.499288, 0.500000, 0.500799},{0.500355, 0.500000, 0.498388}}],
    Line[{{0.500355, 0.500000, 0.498388},{0.500447, 0.500000, 0.501511}}],
    Line[{{0.500447, 0.500000, 0.501511},{0.499207, 0.500000, 0.499535}}],
    Line[{{0.499207, 0.500000, 0.499535},{0.500749, 0.500000, 0.499205}}],
    Line[{{0.500749, 0.500000, 0.499205},{0.500016, 0.500000, 0.501870}}],
    Line[{{0.500016, 0.500000, 0.501870},{0.499206, 0.500000, 0.499344}}],
    Line[{{0.499206, 0.500000, 0.499344},{0.500724, 0.500000, 0.498985}}],
    Line[{{0.500724, 0.500000, 0.498985},{0.500474, 0.500000, 0.501614}}],
    Line[{{0.500474, 0.500000, 0.501614},{0.499135, 0.500000, 0.500199}}],
    Line[{{0.499135, 0.500000, 0.500199},{0.500098, 0.500000, 0.498056}}],
    Line[{{0.500098, 0.500000, 0.498056},{0.500867, 0.500000, 0.500343}}],
    Line[{{0.500867, 0.500000, 0.500343},{0.499576, 0.500000, 0.501738}}],
    Line[{{0.499576, 0.500000, 0.501738},{0.499153, 0.500000, 0.499386}}],
    Line[{{0.499153, 0.500000, 0.499386},{0.500516, 0.500000, 0.498371}}],
    Line[{{0.500516, 0.500000, 0.498371},{0.500855, 0.500000, 0.500632}}],
    Line[{{0.500855, 0.500000, 0.500632},{0.499587, 0.500000, 0.501806}}],
    Line[{{0.499587, 0.500000, 0.501806},{0.499088, 0.500000, 0.499775}}],
    Line[{{0.499088, 0.500000, 0.499775},{0.499856, 0.500000, 0.497957}}],
    Line[{{0.499856, 0.500000, 0.497957},{0.500891, 0.500000, 0.499367}}],
    Line[{{0.500891, 0.500000, 0.499367},{0.500766, 0.500000, 0.501228}}],
    Line[{{0.500766, 0.500000, 0.501228},{0.499539, 0.500000, 0.501855}}],
    Line[{{0.499539, 0.500000, 0.501855},{0.499049, 0.500000, 0.500251}}],
    Line[{{0.499049, 0.500000, 0.500251},{0.499250, 0.500000, 0.498640}}],
    Line[{{0.499250, 0.500000, 0.498640},{0.500343, 0.500000, 0.497967}}],
    Line[{{0.500343, 0.500000, 0.497967},{0.500925, 0.500000, 0.499263}}],
    Line[{{0.500925, 0.500000, 0.499263},{0.500949, 0.500000, 0.500628}}],
    Line[{{0.500949, 0.500000, 0.500628},{0.500560, 0.500000, 0.501841}}],
    Line[{{0.500560, 0.500000, 0.501841},{0.499501, 0.500000, 0.501905}}],
    Line[{{0.499501, 0.500000, 0.501905},{0.499056, 0.500000, 0.500587}}],
    Line[{{0.499056, 0.500000, 0.500587},{0.499114, 0.500000, 0.499109}}],
    Line[{{0.499114, 0.500000, 0.499109},{0.499917, 0.500000, 0.497859}}],
    Line[{{0.499917, 0.500000, 0.497859},{0.500858, 0.500000, 0.499061}}],
    Line[{{0.500858, 0.500000, 0.499061},{0.500881, 0.500000, 0.500785}}],
    Line[{{0.500881, 0.500000, 0.500785},{0.499881, 0.500000, 0.502082}}],
    Line[{{0.499881, 0.500000, 0.502082},{0.499089, 0.500000, 0.500436}}],
    Line[{{0.499089, 0.500000, 0.500436},{0.499372, 0.500000, 0.498489}}],
    Line[{{0.499372, 0.500000, 0.498489},{0.500744, 0.500000, 0.498812}}],
    Line[{{0.500744, 0.500000, 0.498812},{0.500799, 0.500000, 0.500957}}],
    Line[{{0.500799, 0.500000, 0.500957},{0.499396, 0.500000, 0.501485}}],
    Line[{{0.499396, 0.500000, 0.501485},{0.499187, 0.500000, 0.499178}}],
    Line[{{0.499187, 0.500000, 0.499178},{0.500626, 0.500000, 0.498588}}],
    Line[{{0.500626, 0.500000, 0.498588},{0.500765, 0.500000, 0.500992}}],
    Line[{{0.500765, 0.500000, 0.500992},{0.499275, 0.500000, 0.501114}}],
    Line[{{0.499275, 0.500000, 0.501114},{0.499387, 0.500000, 0.498609}}],
    Line[{{0.499387, 0.500000, 0.498609},{0.500835, 0.500000, 0.499465}}],
    Line[{{0.500835, 0.500000, 0.499465},{0.500112, 0.500000, 0.501907}}],
    Line[{{0.500112, 0.500000, 0.501907},{0.499165, 0.500000, 0.499627}}],
    Line[{{0.499165, 0.500000, 0.499627},{0.500640, 0.500000, 0.498775}}],
    Line[{{0.500640, 0.500000, 0.498775},{0.500426, 0.500000, 0.501601}}],
    Line[{{0.500426, 0.500000, 0.501601},{0.499187, 0.500000, 0.499681}}],
    Line[{{0.499187, 0.500000, 0.499681},{0.500716, 0.500000, 0.499126}}],
    Line[{{0.500716, 0.500000, 0.499126},{0.499810, 0.500000, 0.501755}}],
    Line[{{0.499810, 0.500000, 0.501755},{0.499465, 0.500000, 0.498670}}],
    Line[{{0.499465, 0.500000, 0.498670},{0.500760, 0.500000, 0.500519}}],
    Line[{{0.500760, 0.500000, 0.500519},{0.499217, 0.500000, 0.500218}}],
    Line[{{0.499217, 0.500000, 0.500218},{0.500684, 0.500000, 0.499148}}],
    Line[{{0.500684, 0.500000, 0.499148},{0.499514, 0.500000, 0.501358}}],
    Line[{{0.499514, 0.500000, 0.501358},{0.500155, 0.500000, 0.498307}}],
    Line[{{0.500155, 0.500000, 0.498307},{0.500221, 0.500000, 0.501640}}],
    Line[{{0.500221, 0.500000, 0.501640},{0.499587, 0.500000, 0.498578}}],
    Line[{{0.499587, 0.500000, 0.498578},{0.500503, 0.500000, 0.501253}}],
    Line[{{0.500503, 0.500000, 0.501253},{0.499475, 0.500000, 0.498817}}],
    Line[{{0.499475, 0.500000, 0.498817},{0.500503, 0.500000, 0.501206}}],
    Line[{{0.500503, 0.500000, 0.501206},{0.499585, 0.500000, 0.498651}}],
    Line[{{0.391204, 0.500000, 0.401535},{0.404243, 0.500000, 0.349123}}],
    Line[{{0.404243, 0.500000, 0.349123},{0.426476, 0.500000, 0.299986}}],
    Line[{{0.426476, 0.500000, 0.299986},{0.463244, 0.500000, 0.261014}}],
    Line[{{0.463244, 0.500000, 0.261014},{0.515040, 0.500000, 0.251793}}],
    Line[{{0.515040, 0.500000, 0.251793},{0.559575, 0.500000, 0.280865}}],
    Line[{{0.559575, 0.500000, 0.280865},{0.587395, 0.500000, 0.326957}}],
    Line[{{0.587395, 0.500000, 0.326957},{0.603979, 0.500000, 0.378334}}],
    Line[{{0.603979, 0.500000, 0.378334},{0.613232, 0.500000, 0.431558}}],
    Line[{{0.613232, 0.500000, 0.431558},{0.616977, 0.500000, 0.485463}}],
    Line[{{0.616977, 0.500000, 0.485463},{0.615869, 0.500000, 0.539488}}],
    Line[{{0.615869, 0.500000, 0.539488},{0.609718, 0.500000, 0.593168}}],
    Line[{{0.609718, 0.500000, 0.593168},{0.597403, 0.500000, 0.645759}}],
    Line[{{0.597403, 0.500000, 0.645759},{0.576282, 0.500000, 0.695398}}],
    Line[{{0.576282, 0.500000, 0.695398},{0.541232, 0.500000, 0.736007}}],
    Line[{{0.541232, 0.500000, 0.736007},{0.490239, 0.500000, 0.749249}}],
    Line[{{0.490239, 0.500000, 0.749249},{0.444043, 0.500000, 0.723122}}],
    Line[{{0.444043, 0.500000, 0.723122},{0.414782, 0.500000, 0.677967}}],
    Line[{{0.414782, 0.500000, 0.677967},{0.397298, 0.500000, 0.626899}}],
    Line[{{0.397298, 0.500000, 0.626899},{0.387422, 0.500000, 0.573787}}],
    Line[{{0.387422, 0.500000, 0.573787},{0.383172, 0.500000, 0.519921}}],
    Line[{{0.383172, 0.500000, 0.519921},{0.383802, 0.500000, 0.465888}}],
    Line[{{0.383802, 0.500000, 0.465888},{0.389418, 0.500000, 0.412148}}],
    Line[{{0.389418, 0.500000, 0.412148},{0.401033, 0.500000, 0.359395}}],
    Line[{{0.401033, 0.500000, 0.359395},{0.421091, 0.500000, 0.309305}}],
    Line[{{0.421091, 0.500000, 0.309305},{0.454467, 0.500000, 0.267240}}],
    Line[{{0.454467, 0.500000, 0.267240},{0.504406, 0.500000, 0.250150}}],
    Line[{{0.504406, 0.500000, 0.250150},{0.552153, 0.500000, 0.273054}}],
    Line[{{0.552153, 0.500000, 0.273054},{0.582923, 0.500000, 0.317150}}],
    Line[{{0.582923, 0.500000, 0.317150},{0.601350, 0.500000, 0.367878}}],
    Line[{{0.601350, 0.500000, 0.367878},{0.611869, 0.500000, 0.420862}}],
    Line[{{0.611869, 0.500000, 0.420862},{0.616632, 0.500000, 0.474684}}],
    Line[{{0.616632, 0.500000, 0.474684},{0.616481, 0.500000, 0.528720}}],
    Line[{{0.616481, 0.500000, 0.528720},{0.611391, 0.500000, 0.582512}}],
    Line[{{0.611391, 0.500000, 0.582512},{0.600455, 0.500000, 0.635412}}],
    Line[{{0.600455, 0.500000, 0.635412},{0.581413, 0.500000, 0.685907}}],
    Line[{{0.581413, 0.500000, 0.685907},{0.549655, 0.500000, 0.729266}}],
    Line[{{0.549655, 0.500000, 0.729266},{0.501000, 0.500000, 0.750000}}],
    Line[{{0.501000, 0.500000, 0.750000},{0.451848, 0.500000, 0.730586}}],
    Line[{{0.451848, 0.500000, 0.730586},{0.419498, 0.500000, 0.687687}}],
    Line[{{0.419498, 0.500000, 0.687687},{0.400086, 0.500000, 0.637337}}],
    Line[{{0.400086, 0.500000, 0.637337},{0.388901, 0.500000, 0.584491}}],
    Line[{{0.388901, 0.500000, 0.584491},{0.383617, 0.500000, 0.530718}}],
    Line[{{0.383617, 0.500000, 0.530718},{0.383289, 0.500000, 0.476683}}],
    Line[{{0.383289, 0.500000, 0.476683},{0.387860, 0.500000, 0.422844}}],
    Line[{{0.387860, 0.500000, 0.422844},{0.398139, 0.500000, 0.369811}}],
    Line[{{0.398139, 0.500000, 0.369811},{0.416212, 0.500000, 0.318954}}],
    Line[{{0.416212, 0.500000, 0.318954},{0.446415, 0.500000, 0.274450}}],
    Line[{{0.446415, 0.500000, 0.274450},{0.493602, 0.500000, 0.250320}}],
    Line[{{0.493602, 0.500000, 0.250320},{0.543960, 0.500000, 0.266004}}],
    Line[{{0.543960, 0.500000, 0.266004},{0.577950, 0.500000, 0.307550}}],
    Line[{{0.577950, 0.500000, 0.307550},{0.598397, 0.500000, 0.357478}}],
    Line[{{0.598397, 0.500000, 0.357478},{0.610269, 0.500000, 0.410173}}],
    Line[{{0.610269, 0.500000, 0.410173},{0.616082, 0.500000, 0.463891}}],
    Line[{{0.616082, 0.500000, 0.463891},{0.616889, 0.500000, 0.517922}}],
    Line[{{0.616889, 0.500000, 0.517922},{0.612828, 0.500000, 0.571803}}],
    Line[{{0.612828, 0.500000, 0.571803},{0.603186, 0.500000, 0.624958}}],
    Line[{{0.603186, 0.500000, 0.624958},{0.586040, 0.500000, 0.676143}}],
    Line[{{0.586040, 0.500000, 0.676143},{0.557323, 0.500000, 0.721660}}],
    Line[{{0.557323, 0.500000, 0.721660},{0.511733, 0.500000, 0.748913}}],
    Line[{{0.511733, 0.500000, 0.748913},{0.460410, 0.500000, 0.737148}}],
    Line[{{0.460410, 0.500000, 0.737148},{0.424727, 0.500000, 0.697125}}],
    Line[{{0.424727, 0.500000, 0.697125},{0.403199, 0.500000, 0.647666}}],
    Line[{{0.403199, 0.500000, 0.647666},{0.390617, 0.500000, 0.595140}}],
    Line[{{0.390617, 0.500000, 0.595140},{0.384265, 0.500000, 0.541484}}],
    Line[{{0.384265, 0.500000, 0.541484},{0.382978, 0.500000, 0.487463}}],
    Line[{{0.382978, 0.500000, 0.487463},{0.386538, 0.500000, 0.433545}}],
    Line[{{0.386538, 0.500000, 0.433545},{0.395563, 0.500000, 0.380280}}],
    Line[{{0.395563, 0.500000, 0.380280},{0.411824, 0.500000, 0.328798}}],
    Line[{{0.411824, 0.500000, 0.328798},{0.439125, 0.500000, 0.282385}}],
    Line[{{0.439125, 0.500000, 0.282385},{0.483022, 0.500000, 0.252287}}],
    Line[{{0.483022, 0.500000, 0.252287},{0.535045, 0.500000, 0.259978}}],
    Line[{{0.535045, 0.500000, 0.259978},{0.572463, 0.500000, 0.298290}}],
    Line[{{0.572463, 0.500000, 0.298290},{0.595123, 0.500000, 0.347226}}],
    Line[{{0.595123, 0.500000, 0.347226},{0.608438, 0.500000, 0.399567}}],
    Line[{{0.511896, 0.738166, 0.748904},{0.526952, 0.776880, 0.744203}}],
    Line[{{0.526952, 0.776880, 0.744203},{0.560414, 0.809857, 0.718194}}],
    Line[{{0.560414, 0.809857, 0.718194},{0.585581, 0.834014, 0.677199}}],
    Line[{{0.585581, 0.834014, 0.677199},{0.602339, 0.849656, 0.628368}}],
    Line[{{0.602339, 0.849656, 0.628368},{0.612288, 0.858739, 0.576081}}],
    Line[{{0.612288, 0.858739, 0.576081},{0.616750, 0.862758, 0.522398}}],
    Line[{{0.616750, 0.862758, 0.522398},{0.616340, 0.862391, 0.468378}}],
    Line[{{0.616340, 0.862391, 0.468378},{0.611003, 0.857576, 0.414842}}],
    Line[{{0.611003, 0.857576, 0.414842},{0.600002, 0.847500, 0.362953}}],
    Line[{{0.600002, 0.847500, 0.362953},{0.581908, 0.830534, 0.315066}}],
    Line[{{0.581908, 0.830534, 0.315066},{0.555216, 0.804788, 0.276082}}],
    Line[{{0.555216, 0.804788, 0.276082},{0.520635, 0.770582, 0.253369}}],
    Line[{{0.520635, 0.770582, 0.253369},{0.518315, 0.731734, 0.252644}}],
    Line[{{0.518315, 0.731734, 0.252644},{0.553269, 0.697116, 0.274119}}],
    Line[{{0.553269, 0.697116, 0.274119},{0.580511, 0.670794, 0.312317}}],
    Line[{{0.580511, 0.670794, 0.312317},{0.599100, 0.653334, 0.359827}}],
    Line[{{0.599100, 0.653334, 0.359827},{0.610494, 0.642886, 0.411554}}],
    Line[{{0.610494, 0.642886, 0.411554},{0.616154, 0.637776, 0.465027}}],
    Line[{{0.616154, 0.637776, 0.465027},{0.616862, 0.637142, 0.519041}}],
    Line[{{0.616862, 0.637142, 0.519041},{0.612713, 0.640876, 0.572771}}],
    Line[{{0.612713, 0.640876, 0.572771},{0.603136, 0.649610, 0.625192}}],
    Line[{{0.603136, 0.649610, 0.625192},{0.586849, 0.664788, 0.674333}}],
    Line[{{0.586849, 0.664788, 0.674333},{0.562230, 0.688376, 0.716001}}],
    Line[{{0.562230, 0.688376, 0.716001},{0.529207, 0.720874, 0.743155}}],
    Line[{{0.529207, 0.720874, 0.743155},{0.509479, 0.759417, 0.749302}}],
    Line[{{0.509479, 0.759417, 0.749302},{0.545651, 0.795404, 0.732676}}],
    Line[{{0.545651, 0.795404, 0.732676},{0.574933, 0.823880, 0.697715}}],
    Line[{{0.574933, 0.823880, 0.697715},{0.595455, 0.843281, 0.651808}}],
    Line[{{0.595455, 0.843281, 0.651808},{0.608382, 0.855194, 0.600775}}],
    Line[{{0.608382, 0.855194, 0.600775},{0.615288, 0.861446, 0.547573}}],
    Line[{{0.615288, 0.861446, 0.547573},{0.617122, 0.863092, 0.493608}}],
    Line[{{0.617122, 0.863092, 0.493608},{0.614136, 0.860409, 0.439737}}],
    Line[{{0.614136, 0.860409, 0.439737},{0.605918, 0.852944, 0.386884}}],
    Line[{{0.605918, 0.852944, 0.386884},{0.591351, 0.839447, 0.336706}}],
    Line[{{0.591351, 0.839447, 0.336706},{0.568797, 0.817982, 0.292745}}],
    Line[{{0.568797, 0.817982, 0.292745},{0.537555, 0.787410, 0.261500}}],
    Line[{{0.537555, 0.787410, 0.261500},{0.501000, 0.750000, 0.250000}}],
    Line[{{0.501000, 0.750000, 0.250000},{0.537555, 0.712590, 0.261500}}],
    Line[{{0.537555, 0.712590, 0.261500},{0.568797, 0.682018, 0.292745}}],
    Line[{{0.568797, 0.682018, 0.292745},{0.591351, 0.660553, 0.336706}}],
    Line[{{0.591351, 0.660553, 0.336706},{0.605918, 0.647056, 0.386884}}],
    Line[{{0.605918, 0.647056, 0.386884},{0.614136, 0.639591, 0.439737}}],
    Line[{{0.614136, 0.639591, 0.439737},{0.617122, 0.636908, 0.493608}}],
    Line[{{0.617122, 0.636908, 0.493608},{0.615288, 0.638554, 0.547573}}],
    Line[{{0.615288, 0.638554, 0.547573},{0.608382, 0.644806, 0.600774}}],
    Line[{{0.608382, 0.644806, 0.600774},{0.595455, 0.656719, 0.651808}}],
    Line[{{0.595455, 0.656719, 0.651808},{0.574933, 0.676119, 0.697716}}],
    Line[{{0.574933, 0.676119, 0.697716},{0.545651, 0.704596, 0.732676}}],
    Line[{{0.545651, 0.704596, 0.732676},{0.509479, 0.740582, 0.749302}}],
    Line[{{0.509479, 0.740582, 0.749302},{0.529194, 0.779112, 0.743162}}],
    Line[{{0.529194, 0.779112, 0.743162},{0.562220, 0.811613, 0.716015}}],
    Line[{{0.562220, 0.811613, 0.716015},{0.586841, 0.835204, 0.674351}}],
    Line[{{0.586841, 0.835204, 0.674351},{0.603130, 0.850384, 0.625211}}],
    Line[{{0.603130, 0.850384, 0.625211},{0.612709, 0.859120, 0.572792}}],
    Line[{{0.612709, 0.859120, 0.572792},{0.616859, 0.862856, 0.519063}}],
    Line[{{0.616859, 0.862856, 0.519063},{0.616154, 0.862224, 0.465050}}],
    Line[{{0.616154, 0.862224, 0.465050},{0.610496, 0.857116, 0.411575}}],
    Line[{{0.610496, 0.857116, 0.411575},{0.599104, 0.846669, 0.359847}}],
    Line[{{0.599104, 0.846669, 0.359847},{0.580518, 0.829212, 0.312334}}],
    Line[{{0.580518, 0.829212, 0.312334},{0.553279, 0.802894, 0.274131}}],
    Line[{{0.553279, 0.802894, 0.274131},{0.518327, 0.768277, 0.252650}}],
    Line[{{0.518327, 0.768277, 0.252650},{0.520633, 0.729421, 0.253370}}],
    Line[{{0.520633, 0.729421, 0.253370},{0.555214, 0.695215, 0.276081}}],
    Line[{{0.555214, 0.695215, 0.276081},{0.581906, 0.669469, 0.315065}}],
    Line[{{0.581906, 0.669469, 0.315065},{0.600000, 0.652502, 0.362952}}],
    Line[{{0.600000, 0.652502, 0.362952},{0.611002, 0.642426, 0.414841}}],
    Line[{{0.611002, 0.642426, 0.414841},{0.616339, 0.637611, 0.468377}}],
    Line[{{0.616339, 0.637611, 0.468377},{0.616749, 0.637244, 0.522397}}],
    Line[{{0.616749, 0.637244, 0.522397},{0.612287, 0.641262, 0.576080}}],
    Line[{{0.612287, 0.641262, 0.576080},{0.602337, 0.650345, 0.628369}}],
    Line[{{0.602337, 0.650345, 0.628369},{0.585581, 0.665986, 0.677198}}],
    Line[{{0.585581, 0.665986, 0.677198},{0.560412, 0.690145, 0.718194}}],
    Line[{{0.560412, 0.690145, 0.718194},{0.526951, 0.723122, 0.744201}}],
    Line[{{0.526951, 0.723122, 0.744201},{0.511912, 0.761847, 0.748898}}],
    Line[{{0.501000, 0.750002, 0.500003},{0.501000, 0.750001, 0.500004}}],
    Line[{{0.501000, 0.750001, 0.500004},{0.501000, 0.750001, 0.500005}}],
    Line[{{0.501000, 0.750001, 0.500005},{0.501000, 0.750001, 0.500005}}],
    Line[{{0.501000, 0.750001, 0.500005},{0.501000, 0.750001, 0.500005}}],
    Line[{{0.501000, 0.750001, 0.500005},{0.501000, 0.750000, 0.500005}}],
    Line[{{0.501000, 0.750000, 0.500005},{0.501000, 0.750000, 0.500005}}],
    Line[{{0.501000, 0.750000, 0.500005},{0.501000, 0.750000, 0.500005}}],
    Line[{{0.501000, 0.750000, 0.500005},{0.501000, 0.749999, 0.500005}}],
    Line[{{0.501000, 0.749999, 0.500005},{0.501000, 0.749999, 0.500004}}],
    Line[{{0.501000, 0.749999, 0.500004},{0.501000, 0.749999, 0.500004}}],
    Line[{{0.501000, 0.749999, 0.500004},{0.501000, 0.749999, 0.500003}}],
    Line[{{0.501000, 0.749999, 0.500003},{0.501000, 0.749998, 0.500003}}],
    Line[{{0.501000, 0.749998, 0.500003},{0.501000, 0.749998, 0.500002}}],
    Line[{{0.501000, 0.749998, 0.500002},{0.501000, 0.749998, 0.500001}}],
    Line[{{0.501000, 0.749998, 0.500001},{0.501000, 0.749998, 0.500000}}],
    Line[{{0.501000, 0.749998, 0.500000},{0.501000, 0.749998, 0.500000}}],
    Line[{{0.501000, 0.749998, 0.500000},{0.501000, 0.749998, 0.499999}}],
    Line[{{0.501000, 0.749998, 0.499999},{0.501000, 0.749998, 0.499999}}],
    Line[{{0.501000, 0.749998, 0.499999},{0.501000, 0.749998, 0.499998}}],
    Line[{{0.501000, 0.749998, 0.499998},{0.501000, 0.749998, 0.499997}}],
    Line[{{0.501000, 0.749998, 0.499997},{0.501000, 0.749998, 0.499997}}],
    Line[{{0.501000, 0.749998, 0.499997},{0.501000, 0.749999, 0.499996}}],
    Line[{{0.501000, 0.749999, 0.499996},{0.501000, 0.749999, 0.499995}}],
    Line[{{0.501000, 0.749999, 0.499995},{0.501000, 0.749999, 0.499995}}],
    Line[{{0.501000, 0.749999, 0.499995},{0.501000, 0.749999, 0.499995}}],
    Line[{{0.501000, 0.749999, 0.499995},{0.501000, 0.750000, 0.499995}}],
    Line[{{0.501000, 0.750000, 0.499995},{0.501000, 0.750000, 0.499995}}],
    Line[{{0.501000, 0.750000, 0.499995},{0.501000, 0.750000, 0.499995}}],
    Line[{{0.501000, 0.750000, 0.499995},{0.501000, 0.750001, 0.499995}}],
    Line[{{0.501000, 0.750001, 0.499995},{0.501000, 0.750001, 0.499995}}],
    Line[{{0.501000, 0.750001, 0.499995},{0.501000, 0.750001, 0.499996}}],
    Line[{{0.501000, 0.750001, 0.499996},{0.501000, 0.750001, 0.499997}}],
    Line[{{0.501000, 0.750001, 0.499997},{0.501000, 0.750002, 0.499997}}],
    Line[{{0.501000, 0.750002, 0.499997},{0.501000, 0.750002, 0.499998}}],
    Line[{{0.501000, 0.750002, 0.499998},{0.501000, 0.750002, 0.499998}}],
    Line[{{0.501000, 0.750002, 0.499998},{0.501000, 0.749999, 0.499999}}],
    Line[{{0.501000, 0.749999, 0.499999},{0.501000, 0.750002, 0.499997}}],
    Line[{{0.501000, 0.750002, 0.499997},{0.501000, 0.750001, 0.500005}}],
    Line[{{0.501000, 0.750001, 0.500005},{0.501000, 0.749998, 0.500000}}],
    Line[{{0.501000, 0.749998, 0.500000},{0.501000, 0.750000, 0.499995}}],
    Line[{{0.501000, 0.750000, 0.499995},{0.501000, 0.750002, 0.500002}}],
    Line[{{0.501000, 0.750002, 0.500002},{0.501000, 0.749998, 0.500003}}],
    Line[{{0.501000, 0.749998, 0.500003},{0.501000, 0.749999, 0.499996}}],
    Line[{{0.501000, 0.749999, 0.499996},{0.501000, 0.750002, 0.499999}}],
    Line[{{0.501000, 0.750002, 0.499999},{0.501000, 0.750000, 0.500005}}],
    Line[{{0.501000, 0.750000, 0.500005},{0.501000, 0.749998, 0.499998}}],
    Line[{{0.501000, 0.749998, 0.499998},{0.501000, 0.750001, 0.499996}}],
    Line[{{0.501000, 0.750001, 0.499996},{0.501000, 0.750001, 0.500004}}],
    Line[{{0.501000, 0.750001, 0.500004},{0.501000, 0.749998, 0.500001}}],
    Line[{{0.501000, 0.749998, 0.500001},{0.501000, 0.750000, 0.499995}}],
    Line[{{0.501000, 0.750000, 0.499995},{0.501000, 0.750002, 0.500001}}],
    Line[{{0.501000, 0.750002, 0.500001},{0.501000, 0.749999, 0.500004}}],
    Line[{{0.501000, 0.749999, 0.500004},{0.501000, 0.749999, 0.499996}}],
    Line[{{0.501000, 0.749999, 0.499996},{0.501000, 0.750002, 0.499998}}],
    Line[{{0.501000, 0.750002, 0.499998},{0.501000, 0.750000, 0.500005}}],
    Line[{{0.501000, 0.750000, 0.500005},{0.501000, 0.749998, 0.499999}}],
    Line[{{0.501000, 0.749998, 0.499999},{0.501000, 0.750001, 0.499996}}],
    Line[{{0.501000, 0.750001, 0.499996},{0.501000, 0.750001, 0.500003}}],
    Line[{{0.501000, 0.750001, 0.500003},{0.501000, 0.749998, 0.500002}}],
    Line[{{0.501000, 0.749998, 0.500002},{0.501000, 0.750000, 0.499995}}],
    Line[{{0.501000, 0.750000, 0.499995},{0.501000, 0.750002, 0.500000}}],
    Line[{{0.501000, 0.750002, 0.500000},{0.501000, 0.749999, 0.500005}}],
    Line[{{0.501000, 0.749999, 0.500005},{0.501000, 0.749998, 0.499997}}],
    Line[{{0.501000, 0.749998, 0.499997},{0.501000, 0.750002, 0.499998}}],
    Line[{{0.501000, 0.750002, 0.499998},{0.501000, 0.750000, 0.500005}}],
    Line[{{0.501000, 0.750000, 0.500005},{0.501000, 0.749998, 0.500000}}],
    Line[{{0.501000, 0.749998, 0.500000},{0.501000, 0.750001, 0.499995}}],
    Line[{{0.501000, 0.750001, 0.499995},{0.501000, 0.750002, 0.500002}}],
    Line[{{0.501000, 0.750002, 0.500002},{0.501000, 0.749998, 0.500003}}],
    Line[{{0.501000, 0.749998, 0.500003},{0.501000, 0.749999, 0.499995}}],
    Line[{{0.501000, 0.749999, 0.499995},{0.501000, 0.750002, 0.500000}}],
    Line[{{0.501000, 0.750002, 0.500000},{0.501000, 0.750000, 0.500005}}],
    Line[{{0.501000, 0.750000, 0.500005},{0.501000, 0.749998, 0.499998}}],
    Line[{{0.501000, 0.749998, 0.499998},{0.501000, 0.750002, 0.499997}}],
    Line[{{0.511791, 0.761731, 0.251075},{0.527039, 0.723033, 0.255833}}],
    Line[{{0.527039, 0.723033, 0.255833},{0.560484, 0.690075, 0.281884}}],
    Line[{{0.560484, 0.690075, 0.281884},{0.585632, 0.665938, 0.322906}}],
    Line[{{0.585632, 0.665938, 0.322906},{0.602370, 0.650315, 0.371749}}],
    Line[{{0.602370, 0.650315, 0.371749},{0.612306, 0.641245, 0.424043}}],
    Line[{{0.612306, 0.641245, 0.424043},{0.616756, 0.637237, 0.477727}}],
    Line[{{0.616756, 0.637237, 0.477727},{0.616335, 0.637614, 0.531747}}],
    Line[{{0.616335, 0.637614, 0.531747},{0.610986, 0.642440, 0.585281}}],
    Line[{{0.610986, 0.642440, 0.585281},{0.599970, 0.652529, 0.637164}}],
    Line[{{0.599970, 0.652529, 0.637164},{0.581858, 0.669514, 0.685037}}],
    Line[{{0.581858, 0.669514, 0.685037},{0.555146, 0.695280, 0.723994}}],
    Line[{{0.555146, 0.695280, 0.723994},{0.520551, 0.729501, 0.746662}}],
    Line[{{0.520551, 0.729501, 0.746662},{0.518374, 0.768328, 0.747340}}],
    Line[{{0.518374, 0.768328, 0.747340},{0.553321, 0.802936, 0.725833}}],
    Line[{{0.553321, 0.802936, 0.725833},{0.580547, 0.829241, 0.687612}}],
    Line[{{0.580547, 0.829241, 0.687612},{0.599124, 0.846688, 0.640091}}],
    Line[{{0.599124, 0.846688, 0.640091},{0.610508, 0.857127, 0.588361}}],
    Line[{{0.610508, 0.857127, 0.588361},{0.616159, 0.862229, 0.534886}}],
    Line[{{0.616159, 0.862229, 0.534886},{0.616859, 0.862856, 0.480872}}],
    Line[{{0.616859, 0.862856, 0.480872},{0.612702, 0.859115, 0.427144}}],
    Line[{{0.612702, 0.859115, 0.427144},{0.603115, 0.850372, 0.374726}}],
    Line[{{0.603115, 0.850372, 0.374726},{0.586817, 0.835182, 0.325593}}],
    Line[{{0.586817, 0.835182, 0.325593},{0.562184, 0.811579, 0.283942}}],
    Line[{{0.562184, 0.811579, 0.283942},{0.529149, 0.779069, 0.256816}}],
    Line[{{0.529149, 0.779069, 0.256816},{0.509478, 0.740579, 0.250697}}],
    Line[{{0.509478, 0.740579, 0.250697},{0.545652, 0.704594, 0.267325}}],
    Line[{{0.545652, 0.704594, 0.267325},{0.574933, 0.676119, 0.302285}}],
    Line[{{0.574933, 0.676119, 0.302285},{0.595455, 0.656719, 0.348193}}],
    Line[{{0.595455, 0.656719, 0.348193},{0.608382, 0.644806, 0.399227}}],
    Line[{{0.608382, 0.644806, 0.399227},{0.615288, 0.638554, 0.452429}}],
    Line[{{0.615288, 0.638554, 0.452429},{0.617122, 0.636908, 0.506394}}],
    Line[{{0.617122, 0.636908, 0.506394},{0.614136, 0.639591, 0.560264}}],
    Line[{{0.614136, 0.639591, 0.560264},{0.605918, 0.647056, 0.613116}}],
    Line[{{0.605918, 0.647056, 0.613116},{0.591351, 0.660553, 0.663294}}],
    Line[{{0.591351, 0.660553, 0.663294},{0.568797, 0.682018, 0.707255}}],
    Line[{{0.568797, 0.682018, 0.707255},{0.537555, 0.712590, 0.738500}}],
    Line[{{0.537555, 0.712590, 0.738500},{0.501000, 0.750000, 0.750000}}],
    Line[{{0.501000, 0.750000, 0.750000},{0.537555, 0.787410, 0.738500}}],
    Line[{{0.537555, 0.787410, 0.738500},{0.568797, 0.817982, 0.707255}}],
    Line[{{0.568797, 0.817982, 0.707255},{0.591351, 0.839447, 0.663294}}],
    Line[{{0.591351, 0.839447, 0.663294},{0.605918, 0.852944, 0.613116}}],
    Line[{{0.605918, 0.852944, 0.613116},{0.614136, 0.860409, 0.560264}}],
    Line[{{0.614136, 0.860409, 0.560264},{0.617122, 0.863092, 0.506394}}],
    Line[{{0.617122, 0.863092, 0.506394},{0.615288, 0.861446, 0.452429}}],
    Line[{{0.615288, 0.861446, 0.452429},{0.608382, 0.855194, 0.399227}}],
    Line[{{0.608382, 0.855194, 0.399227},{0.595455, 0.843281, 0.348193}}],
    Line[{{0.595455, 0.843281, 0.348193},{0.574933, 0.823881, 0.302285}}],
    Line[{{0.574933, 0.823881, 0.302285},{0.545652, 0.795406, 0.267325}}],
    Line[{{0.545652, 0.795406, 0.267325},{0.509478, 0.759421, 0.250697}}],
    Line[{{0.509478, 0.759421, 0.250697},{0.529180, 0.720901, 0.256831}}],
    Line[{{0.529180, 0.720901, 0.256831},{0.562209, 0.688397, 0.283972}}],
    Line[{{0.562209, 0.688397, 0.283972},{0.586834, 0.664802, 0.325632}}],
    Line[{{0.586834, 0.664802, 0.325632},{0.603126, 0.649618, 0.374769}}],
    Line[{{0.603126, 0.649618, 0.374769},{0.612708, 0.640880, 0.427189}}],
    Line[{{0.612708, 0.640880, 0.427189},{0.616861, 0.637142, 0.480918}}],
    Line[{{0.616861, 0.637142, 0.480918},{0.616157, 0.637774, 0.534932}}],
    Line[{{0.616157, 0.637774, 0.534932},{0.610501, 0.642880, 0.588406}}],
    Line[{{0.610501, 0.642880, 0.588406},{0.599111, 0.653324, 0.640135}}],
    Line[{{0.599111, 0.653324, 0.640135},{0.580529, 0.670777, 0.687649}}],
    Line[{{0.580529, 0.670777, 0.687649},{0.553294, 0.697091, 0.725860}}],
    Line[{{0.553294, 0.697091, 0.725860},{0.518341, 0.731706, 0.747349}}],
    Line[{{0.518341, 0.731706, 0.747349},{0.520589, 0.770536, 0.746648}}],
    Line[{{0.520589, 0.770536, 0.746648},{0.555179, 0.804751, 0.723962}}],
    Line[{{0.555179, 0.804751, 0.723962},{0.581881, 0.830508, 0.684992}}],
    Line[{{0.581881, 0.830508, 0.684992},{0.599984, 0.847483, 0.637112}}],
    Line[{{0.599984, 0.847483, 0.637112},{0.610993, 0.857566, 0.585227}}],
    Line[{{0.610993, 0.857566, 0.585227},{0.616336, 0.862387, 0.531693}}],
    Line[{{0.616336, 0.862387, 0.531693},{0.616752, 0.862760, 0.477673}}],
    Line[{{0.616752, 0.862760, 0.477673},{0.612297, 0.858747, 0.423989}}],
    Line[{{0.612297, 0.858747, 0.423989},{0.602355, 0.849671, 0.371697}}],
    Line[{{0.602355, 0.849671, 0.371697},{0.585609, 0.834040, 0.322860}}],
    Line[{{0.585609, 0.834040, 0.322860},{0.560451, 0.809894, 0.281850}}],
    Line[{{0.560451, 0.809894, 0.281850},{0.527000, 0.776927, 0.255819}}],
    Line[{{0.527000, 0.776927, 0.255819},{0.511860, 0.738204, 0.251090}}],
    Line[{{0.768979, 0.356045, 0.595509},{0.765166, 0.344399, 0.648112}}],
    Line[{{0.765166, 0.344399, 0.648112},{0.759615, 0.323886, 0.697684}}],
    Line[{{0.759615, 0.323886, 0.697684},{0.753351, 0.288717, 0.737625}}],
    Line[{{0.753351, 0.288717, 0.737625},{0.751255, 0.237363, 0.748724}}],
    Line[{{0.751255, 0.237363, 0.748724},{0.756207, 0.192450, 0.720863}}],
    Line[{{0.756207, 0.192450, 0.720863},{0.762426, 0.165059, 0.674962}}],
    Line[{{0.762426, 0.165059, 0.674962},{0.767183, 0.149251, 0.623565}}],
    Line[{{0.767183, 0.149251, 0.623565},{0.770166, 0.140608, 0.570321}}],
    Line[{{0.770166, 0.140608, 0.570321},{0.771466, 0.137078, 0.516418}}],
    Line[{{0.771466, 0.137078, 0.516418},{0.771150, 0.137923, 0.462388}}],
    Line[{{0.771150, 0.137923, 0.462388},{0.769202, 0.143314, 0.408660}}],
    Line[{{0.769202, 0.143314, 0.408660},{0.765528, 0.154423, 0.355928}}],
    Line[{{0.765528, 0.154423, 0.355928},{0.760101, 0.174073, 0.305982}}],
    Line[{{0.760101, 0.174073, 0.305982},{0.753785, 0.207848, 0.264798}}],
    Line[{{0.753785, 0.207848, 0.264798},{0.751115, 0.258468, 0.250574}}],
    Line[{{0.751115, 0.258468, 0.250574},{0.755703, 0.304719, 0.276029}}],
    Line[{{0.755703, 0.304719, 0.276029},{0.761980, 0.333295, 0.321162}}],
    Line[{{0.761980, 0.333295, 0.321162},{0.766874, 0.349810, 0.372316}}],
    Line[{{0.766874, 0.349810, 0.372316},{0.769994, 0.358918, 0.425473}}],
    Line[{{0.769994, 0.358918, 0.425473},{0.771422, 0.362809, 0.479349}}],
    Line[{{0.771422, 0.362809, 0.479349},{0.771233, 0.362301, 0.533383}}],
    Line[{{0.771233, 0.362301, 0.533383},{0.769415, 0.357294, 0.587154}}],
    Line[{{0.769415, 0.357294, 0.587154},{0.765880, 0.346707, 0.640004}}],
    Line[{{0.765880, 0.346707, 0.640004},{0.760582, 0.327888, 0.690292}}],
    Line[{{0.760582, 0.327888, 0.690292},{0.754242, 0.295474, 0.732610}}],
    Line[{{0.754242, 0.295474, 0.732610},{0.751030, 0.245750, 0.749852}}],
    Line[{{0.751030, 0.245750, 0.749852},{0.755205, 0.198237, 0.726973}}],
    Line[{{0.755205, 0.198237, 0.726973},{0.761522, 0.168427, 0.682690}}],
    Line[{{0.761522, 0.168427, 0.682690},{0.766553, 0.151175, 0.631800}}],
    Line[{{0.766553, 0.151175, 0.631800},{0.769811, 0.141588, 0.578738}}],
    Line[{{0.769811, 0.141588, 0.578738},{0.771368, 0.137331, 0.524894}}],
    Line[{{0.771368, 0.137331, 0.524894},{0.771305, 0.137501, 0.470857}}],
    Line[{{0.771305, 0.137501, 0.470857},{0.769618, 0.142130, 0.417048}}],
    Line[{{0.769618, 0.142130, 0.417048},{0.766221, 0.152209, 0.364087}}],
    Line[{{0.766221, 0.152209, 0.364087},{0.761055, 0.170229, 0.313484}}],
    Line[{{0.761055, 0.170229, 0.313484},{0.754715, 0.201320, 0.270135}}],
    Line[{{0.754715, 0.201320, 0.270135},{0.751000, 0.250000, 0.250000}}],
    Line[{{0.751000, 0.250000, 0.250000},{0.754715, 0.298680, 0.270135}}],
    Line[{{0.754715, 0.298680, 0.270135},{0.761055, 0.329771, 0.313484}}],
    Line[{{0.761055, 0.329771, 0.313484},{0.766221, 0.347791, 0.364087}}],
    Line[{{0.766221, 0.347791, 0.364087},{0.769618, 0.357870, 0.417048}}],
    Line[{{0.769618, 0.357870, 0.417048},{0.771305, 0.362499, 0.470857}}],
    Line[{{0.771305, 0.362499, 0.470857},{0.771368, 0.362669, 0.524894}}],
    Line[{{0.771368, 0.362669, 0.524894},{0.769811, 0.358412, 0.578738}}],
    Line[{{0.769811, 0.358412, 0.578738},{0.766553, 0.348825, 0.631800}}],
    Line[{{0.766553, 0.348825, 0.631800},{0.761523, 0.331572, 0.682689}}],
    Line[{{0.761523, 0.331572, 0.682689},{0.755206, 0.301765, 0.726972}}],
    Line[{{0.755206, 0.301765, 0.726972},{0.751030, 0.254251, 0.749853}}],
    Line[{{0.751030, 0.254251, 0.749853},{0.754242, 0.204528, 0.732611}}],
    Line[{{0.754242, 0.204528, 0.732611},{0.760581, 0.172113, 0.690294}}],
    Line[{{0.760581, 0.172113, 0.690294},{0.765880, 0.153293, 0.640006}}],
    Line[{{0.765880, 0.153293, 0.640006},{0.769415, 0.142706, 0.587155}}],
    Line[{{0.769415, 0.142706, 0.587155},{0.771233, 0.137699, 0.533385}}],
    Line[{{0.771233, 0.137699, 0.533385},{0.771422, 0.137191, 0.479350}}],
    Line[{{0.771422, 0.137191, 0.479350},{0.769994, 0.141081, 0.425475}}],
    Line[{{0.769994, 0.141081, 0.425475},{0.766874, 0.150189, 0.372318}}],
    Line[{{0.766874, 0.150189, 0.372318},{0.761980, 0.166704, 0.321163}}],
    Line[{{0.761980, 0.166704, 0.321163},{0.755703, 0.195280, 0.276030}}],
    Line[{{0.755703, 0.195280, 0.276030},{0.751116, 0.241530, 0.250574}}],
    Line[{{0.751116, 0.241530, 0.250574},{0.753786, 0.292150, 0.264797}}],
    Line[{{0.753786, 0.292150, 0.264797},{0.760101, 0.325926, 0.305981}}],
    Line[{{0.760101, 0.325926, 0.305981},{0.765528, 0.345576, 0.355927}}],
    Line[{{0.765528, 0.345576, 0.355927},{0.769203, 0.356685, 0.408660}}],
    Line[{{0.769203, 0.356685, 0.408660},{0.771151, 0.362076, 0.462388}}],
    Line[{{0.771151, 0.362076, 0.462388},{0.771467, 0.362920, 0.516419}}],
    Line[{{0.771467, 0.362920, 0.516419},{0.770167, 0.359390, 0.570323}}],
    Line[{{0.770167, 0.359390, 0.570323},{0.767183, 0.350748, 0.623568}}],
    Line[{{0.767183, 0.350748, 0.623568},{0.762426, 0.334939, 0.674965}}],
    Line[{{0.762426, 0.334939, 0.674965},{0.756207, 0.307549, 0.720866}}],
    Line[{{0.756207, 0.307549, 0.720866},{0.751255, 0.262633, 0.748728}}],
    Line[{{0.751255, 0.262633, 0.748728},{0.753352, 0.211282, 0.737624}}],
    Line[{{0.753352, 0.211282, 0.737624},{0.759615, 0.176113, 0.697684}}],
    Line[{{0.759615, 0.176113, 0.697684},{0.765167, 0.155600, 0.648111}}],
    Line[{{0.765167, 0.155600, 0.648111},{0.768981, 0.143954, 0.595507}}],
    Line[{{0.751000, 0.250030, 0.499921},{0.751000, 0.250009, 0.499898}}],
    Line[{{0.751000, 0.250009, 0.499898},{0.751000, 0.249981, 0.499906}}],
    Line[{{0.751000, 0.249981, 0.499906},{0.751000, 0.249963, 0.499935}}],
    Line[{{0.751000, 0.249963, 0.499935},{0.751000, 0.249957, 0.499963}}],
    Line[{{0.751000, 0.249957, 0.499963},{0.751000, 0.249955, 0.499981}}],
    Line[{{0.751000, 0.249955, 0.499981},{0.751000, 0.249955, 0.499995}}],
    Line[{{0.751000, 0.249955, 0.499995},{0.751000, 0.249955, 0.500004}}],
    Line[{{0.751000, 0.249955, 0.500004},{0.751000, 0.249956, 0.500008}}],
    Line[{{0.751000, 0.249956, 0.500008},{0.751000, 0.249956, 0.500008}}],
    Line[{{0.751000, 0.249956, 0.500008},{0.751000, 0.249957, 0.500004}}],
    Line[{{0.751000, 0.249957, 0.500004},{0.751000, 0.249957, 0.499995}}],
    Line[{{0.751000, 0.249957, 0.499995},{0.751000, 0.249959, 0.499978}}],
    Line[{{0.751000, 0.249959, 0.499978},{0.751000, 0.249965, 0.499953}}],
    Line[{{0.751000, 0.249965, 0.499953},{0.751000, 0.249984, 0.499921}}],
    Line[{{0.751000, 0.249984, 0.499921},{0.751000, 0.250026, 0.499938}}],
    Line[{{0.751000, 0.250026, 0.499938},{0.751000, 0.250037, 0.500004}}],
    Line[{{0.751000, 0.250037, 0.500004},{0.751000, 0.250010, 0.500075}}],
    Line[{{0.751000, 0.250010, 0.500075},{0.751000, 0.249966, 0.500012}}],
    Line[{{0.751000, 0.249966, 0.500012},{0.751000, 0.250002, 0.499927}}],
    Line[{{0.751000, 0.250002, 0.499927},{0.751000, 0.250034, 0.500023}}],
    Line[{{0.751000, 0.250034, 0.500023},{0.751000, 0.249975, 0.500053}}],
    Line[{{0.751000, 0.249975, 0.500053},{0.751000, 0.249979, 0.499945}}],
    Line[{{0.751000, 0.249979, 0.499945},{0.751000, 0.250028, 0.500028}}],
    Line[{{0.751000, 0.250028, 0.500028},{0.751000, 0.249966, 0.499997}}],
    Line[{{0.751000, 0.249966, 0.499997},{0.751000, 0.250024, 0.499950}}],
    Line[{{0.751000, 0.250024, 0.499950},{0.751000, 0.250010, 0.500064}}],
    Line[{{0.751000, 0.250010, 0.500064},{0.751000, 0.249983, 0.499947}}],
    Line[{{0.751000, 0.249983, 0.499947},{0.751000, 0.250021, 0.500047}}],
    Line[{{0.751000, 0.250021, 0.500047},{0.751000, 0.249994, 0.499945}}],
    Line[{{0.751000, 0.249994, 0.499945},{0.751000, 0.249978, 0.500036}}],
    Line[{{0.751000, 0.249978, 0.500036},{0.751000, 0.250026, 0.500004}}],
    Line[{{0.751000, 0.250026, 0.500004},{0.751000, 0.250006, 0.499950}}],
    Line[{{0.751000, 0.250006, 0.499950},{0.751000, 0.249980, 0.499972}}],
    Line[{{0.751000, 0.249980, 0.499972},{0.751000, 0.249977, 0.499987}}],
    Line[{{0.751000, 0.249977, 0.499987},{0.751000, 0.249978, 0.499991}}],
    Line[{{0.751000, 0.249978, 0.499991},{0.751000, 0.249999, 0.499960}}],
    Line[{{0.751000, 0.249999, 0.499960},{0.751000, 0.250017, 0.500021}}],
    Line[{{0.751000, 0.250017, 0.500021},{0.751000, 0.249984, 0.500021}}],
    Line[{{0.751000, 0.249984, 0.500021},{0.751000, 0.249999, 0.499960}}],
    Line[{{0.751000, 0.249999, 0.499960},{0.751000, 0.250020, 0.500000}}],
    Line[{{0.751000, 0.250020, 0.500000},{0.751000, 0.250014, 0.500034}}],
    Line[{{0.751000, 0.250014, 0.500034},{0.751000, 0.249982, 0.500019}}],
    Line[{{0.751000, 0.249982, 0.500019},{0.751000, 0.249985, 0.499975}}],
    Line[{{0.751000, 0.249985, 0.499975},{0.751000, 0.250015, 0.500018}}],
    Line[{{0.751000, 0.250015, 0.500018},{0.751000, 0.250012, 0.499979}}],
    Line[{{0.751000, 0.250012, 0.499979},{0.751000, 0.250003, 0.499972}}],
    Line[{{0.751000, 0.250003, 0.499972},{0.751000, 0.250004, 0.500025}}],
    Line[{{0.751000, 0.250004, 0.500025},{0.751000, 0.250010, 0.499998}}],
    Line[{{0.751000, 0.250010, 0.499998},{0.751000, 0.250010, 0.500010}}],
    Line[{{0.751000, 0.250010, 0.500010},{0.751000, 0.249992, 0.500013}}],
    Line[{{0.751000, 0.249992, 0.500013},{0.751000, 0.249990, 0.499992}}],
    Line[{{0.751000, 0.249990, 0.499992},{0.751000, 0.250007, 0.499985}}],
    Line[{{0.751000, 0.250007, 0.499985},{0.751000, 0.249999, 0.500014}}],
    Line[{{0.751000, 0.249999, 0.500014},{0.751000, 0.250004, 0.500008}}],
    Line[{{0.751000, 0.250004, 0.500008},{0.751000, 0.250000, 0.500000}}],
    Line[{{0.751000, 0.250000, 0.500000},{0.751000, 0.250000, 0.500004}}],
    Line[{{0.751000, 0.250000, 0.500004},{0.751000, 0.250000, 0.500004}}],
    Line[{{0.751000, 0.250000, 0.500004},{0.751000, 0.250000, 0.500004}}],
    Line[{{0.751000, 0.250000, 0.500004},{0.751000, 0.250000, 0.500004}}],
    Line[{{0.751000, 0.250000, 0.500004},{0.751000, 0.250000, 0.500004}}],
    Line[{{0.751000, 0.250000, 0.500004},{0.751000, 0.249999, 0.500003}}],
    Line[{{0.751000, 0.249999, 0.500003},{0.751000, 0.249999, 0.500003}}],
    Line[{{0.751000, 0.249999, 0.500003},{0.751000, 0.249999, 0.500003}}],
    Line[{{0.751000, 0.249999, 0.500003},{0.751000, 0.249999, 0.500002}}],
    Line[{{0.751000, 0.249999, 0.500002},{0.751000, 0.249999, 0.500002}}],
    Line[{{0.751000, 0.249999, 0.500002},{0.751000, 0.249998, 0.500001}}],
    Line[{{0.751000, 0.249998, 0.500001},{0.751000, 0.249998, 0.500001}}],
    Line[{{0.751000, 0.249998, 0.500001},{0.751000, 0.249998, 0.500000}}],
    Line[{{0.751000, 0.249998, 0.500000},{0.751000, 0.249998, 0.500000}}],
    Line[{{0.751000, 0.249998, 0.500000},{0.751000, 0.249998, 0.499999}}],
    Line[{{0.751000, 0.249998, 0.499999},{0.751000, 0.249998, 0.499999}}],
    Line[{{0.751000, 0.249998, 0.499999},{0.751000, 0.249998, 0.499998}}],
    Line[{{0.751000, 0.249998, 0.499998},{0.751000, 0.249999, 0.499998}}],
    Line[{{0.751000, 0.249999, 0.499998},{0.751000, 0.249999, 0.499998}}],
    Line[{{0.768980, 0.143955, 0.404493},{0.765167, 0.155601, 0.351890}}],
    Line[{{0.765167, 0.155601, 0.351890},{0.759615, 0.176114, 0.302318}}],
    Line[{{0.759615, 0.176114, 0.302318},{0.753352, 0.211282, 0.262376}}],
    Line[{{0.753352, 0.211282, 0.262376},{0.751255, 0.262635, 0.251275}}],
    Line[{{0.751255, 0.262635, 0.251275},{0.756206, 0.307548, 0.279135}}],
    Line[{{0.756206, 0.307548, 0.279135},{0.762426, 0.334940, 0.325036}}],
    Line[{{0.762426, 0.334940, 0.325036},{0.767183, 0.350748, 0.376433}}],
    Line[{{0.767183, 0.350748, 0.376433},{0.770166, 0.359392, 0.429676}}],
    Line[{{0.770166, 0.359392, 0.429676},{0.771466, 0.362922, 0.483580}}],
    Line[{{0.771466, 0.362922, 0.483580},{0.771150, 0.362077, 0.537610}}],
    Line[{{0.771150, 0.362077, 0.537610},{0.769202, 0.356687, 0.591338}}],
    Line[{{0.769202, 0.356687, 0.591338},{0.765528, 0.345578, 0.644069}}],
    Line[{{0.765528, 0.345578, 0.644069},{0.760101, 0.325928, 0.694015}}],
    Line[{{0.760101, 0.325928, 0.694015},{0.753786, 0.292154, 0.735200}}],
    Line[{{0.753786, 0.292154, 0.735200},{0.751115, 0.241535, 0.749427}}],
    Line[{{0.751115, 0.241535, 0.749427},{0.755703, 0.195283, 0.723972}}],
    Line[{{0.755703, 0.195283, 0.723972},{0.761979, 0.166706, 0.678840}}],
    Line[{{0.761979, 0.166706, 0.678840},{0.766874, 0.150190, 0.627686}}],
    Line[{{0.766874, 0.150190, 0.627686},{0.769994, 0.141082, 0.574529}}],
    Line[{{0.769994, 0.141082, 0.574529},{0.771422, 0.137192, 0.520653}}],
    Line[{{0.771422, 0.137192, 0.520653},{0.771233, 0.137699, 0.466619}}],
    Line[{{0.771233, 0.137699, 0.466619},{0.769415, 0.142706, 0.412849}}],
    Line[{{0.769415, 0.142706, 0.412849},{0.765880, 0.153293, 0.359998}}],
    Line[{{0.765880, 0.153293, 0.359998},{0.760582, 0.172112, 0.309709}}],
    Line[{{0.760582, 0.172112, 0.309709},{0.754242, 0.204526, 0.267392}}],
    Line[{{0.754242, 0.204526, 0.267392},{0.751030, 0.254249, 0.250148}}],
    Line[{{0.751030, 0.254249, 0.250148},{0.755205, 0.301762, 0.273027}}],
    Line[{{0.755205, 0.301762, 0.273027},{0.761522, 0.331572, 0.317310}}],
    Line[{{0.761522, 0.331572, 0.317310},{0.766553, 0.348824, 0.368200}}],
    Line[{{0.766553, 0.348824, 0.368200},{0.769811, 0.358412, 0.421262}}],
    Line[{{0.769811, 0.358412, 0.421262},{0.771368, 0.362669, 0.475105}}],
    Line[{{0.771368, 0.362669, 0.475105},{0.771305, 0.362499, 0.529142}}],
    Line[{{0.771305, 0.362499, 0.529142},{0.769618, 0.357870, 0.582951}}],
    Line[{{0.769618, 0.357870, 0.582951},{0.766221, 0.347791, 0.635912}}],
    Line[{{0.766221, 0.347791, 0.635912},{0.761055, 0.329771, 0.686515}}],
    Line[{{0.761055, 0.329771, 0.686515},{0.754715, 0.298680, 0.729864}}],
    Line[{{0.754715, 0.298680, 0.729864},{0.751000, 0.250000, 0.750000}}],
    Line[{{0.751000, 0.250000, 0.750000},{0.754715, 0.201320, 0.729865}}],
    Line[{{0.754715, 0.201320, 0.729865},{0.761055, 0.170228, 0.686515}}],
    Line[{{0.761055, 0.170228, 0.686515},{0.766222, 0.152208, 0.635911}}],
    Line[{{0.766222, 0.152208, 0.635911},{0.769618, 0.142130, 0.582948}}],
    Line[{{0.769618, 0.142130, 0.582948},{0.771306, 0.137501, 0.529139}}],
    Line[{{0.771306, 0.137501, 0.529139},{0.771369, 0.137333, 0.475101}}],
    Line[{{0.771369, 0.137333, 0.475101},{0.769811, 0.141590, 0.421257}}],
    Line[{{0.769811, 0.141590, 0.421257},{0.766554, 0.151177, 0.368194}}],
    Line[{{0.766554, 0.151177, 0.368194},{0.761522, 0.168430, 0.317303}}],
    Line[{{0.761522, 0.168430, 0.317303},{0.755205, 0.198240, 0.273020}}],
    Line[{{0.755205, 0.198240, 0.273020},{0.751030, 0.245757, 0.250145}}],
    Line[{{0.751030, 0.245757, 0.250145},{0.754243, 0.295478, 0.267394}}],
    Line[{{0.754243, 0.295478, 0.267394},{0.760583, 0.327892, 0.309712}}],
    Line[{{0.760583, 0.327892, 0.309712},{0.765881, 0.346710, 0.360002}}],
    Line[{{0.765881, 0.346710, 0.360002},{0.769416, 0.357296, 0.412854}}],
    Line[{{0.769416, 0.357296, 0.412854},{0.771234, 0.362302, 0.466625}}],
    Line[{{0.771234, 0.362302, 0.466625},{0.771423, 0.362808, 0.520661}}],
    Line[{{0.771423, 0.362808, 0.520661},{0.769995, 0.358917, 0.574537}}],
    Line[{{0.769995, 0.358917, 0.574537},{0.766874, 0.349809, 0.627695}}],
    Line[{{0.766874, 0.349809, 0.627695},{0.761979, 0.333292, 0.678849}}],
    Line[{{0.761979, 0.333292, 0.678849},{0.755703, 0.304714, 0.723980}}],
    Line[{{0.755703, 0.304714, 0.723980},{0.751116, 0.258458, 0.749430}}],
    Line[{{0.751116, 0.258458, 0.749430},{0.753787, 0.207841, 0.735199}}],
    Line[{{0.753787, 0.207841, 0.735199},{0.760102, 0.174067, 0.694014}}],
    Line[{{0.760102, 0.174067, 0.694014},{0.765530, 0.154419, 0.644066}}],
    Line[{{0.765530, 0.154419, 0.644066},{0.769204, 0.143311, 0.591333}}],
    Line[{{0.769204, 0.143311, 0.591333},{0.771152, 0.137922, 0.537605}}],
    Line[{{0.771152, 0.137922, 0.537605},{0.771467, 0.137078, 0.483574}}],
    Line[{{0.771467, 0.137078, 0.483574},{0.770167, 0.140608, 0.429670}}],
    Line[{{0.770167, 0.140608, 0.429670},{0.767184, 0.149251, 0.376425}}],
    Line[{{0.767184, 0.149251, 0.376425},{0.762426, 0.165060, 0.325028}}],
    Line[{{0.762426, 0.165060, 0.325028},{0.756207, 0.192451, 0.279127}}],
    Line[{{0.756207, 0.192451, 0.279127},{0.751255, 0.237368, 0.251268}}],
    Line[{{0.751255, 0.237368, 0.251268},{0.753352, 0.288720, 0.262372}}],
    Line[{{0.753352, 0.288720, 0.262372},{0.759615, 0.323889, 0.302313}}],
    Line[{{0.759615, 0.323889, 0.302313},{0.765168, 0.344402, 0.351886}}],
    Line[{{0.765168, 0.344402, 0.351886},{0.768981, 0.356048, 0.404490}}],
    Line[{{0.755782, 0.500000, 0.723443},{0.745173, 0.500000, 0.776433}}],
    Line[{{0.745173, 0.500000, 0.776433},{0.729434, 0.500000, 0.828109}}],
    Line[{{0.729434, 0.500000, 0.828109},{0.705488, 0.500000, 0.876454}}],
    Line[{{0.705488, 0.500000, 0.876454},{0.669536, 0.500000, 0.916497}}],
    Line[{{0.669536, 0.500000, 0.916497},{0.622385, 0.500000, 0.942462}}],
    Line[{{0.622385, 0.500000, 0.942462},{0.570043, 0.500000, 0.955599}}],
    Line[{{0.570043, 0.500000, 0.955599},{0.516244, 0.500000, 0.960471}}],
    Line[{{0.516244, 0.500000, 0.960471},{0.462229, 0.500000, 0.959310}}],
    Line[{{0.462229, 0.500000, 0.959310},{0.408780, 0.500000, 0.951576}}],
    Line[{{0.408780, 0.500000, 0.951576},{0.357841, 0.500000, 0.933895}}],
    Line[{{0.357841, 0.500000, 0.933895},{0.314548, 0.500000, 0.901975}}],
    Line[{{0.314548, 0.500000, 0.901975},{0.283715, 0.500000, 0.857802}}],
    Line[{{0.283715, 0.500000, 0.857802},{0.263514, 0.500000, 0.807738}}],
    Line[{{0.263514, 0.500000, 0.807738},{0.250100, 0.500000, 0.755401}}],
    Line[{{0.250100, 0.500000, 0.755401},{0.240999, 0.500000, 0.702129}}],
    Line[{{0.240999, 0.500000, 0.702129},{0.234866, 0.500000, 0.648430}}],
    Line[{{0.234866, 0.500000, 0.648430},{0.230968, 0.500000, 0.594520}}],
    Line[{{0.230968, 0.500000, 0.594520},{0.228913, 0.500000, 0.540508}}],
    Line[{{0.228913, 0.500000, 0.540508},{0.228511, 0.500000, 0.486457}}],
    Line[{{0.228511, 0.500000, 0.486457},{0.229728, 0.500000, 0.432419}}],
    Line[{{0.229728, 0.500000, 0.432419},{0.232672, 0.500000, 0.378448}}],
    Line[{{0.232672, 0.500000, 0.378448},{0.237623, 0.500000, 0.324625}}],
    Line[{{0.237623, 0.500000, 0.324625},{0.245121, 0.500000, 0.271101}}],
    Line[{{0.245121, 0.500000, 0.271101},{0.256158, 0.500000, 0.218201}}],
    Line[{{0.256158, 0.500000, 0.218201},{0.272566, 0.500000, 0.166738}}],
    Line[{{0.272566, 0.500000, 0.166738},{0.297581, 0.500000, 0.118949}}],
    Line[{{0.297581, 0.500000, 0.118949},{0.334855, 0.500000, 0.080149}}],
    Line[{{0.334855, 0.500000, 0.080149},{0.382818, 0.500000, 0.055686}}],
    Line[{{0.382818, 0.500000, 0.055686},{0.435416, 0.500000, 0.043581}}],
    Line[{{0.435416, 0.500000, 0.043581},{0.489274, 0.500000, 0.039380}}],
    Line[{{0.489274, 0.500000, 0.039380},{0.543272, 0.500000, 0.041141}}],
    Line[{{0.543272, 0.500000, 0.041141},{0.596592, 0.500000, 0.049688}}],
    Line[{{0.596592, 0.500000, 0.049688},{0.647045, 0.500000, 0.068665}}],
    Line[{{0.647045, 0.500000, 0.068665},{0.689189, 0.500000, 0.102079}}],
    Line[{{0.689189, 0.500000, 0.102079},{0.718762, 0.500000, 0.147120}}],
    Line[{{0.718762, 0.500000, 0.147120},{0.738114, 0.500000, 0.197526}}],
    Line[{{0.738114, 0.500000, 0.197526},{0.751000, 0.500000, 0.250000}}],
    Line[{{0.751000, 0.500000, 0.250000},{0.759747, 0.500000, 0.303332}}],
    Line[{{0.759747, 0.500000, 0.303332},{0.765624, 0.500000, 0.357062}}],
    Line[{{0.765624, 0.500000, 0.357062},{0.769320, 0.500000, 0.410986}}],
    Line[{{0.769320, 0.500000, 0.410986},{0.771201, 0.500000, 0.465005}}],
    Line[{{0.771201, 0.500000, 0.465005},{0.771438, 0.500000, 0.519056}}],
    Line[{{0.771438, 0.500000, 0.519056},{0.770052, 0.500000, 0.573090}}],
    Line[{{0.770052, 0.500000, 0.573090},{0.766920, 0.500000, 0.627050}}],
    Line[{{0.766920, 0.500000, 0.627050},{0.761738, 0.500000, 0.680851}}],
    Line[{{0.761738, 0.500000, 0.680851},{0.753933, 0.500000, 0.734330}}],
    Line[{{0.753933, 0.500000, 0.734330},{0.742449, 0.500000, 0.787133}}],
    Line[{{0.742449, 0.500000, 0.787133},{0.725336, 0.500000, 0.838359}}],
    Line[{{0.725336, 0.500000, 0.838359},{0.699211, 0.500000, 0.885532}}],
    Line[{{0.699211, 0.500000, 0.885532},{0.660642, 0.500000, 0.923029}}],
    Line[{{0.660642, 0.500000, 0.923029},{0.611937, 0.500000, 0.946026}}],
    Line[{{0.611937, 0.500000, 0.946026},{0.559112, 0.500000, 0.957149}}],
    Line[{{0.559112, 0.500000, 0.957149},{0.505206, 0.500000, 0.960701}}],
    Line[{{0.505206, 0.500000, 0.960701},{0.451232, 0.500000, 0.958331}}],
    Line[{{0.451232, 0.500000, 0.958331},{0.398061, 0.500000, 0.948931}}],
    Line[{{0.398061, 0.500000, 0.948931},{0.348153, 0.500000, 0.928606}}],
    Line[{{0.348153, 0.500000, 0.928606},{0.307206, 0.500000, 0.893733}}],
    Line[{{0.307206, 0.500000, 0.893733},{0.278862, 0.500000, 0.847887}}],
    Line[{{0.278862, 0.500000, 0.847887},{0.260325, 0.500000, 0.797167}}],
    Line[{{0.260325, 0.500000, 0.797167},{0.247948, 0.500000, 0.744568}}],
    Line[{{0.247948, 0.500000, 0.744568},{0.239539, 0.500000, 0.691180}}],
    Line[{{0.239539, 0.500000, 0.691180},{0.233909, 0.500000, 0.637424}}],
    Line[{{0.233909, 0.500000, 0.637424},{0.230413, 0.500000, 0.583486}}],
    Line[{{0.230413, 0.500000, 0.583486},{0.228706, 0.500000, 0.529461}}],
    Line[{{0.228706, 0.500000, 0.529461},{0.228634, 0.500000, 0.475409}}],
    Line[{{0.228634, 0.500000, 0.475409},{0.230190, 0.500000, 0.421380}}],
    Line[{{0.230190, 0.500000, 0.421380},{0.233515, 0.500000, 0.367431}}],
    Line[{{0.233515, 0.500000, 0.367431},{0.238932, 0.500000, 0.313653}}],
    Line[{{0.238932, 0.500000, 0.313653},{0.247054, 0.500000, 0.260221}}],
    Line[{{0.247054, 0.500000, 0.260221},{0.259003, 0.500000, 0.207524}}],
    Line[{{0.259003, 0.500000, 0.207524},{0.276856, 0.500000, 0.156556}}],
    Line[{{0.276856, 0.500000, 0.156556},{0.304145, 0.500000, 0.110059}}],
    Line[{{0.304145, 0.500000, 0.110059},{0.343995, 0.500000, 0.073935}}],
    Line[{{0.343995, 0.500000, 0.073935},{0.393368, 0.500000, 0.052378}}],
    Line[{{0.703159, 0.500000, 0.825637},{0.676143, 0.500000, 0.872310}}],
    Line[{{0.676143, 0.500000, 0.872310},{0.637109, 0.500000, 0.909352}}],
    Line[{{0.637109, 0.500000, 0.909352},{0.588319, 0.500000, 0.932164}}],
    Line[{{0.588319, 0.500000, 0.932164},{0.535362, 0.500000, 0.942551}}],
    Line[{{0.535362, 0.500000, 0.942551},{0.481376, 0.500000, 0.943834}}],
    Line[{{0.481376, 0.500000, 0.943834},{0.427888, 0.500000, 0.936527}}],
    Line[{{0.427888, 0.500000, 0.936527},{0.377278, 0.500000, 0.917991}}],
    Line[{{0.377278, 0.500000, 0.917991},{0.334657, 0.500000, 0.885155}}],
    Line[{{0.334657, 0.500000, 0.885155},{0.304085, 0.500000, 0.840776}}],
    Line[{{0.304085, 0.500000, 0.840776},{0.283718, 0.500000, 0.790776}}],
    Line[{{0.283718, 0.500000, 0.790776},{0.270067, 0.500000, 0.738500}}],
    Line[{{0.270067, 0.500000, 0.738500},{0.260818, 0.500000, 0.685254}}],
    Line[{{0.260818, 0.500000, 0.685254},{0.254673, 0.500000, 0.631557}}],
    Line[{{0.254673, 0.500000, 0.631557},{0.250921, 0.500000, 0.577636}}],
    Line[{{0.250921, 0.500000, 0.577636},{0.249183, 0.500000, 0.523613}}],
    Line[{{0.249183, 0.500000, 0.523613},{0.249298, 0.500000, 0.469562}}],
    Line[{{0.249298, 0.500000, 0.469562},{0.251278, 0.500000, 0.415547}}],
    Line[{{0.251278, 0.500000, 0.415547},{0.255306, 0.500000, 0.361647}}],
    Line[{{0.255306, 0.500000, 0.361647},{0.261793, 0.500000, 0.307989}}],
    Line[{{0.261793, 0.500000, 0.307989},{0.271510, 0.500000, 0.254827}}],
    Line[{{0.271510, 0.500000, 0.254827},{0.285854, 0.500000, 0.202738}}],
    Line[{{0.285854, 0.500000, 0.202738},{0.307305, 0.500000, 0.153200}}],
    Line[{{0.307305, 0.500000, 0.153200},{0.339400, 0.500000, 0.109933}}],
    Line[{{0.339400, 0.500000, 0.109933},{0.383360, 0.500000, 0.078907}}],
    Line[{{0.383360, 0.500000, 0.078907},{0.434558, 0.500000, 0.062012}}],
    Line[{{0.434558, 0.500000, 0.062012},{0.488198, 0.500000, 0.055877}}],
    Line[{{0.488198, 0.500000, 0.055877},{0.542147, 0.500000, 0.058213}}],
    Line[{{0.542147, 0.500000, 0.058213},{0.594812, 0.500000, 0.069950}}],
    Line[{{0.594812, 0.500000, 0.069950},{0.642692, 0.500000, 0.094582}}],
    Line[{{0.642692, 0.500000, 0.094582},{0.680183, 0.500000, 0.133196}}],
    Line[{{0.680183, 0.500000, 0.133196},{0.705843, 0.500000, 0.180643}}],
    Line[{{0.705843, 0.500000, 0.180643},{0.722906, 0.500000, 0.231889}}],
    Line[{{0.722906, 0.500000, 0.231889},{0.734422, 0.500000, 0.284685}}],
    Line[{{0.734422, 0.500000, 0.284685},{0.742198, 0.500000, 0.338169}}],
    Line[{{0.742198, 0.500000, 0.338169},{0.747235, 0.500000, 0.391983}}],
    Line[{{0.747235, 0.500000, 0.391983},{0.750079, 0.500000, 0.445958}}],
    Line[{{0.750079, 0.500000, 0.445958},{0.751000, 0.500000, 0.500000}}],
    Line[{{0.751000, 0.500000, 0.500000},{0.750079, 0.500000, 0.554042}}],
    Line[{{0.750079, 0.500000, 0.554042},{0.747235, 0.500000, 0.608018}}],
    Line[{{0.747235, 0.500000, 0.608018},{0.742198, 0.500000, 0.661831}}],
    Line[{{0.742198, 0.500000, 0.661831},{0.734422, 0.500000, 0.715315}}],
    Line[{{0.734422, 0.500000, 0.715315},{0.722906, 0.500000, 0.768111}}],
    Line[{{0.722906, 0.500000, 0.768111},{0.705843, 0.500000, 0.819357}}],
    Line[{{0.705843, 0.500000, 0.819357},{0.680183, 0.500000, 0.866802}}],
    Line[{{0.680183, 0.500000, 0.866802},{0.642693, 0.500000, 0.905417}}],
    Line[{{0.642693, 0.500000, 0.905417},{0.594812, 0.500000, 0.930051}}],
    Line[{{0.594812, 0.500000, 0.930051},{0.542147, 0.500000, 0.941787}}],
    Line[{{0.542147, 0.500000, 0.941787},{0.488198, 0.500000, 0.944123}}],
    Line[{{0.488198, 0.500000, 0.944123},{0.434559, 0.500000, 0.937989}}],
    Line[{{0.434559, 0.500000, 0.937989},{0.383361, 0.500000, 0.921094}}],
    Line[{{0.383361, 0.500000, 0.921094},{0.339399, 0.500000, 0.890069}}],
    Line[{{0.339399, 0.500000, 0.890069},{0.307304, 0.500000, 0.846802}}],
    Line[{{0.307304, 0.500000, 0.846802},{0.285853, 0.500000, 0.797265}}],
    Line[{{0.285853, 0.500000, 0.797265},{0.271509, 0.500000, 0.745176}}],
    Line[{{0.271509, 0.500000, 0.745176},{0.261792, 0.500000, 0.692014}}],
    Line[{{0.261792, 0.500000, 0.692014},{0.255304, 0.500000, 0.638356}}],
    Line[{{0.255304, 0.500000, 0.638356},{0.251277, 0.500000, 0.584456}}],
    Line[{{0.251277, 0.500000, 0.584456},{0.249297, 0.500000, 0.530441}}],
    Line[{{0.249297, 0.500000, 0.530441},{0.249182, 0.500000, 0.476389}}],
    Line[{{0.249182, 0.500000, 0.476389},{0.250920, 0.500000, 0.422366}}],
    Line[{{0.250920, 0.500000, 0.422366},{0.254673, 0.500000, 0.368446}}],
    Line[{{0.254673, 0.500000, 0.368446},{0.260818, 0.500000, 0.314749}}],
    Line[{{0.260818, 0.500000, 0.314749},{0.270069, 0.500000, 0.261504}}],
    Line[{{0.270069, 0.500000, 0.261504},{0.283719, 0.500000, 0.209228}}],
    Line[{{0.283719, 0.500000, 0.209228},{0.304088, 0.500000, 0.159228}}],
    Line[{{0.304088, 0.500000, 0.159228},{0.334658, 0.500000, 0.114850}}],
    Line[{{0.334658, 0.500000, 0.114850},{0.377277, 0.500000, 0.082012}}],
    Line[{{0.377277, 0.500000, 0.082012},{0.427888, 0.500000, 0.063475}}],
    Line[{{0.427888, 0.500000, 0.063475},{0.481376, 0.500000, 0.056169}}],
    Line[{{0.481376, 0.500000, 0.056169},{0.535361, 0.500000, 0.057452}}],
    Line[{{0.535361, 0.500000, 0.057452},{0.588318, 0.500000, 0.067839}}],
    Line[{{0.588318, 0.500000, 0.067839},{0.637107, 0.500000, 0.090652}}],
    Line[{{0.637107, 0.500000, 0.090652},{0.676141, 0.500000, 0.127694}}],
    Line[{{0.676141, 0.500000, 0.127694},{0.703156, 0.500000, 0.174367}}],
    Line[{{0.393366, 0.500000, 0.947621},{0.343991, 0.500000, 0.926063}}],
    Line[{{0.343991, 0.500000, 0.926063},{0.304142, 0.500000, 0.889936}}],
    Line[{{0.304142, 0.500000, 0.889936},{0.276857, 0.500000, 0.843441}}],
    Line[{{0.276857, 0.500000, 0.843441},{0.259003, 0.500000, 0.792473}}],
    Line[{{0.259003, 0.500000, 0.792473},{0.247054, 0.500000, 0.739775}}],
    Line[{{0.247054, 0.500000, 0.739775},{0.238931, 0.500000, 0.686344}}],
    Line[{{0.238931, 0.500000, 0.686344},{0.233514, 0.500000, 0.632566}}],
    Line[{{0.233514, 0.500000, 0.632566},{0.230188, 0.500000, 0.578618}}],
    Line[{{0.230188, 0.500000, 0.578618},{0.228632, 0.500000, 0.524589}}],
    Line[{{0.228632, 0.500000, 0.524589},{0.228705, 0.500000, 0.470537}}],
    Line[{{0.228705, 0.500000, 0.470537},{0.230412, 0.500000, 0.416512}}],
    Line[{{0.230412, 0.500000, 0.416512},{0.233909, 0.500000, 0.362574}}],
    Line[{{0.233909, 0.500000, 0.362574},{0.239539, 0.500000, 0.308819}}],
    Line[{{0.239539, 0.500000, 0.308819},{0.247949, 0.500000, 0.255432}}],
    Line[{{0.247949, 0.500000, 0.255432},{0.260325, 0.500000, 0.202834}}],
    Line[{{0.260325, 0.500000, 0.202834},{0.278862, 0.500000, 0.152114}}],
    Line[{{0.278862, 0.500000, 0.152114},{0.307205, 0.500000, 0.106266}}],
    Line[{{0.307205, 0.500000, 0.106266},{0.348155, 0.500000, 0.071396}}],
    Line[{{0.348155, 0.500000, 0.071396},{0.398062, 0.500000, 0.051069}}],
    Line[{{0.398062, 0.500000, 0.051069},{0.451231, 0.500000, 0.041668}}],
    Line[{{0.451231, 0.500000, 0.041668},{0.505205, 0.500000, 0.039298}}],
    Line[{{0.505205, 0.500000, 0.039298},{0.559111, 0.500000, 0.042850}}],
    Line[{{0.559111, 0.500000, 0.042850},{0.611936, 0.500000, 0.053974}}],
    Line[{{0.611936, 0.500000, 0.053974},{0.660638, 0.500000, 0.076971}}],
    Line[{{0.660638, 0.500000, 0.076971},{0.699208, 0.500000, 0.114467}}],
    Line[{{0.699208, 0.500000, 0.114467},{0.725335, 0.500000, 0.161640}}],
    Line[{{0.725335, 0.500000, 0.161640},{0.742448, 0.500000, 0.212867}}],
    Line[{{0.742448, 0.500000, 0.212867},{0.753932, 0.500000, 0.265669}}],
    Line[{{0.753932, 0.500000, 0.265669},{0.761737, 0.500000, 0.319149}}],
    Line[{{0.761737, 0.500000, 0.319149},{0.766919, 0.500000, 0.372949}}],
    Line[{{0.766919, 0.500000, 0.372949},{0.770052, 0.500000, 0.426909}}],
    Line[{{0.770052, 0.500000, 0.426909},{0.771437, 0.500000, 0.480943}}],
    Line[{{0.771437, 0.500000, 0.480943},{0.771200, 0.500000, 0.534995}}],
    Line[{{0.771200, 0.500000, 0.534995},{0.769319, 0.500000, 0.589014}}],
    Line[{{0.769319, 0.500000, 0.589014},{0.765624, 0.500000, 0.642938}}],
    Line[{{0.765624, 0.500000, 0.642938},{0.759747, 0.500000, 0.696667}}],
    Line[{{0.759747, 0.500000, 0.696667},{0.751000, 0.500000, 0.750000}}],
    Line[{{0.751000, 0.500000, 0.750000},{0.738113, 0.500000, 0.802473}}],
    Line[{{0.738113, 0.500000, 0.802473},{0.718762, 0.500000, 0.852880}}],
    Line[{{0.718762, 0.500000, 0.852880},{0.689189, 0.500000, 0.897925}}],
    Line[{{0.689189, 0.500000, 0.897925},{0.647040, 0.500000, 0.931336}}],
    Line[{{0.647040, 0.500000, 0.931336},{0.596586, 0.500000, 0.950312}}],
    Line[{{0.596586, 0.500000, 0.950312},{0.543265, 0.500000, 0.958858}}],
    Line[{{0.543265, 0.500000, 0.958858},{0.489267, 0.500000, 0.960618}}],
    Line[{{0.489267, 0.500000, 0.960618},{0.435409, 0.500000, 0.956416}}],
    Line[{{0.435409, 0.500000, 0.956416},{0.382810, 0.500000, 0.944309}}],
    Line[{{0.382810, 0.500000, 0.944309},{0.334847, 0.500000, 0.919843}}],
    Line[{{0.334847, 0.500000, 0.919843},{0.297579, 0.500000, 0.881039}}],
    Line[{{0.297579, 0.500000, 0.881039},{0.272563, 0.500000, 0.833251}}],
    Line[{{0.272563, 0.500000, 0.833251},{0.256156, 0.500000, 0.781788}}],
    Line[{{0.256156, 0.500000, 0.781788},{0.245120, 0.500000, 0.728887}}],
    Line[{{0.245120, 0.500000, 0.728887},{0.237623, 0.500000, 0.675362}}],
    Line[{{0.237623, 0.500000, 0.675362},{0.232673, 0.500000, 0.621538}}],
    Line[{{0.232673, 0.500000, 0.621538},{0.229731, 0.500000, 0.567567}}],
    Line[{{0.229731, 0.500000, 0.567567},{0.228514, 0.500000, 0.513529}}],
    Line[{{0.228514, 0.500000, 0.513529},{0.228916, 0.500000, 0.459478}}],
    Line[{{0.228916, 0.500000, 0.459478},{0.230972, 0.500000, 0.405465}}],
    Line[{{0.230972, 0.500000, 0.405465},{0.234870, 0.500000, 0.351555}}],
    Line[{{0.234870, 0.500000, 0.351555},{0.241003, 0.500000, 0.297855}}],
    Line[{{0.241003, 0.500000, 0.297855},{0.250104, 0.500000, 0.244583}}],
    Line[{{0.250104, 0.500000, 0.244583},{0.263519, 0.500000, 0.192246}}],
    Line[{{0.263519, 0.500000, 0.192246},{0.283722, 0.500000, 0.142182}}],
    Line[{{0.283722, 0.500000, 0.142182},{0.314560, 0.500000, 0.098012}}],
    Line[{{0.314560, 0.500000, 0.098012},{0.357857, 0.500000, 0.066099}}],
    Line[{{0.357857, 0.500000, 0.066099},{0.408794, 0.500000, 0.048420}}],
    Line[{{0.408794, 0.500000, 0.048420},{0.462244, 0.500000, 0.040686}}],
    Line[{{0.462244, 0.500000, 0.040686},{0.516260, 0.500000, 0.039528}}],
    Line[{{0.516260, 0.500000, 0.039528},{0.570060, 0.500000, 0.044402}}],
    Line[{{0.570060, 0.500000, 0.044402},{0.622400, 0.500000, 0.057541}}],
    Line[{{0.622400, 0.500000, 0.057541},{0.669549, 0.500000, 0.083512}}],
    Line[{{0.669549, 0.500000, 0.083512},{0.705497, 0.500000, 0.123557}}],
    Line[{{0.705497, 0.500000, 0.123557},{0.729442, 0.500000, 0.171904}}],
    Line[{{0.729442, 0.500000, 0.171904},{0.745178, 0.500000, 0.223581}}],
    Line[{{0.745178, 0.500000, 0.223581},{0.755786, 0.500000, 0.276571}}],
    Line[{{0.768981, 0.643954, 0.595498},{0.765168, 0.655599, 0.648102}}],
    Line[{{0.765168, 0.655599, 0.648102},{0.759616, 0.676111, 0.697676}}],
    Line[{{0.759616, 0.676111, 0.697676},{0.753354, 0.711278, 0.737617}}],
    Line[{{0.753354, 0.711278, 0.737617},{0.751255, 0.762628, 0.748726}}],
    Line[{{0.751255, 0.762628, 0.748726},{0.756207, 0.807544, 0.720868}}],
    Line[{{0.756207, 0.807544, 0.720868},{0.762426, 0.834936, 0.674967}}],
    Line[{{0.762426, 0.834936, 0.674967},{0.767183, 0.850745, 0.623571}}],
    Line[{{0.767183, 0.850745, 0.623571},{0.770167, 0.859389, 0.570327}}],
    Line[{{0.770167, 0.859389, 0.570327},{0.771466, 0.862919, 0.516422}}],
    Line[{{0.771466, 0.862919, 0.516422},{0.771151, 0.862075, 0.462392}}],
    Line[{{0.771151, 0.862075, 0.462392},{0.769203, 0.856685, 0.408663}}],
    Line[{{0.769203, 0.856685, 0.408663},{0.765529, 0.845576, 0.355931}}],
    Line[{{0.765529, 0.845576, 0.355931},{0.760101, 0.825927, 0.305985}}],
    Line[{{0.760101, 0.825927, 0.305985},{0.753786, 0.792152, 0.264800}}],
    Line[{{0.753786, 0.792152, 0.264800},{0.751116, 0.741532, 0.250575}}],
    Line[{{0.751116, 0.741532, 0.250575},{0.755703, 0.695282, 0.276031}}],
    Line[{{0.755703, 0.695282, 0.276031},{0.761980, 0.666706, 0.321164}}],
    Line[{{0.761980, 0.666706, 0.321164},{0.766874, 0.650190, 0.372318}}],
    Line[{{0.766874, 0.650190, 0.372318},{0.769994, 0.641082, 0.425474}}],
    Line[{{0.769994, 0.641082, 0.425474},{0.771422, 0.637192, 0.479350}}],
    Line[{{0.771422, 0.637192, 0.479350},{0.771233, 0.637699, 0.533384}}],
    Line[{{0.771233, 0.637699, 0.533384},{0.769415, 0.642707, 0.587154}}],
    Line[{{0.769415, 0.642707, 0.587154},{0.765880, 0.653294, 0.640005}}],
    Line[{{0.765880, 0.653294, 0.640005},{0.760582, 0.672113, 0.690293}}],
    Line[{{0.760582, 0.672113, 0.690293},{0.754242, 0.704528, 0.732610}}],
    Line[{{0.754242, 0.704528, 0.732610},{0.751030, 0.754252, 0.749853}}],
    Line[{{0.751030, 0.754252, 0.749853},{0.755206, 0.801764, 0.726972}}],
    Line[{{0.755206, 0.801764, 0.726972},{0.761522, 0.831572, 0.682689}}],
    Line[{{0.761522, 0.831572, 0.682689},{0.766553, 0.848825, 0.631800}}],
    Line[{{0.766553, 0.848825, 0.631800},{0.769811, 0.858412, 0.578738}}],
    Line[{{0.769811, 0.858412, 0.578738},{0.771368, 0.862669, 0.524894}}],
    Line[{{0.771368, 0.862669, 0.524894},{0.771305, 0.862499, 0.470857}}],
    Line[{{0.771305, 0.862499, 0.470857},{0.769618, 0.857870, 0.417048}}],
    Line[{{0.769618, 0.857870, 0.417048},{0.766221, 0.847791, 0.364087}}],
    Line[{{0.766221, 0.847791, 0.364087},{0.761055, 0.829771, 0.313484}}],
    Line[{{0.761055, 0.829771, 0.313484},{0.754715, 0.798680, 0.270135}}],
    Line[{{0.754715, 0.798680, 0.270135},{0.751000, 0.750000, 0.250000}}],
    Line[{{0.751000, 0.750000, 0.250000},{0.754715, 0.701320, 0.270135}}],
    Line[{{0.754715, 0.701320, 0.270135},{0.761055, 0.670229, 0.313484}}],
    Line[{{0.761055, 0.670229, 0.313484},{0.766221, 0.652209, 0.364087}}],
    Line[{{0.766221, 0.652209, 0.364087},{0.769618, 0.642130, 0.417048}}],
    Line[{{0.769618, 0.642130, 0.417048},{0.771305, 0.637501, 0.470857}}],
    Line[{{0.771305, 0.637501, 0.470857},{0.771368, 0.637331, 0.524894}}],
    Line[{{0.771368, 0.637331, 0.524894},{0.769811, 0.641588, 0.578738}}],
    Line[{{0.769811, 0.641588, 0.578738},{0.766553, 0.651174, 0.631801}}],
    Line[{{0.766553, 0.651174, 0.631801},{0.761522, 0.668428, 0.682689}}],
    Line[{{0.761522, 0.668428, 0.682689},{0.755206, 0.698236, 0.726972}}],
    Line[{{0.755206, 0.698236, 0.726972},{0.751030, 0.745748, 0.749853}}],
    Line[{{0.751030, 0.745748, 0.749853},{0.754242, 0.795472, 0.732610}}],
    Line[{{0.754242, 0.795472, 0.732610},{0.760582, 0.827887, 0.690293}}],
    Line[{{0.760582, 0.827887, 0.690293},{0.765880, 0.846706, 0.640005}}],
    Line[{{0.765880, 0.846706, 0.640005},{0.769415, 0.857293, 0.587154}}],
    Line[{{0.769415, 0.857293, 0.587154},{0.771233, 0.862301, 0.533385}}],
    Line[{{0.771233, 0.862301, 0.533385},{0.771422, 0.862808, 0.479350}}],
    Line[{{0.771422, 0.862808, 0.479350},{0.769994, 0.858918, 0.425474}}],
    Line[{{0.769994, 0.858918, 0.425474},{0.766874, 0.849810, 0.372318}}],
    Line[{{0.766874, 0.849810, 0.372318},{0.761980, 0.833295, 0.321163}}],
    Line[{{0.761980, 0.833295, 0.321163},{0.755703, 0.804719, 0.276031}}],
    Line[{{0.755703, 0.804719, 0.276031},{0.751116, 0.758468, 0.250575}}],
    Line[{{0.751116, 0.758468, 0.250575},{0.753786, 0.707849, 0.264800}}],
    Line[{{0.753786, 0.707849, 0.264800},{0.760101, 0.674074, 0.305984}}],
    Line[{{0.760101, 0.674074, 0.305984},{0.765529, 0.654424, 0.355930}}],
    Line[{{0.765529, 0.654424, 0.355930},{0.769203, 0.643315, 0.408663}}],
    Line[{{0.769203, 0.643315, 0.408663},{0.771151, 0.637925, 0.462391}}],
    Line[{{0.771151, 0.637925, 0.462391},{0.771466, 0.637081, 0.516422}}],
    Line[{{0.771466, 0.637081, 0.516422},{0.770167, 0.640611, 0.570327}}],
    Line[{{0.770167, 0.640611, 0.570327},{0.767183, 0.649254, 0.623571}}],
    Line[{{0.767183, 0.649254, 0.623571},{0.762426, 0.665063, 0.674967}}],
    Line[{{0.762426, 0.665063, 0.674967},{0.756207, 0.692455, 0.720868}}],
    Line[{{0.756207, 0.692455, 0.720868},{0.751255, 0.737371, 0.748726}}],
    Line[{{0.751255, 0.737371, 0.748726},{0.753354, 0.788722, 0.737618}}],
    Line[{{0.753354, 0.788722, 0.737618},{0.759616, 0.823889, 0.697677}}],
    Line[{{0.759616, 0.823889, 0.697677},{0.765168, 0.844401, 0.648103}}],
    Line[{{0.765168, 0.844401, 0.648103},{0.768981, 0.856046, 0.595499}}],
    Line[{{0.751000, 0.750030, 0.500024},{0.751000, 0.750029, 0.500017}}],
    Line[{{0.751000, 0.750029, 0.500017},{0.751000, 0.750023, 0.500048}}],
    Line[{{0.751000, 0.750023, 0.500048},{0.751000, 0.749972, 0.500046}}],
    Line[{{0.751000, 0.749972, 0.500046},{0.751000, 0.749975, 0.499945}}],
    Line[{{0.751000, 0.749975, 0.499945},{0.751000, 0.750036, 0.499987}}],
    Line[{{0.751000, 0.750036, 0.499987},{0.751000, 0.749995, 0.500075}}],
    Line[{{0.751000, 0.749995, 0.500075},{0.751000, 0.749966, 0.499991}}],
    Line[{{0.751000, 0.749966, 0.499991},{0.751000, 0.750016, 0.499931}}],
    Line[{{0.751000, 0.750016, 0.499931},{0.751000, 0.750033, 0.500028}}],
    Line[{{0.751000, 0.750033, 0.500028},{0.751000, 0.749975, 0.500055}}],
    Line[{{0.751000, 0.749975, 0.500055},{0.751000, 0.749968, 0.499973}}],
    Line[{{0.751000, 0.749968, 0.499973},{0.751000, 0.750012, 0.499929}}],
    Line[{{0.751000, 0.750012, 0.499929},{0.751000, 0.750033, 0.500014}}],
    Line[{{0.751000, 0.750033, 0.500014},{0.751000, 0.750013, 0.500063}}],
    Line[{{0.751000, 0.750013, 0.500063},{0.751000, 0.750001, 0.500068}}],
    Line[{{0.751000, 0.750001, 0.500068},{0.751000, 0.749975, 0.500049}}],
    Line[{{0.751000, 0.749975, 0.500049},{0.751000, 0.749966, 0.499976}}],
    Line[{{0.751000, 0.749966, 0.499976},{0.751000, 0.750018, 0.499938}}],
    Line[{{0.751000, 0.750018, 0.499938},{0.751000, 0.750031, 0.499997}}],
    Line[{{0.751000, 0.750031, 0.499997},{0.751000, 0.750030, 0.500036}}],
    Line[{{0.751000, 0.750030, 0.500036},{0.751000, 0.750000, 0.500070}}],
    Line[{{0.751000, 0.750000, 0.500070},{0.751000, 0.749971, 0.500037}}],
    Line[{{0.751000, 0.749971, 0.500037},{0.751000, 0.749969, 0.499984}}],
    Line[{{0.751000, 0.749969, 0.499984},{0.751000, 0.749973, 0.499981}}],
    Line[{{0.751000, 0.749973, 0.499981},{0.751000, 0.749976, 0.500027}}],
    Line[{{0.751000, 0.749976, 0.500027},{0.751000, 0.750012, 0.500053}}],
    Line[{{0.751000, 0.750012, 0.500053},{0.751000, 0.750028, 0.500001}}],
    Line[{{0.751000, 0.750028, 0.500001},{0.751000, 0.749989, 0.499952}}],
    Line[{{0.751000, 0.749989, 0.499952},{0.751000, 0.750005, 0.500049}}],
    Line[{{0.751000, 0.750005, 0.500049},{0.751000, 0.749982, 0.500022}}],
    Line[{{0.751000, 0.749982, 0.500022},{0.751000, 0.749983, 0.500021}}],
    Line[{{0.751000, 0.749983, 0.500021},{0.751000, 0.750015, 0.500018}}],
    Line[{{0.751000, 0.750015, 0.500018},{0.751000, 0.749988, 0.500019}}],
    Line[{{0.751000, 0.749988, 0.500019},{0.751000, 0.749984, 0.499986}}],
    Line[{{0.751000, 0.749984, 0.499986},{0.751000, 0.749987, 0.499993}}],
    Line[{{0.751000, 0.749987, 0.499993},{0.751000, 0.750004, 0.499978}}],
    Line[{{0.751000, 0.750004, 0.499978},{0.751000, 0.750007, 0.500000}}],
    Line[{{0.751000, 0.750007, 0.500000},{0.751000, 0.750002, 0.499997}}],
    Line[{{0.751000, 0.750002, 0.499997},{0.751000, 0.749997, 0.499989}}],
    Line[{{0.751000, 0.749997, 0.499989},{0.751000, 0.750003, 0.500009}}],
    Line[{{0.751000, 0.750003, 0.500009},{0.751000, 0.749995, 0.500016}}],
    Line[{{0.751000, 0.749995, 0.500016},{0.751000, 0.750001, 0.500024}}],
    Line[{{0.751000, 0.750001, 0.500024},{0.751000, 0.750004, 0.500018}}],
    Line[{{0.751000, 0.750004, 0.500018},{0.751000, 0.750006, 0.499983}}],
    Line[{{0.751000, 0.750006, 0.499983},{0.751000, 0.749990, 0.499978}}],
    Line[{{0.751000, 0.749990, 0.499978},{0.751000, 0.749985, 0.499996}}],
    Line[{{0.751000, 0.749985, 0.499996},{0.751000, 0.749990, 0.500021}}],
    Line[{{0.751000, 0.749990, 0.500021},{0.751000, 0.749983, 0.500010}}],
    Line[{{0.751000, 0.749983, 0.500010},{0.751000, 0.750015, 0.499978}}],
    Line[{{0.751000, 0.750015, 0.499978},{0.751000, 0.749987, 0.500025}}],
    Line[{{0.751000, 0.749987, 0.500025},{0.751000, 0.750018, 0.499993}}],
    Line[{{0.751000, 0.750018, 0.499993},{0.751000, 0.749984, 0.499991}}],
    Line[{{0.751000, 0.749984, 0.499991},{0.751000, 0.750017, 0.500003}}],
    Line[{{0.751000, 0.750017, 0.500003},{0.751000, 0.750003, 0.500032}}],
    Line[{{0.751000, 0.750003, 0.500032},{0.751000, 0.749989, 0.499973}}],
    Line[{{0.751000, 0.749989, 0.499973},{0.751000, 0.750015, 0.499985}}],
    Line[{{0.751000, 0.750015, 0.499985},{0.751000, 0.749982, 0.500001}}],
    Line[{{0.751000, 0.749982, 0.500001},{0.751000, 0.750016, 0.500027}}],
    Line[{{0.751000, 0.750016, 0.500027},{0.751000, 0.750014, 0.500028}}],
    Line[{{0.751000, 0.750014, 0.500028},{0.751000, 0.750018, 0.499989}}],
    Line[{{0.751000, 0.750018, 0.499989},{0.751000, 0.750019, 0.499978}}],
    Line[{{0.751000, 0.750019, 0.499978},{0.751000, 0.749991, 0.500048}}],
    Line[{{0.751000, 0.749991, 0.500048},{0.751000, 0.749990, 0.499953}}],
    Line[{{0.751000, 0.749990, 0.499953},{0.751000, 0.750022, 0.500024}}],
    Line[{{0.751000, 0.750022, 0.500024},{0.751000, 0.749986, 0.499951}}],
    Line[{{0.751000, 0.749986, 0.499951},{0.751000, 0.749994, 0.500045}}],
    Line[{{0.751000, 0.749994, 0.500045},{0.751000, 0.749986, 0.499952}}],
    Line[{{0.751000, 0.749986, 0.499952},{0.751000, 0.750003, 0.500055}}],
    Line[{{0.751000, 0.750003, 0.500055},{0.751000, 0.750019, 0.499966}}],
    Line[{{0.751000, 0.750019, 0.499966},{0.751000, 0.749980, 0.500033}}],
    Line[{{0.751000, 0.749980, 0.500033},{0.751000, 0.749981, 0.499988}}],
    Line[{{0.751000, 0.749981, 0.499988},{0.751000, 0.750001, 0.499951}}],
    Line[{{0.751000, 0.750001, 0.499951},{0.751000, 0.750011, 0.500042}}],
    Line[{{0.751000, 0.750011, 0.500042},{0.751000, 0.749979, 0.499972}}],
    Line[{{0.768982, 0.856048, 0.404511},{0.765170, 0.844405, 0.351907}}],
    Line[{{0.765170, 0.844405, 0.351907},{0.759618, 0.823895, 0.302332}}],
    Line[{{0.759618, 0.823895, 0.302332},{0.753355, 0.788731, 0.262386}}],
    Line[{{0.753355, 0.788731, 0.262386},{0.751255, 0.737381, 0.251272}}],
    Line[{{0.751255, 0.737381, 0.251272},{0.756206, 0.692460, 0.279125}}],
    Line[{{0.756206, 0.692460, 0.279125},{0.762426, 0.665066, 0.325023}}],
    Line[{{0.762426, 0.665066, 0.325023},{0.767183, 0.649256, 0.376420}}],
    Line[{{0.767183, 0.649256, 0.376420},{0.770167, 0.640611, 0.429664}}],
    Line[{{0.770167, 0.640611, 0.429664},{0.771467, 0.637081, 0.483569}}],
    Line[{{0.771467, 0.637081, 0.483569},{0.771152, 0.637924, 0.537599}}],
    Line[{{0.771152, 0.637924, 0.537599},{0.769204, 0.643313, 0.591328}}],
    Line[{{0.769204, 0.643313, 0.591328},{0.765530, 0.654421, 0.644061}}],
    Line[{{0.765530, 0.654421, 0.644061},{0.760103, 0.674069, 0.694009}}],
    Line[{{0.760103, 0.674069, 0.694009},{0.753788, 0.707843, 0.735193}}],
    Line[{{0.753788, 0.707843, 0.735193},{0.751116, 0.758459, 0.749426}}],
    Line[{{0.751116, 0.758459, 0.749426},{0.755703, 0.804713, 0.723974}}],
    Line[{{0.755703, 0.804713, 0.723974},{0.761980, 0.833291, 0.678843}}],
    Line[{{0.761980, 0.833291, 0.678843},{0.766874, 0.849807, 0.627690}}],
    Line[{{0.766874, 0.849807, 0.627690},{0.769994, 0.858915, 0.574532}}],
    Line[{{0.769994, 0.858915, 0.574532},{0.771422, 0.862806, 0.520656}}],
    Line[{{0.771422, 0.862806, 0.520656},{0.771233, 0.862300, 0.466621}}],
    Line[{{0.771233, 0.862300, 0.466621},{0.769415, 0.857293, 0.412850}}],
    Line[{{0.769415, 0.857293, 0.412850},{0.765880, 0.846707, 0.359998}}],
    Line[{{0.765880, 0.846707, 0.359998},{0.760582, 0.827888, 0.309709}}],
    Line[{{0.760582, 0.827888, 0.309709},{0.754242, 0.795474, 0.267392}}],
    Line[{{0.754242, 0.795474, 0.267392},{0.751030, 0.745751, 0.250148}}],
    Line[{{0.751030, 0.745751, 0.250148},{0.755205, 0.698238, 0.273026}}],
    Line[{{0.755205, 0.698238, 0.273026},{0.761522, 0.668428, 0.317310}}],
    Line[{{0.761522, 0.668428, 0.317310},{0.766553, 0.651175, 0.368199}}],
    Line[{{0.766553, 0.651175, 0.368199},{0.769811, 0.641588, 0.421262}}],
    Line[{{0.769811, 0.641588, 0.421262},{0.771368, 0.637331, 0.475105}}],
    Line[{{0.771368, 0.637331, 0.475105},{0.771305, 0.637501, 0.529142}}],
    Line[{{0.771305, 0.637501, 0.529142},{0.769618, 0.642130, 0.582951}}],
    Line[{{0.769618, 0.642130, 0.582951},{0.766221, 0.652209, 0.635913}}],
    Line[{{0.766221, 0.652209, 0.635913},{0.761055, 0.670229, 0.686516}}],
    Line[{{0.761055, 0.670229, 0.686516},{0.754715, 0.701320, 0.729864}}],
    Line[{{0.754715, 0.701320, 0.729864},{0.751000, 0.750000, 0.750000}}],
    Line[{{0.751000, 0.750000, 0.750000},{0.754715, 0.798680, 0.729864}}],
    Line[{{0.754715, 0.798680, 0.729864},{0.761055, 0.829771, 0.686516}}],
    Line[{{0.761055, 0.829771, 0.686516},{0.766221, 0.847791, 0.635913}}],
    Line[{{0.766221, 0.847791, 0.635913},{0.769618, 0.857870, 0.582951}}],
    Line[{{0.769618, 0.857870, 0.582951},{0.771305, 0.862499, 0.529142}}],
    Line[{{0.771305, 0.862499, 0.529142},{0.771368, 0.862669, 0.475105}}],
    Line[{{0.771368, 0.862669, 0.475105},{0.769811, 0.858412, 0.421262}}],
    Line[{{0.769811, 0.858412, 0.421262},{0.766553, 0.848825, 0.368199}}],
    Line[{{0.766553, 0.848825, 0.368199},{0.761522, 0.831572, 0.317310}}],
    Line[{{0.761522, 0.831572, 0.317310},{0.755205, 0.801762, 0.273026}}],
    Line[{{0.755205, 0.801762, 0.273026},{0.751030, 0.754249, 0.250147}}],
    Line[{{0.751030, 0.754249, 0.250147},{0.754242, 0.704526, 0.267392}}],
    Line[{{0.754242, 0.704526, 0.267392},{0.760582, 0.672112, 0.309709}}],
    Line[{{0.760582, 0.672112, 0.309709},{0.765880, 0.653293, 0.359998}}],
    Line[{{0.765880, 0.653293, 0.359998},{0.769415, 0.642707, 0.412850}}],
    Line[{{0.769415, 0.642707, 0.412850},{0.771233, 0.637700, 0.466621}}],
    Line[{{0.771233, 0.637700, 0.466621},{0.771422, 0.637194, 0.520656}}],
    Line[{{0.771422, 0.637194, 0.520656},{0.769994, 0.641085, 0.574532}}],
    Line[{{0.769994, 0.641085, 0.574532},{0.766874, 0.650193, 0.627690}}],
    Line[{{0.766874, 0.650193, 0.627690},{0.761980, 0.666709, 0.678843}}],
    Line[{{0.761980, 0.666709, 0.678843},{0.755703, 0.695287, 0.723975}}],
    Line[{{0.755703, 0.695287, 0.723975},{0.751116, 0.741541, 0.749427}}],
    Line[{{0.751116, 0.741541, 0.749427},{0.753788, 0.792157, 0.735193}}],
    Line[{{0.753788, 0.792157, 0.735193},{0.760103, 0.825931, 0.694009}}],
    Line[{{0.760103, 0.825931, 0.694009},{0.765530, 0.845579, 0.644061}}],
    Line[{{0.765530, 0.845579, 0.644061},{0.769204, 0.856687, 0.591328}}],
    Line[{{0.769204, 0.856687, 0.591328},{0.771152, 0.862076, 0.537600}}],
    Line[{{0.771152, 0.862076, 0.537600},{0.771467, 0.862919, 0.483569}}],
    Line[{{0.771467, 0.862919, 0.483569},{0.770167, 0.859389, 0.429665}}],
    Line[{{0.770167, 0.859389, 0.429665},{0.767183, 0.850744, 0.376421}}],
    Line[{{0.767183, 0.850744, 0.376421},{0.762426, 0.834934, 0.325024}}],
    Line[{{0.762426, 0.834934, 0.325024},{0.756206, 0.807540, 0.279125}}],
    Line[{{0.756206, 0.807540, 0.279125},{0.751255, 0.762620, 0.251272}}],
    Line[{{0.751255, 0.762620, 0.251272},{0.753355, 0.711270, 0.262386}}],
    Line[{{0.753355, 0.711270, 0.262386},{0.759618, 0.676105, 0.302332}}],
    Line[{{0.759618, 0.676105, 0.302332},{0.765169, 0.655596, 0.351906}}],
    Line[{{0.765169, 0.655596, 0.351906},{0.768982, 0.643952, 0.404511}}]},
    Boxed -> True,
    Lighting -> True,
    SphericalRegion -> False,
    BoxRatios -> {1.000000, 1.000000, 1.000000},
    ViewPoint -> {-0.175405, -0.746818, 3.572219}
  ]
], "Picture",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J1000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo002VOol0
0`00Oomoo`2oOol00:Eoo`@00;moo`00YGoo0P000Woo0P00_Goo002TOol00`00Ool00004Ool2002k
Ool00:Aoo`03001oo`0000Ioo`800;Uoo`00Xgoo00@007ooOol000Qoo`800;Moo`00Xgoo00@007oo
Ool000Yoo`800;Eoo`00XWoo00D007ooOomoo`0000aoo`03001oogoo0;9oo`00XWoo00@007ooOol0
00ioo`800;9oo`00XGoo00D007ooOomoo`00011oo`800;1oo`00X7oo00<007ooOol00Woo00<007oo
Ool047oo0P00[Woo002POol00`00Oomoo`02Ool00`00Oomoo`0BOol2002/Ool009moo`03001oogoo
00=oo`03001oogoo01Aoo`800:Yoo`00Wgoo00<007ooOol00goo00<007ooOol05Woo0P00Z7oo002N
Ool00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`2UOol009ioo`03001oogoo00Aoo`03001o
ogoo01Uoo`800:Eoo`00WGoo00<007ooOol01Goo00<007ooOol06goo0P00Xgoo002MOol00`00Oomo
o`05Ool00`00Oomoo`0MOol2002QOol009aoo`03001oogoo00Ioo`03001oogoo01moo`8009moo`00
Vgoo00<007ooOol01goo00<007ooOol08Goo0P00WGoo002KOol00`00Oomoo`07Ool00`00Oomoo`0S
Ool2002KOol009Yoo`03001oogoo00Qoo`03001oogoo02Eoo`03001oogoo09Qoo`00VWoo00<007oo
Ool01goo00<007ooOol09goo0P00V7oo002IOol00`00Oomoo`08Ool00`00Oomoo`0YOol2002FOol0
09Uoo`03001oogoo00Qoo`03001oogoo02]oo`8009Aoo`00V7oo00<007ooOol02Goo00<007ooOol0
;Goo0P00TWoo002HOol00`00Oomoo`09Ool00`00Oomoo`0_Ool2002@Ool009Moo`03001oogoo00Yo
o`03001oogoo035oo`8008ioo`00UWoo00<007ooOol02goo00<007ooOol0<goo00<007ooOol0Rgoo
002FOol00`00Oomoo`0;Ool00`00Oomoo`0dOol2002;Ool009Eoo`03001oogoo00aoo`03001oogoo
03Ioo`8008Uoo`00UGoo00<007ooOol037oo00<007ooOol0>7oo0P00Qgoo002DOol00`00Oomoo`0=
Ool00`00Oomoo`0jOol20025Ool009Aoo`03001oogoo00eoo`03001oogoo03aoo`8008=oo`00Tgoo
00<007ooOol03Woo0`00?Woo00<007ooOol0P7oo002COol00`00Oomoo`0>Ool3000oOol20020Ool0
099oo`03001oogoo00ioo`@0045oo`8007ioo`00TGoo00<007ooOol03goo0P0000=oo`00Ool0@Woo
0P00O7oo002AOol00`00Oomoo`0?Ool200000goo001oo`14Ool2001jOol0091oo`03001oogoo00mo
o`80009oo`03001oogoo04Eoo`8007Qoo`00T7oo00<007ooOol03goo0P0000=oo`000000BGoo0P00
MWoo002?Ool00`00Oomoo`0?Ool300000goo0000001;Ool00`00Oomoo`1cOol008moo`03001oogoo
00moo`<00003Ool0000004aoo`8007=oo`00SWoo00<007ooOol03goo0P0000=oo`00Ool00P00CWoo
0P00LGoo002>Ool00`00Oomoo`0>Ool300000goo001oo`02001@Ool2001_Ool008eoo`03001oogoo
00moo`80009oo`04001oo`00001BOol2001]Ool008aoo`03001oogoo00moo`<0009oo`03001oo`00
05Eoo`8006]oo`00S7oo00<007ooOol03goo0P000goo00<007oo0000Egoo0P00JGoo002;Ool00`00
Oomoo`0?Ool20004Ool00`00Ool0001IOol00`00Oomoo`1VOol008]oo`03001oogoo00moo`8000Ao
o`<005Yoo`8006Ioo`00RWoo00<007ooOol03goo0P001Goo0`00G7oo0P00I7oo002:Ool00`00Oomo
o`0>Ool20005Ool01000Ool000007goo0P00?Goo0P00HWoo0029Ool00`00Oomoo`0?Ool20005Ool0
1000Ool000007Woo0`00?goo0P00H7oo0029Ool00`00Oomoo`0>Ool20006Ool01000Ool000007Woo
1000@7oo0P00GWoo0028Ool00`00Oomoo`0>Ool30006Ool01000Ool000007Woo00@007ooOol0049o
o`8005aoo`00Qgoo00<007ooOol03goo0P001goo00@007oo000001ioo`03001oogoo008004=oo`03
001oogoo05Uoo`00Qgoo00<007ooOol03Woo0`001goo10007Woo0P000Woo00<007ooOol0@7oo0P00
Fgoo0026Ool00`00Oomoo`0?Ool20008Ool4000NOol20002Ool20011Ool00`00Ool0001JOol008Io
o`03001oogoo00ioo`8000Uoo`<001moo`8000=oo`03001oogoo03ioo`04001oogoo001JOol008Eo
o`03001oogoo00moo`8000Uoo`<0021oo`05001oogooOol0000oOol01@00Oomoogoo0000FWoo0025
Ool00`00Oomoo`0>Ool2000:Ool3000POol01000Oomoogoo0P00?Woo00<007ooOol00Woo00<007oo
Ool0Egoo0024Ool00`00Oomoo`0?Ool2000:Ool3000POol00`00Oomoo`02Ool00`00Oomoo`0kOol0
0`00Oomoo`03Ool00`00Oomoo`1GOol008Aoo`03001oogoo00ioo`8000]oo`<0021oo`8000=oo`80
03]oo`03001oogoo00Aoo`03001oogoo05Moo`00Pgoo00<007ooOol03goo0P002goo0`0087oo0P00
0goo0P00>goo00<007ooOol01Goo00<007ooOol0EWoo0022Ool00`00Oomoo`0?Ool2000<Ool2000Q
Ool20004Ool00`00Oomoo`0hOol00`00Oomoo`06Ool00`00Oomoo`1FOol0089oo`03001oogoo00mo
o`03001oogoo00Yoo`<0025oo`8000Aoo`03001oogoo03Moo`03001oogoo00Moo`03001oogoo05Io
o`00PGoo00<007ooOol03goo0P0037oo0`008Woo00@007ooOomoo`<003Qoo`03001oogoo00Qoo`03
001oogoo05Eoo`00PGoo00<007ooOol03Woo0P003Goo0`008Woo00@007ooOomoo`<003Moo`03001o
ogoo00Uoo`03001oogoo05Eoo`00P7oo00<007ooOol03goo0P003Goo0`008Woo00<007ooOol01000
27oo40007goo00<007ooOol02Woo00<007ooOol0E7oo0020Ool00`00Oomoo`0>Ool2000>Ool2000S
Ool200001goo00000000Ool007oo00X000Qoo`L001]oo`03001oogoo00]oo`03001oogoo05Aoo`00
Ogoo00<007ooOol03goo0P003Woo0P008goo1@0000=oo`0000001@004goo100067oo00<007ooOol0
37oo00<007ooOol0E7oo001oOol00`00Oomoo`0>Ool2000?Ool2000SOol600000goo001oo`03000G
Ool3000FOol00`00Oomoo`0=Ool00`00Oomoo`1COol007ioo`03001oogoo00moo`8000ioo`<0029o
o`@000Eoo`<001Yoo`<001=oo`03001oogoo00ioo`03001oogoo05=oo`00OGoo00<007ooOol047oo
0P003Woo10007goo1@001Goo100077oo0P004Goo00<007ooOol03goo00<007ooOol0Dgoo001mOol0
0`00Oomoo`0?Ool2000?Ool20002Ool2000KOol40002Ool20004Ool3000NOol2000@Ool00`00Oomo
o`0@Ool00`00Oomoo`1BOol007aoo`03001oogoo011oo`8000ioo`8000Eoo`8001Moo`<000Eoo`80
00Eoo`8001moo`8000ioo`03001oogoo015oo`03001oogoo059oo`00O7oo00<007ooOol047oo0P00
3Woo0P001goo0P004goo0`001goo0P001Goo0P0087oo00<007ooOol02goo00<007ooOol04Woo00<0
07ooOol0DWoo001kOol00`00Oomoo`0AOol00`00Oomoo`0<Ool2000:Ool2000?Ool3000:Ool00`00
Oomoo`03Ool2000POol2000<Ool00`00Oomoo`0COol00`00Oomoo`1AOol007]oo`03001oogoo011o
o`8000ioo`8000aoo`8000]oo`<000aoo`8000Eoo`03001oogoo01moo`03001oogoo00Uoo`03001o
ogoo01Aoo`03001oogoo055oo`00NWoo00<007ooOol04Goo0P003Goo0`003Woo0P0027oo0P003Woo
0P001Goo00<007ooOol07goo0P002Goo00<007ooOol05Goo00<007ooOol0DGoo001jOol00`00Oomo
o`0@Ool2000=Ool3000AOol20004Ool3000?Ool20005Ool2000POol20009Ool00`00Oomoo`0FOol0
0`00Oomoo`1@Ool007Uoo`03001oogoo015oo`8000eoo`<001=oo`800004Ool00000000@Ool20005
Ool2000QOol00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`1@Ool007Qoo`03001oogoo019o
o`8000aoo`@001Eoo`8001=oo`03001oogoo00Aoo`03001oogoo01moo`8000Ioo`03001oogoo01Qo
o`03001oogoo051oo`00N7oo00<007ooOol04Woo30000Woo0`005Goo0P0000=oo`0000004Goo0P00
1Goo0P0087oo0P001Woo00<007ooOol06Goo00<007ooOol0Cgoo001gOol00`00Oomoo`0BOol60002
Ool:000DOol20004Ool00`00Oomoo`0>Ool20005Ool2000POol20005Ool00`00Oomoo`0JOol00`00
Oomoo`1?Ool007Moo`03001oogoo011oo`@000]oo`H0019oo`8000Ioo`8000ioo`8000Ioo`03001o
ogoo01ioo`8000Aoo`03001oogoo01]oo`03001oogoo04moo`00MWoo00<007ooOol047oo0P000Woo
00<007ooOol00Woo2P0000=oo`00000010003Goo0P002Goo0P003Goo00<007ooOol017oo00<007oo
Ool07Woo0P0017oo00<007ooOol01Woo1`003goo00<007ooOol0CWoo001fOol00`00Oomoo`0?Ool2
0003Ool00`00Ool0000E000;Ool00`00Oomoo`0:Ool2000;Ool20005Ool2000OOol00`00Oomoo`02
Ool00`00Oomoo`05Ool50002Ool4000=Ool00`00Oomoo`1>Ool007Eoo`03001oogoo00moo`8000Ao
o`D000Ioo`<0009oo`X000Qoo`8000ioo`8000Uoo`8000Eoo`8001moo`05001oogooOol00007Ool3
0008Ool2000<Ool00`00Oomoo`1>Ool007Eoo`03001oogoo00ioo`8000Eoo`<000Moo`<000Moo`P0
00Eoo`80015oo`8000Moo`8000Ioo`03001oogoo01aoo`8000=oo`03001oogoo00Aoo`8000]oo`80
00aoo`03001oogoo04eoo`00M7oo00<007ooOol03Woo0P0017oo100027oo0P002goo1`000goo0P00
4goo0P001Woo00<007ooOol017oo00<007ooOol077oo0P000Woo00<007ooOol00goo0`003Goo0P00
2goo00<007ooOol0CGoo001cOol00`00Oomoo`0?Ool20003Ool300000goo00000006Ool3000=Ool9
000FOol20004Ool20005Ool2000MOol01@00Oomoogoo000017oo0`003goo0P002goo00<007ooOol0
C7oo001cOol00`00Oomoo`0>Ool20004Ool20002Ool20005Ool3000AOol6000HOol20002Ool20005
Ool2000LOol20002Ool00`00Oomoo`02Ool3000@Ool2000;Ool00`00Oomoo`1<Ool0079oo`03001o
ogoo00ioo`<000=oo`8000Aoo`80009oo`@001Aoo`H001Qoo`@000Eoo`8001aoo`04001oogoo0005
Ool2000BOol2000:Ool00`00Oomoo`1<Ool0079oo`03001oogoo00ioo`8000=oo`8000Ioo`D001Mo
o`L001Qoo`8000Ioo`03001oogoo01Uoo`80009oo`03001oogoo009oo`8001=oo`<000Yoo`03001o
ogoo04]oo`00LGoo00<007ooOol03goo0P000goo0P002Woo00<007ooOol05Goo0P0000=oo`000000
10005goo0`0017oo0P006Goo0P000Woo00<007ooOol00goo0P0057oo0P002Woo00<007ooOol0Bgoo
001aOol00`00Oomoo`0>Ool20003Ool2000:Ool00`00Oomoo`0FOol00`00Oomoo`03Ool5000EOol2
00000goo001oo`02Ool2000HOol20002Ool00`00Oomoo`03Ool2000EOol2000:Ool00`00Oomoo`1;
Ool0071oo`03001oogoo00moo`8000=oo`8000Yoo`03001oogoo01Ioo`03001oogoo00Aoo`H001=o
o`80009oo`800003Ool0000001Qoo`80009oo`03001oogoo00=oo`8001Ioo`8000Yoo`03001oogoo
04Yoo`00L7oo00<007ooOol03goo00@007ooOomoo`8000Yoo`03001oogoo01Moo`03001oogoo00Io
o`H0019oo`03001oogoo009oo`<001Moo`80009oo`03001oogoo00=oo`8001Moo`8000Yoo`03001o
ogoo04Yoo`00Kgoo00<007ooOol03goo0P000goo0P002Goo00<007ooOol067oo00<007ooOol027oo
1P0047oo00<007ooOol017oo0P005Goo0P000Woo00<007ooOol017oo0P0067oo00<007ooOol027oo
00<007ooOol0BWoo001^Ool00`00Oomoo`0@Ool20002Ool2000:Ool00`00Oomoo`0HOol00`00Oomo
o`0:Ool6000>Ool20005Ool4000BOol20003Ool00`00Oomoo`03Ool3000HOol00`00Oomoo`09Ool0
0`00Oomoo`19Ool006ioo`03001oogoo00moo`8000=oo`8000Uoo`03001oogoo01Uoo`03001oogoo
00aoo`H000aoo`8000Eoo`80009oo`8000ioo`<000=oo`03001oogoo00Aoo`8001Uoo`8000Yoo`03
001oogoo04Uoo`00KGoo00<007ooOol047oo0P000goo0P002Goo00<007ooOol06Goo00<007ooOol0
3Goo1`002goo00<007ooOol017oo00<007ooOol00Woo0P002goo0P0017oo00<007ooOol01Goo0P00
6Goo0P002Woo00<007ooOol0BGoo001]Ool00`00Oomoo`0@Ool20002Ool30008Ool00`00Oomoo`0J
Ool2000@Ool6000:Ool00`00Oomoo`04Ool20005Ool20007Ool30005Ool00`00Oomoo`04Ool3000I
Ool2000;Ool00`00Oomoo`18Ool006aoo`03001oogoo015oo`80009oo`8000Uoo`03001oogoo01]o
o`03001oogoo011oo`H000Qoo`8000Eoo`8000Moo`8000Aoo`8000Ioo`03001oogoo00Eoo`8001Yo
o`8000]oo`03001oogoo04Qoo`00K7oo00<007ooOol047oo0P000goo0P0027oo00<007ooOol077oo
0P004goo1@001goo0P001Goo0P002Goo10001goo00<007ooOol01Woo0P006Woo0P002goo00<007oo
Ool0B7oo001[Ool00`00Oomoo`0AOol20003Ool20007Ool00`00Oomoo`0MOol2000DOol50006Ool2
0006Ool00`00Oomoo`07Ool40007Ool00`00Oomoo`06Ool2000JOol2000<Ool00`00Oomoo`17Ool0
06]oo`03001oogoo015oo`8000=oo`8000Moo`03001oogoo01ioo`8001Aoo`H000Aoo`8000Ioo`03
001oogoo00Eoo`<000=oo`8000Aoo`03001oogoo00Moo`8001Yoo`8000aoo`03001oogoo04Moo`00
JWoo00<007ooOol04Woo0P000Woo0P001goo00<007ooOol087oo00<007ooOol057oo1@000goo00<0
07oo00001Goo0P0017oo0`001goo00@007ooOol000Uoo`<001Yoo`8000aoo`03001oogoo04Moo`00
JGoo00<007ooOol04goo0P000Woo0P001goo00<007ooOol05Woo3@005Goo200000=oo`00Ool017oo
0P000Woo0`002Woo0`002Goo0P006goo0P003Goo00<007ooOol0AWoo001YOol00`00Oomoo`0COol0
1000Oomoogoo0P001Woo00<007ooOol05Goo10001Goo1`005Goo2@001Goo1@003Goo0`0027oo0P00
6goo0P003Goo00<007ooOol0AWoo001XOol00`00Oomoo`0DOol01000Oomoogoo0P001Goo00<007oo
Ool05Goo0P0037oo1@005Goo1@000Woo00@007ooOomoo`D000eoo`04001oogooOol20006Ool2000K
Ool2000>Ool00`00Oomoo`15Ool006Qoo`03001oogoo01=oo`8000=oo`8000Eoo`03001oogoo01Ao
o`80011oo`D001=oo`L00003Ool0000000<000moo`03001oogoo00=oo`8000Aoo`8001]oo`03001o
ogoo00eoo`03001oogoo04Eoo`00Igoo00<007ooOol057oo0P000goo00<007ooOol00goo00<007oo
Ool057oo0P004goo1`003Goo2P0000=oo`0000000`003Goo00<007ooOol01Woo0P000Woo0P006Woo
0P003goo00<007ooOol0AGoo001WOol00`00Oomoo`0DOol20003Ool00`00Oomoo`03Ool00`00Oomo
o`0COol2000EOolF00000goo0000000700000goo0000000=Ool00`00Oomoo`08Ool40009Ool00`00
Oomoo`0>Ool2000@Ool00`00Oomoo`14Ool006Ioo`03001oogoo01Eoo`80009oo`8000Aoo`03001o
ogoo01Aoo`8001Moo`<0009oo`X000Qoo`L00003Ool0000000aoo`03001oogoo00]oo`8000Uoo`03
001oogoo00ioo`80011oo`03001oogoo04Aoo`00IWoo00<007ooOol05Goo0P000Woo0P0017oo00<0
07ooOol04goo0P006Goo0`0057oo1@000Woo0P002goo00<007ooOol037oo00@007oo000001Qoo`03
001oogoo00moo`03001oogoo04Aoo`00IGoo00<007ooOol05Woo0P000Woo0P000goo00<007ooOol0
57oo0P006Woo0`0057oo1@0000=oo`0000002goo00<007ooOol037oo00@007ooOomoo`8001Eoo`80
019oo`03001oogoo04=oo`00I7oo00<007ooOol05goo0P000Woo0P000Woo00<007ooOol05Goo00<0
07ooOol06goo0P0057oo1@0000=oo`00Ool02Goo00<007ooOol03Goo00<007ooOol00goo0P004goo
0P004Woo00<007ooOol0@goo001TOol00`00Oomoo`0GOol20002Ool20002Ool00`00Oomoo`0DOol2
000NOol2000COol200000goo000000020009Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool2000AOol2
000BOol00`00Oomoo`13Ool006=oo`03001oogoo01Qoo`80009oo`800003Ool007oo01Ioo`8001mo
o`8001=oo`800004Ool000000009Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool3
000COol00`00Oomoo`12Ool006=oo`03001oogoo00ioo`03001oogoo00Moo`80009oo`800003Ool0
07oo01Ioo`80021oo`80019oo`<00004Ool000000007Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool2
000=Ool2000DOol00`00Oomoo`12Ool0069oo`03001oogoo00ioo`8000Uoo`80009oo`<001Qoo`80
025oo`80015oo`@00003Ool0000000Ioo`03001oogoo011oo`03001oogoo00Yoo`8000]oo`8001Ao
o`03001oogoo049oo`00HWoo00<007ooOol03Goo0`002Goo0P000Woo0`0067oo00<007ooOol08Goo
0P004Goo0`0000Aoo`00000000Eoo`03001oogoo011oo`8000eoo`8000Qoo`8001Ioo`03001oogoo
045oo`00HGoo00<007ooOol03Woo0`002Goo0P000Woo0P006Goo00<007ooOol08Goo0P004Goo1000
00=oo`00000017oo00<007ooOol04Goo0P003goo0P001Woo0P005Woo00<007ooOol0@Goo001QOol0
0`00Oomoo`0=Ool40009Ool20002Ool2000IOol00`00Oomoo`0ROol2000AOol00`00Ool000040002
Ool00`00Oomoo`0BOol2000AOol20003Ool2000GOol00`00Oomoo`11Ool0061oo`8000moo`@000Uo
o`80009oo`8001Uoo`03001oogoo02=oo`80011oo`P00003Ool007oo01=oo`8001=oo`800003Ool0
000001Qoo`03001oogoo041oo`00H7oo00@007oo000000aoo`@000Yoo`800004Ool007oo000IOol0
0`00Oomoo`0SOol2000@Ool2000017oo000007oo0`005Goo0P005Goo0P006Goo00<007ooOol0@7oo
001OOol00`00Oomoo`02Ool2000:Ool4000:Ool2000017oo001oo`006Goo0P009Goo0P0047oo0P00
00Aoo`00001oo`8001Eoo`8001Eoo`@001Moo`03001oogoo041oo`00Ggoo00<007ooOol017oo0P00
1goo0P0000=oo`0000002Woo0`000Woo00<007ooOol05goo0P009Woo00<007ooOol03Woo1@0000=o
o`0000005Goo0P0057oo0P000goo0P005Woo00<007ooOol0?goo001OOol00`00Oomoo`06Ool20005
Ool200000goo0000000:Ool30002Ool2000HOol2000VOol2000@Ool500000goo0000000EOol2000C
Ool20005Ool2000DOol00`00Oomoo`0oOol005moo`03001oogoo00Qoo`80009oo`800004Ool00000
000;Ool20002Ool2000IOol00`00Oomoo`0UOol00`00Oomoo`0AOol200000goo0000000EOol2000B
Ool20008Ool2000BOol00`00Oomoo`0oOol005ioo`03001oogoo00]oo`@00003Ool0000000]oo`<0
009oo`8001Uoo`03001oogoo02Eoo`80019oo`<00003Ool0000001Aoo`80015oo`<000Yoo`03001o
ogoo011oo`03001oogoo03ioo`00GWoo00<007ooOol037oo0`0000=oo`0000002goo0`000Woo0P00
6Goo0P004goo0P004Goo0P004Goo00D007oo000007oo008001Aoo`80015oo`8000aoo`80011oo`03
001oogoo03ioo`00GWoo00<007ooOol02goo0P000Woo0`002Woo00@007oo000000=oo`8001Qoo`80
01=oo`80019oo`8000moo`03001oogoo0080009oo`03001oogoo019oo`80011oo`8000moo`8000mo
o`03001oogoo03eoo`00GWoo00<007ooOol02goo0P000goo0`002Goo00<007ooOol00P000Woo0P00
6Goo00<007ooOol09Goo0P003goo00@007ooOomoo`800003Ool0000001=oo`80011oo`80015oo`80
00eoo`03001oogoo03eoo`00GGoo00<007ooOol02goo0P0017oo0P0000=oo`0000001Woo00@007oo
Oomoo`80009oo`8000eoo`03001oogoo00Uoo`8002Ioo`8000ioo`03001oogoo009oo`800003Ool0
000001=oo`<000ioo`8001Aoo`8000]oo`03001oogoo03eoo`00GGoo00<007ooOol02Woo0`000goo
0P0017oo0P000goo00<007ooOol00Woo0P000goo0P002goo10002Goo0P009goo00<007ooOol02goo
00<007ooOol017oo0P0000=oo`0000004goo0P003Goo0`005Woo0P002Woo00<007ooOol0?7oo001M
Ool00`00Oomoo`0:Ool20004Ool20006Ool200000goo001oo`03Ool20003Ool2000:Ool20002Ool2
0009Ool00`00Oomoo`0UOol2000<Ool00`00Oomoo`04Ool200000goo0000000COol2000=Ool2000I
Ool20008Ool00`00Oomoo`0lOol005eoo`03001oogoo00Uoo`8000Eoo`8000Qoo`8000Aoo`<0009o
o`8000Yoo`03001oogoo009oo`8000Qoo`8002Ioo`8000]oo`03001oogoo00Eoo`800003Ool00000
01=oo`8000aoo`<001]oo`8000Ioo`03001oogoo03aoo`00G7oo00<007ooOol02Goo0`001Goo0P00
27oo00@007oo000000=oo`80009oo`<000Qoo`8000Eoo`03001oogoo00Moo`03001oogoo02Aoo`80
00]oo`03001oogoo00Ioo`800003Ool0000001=oo`8000Yoo`<001ioo`8000Eoo`03001oogoo03]o
o`00G7oo00<007ooOol02Goo0P001Woo00<007ooOol01Woo00<007ooOol00Woo0P0000=oo`000000
0goo0P0027oo0P001Goo0P0027oo0P009Woo00<007ooOol027oo00<007ooOol01goo0P0000=oo`00
00004goo0P002Woo0P008Goo0P000goo00<007ooOol0>goo001LOol00`00Oomoo`08Ool30006Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool40002Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`0TOol00`00Oomoo`07Ool00`00Oomoo`08Ool20002Ool00`00Oomoo`0AOol20009Ool2
000TOol200000goo001oo`0lOol005aoo`03001oogoo00Qoo`8000Ioo`8000Moo`03001oogoo00Mo
o`80009oo`<000Ioo`8000Moo`8000Qoo`8002Eoo`8000Qoo`03001oogoo00Uoo`03001oogoo0080
01=oo`03001oogoo00Ioo`8002Moo`<003aoo`00Fgoo00<007ooOol027oo0`001Woo0P001Woo00<0
07ooOol027oo100000=oo`0000001Woo0P0027oo00<007ooOol01goo0P0097oo0P001goo00<007oo
Ool02Woo0P0000=oo`0000004goo0P001Woo0`00:Goo00<007ooOol0>Woo001KOol00`00Oomoo`08
Ool20007Ool20006Ool00`00Oomoo`09Ool200000goo000000020005Ool20008Ool20008Ool2000T
Ool20006Ool00`00Oomoo`0;Ool20002Ool00`00Oomoo`0BOol00`00Oomoo`03Ool3000YOol00`00
Oomoo`0kOol005]oo`03001oogoo00Moo`8000Qoo`03001oogoo00Aoo`03001oogoo00Yoo`<0009o
o`8000Eoo`8000Qoo`8000Uoo`8002=oo`8000Ioo`03001oogoo00]oo`80009oo`03001oogoo019o
o`80009oo`@002Yoo`03001oogoo03]oo`00Fgoo00<007ooOol01goo0P001goo0P001Woo00<007oo
Ool02goo0P000Woo10000goo00<007ooOol01goo0`002Goo0P008Woo0P001Goo00<007ooOol03Goo
0P0000=oo`00000057oo1P00:Woo00<007ooOol0?7oo001JOol00`00Oomoo`07Ool20008Ool20005
Ool00`00Oomoo`0<Ool30002Ool200001Goo000007oo000027oo10002Woo0P008Goo0P0017oo00<0
07ooOol03Woo0P0000=oo`0000005Goo0`00:goo00<007ooOol0?Goo001JOol00`00Oomoo`07Ool2
0008Ool20005Ool00`00Oomoo`0=Ool20002Ool30002Ool20008Ool40005Ool=000KOol20004Ool0
0`00Oomoo`0>Ool20002Ool00`00Oomoo`10Ool00`00Oomoo`0nOol005Yoo`03001oogoo00Ioo`80
00Uoo`8000Aoo`03001oogoo00ioo`<0009oo`8000=oo`<000Eoo`D0009oo`L0009oo`800003Ool0
000000@001Uoo`8000=oo`03001oogoo00moo`80009oo`80045oo`03001oogoo03ioo`00FGoo00<0
07ooOol01goo0P0027oo0`000goo00<007ooOol047oo0`000Woo0P000Woo00<007ooOol00P000goo
0`000Woo1@001goo0P001Goo0`005goo00D007ooOomoo`00019oo`<00003Ool00000041oo`03001o
ogoo03moo`00FGoo00<007ooOol01Woo0P002Goo0P0017oo00<007ooOol04Goo0P000goo0P0000=o
o`00Ool00goo100017oo10002Goo0P001Woo0`005Goo00D007ooOomoo`0001=oo`800003Ool00000
03moo`03001oogoo041oo`00FGoo00<007ooOol01Woo0P002Goo0P000goo00<007ooOol04Woo0`00
0Woo0P0000=oo`00Ool00Woo1@0017oo10002Woo0`001Woo0`004Woo0P000Woo00<007ooOol04Woo
0P0000=oo`000000?goo00<007ooOol0@7oo001IOol00`00Oomoo`05Ool2000:Ool20003Ool00`00
Oomoo`0COol30002Ool3000017oo0000000017oo0P000Woo0`0037oo0`001goo0P004Goo0P0000=o
o`00Ool057oo0P000Woo0P00?Goo00<007ooOol0@Goo001HOol00`00Oomoo`06Ool20009Ool30002
Ool00`00Oomoo`0EOol20003Ool40008Ool200000goo0000000=Ool40006Ool2000?Ool20002Ool0
0`00Oomoo`0COol20002Ool2000lOol00`00Oomoo`12Ool005Qoo`03001oogoo00Eoo`8000Yoo`80
009oo`03001oogoo01Moo`800003Ool00000008000]oo`<000moo`<000Ioo`8000ioo`800003Ool0
07oo01Eoo`80009oo`8003]oo`03001oogoo04=oo`00F7oo00<007ooOol01Goo0P002Woo0P000Woo
00<007ooOol067oo0`0000Aoo`00000000]oo`<0011oo`<000Aoo`8000eoo`800003Ool007oo01Mo
o`03001oogoo008003]oo`03001oogoo04=oo`00F7oo00<007ooOol017oo0P002goo0P0000=oo`00
Ool06Goo100000=oo`00Ool00P002Woo0P0000=oo`0000003goo10000goo0P002goo0P000Woo00<0
07ooOol05Woo00<007ooOol00P00>Woo00<007ooOol0A7oo001GOol00`00Oomoo`05Ool2000;Ool2
00000goo001oo`0GOol30002Ool30002Ool2000:Ool20002Ool2000?Ool40002Ool00`00Oomoo`08
Ool300000goo001oo`0HOol00`00Oomoo`02000iOol00`00Oomoo`15Ool005Moo`03001oogoo00Eo
o`8000Yoo`800003Ool007oo01Moo`<000Aoo`8000=oo`8000Uoo`8000Aoo`8000moo`H000Moo`@0
0003Ool007oo01Uoo`800003Ool0000003Uoo`03001oogoo04Eoo`00Egoo00<007ooOol017oo0P00
2goo0P0000=oo`00Ool05Woo0P001goo0P000goo0P0027oo0P001Woo0P0047oo30000goo00<007oo
Ool067oo0P000Woo00<007ooOol0=Woo00<007ooOol0AWoo001GOol00`00Oomoo`04Ool2000;Ool3
000GOol20008Ool30003Ool20008Ool00`00Oomoo`06Ool2000@Ool70005Ool00`00Oomoo`0IOol2
0002Ool00`00Oomoo`0eOol00`00Oomoo`17Ool005Ioo`03001oogoo00Eoo`8000]oo`8001Moo`80
00Uoo`D0009oo`8000Moo`8000Uoo`8000ioo`8000Yoo`03001oogoo01Uoo`80009oo`8003Eoo`03
001oogoo04Qoo`00EWoo00<007ooOol017oo0P002goo0`005Woo0P002Woo0P0000Aoo`000000009o
o`8000Ioo`8000]oo`8000aoo`8000Uoo`03001oogoo01Yoo`80009oo`8003Eoo`03001oogoo04Qo
o`00EWoo00<007ooOol017oo0P002goo0P005Woo0P002goo0P000Woo0`000Woo0P001Goo0P003Goo
0P002goo00<007ooOol01Woo00<007ooOol06goo0P000Woo0P00=7oo00<007ooOol0BGoo001FOol0
0`00Oomoo`04Ool2000;Ool2000EOol2000<Ool20003Ool4000017oo0000000017oo00<007ooOol0
3Goo0P002Goo00<007ooOol01Woo00<007ooOol017oo1P004Goo0P000Woo0P00<goo00<007ooOol0
BWoo001EOol00`00Oomoo`05Ool00`00Oomoo`0:Ool2000DOol2000>Ool00`00Oomoo`03Ool30000
17oo000000000goo00<007ooOol03goo0P001goo00<007ooOol01Goo00<007ooOol017oo100000=o
o`0000000P003goo0P000Woo0P00<goo00<007ooOol0BWoo001EOol00`00Oomoo`04Ool2000;Ool2
000DOol2000?Ool00`00Oomoo`04Ool3000017oo000000000Woo0P004Woo0P001Goo00<007ooOol0
17oo00<007ooOol017oo0`001Woo0P003Woo0P000Woo0P00<Woo00<007ooOol0Bgoo001EOol00`00
Oomoo`04Ool2000;Ool2000DOol00`00Oomoo`0>Ool00`00Oomoo`06Ool300000goo00000003000D
Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20009Ool2000=Ool20002Ool2000aOol00`00
Oomoo`1<Ool005Aoo`03001oogoo00Eoo`03001oogoo00Uoo`<001=oo`03001oogoo00moo`8000Qo
o`<00003Ool00000008001Ioo`800003Ool007oo00Aoo`03001oogoo00=oo`<000Uoo`<000aoo`80
009oo`80031oo`03001oogoo04eoo`00E7oo00<007ooOol017oo0P002goo0P004goo0P004Goo0P00
2Goo100000Aoo`00000001Moo`8000Aoo`03001oogoo00=oo`<000]oo`8000aoo`80009oo`80031o
o`03001oogoo04eoo`00E7oo00<007ooOol017oo0P002Woo0`004goo00<007ooOol047oo0P002goo
0`0000=oo`0000000P005Goo10000Woo00<007ooOol00goo0P0037oo0`002goo0P000goo00<007oo
Ool0;Goo00<007ooOol0CWoo001DOol00`00Oomoo`04Ool2000:Ool2000COol2000BOol2000=Ool7
000DOol20002Ool20005Ool2000>Ool2000;Ool20002Ool2000^Ool00`00Oomoo`1?Ool005=oo`03
001oogoo00Eoo`8000Uoo`<001=oo`03001oogoo019oo`03001oogoo00aoo`@00004Ool00000000B
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool2000>Ool2000;Ool20002Ool2000^Ool00`00Oomoo`1?
Ool005=oo`03001oogoo00Eoo`8000Uoo`8001=oo`8001Aoo`8000ioo`@00004Ool00000000@Ool2
0004Ool00`00Oomoo`02Ool2000?Ool2000;Ool20002Ool2000]Ool00`00Oomoo`1@Ool005=oo`03
001oogoo00Eoo`03001oogoo00Moo`<001=oo`8001Aoo`8000moo`D00004Ool00000000>Ool20004
Ool00`00Oomoo`02Ool2000@Ool2000:Ool01000Oomoogoo0P00;7oo00<007ooOol0DGoo001COol0
0`00Oomoo`05Ool00`00Oomoo`06Ool4000COol00`00Oomoo`0COol2000?Ool00`00Oomoo`040000
17oo0000000037oo00<007ooOol00goo00@007ooOomoo`80015oo`8000Yoo`04001oogooOol2000[
Ool00`00Oomoo`1BOol0059oo`03001oogoo00Ioo`03001oogoo00Ioo`<001=oo`8001Eoo`8000mo
o`8000=oo`@00004Ool000000009Ool20005Ool01000Oomoogoo0P004Goo0P002Goo0P000goo0P00
:goo00<007ooOol0DWoo001BOol00`00Oomoo`06Ool20006Ool4000COol00`00Oomoo`0DOol2000?
Ool20005Ool80007Ool00`00Oomoo`04Ool00`00Oomoo`02000BOol20009Ool20003Ool2000ZOol0
0`00Oomoo`1COol0059oo`03001oogoo00Ioo`8000Ioo`<001Aoo`03001oogoo01Eoo`03001oogoo
00eoo`8000Moo`P000Aoo`8000Ioo`03001oogoo0080019oo`8000Uoo`03001oogoo009oo`8002Uo
o`03001oogoo05Aoo`00DWoo00<007ooOol01Woo0P001Goo0`0057oo0P005goo0P003Woo0P002Goo
20000Woo00<007ooOol01Goo00<007ooOol00P004goo00<007ooOol01goo00@007ooOomoo`<002Uo
o`03001oogoo05Aoo`00DGoo00<007ooOol01goo0P0017oo0`005Goo0P005goo0P003Woo0P002goo
2@001goo00<007ooOol00P004goo00<007ooOol01Woo0P000goo0P00:Goo00<007ooOol0EGoo001A
Ool00`00Oomoo`08Ool20003Ool2000FOol00`00Oomoo`0FOol2000?Ool00`00Oomoo`0;Ool80006
Ool01000Ool0000057oo00<007ooOol01Woo00<007ooOol00Woo0P00:7oo00<007ooOol0EWoo001A
Ool00`00Oomoo`08Ool6000GOol00`00Oomoo`0FOol2000?Ool00`00Oomoo`0=Ool400000goo0000
00020003Ool01000Ool0000057oo00<007ooOol01Goo0P0017oo0P00:7oo00<007ooOol0EWoo001A
Ool00`00Oomoo`09Ool4000HOol00`00Oomoo`0GOol00`00Oomoo`0=Ool2000?Ool500000goo0000
000200000goo001oo`02000DOol00`00Oomoo`04Ool20005Ool2000WOol00`00Oomoo`1GOol0051o
o`03001oogoo00aoo`03001oogoo01Moo`03001oogoo01Moo`8000ioo`8000ioo`80009oo`@00003
Ool0000000D001Aoo`03001oogoo00Aoo`8000Aoo`8002Moo`03001oogoo05Qoo`00D7oo00<007oo
Ool037oo00<007ooOol05goo00<007ooOol05goo0P003Woo0P003Goo0`0017oo10000Woo100057oo
00<007ooOol00goo0P001Goo0P009Woo00<007ooOol0FGoo001@Ool00`00Oomoo`0;Ool00`00Oomo
o`0HOol00`00Oomoo`0GOol2000>Ool2000=Ool20007Ool;000AOol01000Oomoogoo0`001Goo0P00
9goo00<007ooOol0FGoo001@Ool00`00Oomoo`0:Ool00`00Oomoo`0IOol2000IOol00`00Oomoo`0<
Ool2000<Ool2000;Ool40002Ool6000=Ool00`00Ool000030005Ool3000VOol00`00Oomoo`1JOol0
04moo`03001oogoo00]oo`03001oogoo01Uoo`8001Uoo`8000eoo`8000]oo`8000ioo`D0009oo`P0
00Ioo`H000Moo`8002Ioo`03001oogoo05]oo`00Cgoo00<007ooOol02Woo00<007ooOol06Woo0P00
6Goo0P003Woo00<007ooOol01goo0P0047oo1`0017oo3`001goo0`009Woo00<007ooOol0Fgoo001?
Ool00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`0GOol2000>Ool00`00Oomoo`06Ool2000A
Ool20003Ool60005Ool80008Ool3000VOol00`00Oomoo`1LOol004ioo`03001oogoo00Yoo`03001o
ogoo01aoo`8001Uoo`8000eoo`03001oogoo00Eoo`80019oo`8000Eoo`L000Qoo`8000Ioo`@002Io
o`03001oogoo05eoo`00CWoo00<007ooOol02Woo00<007ooOol07Goo00<007ooOol05goo0P003Goo
00<007ooOol00goo0`004goo0P002Goo2P0000=oo`0000000goo1@009goo00<007ooOol0GWoo001>
Ool00`00Oomoo`09Ool00`00Oomoo`0NOol2000HOol2000=Ool00`00Oomoo`02Ool2000EOol2000=
Ool@000XOol00`00Oomoo`1NOol004ioo`03001oogoo00Qoo`03001oogoo021oo`03001oogoo01Io
o`8000eoo`03001oogoo008001Moo`03001oogoo011oo`T002Yoo`03001oogoo05moo`00CGoo00<0
07ooOol02Goo00<007ooOol087oo0P005goo0`0037oo100067oo00<007ooOol04Woo0P00;Woo00<0
07ooOol0H7oo001=Ool00`00Oomoo`08Ool00`00Oomoo`0ROol2000FOol3000;Ool3000JOol00`00
Oomoo`0BOol2000^Ool00`00Oomoo`1POol004eoo`03001oogoo00Qoo`03001oogoo02=oo`8001Eo
o`03001oo`0000Uoo`@001]oo`03001oogoo019oo`8002eoo`03001oogoo065oo`00CGoo00<007oo
Ool01goo00<007ooOol09Goo0P004goo10001goo0`000Woo00<007ooOol06Goo00<007ooOol04Goo
0`00;7oo00<007ooOol0HWoo001<Ool00`00Oomoo`07Ool00`00Oomoo`0WOol3000AOol20002Ool0
1000Oomoogoo1@000goo00<007ooOol067oo0P004goo0P00;7oo00<007ooOol0Hgoo001<Ool00`00
Oomoo`07Ool00`00Oomoo`0YOol5000;Ool700000goo000000030005Ool00`00Oomoo`0HOol2000C
Ool2000/Ool00`00Oomoo`1SOol004aoo`03001oogoo00Ioo`03001oogoo02aoo`T000=oo`H0009o
o`800004Ool000000006Ool00`00Oomoo`0HOol2000COol00`00Oomoo`0ZOol00`00Oomoo`1TOol0
04aoo`03001oogoo00Ioo`03001oogoo02moo``000Ioo`@000Moo`03001oogoo01Qoo`80019oo`80
02]oo`03001oogoo06Eoo`00Bgoo00<007ooOol01Woo00<007ooOol0@Woo10001goo00<007ooOol0
67oo0P004Woo0P00:goo00<007ooOol0IGoo001;Ool00`00Oomoo`06Ool00`00Oomoo`12Ool30008
Ool00`00Oomoo`0HOol2000BOol2000ZOol00`00Oomoo`1VOol004]oo`03001oogoo00Eoo`03001o
ogoo04Aoo`8000Qoo`03001oogoo01Qoo`80015oo`8002Yoo`03001oogoo06Moo`00Bgoo00<007oo
Ool017oo00<007ooOol0AGoo0P001goo0P006Woo0P004Goo0P00:Goo00<007ooOol0J7oo001:Ool0
0`00Oomoo`05Ool00`00Oomoo`16Ool00`00Oomoo`05Ool2000JOol2000@Ool2000ZOol00`00Oomo
o`1XOol004Yoo`03001oogoo00Aoo`03001oogoo04Moo`8000Ioo`8001Yoo`80011oo`8002Uoo`03
001oogoo06Uoo`00BWoo00<007ooOol017oo00<007ooOol0B7oo00<007ooOol017oo0P006Woo0P00
3goo0`00:7oo00<007ooOol0JWoo0019Ool00`00Oomoo`04Ool00`00Oomoo`19Ool20005Ool00`00
Oomoo`0IOol2000?Ool2000YOol00`00Oomoo`1ZOol004Uoo`03001oogoo00Aoo`03001oogoo04Yo
o`8000=oo`8001]oo`8000ioo`<002Qoo`03001oogoo06]oo`00BGoo00<007ooOol00goo00<007oo
Ool0Bgoo0`0000=oo`00000077oo0P003Woo0P00:7oo00<007ooOol0K7oo0019Ool00`00Oomoo`02
Ool00`00Oomoo`1=Ool4000MOol2000=Ool3000WOol00`00Oomoo`1]Ool004Qoo`03001oogoo00=o
o`03001oogoo04moo`03001oogoo01aoo`8000eoo`8002Qoo`03001oogoo06eoo`00B7oo00<007oo
Ool00Woo00<007ooOol0Kgoo0`002goo0`009goo00<007ooOol0KWoo0018Ool00`00Oomoo`02Ool0
0`00Oomoo`1`Ool2000;Ool2000WOol00`00Oomoo`1_Ool004Qoo`05001oogooOol0001cOol2000:
Ool3000WOol00`00Oomoo`1_Ool004Moo`03001oogoo009oo`03001oogoo075oo`8000Yoo`8002Mo
o`03001oogoo071oo`00Agoo00D007ooOomoo`0007Aoo`8000Uoo`8002Moo`03001oogoo075oo`00
Agoo00@007ooOol007Eoo`8000Qoo`<002Ioo`03001oogoo079oo`00Agoo00@007ooOol007Eoo`80
00Qoo`8002Moo`03001oogoo079oo`00AWoo00@007ooOol007Ioo`8000Moo`<002Ioo`03001oogoo
07=oo`00AWoo00@007ooOol007Ioo`8000Ioo`<002Ioo`03001oogoo07Aoo`00AWoo00<007oo0000
Mgoo0P001Woo0P009goo00<007ooOol0M7oo0016Ool2001hOol20005Ool3000VOol00`00Oomoo`1e
Ool004Eoo`03001oo`0007Qoo`8000Aoo`<002Ioo`03001oogoo07Ioo`00AGoo0P00NGoo0P000goo
0`009Woo00<007ooOol0Mgoo0015Ool2001jOol20002Ool2000WOol00`00Oomoo`1gOol004Eoo`03
001oogoo07Uoo`D002Moo`03001oogoo07Qoo`00A7oo0P00Ngoo10009goo00<007ooOol0NGoo0014
Ool2001kOol00`00Oomoo`0XOol00`00Oomoo`1iOol004Ioo`8007Uoo`03001oogoo02Moo`03001o
ogoo07Yoo`00B7oo0P00Mgoo00<007ooOol09Woo00<007ooOol0Ngoo001:Ool2001eOol00`00Oomo
o`0UOol00`00Oomoo`1lOol004aoo`<0079oo`03001oogoo02Eoo`03001oogoo07aoo`00Cgoo0P00
L7oo00<007ooOol097oo00<007ooOol0OGoo001AOol2001^Ool00`00Oomoo`0SOol00`00Oomoo`1n
Ool005=oo`8006aoo`03001oogoo02=oo`03001oogoo07ioo`00EGoo0P00JWoo00<007ooOol08Woo
00<007ooOol0Ogoo001GOol3001WOol00`00Oomoo`0QOol00`00Oomoo`20Ool005Yoo`8006Eoo`03
001oogoo021oo`03001oogoo085oo`00G7oo0P00Hgoo00<007ooOol087oo00<007ooOol0PGoo001N
Ool2001QOol00`00Oomoo`0OOol00`00Oomoo`22Ool0061oo`<005ioo`03001oogoo01ioo`03001o
ogoo08=oo`00Hgoo0P00GGoo00<007ooOol07Goo00<007ooOol0Pgoo001UOol2001KOol00`00Oomo
o`0LOol00`00Oomoo`24Ool006Moo`8005Uoo`03001oogoo01]oo`03001oogoo08Eoo`00JGoo0P00
Egoo00<007ooOol06Woo00<007ooOol0QWoo001[Ool3001DOol00`00Oomoo`0JOol00`00Oomoo`26
Ool006ioo`80059oo`03001oogoo01Uoo`03001oogoo08Moo`00L7oo0P00D7oo00<007ooOol067oo
00<007ooOol0R7oo001bOol2001>Ool00`00Oomoo`0HOol00`00Oomoo`28Ool007Aoo`<004]oo`03
001oogoo01Moo`03001oogoo08Uoo`00Mgoo0P00BGoo00<007ooOol05Woo00<007ooOol0RWoo001i
Ool20017Ool00`00Oomoo`0FOol00`00Oomoo`2:Ool007]oo`8004Eoo`03001oogoo01Eoo`03001o
ogoo08]oo`00OGoo0`00@Woo00<007ooOol057oo00<007ooOol0S7oo0020Ool20010Ool00`00Oomo
o`0COol00`00Oomoo`2=Ool0089oo`8003ioo`03001oogoo01=oo`03001oogoo08eoo`00Q7oo0P00
?7oo00<007ooOol04Woo00<007ooOol0SWoo0026Ool2000jOol00`00Oomoo`0AOol00`00Oomoo`2?
Ool008Qoo`<003Moo`03001oogoo015oo`03001oogoo08moo`00Rgoo0P00=Goo00<007ooOol047oo
00<007ooOol0T7oo002=Ool2000cOol00`00Oomoo`0?Ool00`00Oomoo`2AOol008moo`80035oo`03
001oogoo00ioo`03001oogoo099oo`00TGoo0`00;Woo00<007ooOol03Woo00<007ooOol0TWoo002D
Ool2000/Ool00`00Oomoo`0=Ool00`00Oomoo`2COol009Ioo`8002Yoo`03001oogoo00aoo`03001o
ogoo09Aoo`00V7oo0P00:7oo00<007ooOol037oo00<007ooOol0U7oo002JOol3000UOol00`00Oomo
o`0;Ool00`00Oomoo`2EOol009eoo`8002=oo`03001oogoo00Yoo`03001oogoo09Ioo`00Wgoo0P00
8Goo00<007ooOol02Goo00<007ooOol0Ugoo002QOol2000OOol00`00Oomoo`09Ool00`00Oomoo`2G
Ool00:=oo`8001ioo`03001oogoo00Moo`03001oogoo09Qoo`00YGoo0`006goo00<007ooOol01Woo
00<007ooOol0VGoo002XOol2000IOol00`00Oomoo`06Ool00`00Oomoo`2IOol00:Yoo`8001Moo`03
001oogoo00Eoo`03001oogoo09Yoo`00[7oo0P005Goo00<007ooOol017oo00<007ooOol0Vgoo002^
Ool3000BOol00`00Oomoo`03Ool00`00Oomoo`2LOol00;5oo`80011oo`03001oogoo00=oo`03001o
ogoo09aoo`00/goo0P003Woo00<007ooOol00Woo00<007ooOol0WGoo002eOol2000<Ool01@00Oomo
ogoo0000X7oo002gOol2000:Ool01@00Oomoogoo0000X7oo002iOol30007Ool01000Oomoo`00XGoo
002lOol20005Ool00`00Ool0002ROol00;ioo`8000=oo`800:=oo`00`7oo0P0000=oo`000000Xgoo
0032Ool2002TOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo0000\
\>"]],

Cell["\<\
Fig. 1.12 Magnetic field lines  in a TE(1,2,1) cavity mode (The \
image can be reoriented by dragging on it with the mouse.)\
\>", "Caption",
  CellTags->"Fig. 1.12"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  "  Repeat the calculation of the Lyapunov exponent done in the text, but \
for an ",
  StyleBox["integrable",
    FontSlant->"Italic"],
  " system, the one-dimensional undamped harmonic oscillator, with \
dimensionless Hamiltonian ",
  StyleBox["H=",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`v\^2\)]],
  StyleBox[" + ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  ")/2,",
  StyleBox[" ",
    FontSlant->"Italic"],
  " taking the",
  StyleBox[" ",
    FontSlant->"Italic"],
  "initial condition ",
  StyleBox["x",
    FontSlant->"Italic"],
  "=0, ",
  StyleBox["v",
    FontSlant->"Italic"],
  " = 1.  What happens to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](t)\)]],
  ", the right-hand side of ",
  ButtonBox["Eq. (1.4.2)",
    ButtonData:>"(1.4.2)",
    ButtonStyle->"Hyperlink"],
  ", at large times?"
}], "Text",
  CellTags->"i:58"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Not all trajectories of a chaotic system have positive Lyapunov \
exponents. Certain regions of phase-space can still be integrable, containing \
nested curves upon which the orbits lie.  Take, for example, our chaotic \
system described by ",
  ButtonBox["Eq. (1.4.1)",
    ButtonData:>"(1.4.1)",
    ButtonStyle->"Hyperlink"],
  " with the same parameter values as discussed before, (",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "=",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`k\_1\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "=1, ",
  StyleBox["\[Omega]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "=2), but a different initial condition, ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(0) = 3, ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(0) = 3.  Repeat the evaluation of the Lyapunov exponent for this \
trajectory, again taking 40 adjacent trajectories with ",
  Cell[BoxData[
      FormBox[
        RowBox[{"|", 
          FormBox[
            SubscriptBox[
              StyleBox["d",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"],
            "TraditionalForm"], "|"}], TraditionalForm]]],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-5\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 50\)]],
  "."
}], "Text",
  CellTags->"i:59"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Hamiltonian systems are not the only systems that exhibit chaotic motion. \
Systems that have dissipation can also exhibit chaos. The fact that these \
systems no longer conserve phase-space volume implies that orbits can \
collapse onto weirdly-shaped surfaces called ",
  StyleBox["strange attractors",
    FontSlant->"Italic"],
  ".  Although motion becomes confined to this attracting surface, motion \
within the surface can be chaotic, exhibiting a positive Lyapunov exponent. \
The Lorenz system of ODEs is an example of a dissipative chaotic system with \
a strange attractor.  This system models an unstable thermally convecting \
fluid, heated from below. The equations for the system are three coupled ODEs \
for functions ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "),",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), and ",
  StyleBox["z",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), (which are a normalized amplitude of convection, a temperature \
difference between ascending and descending fluid, and a distortion of the \
vertical temperature profile from a linear law, respectively):"
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
              MultilineFunction->None],
            FontSize->14], "=", \(\[Sigma](y - x)\)}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            FractionBox[\(\[DifferentialD]y\), \(\[DifferentialD]t\),
              MultilineFunction->None],
            FontSize->14], "=", \(r\ x - y - x\ z\)}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            FractionBox[\(\[DifferentialD]z\), \(\[DifferentialD]t\),
              MultilineFunction->None],
            FontSize->14], "=", \(x\ y - b\ z\)}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(1.4.25)"],

Cell[TextData[{
  "where \[Sigma] , ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " are constants. For sufficiently large ",
  StyleBox["r",
    FontSlant->"Italic"],
  ",  this system exhibits chaos."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Taking characteristic values of ",
  StyleBox["\[Sigma]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox["=10, ",
    FontFamily->"Symbol"],
  StyleBox["b",
    FontSlant->"Italic"],
  "=8/3, and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 28, ",
  StyleBox[" ",
    FontFamily->"Symbol"],
  "integrate the Lorenz equations for 0<",
  StyleBox["t",
    FontSlant->"Italic"],
  "<100. Take as an initial condition ",
  StyleBox["x",
    FontSlant->"Italic"],
  "=1,",
  StyleBox["y",
    FontSlant->"Italic"],
  "=15,",
  StyleBox["z",
    FontSlant->"Italic"],
  "=10. Use the function ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to plot the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x(t), y(t), z(t))\)\)]],
  " orbit .  This orbit will exhibit the strange attractor for this \
dissipative dynamical system. ",
  StyleBox["(Hints: To integrate for the required length of time you will \
need to increase the ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["MaxSteps",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" option in ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" to around 10,000 or so. Also, after plotting the strange \
attractor, it is fun to rotate it and view it at different angles. See the \
discussion of real-time 3D graphics in Chapter ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  ButtonBox["9",
    ButtonData:>{"Chapter9.nb", None},
    ButtonStyle->"Hyperlink"],
  StyleBox[". You will need to increase the number of plot points used in the \
parametric plot, to ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["PlotPoints->5000",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" or more.)",
    FontColor->RGBColor[0, 0, 0.00389105]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Repeat part (a) using higher accuracy, by taking ",
  StyleBox["AccuracyGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PrecisionGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to their highest possible values for your computer system. Plot the \
displacement between the two trajectories as a function of time. Does this \
system exhibit the explosive growth in error characteristic of chaos? "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Calculate the Lyapunov exponent for this trajectory by plotting the \
right-hand side of ",
  ButtonBox["Eq. (1.4.2)",
    ButtonData:>"(1.4.2)",
    ButtonStyle->"Hyperlink"],
  " for  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 15\)]],
  ". [Now ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["z",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Bold"], "=", " ", \((x, y, z)\)}], 
        TraditionalForm]]],
  " in ",
  ButtonBox["Eq. (1.4.2)",
    ButtonData:>"(1.4.2)",
    ButtonStyle->"Hyperlink"],
  ".] Average over 20 nearby trajectories with  |",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["d",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  "| < ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-5\)\)]],
  "."
}], "Text",
  CellTags->"i:62"],

Cell[TextData[{
  "The solution to part a) is shown  in Fig. ",
  ButtonBox["1.13",
    ButtonData:>"Fig. 1.13",
    ButtonStyle->"Hyperlink"],
  " (this plot can be viewed from different angles by dragging on it using  \
the mouse):"
}], "Text"],

Cell[BoxData[
  Graphics3D[{
    Line[{{1.000000, 15.000000, 10.000000},{2.337856, 15.152051, 9.986897}}],
    Line[{{2.337856, 15.152051, 9.986897},{3.574012, 15.530132, 10.172983}}],
    Line[{{3.574012, 15.530132, 10.172983},{4.738314, 16.106316, 10.555212}}],
    
    Line[{{4.738314, 16.106316, 10.555212},{5.855045, 16.851147, 11.139816}}],
    
    Line[{{5.855045, 16.851147, 11.139816},{6.943254, 17.732479, 11.939657}}],
    
    Line[{{6.943254, 17.732479, 11.939657},{8.016925, 18.713840, 12.971772}}],
    
    Line[{{8.016925, 18.713840, 12.971772},{9.084954, 19.752586, 14.254806}}],
    
    Line[{{9.084954, 19.752586, 14.254806},{
      10.150963, 20.798189, 15.805965}}],
    Line[{{10.150963, 20.798189, 15.805965},{
      11.212988, 21.790998, 17.637310}}],
    Line[{{11.212988, 21.790998, 17.637310},{
      12.263118, 22.662033, 19.751232}}],
    Line[{{12.263118, 22.662033, 19.751232},{
      13.287227, 23.334364, 22.135406}}],
    Line[{{13.287227, 23.334364, 22.135406},{
      14.264962, 23.726706, 24.757658}}],
    Line[{{14.264962, 23.726706, 24.757658},{
      15.170202, 23.759630, 27.561739}}],
    Line[{{15.170202, 23.759630, 27.561739},{
      15.972179, 23.364384, 30.465368}}],
    Line[{{15.972179, 23.364384, 30.465368},{
      16.637463, 22.493452, 33.362129}}],
    Line[{{16.637463, 22.493452, 33.362129},{
      17.132738, 21.130896, 36.128159}}],
    Line[{{17.132738, 21.130896, 36.128159},{
      17.428192, 19.300148, 38.633728}}],
    Line[{{17.428192, 19.300148, 38.633728},{
      17.501114, 17.066362, 40.758633}}],
    Line[{{17.501114, 17.066362, 40.758633},{
      17.339020, 14.531789, 42.407940}}],
    Line[{{17.339020, 14.531789, 42.407940},{
      16.941679, 11.824023, 43.524727}}],
    Line[{{16.941679, 11.824023, 43.524727},{
      16.321609, 9.079737, 44.096458}}],
    Line[{{16.321609, 9.079737, 44.096458},{15.502877, 6.427318, 44.153481}}],
    
    Line[{{15.502877, 6.427318, 44.153481},{14.518472, 3.972615, 43.760529}}],
    
    Line[{{14.518472, 3.972615, 43.760529},{13.406856, 1.790296, 43.004017}}],
    
    Line[{{13.406856, 1.790296, 43.004017},{
      12.208315, -0.078362, 41.978405}}],
    Line[{{12.208315, -0.078362, 41.978405},{
      10.961724, -1.622309, 40.774570}}],
    Line[{{10.961724, -1.622309, 40.774570},{
      9.702104, -2.854249, 39.471806}}],
    Line[{{9.702104, -2.854249, 39.471806},{8.459093, -3.802980, 38.133709}}],
    
    Line[{{8.459093, -3.802980, 38.133709},{7.256284, -4.506219, 36.807381}}],
    
    Line[{{7.256284, -4.506219, 36.807381},{6.111244, -5.004838, 35.524799}}],
    
    Line[{{6.111244, -5.004838, 35.524799},{5.035998, -5.338796, 34.305450}}],
    
    Line[{{5.035998, -5.338796, 34.305450},{4.037771, -5.544663, 33.159199}}],
    
    Line[{{4.037771, -5.544663, 33.159199},{3.119838, -5.654380, 32.089104}}],
    
    Line[{{3.119838, -5.654380, 32.089104},{2.282368, -5.694890, 31.093729}}],
    
    Line[{{2.282368, -5.694890, 31.093729},{1.523180, -5.688320, 30.168953}}],
    
    Line[{{1.523180, -5.688320, 30.168953},{0.838414, -5.652453, 29.309305}}],
    
    Line[{{0.838414, -5.652453, 29.309305},{0.223067, -5.601331, 28.508860}}],
    
    Line[{{
      0.223067, -5.601331, 28.508860},{-0.328564, -5.545857, 27.761820}}],
    Line[{{-0.328564, -5.545857, 27.761820},{-0.822552, -5.494376, 
        27.062853}}],
    Line[{{-0.822552, -5.494376, 27.062853},{-1.265082, -5.453176, 
        26.407276}}],
    Line[{{-1.265082, -5.453176, 26.407276},{-1.662266, -5.426926, 
        25.791107}}],
    Line[{{-1.662266, -5.426926, 25.791107},{-2.020016, -5.419023, 
        25.211075}}],
    Line[{{-2.020016, -5.419023, 25.211075},{-2.343955, -5.431890, 
        24.664570}}],
    Line[{{-2.343955, -5.431890, 24.664570},{-2.639365, -5.467209, 
        24.149595}}],
    Line[{{-2.639365, -5.467209, 24.149595},{-2.911154, -5.526106, 
        23.664690}}],
    Line[{{-2.911154, -5.526106, 23.664690},{-3.163854, -5.609299, 
        23.208879}}],
    Line[{{-3.163854, -5.609299, 23.208879},{-3.401614, -5.717206, 
        22.781618}}],
    Line[{{-3.401614, -5.717206, 22.781618},{-3.628221, -5.850037, 
        22.382736}}],
    Line[{{-3.628221, -5.850037, 22.382736},{-3.847111, -6.007844, 
        22.012415}}],
    Line[{{-3.847111, -6.007844, 22.012415},{-4.061395, -6.190575, 
        21.671144}}],
    Line[{{-4.061395, -6.190575, 21.671144},{-4.273876, -6.398088, 
        21.359715}}],
    Line[{{-4.273876, -6.398088, 21.359715},{-4.487074, -6.630165, 
        21.079195}}],
    Line[{{-4.487074, -6.630165, 21.079195},{-4.703246, -6.886500, 
        20.830931}}],
    Line[{{-4.703246, -6.886500, 20.830931},{-4.924397, -7.166691, 
        20.616524}}],
    Line[{{-4.924397, -7.166691, 20.616524},{-5.152300, -7.470201, 
        20.437840}}],
    Line[{{-5.152300, -7.470201, 20.437840},{-5.388500, -7.796329, 
        20.296993}}],
    Line[{{-5.388500, -7.796329, 20.296993},{-5.634315, -8.144140, 
        20.196342}}],
    Line[{{-5.634315, -8.144140, 20.196342},{-5.890838, -8.512419, 
        20.138466}}],
    Line[{{-5.890838, -8.512419, 20.138466},{-6.158926, -8.899592, 
        20.126144}}],
    Line[{{-6.158926, -8.899592, 20.126144},{-6.439182, -9.303640, 
        20.162312}}],
    Line[{{-6.439182, -9.303640, 20.162312},{-6.731935, -9.722019, 
        20.250008}}],
    Line[{{-6.731935, -9.722019, 20.250008},{-7.037212, -10.151564, 
        20.392305}}],
    Line[{{-7.037212, -10.151564, 20.392305},{-7.354702, -10.588393, 
        20.592196}}],
    Line[{{-7.354702, -10.588393, 20.592196},{-7.683716, -11.027829, 
        20.852461}}],
    Line[{{-7.683716, -11.027829, 20.852461},{-8.023146, -11.464319, 
        21.175533}}],
    Line[{{-8.023146, -11.464319, 21.175533},{-8.371411, -11.891394, 
        21.563267}}],
    Line[{{-8.371411, -11.891394, 21.563267},{-8.726428, -12.301658, 
        22.016718}}],
    Line[{{-8.726428, -12.301658, 22.016718},{-9.085556, -12.686803, 
        22.535921}}],
    Line[{{-9.085556, -12.686803, 22.535921},{-9.445581, -13.037743, 
        23.119556}}],
    Line[{{-9.445581, -13.037743, 23.119556},{-9.802701, -13.344803, 
        23.764713}}],
    Line[{{-9.802701, -13.344803, 23.764713},{-10.152523, -13.597904, 
        24.466614}}],
    Line[{{-10.152523, -13.597904, 24.466614},{-10.490125, -13.787062, 
        25.218386}}],
    Line[{{-10.490125, -13.787062, 25.218386},{-10.810116, -13.902746, 
        26.010946}}],
    Line[{{-10.810116, -13.902746, 26.010946},{-11.106760, -13.936457, 
        26.832968}}],
    Line[{{-11.106760, -13.936457, 26.832968},{-11.374128, -13.881283, 
        27.671003}}],
    Line[{{-11.374128, -13.881283, 27.671003},{-11.606297, -13.732495, 
        28.509768}}],
    Line[{{-11.606297, -13.732495, 28.509768},{-11.797587, -13.488081, 
        29.332630}}],
    Line[{{-11.797587, -13.488081, 29.332630},{-11.942814, -13.149145, 
        30.122252}}],
    Line[{{-11.942814, -13.149145, 30.122252},{-12.037556, -12.720149, 
        30.861368}}],
    Line[{{-12.037556, -12.720149, 30.861368},{-12.078397, -12.208902, 
        31.533644}}],
    Line[{{-12.078397, -12.208902, 31.533644},{-12.063148, -11.626349, 
        32.124504}}],
    Line[{{-12.063148, -11.626349, 32.124504},{-11.990996, -10.986043, 
        32.621929}}],
    Line[{{-11.990996, -10.986043, 32.621929},{-11.862598, -10.303454, 
        33.017025}}],
    Line[{{-11.862598, -10.303454, 33.017025},{-11.680080, -9.595135, 
        33.304401}}],
    Line[{{-11.680080, -9.595135, 33.304401},{-11.446953, -8.877802, 
        33.482262}}],
    Line[{{-11.446953, -8.877802, 33.482262},{-11.167960, -8.167476, 
        33.552261}}],
    Line[{{-11.167960, -8.167476, 33.552261},{-10.848853, -7.478714, 
        33.519112}}],
    Line[{{-10.848853, -7.478714, 33.519112},{-10.496125, -6.824039, 
        33.390022}}],
    Line[{{-10.496125, -6.824039, 33.390022},{-10.116729, -6.213568, 
        33.174057}}],
    Line[{{-10.116729, -6.213568, 33.174057},{-9.717794, -5.654848, 
        32.881454}}],
    Line[{{-9.717794, -5.654848, 32.881454},{-9.306370, -5.152892, 
        32.522995}}],
    Line[{{-9.306370, -5.152892, 32.522995},{-8.889192, -4.710370, 
        32.109455}}],
    Line[{{-8.889192, -4.710370, 32.109455},{-8.472508, -4.327909, 
        31.651165}}],
    Line[{{-8.472508, -4.327909, 31.651165},{-8.061952, -4.004454, 
        31.157705}}],
    Line[{{-8.061952, -4.004454, 31.157705},{-7.662448, -3.737650, 
        30.637697}}],
    Line[{{-7.662448, -3.737650, 30.637697},{-7.278184, -3.524214, 
        30.098728}}],
    Line[{{-7.278184, -3.524214, 30.098728},{-6.912605, -3.360270, 
        29.547323}}],
    Line[{{-6.912605, -3.360270, 29.547323},{-6.568442, -3.241642, 
        28.989004}}],
    Line[{{-6.568442, -3.241642, 28.989004},{-6.247764, -3.164088, 
        28.428373}}],
    Line[{{-6.247764, -3.164088, 28.428373},{-5.952044, -3.123479, 
        27.869223}}],
    Line[{{-5.952044, -3.123479, 27.869223},{-5.682232, -3.115940, 
        27.314655}}],
    Line[{{-5.682232, -3.115940, 27.314655},{-5.438837, -3.137931, 
        26.767199}}],
    Line[{{-5.438837, -3.137931, 26.767199},{-5.221998, -3.186309, 
        26.228918}}],
    Line[{{-5.221998, -3.186309, 26.228918},{-5.031566, -3.258353, 
        25.701509}}],
    Line[{{-5.031566, -3.258353, 25.701509},{-4.867164, -3.351765, 
        25.186392}}],
    Line[{{-4.867164, -3.351765, 25.186392},{-4.728255, -3.464665, 
        24.684782}}],
    Line[{{-4.728255, -3.464665, 24.684782},{-4.614192, -3.595568, 
        24.197746}}],
    Line[{{-4.614192, -3.595568, 24.197746},{-4.524268, -3.743353, 
        23.726269}}],
    Line[{{-4.524268, -3.743353, 23.726269},{-4.457750, -3.907232, 
        23.271280}}],
    Line[{{-4.457750, -3.907232, 23.271280},{-4.413917, -4.086715, 
        22.833704}}],
    Line[{{-4.413917, -4.086715, 22.833704},{-4.392082, -4.281571, 
        22.414486}}],
    Line[{{-4.392082, -4.281571, 22.414486},{-4.391613, -4.491797, 
        22.014627}}],
    Line[{{-4.391613, -4.491797, 22.014627},{-4.411946, -4.717578, 
        21.635193}}],
    Line[{{-4.411946, -4.717578, 21.635193},{-4.452598, -4.959251, 
        21.277359}}],
    Line[{{-4.452598, -4.959251, 21.277359},{-4.513169, -5.217276, 
        20.942417}}],
    Line[{{-4.513169, -5.217276, 20.942417},{-4.593343, -5.492191, 
        20.631800}}],
    Line[{{-4.593343, -5.492191, 20.631800},{-4.692893, -5.784580, 
        20.347107}}],
    Line[{{-4.692893, -5.784580, 20.347107},{-4.811665, -6.095037, 
        20.090122}}],
    Line[{{-4.811665, -6.095037, 20.090122},{-4.949575, -6.424110, 
        19.862829}}],
    Line[{{-4.949575, -6.424110, 19.862829},{-5.106600, -6.772268, 
        19.667435}}],
    Line[{{-5.106600, -6.772268, 19.667435},{-5.282752, -7.139837, 
        19.506384}}],
    Line[{{-5.282752, -7.139837, 19.506384},{-5.478066, -7.526940, 
        19.382362}}],
    Line[{{-5.478066, -7.526940, 19.382362},{-5.692574, -7.933435, 
        19.298321}}],
    Line[{{-5.692574, -7.933435, 19.298321},{-5.926273, -8.358821, 
        19.257442}}],
    Line[{{-5.926273, -8.358821, 19.257442},{-6.179093, -8.802165, 
        19.263163}}],
    Line[{{-6.179093, -8.802165, 19.263163},{-6.450858, -9.261991, 
        19.319105}}],
    Line[{{-6.450858, -9.261991, 19.319105},{-6.741234, -9.736176, 
        19.429058}}],
    Line[{{-6.741234, -9.736176, 19.429058},{-7.049686, -10.221838, 
        19.596882}}],
    Line[{{-7.049686, -10.221838, 19.596882},{-7.375410, -10.715218, 
        19.826395}}],
    Line[{{-7.375410, -10.715218, 19.826395},{-7.717275, -11.211549, 
        20.121273}}],
    Line[{{-7.717275, -11.211549, 20.121273},{-8.073754, -11.705005, 
        20.484787}}],
    Line[{{-8.073754, -11.705005, 20.484787},{-8.442848, -12.188539, 
        20.919662}}],
    Line[{{-8.442848, -12.188539, 20.919662},{-8.822030, -12.653959, 
        21.427721}}],
    Line[{{-8.822030, -12.653959, 21.427721},{-9.208165, -13.091858, 
        22.009613}}],
    Line[{{-9.208165, -13.091858, 22.009613},{-9.597477, -13.491772, 
        22.664450}}],
    Line[{{-9.597477, -13.491772, 22.664450},{-9.985507, -13.842372, 
        23.389446}}],
    Line[{{-9.985507, -13.842372, 23.389446},{-10.367105, -14.131761, 
        24.179544}}],
    Line[{{-10.367105, -14.131761, 24.179544},{-10.736486, -14.347979, 
        25.027178}}],
    Line[{{-10.736486, -14.347979, 25.027178},{-11.087280, -14.479506, 
        25.921984}}],
    Line[{{-11.087280, -14.479506, 25.921984},{-11.412682, -14.516018, 
        26.850784}}],
    Line[{{-11.412682, -14.516018, 26.850784},{-11.705644, -14.449065, 
        27.797792}}],
    Line[{{-11.705644, -14.449065, 27.797792},{-11.959100, -14.272939, 
        28.744781}}],
    Line[{{-11.959100, -14.272939, 28.744781},{-12.166278, -13.985249, 
        29.671925}}],
    Line[{{-12.166278, -13.985249, 29.671925},{-12.321006, -13.587545, 
        30.558468}}],
    Line[{{-12.321006, -13.587545, 30.558468},{-12.418050, -13.085571, 
        31.383818}}],
    Line[{{-12.418050, -13.085571, 31.383818},{-12.453427, -12.489296, 
        32.128635}}],
    Line[{{-12.453427, -12.489296, 32.128635},{-12.424671, -11.812522, 
        32.775944}}],
    Line[{{-12.424671, -11.812522, 32.775944},{-12.331025, -11.072204, 
        33.312115}}],
    Line[{{-12.331025, -11.072204, 33.312115},{-12.173530, -10.287492, 
        33.727554}}],
    Line[{{-12.173530, -10.287492, 33.727554},{-11.955009, -9.478609, 
        34.017124}}],
    Line[{{-11.955009, -9.478609, 34.017124},{-11.679952, -8.665644, 
        34.180195}}],
    Line[{{-11.679952, -8.665644, 34.180195},{-11.354274, -7.867451, 
        34.220310}}],
    Line[{{-11.354274, -7.867451, 34.220310},{-10.985027, -7.100746, 
        34.144596}}],
    Line[{{-10.985027, -7.100746, 34.144596},{-10.580051, -6.379443, 
        33.962967}}],
    Line[{{-10.580051, -6.379443, 33.962967},{-10.147616, -5.714284, 
        33.687271}}],
    Line[{{-10.147616, -5.714284, 33.687271},{-9.696064, -5.112745, 
        33.330376}}],
    Line[{{-9.696064, -5.112745, 33.330376},{-9.233502, -4.579208, 
        32.905407}}],
    Line[{{-9.233502, -4.579208, 32.905407},{-8.767550, -4.115295, 
        32.425110}}],
    Line[{{-8.767550, -4.115295, 32.425110},{-8.305139, -3.720298, 
        31.901369}}],
    Line[{{-8.305139, -3.720298, 31.901369},{-7.852382, -3.391695, 
        31.344900}}],
    Line[{{-7.852382, -3.391695, 31.344900},{-7.414502, -3.125642, 
        30.765083}}],
    Line[{{-7.414502, -3.125642, 30.765083},{-6.995812, -2.917429, 
        30.169926}}],
    Line[{{-6.995812, -2.917429, 30.169926},{-6.599744, -2.761880, 
        29.566116}}],
    Line[{{-6.599744, -2.761880, 29.566116},{-6.228899, -2.653675, 
        28.959137}}],
    Line[{{-6.228899, -2.653675, 28.959137},{-5.885129, -2.587602, 
        28.353409}}],
    Line[{{-5.885129, -2.587602, 28.353409},{-5.569625, -2.558738, 
        27.752439}}],
    Line[{{-5.569625, -2.558738, 27.752439},{-5.283017, -2.562577, 
        27.158995}}],
    Line[{{-5.283017, -2.562577, 27.158995},{-5.025469, -2.595098, 
        26.575237}}],
    Line[{{-5.025469, -2.595098, 26.575237},{-4.796771, -2.652812, 
        26.002861}}],
    Line[{{-4.796771, -2.652812, 26.002861},{-4.596429, -2.732756, 
        25.443199}}],
    Line[{{-4.596429, -2.732756, 25.443199},{-4.423737, -2.832490, 
        24.897320}}],
    Line[{{-4.423737, -2.832490, 24.897320},{-4.277848, -2.950066, 
        24.366108}}],
    Line[{{-4.277848, -2.950066, 24.366108},{-4.157835, -3.083993, 
        23.850327}}],
    Line[{{-4.157835, -3.083993, 23.850327},{-4.062737, -3.233194, 
        23.350668}}],
    Line[{{-4.062737, -3.233194, 23.350668},{-3.991597, -3.396965, 
        22.867792}}],
    Line[{{-3.991597, -3.396965, 22.867792},{-3.943503, -3.574930, 
        22.402370}}],
    Line[{{-3.943503, -3.574930, 22.402370},{-3.917606, -3.767004, 
        21.955107}}],
    Line[{{-3.917606, -3.767004, 21.955107},{-3.913142, -3.973353, 
        21.526766}}],
    Line[{{-3.913142, -3.973353, 21.526766},{-3.929446, -4.194352, 
        21.118195}}],
    Line[{{-3.929446, -4.194352, 21.118195},{-3.965961, -4.430556, 
        20.730349}}],
    Line[{{-3.965961, -4.430556, 20.730349},{-4.022245, -4.682666, 
        20.364313}}],
    Line[{{-4.022245, -4.682666, 20.364313},{-4.097968, -4.951493, 
        20.021317}}],
    Line[{{-4.097968, -4.951493, 20.021317},{-4.192914, -5.237926, 
        19.702763}}],
    Line[{{-4.192914, -5.237926, 19.702763},{-4.306973, -5.542901, 
        19.410254}}],
    Line[{{-4.306973, -5.542901, 19.410254},{-4.440136, -5.867358, 
        19.145601}}],
    Line[{{-4.440136, -5.867358, 19.145601},{-4.592486, -6.212208, 
        18.910872}}],
    Line[{{-4.592486, -6.212208, 18.910872},{-4.764176, -6.578276, 
        18.708391}}],
    Line[{{-4.764176, -6.578276, 18.708391},{-4.955420, -6.966256, 
        18.540777}}],
    Line[{{-4.955420, -6.966256, 18.540777},{-5.166470, -7.376643, 
        18.410963}}],
    Line[{{-5.166470, -7.376643, 18.410963},{-5.397585, -7.809656, 
        18.322201}}],
    Line[{{-5.397585, -7.809656, 18.322201},{-5.649005, -8.265156, 
        18.278082}}],
    Line[{{-5.649005, -8.265156, 18.278082},{-5.920914, -8.742539, 
        18.282522}}],
    Line[{{-5.920914, -8.742539, 18.282522},{-6.213391, -9.240626, 
        18.339750}}],
    Line[{{-6.213391, -9.240626, 18.339750},{-6.526365, -9.757524, 
        18.454268}}],
    Line[{{-6.526365, -9.757524, 18.454268},{-6.859549, -10.290487, 
        18.630760}}],
    Line[{{-6.859549, -10.290487, 18.630760},{-7.212377, -10.835764, 
        18.874023}}],
    Line[{{-7.212377, -10.835764, 18.874023},{-7.583922, -11.388436, 
        19.188776}}],
    Line[{{-7.583922, -11.388436, 19.188776},{-7.972818, -11.942276, 
        19.579483}}],
    Line[{{-7.972818, -11.942276, 19.579483},{-8.377163, -12.489601, 
        20.050083}}],
    Line[{{-8.377163, -12.489601, 20.050083},{-8.794437, -13.021234, 
        20.603636}}],
    Line[{{-8.794437, -13.021234, 20.603636},{-9.221404, -13.526391, 
        21.241980}}],
    Line[{{-9.221404, -13.526391, 21.241980},{-9.654049, -13.992880, 
        21.965225}}],
    Line[{{-9.654049, -13.992880, 21.965225},{-10.087497, -14.407152, 
        22.771313}}],
    Line[{{-10.087497, -14.407152, 22.771313},{-10.516012, -14.754780, 
        23.655497}}],
    Line[{{-10.516012, -14.754780, 23.655497},{-10.933003, -15.020903, 
        24.609924}}],
    Line[{{-10.933003, -15.020903, 24.609924},{-11.331104, -15.190959, 
        25.623281}}],
    Line[{{-11.331104, -15.190959, 25.623281},{-11.702302, -15.251549, 
        26.680595}}],
    Line[{{-11.702302, -15.251549, 26.680595},{-12.038177, -15.191448, 
        27.763372}}],
    Line[{{-12.038177, -15.191448, 27.763372},{-12.330187, -15.002609, 
        28.849979}}],
    Line[{{-12.330187, -15.002609, 28.849979},{-12.570028, -14.681206, 
        29.916311}}],
    Line[{{-12.570028, -14.681206, 29.916311},{-12.750069, -14.228392, 
        30.936949}}],
    Line[{{-12.750069, -14.228392, 30.936949},{-12.863765, -13.650720, 
        31.886467}}],
    Line[{{-12.863765, -13.650720, 31.886467},{-12.906089, -12.960258, 
        32.740936}}],
    Line[{{-12.906089, -12.960258, 32.740936},{-12.873887, -12.174084, 
        33.479427}}],
    Line[{{-12.873887, -12.174084, 33.479427},{-12.766144, -11.313410, 
        34.085342}}],
    Line[{{-12.766144, -11.313410, 34.085342},{-12.584103, -10.402234, 
        34.547390}}],
    Line[{{-12.584103, -10.402234, 34.547390},{-12.331246, -9.465790, 
        34.860096}}],
    Line[{{-12.331246, -9.465790, 34.860096},{-12.013122, -8.528947, 
        35.023769}}],
    Line[{{-12.013122, -8.528947, 35.023769},{-11.637035, -7.614723, 
        35.044052}}],
    Line[{{-11.637035, -7.614723, 35.044052},{-11.211651, -6.743103, 
        34.930988}}],
    Line[{{-11.211651, -6.743103, 34.930988},{-10.746528, -5.930227, 
        34.697941}}],
    Line[{{-10.746528, -5.930227, 34.697941},{-10.251650, -5.188007, 
        34.360340}}],
    Line[{{-10.251650, -5.188007, 34.360340},{-9.736976, -4.524128, 
        33.934525}}],
    Line[{{-9.736976, -4.524128, 33.934525},{-9.212059, -3.942369, 
        33.436749}}],
    Line[{{-9.212059, -3.942369, 33.436749},{-8.685733, -3.443136, 
        32.882389}}],
    Line[{{-8.685733, -3.443136, 32.882389},{-8.165894, -3.024117, 
        32.285408}}],
    Line[{{-8.165894, -3.024117, 32.285408},{-7.659361, -2.680976, 
        31.658047}}],
    Line[{{-7.659361, -2.680976, 31.658047},{-7.171822, -2.407998, 
        31.010704}}],
    Line[{{-7.171822, -2.407998, 31.010704},{-6.707837, -2.198671, 
        30.351984}}],
    Line[{{-6.707837, -2.198671, 30.351984},{-6.270890, -2.046163, 
        29.688818}}],
    Line[{{-6.270890, -2.046163, 29.688818},{-5.863488, -1.943691, 
        29.026670}}],
    Line[{{-5.863488, -1.943691, 29.026670},{-5.487264, -1.884797, 
        28.369751}}],
    Line[{{-5.487264, -1.884797, 28.369751},{-5.143106, -1.863521, 
        27.721245}}],
    Line[{{-5.143106, -1.863521, 27.721245},{-4.831279, -1.874530, 
        27.083511}}],
    Line[{{-4.831279, -1.874530, 27.083511},{-4.551547, -1.913154, 
        26.458275}}],
    Line[{{-4.551547, -1.913154, 26.458275},{-4.303285, -1.975409, 
        25.846783}}],
    Line[{{-4.303285, -1.975409, 25.846783},{-4.085582, -2.057982, 
        25.249926}}],
    Line[{{-4.085582, -2.057982, 25.249926},{-3.897330, -2.158187, 
        24.668346}}],
    Line[{{-3.897330, -2.158187, 24.668346},{-3.737296, -2.273922, 
        24.102528}}],
    Line[{{-3.737296, -2.273922, 24.102528},{-3.604192, -2.403611, 
        23.552847}}],
    Line[{{-3.604192, -2.403611, 23.552847},{-3.496729, -2.546149, 
        23.019634}}],
    Line[{{-3.496729, -2.546149, 23.019634},{-3.413650, -2.700852, 
        22.503199}}],
    Line[{{-3.413650, -2.700852, 22.503199},{-3.353776, -2.867396, 
        22.003872}}],
    Line[{{-3.353776, -2.867396, 22.003872},{-3.316021, -3.045779, 
        21.522024}}],
    Line[{{-3.316021, -3.045779, 21.522024},{-3.299420, -3.236272, 
        21.058090}}],
    Line[{{-3.299420, -3.236272, 21.058090},{-3.303134, -3.439384, 
        20.612577}}],
    Line[{{-3.303134, -3.439384, 20.612577},{-3.326463, -3.655827, 
        20.186102}}],
    Line[{{-3.326463, -3.655827, 20.186102},{-3.368852, -3.886486, 
        19.779385}}],
    Line[{{-3.368852, -3.886486, 19.779385},{-3.429887, -4.132390, 
        19.393293}}],
    Line[{{-3.429887, -4.132390, 19.393293},{-3.509300, -4.394690, 
        19.028841}}],
    Line[{{-3.509300, -4.394690, 19.028841},{-3.606962, -4.674628, 
        18.687227}}],
    Line[{{-3.606962, -4.674628, 18.687227},{-3.722878, -4.973517, 
        18.369850}}],
    Line[{{-3.722878, -4.973517, 18.369850},{-3.857179, -5.292712, 
        18.078342}}],
    Line[{{-3.857179, -5.292712, 18.078342},{-4.010114, -5.633572, 
        17.814592}}],
    Line[{{-4.010114, -5.633572, 17.814592},{-4.182037, -5.997439, 
        17.580786}}],
    Line[{{-4.182037, -5.997439, 17.580786},{-4.373391, -6.385572, 
        17.379431}}],
    Line[{{-4.373391, -6.385572, 17.379431},{-4.584695, -6.799117, 
        17.213396}}],
    Line[{{-4.584695, -6.799117, 17.213396},{-4.816514, -7.239017, 
        17.085945}}],
    Line[{{-4.816514, -7.239017, 17.085945},{-5.069440, -7.705949, 
        17.000761}}],
    Line[{{-5.069440, -7.705949, 17.000761},{-5.344056, -8.200221, 
        16.961975}}],
    Line[{{-5.344056, -8.200221, 16.961975},{-5.640893, -8.721644, 
        16.974171}}],
    Line[{{-5.640893, -8.721644, 16.974171},{-5.960390, -9.269413, 
        17.042404}}],
    Line[{{-5.960390, -9.269413, 17.042404},{-6.302823, -9.841913, 
        17.172134}}],
    Line[{{-6.302823, -9.841913, 17.172134},{-6.668250, -10.436567, 
        17.369221}}],
    Line[{{-6.668250, -10.436567, 17.369221},{-7.056416, -11.049603, 
        17.639751}}],
    Line[{{-7.056416, -11.049603, 17.639751},{-7.466671, -11.675844, 
        17.989964}}],
    Line[{{-7.466671, -11.675844, 17.989964},{-7.897851, -12.308490, 
        18.425930}}],
    Line[{{-7.897851, -12.308490, 18.425930},{-8.348175, -12.938903, 
        18.953314}}],
    Line[{{-8.348175, -12.938903, 18.953314},{-8.815107, -13.556419, 
        19.576931}}],
    Line[{{-8.815107, -13.556419, 19.576931},{-9.295242, -14.148307, 
        20.300240}}],
    Line[{{-9.295242, -14.148307, 20.300240},{-9.784180, -14.699726, 
        21.124758}}],
    Line[{{-9.784180, -14.699726, 21.124758},{-10.276434, -15.193929, 
        22.049379}}],
    Line[{{-10.276434, -15.193929, 22.049379},{-10.765379, -15.612694, 
        23.069683}}],
    Line[{{-10.765379, -15.612694, 23.069683},{-11.243220, -15.936870, 
        24.177217}}],
    Line[{{-11.243220, -15.936870, 24.177217},{-11.701082, -16.147383, 
        25.358963}}],
    Line[{{-11.701082, -16.147383, 25.358963},{-12.129182, -16.226402, 
        26.597044}}],
    Line[{{-12.129182, -16.226402, 26.597044},{-12.517064, -16.158695, 
        27.868628}}],
    Line[{{-12.517064, -16.158695, 27.868628},{-12.854018, -15.933217, 
        29.146452}}],
    Line[{{-12.854018, -15.933217, 29.146452},{-13.129563, -15.544457, 
        30.399857}}],
    Line[{{-13.129563, -15.544457, 30.399857},{-13.334005, -14.993677, 
        31.596188}}],
    Line[{{-13.334005, -14.993677, 31.596188},{-13.459053, -14.289583, 
        32.702785}}],
    Line[{{-13.459053, -14.289583, 32.702785},{-13.498401, -13.448421, 
        33.689125}}],
    Line[{{-13.498401, -13.448421, 33.689125},{-13.448227, -12.493242, 
        34.529018}}],
    Line[{{-13.448227, -12.493242, 34.529018},{-13.307541, -11.452486, 
        35.202454}}],
    Line[{{-13.307541, -11.452486, 35.202454},{-13.078337, -10.358014, 
        35.696896}}],
    Line[{{-13.078337, -10.358014, 35.696896},{-12.765521, -9.242809, 
        36.007847}}],
    Line[{{-12.765521, -9.242809, 36.007847},{-12.376634, -8.138641, 
        36.138634}}],
    Line[{{-12.376634, -8.138641, 36.138634},{-11.921378, -7.074055, 
        36.099453}}],
    Line[{{-11.921378, -7.074055, 36.099453},{-11.411032, -6.072853, 
        35.905895}}],
    Line[{{-11.411032, -6.072853, 35.905895},{-10.857793, -5.153182, 
        35.577229}}],
    Line[{{-10.857793, -5.153182, 35.577229},{-10.274143, -4.327281, 
        35.134617}}],
    Line[{{-10.274143, -4.327281, 35.134617},{-9.672261, -3.601758, 
        34.599541}}],
    Line[{{-9.672261, -3.601758, 34.599541},{-9.063554, -2.978272, 
        33.992516}}],
    Line[{{-9.063554, -2.978272, 33.992516},{-8.458293, -2.454442, 
        33.332199}}],
    Line[{{-8.458293, -2.454442, 33.332199},{-7.865394, -2.024851, 
        32.634865}}],
    Line[{{-7.865394, -2.024851, 32.634865},{-7.292299, -1.682020, 
        31.914175}}],
    Line[{{-7.292299, -1.682020, 31.914175},{-6.744968, -1.417264, 
        31.181231}}],
    Line[{{-6.744968, -1.417264, 31.181231},{-6.227937, -1.221399, 
        30.444757}}],
    Line[{{-6.227937, -1.221399, 30.444757},{-5.744433, -1.085293, 
        29.711401}}],
    Line[{{-5.744433, -1.085293, 29.711401},{-5.296529, -1.000257, 
        28.986069}}],
    Line[{{-5.296529, -1.000257, 28.986069},{-4.885303, -0.958293, 
        28.272251}}],
    Line[{{-4.885303, -0.958293, 28.272251},{-4.511013, -0.952255, 
        27.572346}}],
    Line[{{-4.511013, -0.952255, 27.572346},{-4.173251, -0.975910, 
        26.887903}}],
    Line[{{-4.173251, -0.975910, 26.887903},{-3.871104, -1.023945, 
        26.219875}}],
    Line[{{-3.871104, -1.023945, 26.219875},{-3.603282, -1.091930, 
        25.568769}}],
    Line[{{-3.603282, -1.091930, 25.568769},{-3.368235, -1.176258, 
        24.934805}}],
    Line[{{-3.368235, -1.176258, 24.934805},{-3.164256, -1.274073, 
        24.318014}}],
    Line[{{-3.164256, -1.274073, 24.318014},{-2.989560, -1.383186, 
        23.718313}}],
    Line[{{-2.989560, -1.383186, 23.718313},{-2.842355, -1.501995, 
        23.135571}}],
    Line[{{-2.842355, -1.501995, 23.135571},{-2.720890, -1.629413, 
        22.569637}}],
    Line[{{-2.720890, -1.629413, 22.569637},{-2.623500, -1.764793, 
        22.020374}}],
    Line[{{-2.623500, -1.764793, 22.020374},{-2.548637, -1.907864, 
        21.487680}}],
    Line[{{-2.548637, -1.907864, 21.487680},{-2.494887, -2.058683, 
        20.971498}}],
    Line[{{-2.494887, -2.058683, 20.971498},{-2.460994, -2.217580, 
        20.471834}}],
    Line[{{-2.460994, -2.217580, 20.471834},{-2.445862, -2.385125, 
        19.988754}}],
    Line[{{-2.445862, -2.385125, 19.988754},{-2.448565, -2.562089, 
        19.522408}}],
    Line[{{-2.448565, -2.562089, 19.522408},{-2.468345, -2.749421, 
        19.073029}}],
    Line[{{-2.468345, -2.749421, 19.073029},{-2.504618, -2.948228, 
        18.640949}}],
    Line[{{-2.504618, -2.948228, 18.640949},{-2.556964, -3.159750, 
        18.226610}}],
    Line[{{-2.556964, -3.159750, 18.226610},{-2.625129, -3.385355, 
        17.830582}}],
    Line[{{-2.625129, -3.385355, 17.830582},{-2.709019, -3.626521, 
        17.453571}}],
    Line[{{-2.709019, -3.626521, 17.453571},{-2.808693, -3.884826, 
        17.096458}}],
    Line[{{-2.808693, -3.884826, 17.096458},{-2.924361, -4.161942, 
        16.760307}}],
    Line[{{-2.924361, -4.161942, 16.760307},{-3.056375, -4.459619, 
        16.446398}}],
    Line[{{-3.056375, -4.459619, 16.446398},{-3.205223, -4.779668, 
        16.156267}}],
    Line[{{-3.205223, -4.779668, 16.156267},{-3.371522, -5.123953, 
        15.891731}}],
    Line[{{-3.371522, -5.123953, 15.891731},{-3.556008, -5.494354, 
        15.654943}}],
    Line[{{-3.556008, -5.494354, 15.654943},{-3.759528, -5.892743, 
        15.448425}}],
    Line[{{-3.759528, -5.892743, 15.448425},{-3.983021, -6.320930, 
        15.275126}}],
    Line[{{-3.983021, -6.320930, 15.275126},{-4.227506, -6.780620, 
        15.138475}}],
    Line[{{-4.227506, -6.780620, 15.138475},{-4.494059, -7.273317, 
        15.042433}}],
    Line[{{-4.494059, -7.273317, 15.042433},{-4.783781, -7.800240, 
        14.991547}}],
    Line[{{-4.783781, -7.800240, 14.991547},{-5.097770, -8.362197, 
        14.991009}}],
    Line[{{-5.097770, -8.362197, 14.991009},{-5.437061, -8.959411, 
        15.046663}}],
    Line[{{-5.437061, -8.959411, 15.046663},{-5.802592, -9.591367, 
        15.165093}}],
    Line[{{-5.802592, -9.591367, 15.165093},{-6.195098, -10.256532, 
        15.353496}}],
    Line[{{-6.195098, -10.256532, 15.353496},{-6.615057, -10.952128, 
        15.619795}}],
    Line[{{-6.615057, -10.952128, 15.619795},{-7.062551, -11.673803, 
        15.972345}}],
    Line[{{-7.062551, -11.673803, 15.972345},{-7.537156, -12.415274, 
        16.419876}}],
    Line[{{-7.537156, -12.415274, 16.419876},{-8.037784, -13.168019, 
        16.971098}}],
    Line[{{-8.037784, -13.168019, 16.971098},{-8.562510, -13.920837, 
        17.634348}}],
    Line[{{-8.562510, -13.920837, 17.634348},{-9.108395, -14.659683, 
        18.416883}}],
    Line[{{-9.108395, -14.659683, 18.416883},{-9.671277, -15.367278, 
        19.324251}}],
    Line[{{-9.671277, -15.367278, 19.324251},{-10.245611, -16.023287, 
        20.359259}}],
    Line[{{-10.245611, -16.023287, 20.359259},{-10.824293, -16.604433, 
        21.520958}}],
    Line[{{-10.824293, -16.604433, 21.520958},{-11.398561, -17.085119, 
        22.803474}}],
    Line[{{-11.398561, -17.085119, 22.803474},{-11.957975, -17.438448, 
        24.194910}}],
    Line[{{-11.957975, -17.438448, 24.194910},{-12.490529, -17.637764, 
        25.676462}}],
    Line[{{-12.490529, -17.637764, 25.676462},{-12.982920, -17.658583, 
        27.221968}}],
    Line[{{-12.982920, -17.658583, 27.221968},{-13.420957, -17.480913, 
        28.797905}}],
    Line[{{-13.420957, -17.480913, 28.797905},{-13.790230, -17.091763, 
        30.364487}}],
    Line[{{-13.790230, -17.091763, 30.364487},{-14.076893, -16.487268, 
        31.877544}}],
    Line[{{-14.076893, -16.487268, 31.877544},{-14.268560, -15.674423, 
        33.291180}}],
    Line[{{-14.268560, -15.674423, 33.291180},{-14.355249, -14.671693, 
        34.561214}}],
    Line[{{-14.355249, -14.671693, 34.561214},{-14.330217, -13.508470, 
        35.648708}}],
    Line[{{-14.330217, -13.508470, 35.648708},{-14.190622, -12.223157, 
        36.523285}}],
    Line[{{-14.190622, -12.223157, 36.523285},{-13.937864, -10.860190, 
        37.165531}}],
    Line[{{-13.937864, -10.860190, 37.165531},{-13.577583, -9.466330, 
        37.568195}}],
    Line[{{-13.577583, -9.466330, 37.568195},{-13.119287, -8.086831, 
        37.735985}}],
    Line[{{-13.119287, -8.086831, 37.735985},{-12.575675, -6.762124, 
        37.684082}}],
    Line[{{-12.575675, -6.762124, 37.684082},{-11.961747, -5.525279, 
        37.435722}}],
    Line[{{-11.961747, -5.525279, 37.435722},{-11.293806, -4.400616, 
        37.019329}}],
    Line[{{-11.293806, -4.400616, 37.019329},{-10.588478, -3.403430, 
        36.465603}}],
    Line[{{-10.588478, -3.403430, 36.465603},{-9.861849, -2.540607, 
        35.805023}}],
    Line[{{-9.861849, -2.540607, 35.805023},{-9.128773, -1.811895, 
        35.065899}}],
    Line[{{-9.128773, -1.811895, 35.065899},{-8.402384, -1.211479, 
        34.273155}}],
    Line[{{-8.402384, -1.211479, 34.273155},{-7.693808, -0.729632, 
        33.447697}}],
    Line[{{-7.693808, -0.729632, 33.447697},{-7.012062, -0.354222, 
        32.606308}}],
    Line[{{-7.012062, -0.354222, 32.606308},{-6.364086, -0.071981, 
        31.761904}}],
    Line[{{-6.364086, -0.071981, 31.761904},{-5.754879, 0.130512, 
        30.923992}}],
    Line[{{-5.754879, 0.130512, 30.923992},{-5.187715, 0.266137, 30.099245}}],
    
    Line[{{-5.187715, 0.266137, 30.099245},{-4.664369, 0.346779, 29.292070}}],
    
    Line[{{-4.664369, 0.346779, 29.292070},{-4.185381, 0.383065, 28.505144}}],
    
    Line[{{-4.185381, 0.383065, 28.505144},{-3.750292, 0.384264, 27.739872}}],
    
    Line[{{-3.750292, 0.384264, 27.739872},{-3.357869, 0.358278, 26.996763}}],
    
    Line[{{-3.357869, 0.358278, 26.996763},{-3.006310, 0.311711, 26.275732}}],
    
    Line[{{-3.006310, 0.311711, 26.275732},{-2.693414, 0.249977, 25.576307}}],
    
    Line[{{-2.693414, 0.249977, 25.576307},{-2.416726, 0.177423, 24.897806}}],
    
    Line[{{-2.416726, 0.177423, 24.897806},{-2.173657, 0.097467, 24.239443}}],
    
    Line[{{-2.173657, 0.097467, 24.239443},{-1.961581, 0.012726, 23.600397}}],
    
    Line[{{-1.961581, 0.012726, 23.600397},{-1.777904, -0.074863, 
        22.979870}}],
    Line[{{-1.777904, -0.074863, 22.979870},{-1.620124, -0.163928, 
        22.377100}}],
    Line[{{-1.620124, -0.163928, 22.377100},{-1.485870, -0.253567, 
        21.791393}}],
    Line[{{-1.485870, -0.253567, 21.791393},{-1.372930, -0.343262, 
        21.222111}}],
    Line[{{-1.372930, -0.343262, 21.222111},{-1.279269, -0.432808, 
        20.668680}}],
    Line[{{-1.279269, -0.432808, 20.668680},{-1.203037, -0.522250, 
        20.130585}}],
    Line[{{-1.203037, -0.522250, 20.130585},{-1.142577, -0.611837, 
        19.607363}}],
    Line[{{-1.142577, -0.611837, 19.607363},{-1.096420, -0.701976, 
        19.098606}}],
    Line[{{-1.096420, -0.701976, 19.098606},{-1.063282, -0.793207, 
        18.603949}}],
    Line[{{-1.063282, -0.793207, 18.603949},{-1.042060, -0.886173, 
        18.123064}}],
    Line[{{-1.042060, -0.886173, 18.123064},{-1.031818, -0.981606, 
        17.655670}}],
    Line[{{-1.031818, -0.981606, 17.655670},{-1.031785, -1.080310, 
        17.201517}}],
    Line[{{-1.031785, -1.080310, 17.201517},{-1.041342, -1.183155, 
        16.760395}}],
    Line[{{-1.041342, -1.183155, 16.760395},{-1.060016, -1.291074, 
        16.332132}}],
    Line[{{-1.060016, -1.291074, 16.332132},{-1.087468, -1.405059, 
        15.916598}}],
    Line[{{-1.087468, -1.405059, 15.916598},{-1.123492, -1.526164, 
        15.513703}}],
    Line[{{-1.123492, -1.526164, 15.513703},{-1.168003, -1.655511, 
        15.123410}}],
    Line[{{-1.168003, -1.655511, 15.123410},{-1.221034, -1.794289, 
        14.745733}}],
    Line[{{-1.221034, -1.794289, 14.745733},{-1.282733, -1.943769, 
        14.380752}}],
    Line[{{-1.282733, -1.943769, 14.380752},{-1.353359, -2.105309, 
        14.028619}}],
    Line[{{-1.353359, -2.105309, 14.028619},{-1.433279, -2.280364, 
        13.689569}}],
    Line[{{-1.433279, -2.280364, 13.689569},{-1.522969, -2.470495, 
        13.363940}}],
    Line[{{-1.522969, -2.470495, 13.363940},{-1.623016, -2.677380, 
        13.052184}}],
    Line[{{-1.623016, -2.677380, 13.052184},{-1.734114, -2.902826, 
        12.754894}}],
    Line[{{-1.734114, -2.902826, 12.754894},{-1.857070, -3.148777, 
        12.472824}}],
    Line[{{-1.857070, -3.148777, 12.472824},{-1.992808, -3.417325, 
        12.206924}}],
    Line[{{-1.992808, -3.417325, 12.206924},{-2.142369, -3.710711, 
        11.958374}}],
    Line[{{-2.142369, -3.710711, 11.958374},{-2.306916, -4.031339, 
        11.728625}}],
    Line[{{-2.306916, -4.031339, 11.728625},{-2.487738, -4.381761, 
        11.519458}}],
    Line[{{-2.487738, -4.381761, 11.519458},{-2.686252, -4.764685, 
        11.333021}}],
    Line[{{-2.686252, -4.764685, 11.333021},{-2.904002, -5.182942, 
        11.171935}}],
    Line[{{-2.904002, -5.182942, 11.171935},{-3.142662, -5.639473, 
        11.039333}}],
    Line[{{-3.142662, -5.639473, 11.039333},{-3.404032, -6.137279, 
        10.938979}}],
    Line[{{-3.404032, -6.137279, 10.938979},{-3.690019, -6.679338, 
        10.875365}}],
    Line[{{-3.690019, -6.679338, 10.875365},{-4.002636, -7.268533, 
        10.853820}}],
    Line[{{-4.002636, -7.268533, 10.853820},{-4.343966, -7.907509, 
        10.880632}}],
    Line[{{-4.343966, -7.907509, 10.880632},{-4.716120, -8.598477, 
        10.963182}}],
    Line[{{-4.716120, -8.598477, 10.963182},{-5.121198, -9.343003, 
        11.110056}}],
    Line[{{-5.121198, -9.343003, 11.110056},{-5.561203, -10.141693, 
        11.331157}}],
    Line[{{-5.561203, -10.141693, 11.331157},{-6.037941, -10.993776, 
        11.637775}}],
    Line[{{-6.037941, -10.993776, 11.637775},{-6.552886, -11.896632, 
        12.042592}}],
    Line[{{-6.552886, -11.896632, 12.042592},{-7.107013, -12.845201, 
        12.559592}}],
    Line[{{-7.107013, -12.845201, 12.559592},{-7.700572, -13.831285, 
        13.203822}}],
    Line[{{-7.700572, -13.831285, 13.203822},{-8.332833, -14.842781, 
        13.990945}}],
    Line[{{-8.332833, -14.842781, 13.990945},{-9.001756, -15.862860, 
        14.936500}}],
    Line[{{-9.001756, -15.862860, 14.936500},{-9.703636, -16.869198, 
        16.054832}}],
    Line[{{-9.703636, -16.869198, 16.054832},{-10.432704, -17.833389, 
        17.357569}}],
    Line[{{-10.432704, -17.833389, 17.357569},{-11.180730, -18.720692, 
        18.851706}}],
    Line[{{-11.180730, -18.720692, 18.851706},{-11.936666, -19.490366, 
        20.537262}}],
    Line[{{-11.936666, -19.490366, 20.537262},{-12.686394, -20.096865, 
        22.404707}}],
    Line[{{-12.686394, -20.096865, 22.404707},{-13.412654, -20.492115, 
        24.432440}}],
    Line[{{-13.412654, -20.492115, 24.432440},{-14.095273, -20.629028, 
        26.584791}}],
    Line[{{-14.095273, -20.629028, 26.584791},{-14.711749, -20.466188, 
        28.811167}}],
    Line[{{-14.711749, -20.466188, 28.811167},{-15.238271, -19.973303, 
        31.046917}}],
    Line[{{-15.238271, -19.973303, 31.046917},{-15.651169, -19.136700, 
        33.216461}}],
    Line[{{-15.651169, -19.136700, 33.216461},{-15.928726, -17.963749, 
        35.238853}}],
    Line[{{-15.928726, -17.963749, 35.238853},{-16.053110, -16.485138, 
        37.035069}}],
    Line[{{-16.053110, -16.485138, 37.035069},{-16.012215, -14.754002, 
        38.536308}}],
    Line[{{-16.012215, -14.754002, 38.536308},{-15.801064, -12.841637, 
        39.691498}}],
    Line[{{-15.801064, -12.841637, 39.691498},{-15.422545, -10.830440, 
        40.472641}}],
    Line[{{-15.422545, -10.830440, 40.472641},{-14.887306, -8.805158, 
        40.876839}}],
    Line[{{-14.887306, -8.805158, 40.876839},{-14.212798, -6.844256, 
        40.924633}}],
    Line[{{-14.212798, -6.844256, 40.924633},{-13.421684, -5.013037, 
        40.655312}}],
    Line[{{-13.421684, -5.013037, 40.655312},{-12.539866, -3.359369, 
        40.120491}}],
    Line[{{-12.539866, -3.359369, 40.120491},{-11.594432, -1.912410, 
        39.377209}}],
    Line[{{-11.594432, -1.912410, 39.377209},{-10.611803, -0.683855, 
        38.481857}}],
    Line[{{-10.611803, -0.683855, 38.481857},{-9.616271, 0.329102, 
        37.485691}}],
    Line[{{-9.616271, 0.329102, 37.485691},{-8.628997, 1.139995, 36.432140}}],
    
    Line[{{-8.628997, 1.139995, 36.432140},{-7.667475, 1.769290, 35.355709}}],
    
    Line[{{-7.667475, 1.769290, 35.355709},{-6.745390, 2.241060, 34.282192}}],
    
    Line[{{-6.745390, 2.241060, 34.282192},{-5.872767, 2.580398, 33.229622}}],
    
    Line[{{-5.872767, 2.580398, 33.229622},{-5.056316, 2.811586, 32.209602}}],
    
    Line[{{-5.056316, 2.811586, 32.209602},{-4.299884, 2.956952, 31.228765}}],
    
    Line[{{-4.299884, 2.956952, 31.228765},{-3.604950, 3.036273, 30.290089}}],
    
    Line[{{-3.604950, 3.036273, 30.290089},{-2.971100, 3.066561, 29.394028}}],
    
    Line[{{-2.971100, 3.066561, 29.394028},{-2.396476, 3.062110, 28.539427}}],
    
    Line[{{-2.396476, 3.062110, 28.539427},{-1.878158, 3.034704, 27.724188}}],
    
    Line[{{-1.878158, 3.034704, 27.724188},{-1.412492, 2.993889, 26.945755}}],
    
    Line[{{-1.412492, 2.993889, 26.945755},{-0.995364, 2.947284, 26.201456}}],
    
    Line[{{-0.995364, 2.947284, 26.201456},{-0.622401, 2.900887, 25.488686}}],
    
    Line[{{-0.622401, 2.900887, 25.488686},{-0.289147, 2.859351, 24.805050}}],
    
    Line[{{-0.289147, 2.859351, 24.805050},{0.008820, 2.826246, 24.148415}}],
    Line[{{0.008820, 2.826246, 24.148415},{0.275800, 2.804275, 23.516935}}],
    Line[{{0.275800, 2.804275, 23.516935},{0.515902, 2.795465, 22.909046}}],
    Line[{{0.515902, 2.795465, 22.909046},{0.733014, 2.801326, 22.323454}}],
    Line[{{0.733014, 2.801326, 22.323454},{0.930777, 2.822985, 21.759104}}],
    Line[{{0.930777, 2.822985, 21.759104},{1.112581, 2.861301, 21.215166}}],
    Line[{{1.112581, 2.861301, 21.215166},{1.281562, 2.916948, 20.691010}}],
    Line[{{1.281562, 2.916948, 20.691010},{1.440619, 2.990494, 20.186186}}],
    Line[{{1.440619, 2.990494, 20.186186},{1.592424, 3.082462, 19.700411}}],
    Line[{{1.592424, 3.082462, 19.700411},{1.739447, 3.193372, 19.233559}}],
    Line[{{1.739447, 3.193372, 19.233559},{1.883971, 3.323789, 18.785658}}],
    Line[{{1.883971, 3.323789, 18.785658},{2.028122, 3.474338, 18.356895}}],
    Line[{{2.028122, 3.474338, 18.356895},{2.173884, 3.645737, 17.947611}}],
    Line[{{2.173884, 3.645737, 17.947611},{2.323128, 3.838806, 17.558319}}],
    Line[{{2.323128, 3.838806, 17.558319},{2.477628, 4.054479, 17.189716}}],
    Line[{{2.477628, 4.054479, 17.189716},{2.639086, 4.293808, 16.842710}}],
    Line[{{2.639086, 4.293808, 16.842710},{2.809146, 4.557961, 16.518425}}],
    Line[{{2.809146, 4.557961, 16.518425},{2.989413, 4.848212, 16.218254}}],
    Line[{{2.989413, 4.848212, 16.218254},{3.181465, 5.165935, 15.943875}}],
    Line[{{3.181465, 5.165935, 15.943875},{3.386865, 5.512572, 15.697298}}],
    Line[{{3.386865, 5.512572, 15.697298},{3.607164, 5.889601, 15.480910}}],
    Line[{{3.607164, 5.889601, 15.480910},{3.843910, 6.298510, 15.297519}}],
    Line[{{3.843910, 6.298510, 15.297519},{4.098642, 6.740715, 15.150408}}],
    Line[{{4.098642, 6.740715, 15.150408},{4.372878, 7.217494, 15.043393}}],
    Line[{{4.372878, 7.217494, 15.043393},{4.668108, 7.729910, 14.980870}}],
    Line[{{4.668108, 7.729910, 14.980870},{4.985761, 8.278649, 14.967874}}],
    Line[{{4.985761, 8.278649, 14.967874},{5.327171, 8.863898, 15.010109}}],
    Line[{{5.327171, 8.863898, 15.010109},{5.693542, 9.485166, 15.113990}}],
    Line[{{5.693542, 9.485166, 15.113990},{6.085855, 10.140999, 15.286615}}],
    Line[{{6.085855, 10.140999, 15.286615},{6.504820, 10.828797, 15.535750}}],
    
    Line[{{6.504820, 10.828797, 15.535750},{6.950763, 11.544459, 15.869730}}],
    
    Line[{{6.950763, 11.544459, 15.869730},{7.423481, 12.282014, 16.297207}}],
    
    Line[{{7.423481, 12.282014, 16.297207},{7.922153, 13.033350, 16.827028}}],
    
    Line[{{7.922153, 13.033350, 16.827028},{8.445115, 13.787755, 17.467638}}],
    
    Line[{{8.445115, 13.787755, 17.467638},{8.989717, 14.531657, 18.226654}}],
    
    Line[{{8.989717, 14.531657, 18.226654},{9.552116, 15.248375, 19.110060}}],
    
    Line[{{9.552116, 15.248375, 19.110060},{
      10.127098, 15.918062, 20.121347}}],
    Line[{{10.127098, 15.918062, 20.121347},{
      10.707906, 16.517857, 21.260460}}],
    Line[{{10.707906, 16.517857, 21.260460},{
      11.286119, 17.022387, 22.522629}}],
    Line[{{11.286119, 17.022387, 22.522629},{
      11.851628, 17.404779, 23.897242}}],
    Line[{{11.851628, 17.404779, 23.897242},{
      12.392704, 17.638000, 25.366894}}],
    Line[{{12.392704, 17.638000, 25.366894},{
      12.896231, 17.696777, 26.906786}}],
    Line[{{12.896231, 17.696777, 26.906786},{
      13.348108, 17.559874, 28.484718}}],
    Line[{{13.348108, 17.559874, 28.484718},{
      13.733856, 17.212545, 30.061867}}],
    Line[{{13.733856, 17.212545, 30.061867},{
      14.039375, 16.648876, 31.594490}}],
    Line[{{14.039375, 16.648876, 31.594490},{
      14.251849, 15.873592, 33.036526}}],
    Line[{{14.251849, 15.873592, 33.036526},{
      14.360690, 14.902964, 34.342892}}],
    Line[{{14.360690, 14.902964, 34.342892},{
      14.358412, 13.764439, 35.473114}}],
    Line[{{14.358412, 13.764439, 35.473114},{
      14.241340, 12.495056, 36.394703}}],
    Line[{{14.241340, 12.495056, 36.394703},{
      14.010021, 11.138588, 37.085823}}],
    Line[{{14.010021, 11.138588, 37.085823},{
      13.669302, 9.741905, 37.536762}}],
    Line[{{13.669302, 9.741905, 37.536762},{13.228017, 8.351127, 37.749985}}],
    
    Line[{{13.228017, 8.351127, 37.749985},{12.698371, 7.008079, 37.738903}}],
    
    Line[{{12.698371, 7.008079, 37.738903},{12.095063, 5.747589, 37.525551}}],
    
    Line[{{12.095063, 5.747589, 37.525551},{11.434301, 4.595864, 37.137764}}],
    
    Line[{{11.434301, 4.595864, 37.137764},{10.732802, 3.569979, 36.606205}}],
    
    Line[{{10.732802, 3.569979, 36.606205},{10.006892, 2.678377, 35.961731}}],
    
    Line[{{10.006892, 2.678377, 35.961731},{9.271776, 1.922035, 35.233356}}],
    Line[{{9.271776, 1.922035, 35.233356},{8.541001, 1.296018, 34.446842}}],
    Line[{{8.541001, 1.296018, 34.446842},{7.826144, 0.791147, 33.623989}}],
    Line[{{7.826144, 0.791147, 33.623989},{7.136659, 0.395562, 32.782425}}],
    Line[{{7.136659, 0.395562, 32.782425},{6.479899, 0.096038, 31.935816}}],
    Line[{{6.479899, 0.096038, 31.935816},{5.861238, -0.120965, 31.094303}}],
    Line[{{5.861238, -0.120965, 31.094303},{5.284261, -0.268545, 30.265060}}],
    
    Line[{{5.284261, -0.268545, 30.265060},{4.751013, -0.358864, 29.452877}}],
    
    Line[{{4.751013, -0.358864, 29.452877},{4.262242, -0.402856, 28.660711}}],
    
    Line[{{4.262242, -0.402856, 28.660711},{3.817650, -0.410093, 27.890158}}],
    
    Line[{{3.817650, -0.410093, 27.890158},{3.416123, -0.388771, 27.141857}}],
    
    Line[{{3.416123, -0.388771, 27.141857},{3.055938, -0.345760, 26.415796}}],
    
    Line[{{3.055938, -0.345760, 26.415796},{2.734942, -0.286713, 25.711548}}],
    
    Line[{{2.734942, -0.286713, 25.711548},{2.450703, -0.216187, 25.028442}}],
    
    Line[{{2.450703, -0.216187, 25.028442},{2.200634, -0.137778, 24.365694}}],
    
    Line[{{2.200634, -0.137778, 24.365694},{1.982093, -0.054257, 23.722467}}],
    
    Line[{{1.982093, -0.054257, 23.722467},{1.792460, 0.032310, 23.097950}}],
    Line[{{1.792460, 0.032310, 23.097950},{1.629200, 0.120444, 22.491364}}],
    Line[{{1.629200, 0.120444, 22.491364},{1.489899, 0.209154, 21.901987}}],
    Line[{{1.489899, 0.209154, 21.901987},{1.372301, 0.297848, 21.329165}}],
    Line[{{1.372301, 0.297848, 21.329165},{1.274324, 0.386261, 20.772306}}],
    Line[{{1.274324, 0.386261, 20.772306},{1.194071, 0.474385, 20.230877}}],
    Line[{{1.194071, 0.474385, 20.230877},{1.129836, 0.562427, 19.704399}}],
    Line[{{1.129836, 0.562427, 19.704399},{1.080104, 0.650756, 19.192446}}],
    Line[{{1.080104, 0.650756, 19.192446},{1.043545, 0.739878, 18.694639}}],
    Line[{{1.043545, 0.739878, 18.694639},{1.019011, 0.830408, 18.210636}}],
    Line[{{1.019011, 0.830408, 18.210636},{1.005523, 0.923045, 17.740139}}],
    Line[{{1.005523, 0.923045, 17.740139},{1.002269, 1.018566, 17.282885}}],
    Line[{{1.002269, 1.018566, 17.282885},{1.008588, 1.117812, 16.838644}}],
    Line[{{1.008588, 1.117812, 16.838644},{1.023968, 1.221684, 16.407227}}],
    Line[{{1.023968, 1.221684, 16.407227},{1.048032, 1.331141, 15.988482}}],
    Line[{{1.048032, 1.331141, 15.988482},{1.080534, 1.447202, 15.582296}}],
    Line[{{1.080534, 1.447202, 15.582296},{1.121352, 1.570947, 15.188606}}],
    Line[{{1.121352, 1.570947, 15.188606},{1.170480, 1.703525, 14.807396}}],
    Line[{{1.170480, 1.703525, 14.807396},{1.228026, 1.846159, 14.438707}}],
    Line[{{1.228026, 1.846159, 14.438707},{1.294209, 2.000154, 14.082650}}],
    Line[{{1.294209, 2.000154, 14.082650},{1.369356, 2.166909, 13.739411}}],
    Line[{{1.369356, 2.166909, 13.739411},{1.453898, 2.347925, 13.409269}}],
    Line[{{1.453898, 2.347925, 13.409269},{1.548377, 2.544815, 13.092607}}],
    Line[{{1.548377, 2.544815, 13.092607},{1.653440, 2.759315, 12.789935}}],
    Line[{{1.653440, 2.759315, 12.789935},{1.769845, 2.993299, 12.501912}}],
    Line[{{1.769845, 2.993299, 12.501912},{1.898464, 3.248779, 12.229376}}],
    Line[{{1.898464, 3.248779, 12.229376},{2.040284, 3.527924, 11.973368}}],
    Line[{{2.040284, 3.527924, 11.973368},{2.196411, 3.833056, 11.735185}}],
    Line[{{2.196411, 3.833056, 11.735185},{2.368077, 4.166663, 11.516413}}],
    Line[{{2.368077, 4.166663, 11.516413},{2.556638, 4.531385, 11.318987}}],
    Line[{{2.556638, 4.531385, 11.318987},{2.763582, 4.930005, 11.145264}}],
    Line[{{2.763582, 4.930005, 11.145264},{2.990526, 5.365443, 10.998070}}],
    Line[{{2.990526, 5.365443, 10.998070},{3.239213, 5.840685, 10.880832}}],
    Line[{{3.239213, 5.840685, 10.880832},{3.511512, 6.358784, 10.797614}}],
    Line[{{3.511512, 6.358784, 10.797614},{3.809399, 6.922725, 10.753287}}],
    Line[{{3.809399, 6.922725, 10.753287},{4.134938, 7.535340, 10.753613}}],
    Line[{{4.134938, 7.535340, 10.753613},{4.490258, 8.199162, 10.805378}}],
    Line[{{4.490258, 8.199162, 10.805378},{4.877501, 8.916215, 10.916523}}],
    Line[{{4.877501, 8.916215, 10.916523},{5.298761, 9.687723, 11.096264}}],
    Line[{{5.298761, 9.687723, 11.096264},{5.755995, 10.513783, 11.355183}}],
    Line[{{5.755995, 10.513783, 11.355183},{6.250923, 11.392951, 11.705294}}],
    
    Line[{{6.250923, 11.392951, 11.705294},{6.784853, 12.321634, 12.159993}}],
    
    Line[{{6.784853, 12.321634, 12.159993},{7.358506, 13.293505, 12.733929}}],
    
    Line[{{7.358506, 13.293505, 12.733929},{7.971764, 14.298729, 13.442672}}],
    
    Line[{{7.971764, 14.298729, 13.442672},{8.623386, 15.323167, 14.302142}}],
    
    Line[{{8.623386, 15.323167, 14.302142},{9.310663, 16.347553, 15.327735}}],
    
    Line[{{9.310663, 16.347553, 15.327735},{
      10.029031, 17.346752, 16.533070}}],
    Line[{{10.029031, 17.346752, 16.533070},{
      10.771660, 18.289291, 17.928217}}],
    Line[{{10.771660, 18.289291, 17.928217},{
      11.529068, 19.137316, 19.517590}}],
    Line[{{11.529068, 19.137316, 19.517590},{
      12.288787, 19.847273, 21.297432}}],
    Line[{{12.288787, 19.847273, 21.297432},{
      13.035177, 20.371561, 23.253155}}],
    Line[{{13.035177, 20.371561, 23.253155},{
      13.749471, 20.661396, 25.356945}}],
    Line[{{13.749471, 20.661396, 25.356945},{
      14.410148, 20.670910, 27.566143}}],
    Line[{{14.410148, 20.670910, 27.566143},{
      14.993718, 20.362350, 29.823048}}],
    Line[{{14.993718, 20.362350, 29.823048},{
      15.475953, 19.711767, 32.056763}}],
    Line[{{15.475953, 19.711767, 32.056763},{
      15.833541, 18.714287, 34.187504}}],
    Line[{{15.833541, 18.714287, 34.187504},{
      16.046009, 17.387775, 36.133125}}],
    Line[{{16.046009, 17.387775, 36.133125},{
      16.097677, 15.773795, 37.817181}}],
    Line[{{16.097677, 15.773795, 37.817181},{
      15.979387, 13.935248, 39.177204}}],
    Line[{{15.979387, 13.935248, 39.177204},{
      15.689643, 11.950530, 40.171593}}],
    Line[{{15.689643, 11.950530, 40.171593},{
      15.234972, 9.905350, 40.783539}}],
    Line[{{15.234972, 9.905350, 40.783539},{14.629434, 7.883714, 41.021446}}],
    
    Line[{{14.629434, 7.883714, 41.021446},{13.893320, 5.959733, 40.915672}}],
    
    Line[{{13.893320, 5.959733, 40.915672},{13.051311, 4.191750, 40.512756}}],
    
    Line[{{13.051311, 4.191750, 40.512756},{12.130405, 2.619427, 39.868458}}],
    
    Line[{{12.130405, 2.619427, 39.868458},{11.157886, 1.263719, 39.040997}}],
    
    Line[{{11.157886, 1.263719, 39.040997},{10.159615, 0.129087, 38.085560}}],
    
    Line[{{10.159615, 0.129087, 38.085560},{9.158759, -0.792980, 37.050571}}],
    
    Line[{{9.158759, -0.792980, 37.050571},{8.175004, -1.520029, 35.975796}}],
    
    Line[{{8.175004, -1.520029, 35.975796},{7.224200, -2.074947, 34.891869}}],
    
    Line[{{7.224200, -2.074947, 34.891869},{6.318384, -2.482924, 33.820972}}],
    
    Line[{{6.318384, -2.482924, 33.820972},{5.466033, -2.769187, 32.778011}}],
    
    Line[{{5.466033, -2.769187, 32.778011},{4.672475, -2.957496, 31.772085}}],
    
    Line[{{4.672475, -2.957496, 31.772085},{3.940382, -3.069265, 30.807899}}],
    
    Line[{{3.940382, -3.069265, 30.807899},{3.270263, -3.123166, 29.887049}}],
    
    Line[{{3.270263, -3.123166, 29.887049},{2.660937, -3.135060, 29.009050}}],
    
    Line[{{2.660937, -3.135060, 29.009050},{2.109959, -3.118139, 28.172148}}],
    
    Line[{{2.109959, -3.118139, 28.172148},{1.613977, -3.083174, 27.373903}}],
    
    Line[{{1.613977, -3.083174, 27.373903},{1.169042, -3.038823, 26.611603}}],
    
    Line[{{1.169042, -3.038823, 26.611603},{0.770843, -2.991943, 25.882528}}],
    
    Line[{{0.770843, -2.991943, 25.882528},{0.414904, -2.947894, 25.184114}}],
    
    Line[{{0.414904, -2.947894, 25.184114},{0.096723, -2.910808, 24.514050}}],
    
    Line[{{
      0.096723, -2.910808, 24.514050},{-0.188113, -2.883834, 23.870308}}],
    Line[{{-0.188113, -2.883834, 23.870308},{-0.443862, -2.869343, 
        23.251160}}],
    Line[{{-0.443862, -2.869343, 23.251160},{-0.674569, -2.869107, 
        22.655159}}],
    Line[{{-0.674569, -2.869107, 22.655159},{-0.884041, -2.884450, 
        22.081123}}],
    Line[{{-0.884041, -2.884450, 22.081123},{-1.075832, -2.916363, 
        21.528109}}],
    Line[{{-1.075832, -2.916363, 21.528109},{-1.253242, -2.965613, 
        20.995390}}],
    Line[{{-1.253242, -2.965613, 20.995390},{-1.419318, -3.032825, 
        20.482437}}],
    Line[{{-1.419318, -3.032825, 20.482437},{-1.576876, -3.118545, 
        19.988895}}],
    Line[{{-1.576876, -3.118545, 19.988895},{-1.728515, -3.223300, 
        19.514582}}],
    Line[{{-1.728515, -3.223300, 19.514582},{-1.876633, -3.347633, 
        19.059475}}],
    Line[{{-1.876633, -3.347633, 19.059475},{-2.023459, -3.492145, 
        18.623707}}],
    Line[{{-2.023459, -3.492145, 18.623707},{-2.171068, -3.657512, 
        18.207577}}],
    Line[{{-2.171068, -3.657512, 18.207577},{-2.321407, -3.844505, 
        17.811554}}],
    Line[{{-2.321407, -3.844505, 17.811554},{-2.476316, -4.054004, 
        17.436293}}],
    Line[{{-2.476316, -4.054004, 17.436293},{-2.637549, -4.287000, 
        17.082647}}],
    Line[{{-2.637549, -4.287000, 17.082647},{-2.806792, -4.544599, 
        16.751694}}],
    Line[{{-2.806792, -4.544599, 16.751694},{-2.985683, -4.828014, 
        16.444763}}],
    Line[{{-2.985683, -4.828014, 16.444763},{-3.175823, -5.138552, 
        16.163469}}],
    Line[{{-3.175823, -5.138552, 16.163469},{-3.378789, -5.477589, 
        15.909745}}],
    Line[{{-3.378789, -5.477589, 15.909745},{-3.596142, -5.846553, 
        15.685886}}],
    Line[{{-3.596142, -5.846553, 15.685886},{-3.829430, -6.246870, 
        15.494599}}],
    Line[{{-3.829430, -6.246870, 15.494599},{-4.080184, -6.679907, 
        15.339050}}],
    Line[{{-4.080184, -6.679907, 15.339050},{-4.349924, -7.146924, 
        15.222912}}],
    Line[{{-4.349924, -7.146924, 15.222912},{-4.640124, -7.648947, 
        15.150426}}],
    Line[{{-4.640124, -7.648947, 15.150426},{-4.952206, -8.186676, 
        15.126443}}],
    Line[{{-4.952206, -8.186676, 15.126443},{-5.287504, -8.760346, 
        15.156471}}],
    Line[{{-5.287504, -8.760346, 15.156471},{-5.647210, -9.369511, 
        15.246689}}],
    Line[{{-5.647210, -9.369511, 15.246689},{-6.032325, -10.012874, 
        15.403958}}],
    Line[{{-6.032325, -10.012874, 15.403958},{-6.443584, -10.688022, 
        15.635797}}],
    Line[{{-6.443584, -10.688022, 15.635797},{-6.881339, -11.391088, 
        15.950234}}],
    Line[{{-6.881339, -11.391088, 15.950234},{-7.345482, -12.116514, 
        16.355743}}],
    Line[{{-7.345482, -12.116514, 16.355743},{-7.835273, -12.856616, 
        16.860886}}],
    Line[{{-7.835273, -12.856616, 16.860886},{-8.349199, -13.601281, 
        17.473986}}],
    Line[{{-8.349199, -13.601281, 17.473986},{-8.884795, -14.337644, 
        18.202576}}],
    Line[{{-8.884795, -14.337644, 18.202576},{-9.438469, -15.049851, 
        19.052753}}],
    Line[{{-9.438469, -15.049851, 19.052753},{-10.005310, -15.718955, 
        20.028313}}],
    Line[{{-10.005310, -15.718955, 20.028313},{-10.578922, -16.323048, 
        21.129730}}],
    Line[{{-10.578922, -16.323048, 21.129730},{-11.151313, -16.837740, 
        22.353073}}],
    Line[{{-11.151313, -16.837740, 22.353073},{-11.712837, -17.236961, 
        23.688919}}],
    Line[{{-11.712837, -17.236961, 23.688919},{-12.252257, -17.494270, 
        25.121370}}],
    Line[{{-12.252257, -17.494270, 25.121370},{-12.756940, -17.584606, 
        26.627422}}],
    Line[{{-12.756940, -17.584606, 26.627422},{-13.213220, -17.486435, 
        28.176838}}],
    Line[{{-13.213220, -17.486435, 28.176838},{-13.606949, -17.184118, 
        29.732779}}],
    Line[{{-13.606949, -17.184118, 29.732779},{-13.924218, -16.670197, 
        31.253271}}],
    Line[{{-13.924218, -16.670197, 31.253271},{-14.152205, -15.947259, 
        32.693584}}],
    Line[{{-14.152205, -15.947259, 32.693584},{-14.280084, -15.029012, 
        34.009285}}],
    Line[{{-14.280084, -15.029012, 34.009285},{-14.299911, -13.940171, 
        35.159752}}],
    Line[{{-14.299911, -13.940171, 35.159752},{-14.207328, -12.715138, 
        36.111496}}],
    Line[{{-14.207328, -12.715138, 36.111496},{-14.002040, -11.395472, 
        36.840912}}],
    Line[{{-14.002040, -11.395472, 36.840912},{-13.687944, -10.026507, 
        37.335941}}],
    Line[{{-13.687944, -10.026507, 37.335941},{-13.272914, -8.653642, 
        37.596439}}],
    Line[{{-13.272914, -8.653642, 37.596439},{-12.768256, -7.318808, 
        37.633236}}],
    Line[{{-12.768256, -7.318808, 37.633236},{-12.187902, -6.057642, 
        37.466095}}],
    Line[{{-12.187902, -6.057642, 37.466095},{-11.547469, -4.897709, 
        37.121021}}],
    Line[{{-11.547469, -4.897709, 37.121021},{-10.863285, -3.857753, 
        36.627445}}],
    Line[{{-10.863285, -3.857753, 36.627445},{-10.151491, -2.947965, 
        36.015568}}],
    Line[{{-10.151491, -2.947965, 36.015568},{-9.427283, -2.170981, 
        35.314224}}],
    Line[{{-9.427283, -2.170981, 35.314224},{-8.704357, -1.523317, 
        34.549404}}],
    Line[{{-8.704357, -1.523317, 34.549404},{-7.994540, -0.996968, 
        33.743385}}],
    Line[{{-7.994540, -0.996968, 33.743385},{-7.307618, -0.580954, 
        32.914417}}],
    Line[{{-7.307618, -0.580954, 32.914417},{-6.651309, -0.262663, 
        32.076851}}],
    Line[{{-6.651309, -0.262663, 32.076851},{-6.031365, -0.028927, 
        31.241488}}],
    Line[{{-6.031365, -0.028927, 31.241488},{-5.451743, 0.133168, 
        30.416107}}],
    Line[{{-5.451743, 0.133168, 30.416107},{-4.914829, 0.235743, 29.606030}}],
    
    Line[{{-4.914829, 0.235743, 29.606030},{-4.421681, 0.289791, 28.814648}}],
    
    Line[{{-4.421681, 0.289791, 28.814648},{-3.972274, 0.305005, 28.043919}}],
    
    Line[{{-3.972274, 0.305005, 28.043919},{-3.565725, 0.289742, 27.294756}}],
    
    Line[{{-3.565725, 0.289742, 27.294756},{-3.200505, 0.251050, 26.567362}}],
    
    Line[{{-3.200505, 0.251050, 26.567362},{-2.874618, 0.194760, 25.861469}}],
    
    Line[{{-2.874618, 0.194760, 25.861469},{-2.585761, 0.125598, 25.176529}}],
    
    Line[{{-2.585761, 0.125598, 25.176529},{-2.331444, 0.047318, 24.511841}}],
    
    Line[{{-2.331444, 0.047318, 24.511841},{-2.109101, -0.037173, 
        23.866634}}],
    Line[{{-2.109101, -0.037173, 23.866634},{-1.916169, -0.125690, 
        23.240139}}],
    Line[{{-1.916169, -0.125690, 23.240139},{-1.750152, -0.216657, 
        22.631611}}],
    Line[{{-1.750152, -0.216657, 22.631611},{-1.608666, -0.309005, 
        22.040359}}],
    Line[{{-1.608666, -0.309005, 22.040359},{-1.489474, -0.402083, 
        21.465748}}],
    Line[{{-1.489474, -0.402083, 21.465748},{-1.390505, -0.495582, 
        20.907204}}],
    Line[{{-1.390505, -0.495582, 20.907204},{-1.309873, -0.589472, 
        20.364208}}],
    Line[{{-1.309873, -0.589472, 20.364208},{-1.245876, -0.683948, 
        19.836304}}],
    Line[{{-1.245876, -0.683948, 19.836304},{-1.197004, -0.779384, 
        19.323082}}],
    Line[{{-1.197004, -0.779384, 19.323082},{-1.161933, -0.876300, 
        18.824184}}],
    Line[{{-1.161933, -0.876300, 18.824184},{-1.139521, -0.975342, 
        18.339293}}],
    Line[{{-1.139521, -0.975342, 18.339293},{-1.128800, -1.077247, 
        17.868137}}],
    Line[{{-1.128800, -1.077247, 17.868137},{-1.128969, -1.182842, 
        17.410482}}],
    Line[{{-1.128969, -1.182842, 17.410482},{-1.139387, -1.293028, 
        16.966139}}],
    Line[{{-1.139387, -1.293028, 16.966139},{-1.159561, -1.408776, 
        16.534958}}],
    Line[{{-1.159561, -1.408776, 16.534958},{-1.189141, -1.531122, 
        16.116835}}],
    Line[{{-1.189141, -1.531122, 16.116835},{-1.227914, -1.661174, 
        15.711716}}],
    Line[{{-1.227914, -1.661174, 15.711716},{-1.275795, -1.800110, 
        15.319602}}],
    Line[{{-1.275795, -1.800110, 15.319602},{-1.332821, -1.949184, 
        14.940557}}],
    Line[{{-1.332821, -1.949184, 14.940557},{-1.399152, -2.109736, 
        14.574714}}],
    Line[{{-1.399152, -2.109736, 14.574714},{-1.475063, -2.283196, 
        14.222291}}],
    Line[{{-1.475063, -2.283196, 14.222291},{-1.560944, -2.471096, 
        13.883602}}],
    Line[{{-1.560944, -2.471096, 13.883602},{-1.657299, -2.675078, 
        13.559074}}],
    Line[{{-1.657299, -2.675078, 13.559074},{-1.764745, -2.896904, 
        13.249269}}],
    Line[{{-1.764745, -2.896904, 13.249269},{-1.884017, -3.138464, 
        12.954901}}],
    Line[{{-1.884017, -3.138464, 12.954901},{-2.015963, -3.401788, 
        12.676880}}],
    Line[{{-2.015963, -3.401788, 12.676880},{-2.161553, -3.689048, 
        12.416323}}],
    Line[{{-2.161553, -3.689048, 12.416323},{-2.321877, -4.002563, 
        12.174618}}],
    Line[{{-2.321877, -4.002563, 12.174618},{-2.498149, -4.344798, 
        11.953458}}],
    Line[{{-2.498149, -4.344798, 11.953458},{-2.691711, -4.718361, 
        11.754891}}],
    Line[{{-2.691711, -4.718361, 11.754891},{-2.904028, -5.125976, 
        11.581413}}],
    Line[{{-2.904028, -5.125976, 11.581413},{-3.136695, -5.570478, 
        11.435997}}],
    Line[{{-3.136695, -5.570478, 11.435997},{-3.391422, -6.054744, 
        11.322228}}],
    Line[{{-3.391422, -6.054744, 11.322228},{-3.670036, -6.581655, 
        11.244359}}],
    Line[{{-3.670036, -6.581655, 11.244359},{-3.974457, -7.153993, 
        11.207444}}],
    Line[{{-3.974457, -7.153993, 11.207444},{-4.306679, -7.774321, 
        11.217441}}],
    Line[{{-4.306679, -7.774321, 11.217441},{-4.668730, -8.444810, 
        11.281328}}],
    Line[{{-4.668730, -8.444810, 11.281328},{-5.062630, -9.167048, 
        11.407226}}],
    Line[{{-5.062630, -9.167048, 11.407226},{-5.490316, -9.941722, 
        11.604496}}],
    Line[{{-5.490316, -9.941722, 11.604496},{-5.953541, -10.768253, 
        11.883805}}],
    Line[{{-5.953541, -10.768253, 11.883805},{-6.453770, -11.644391, 
        12.257152}}],
    Line[{{-6.453770, -11.644391, 12.257152},{-6.992002, -12.565610, 
        12.737779}}],
    Line[{{-6.992002, -12.565610, 12.737779},{-7.568580, -13.524508, 
        13.339977}}],
    Line[{{-7.568580, -13.524508, 13.339977},{-8.182937, -14.510074, 
        14.078690}}],
    Line[{{-8.182937, -14.510074, 14.078690},{-8.833309, -15.506917, 
        14.968858}}],
    Line[{{-8.833309, -15.506917, 14.968858},{-9.516396, -16.494551, 
        16.024452}}],
    Line[{{-9.516396, -16.494551, 16.024452},{-10.226985, -17.446785, 
        17.257143}}],
    Line[{{-10.226985, -17.446785, 17.257143},{-10.957583, -18.331421, 
        18.674534}}],
    Line[{{-10.957583, -18.331421, 18.674534},{-11.698056, -19.110472, 
        20.278019}}],
    Line[{{-11.698056, -19.110472, 20.278019},{-12.435377, -19.741098, 
        22.060400}}],
    Line[{{-12.435377, -19.741098, 22.060400},{-13.153519, -20.177551, 
        24.003477}}],
    Line[{{-13.153519, -20.177551, 24.003477},{-13.833605, -20.374231, 
        26.076029}}],
    Line[{{-13.833605, -20.374231, 26.076029},{-14.454388, -20.289879, 
        28.232727}}],
    Line[{{-14.454388, -20.289879, 28.232727},{-14.993124, -19.892582, 
        30.414560}}],
    Line[{{-14.993124, -19.892582, 30.414560},{-15.426861, -19.165026, 
        32.551243}}],
    Line[{{-15.426861, -19.165026, 32.551243},{-15.734082, -18.108976, 
        34.565948}}],
    Line[{{-15.734082, -18.108976, 34.565948},{-15.896528, -16.747978, 
        36.381813}}],
    Line[{{-15.896528, -16.747978, 36.381813},{-15.900982, -15.127367, 
        37.929585}}],
    Line[{{-15.900982, -15.127367, 37.929585},{-15.740743, -13.311134, 
        39.155048}}],
    Line[{{-15.740743, -13.311134, 39.155048},{-15.416503, -11.375822, 
        40.024731}}],
    Line[{{-15.416503, -11.375822, 40.024731},{-14.936459, -9.402638, 
        40.528679}}],
    Line[{{-14.936459, -9.402638, 40.528679},{-14.315654, -7.469195, 
        40.679985}}],
    Line[{{-14.315654, -7.469195, 40.679985},{-13.574611, -5.642382, 
        40.511112}}],
    Line[{{-13.574611, -5.642382, 40.511112},{-12.737539, -3.973565, 
        40.068211}}],
    Line[{{-12.737539, -3.973565, 40.068211},{-11.830389, -2.496501, 
        39.404663}}],
    Line[{{-11.830389, -2.496501, 39.404663},{-10.879011, -1.227796, 
        38.575035}}],
    Line[{{-10.879011, -1.227796, 38.575035},{-9.907636, -0.169242, 
        37.630333}}],
    Line[{{-9.907636, -0.169242, 37.630333},{-8.937777, 0.688819, 
        36.614887}}],
    Line[{{-8.937777, 0.688819, 36.614887},{-7.987571, 1.363879, 35.564827}}],
    
    Line[{{-7.987571, 1.363879, 35.564827},{-7.071526, 1.877946, 34.507893}}],
    
    Line[{{-7.071526, 1.877946, 34.507893},{-6.200563, 2.254845, 33.464081}}],
    
    Line[{{-6.200563, 2.254845, 33.464081},{-5.382298, 2.518226, 32.446819}}],
    
    Line[{{-5.382298, 2.518226, 32.446819},{-4.621428, 2.690258, 31.464296}}],
    
    Line[{{-4.621428, 2.690258, 31.464296},{-3.920201, 2.790874, 30.520754}}],
    
    Line[{{-3.920201, 2.790874, 30.520754},{-3.278878, 2.837438, 29.617638}}],
    
    Line[{{-3.278878, 2.837438, 29.617638},{-2.696168, 2.844699, 28.754524}}],
    
    Line[{{-2.696168, 2.844699, 28.754524},{-2.169620, 2.824926, 27.929842}}],
    
    Line[{{-2.169620, 2.824926, 27.929842},{-1.695960, 2.788145, 27.141397}}],
    
    Line[{{-1.695960, 2.788145, 27.141397},{-1.271369, 2.742421, 26.386745}}],
    
    Line[{{-1.271369, 2.742421, 26.386745},{-0.891707, 2.694146, 25.663420}}],
    
    Line[{{-0.891707, 2.694146, 25.663420},{-0.552689, 2.648316, 24.969097}}],
    
    Line[{{-0.552689, 2.648316, 24.969097},{-0.250020, 2.608785, 24.301662}}],
    
    Line[{{-0.250020, 2.608785, 24.301662},{0.020508, 2.578485, 23.659256}}],
    Line[{{0.020508, 2.578485, 23.659256},{0.262945, 2.559622, 23.040276}}],
    Line[{{0.262945, 2.559622, 23.040276},{0.481135, 2.553842, 22.443369}}],
    Line[{{0.481135, 2.553842, 22.443369},{0.678692, 2.562364, 21.867416}}],
    Line[{{0.678692, 2.562364, 21.867416},{0.858989, 2.586104, 21.311504}}],
    Line[{{0.858989, 2.586104, 21.311504},{1.025152, 2.625763, 20.774910}}],
    Line[{{1.025152, 2.625763, 20.774910},{1.180068, 2.681909, 20.257082}}],
    Line[{{1.180068, 2.681909, 20.257082},{1.326402, 2.755041, 19.757620}}],
    Line[{{1.326402, 2.755041, 19.757620},{1.466611, 2.845640, 19.276268}}],
    Line[{{1.466611, 2.845640, 19.276268},{1.602963, 2.954210, 18.812908}}],
    Line[{{1.602963, 2.954210, 18.812908},{1.737563, 3.081309, 18.367559}}],
    Line[{{1.737563, 3.081309, 18.367559},{1.872371, 3.227579, 17.940372}}],
    Line[{{1.872371, 3.227579, 17.940372},{2.009227, 3.393761, 17.531645}}],
    Line[{{2.009227, 3.393761, 17.531645},{2.149871, 3.580711, 17.141825}}],
    Line[{{2.149871, 3.580711, 17.141825},{2.295967, 3.789408, 16.771536}}],
    Line[{{2.295967, 3.789408, 16.771536},{2.449116, 4.020962, 16.421581}}],
    Line[{{2.449116, 4.020962, 16.421581},{2.610883, 4.276609, 16.092983}}],
    Line[{{2.610883, 4.276609, 16.092983},{2.782805, 4.557714, 15.787004}}],
    Line[{{2.782805, 4.557714, 15.787004},{2.966408, 4.865751, 15.505177}}],
    Line[{{2.966408, 4.865751, 15.505177},{3.163221, 5.202296, 15.249357}}],
    Line[{{3.163221, 5.202296, 15.249357},{3.374778, 5.568995, 15.021752}}],
    Line[{{3.374778, 5.568995, 15.021752},{3.602627, 5.967529, 14.824984}}],
    Line[{{3.602627, 5.967529, 14.824984},{3.848328, 6.399569, 14.662138}}],
    Line[{{3.848328, 6.399569, 14.662138},{4.113449, 6.866707, 14.536824}}],
    Line[{{4.113449, 6.866707, 14.536824},{4.399552, 7.370373, 14.453238}}],
    Line[{{4.399552, 7.370373, 14.453238},{4.708178, 7.911726, 14.416228}}],
    Line[{{4.708178, 7.911726, 14.416228},{5.040807, 8.491508, 14.431337}}],
    Line[{{5.040807, 8.491508, 14.431337},{5.398828, 9.109890, 14.504873}}],
    Line[{{5.398828, 9.109890, 14.504873},{5.783472, 9.766226, 14.643909}}],
    Line[{{5.783472, 9.766226, 14.643909},{6.195746, 10.458822, 14.856292}}],
    Line[{{6.195746, 10.458822, 14.856292},{6.636336, 11.184612, 15.150591}}],
    
    Line[{{6.636336, 11.184612, 15.150591},{7.105490, 11.938825, 15.535954}}],
    
    Line[{{7.105490, 11.938825, 15.535954},{7.602879, 12.714569, 16.021923}}],
    
    Line[{{7.602879, 12.714569, 16.021923},{8.127433, 13.502462, 16.618052}}],
    
    Line[{{8.127433, 13.502462, 16.618052},{8.677152, 14.290184, 17.333456}}],
    
    Line[{{8.677152, 14.290184, 17.333456},{9.248898, 15.062166, 18.176104}}],
    
    Line[{{9.248898, 15.062166, 18.176104},{9.838186, 15.799375, 19.151976}}],
    
    Line[{{9.838186, 15.799375, 19.151976},{
      10.438965, 16.479216, 20.263956}}],
    Line[{{10.438965, 16.479216, 20.263956},{
      11.043477, 17.075996, 21.510704}}],
    Line[{{11.043477, 17.075996, 21.510704},{
      11.642086, 17.561386, 22.885181}}],
    Line[{{11.642086, 17.561386, 22.885181},{
      12.223339, 17.905895, 24.373621}}],
    Line[{{12.223339, 17.905895, 24.373621},{
      12.774059, 18.080469, 25.954388}}],
    Line[{{12.774059, 18.080469, 25.954388},{
      13.279682, 18.058880, 27.597588}}],
    Line[{{13.279682, 18.058880, 27.597588},{
      13.724772, 17.820400, 29.265308}}],
    Line[{{13.724772, 17.820400, 29.265308},{
      14.093765, 17.352547, 30.912926}}],
    Line[{{14.093765, 17.352547, 30.912926},{
      14.371898, 16.653536, 32.491425}}],
    Line[{{14.371898, 16.653536, 32.491425},{
      14.546224, 15.733982, 33.950676}}],
    Line[{{14.546224, 15.733982, 33.950676},{
      14.606674, 14.617348, 35.243488}}],
    Line[{{14.606674, 14.617348, 35.243488},{
      14.546955, 13.338842, 36.329556}}],
    Line[{{14.546955, 13.338842, 36.329556},{
      14.365181, 11.942977, 37.178944}}],
    Line[{{14.365181, 11.942977, 37.178944},{
      14.064196, 10.479766, 37.774658}}],
    Line[{{14.064196, 10.479766, 37.774658},{
      13.651423, 9.000497, 38.113327}}],
    Line[{{13.651423, 9.000497, 38.113327},{13.138347, 7.553428, 38.204578}}],
    
    Line[{{13.138347, 7.553428, 38.204578},{12.539659, 6.180233, 38.068890}}],
    
    Line[{{12.539659, 6.180233, 38.068890},{11.872193, 4.913599, 37.734554}}],
    
    Line[{{11.872193, 4.913599, 37.734554},{11.153816, 3.776147, 37.234333}}],
    
    Line[{{11.153816, 3.776147, 37.234333},{10.402353, 2.780552, 36.602253}}],
    
    Line[{{10.402353, 2.780552, 36.602253},{9.634705, 1.930616, 35.871029}}],
    Line[{{9.634705, 1.930616, 35.871029},{8.866158, 1.222922, 35.070175}}],
    Line[{{8.866158, 1.222922, 35.070175},{8.109945, 0.648697, 34.224960}}],
    Line[{{8.109945, 0.648697, 34.224960},{7.377022, 0.195649, 33.355980}}],
    Line[{{7.377022, 0.195649, 33.355980},{6.676026, -0.150441, 32.479294}}],
    Line[{{6.676026, -0.150441, 32.479294},{6.013381, -0.404439, 31.606844}}],
    
    Line[{{6.013381, -0.404439, 31.606844},{5.393490, -0.580918, 30.747084}}],
    
    Line[{{5.393490, -0.580918, 30.747084},{4.818993, -0.693526, 29.905638}}],
    
    Line[{{4.818993, -0.693526, 29.905638},{4.291039, -0.754602, 29.085953}}],
    
    Line[{{4.291039, -0.754602, 29.085953},{3.809567, -0.774999, 28.289856}}],
    
    Line[{{3.809567, -0.774999, 28.289856},{3.373561, -0.764042, 27.518032}}],
    
    Line[{{3.373561, -0.764042, 27.518032},{2.981288, -0.729573, 26.770399}}],
    
    Line[{{2.981288, -0.729573, 26.770399},{2.630498, -0.678069, 26.046381}}],
    
    Line[{{2.630498, -0.678069, 26.046381},{2.318603, -0.614780, 25.345129}}],
    
    Line[{{2.318603, -0.614780, 25.345129},{2.042812, -0.543875, 24.665653}}],
    
    Line[{{2.042812, -0.543875, 24.665653},{1.800251, -0.468601, 24.006931}}],
    
    Line[{{1.800251, -0.468601, 24.006931},{1.588047, -0.391421, 23.367954}}],
    
    Line[{{1.588047, -0.391421, 23.367954},{1.403401, -0.314146, 22.747778}}],
    
    Line[{{1.403401, -0.314146, 22.747778},{1.243634, -0.238049, 22.145521}}],
    
    Line[{{1.243634, -0.238049, 22.145521},{1.106223, -0.163969, 21.560390}}],
    
    Line[{{1.106223, -0.163969, 21.560390},{0.988820, -0.092395, 20.991663}}],
    
    Line[{{0.988820, -0.092395, 20.991663},{0.889272, -0.023539, 20.438690}}],
    
    Line[{{0.889272, -0.023539, 20.438690},{0.805619, 0.042602, 19.900887}}],
    Line[{{0.805619, 0.042602, 19.900887},{0.736097, 0.106198, 19.377722}}],
    Line[{{0.736097, 0.106198, 19.377722},{0.679133, 0.167543, 18.868713}}],
    Line[{{0.679133, 0.167543, 18.868713},{0.633335, 0.227029, 18.373425}}],
    Line[{{0.633335, 0.227029, 18.373425},{0.597485, 0.285114, 17.891447}}],
    Line[{{0.597485, 0.285114, 17.891447},{0.570528, 0.342310, 17.422405}}],
    Line[{{0.570528, 0.342310, 17.422405},{0.551560, 0.399164, 16.965952}}],
    Line[{{0.551560, 0.399164, 16.965952},{0.539813, 0.456253, 16.521763}}],
    Line[{{0.539813, 0.456253, 16.521763},{0.534654, 0.514175, 16.089533}}],
    Line[{{0.534654, 0.514175, 16.089533},{0.535563, 0.573550, 15.668976}}],
    Line[{{0.535563, 0.573550, 15.668976},{0.542133, 0.635013, 15.259829}}],
    Line[{{0.542133, 0.635013, 15.259829},{0.554054, 0.699222, 14.861844}}],
    Line[{{0.554054, 0.699222, 14.861844},{0.571112, 0.766858, 14.474794}}],
    Line[{{0.571112, 0.766858, 14.474794},{0.593178, 0.838628, 14.098472}}],
    Line[{{0.593178, 0.838628, 14.098472},{0.620205, 0.915275, 13.732693}}],
    Line[{{0.620205, 0.915275, 13.732693},{0.652221, 0.997579, 13.377294}}],
    Line[{{0.652221, 0.997579, 13.377294},{0.689330, 1.086370, 13.032139}}],
    Line[{{0.689330, 1.086370, 13.032139},{0.731707, 1.182531, 12.697125}}],
    Line[{{0.731707, 1.182531, 12.697125},{0.779597, 1.287012, 12.372181}}],
    Line[{{0.779597, 1.287012, 12.372181},{0.833317, 1.400835, 12.057276}}],
    Line[{{0.833317, 1.400835, 12.057276},{0.893253, 1.525110, 11.752425}}],
    Line[{{0.893253, 1.525110, 11.752425},{0.959867, 1.661042, 11.457700}}],
    Line[{{0.959867, 1.661042, 11.457700},{1.033694, 1.809943, 11.173235}}],
    Line[{{1.033694, 1.809943, 11.173235},{1.115352, 1.973249, 10.899242}}],
    Line[{{1.115352, 1.973249, 10.899242},{1.205539, 2.152526, 10.636024}}],
    Line[{{1.205539, 2.152526, 10.636024},{1.305047, 2.349493, 10.383994}}],
    Line[{{1.305047, 2.349493, 10.383994},{1.414761, 2.566027, 10.143692}}],
    Line[{{1.414761, 2.566027, 10.143692},{1.535671, 2.804182, 9.915820}}],
    Line[{{1.535671, 2.804182, 9.915820},{1.668875, 3.066201, 9.701264}}],
    Line[{{1.668875, 3.066201, 9.701264},{1.815591, 3.354528, 9.501134}}],
    Line[{{1.815591, 3.354528, 9.501134},{1.977163, 3.671817, 9.316826}}],
    Line[{{1.977163, 3.671817, 9.316826},{2.155072, 4.020945, 9.150034}}],
    Line[{{2.155072, 4.020945, 9.150034},{2.350940, 4.404995, 9.002883}}],
    Line[{{2.350940, 4.404995, 9.002883},{2.566540, 4.827278, 8.877925}}],
    Line[{{2.566540, 4.827278, 8.877925},{2.803799, 5.291276, 8.778318}}],
    Line[{{2.803799, 5.291276, 8.778318},{3.064804, 5.800656, 8.707849}}],
    Line[{{3.064804, 5.800656, 8.707849},{3.351795, 6.359163, 8.671128}}],
    Line[{{3.351795, 6.359163, 8.671128},{3.667154, 6.970559, 8.673699}}],
    Line[{{3.667154, 6.970559, 8.673699},{4.013394, 7.638501, 8.722196}}],
    Line[{{4.013394, 7.638501, 8.722196},{4.393127, 8.366360, 8.824526}}],
    Line[{{4.393127, 8.366360, 8.824526},{4.809006, 9.156950, 8.990051}}],
    Line[{{4.809006, 9.156950, 8.990051},{5.263666, 10.012224, 9.229765}}],
    Line[{{5.263666, 10.012224, 9.229765},{5.759612, 10.932820, 9.556439}}],
    Line[{{5.759612, 10.932820, 9.556439},{6.299092, 11.917508, 9.984739}}],
    Line[{{6.299092, 11.917508, 9.984739},{6.883903, 12.962468, 10.531221}}],
    Line[{{6.883903, 12.962468, 10.531221},{7.515144, 14.060434, 11.214191}}],
    
    Line[{{7.515144, 14.060434, 11.214191},{8.192916, 15.199667, 12.053313}}],
    
    Line[{{8.192916, 15.199667, 12.053313},{8.915926, 16.362841, 13.068881}}],
    
    Line[{{8.915926, 16.362841, 13.068881},{9.681043, 17.525877, 14.280649}}],
    
    Line[{{9.681043, 17.525877, 14.280649},{
      10.482767, 18.656904, 15.706090}}],
    Line[{{10.482767, 18.656904, 15.706090},{
      11.312686, 19.715561, 17.357996}}],
    Line[{{11.312686, 19.715561, 17.357996},{
      12.158930, 20.652967, 19.241440}}],
    Line[{{12.158930, 20.652967, 19.241440},{
      13.005732, 21.412783, 21.350203}}],
    Line[{{13.005732, 21.412783, 21.350203},{
      13.833191, 21.933710, 23.663044}}],
    Line[{{13.833191, 21.933710, 23.663044},{
      14.617409, 22.153927, 26.140457}}],
    Line[{{14.617409, 22.153927, 26.140457},{
      15.331091, 22.017221, 28.722780}}],
    Line[{{15.331091, 22.017221, 28.722780},{
      15.944758, 21.480612, 31.330614}}],
    Line[{{15.944758, 21.480612, 31.330614},{
      16.428623, 20.522404, 33.868599}}],
    Line[{{16.428623, 20.522404, 33.868599},{
      16.754976, 19.148941, 36.232765}}],
    Line[{{16.754976, 19.148941, 36.232765},{
      16.900879, 17.398348, 38.320850}}],
    Line[{{16.900879, 17.398348, 38.320850},{
      16.850723, 15.339618, 40.044216}}],
    Line[{{16.850723, 15.339618, 40.044216},{
      16.598215, 13.066469, 41.338741}}],
    Line[{{16.598215, 13.066469, 41.338741},{
      16.147373, 10.686990, 42.172344}}],
    Line[{{16.147373, 10.686990, 42.172344},{
      15.512301, 8.310881, 42.547352}}],
    Line[{{15.512301, 8.310881, 42.547352},{14.715773, 6.037260, 42.497368}}],
    
    Line[{{14.715773, 6.037260, 42.497368},{13.786924, 3.945332, 42.079781}}],
    
    Line[{{13.786924, 3.945332, 42.079781},{12.758474, 2.089373, 41.365990}}],
    
    Line[{{12.758474, 2.089373, 41.365990},{11.663944, 0.498153, 40.431583}}],
    
    Line[{{11.663944, 0.498153, 40.431583},{
      10.535279, -0.822151, 39.348267}}],
    Line[{{10.535279, -0.822151, 39.348267},{
      9.401075, -1.882964, 38.178444}}],
    Line[{{9.401075, -1.882964, 38.178444},{8.285498, -2.707695, 36.972485}}],
    
    Line[{{8.285498, -2.707695, 36.972485},{7.207817, -3.326505, 35.768250}}],
    
    Line[{{7.207817, -3.326505, 35.768250},{6.182448, -3.772094, 34.592125}}],
    
    Line[{{6.182448, -3.772094, 34.592125},{5.219327, -4.076678, 33.460892}}],
    
    Line[{{5.219327, -4.076678, 33.460892},{4.324484, -4.270063, 32.383831}}],
    
    Line[{{4.324484, -4.270063, 32.383831},{3.500697, -4.378634, 31.364780}}],
    
    Line[{{3.500697, -4.378634, 31.364780},{2.748153, -4.424980, 30.403851}}],
    
    Line[{{2.748153, -4.424980, 30.403851},{2.065052, -4.427944, 29.498831}}],
    
    Line[{{2.065052, -4.427944, 29.498831},{1.448145, -4.402917, 28.646219}}],
    
    Line[{{1.448145, -4.402917, 28.646219},{0.893175, -4.362251, 27.841949}}],
    
    Line[{{0.893175, -4.362251, 27.841949},{0.395245, -4.315706, 27.081871}}],
    
    Line[{{
      0.395245, -4.315706, 27.081871},{-0.050897, -4.270886, 26.362066}}],
    Line[{{-0.050897, -4.270886, 26.362066},{-0.450639, -4.233639, 
        25.678999}}],
    Line[{{-0.450639, -4.233639, 25.678999},{-0.809341, -4.208401, 
        25.029604}}],
    Line[{{-0.809341, -4.208401, 25.029604},{-1.132224, -4.198499, 
        24.411304}}],
    Line[{{-1.132224, -4.198499, 24.411304},{-1.424279, -4.206395, 
        23.821997}}],
    Line[{{-1.424279, -4.206395, 23.821997},{-1.690227, -4.233899, 
        23.260021}}],
    Line[{{-1.690227, -4.233899, 23.260021},{-1.934485, -4.282331, 
        22.724121}}],
    Line[{{-1.934485, -4.282331, 22.724121},{-2.161159, -4.352663, 
        22.213404}}],
    Line[{{-2.161159, -4.352663, 22.213404},{-2.374043, -4.445621, 
        21.727306}}],
    Line[{{-2.374043, -4.445621, 21.727306},{-2.576632, -4.561775, 
        21.265562}}],
    Line[{{-2.576632, -4.561775, 21.265562},{-2.772137, -4.701603, 
        20.828182}}],
    Line[{{-2.772137, -4.701603, 20.828182},{-2.963506, -4.865540, 
        20.415443}}],
    Line[{{-2.963506, -4.865540, 20.415443},{-3.153447, -5.054007, 
        20.027880}}],
    Line[{{-3.153447, -5.054007, 20.027880},{-3.344452, -5.267439, 
        19.666271}}],
    Line[{{-3.344452, -5.267439, 19.666271},{-3.538818, -5.506292, 
        19.331669}}],
    Line[{{-3.538818, -5.506292, 19.331669},{-3.738666, -5.771034, 
        19.025387}}],
    Line[{{-3.738666, -5.771034, 19.025387},{-3.945961, -6.062142, 
        18.749027}}],
    Line[{{-3.945961, -6.062142, 18.749027},{-4.162529, -6.380075, 
        18.504496}}],
    Line[{{-4.162529, -6.380075, 18.504496},{-4.390057, -6.725233, 
        18.294020}}],
    Line[{{-4.390057, -6.725233, 18.294020},{-4.630109, -7.097912, 
        18.120176}}],
    Line[{{-4.630109, -7.097912, 18.120176},{-4.884122, -7.498251, 
        17.985905}}],
    Line[{{-4.884122, -7.498251, 17.985905},{-5.153397, -7.926147, 
        17.894526}}],
    Line[{{-5.153397, -7.926147, 17.894526},{-5.439082, -8.381150, 
        17.849747}}],
    Line[{{-5.439082, -8.381150, 17.849747},{-5.742163, -8.862395, 
        17.855679}}],
    Line[{{-5.742163, -8.862395, 17.855679},{-6.063412, -9.368418, 
        17.916784}}],
    Line[{{-6.063412, -9.368418, 17.916784},{-6.403360, -9.897046, 
        18.037870}}],
    Line[{{-6.403360, -9.897046, 18.037870},{-6.762240, -10.445225, 
        18.223999}}],
    Line[{{-6.762240, -10.445225, 18.223999},{-7.139920, -11.008844, 
        18.480368}}],
    Line[{{-7.139920, -11.008844, 18.480368},{-7.535831, -11.582542, 
        18.812187}}],
    Line[{{-7.535831, -11.582542, 18.812187},{-7.948884, -12.159563, 
        19.224386}}],
    Line[{{-7.948884, -12.159563, 19.224386},{-8.377371, -12.731547, 
        19.721418}}],
    Line[{{-8.377371, -12.731547, 19.721418},{-8.818874, -13.288482, 
        20.306807}}],
    Line[{{-8.818874, -13.288482, 20.306807},{-9.270168, -13.818615, 
        20.982761}}],
    Line[{{-9.270168, -13.818615, 20.982761},{-9.727129, -14.308514, 
        21.749643}}],
    Line[{{-9.727129, -14.308514, 21.749643},{-10.184686, -14.743339, 
        22.605429}}],
    Line[{{-10.184686, -14.743339, 22.605429},{-10.636771, -15.107142, 
        23.545126}}],
    Line[{{-10.636771, -15.107142, 23.545126},{-11.076353, -15.383492, 
        24.560272}}],
    Line[{{-11.076353, -15.383492, 24.560272},{-11.495515, -15.556286, 
        25.638536}}],
    Line[{{-11.495515, -15.556286, 25.638536},{-11.885613, -15.610704, 
        26.763527}}],
    Line[{{-11.885613, -15.610704, 26.763527},{-12.237523, -15.534390, 
        27.914833}}],
    Line[{{-12.237523, -15.534390, 27.914833},{-12.541983, -15.318645, 
        29.068539}}],
    Line[{{-12.541983, -15.318645, 29.068539},{-12.790004, -14.959480, 
        30.198078}}],
    Line[{{-12.790004, -14.959480, 30.198078},{-12.973346, -14.458648, 
        31.275419}}],
    Line[{{-12.973346, -14.458648, 31.275419},{-13.085012, -13.823983, 
        32.272705}}],
    Line[{{-13.085012, -13.823983, 32.272705},{-13.119719, -13.069508, 
        33.163956}}],
    Line[{{-13.119719, -13.069508, 33.163956},{-13.074292, -12.214796, 
        33.926773}}],
    Line[{{-13.074292, -12.214796, 33.926773},{-12.947954, -11.283869, 
        34.543842}}],
    Line[{{-12.947954, -11.283869, 34.543842},{-12.742436, -10.303609, 
        35.003944}}],
    Line[{{-12.742436, -10.303609, 35.003944},{-12.461930, -9.301957, 
        35.302464}}],
    Line[{{-12.461930, -9.301957, 35.302464},{-12.112863, -8.306072, 
        35.441235}}],
    Line[{{-12.112863, -8.306072, 35.441235},{-11.703528, -7.340655, 
        35.427883}}],
    Line[{{-11.703528, -7.340655, 35.427883},{-11.243611, -6.426724, 
        35.274712}}],
    Line[{{-11.243611, -6.426724, 35.274712},{-10.743663, -5.580782, 
        34.997337}}],
    Line[{{-10.743663, -5.580782, 34.997337},{-10.214566, -4.814511, 
        34.613316}}],
    Line[{{-10.214566, -4.814511, 34.613316},{-9.667053, -4.134898, 
        34.140820}}],
    Line[{{-9.667053, -4.134898, 34.140820},{-9.111286, -3.544694, 
        33.597561}}],
    Line[{{-9.111286, -3.544694, 33.597561},{-8.556547, -3.043093, 
        32.999985}}],
    Line[{{-8.556547, -3.043093, 32.999985},{-8.011016, -2.626510, 
        32.362766}}],
    Line[{{-8.011016, -2.626510, 32.362766},{-7.481649, -2.289366, 
        31.698521}}],
    Line[{{-7.481649, -2.289366, 31.698521},{-6.974146, -2.024811, 
        31.017775}}],
    Line[{{-6.974146, -2.024811, 31.017775},{-6.492974, -1.825338, 
        30.329056}}],
    Line[{{-6.492974, -1.825338, 30.329056},{-6.041450, -1.683279, 
        29.639090}}],
    Line[{{-6.041450, -1.683279, 29.639090},{-5.621852, -1.591178, 
        28.953045}}],
    Line[{{-5.621852, -1.591178, 28.953045},{-5.235555, -1.542054, 
        28.274799}}],
    Line[{{-5.235555, -1.542054, 28.274799},{-4.883167, -1.529559, 
        27.607187}}],
    Line[{{-4.883167, -1.529559, 27.607187},{-4.564670, -1.548082, 
        26.952225}}],
    Line[{{-4.564670, -1.548082, 26.952225},{-4.279548, -1.592770, 
        26.311316}}],
    Line[{{-4.279548, -1.592770, 26.311316},{-4.026912, -1.659533, 
        25.685408}}],
    Line[{{-4.026912, -1.659533, 25.685408},{-3.805603, -1.745002, 
        25.075125}}],
    Line[{{-3.805603, -1.745002, 25.075125},{-3.614284, -1.846478, 
        24.480871}}],
    Line[{{-3.614284, -1.846478, 24.480871},{-3.451518, -1.961877, 
        23.902906}}],
    Line[{{-3.451518, -1.961877, 23.902906},{-3.315835, -2.089661, 
        23.341415}}],
    Line[{{-3.315835, -2.089661, 23.341415},{-3.205782, -2.228776, 
        22.796547}}],
    Line[{{-3.205782, -2.228776, 22.796547},{-3.119963, -2.378593, 
        22.268444}}],
    Line[{{-3.119963, -2.378593, 22.268444},{-3.057077, -2.538850, 
        21.757278}}],
    Line[{{-3.057077, -2.538850, 21.757278},{-3.015933, -2.709607, 
        21.263266}}],
    Line[{{-3.015933, -2.709607, 21.263266},{-2.995477, -2.891197, 
        20.786686}}],
    Line[{{-2.995477, -2.891197, 20.786686},{-2.994796, -3.084193, 
        20.327894}}],
    Line[{{-2.994796, -3.084193, 20.327894},{-3.013130, -3.289371, 
        19.887341}}],
    Line[{{-3.013130, -3.289371, 19.887341},{-3.049874, -3.507682, 
        19.465582}}],
    Line[{{-3.049874, -3.507682, 19.465582},{-3.104577, -3.740231, 
        19.063303}}],
    Line[{{-3.104577, -3.740231, 19.063303},{-3.176944, -3.988249, 
        18.681334}}],
    Line[{{-3.176944, -3.988249, 18.681334},{-3.266831, -4.253078, 
        18.320662}}],
    Line[{{-3.266831, -4.253078, 18.320662},{-3.374238, -4.536146, 
        17.982471}}],
    Line[{{-3.374238, -4.536146, 17.982471},{-3.499305, -4.838951, 
        17.668156}}],
    Line[{{-3.499305, -4.838951, 17.668156},{-3.642305, -5.163032, 
        17.379360}}],
    Line[{{-3.642305, -5.163032, 17.379360},{-3.803630, -5.509945, 
        17.118000}}],
    Line[{{-3.803630, -5.509945, 17.118000},{-3.983786, -5.881231, 
        16.886307}}],
    Line[{{-3.983786, -5.881231, 16.886307},{-4.183370, -6.278363, 
        16.686871}}],
    Line[{{-4.183370, -6.278363, 16.686871},{-4.403063, -6.702713, 
        16.522661}}],
    Line[{{-4.403063, -6.702713, 16.522661},{-4.643596, -7.155457, 
        16.397095}}],
    Line[{{-4.643596, -7.155457, 16.397095},{-4.905739, -7.637527, 
        16.314045}}],
    Line[{{-4.905739, -7.637527, 16.314045},{-5.190257, -8.149481, 
        16.277901}}],
    Line[{{-5.190257, -8.149481, 16.277901},{-5.497867, -8.691372, 
        16.293568}}],
    Line[{{-5.497867, -8.691372, 16.293568},{-5.829206, -9.262647, 
        16.366499}}],
    Line[{{-5.829206, -9.262647, 16.366499},{-6.184745, -9.861886, 
        16.502649}}],
    Line[{{-6.184745, -9.861886, 16.502649},{-6.564736, -10.486675, 
        16.708452}}],
    Line[{{-6.564736, -10.486675, 16.708452},{-6.969123, -11.133328, 
        16.990734}}],
    Line[{{-6.969123, -11.133328, 16.990734},{-7.397410, -11.796613, 
        17.356461}}],
    Line[{{-7.397410, -11.796613, 17.356461},{-7.848601, -12.469557, 
        17.812691}}],
    Line[{{-7.848601, -12.469557, 17.812691},{-8.321007, -13.143104, 
        18.366032}}],
    Line[{{-8.321007, -13.143104, 18.366032},{-8.812137, -13.805955, 
        19.022320}}],
    Line[{{-8.812137, -13.805955, 19.022320},{-9.318548, -14.444399, 
        19.786030}}],
    Line[{{-9.318548, -14.444399, 19.786030},{-9.835701, -15.042279, 
        20.659618}}],
    Line[{{-9.835701, -15.042279, 20.659618},{-10.357837, -15.581147, 
        21.642706}}],
    Line[{{-10.357837, -15.581147, 21.642706},{-10.877895, -16.040697, 
        22.731245}}],
    Line[{{-10.877895, -16.040697, 22.731245},{-11.387491, -16.399412, 
        23.916718}}],
    Line[{{-11.387491, -16.399412, 23.916718},{-11.876970, -16.635624, 
        25.185411}}],
    Line[{{-11.876970, -16.635624, 25.185411},{-12.335582, -16.728855, 
        26.517971}}],
    Line[{{-12.335582, -16.728855, 26.517971},{-12.751775, -16.661467, 
        27.889338}}],
    Line[{{-12.751775, -16.661467, 27.889338},{-13.113624, -16.420435, 
        29.269232}}],
    Line[{{-13.113624, -16.420435, 29.269232},{-13.409396, -15.999101, 
        30.623253}}],
    Line[{{-13.409396, -15.999101, 30.623253},{-13.628208, -15.398593, 
        31.914625}}],
    Line[{{-13.628208, -15.398593, 31.914625},{-13.760735, -14.628728, 
        33.106472}}],
    Line[{{-13.760735, -14.628728, 33.106472},{-13.799900, -13.708035, 
        34.164448}}],
    Line[{{-13.799900, -13.708035, 34.164448},{-13.741458, -12.662955, 
        35.059280}}],
    Line[{{-13.741458, -12.662955, 35.059280},{-13.584399, -11.526122, 
        35.768982}}],
    Line[{{-13.584399, -11.526122, 35.768982},{-13.331119, -10.333941, 
        36.280369}}],
    Line[{{-13.331119, -10.333941, 36.280369},{-12.987322, -9.123824, 
        36.589634}}],
    Line[{{-12.987322, -9.123824, 36.589634},{-12.561665, -7.931450, 
        36.701954}}],
    Line[{{-12.561665, -7.931450, 36.701954},{-12.065196, -6.788402, 
        36.630268}}],
    Line[{{-12.065196, -6.788402, 36.630268},{-11.510648, -5.720465, 
        36.393436}}],
    Line[{{-11.510648, -5.720465, 36.393436},{-10.911673, -4.746713, 
        36.014122}}],
    Line[{{-10.911673, -4.746713, 36.014122},{-10.282106, -3.879348, 
        35.516705}}],
    Line[{{-10.282106, -3.879348, 35.516705},{-9.635313, -3.124158, 
        34.925465}}],
    Line[{{-9.635313, -3.124158, 34.925465},{-8.983661, -2.481438, 
        34.263161}}],
    Line[{{-8.983661, -2.481438, 34.263161},{-8.338150, -1.947133, 
        33.550106}}],
    Line[{{-8.338150, -1.947133, 33.550106},{-7.708186, -1.514036, 
        32.803658}}],
    Line[{{-7.708186, -1.514036, 32.803658},{-7.101486, -1.172912, 
        32.038082}}],
    Line[{{-7.101486, -1.172912, 32.038082},{-6.524096, -0.913464, 
        31.264696}}],
    Line[{{-6.524096, -0.913464, 31.264696},{-5.980489, -0.725098, 
        30.492146}}],
    Line[{{-5.980489, -0.725098, 30.492146},{-5.473709, -0.597496, 
        29.726812}}],
    Line[{{-5.473709, -0.597496, 29.726812},{-5.005562, -0.521009, 
        28.973209}}],
    Line[{{-5.005562, -0.521009, 28.973209},{-4.576806, -0.486888, 
        28.234390}}],
    Line[{{-4.576806, -0.486888, 28.234390},{-4.187340, -0.487419, 
        27.512287}}],
    Line[{{-4.187340, -0.487419, 27.512287},{-3.836395, -0.515948, 
        26.808004}}],
    Line[{{-3.836395, -0.515948, 26.808004},{-3.522688, -0.566866, 
        26.122074}}],
    Line[{{-3.522688, -0.566866, 26.122074},{-3.244575, -0.635541, 
        25.454624}}],
    Line[{{-3.244575, -0.635541, 25.454624},{-3.000172, -0.718238, 
        24.805531}}],
    Line[{{-3.000172, -0.718238, 24.805531},{-2.787455, -0.812018, 
        24.174522}}],
    Line[{{-2.787455, -0.812018, 24.174522},{-2.604352, -0.914646, 
        23.561243}}],
    Line[{{-2.604352, -0.914646, 23.561243},{-2.448802, -1.024498, 
        22.965315}}],
    Line[{{-2.448802, -1.024498, 22.965315},{-2.318814, -1.140469, 
        22.386364}}],
    Line[{{-2.318814, -1.140469, 22.386364},{-2.212502, -1.261899, 
        21.824043}}],
    Line[{{-2.212502, -1.261899, 21.824043},{-2.128116, -1.388503, 
        21.278049}}],
    Line[{{-2.128116, -1.388503, 21.278049},{-2.064060, -1.520314, 
        20.748129}}],
    Line[{{-2.064060, -1.520314, 20.748129},{-2.018909, -1.657629, 
        20.234081}}],
    Line[{{-2.018909, -1.657629, 20.234081},{-1.991409, -1.800971, 
        19.735773}}],
    Line[{{-1.991409, -1.800971, 19.735773},{-1.980489, -1.951055, 
        19.253124}}],
    Line[{{-1.980489, -1.951055, 19.253124},{-1.985253, -2.108761, 
        18.786135}}],
    Line[{{-1.985253, -2.108761, 18.786135},{-2.004982, -2.275113, 
        18.334869}}],
    Line[{{-2.004982, -2.275113, 18.334869},{-2.039131, -2.451266, 
        17.899483}}],
    Line[{{-2.039131, -2.451266, 17.899483},{-2.087319, -2.638493, 
        17.480211}}],
    Line[{{-2.087319, -2.638493, 17.480211},{-2.149331, -2.838177, 
        17.077402}}],
    Line[{{-2.149331, -2.838177, 17.077402},{-2.225108, -3.051811, 
        16.691515}}],
    Line[{{-2.225108, -3.051811, 16.691515},{-2.314744, -3.280986, 
        16.323147}}],
    Line[{{-2.314744, -3.280986, 16.323147},{-2.418480, -3.527398, 
        15.973047}}],
    Line[{{-2.418480, -3.527398, 15.973047},{-2.536701, -3.792842, 
        15.642145}}],
    Line[{{-2.536701, -3.792842, 15.642145},{-2.669931, -4.079206, 
        15.331578}}],
    Line[{{-2.669931, -4.079206, 15.331578},{-2.818826, -4.388467, 
        15.042728}}],
    Line[{{-2.818826, -4.388467, 15.042728},{-2.984174, -4.722683, 
        14.777255}}],
    Line[{{-2.984174, -4.722683, 14.777255},{-3.166886, -5.083977, 
        14.537145}}],
    Line[{{-3.166886, -5.083977, 14.537145},{-3.367992, -5.474510, 
        14.324759}}],
    Line[{{-3.367992, -5.474510, 14.324759},{-3.588628, -5.896450, 
        14.142889}}],
    Line[{{-3.588628, -5.896450, 14.142889},{-3.830028, -6.351925, 
        13.994825}}],
    Line[{{-3.830028, -6.351925, 13.994825},{-4.093507, -6.842959, 
        13.884418}}],
    Line[{{-4.093507, -6.842959, 13.884418},{-4.380437, -7.371378, 
        13.816144}}],
    Line[{{-4.380437, -7.371378, 13.816144},{-4.692224, -7.938713, 
        13.795197}}],
    Line[{{-4.692224, -7.938713, 13.795197},{-5.030257, -8.546025, 
        13.827521}}],
    Line[{{-5.030257, -8.546025, 13.827521},{-5.395875, -9.193755, 
        13.919915}}],
    Line[{{-5.395875, -9.193755, 13.919915},{-5.790280, -9.881452, 
        14.080004}}],
    Line[{{-5.790280, -9.881452, 14.080004},{-6.214476, -10.607522, 
        14.316317}}],
    Line[{{-6.214476, -10.607522, 14.316317},{-6.669137, -11.368875, 
        14.638144}}],
    Line[{{-6.669137, -11.368875, 14.638144},{-7.154503, -12.160528, 
        15.055512}}],
    Line[{{-7.154503, -12.160528, 15.055512},{-7.670201, -12.975202, 
        15.578835}}],
    Line[{{-7.670201, -12.975202, 15.578835},{-8.215070, -13.802793, 
        16.218649}}],
    Line[{{-8.215070, -13.802793, 16.218649},{-8.786947, -14.629990, 
        16.984987}}],
    Line[{{-8.786947, -14.629990, 16.984987},{-9.382435, -15.439848, 
        17.886641}}],
    Line[{{-9.382435, -15.439848, 17.886641},{-9.996657, -16.211508, 
        18.930202}}],
    Line[{{-9.996657, -16.211508, 18.930202},{-10.623035, -16.920259, 
        20.118820}}],
    Line[{{-10.623035, -16.920259, 20.118820},{-11.253076, -17.537750, 
        21.450842}}],
    Line[{{-11.253076, -17.537750, 21.450842},{-11.876254, -18.032911, 
        22.918285}}],
    Line[{{-11.876254, -18.032911, 22.918285},{-12.480028, -18.373400, 
        24.505495}}],
    Line[{{-12.480028, -18.373400, 24.505495},{-13.049970, -18.527578, 
        26.188000}}],
    Line[{{-13.049970, -18.527578, 26.188000},{-13.570167, -18.467264, 
        27.932087}}],
    Line[{{-13.570167, -18.467264, 27.932087},{-14.023825, -18.170794, 
        29.695217}}],
    Line[{{-14.023825, -18.170794, 29.695217},{-14.394135, -17.626165, 
        31.427652}}],
    Line[{{-14.394135, -17.626165, 31.427652},{-14.665321, -16.833727, 
        33.075287}}],
    Line[{{-14.665321, -16.833727, 33.075287},{-14.823817, -15.807885, 
        34.583580}}],
    Line[{{-14.823817, -15.807885, 34.583580},{-14.859410, -14.577285, 
        35.902119}}],
    Line[{{-14.859410, -14.577285, 35.902119},{-14.766223, -13.183288, 
        36.989182}}],
    Line[{{-14.766223, -13.183288, 36.989182},{-14.543358, -11.676714, 
        37.815498}}],
    Line[{{-14.543358, -11.676714, 37.815498},{-14.195127, -10.113396, 
        38.366608}}],
    Line[{{-14.195127, -10.113396, 38.366608},{-13.730782, -8.549160, 
        38.643322}}],
    Line[{{-13.730782, -8.549160, 38.643322},{-13.163811, -7.035149, 
        38.660400}}],
    Line[{{-13.163811, -7.035149, 38.660400},{-12.510909, -5.614120, 
        38.443748}}],
    Line[{{-12.510909, -5.614120, 38.443748},{-11.790745, -4.318190, 
        38.026752}}],
    Line[{{-11.790745, -4.318190, 38.026752},{-11.022720, -3.168085, 
        37.446449}}],
    Line[{{-11.022720, -3.168085, 37.446449},{-10.225827, -2.173740, 
        36.740059}}],
    Line[{{-10.225827, -2.173740, 36.740059},{-9.417735, -1.335808, 
        35.942368}}],
    Line[{{-9.417735, -1.335808, 35.942368},{-8.614128, -0.647705, 
        35.083942}}],
    Line[{{-8.614128, -0.647705, 35.083942},{-7.828305, -0.097761, 
        34.190239}}],
    Line[{{-7.828305, -0.097761, 34.190239},{-7.071026, 0.328788, 
        33.281464}}],
    Line[{{-7.071026, 0.328788, 33.281464},{-6.350539, 0.648142, 32.372871}}],
    
    Line[{{-6.350539, 0.648142, 32.372871},{-5.672751, 0.876660, 31.475414}}],
    
    Line[{{-5.672751, 0.876660, 31.475414},{-5.041479, 1.029972, 30.596493}}],
    
    Line[{{-5.041479, 1.029972, 30.596493},{-4.458747, 1.122415, 29.740721}}],
    
    Line[{{-4.458747, 1.122415, 29.740721},{-3.925100, 1.166733, 28.910618}}],
    
    Line[{{-3.925100, 1.166733, 28.910618},{-3.439898, 1.173967, 28.107214}}],
    
    Line[{{-3.439898, 1.173967, 28.107214},{-3.001595, 1.153478, 27.330521}}],
    
    Line[{{-3.001595, 1.153478, 27.330521},{-2.607975, 1.113048, 26.579901}}],
    
    Line[{{-2.607975, 1.113048, 26.579901},{-2.256367, 1.059034, 25.854345}}],
    
    Line[{{-2.256367, 1.059034, 25.854345},{-1.943808, 0.996536, 25.152651}}],
    
    Line[{{-1.943808, 0.996536, 25.152651},{-1.667188, 0.929571, 24.473570}}],
    
    Line[{{-1.667188, 0.929571, 24.473570},{-1.423355, 0.861243, 23.815863}}],
    
    Line[{{-1.423355, 0.861243, 23.815863},{-1.209200, 0.793889, 23.178370}}],
    
    Line[{{-1.209200, 0.793889, 23.178370},{-1.021718, 0.729225, 22.560019}}],
    
    Line[{{-1.021718, 0.729225, 22.560019},{-0.858053, 0.668460, 21.959841}}],
    
    Line[{{-0.858053, 0.668460, 21.959841},{-0.715524, 0.612401, 21.376965}}],
    
    Line[{{-0.715524, 0.612401, 21.376965},{-0.591646, 0.561543, 20.810612}}],
    
    Line[{{-0.591646, 0.561543, 20.810612},{-0.484136, 0.516140, 20.260090}}],
    
    Line[{{-0.484136, 0.516140, 20.260090},{-0.390911, 0.476269, 19.724771}}],
    
    Line[{{-0.390911, 0.476269, 19.724771},{-0.310087, 0.441875, 19.204094}}],
    
    Line[{{-0.310087, 0.441875, 19.204094},{-0.239969, 0.412816, 18.697546}}],
    
    Line[{{-0.239969, 0.412816, 18.697546},{-0.179039, 0.388895, 18.204660}}],
    
    Line[{{-0.179039, 0.388895, 18.204660},{-0.125946, 0.369880, 17.725002}}],
    
    Line[{{-0.125946, 0.369880, 17.725002},{-0.079488, 0.355531, 17.258171}}],
    
    Line[{{-0.079488, 0.355531, 17.258171},{-0.038600, 0.345613, 16.803787}}],
    
    Line[{{-0.038600, 0.345613, 16.803787},{-0.002343, 0.339904, 16.361496}}],
    
    Line[{{-0.002343, 0.339904, 16.361496},{0.030116, 0.338208, 15.930962}}],
    Line[{{0.030116, 0.338208, 15.930962},{0.059512, 0.340360, 15.511860}}],
    Line[{{0.059512, 0.340360, 15.511860},{0.086496, 0.346229, 15.103885}}],
    Line[{{0.086496, 0.346229, 15.103885},{0.111646, 0.355722, 14.706741}}],
    Line[{{0.111646, 0.355722, 14.706741},{0.135479, 0.368789, 14.320148}}],
    Line[{{0.135479, 0.368789, 14.320148},{0.158460, 0.385420, 13.943834}}],
    Line[{{0.158460, 0.385420, 13.943834},{0.181010, 0.405650, 13.577539}}],
    Line[{{0.181010, 0.405650, 13.577539},{0.203516, 0.429558, 13.221014}}],
    Line[{{0.203516, 0.429558, 13.221014},{0.226339, 0.457269, 12.874020}}],
    Line[{{0.226339, 0.457269, 12.874020},{0.249817, 0.488956, 12.536327}}],
    Line[{{0.249817, 0.488956, 12.536327},{0.274278, 0.524841, 12.207722}}],
    Line[{{0.274278, 0.524841, 12.207722},{0.300040, 0.565196, 11.887997}}],
    Line[{{0.300040, 0.565196, 11.887997},{0.327421, 0.610349, 11.576962}}],
    Line[{{0.327421, 0.610349, 11.576962},{0.356740, 0.660681, 11.274437}}],
    Line[{{0.356740, 0.660681, 11.274437},{0.388327, 0.716637, 10.980261}}],
    Line[{{0.388327, 0.716637, 10.980261},{0.422526, 0.778726, 10.694285}}],
    Line[{{0.422526, 0.778726, 10.694285},{0.459698, 0.847523, 10.416385}}],
    Line[{{0.459698, 0.847523, 10.416385},{0.500232, 0.923684, 10.146452}}],
    Line[{{0.500232, 0.923684, 10.146452},{0.544542, 1.007944, 9.884406}}],
    Line[{{0.544542, 1.007944, 9.884406},{0.593078, 1.101128, 9.630198}}],
    Line[{{0.593078, 1.101128, 9.630198},{0.646333, 1.204161, 9.383808}}],
    Line[{{0.646333, 1.204161, 9.383808},{0.704843, 1.318075, 9.145261}}],
    Line[{{0.704843, 1.318075, 9.145261},{0.769198, 1.444021, 8.914628}}],
    Line[{{0.769198, 1.444021, 8.914628},{0.840049, 1.583281, 8.692039}}],
    Line[{{0.840049, 1.583281, 8.692039},{0.918111, 1.737278, 8.477690}}],
    Line[{{0.918111, 1.737278, 8.477690},{1.004176, 1.907596, 8.271863}}],
    Line[{{1.004176, 1.907596, 8.271863},{1.099120, 2.095989, 8.074944}}],
    Line[{{1.099120, 2.095989, 8.074944},{1.203909, 2.304397, 7.887428}}],
    Line[{{1.203909, 2.304397, 7.887428},{1.319615, 2.534970, 7.709978}}],
    Line[{{1.319615, 2.534970, 7.709978},{1.447419, 2.790075, 7.543413}}],
    Line[{{1.447419, 2.790075, 7.543413},{1.588631, 3.072317, 7.388793}}],
    Line[{{1.588631, 3.072317, 7.388793},{1.744691, 3.384556, 7.247424}}],
    Line[{{1.744691, 3.384556, 7.247424},{1.917192, 3.729914, 7.120947}}],
    Line[{{1.917192, 3.729914, 7.120947},{2.107882, 4.111789, 7.011395}}],
    Line[{{2.107882, 4.111789, 7.011395},{2.318683, 4.533857, 6.921260}}],
    Line[{{2.318683, 4.533857, 6.921260},{2.551692, 5.000052, 6.853635}}],
    Line[{{2.551692, 5.000052, 6.853635},{2.809196, 5.514560, 6.812289}}],
    Line[{{2.809196, 5.514560, 6.812289},{3.093675, 6.081763, 6.801832}}],
    Line[{{3.093675, 6.081763, 6.801832},{3.407790, 6.706153, 6.827888}}],
    Line[{{3.407790, 6.706153, 6.827888},{3.754385, 7.392249, 6.897247}}],
    Line[{{3.754385, 7.392249, 6.897247},{4.136454, 8.144403, 7.018115}}],
    Line[{{4.136454, 8.144403, 7.018115},{4.557101, 8.966541, 7.200333}}],
    Line[{{4.557101, 8.966541, 7.200333},{5.019477, 9.861856, 7.455610}}],
    Line[{{5.019477, 9.861856, 7.455610},{5.526681, 10.832320, 7.797763}}],
    Line[{{5.526681, 10.832320, 7.797763},{6.081626, 11.878095, 8.242909}}],
    Line[{{6.081626, 11.878095, 8.242909},{6.686841, 12.996714, 8.809575}}],
    Line[{{6.686841, 12.996714, 8.809575},{7.344213, 14.182101, 9.518660}}],
    Line[{{7.344213, 14.182101, 9.518660},{8.054648, 15.423348, 10.393137}}],
    Line[{{8.054648, 15.423348, 10.393137},{8.817640, 16.703321, 11.457396}}],
    
    Line[{{8.817640, 16.703321, 11.457396},{9.630737, 17.997131, 12.736047}}],
    
    Line[{{9.630737, 17.997131, 12.736047},{
      10.488914, 19.270655, 14.252039}}],
    Line[{{10.488914, 19.270655, 14.252039},{
      11.383880, 20.479340, 16.023924}}],
    Line[{{11.383880, 20.479340, 16.023924},{
      12.303367, 21.567728, 18.062212}}],
    Line[{{12.303367, 21.567728, 18.062212},{
      13.230493, 22.470209, 20.364895}}],
    Line[{{13.230493, 22.470209, 20.364895},{
      14.143336, 23.113592, 22.912525}}],
    Line[{{14.143336, 23.113592, 22.912525},{
      15.014933, 23.422121, 25.663610}}],
    Line[{{15.014933, 23.422121, 25.663610},{
      15.813831, 23.324953, 28.551447}}],
    Line[{{15.813831, 23.324953, 28.551447},{
      16.505466, 22.765968, 31.483915}}],
    Line[{{16.505466, 22.765968, 31.483915},{
      17.054367, 21.714380, 34.347534}}],
    Line[{{17.054367, 21.714380, 34.347534},{
      17.427114, 20.174160, 37.016357}}],
    Line[{{17.427114, 20.174160, 37.016357},{
      17.595785, 18.189522, 39.365494}}],
    Line[{{17.595785, 18.189522, 39.365494},{
      17.541262, 15.844129, 41.286743}}],
    Line[{{17.541262, 15.844129, 41.286743},{
      17.255825, 13.253242, 42.703121}}],
    Line[{{17.255825, 13.253242, 42.703121},{
      16.744452, 10.549815, 43.578796}}],
    Line[{{16.744452, 10.549815, 43.578796},{
      16.024456, 7.867523, 43.921745}}],
    Line[{{16.024456, 7.867523, 43.921745},{15.123616, 5.324782, 43.778999}}],
    
    Line[{{15.123616, 5.324782, 43.778999},{14.077092, 3.013092, 43.225952}}],
    
    Line[{{14.077092, 3.013092, 43.225952},{12.923860, 0.991488, 42.353130}}],
    
    Line[{{12.923860, 0.991488, 42.353130},{
      11.703226, -0.713025, 41.253452}}],
    Line[{{11.703226, -0.713025, 41.253452},{
      10.451964, -2.100642, 40.012287}}],
    Line[{{10.451964, -2.100642, 40.012287},{
      9.202297, -3.191641, 38.701378}}],
    Line[{{9.202297, -3.191641, 38.701378},{7.980783, -4.018919, 37.376354}}],
    
    Line[{{7.980783, -4.018919, 37.376354},{6.807979, -4.621495, 36.077023}}],
    
    Line[{{6.807979, -4.621495, 36.077023},{5.698684, -5.039572, 34.829346}}],
    
    Line[{{5.698684, -5.039572, 34.829346},{4.662544, -5.311261, 33.648243}}],
    
    Line[{{4.662544, -5.311261, 33.648243},{3.704841, -5.470701, 32.540390}}],
    
    Line[{{3.704841, -5.470701, 32.540390},{2.827333, -5.547263, 31.506794}}],
    
    Line[{{2.827333, -5.547263, 31.506794},{2.029052, -5.565436, 30.544855}}],
    
    Line[{{2.029052, -5.565436, 30.544855},{1.307017, -5.545160, 29.649939}}],
    
    Line[{{1.307017, -5.545160, 29.649939},{0.656831, -5.502349, 28.816477}}],
    
    Line[{{0.656831, -5.502349, 28.816477},{0.073172, -5.449482, 28.038725}}],
    
    Line[{{
      0.073172, -5.449482, 28.038725},{-0.449822, -5.396204, 27.311207}}],
    Line[{{-0.449822, -5.396204, 27.311207},{-0.918256, -5.349858, 
        26.628992}}],
    Line[{{-0.918256, -5.349858, 26.628992},{-1.338261, -5.315948, 
        25.987803}}],
    Line[{{-1.338261, -5.315948, 25.987803},{-1.715838, -5.298539, 
        25.384054}}],
    Line[{{-1.715838, -5.298539, 25.384054},{-2.056744, -5.300569, 
        24.814835}}],
    Line[{{-2.056744, -5.300569, 24.814835},{-2.366427, -5.324126, 
        24.277861}}],
    Line[{{-2.366427, -5.324126, 24.277861},{-2.649980, -5.370647, 
        23.771410}}],
    Line[{{-2.649980, -5.370647, 23.771410},{-2.912126, -5.441092, 
        23.294270}}],
    Line[{{-2.912126, -5.441092, 23.294270},{-3.157210, -5.536071, 
        22.845675}}],
    Line[{{-3.157210, -5.536071, 22.845675},{-3.389211, -5.655943, 
        22.425259}}],
    Line[{{-3.389211, -5.655943, 22.425259},{-3.611753, -5.800895, 
        22.033018}}],
    Line[{{-3.611753, -5.800895, 22.033018},{-3.828127, -5.970984, 
        21.669277}}],
    Line[{{-3.828127, -5.970984, 21.669277},{-4.041311, -6.166183, 
        21.334667}}],
    Line[{{-4.041311, -6.166183, 21.334667},{-4.253994, -6.386388, 
        21.030109}}],
    Line[{{-4.253994, -6.386388, 21.030109},{-4.468596, -6.631428, 
        20.756804}}],
    Line[{{-4.468596, -6.631428, 20.756804},{-4.687286, -6.901049, 
        20.516230}}],
    Line[{{-4.687286, -6.901049, 20.516230},{-4.911998, -7.194893, 
        20.310133}}],
    Line[{{-4.911998, -7.194893, 20.310133},{-5.144443, -7.512469, 
        20.140528}}],
    Line[{{-5.144443, -7.512469, 20.140528},{-5.386111, -7.853097, 
        20.009693}}],
    Line[{{-5.386111, -7.853097, 20.009693},{-5.638276, -8.215856, 
        19.920158}}],
    Line[{{-5.638276, -8.215856, 19.920158},{-5.901989, -8.599509, 
        19.874693}}],
    Line[{{-5.901989, -8.599509, 19.874693},{-6.178064, -9.002436, 
        19.876276}}],
    Line[{{-6.178064, -9.002436, 19.876276},{-6.467060, -9.422527, 
        19.928051}}],
    Line[{{-6.467060, -9.422527, 19.928051},{-6.769259, -9.857107, 
        20.033276}}],
    Line[{{-6.769259, -9.857107, 20.033276},{-7.084624, -10.302808, 
        20.195229}}],
    Line[{{-7.084624, -10.302808, 20.195229},{-7.412769, -10.755505, 
        20.417101}}],
    Line[{{-7.412769, -10.755505, 20.417101},{-7.752906, -11.210178, 
        20.701860}}],
    Line[{{-7.752906, -11.210178, 20.701860},{-8.103804, -11.660884, 
        21.052055}}],
    Line[{{-8.103804, -11.660884, 21.052055},{-8.463731, -12.100670, 
        21.469622}}],
    Line[{{-8.463731, -12.100670, 21.469622},{-8.830411, -12.521571, 
        21.955610}}],
    Line[{{-8.830411, -12.521571, 21.955610},{-9.200986, -12.914699, 
        22.509916}}],
    Line[{{-9.200986, -12.914699, 22.509916},{-9.571967, -13.270277, 
        23.130962}}],
    Line[{{-9.571967, -13.270277, 23.130962},{-9.939254, -13.577960, 
        23.815420}}],
    Line[{{-9.939254, -13.577960, 23.815420},{-10.298117, -13.827044, 
        24.557901}}],
    Line[{{-10.298117, -13.827044, 24.557901},{-10.643265, -14.006948, 
        25.350729}}],
    Line[{{-10.643265, -14.006948, 25.350729},{-10.968939, -14.107708, 
        26.183886}}],
    Line[{{-10.968939, -14.107708, 26.183886},{-11.269011, -14.120570, 
        27.044836}}],
    Line[{{-11.269011, -14.120570, 27.044836},{-11.537211, -14.038617, 
        27.918945}}],
    Line[{{-11.537211, -14.038617, 27.918945},{-11.767306, -13.857458, 
        28.789570}}],
    Line[{{-11.767306, -13.857458, 28.789570},{-11.953392, -13.575684, 
        29.638859}}],
    Line[{{-11.953392, -13.575684, 29.638859},{-12.090152, -13.195361, 
        30.448341}}],
    Line[{{-12.090152, -13.195361, 30.448341},{-12.173148, -12.722179, 
        31.199873}}],
    Line[{{-12.173148, -12.722179, 31.199873},{-12.199080, -12.165421, 
        31.876530}}],
    Line[{{-12.199080, -12.165421, 31.876530},{-12.166007, -11.537604, 
        32.463570}}],
    Line[{{-12.166007, -11.537604, 32.463570},{-12.073500, -10.853872, 
        32.949188}}],
    Line[{{-12.073500, -10.853872, 32.949188},{-11.922700, -10.131167, 
        33.325111}}],
    Line[{{-11.922700, -10.131167, 33.325111},{-11.716306, -9.387285, 
        33.586899}}],
    Line[{{-11.716306, -9.387285, 33.586899},{-11.458451, -8.639893, 
        33.733967}}],
    Line[{{-11.458451, -8.639893, 33.733967},{-11.154515, -7.905583, 
        33.769325}}],
    Line[{{-11.154515, -7.905583, 33.769325},{-10.810860, -7.199127, 
        33.699085}}],
    Line[{{-10.810860, -7.199127, 33.699085},{-10.434535, -6.532925, 
        33.531784}}],
    Line[{{-10.434535, -6.532925, 33.531784},{-10.032972, -5.916678, 
        33.277676}}],
    Line[{{-10.032972, -5.916678, 33.277676},{-9.613686, -5.357305, 
        32.947994}}],
    Line[{{-9.613686, -5.357305, 32.947994},{-9.184000, -4.859044, 
        32.554298}}],
    Line[{{-9.184000, -4.859044, 32.554298},{-8.750827, -4.423738, 
        32.107883}}],
    Line[{{-8.750827, -4.423738, 32.107883},{-8.320494, -4.051169, 
        31.619421}}],
    Line[{{-8.320494, -4.051169, 31.619421},{-7.898624, -3.739492, 
        31.098633}}],
    Line[{{-7.898624, -3.739492, 31.098633},{-7.490068, -3.485640, 
        30.554142}}],
    Line[{{-7.490068, -3.485640, 30.554142},{-7.098878, -3.285721, 
        29.993420}}],
    Line[{{-7.098878, -3.285721, 29.993420},{-6.728324, -3.135361, 
        29.422812}}],
    Line[{{-6.728324, -3.135361, 29.422812},{-6.380940, -3.029994, 
        28.847603}}],
    Line[{{-6.380940, -3.029994, 28.847603},{-6.058582, -2.965087, 
        28.272148}}],
    Line[{{-6.058582, -2.965087, 28.272148},{-5.762507, -2.936311, 
        27.699982}}],
    Line[{{-5.762507, -2.936311, 27.699982},{-5.493455, -2.939662, 
        27.133963}}],
    Line[{{-5.493455, -2.939662, 27.133963},{-5.251736, -2.971544, 
        26.576387}}],
    Line[{{-5.251736, -2.971544, 26.576387},{-5.037306, -3.028794, 
        26.029116}}],
    Line[{{-5.037306, -3.028794, 26.029116},{-4.849849, -3.108720, 
        25.493656}}],
    Line[{{-4.849849, -3.108720, 25.493656},{-4.688844, -3.209075, 
        24.971268}}],
    Line[{{-4.688844, -3.209075, 24.971268},{-4.553627, -3.328055, 
        24.463022}}],
    Line[{{-4.553627, -3.328055, 24.463022},{-4.443445, -3.464261, 
        23.969868}}],
    Line[{{-4.443445, -3.464261, 23.969868},{-4.357502, -3.616669, 
        23.492682}}],
    Line[{{-4.357502, -3.616669, 23.492682},{-4.294999, -3.784596, 
        23.032303}}],
    Line[{{-4.294999, -3.784596, 23.032303},{-4.255160, -3.967656, 
        22.589584}}],
    Line[{{-4.255160, -3.967656, 22.589584},{-4.237261, -4.165725, 
        22.165401}}],
    Line[{{-4.237261, -4.165725, 22.165401},{-4.240646, -4.378906, 
        21.760698}}],
    Line[{{-4.240646, -4.378906, 21.760698},{-4.264740, -4.607490, 
        21.376499}}],
    Line[{{-4.264740, -4.607490, 21.376499},{-4.309057, -4.851924, 
        21.013937}}],
    Line[{{-4.309057, -4.851924, 21.013937},{-4.373210, -5.112773, 
        20.674276}}],
    Line[{{-4.373210, -5.112773, 20.674276},{-4.456903, -5.390688, 
        20.358927}}],
    Line[{{-4.456903, -5.390688, 20.358927},{-4.559933, -5.686364, 
        20.069481}}],
    Line[{{-4.559933, -5.686364, 20.069481},{-4.682186, -6.000506, 
        19.807718}}],
    Line[{{-4.682186, -6.000506, 19.807718},{-4.823622, -6.333787, 
        19.575634}}],
    Line[{{-4.823622, -6.333787, 19.575634},{-4.984267, -6.686796, 
        19.375462}}],
    Line[{{-4.984267, -6.686796, 19.375462},{-5.164192, -7.059986, 
        19.209686}}],
    Line[{{-5.164192, -7.059986, 19.209686},{-5.363499, -7.453616, 
        19.081060}}],
    Line[{{-5.363499, -7.453616, 19.081060},{-5.582289, -7.867672, 
        18.992611}}],
    Line[{{-5.582289, -7.867672, 18.992611},{-5.820638, -8.301796, 
        18.947645}}],
    Line[{{-5.820638, -8.301796, 18.947645},{-6.078560, -8.755183, 
        18.949732}}],
    Line[{{-6.078560, -8.755183, 18.949732},{-6.355964, -9.226484, 
        19.002678}}],
    Line[{{-6.355964, -9.226484, 19.002678},{-6.652609, -9.713689, 
        19.110489}}],
    Line[{{-6.652609, -9.713689, 19.110489},{-6.968050, -10.214005, 
        19.277283}}],
    Line[{{-6.968050, -10.214005, 19.277283},{-7.301575, -10.723719, 
        19.507198}}],
    Line[{{-7.301575, -10.723719, 19.507198},{-7.652135, -11.238089, 
        19.804235}}],
    Line[{{-7.652135, -11.238089, 19.804235},{-8.018276, -11.751201, 
        20.172085}}],
    Line[{{-8.018276, -11.751201, 20.172085},{-8.398062, -12.255903, 
        20.613874}}],
    Line[{{-8.398062, -12.255903, 20.613874},{-8.788990, -12.743731, 
        21.131872}}],
    Line[{{-8.788990, -12.743731, 21.131872},{-9.187939, -13.204953, 
        21.727167}}],
    Line[{{-9.187939, -13.204953, 21.727167},{-9.591085, -13.628587, 
        22.399282}}],
    Line[{{-9.591085, -13.628587, 22.399282},{-9.993885, -14.002681, 
        23.145760}}],
    Line[{{-9.993885, -14.002681, 23.145760},{-10.391048, -14.314585, 
        23.961803}}],
    Line[{{-10.391048, -14.314585, 23.961803},{-10.776562, -14.551404, 
        24.839859}}],
    Line[{{-10.776562, -14.551404, 24.839859},{-11.143793, -14.700680, 
        25.769501}}],
    Line[{{-11.143793, -14.700680, 25.769501},{-11.485572, -14.751018, 
        26.737123}}],
    Line[{{-11.485572, -14.751018, 26.737123},{-11.794437, -14.693015, 
        27.726254}}],
    Line[{{-11.794437, -14.693015, 27.726254},{-12.062861, -14.520036, 
        28.717777}}],
    Line[{{-12.062861, -14.520036, 28.717777},{-12.283573, -14.229032, 
        29.690638}}],
    Line[{{-12.283573, -14.229032, 29.690638},{-12.449902, -13.821163, 
        30.622681}}],
    Line[{{-12.449902, -13.821163, 30.622681},{-12.556144, -13.302152, 
        31.491804}}],
    Line[{{-12.556144, -13.302152, 31.491804},{-12.597899, -12.682308, 
        32.277134}}],
    Line[{{-12.597899, -12.682308, 32.277134},{-12.572384, -11.976201, 
        32.960293}}],
    Line[{{-12.572384, -11.976201, 32.960293},{-12.478643, -11.201887, 
        33.526493}}],
    Line[{{-12.478643, -11.201887, 33.526493},{-12.317656, -10.379872, 
        33.965305}}],
    Line[{{-12.317656, -10.379872, 33.965305},{-12.092327, -9.531863, 
        34.271160}}],
    Line[{{-12.092327, -9.531863, 34.271160},{-11.807358, -8.679479, 
        34.443367}}],
    Line[{{-11.807358, -8.679479, 34.443367},{-11.469003, -7.842962, 
        34.485825}}],
    Line[{{-11.469003, -7.842962, 34.485825},{-11.084741, -7.040238, 
        34.406300}}],
    Line[{{-11.084741, -7.040238, 34.406300},{-10.662901, -6.286142, 
        34.215588}}],
    Line[{{-10.662901, -6.286142, 34.215588},{-10.212267, -5.592037, 
        33.926514}}],
    Line[{{-10.212267, -5.592037, 33.926514},{-9.741693, -4.965725, 
        33.552979}}],
    Line[{{-9.741693, -4.965725, 33.552979},{-9.259768, -4.411643, 
        33.109097}}],
    Line[{{-9.259768, -4.411643, 33.109097},{-8.774539, -3.931237, 
        32.608486}}],
    Line[{{-8.774539, -3.931237, 32.608486},{-8.293301, -3.523478, 
        32.063770}}],
    Line[{{-8.293301, -3.523478, 32.063770},{-7.822456, -3.185400, 
        31.486256}}],
    Line[{{-7.822456, -3.185400, 31.486256},{-7.367447, -2.912662, 
        30.885759}}],
    Line[{{-7.367447, -2.912662, 30.885759},{-6.932737, -2.700042, 
        30.270596}}],
    Line[{{-6.932737, -2.700042, 30.270596},{-6.521843, -2.541864, 
        29.647642}}],
    Line[{{-6.521843, -2.541864, 29.647642},{-6.137401, -2.432347, 
        29.022474}}],
    Line[{{-6.137401, -2.432347, 29.022474},{-5.781249, -2.365864, 
        28.399527}}],
    Line[{{-5.781249, -2.365864, 28.399527},{-5.454532, -2.337136, 
        27.782278}}],
    Line[{{-5.454532, -2.337136, 27.782278},{-5.157805, -2.341354, 
        27.173426}}],
    Line[{{-5.157805, -2.341354, 27.173426},{-4.891138, -2.374251, 
        26.575033}}],
    Line[{{-4.891138, -2.374251, 26.575033},{-4.654217, -2.432139, 
        25.988688}}],
    Line[{{-4.654217, -2.432139, 25.988688},{-4.446435, -2.511903, 
        25.415604}}],
    Line[{{-4.446435, -2.511903, 25.415604},{-4.266972, -2.610985, 
        24.856737}}],
    Line[{{-4.266972, -2.610985, 24.856737},{-4.114868, -2.727355, 
        24.312853}}],
    Line[{{-4.114868, -2.727355, 24.312853},{-3.989088, -2.859466, 
        23.784599}}],
    Line[{{-3.989088, -2.859466, 23.784599},{-3.888566, -3.006204, 
        23.272556}}],
    Line[{{-3.888566, -3.006204, 23.272556},{-3.812254, -3.166853, 
        22.777277}}],
    Line[{{-3.812254, -3.166853, 22.777277},{-3.759151, -3.341037, 
        22.299320}}],
    Line[{{-3.759151, -3.341037, 22.299320},{-3.728330, -3.528686, 
        21.839283}}],
    Line[{{-3.728330, -3.528686, 21.839283},{-3.718958, -3.729990, 
        21.397821}}],
    Line[{{-3.718958, -3.729990, 21.397821},{-3.730314, -3.945365, 
        20.975676}}],
    Line[{{-3.730314, -3.945365, 20.975676},{-3.761792, -4.175416, 
        20.573687}}],
    Line[{{-3.761792, -4.175416, 20.573687},{-3.812908, -4.420906, 
        20.192820}}],
    Line[{{-3.812908, -4.420906, 20.192820},{-3.883305, -4.682724, 
        19.834190}}],
    Line[{{-3.883305, -4.682724, 19.834190},{-3.972750, -4.961853, 
        19.499073}}],
    Line[{{-3.972750, -4.961853, 19.499073},{-4.081127, -5.259342, 
        19.188944}}],
    Line[{{-4.081127, -5.259342, 19.188944},{-4.208433, -5.576269, 
        18.905485}}],
    Line[{{-4.208433, -5.576269, 18.905485},{-4.354770, -5.913707, 
        18.650629}}],
    Line[{{-4.354770, -5.913707, 18.650629},{-4.520329, -6.272680, 
        18.426575}}],
    Line[{{-4.520329, -6.272680, 18.426575},{-4.705375, -6.654114, 
        18.235811}}],
    Line[{{-4.705375, -6.654114, 18.235811},{-4.910230, -7.058784, 
        18.081160}}],
    Line[{{-4.910230, -7.058784, 18.081160},{-5.135249, -7.487235, 
        17.965773}}],
    Line[{{-5.135249, -7.487235, 17.965773},{-5.380791, -7.939712, 
        17.893175}}],
    Line[{{-5.380791, -7.939712, 17.893175},{-5.647185, -8.416057, 
        17.867256}}],
    Line[{{-5.647185, -8.416057, 17.867256},{-5.934689, -8.915594, 
        17.892269}}],
    Line[{{-5.934689, -8.915594, 17.892269},{-6.243446, -9.437010, 
        17.972822}}],
    Line[{{-6.243446, -9.437010, 17.972822},{-6.573417, -9.978192, 
        18.113798}}],
    Line[{{-6.573417, -9.978192, 18.113798},{-6.924327, -10.536081, 
        18.320328}}],
    Line[{{-6.924327, -10.536081, 18.320328},{-7.295579, -11.106490, 
        18.597595}}],
    Line[{{-7.295579, -11.106490, 18.597595},{-7.686175, -11.683927, 
        18.950748}}],
    Line[{{-7.686175, -11.683927, 18.950748},{-8.094619, -12.261441, 
        19.384573}}],
    Line[{{-8.094619, -12.261441, 19.384573},{-8.518817, -12.830466, 
        19.903276}}],
    Line[{{-8.518817, -12.830466, 19.903276},{-8.955980, -13.380741, 
        20.510029}}],
    Line[{{-8.955980, -13.380741, 20.510029},{-9.402526, -13.900303, 
        21.206572}}],
    Line[{{-9.402526, -13.900303, 21.206572},{-9.853990, -14.375582, 
        21.992659}}],
    Line[{{-9.853990, -14.375582, 21.992659},{-10.304978, -14.791647, 
        22.865541}}],
    Line[{{-10.304978, -14.791647, 22.865541},{-10.749145, -15.132663, 
        23.819412}}],
    Line[{{-10.749145, -15.132663, 23.819412},{-11.179206, -15.382468, 
        24.844902}}],
    Line[{{-11.179206, -15.382468, 24.844902},{-11.587062, -15.525476, 
        25.928759}}],
    Line[{{-11.587062, -15.525476, 25.928759},{-11.963974, -15.547661, 
        27.053761}}],
    Line[{{-11.963974, -15.547661, 27.053761},{-12.300805, -15.437716, 
        28.198767}}],
    Line[{{-12.300805, -15.437716, 28.198767},{-12.588406, -15.188243, 
        29.339405}}],
    Line[{{-12.588406, -15.188243, 29.339405},{-12.818018, -14.796745, 
        30.448971}}],
    Line[{{-12.818018, -14.796745, 30.448971},{-12.981752, -14.266472, 
        31.499712}}],
    Line[{{-12.981752, -14.266472, 31.499712},{-13.073075, -13.606767, 
        32.464462}}],
    Line[{{-13.073075, -13.606767, 32.464462},{-13.087257, -12.832932, 
        33.318344}}],
    Line[{{-13.087257, -12.832932, 33.318344},{-13.021733, -11.965501, 
        34.040398}}],
    Line[{{-13.021733, -11.965501, 34.040398},{-12.876346, -11.029013, 
        34.614967}}],
    Line[{{-12.876346, -11.029013, 34.614967},{-12.653411, -10.050402, 
        35.032543}}],
    Line[{{-12.653411, -10.050402, 35.032543},{-12.357636, -9.057196, 
        35.290138}}],
    Line[{{-12.357636, -9.057196, 35.290138},{-11.995855, -8.075722, 
        35.391003}}],
    Line[{{-11.995855, -8.075722, 35.391003},{-11.576632, -7.129561, 
        35.343830}}],
    Line[{{-11.576632, -7.129561, 35.343830},{-11.109783, -6.238461, 
        35.161621}}],
    Line[{{-11.109783, -6.238461, 35.161621},{-10.605856, -5.417612, 
        34.860329}}],
    Line[{{-10.605856, -5.417612, 34.860329},{-10.075605, -4.677460, 
        34.457485}}],
    Line[{{-10.075605, -4.677460, 34.457485},{-9.529538, -4.023916, 
        33.970989}}],
    Line[{{-9.529538, -4.023916, 33.970989},{-8.977522, -3.458863, 
        33.418076}}],
    Line[{{-8.977522, -3.458863, 33.418076},{-8.428499, -2.980851, 
        32.814621}}],
    Line[{{-8.428499, -2.980851, 32.814621},{-7.890292, -2.585870, 
        32.174671}}],
    Line[{{-7.890292, -2.585870, 32.174671},{-7.369502, -2.268110, 
        31.510233}}],
    Line[{{-7.369502, -2.268110, 31.510233},{-6.871494, -2.020647, 
        30.831276}}],
    Line[{{-6.871494, -2.020647, 30.831276},{-6.400432, -1.836028, 
        30.145838}}],
    Line[{{-6.400432, -1.836028, 30.145838},{-5.959365, -1.706723, 
        29.460232}}],
    Line[{{-5.959365, -1.706723, 29.460232},{-5.550349, -1.625483, 
        28.779299}}],
    Line[{{-5.550349, -1.625483, 28.779299},{-5.174579, -1.585546, 
        28.106667}}],
    Line[{{-5.174579, -1.585546, 28.106667},{-4.832519, -1.580813, 
        27.444975}}],
    Line[{{-4.832519, -1.580813, 27.444975},{-4.524046, -1.605910, 
        26.796112}}],
    Line[{{-4.524046, -1.605910, 26.796112},{-4.248573, -1.656217, 
        26.161383}}],
    Line[{{-4.248573, -1.656217, 26.161383},{-4.005164, -1.727856, 
        25.541683}}],
    Line[{{-4.005164, -1.727856, 25.541683},{-3.792640, -1.817650, 
        24.937603}}],
    Line[{{-3.792640, -1.817650, 24.937603},{-3.609662, -1.923075, 
        24.349539}}],
    Line[{{-3.609662, -1.923075, 24.349539},{-3.454808, -2.042197, 
        23.777754}}],
    Line[{{-3.454808, -2.042197, 23.777754},{-3.326632, -2.173610, 
        23.222445}}],
    Line[{{-3.326632, -2.173610, 23.222445},{-3.223716, -2.316374, 
        22.683784}}],
    Line[{{-3.223716, -2.316374, 22.683784},{-3.144709, -2.469958, 
        22.161947}}],
    Line[{{-3.144709, -2.469958, 22.161947},{-3.088352, -2.634182, 
        21.657133}}],
    Line[{{-3.088352, -2.634182, 21.657133},{-3.053508, -2.809178, 
        21.169601}}],
    Line[{{-3.053508, -2.809178, 21.169601},{-3.039170, -2.995340, 
        20.699669}}],
    Line[{{-3.039170, -2.995340, 20.699669},{-3.044479, -3.193291, 
        20.247744}}],
    Line[{{-3.044479, -3.193291, 20.247744},{-3.068725, -3.403849, 
        19.814325}}],
    Line[{{-3.068725, -3.403849, 19.814325},{-3.111351, -3.628004, 
        19.400030}}],
    Line[{{-3.111351, -3.628004, 19.400030},{-3.171957, -3.866885, 
        19.005610}}],
    Line[{{-3.171957, -3.866885, 19.005610},{-3.250293, -4.121747, 
        18.631962}}],
    Line[{{-3.250293, -4.121747, 18.631962},{-3.346256, -4.393946, 
        18.280159}}],
    Line[{{-3.346256, -4.393946, 18.280159},{-3.459888, -4.684915, 
        17.951477}}],
    Line[{{-3.459888, -4.684915, 17.951477},{-3.591366, -4.996147, 
        17.647409}}],
    Line[{{-3.591366, -4.996147, 17.647409},{-3.740993, -5.329164, 
        17.369715}}],
    Line[{{-3.740993, -5.329164, 17.369715},{-3.909190, -5.685493, 
        17.120434}}],
    Line[{{-3.909190, -5.685493, 17.120434},{-4.096479, -6.066618, 
        16.901939}}],
    Line[{{-4.096479, -6.066618, 16.901939},{-4.303473, -6.473946, 
        16.716969}}],
    Line[{{-4.303473, -6.473946, 16.716969},{-4.530853, -6.908737, 
        16.568661}}],
    Line[{{-4.530853, -6.908737, 16.568661},{-4.779344, -7.372037, 
        16.460602}}],
    Line[{{-4.779344, -7.372037, 16.460602},{-5.049690, -7.864592, 
        16.396852}}],
    Line[{{-5.049690, -7.864592, 16.396852},{-5.342612, -8.386716, 
        16.381975}}],
    Line[{{-5.342612, -8.386716, 16.381975},{-5.658774, -8.938190, 
        16.421070}}],
    Line[{{-5.658774, -8.938190, 16.421070},{-5.998714, -9.518064, 
        16.519732}}],
    Line[{{-5.998714, -9.518064, 16.519732},{-6.362793, -10.124496, 
        16.684067}}],
    Line[{{-6.362793, -10.124496, 16.684067},{-6.751108, -10.754519, 
        16.920582}}],
    Line[{{-6.751108, -10.754519, 16.920582},{-7.163398, -11.403810, 
        17.236078}}],
    Line[{{-7.163398, -11.403810, 17.236078},{-7.598944, -12.066424, 
        17.637487}}],
    Line[{{-7.598944, -12.066424, 17.637487},{-8.056437, -12.734568, 
        18.131516}}],
    Line[{{-8.056437, -12.734568, 18.131516},{-8.533854, -13.398293, 
        18.724400}}],
    Line[{{-8.533854, -13.398293, 18.724400},{-9.028306, -14.045417, 
        19.421272}}],
    Line[{{-9.028306, -14.045417, 19.421272},{-9.535901, -14.661291, 
        20.225698}}],
    Line[{{-9.535901, -14.661291, 20.225698},{-10.051614, -15.228994, 
        21.138840}}],
    Line[{{-10.051614, -15.228994, 21.138840},{-10.569181, -15.729492, 
        22.158749}}],
    Line[{{-10.569181, -15.729492, 22.158749},{-11.081049, -16.142200, 
        23.279512}}],
    Line[{{-11.081049, -16.142200, 23.279512},{-11.578366, -16.445763, 
        24.490475}}],
    Line[{{-11.578366, -16.445763, 24.490475},{-12.051110, -16.619257, 
        25.775665}}],
    Line[{{-12.051110, -16.619257, 25.775665},{-12.488303, -16.643631, 
        27.113546}}],
    Line[{{-12.488303, -16.643631, 27.113546},{-12.878345, -16.503359, 
        28.477085}}],
    Line[{{-12.878345, -16.503359, 28.477085},{-13.209510, -16.188263, 
        29.834547}}],
    Line[{{-13.209510, -16.188263, 29.834547},{-13.470545, -15.695010, 
        31.150896}}],
    Line[{{-13.470545, -15.695010, 31.150896},{-13.651332, -15.028361, 
        32.389671}}],
    Line[{{-13.651332, -15.028361, 32.389671},{-13.743584, -14.201674, 
        33.515423}}],
    Line[{{-13.743584, -14.201674, 33.515423},{-13.741480, -13.236617, 
        34.496227}}],
    Line[{{-13.741480, -13.236617, 34.496227},{-13.642177, -12.161974, 
        35.306145}}],
    Line[{{-13.642177, -12.161974, 35.306145},{-13.446106, -11.011638, 
        35.927078}}],
    Line[{{-13.446106, -11.011638, 35.927078},{-13.157027, -9.822077, 
        36.349880}}],
    Line[{{-13.157027, -9.822077, 36.349880},{-12.781828, -8.629593, 
        36.574528}}],
    Line[{{-12.781828, -8.629593, 36.574528},{-12.330082, -7.467818, 
        36.609360}}],
    Line[{{-12.330082, -7.467818, 36.609360},{-11.813437, -6.365593, 
        36.469650}}],
    Line[{{-11.813437, -6.365593, 36.469650},{-11.244887, -5.345654, 
        36.175629}}],
    Line[{{-11.244887, -5.345654, 36.175629},{-10.638035, -4.424017, 
        35.750427}}],
    Line[{{-10.638035, -4.424017, 35.750427},{-10.006384, -3.610101, 
        35.218105}}],
    Line[{{-10.006384, -3.610101, 35.218105},{-9.362761, -2.907372, 
        34.602039}}],
    Line[{{-9.362761, -2.907372, 34.602039},{-8.718847, -2.314348, 
        33.923717}}],
    Line[{{-8.718847, -2.314348, 33.923717},{-8.084883, -1.825740, 
        33.202007}}],
    Line[{{-8.084883, -1.825740, 33.202007},{-7.469491, -1.433617, 
        32.452808}}],
    Line[{{-7.469491, -1.433617, 32.452808},{-6.879634, -1.128441, 
        31.689026}}],
    Line[{{-6.879634, -1.128441, 31.689026},{-6.320662, -0.899939, 
        30.920774}}],
    Line[{{-6.320662, -0.899939, 30.920774},{-5.796432, -0.737778, 
        30.155706}}],
    Line[{{-5.796432, -0.737778, 30.155706},{-5.309467, -0.632056, 
        29.399401}}],
    Line[{{-5.309467, -0.632056, 29.399401},{-4.861142, -0.573618, 
        28.655766}}],
    Line[{{-4.861142, -0.573618, 28.655766},{-4.451875, -0.554253, 
        27.927397}}],
    Line[{{-4.451875, -0.554253, 27.927397},{-4.081311, -0.566778, 
        27.215912}}],
    Line[{{-4.081311, -0.566778, 27.215912},{-3.748496, -0.605049, 
        26.522209}}],
    Line[{{-3.748496, -0.605049, 26.522209},{-3.452032, -0.663924, 
        25.846685}}],
    Line[{{-3.452032, -0.663924, 25.846685},{-3.190209, -0.739194, 
        25.189402}}],
    Line[{{-3.190209, -0.739194, 25.189402},{-2.961122, -0.827493, 
        24.550209}}],
    Line[{{-2.961122, -0.827493, 24.550209},{-2.762763, -0.926211, 
        23.928833}}],
    Line[{{-2.762763, -0.926211, 23.928833},{-2.593100, -1.033392, 
        23.324945}}],
    Line[{{-2.593100, -1.033392, 23.324945},{-2.450135, -1.147647, 
        22.738197}}],
    Line[{{-2.450135, -1.147647, 22.738197},{-2.331955, -1.268078, 
        22.168257}}],
    Line[{{-2.331955, -1.268078, 22.168257},{-2.236762, -1.394198, 
        21.614826}}],
    Line[{{-2.236762, -1.394198, 21.614826},{-2.162899, -1.525869, 
        21.077650}}],
    Line[{{-2.162899, -1.525869, 21.077650},{-2.108872, -1.663251, 
        20.556526}}],
    Line[{{-2.108872, -1.663251, 20.556526},{-2.073353, -1.806752, 
        20.051313}}],
    Line[{{-2.073353, -1.806752, 20.051313},{-2.055192, -1.956993, 
        19.561928}}],
    Line[{{-2.055192, -1.956993, 19.561928},{-2.053416, -2.114775, 
        19.088362}}],
    Line[{{-2.053416, -2.114775, 19.088362},{-2.067229, -2.281060, 
        18.630672}}],
    Line[{{-2.067229, -2.281060, 18.630672},{-2.096008, -2.456948, 
        18.189007}}],
    Line[{{-2.096008, -2.456948, 18.189007},{-2.139301, -2.643665, 
        17.763596}}],
    Line[{{-2.139301, -2.643665, 17.763596},{-2.196822, -2.842555, 
        17.354773}}],
    Line[{{-2.196822, -2.842555, 17.354773},{-2.268445, -3.055070, 
        16.962990}}],
    Line[{{-2.268445, -3.055070, 16.962990},{-2.354198, -3.282771, 
        16.588827}}],
    Line[{{-2.354198, -3.282771, 16.588827},{-2.454262, -3.527315, 
        16.233017}}],
    Line[{{-2.454262, -3.527315, 16.233017},{-2.568963, -3.790462, 
        15.896471}}],
    Line[{{-2.568963, -3.790462, 15.896471},{-2.698765, -4.074063, 
        15.580299}}],
    Line[{{-2.698765, -4.074063, 15.580299},{-2.844273, -4.380057, 
        15.285851}}],
    Line[{{-2.844273, -4.380057, 15.285851},{-3.006218, -4.710459, 
        15.014749}}],
    Line[{{-3.006218, -4.710459, 15.014749},{-3.185461, -5.067347, 
        14.768929}}],
    Line[{{-3.185461, -5.067347, 14.768929},{-3.382977, -5.452836, 
        14.550696}}],
    Line[{{-3.382977, -5.452836, 14.550696},{-3.599853, -5.869048, 
        14.362771}}],
    Line[{{-3.599853, -5.869048, 14.362771},{-3.837270, -6.318063, 
        14.208355}}],
    Line[{{-3.837270, -6.318063, 14.208355},{-4.096493, -6.801857, 
        14.091191}}],
    Line[{{-4.096493, -6.801857, 14.091191},{-4.378846, -7.322228, 
        14.015641}}],
    Line[{{-4.378846, -7.322228, 14.015641},{-4.685680, -7.880661, 
        13.986733}}],
    Line[{{-4.685680, -7.880661, 13.986733},{-5.018348, -8.478226, 
        14.010262}}],
    Line[{{-5.018348, -8.478226, 14.010262},{-5.378138, -9.115349, 
        14.092788}}],
    Line[{{-5.378138, -9.115349, 14.092788},{-5.766227, -9.791648, 
        14.241749}}],
    Line[{{-5.766227, -9.791648, 14.241749},{-6.183580, -10.505602, 
        14.465355}}],
    Line[{{-6.183580, -10.505602, 14.465355},{-6.630875, -11.254276, 
        14.772681}}],
    Line[{{-6.630875, -11.254276, 14.772681},{-7.108346, -12.032928, 
        15.173370}}],
    Line[{{-7.108346, -12.032928, 15.173370},{-7.615660, -12.834567, 
        15.677607}}],
    Line[{{-7.615660, -12.834567, 15.677607},{-8.151721, -13.649560, 
        16.295595}}],
    Line[{{-8.151721, -13.649560, 16.295595},{-8.714472, -14.465157, 
        17.037115}}],
    Line[{{-8.714472, -14.465157, 17.037115},{-9.300673, -15.265112, 
        17.910835}}],
    Line[{{-9.300673, -15.265112, 17.910835},{-9.905672, -16.029444, 
        18.923321}}],
    Line[{{-9.905672, -16.029444, 18.923321},{-10.523158, -16.734350, 
        20.077906}}],
    Line[{{-10.523158, -16.734350, 20.077906},{-11.145005, -17.352592, 
        21.373413}}],
    Line[{{-11.145005, -17.352592, 21.373413},{-11.761112, -17.854145, 
        22.802662}}],
    Line[{{-11.761112, -17.854145, 22.802662},{-12.359394, -18.207590, 
        24.351089}}],
    Line[{{-12.359394, -18.207590, 24.351089},{-12.925958, -18.382011, 
        25.995861}}],
    Line[{{-12.925958, -18.382011, 25.995861},{-13.445390, -18.349558, 
        27.705013}}],
    Line[{{-13.445390, -18.349558, 27.705013},{-13.901367, -18.088301, 
        29.438122}}],
    Line[{{-13.901367, -18.088301, 29.438122},{-14.277451, -17.585352, 
        31.147495}}],
    Line[{{-14.277451, -17.585352, 31.147495},{-14.558078, -16.839439, 
        32.780872}}],
    Line[{{-14.558078, -16.839439, 32.780872},{-14.729689, -15.862761, 
        34.284996}}],
    Line[{{-14.729689, -15.862761, 34.284996},{-14.781851, -14.681360, 
        35.610058}}],
    Line[{{-14.781851, -14.681360, 35.610058},{-14.708230, -13.333811, 
        36.714069}}],
    Line[{{-14.708230, -13.333811, 36.714069},{-14.507253, -11.868367, 
        37.566582}}],
    Line[{{-14.507253, -11.868367, 37.566582},{-14.182398, -10.338830, 
        38.151226}}],
    Line[{{-14.182398, -10.338830, 38.151226},{-13.742005, -8.799740, 
        38.466427}}],
    Line[{{-13.742005, -8.799740, 38.466427},{-13.198662, -7.301784, 
        38.524403}}],
    Line[{{-13.198662, -7.301784, 38.524403},{-12.568237, -5.888066, 
        38.348648}}],
    Line[{{-12.568237, -5.888066, 38.348648},{-11.868724, -4.591687, 
        37.970535}}],
    Line[{{-11.868724, -4.591687, 37.970535},{-11.119020, -3.434784, 
        37.425598}}],
    Line[{{-11.119020, -3.434784, 37.425598},{-10.337817, -2.428888, 
        36.750145}}],
    Line[{{-10.337817, -2.428888, 36.750145},{-9.542658, -1.576252, 
        35.978550}}],
    Line[{{-9.542658, -1.576252, 35.978550},{-8.749259, -0.871736, 
        35.141396}}],
    Line[{{-8.749259, -0.871736, 35.141396},{-7.971077, -0.304879, 
        34.264458}}],
    Line[{{-7.971077, -0.304879, 34.264458},{-7.219118, 0.138145, 
        33.368446}}],
    Line[{{-7.219118, 0.138145, 33.368446},{-6.501927, 0.472859, 32.469204}}],
    
    Line[{{-6.501927, 0.472859, 32.469204},{-5.825732, 0.715180, 31.578287}}],
    
    Line[{{-5.825732, 0.715180, 31.578287},{-5.194674, 0.880483, 30.703651}}],
    
    Line[{{-5.194674, 0.880483, 30.703651},{-4.611086, 0.982998, 29.850407}}],
    
    Line[{{-4.611086, 0.982998, 29.850407},{-4.075799, 1.035464, 29.021490}}],
    
    Line[{{-4.075799, 1.035464, 29.021490},{-3.588429, 1.048988, 28.218269}}],
    
    Line[{{-3.588429, 1.048988, 28.218269},{-3.147650, 1.033037, 27.441027}}],
    
    Line[{{-3.147650, 1.033037, 27.441027},{-2.751439, 0.995522, 26.689333}}],
    
    Line[{{-2.751439, 0.995522, 26.689333},{-2.397282, 0.942935, 25.962332}}],
    
    Line[{{-2.397282, 0.942935, 25.962332},{-2.082348, 0.880505, 25.258940}}],
    
    Line[{{-2.082348, 0.880505, 25.258940},{-1.803634, 0.812369, 24.577984}}],
    
    Line[{{-1.803634, 0.812369, 24.577984},{-1.558073, 0.741732, 23.918289}}],
    
    Line[{{-1.558073, 0.741732, 23.918289},{-1.342625, 0.671021, 23.278736}}],
    
    Line[{{-1.342625, 0.671021, 23.278736},{-1.154340, 0.602020, 22.658279}}],
    
    Line[{{-1.154340, 0.602020, 22.658279},{-0.990407, 0.535988, 22.055973}}],
    
    Line[{{-0.990407, 0.535988, 22.055973},{-0.848180, 0.473767, 21.470955}}],
    
    Line[{{-0.848180, 0.473767, 21.470955},{-0.725205, 0.415868, 20.902460}}],
    
    Line[{{-0.725205, 0.415868, 20.902460},{-0.619223, 0.362544, 20.349796}}],
    
    Line[{{-0.619223, 0.362544, 20.349796},{-0.528179, 0.313856, 19.812342}}],
    
    Line[{{-0.528179, 0.313856, 19.812342},{-0.450212, 0.269719, 19.289537}}],
    
    Line[{{-0.450212, 0.269719, 19.289537},{-0.383653, 0.229946, 18.780872}}],
    
    Line[{{-0.383653, 0.229946, 18.780872},{-0.327013, 0.194279, 18.285875}}],
    
    Line[{{-0.327013, 0.194279, 18.285875},{-0.278971, 0.162414, 17.804117}}],
    
    Line[{{-0.278971, 0.162414, 17.804117},{-0.238363, 0.134025, 17.335192}}],
    
    Line[{{-0.238363, 0.134025, 17.335192},{-0.204168, 0.108773, 16.878719}}],
    
    Line[{{-0.204168, 0.108773, 16.878719},{-0.175491, 0.086322, 16.434343}}],
    
    Line[{{-0.175491, 0.086322, 16.434343},{-0.151559, 0.066342, 16.001720}}],
    
    Line[{{-0.151559, 0.066342, 16.001720},{-0.131699, 0.048520, 15.580524}}],
    
    Line[{{-0.131699, 0.048520, 15.580524},{-0.115333, 0.032560, 15.170445}}],
    
    Line[{{-0.115333, 0.032560, 15.170445},{-0.101965, 0.018183, 14.771180}}],
    
    Line[{{-0.101965, 0.018183, 14.771180},{-0.091171, 0.005133, 14.382438}}],
    
    Line[{{-0.091171, 0.005133, 14.382438},{-0.082592, -0.006829, 
        14.003938}}],
    Line[{{-0.082592, -0.006829, 14.003938},{-0.075924, -0.017922, 
        13.635408}}],
    Line[{{-0.075924, -0.017922, 13.635408},{-0.070913, -0.028350, 
        13.276584}}],
    Line[{{-0.070913, -0.028350, 13.276584},{-0.067347, -0.038299, 
        12.927209}}],
    Line[{{-0.067347, -0.038299, 12.927209},{-0.065051, -0.047944, 
        12.587033}}],
    Line[{{-0.065051, -0.047944, 12.587033},{-0.063883, -0.057447, 
        12.255816}}],
    Line[{{-0.063883, -0.057447, 12.255816},{-0.063730, -0.066962, 
        11.933321}}],
    Line[{{-0.063730, -0.066962, 11.933321},{-0.064504, -0.076636, 
        11.619319}}],
    Line[{{-0.064504, -0.076636, 11.619319},{-0.066138, -0.086610, 
        11.313587}}],
    Line[{{-0.066138, -0.086610, 11.313587},{-0.068586, -0.097024, 
        11.015910}}],
    Line[{{-0.068586, -0.097024, 11.015910},{-0.071819, -0.108016, 
        10.726077}}],
    Line[{{-0.071819, -0.108016, 10.726077},{-0.075825, -0.119725, 
        10.443884}}],
    Line[{{-0.075825, -0.119725, 10.443884},{-0.080603, -0.132296, 
        10.169131}}],
    Line[{{-0.080603, -0.132296, 10.169131},{-0.086172, -0.145878, 
        9.901626}}],
    Line[{{-0.086172, -0.145878, 9.901626},{-0.092558, -0.160627, 9.641181}}],
    
    Line[{{-0.092558, -0.160627, 9.641181},{-0.099803, -0.176711, 9.387616}}],
    
    Line[{{-0.099803, -0.176711, 9.387616},{-0.107961, -0.194310, 9.140754}}],
    
    Line[{{-0.107961, -0.194310, 9.140754},{-0.117099, -0.213617, 8.900424}}],
    
    Line[{{-0.117099, -0.213617, 8.900424},{-0.127295, -0.234846, 8.666464}}],
    
    Line[{{-0.127295, -0.234846, 8.666464},{-0.138644, -0.258227, 8.438713}}],
    
    Line[{{-0.138644, -0.258227, 8.438713},{-0.151253, -0.284017, 8.217020}}],
    
    Line[{{-0.151253, -0.284017, 8.217020},{-0.165243, -0.312496, 8.001240}}],
    
    Line[{{-0.165243, -0.312496, 8.001240},{-0.180756, -0.343976, 7.791233}}],
    
    Line[{{-0.180756, -0.343976, 7.791233},{-0.197946, -0.378802, 7.586867}}],
    
    Line[{{-0.197946, -0.378802, 7.586867},{-0.216993, -0.417356, 7.388020}}],
    
    Line[{{-0.216993, -0.417356, 7.388020},{-0.238093, -0.460066, 7.194575}}],
    
    Line[{{-0.238093, -0.460066, 7.194575},{-0.261470, -0.507404, 7.006428}}],
    
    Line[{{-0.261470, -0.507404, 7.006428},{-0.287373, -0.559897, 6.823486}}],
    
    Line[{{-0.287373, -0.559897, 6.823486},{-0.316079, -0.618135, 6.645667}}],
    
    Line[{{-0.316079, -0.618135, 6.645667},{-0.347900, -0.682771, 6.472904}}],
    
    Line[{{-0.347900, -0.682771, 6.472904},{-0.383183, -0.754536, 6.305149}}],
    
    Line[{{-0.383183, -0.754536, 6.305149},{-0.422315, -0.834244, 6.142374}}],
    
    Line[{{-0.422315, -0.834244, 6.142374},{-0.465729, -0.922804, 5.984574}}],
    
    Line[{{-0.465729, -0.922804, 5.984574},{-0.513909, -1.021229, 5.831776}}],
    
    Line[{{-0.513909, -1.021229, 5.831776},{-0.567394, -1.130648, 5.684041}}],
    
    Line[{{-0.567394, -1.130648, 5.684041},{-0.626784, -1.252322, 5.541473}}],
    
    Line[{{-0.626784, -1.252322, 5.541473},{-0.692750, -1.387655, 5.404230}}],
    
    Line[{{-0.692750, -1.387655, 5.404230},{-0.766042, -1.538214, 5.272534}}],
    
    Line[{{-0.766042, -1.538214, 5.272534},{-0.847494, -1.705741, 5.146687}}],
    
    Line[{{-0.847494, -1.705741, 5.146687},{-0.938037, -1.892179, 5.027087}}],
    
    Line[{{-0.938037, -1.892179, 5.027087},{-1.038707, -2.099684, 4.914249}}],
    
    Line[{{-1.038707, -2.099684, 4.914249},{-1.150661, -2.330658, 4.808846}}],
    
    Line[{{-1.150661, -2.330658, 4.808846},{-1.275183, -2.587756, 4.711715}}],
    
    Line[{{-1.275183, -2.587756, 4.711715},{-1.413704, -2.873924, 4.623936}}],
    
    Line[{{-1.413704, -2.873924, 4.623936},{-1.567814, -3.192412, 4.546851}}],
    
    Line[{{-1.567814, -3.192412, 4.546851},{-1.739274, -3.546795, 4.482156}}],
    
    Line[{{-1.739274, -3.546795, 4.482156},{-1.930038, -3.940994, 4.431958}}],
    
    Line[{{-1.930038, -3.940994, 4.431958},{-2.142260, -4.379286, 4.398878}}],
    
    Line[{{-2.142260, -4.379286, 4.398878},{-2.378316, -4.866292, 4.386192}}],
    
    Line[{{-2.378316, -4.866292, 4.386192},{-2.640813, -5.406990, 4.397920}}],
    
    Line[{{-2.640813, -5.406990, 4.397920},{-2.932595, -6.006638, 4.439059}}],
    
    Line[{{-2.932595, -6.006638, 4.439059},{-3.256752, -6.670734, 4.515745}}],
    
    Line[{{-3.256752, -6.670734, 4.515745},{-3.616604, -7.404875, 4.635508}}],
    
    Line[{{-3.616604, -7.404875, 4.635508},{-4.015690, -8.214587, 4.807533}}],
    
    Line[{{-4.015690, -8.214587, 4.807533},{-4.457725, -9.105047, 5.042975}}],
    
    Line[{{-4.457725, -9.105047, 5.042975},{-4.946527, -10.080690, 
        5.355287}}],
    Line[{{-4.946527, -10.080690, 5.355287},{-5.485918, -11.144649, 
        5.760549}}],
    Line[{{-5.485918, -11.144649, 5.760549},{-6.079559, -12.298023, 
        6.277769}}],
    Line[{{-6.079559, -12.298023, 6.277769},{-6.730733, -13.538885, 
        6.929094}}],
    Line[{{-6.730733, -13.538885, 6.929094},{-7.442030, -14.861002, 
        7.739841}}],
    Line[{{-7.442030, -14.861002, 7.739841},{-8.214928, -16.252260, 
        8.738218}}],
    Line[{{-8.214928, -16.252260, 8.738218},{-9.049254, -17.692793, 
        9.954578}}],
    Line[{{-9.049254, -17.692793, 9.954578},{-9.942502, -19.152889, 
        11.419927}}],
    Line[{{-9.942502, -19.152889, 11.419927},{-10.889013, -20.590925, 
        13.163499}}],
    Line[{{-10.889013, -20.590925, 13.163499},{-11.879060, -21.951653, 
        15.209123}}],
    Line[{{-11.879060, -21.951653, 15.209123},{-12.897887, -23.165472, 
        17.570244}}],
    Line[{{-12.897887, -23.165472, 17.570244},{-13.924858, -24.149433, 
        20.243780}}],
    Line[{{-13.924858, -24.149433, 20.243780},{-14.932895, -24.810913, 
        23.203308}}],
    Line[{{-14.932895, -24.810913, 23.203308},{-15.888487, -25.054804, 
        26.392748}}],
    Line[{{-15.888487, -25.054804, 26.392748},{-16.752569, -24.794441, 
        29.722446}}],
    Line[{{-16.752569, -24.794441, 29.722446},{-17.482512, -23.965496, 
        33.069805}}],
    Line[{{-17.482512, -23.965496, 33.069805},{-18.035294, -22.540661, 
        36.286404}}],
    Line[{{-18.035294, -22.540661, 36.286404},{-18.371693, -20.541487, 
        39.212406}}],
    Line[{{-18.371693, -20.541487, 39.212406},{-18.460869, -18.043568, 
        41.696507}}],
    Line[{{-18.460869, -18.043568, 41.696507},{-18.284573, -15.171644, 
        43.617805}}],
    Line[{{-18.284573, -15.171644, 43.617805},{-17.839993, -12.084900, 
        44.903847}}],
    Line[{{-17.839993, -12.084900, 44.903847},{-17.140507, -8.954838, 
        45.539845}}],
    Line[{{-17.140507, -8.954838, 45.539845},{-16.214193, -5.941763, 
        45.566990}}],
    Line[{{-16.214193, -5.941763, 45.566990},{-15.100348, -3.175512, 
        45.070442}}],
    Line[{{-15.100348, -3.175512, 45.070442},{-13.844930, -0.744353, 
        44.161793}}],
    Line[{{-13.844930, -0.744353, 44.161793},{-12.495796, 1.307005, 
        42.960484}}],
    Line[{{-12.495796, 1.307005, 42.960484},{-11.098598, 2.972065, 
        41.578625}}],
    Line[{{-11.098598, 2.972065, 41.578625},{-9.693786, 4.273054, 
        40.111130}}],
    Line[{{-9.693786, 4.273054, 40.111130},{-8.314879, 5.250385, 38.631397}}],
    
    Line[{{-8.314879, 5.250385, 38.631397},{-6.987875, 5.953286, 37.191280}}],
    
    Line[{{-6.987875, 5.953286, 37.191280},{-5.731474, 6.432728, 35.823795}}],
    
    Line[{{-5.731474, 6.432728, 35.823795},{-4.557864, 6.736760, 34.546955}}],
    
    Line[{{-4.557864, 6.736760, 34.546955},{-3.473753, 6.907977, 33.367844}}],
    
    Line[{{-3.473753, 6.907977, 33.367844},{-2.481462, 6.982481, 32.286152}}],
    
    Line[{{-2.481462, 6.982481, 32.286152},{-1.579976, 6.989880, 31.297041}}],
    
    Line[{{-1.579976, 6.989880, 31.297041},{-0.765848, 6.953832, 30.393259}}],
    
    Line[{{-0.765848, 6.953832, 30.393259},{-0.033969, 6.892845, 29.566601}}],
    
    Line[{{-0.033969, 6.892845, 29.566601},{0.621836, 6.821131, 28.808865}}],
    Line[{{0.621836, 6.821131, 28.808865},{1.208328, 6.749418, 28.112398}}],
    Line[{{1.208328, 6.749418, 28.112398},{1.732509, 6.685667, 27.470407}}],
    Line[{{1.732509, 6.685667, 27.470407},{2.201363, 6.635664, 26.877071}}],
    Line[{{2.201363, 6.635664, 26.877071},{2.621673, 6.603516, 26.327545}}],
    Line[{{2.621673, 6.603516, 26.327545},{2.999903, 6.592039, 25.817915}}],
    Line[{{2.999903, 6.592039, 25.817915},{3.342123, 6.603070, 25.345108}}],
    Line[{{3.342123, 6.603070, 25.345108},{3.653958, 6.637703, 24.906788}}],
    Line[{{3.653958, 6.637703, 24.906788},{3.940577, 6.696475, 24.501276}}],
    Line[{{3.940577, 6.696475, 24.501276},{4.206686, 6.779506, 24.127445}}],
    Line[{{4.206686, 6.779506, 24.127445},{4.456537, 6.886604, 23.784651}}],
    Line[{{4.456537, 6.886604, 23.784651},{4.693950, 7.017334, 23.472660}}],
    Line[{{4.693950, 7.017334, 23.472660},{4.922328, 7.171070, 23.191593}}],
    Line[{{4.922328, 7.171070, 23.191593},{5.144684, 7.347029, 22.941879}}],
    Line[{{5.144684, 7.347029, 22.941879},{5.363663, 7.544281, 22.724215}}],
    Line[{{5.363663, 7.544281, 22.724215},{5.581561, 7.761750, 22.539526}}],
    Line[{{5.581561, 7.761750, 22.539526},{5.800347, 7.998210, 22.388931}}],
    Line[{{5.800347, 7.998210, 22.388931},{6.021678, 8.252257, 22.273724}}],
    Line[{{6.021678, 8.252257, 22.273724},{6.246909, 8.522279, 22.195320}}],
    Line[{{6.246909, 8.522279, 22.195320},{6.477102, 8.806432, 22.155235}}],
    Line[{{6.477102, 8.806432, 22.155235},{6.713030, 9.102592, 22.155031}}],
    Line[{{6.713030, 9.102592, 22.155031},{6.955173, 9.408318, 22.196270}}],
    Line[{{6.955173, 9.408318, 22.196270},{7.203719, 9.720809, 22.280451}}],
    Line[{{7.203719, 9.720809, 22.280451},{7.458550, 10.036871, 22.408941}}],
    Line[{{7.458550, 10.036871, 22.408941},{7.719236, 10.352882, 22.582874}}],
    
    Line[{{7.719236, 10.352882, 22.582874},{7.985023, 10.664773, 22.803087}}],
    
    Line[{{7.985023, 10.664773, 22.803087},{8.254818, 10.968026, 23.069967}}],
    
    Line[{{8.254818, 10.968026, 23.069967},{8.527183, 11.257702, 23.383360}}],
    
    Line[{{8.527183, 11.257702, 23.383360},{8.800322, 11.528443, 23.742439}}],
    
    Line[{{8.800322, 11.528443, 23.742439},{9.072092, 11.774627, 24.145557}}],
    
    Line[{{9.072092, 11.774627, 24.145557},{9.340002, 11.990401, 24.590149}}],
    
    Line[{{9.340002, 11.990401, 24.590149},{9.601238, 12.169871, 25.072601}}],
    
    Line[{{9.601238, 12.169871, 25.072601},{9.852708, 12.307305, 25.588202}}],
    
    Line[{{9.852708, 12.307305, 25.588202},{
      10.091069, 12.397307, 26.131069}}],
    Line[{{10.091069, 12.397307, 26.131069},{
      10.312819, 12.435106, 26.694181}}],
    Line[{{10.312819, 12.435106, 26.694181},{
      10.514376, 12.416818, 27.269464}}],
    Line[{{10.514376, 12.416818, 27.269464},{
      10.692181, 12.339679, 27.847916}}],
    Line[{{10.692181, 12.339679, 27.847916},{
      10.842811, 12.202309, 28.419815}}],
    Line[{{10.842811, 12.202309, 28.419815},{
      10.963117, 12.004888, 28.975054}}],
    Line[{{10.963117, 12.004888, 28.975054},{
      11.050347, 11.749259, 29.503456}}],
    Line[{{11.050347, 11.749259, 29.503456},{
      11.102269, 11.439026, 29.995121}}],
    Line[{{11.102269, 11.439026, 29.995121},{
      11.117286, 11.079399, 30.440889}}],
    Line[{{11.117286, 11.079399, 30.440889},{
      11.094524, 10.677095, 30.832659}}],
    Line[{{11.094524, 10.677095, 30.832659},{
      11.033894, 10.240047, 31.163719}}],
    Line[{{11.033894, 10.240047, 31.163719},{
      10.936110, 9.777089, 31.428999}}],
    Line[{{10.936110, 9.777089, 31.428999},{10.802696, 9.297565, 31.625219}}],
    
    Line[{{10.802696, 9.297565, 31.625219},{10.635924, 8.810924, 31.750937}}],
    
    Line[{{10.635924, 8.810924, 31.750937},{10.438741, 8.326327, 31.806488}}],
    
    Line[{{10.438741, 8.326327, 31.806488},{10.214650, 7.852313, 31.793825}}],
    
    Line[{{10.214650, 7.852313, 31.793825},{9.967600, 7.396504, 31.716309}}],
    Line[{{9.967600, 7.396504, 31.716309},{9.701830, 6.965412, 31.578430}}],
    Line[{{9.701830, 6.965412, 31.578430},{9.421741, 6.564316, 31.385523}}],
    Line[{{9.421741, 6.564316, 31.385523},{9.131753, 6.197228, 31.143459}}],
    Line[{{9.131753, 6.197228, 31.143459},{8.836190, 5.866927, 30.858387}}],
    Line[{{8.836190, 5.866927, 30.858387},{8.539172, 5.575053, 30.536491}}],
    Line[{{8.539172, 5.575053, 30.536491},{8.244532, 5.322241, 30.183804}}],
    Line[{{8.244532, 5.322241, 30.183804},{7.955756, 5.108278, 29.806055}}],
    Line[{{7.955756, 5.108278, 29.806055},{7.675948, 4.932272, 29.408583}}],
    Line[{{7.675948, 4.932272, 29.408583},{7.407799, 4.792819, 28.996267}}],
    Line[{{7.407799, 4.792819, 28.996267},{7.153596, 4.688155, 28.573509}}],
    Line[{{7.153596, 4.688155, 28.573509},{6.915228, 4.616298, 28.144241}}],
    Line[{{6.915228, 4.616298, 28.144241},{6.694210, 4.575165, 27.711943}}],
    Line[{{6.694210, 4.575165, 27.711943},{6.491714, 4.562665, 27.279686}}],
    Line[{{6.491714, 4.562665, 27.279686},{6.308602, 4.576776, 26.850176}}],
    Line[{{6.308602, 4.576776, 26.850176},{6.145471, 4.615601, 26.425802}}],
    Line[{{6.145471, 4.615601, 26.425802},{6.002685, 4.677407, 26.008686}}],
    Line[{{6.002685, 4.677407, 26.008686},{5.880419, 4.760647, 25.600733}}],
    Line[{{5.880419, 4.760647, 25.600733},{5.778692, 4.863969, 25.203678}}],
    Line[{{5.778692, 4.863969, 25.203678},{5.697404, 4.986222, 24.819122}}],
    Line[{{5.697404, 4.986222, 24.819122},{5.636364, 5.126437, 24.448576}}],
    Line[{{5.636364, 5.126437, 24.448576},{5.595315, 5.283831, 24.093491}}],
    Line[{{5.595315, 5.283831, 24.093491},{5.573957, 5.457772, 23.755285}}],
    Line[{{5.573957, 5.457772, 23.755285},{5.571966, 5.647765, 23.435379}}],
    Line[{{5.571966, 5.647765, 23.435379},{5.589006, 5.853421, 23.135204}}],
    Line[{{5.589006, 5.853421, 23.135204},{5.624743, 6.074434, 22.856239}}],
    Line[{{5.624743, 6.074434, 22.856239},{5.678844, 6.310543, 22.600016}}],
    Line[{{5.678844, 6.310543, 22.600016},{5.750988, 6.561502, 22.368135}}],
    Line[{{5.750988, 6.561502, 22.368135},{5.840859, 6.827044, 22.162283}}],
    Line[{{5.840859, 6.827044, 22.162283},{5.948140, 7.106837, 21.984230}}],
    Line[{{5.948140, 7.106837, 21.984230},{6.072513, 7.400451, 21.835844}}],
    Line[{{6.072513, 7.400451, 21.835844},{6.213637, 7.707304, 21.719078}}],
    Line[{{6.213637, 7.707304, 21.719078},{6.371145, 8.026618, 21.635973}}],
    Line[{{6.371145, 8.026618, 21.635973},{6.544615, 8.357372, 21.588633}}],
    Line[{{6.544615, 8.357372, 21.588633},{6.733554, 8.698240, 21.579208}}],
    Line[{{6.733554, 8.698240, 21.579208},{6.937376, 9.047548, 21.609859}}],
    Line[{{6.937376, 9.047548, 21.609859},{7.155371, 9.403209, 21.682713}}],
    Line[{{7.155371, 9.403209, 21.682713},{7.386673, 9.762678, 21.799788}}],
    Line[{{7.386673, 9.762678, 21.799788},{7.630236, 10.122901, 21.962936}}],
    Line[{{7.630236, 10.122901, 21.962936},{7.884796, 10.480286, 22.173742}}],
    
    Line[{{7.884796, 10.480286, 22.173742},{8.148838, 10.830665, 22.433407}}],
    
    Line[{{8.148838, 10.830665, 22.433407},{8.420568, 11.169296, 22.742630}}],
    
    Line[{{8.420568, 11.169296, 22.742630},{8.697886, 11.490900, 23.101463}}],
    
    Line[{{8.697886, 11.490900, 23.101463},{8.978364, 11.789689, 23.509161}}],
    
    Line[{{8.978364, 11.789689, 23.509161},{9.259230, 12.059462, 23.964029}}],
    
    Line[{{9.259230, 12.059462, 23.964029},{9.537379, 12.293781, 24.463276}}],
    
    Line[{{9.537379, 12.293781, 24.463276},{9.809378, 12.486101, 25.002886}}],
    
    Line[{{9.809378, 12.486101, 25.002886},{
      10.071498, 12.630023, 25.577518}}],
    Line[{{10.071498, 12.630023, 25.577518},{
      10.319790, 12.719608, 26.180487}}],
    Line[{{10.319790, 12.719608, 26.180487},{
      10.550133, 12.749610, 26.803753}}],
    Line[{{10.550133, 12.749610, 26.803753},{
      10.758348, 12.715847, 27.438015}}],
    Line[{{10.758348, 12.715847, 27.438015},{
      10.940333, 12.615518, 28.072979}}],
    Line[{{10.940333, 12.615518, 28.072979},{
      11.092174, 12.447441, 28.697521}}],
    Line[{{11.092174, 12.447441, 28.697521},{
      11.210306, 12.212335, 29.300110}}],
    Line[{{11.210306, 12.212335, 29.300110},{
      11.291678, 11.912873, 29.869270}}],
    Line[{{11.291678, 11.912873, 29.869270},{
      11.333872, 11.553742, 30.393982}}],
    Line[{{11.333872, 11.553742, 30.393982},{
      11.335243, 11.141527, 30.864180}}],
    Line[{{11.335243, 11.141527, 30.864180},{
      11.295012, 10.684473, 31.271191}}],
    Line[{{11.295012, 10.684473, 31.271191},{
      11.213324, 10.192131, 31.608088}}],
    Line[{{11.213324, 10.192131, 31.608088},{
      11.091266, 9.674929, 31.869942}}],
    Line[{{11.091266, 9.674929, 31.869942},{10.930834, 9.143700, 32.053959}}],
    
    Line[{{10.930834, 9.143700, 32.053959},{10.734871, 8.609205, 32.159500}}],
    
    Line[{{10.734871, 8.609205, 32.159500},{10.506949, 8.081656, 32.187927}}],
    
    Line[{{10.506949, 8.081656, 32.187927},{10.251230, 7.570339, 32.142387}}],
    
    Line[{{10.251230, 7.570339, 32.142387},{9.972302, 7.083330, 32.027504}}],
    Line[{{9.972302, 7.083330, 32.027504},{9.675023, 6.627288, 31.849031}}],
    Line[{{9.675023, 6.627288, 31.849031},{9.364347, 6.207381, 31.613497}}],
    Line[{{9.364347, 6.207381, 31.613497},{9.045179, 5.827287, 31.327843}}],
    Line[{{9.045179, 5.827287, 31.327843},{8.722236, 5.489285, 30.999144}}],
    Line[{{8.722236, 5.489285, 30.999144},{8.399941, 5.194405, 30.634333}}],
    Line[{{8.399941, 5.194405, 30.634333},{8.082345, 4.942607, 30.240026}}],
    Line[{{8.082345, 4.942607, 30.240026},{7.773061, 4.732990, 29.822372}}],
    Line[{{7.773061, 4.732990, 29.822372},{7.475242, 4.563991, 29.386986}}],
    Line[{{7.475242, 4.563991, 29.386986},{7.191568, 4.433583, 28.938900}}],
    Line[{{7.191568, 4.433583, 28.938900},{6.924254, 4.339447, 28.482569}}],
    Line[{{6.924254, 4.339447, 28.482569},{6.675077, 4.279117, 28.021902}}],
    Line[{{6.675077, 4.279117, 28.021902},{6.445407, 4.250108, 27.560299}}],
    Line[{{6.445407, 4.250108, 27.560299},{6.236252, 4.250007, 27.100716}}],
    Line[{{6.236252, 4.250007, 27.100716},{6.048299, 4.276545, 26.645716}}],
    Line[{{6.048299, 4.276545, 26.645716},{5.881964, 4.327648, 26.197535}}],
    Line[{{5.881964, 4.327648, 26.197535},{5.737435, 4.401466, 25.758144}}],
    Line[{{5.737435, 4.401466, 25.758144},{5.614719, 4.496388, 25.329298}}],
    Line[{{5.614719, 4.496388, 25.329298},{5.513681, 4.611048, 24.912590}}],
    Line[{{5.513681, 4.611048, 24.912590},{5.434079, 4.744313, 24.509497}}],
    Line[{{5.434079, 4.744313, 24.509497},{5.375599, 4.895277, 24.121414}}],
    Line[{{5.375599, 4.895277, 24.121414},{5.337880, 5.063232, 23.749693}}],
    Line[{{5.337880, 5.063232, 23.749693},{5.320534, 5.247653, 23.395678}}],
    Line[{{5.320534, 5.247653, 23.395678},{5.323172, 5.448165, 23.060719}}],
    Line[{{5.323172, 5.448165, 23.060719},{5.345410, 5.664518, 22.746210}}],
    Line[{{5.345410, 5.664518, 22.746210},{5.386882, 5.896551, 22.453606}}],
    Line[{{5.386882, 5.896551, 22.453606},{5.447244, 6.144162, 22.184433}}],
    Line[{{5.447244, 6.144162, 22.184433},{5.526177, 6.407268, 21.940317}}],
    Line[{{5.526177, 6.407268, 21.940317},{5.623384, 6.685768, 21.722986}}],
    Line[{{5.623384, 6.685768, 21.722986},{5.738583, 6.979502, 21.534285}}],
    Line[{{5.738583, 6.979502, 21.534285},{5.871501, 7.288208, 21.376181}}],
    Line[{{5.871501, 7.288208, 21.376181},{6.021857, 7.611466, 21.250763}}],
    Line[{{6.021857, 7.611466, 21.250763},{6.189348, 7.948656, 21.160242}}],
    Line[{{6.189348, 7.948656, 21.160242},{6.373629, 8.298890, 21.106928}}],
    Line[{{6.373629, 8.298890, 21.106928},{6.574287, 8.660965, 21.093222}}],
    Line[{{6.574287, 8.660965, 21.093222},{6.790818, 9.033288, 21.121567}}],
    Line[{{6.790818, 9.033288, 21.121567},{7.022591, 9.413817, 21.194427}}],
    Line[{{7.022591, 9.413817, 21.194427},{7.268818, 9.800005, 21.314180}}],
    Line[{{7.268818, 9.800005, 21.314180},{7.528514, 10.188713, 21.483103}}],
    Line[{{7.528514, 10.188713, 21.483103},{7.800464, 10.576207, 21.703188}}],
    
    Line[{{7.800464, 10.576207, 21.703188},{8.083173, 10.958048, 21.976105}}],
    
    Line[{{8.083173, 10.958048, 21.976105},{8.374845, 11.329165, 22.302982}}],
    
    Line[{{8.374845, 11.329165, 22.302982},{8.673322, 11.683748, 22.684305}}],
    
    Line[{{8.673322, 11.683748, 22.684305},{8.976087, 12.015426, 23.119688}}],
    
    Line[{{8.976087, 12.015426, 23.119688},{9.280213, 12.317245, 23.607714}}],
    
    Line[{{9.280213, 12.317245, 23.607714},{9.582382, 12.581880, 24.145750}}],
    
    Line[{{9.582382, 12.581880, 24.145750},{9.878876, 12.801805, 24.729763}}],
    
    Line[{{9.878876, 12.801805, 24.729763},{
      10.165615, 12.969569, 25.354189}}],
    Line[{{10.165615, 12.969569, 25.354189},{
      10.438223, 13.078113, 26.011900}}],
    Line[{{10.438223, 13.078113, 26.011900},{
      10.692089, 13.121127, 26.694099}}],
    Line[{{10.692089, 13.121127, 26.694099},{
      10.922505, 13.093447, 27.390551}}],
    Line[{{10.922505, 13.093447, 27.390551},{
      11.124782, 12.991445, 28.089643}}],
    Line[{{11.124782, 12.991445, 28.089643},{
      11.294425, 12.813399, 28.778805}}],
    Line[{{11.294425, 12.813399, 28.778805},{
      11.427307, 12.559735, 29.444881}}],
    Line[{{11.427307, 12.559735, 29.444881},{
      11.519847, 12.233247, 30.074659}}],
    Line[{{11.519847, 12.233247, 30.074659},{
      11.569183, 11.839118, 30.655424}}],
    Line[{{11.569183, 11.839118, 30.655424},{
      11.573336, 11.384797, 31.175545}}],
    Line[{{11.573336, 11.384797, 31.175545},{
      11.531318, 10.879738, 31.625002}}],
    Line[{{11.531318, 10.879738, 31.625002},{
      11.443217, 10.334968, 31.995838}}],
    Line[{{11.443217, 10.334968, 31.995838},{
      11.310221, 9.762570, 32.282482}}],
    Line[{{11.310221, 9.762570, 32.282482},{11.134576, 9.175089, 32.481903}}],
    
    Line[{{11.134576, 9.175089, 32.481903},{10.919511, 8.584931, 32.593601}}],
    
    Line[{{10.919511, 8.584931, 32.593601},{10.669096, 8.003823, 32.619450}}],
    
    Line[{{10.669096, 8.003823, 32.619450},{10.388079, 7.442331, 32.563389}}],
    
    Line[{{10.388079, 7.442331, 32.563389},{10.081692, 6.909522, 32.431061}}],
    
    Line[{{10.081692, 6.909522, 32.431061},{9.755447, 6.412743, 32.229351}}],
    Line[{{9.755447, 6.412743, 32.229351},{9.414948, 5.957542, 31.965956}}],
    Line[{{9.414948, 5.957542, 31.965956},{9.065703, 5.547699, 31.648966}}],
    Line[{{9.065703, 5.547699, 31.648966},{8.712979, 5.185365, 31.286503}}],
    Line[{{8.712979, 5.185365, 31.286503},{8.361671, 4.871237, 30.886433}}],
    Line[{{8.361671, 4.871237, 30.886433},{8.016218, 4.604826, 30.456146}}],
    Line[{{8.016218, 4.604826, 30.456146},{7.680541, 4.384692, 30.002430}}],
    Line[{{7.680541, 4.384692, 30.002430},{7.358014, 4.208689, 29.531372}}],
    Line[{{7.358014, 4.208689, 29.531372},{7.051463, 4.074201, 29.048353}}],
    Line[{{7.051463, 4.074201, 29.048353},{6.763180, 3.978344, 28.558060}}],
    Line[{{6.763180, 3.978344, 28.558060},{6.494958, 3.918135, 28.064526}}],
    Line[{{6.494958, 3.918135, 28.064526},{6.248139, 3.890624, 27.571207}}],
    Line[{{6.248139, 3.890624, 27.571207},{6.023659, 3.892997, 27.081049}}],
    Line[{{6.023659, 3.892997, 27.081049},{5.822108, 3.922649, 26.596561}}],
    Line[{{5.822108, 3.922649, 26.596561},{5.643785, 3.977237, 26.119896}}],
    Line[{{5.643785, 3.977237, 26.119896},{5.488751, 4.054699, 25.652920}}],
    Line[{{5.488751, 4.054699, 25.652920},{5.356877, 4.153274, 25.197268}}],
    Line[{{5.356877, 4.153274, 25.197268},{5.247897, 4.271492, 24.754414}}],
    Line[{{5.247897, 4.271492, 24.754414},{5.161441, 4.408170, 24.325706}}],
    Line[{{5.161441, 4.408170, 24.325706},{5.097076, 4.562387, 23.912424}}],
    Line[{{5.097076, 4.562387, 23.912424},{5.054334, 4.733459, 23.515802}}],
    Line[{{5.054334, 4.733459, 23.515802},{5.032736, 4.920922, 23.137074}}],
    Line[{{5.032736, 4.920922, 23.137074},{5.031816, 5.124488, 22.777491}}],
    Line[{{5.031816, 5.124488, 22.777491},{5.051130, 5.344025, 22.438358}}],
    Line[{{5.051130, 5.344025, 22.438358},{5.090271, 5.579515, 22.121052}}],
    Line[{{5.090271, 5.579515, 22.121052},{5.148874, 5.831023, 21.827040}}],
    Line[{{5.148874, 5.831023, 21.827040},{5.226614, 6.098663, 21.557898}}],
    Line[{{5.226614, 6.098663, 21.557898},{5.323214, 6.382549, 21.315332}}],
    Line[{{5.323214, 6.382549, 21.315332},{5.438426, 6.682765, 21.101187}}],
    Line[{{5.438426, 6.682765, 21.101187},{5.572037, 6.999311, 20.917461}}],
    Line[{{5.572037, 6.999311, 20.917461},{5.723844, 7.332057, 20.766310}}],
    Line[{{5.723844, 7.332057, 20.766310},{5.893642, 7.680686, 20.650047}}],
    Line[{{5.893642, 7.680686, 20.650047},{6.081207, 8.044640, 20.571146}}],
    Line[{{6.081207, 8.044640, 20.571146},{6.286267, 8.423047, 20.532223}}],
    Line[{{6.286267, 8.423047, 20.532223},{6.508475, 8.814657, 20.536009}}],
    Line[{{6.508475, 8.814657, 20.536009},{6.747376, 9.217766, 20.585320}}],
    Line[{{6.747376, 9.217766, 20.585320},{7.002375, 9.630135, 20.682999}}],
    Line[{{7.002375, 9.630135, 20.682999},{7.272685, 10.048916, 20.831842}}],
    Line[{{7.272685, 10.048916, 20.831842},{7.557296, 10.470578, 21.034504}}],
    
    Line[{{7.557296, 10.470578, 21.034504},{7.854920, 10.890840, 21.293371}}],
    
    Line[{{7.854920, 10.890840, 21.293371},{8.163945, 11.304617, 21.610420}}],
    
    Line[{{8.163945, 11.304617, 21.610420},{8.482391, 11.706008, 21.987032}}],
    
    Line[{{8.482391, 11.706008, 21.987032},{8.807864, 12.088296, 22.423801}}],
    
    Line[{{8.807864, 12.088296, 22.423801},{9.137519, 12.443999, 22.920298}}],
    
    Line[{{9.137519, 12.443999, 22.920298},{9.468042, 12.765008, 23.474848}}],
    
    Line[{{9.468042, 12.765008, 23.474848},{9.795636, 13.042740, 24.084301}}],
    
    Line[{{9.795636, 13.042740, 24.084301},{
      10.116035, 13.268412, 24.743809}}],
    Line[{{10.116035, 13.268412, 24.743809},{
      10.424550, 13.433385, 25.446703}}],
    Line[{{10.424550, 13.433385, 25.446703},{
      10.716135, 13.529542, 26.184357}}],
    Line[{{10.716135, 13.529542, 26.184357},{
      10.985497, 13.549784, 26.946228}}],
    Line[{{10.985497, 13.549784, 26.946228},{
      11.227244, 13.488481, 27.720036}}],
    Line[{{11.227244, 13.488481, 27.720036},{
      11.436047, 13.341997, 28.491957}}],
    Line[{{11.436047, 13.341997, 28.491957},{
      11.606854, 13.109091, 29.247141}}],
    Line[{{11.606854, 13.109091, 29.247141},{
      11.735106, 12.791208, 29.970226}}],
    Line[{{11.735106, 12.791208, 29.970226},{
      11.816950, 12.392699, 30.646023}}],
    Line[{{11.816950, 12.392699, 30.646023},{
      11.849459, 11.920763, 31.260221}}],
    Line[{{11.849459, 11.920763, 31.260221},{
      11.830794, 11.385221, 31.800102}}],
    Line[{{11.830794, 11.385221, 31.800102},{
      11.760341, 10.798103, 32.255157}}],
    Line[{{11.760341, 10.798103, 32.255157},{
      11.638766, 10.173043, 32.617577}}],
    Line[{{11.638766, 10.173043, 32.617577},{
      11.468025, 9.524586, 32.882557}}],
    Line[{{11.468025, 9.524586, 32.882557},{11.251284, 8.867414, 33.048374}}],
    
    Line[{{11.251284, 8.867414, 33.048374},{10.992780, 8.215642, 33.116272}}],
    
    Line[{{10.992780, 8.215642, 33.116272},{10.697637, 7.582185, 33.090126}}],
    
    Line[{{10.697637, 7.582185, 33.090126},{10.371642, 6.978251, 32.976021}}],
    
    Line[{{10.371642, 6.978251, 32.976021},{10.021005, 6.413023, 32.781693}}],
    
    Line[{{10.021005, 6.413023, 32.781693},{9.652109, 5.893509, 32.515991}}],
    Line[{{9.652109, 5.893509, 32.515991},{9.271296, 5.424543, 32.188328}}],
    Line[{{9.271296, 5.424543, 32.188328},{8.884658, 5.008926, 31.808208}}],
    Line[{{8.884658, 5.008926, 31.808208},{8.497890, 4.647659, 31.384861}}],
    Line[{{8.497890, 4.647659, 31.384861},{8.116164, 4.340235, 30.926941}}],
    Line[{{8.116164, 4.340235, 30.926941},{7.744050, 4.084954, 30.442350}}],
    Line[{{7.744050, 4.084954, 30.442350},{7.385475, 3.879240, 29.938137}}],
    Line[{{7.385475, 3.879240, 29.938137},{7.043720, 3.719923, 29.420460}}],
    Line[{{7.043720, 3.719923, 29.420460},{6.721433, 3.603503, 28.894617}}],
    Line[{{6.721433, 3.603503, 28.894617},{6.420665, 3.526356, 28.365101}}],
    Line[{{6.420665, 3.526356, 28.365101},{6.142935, 3.484904, 27.835688}}],
    Line[{{6.142935, 3.484904, 27.835688},{5.889279, 3.475740, 27.309532}}],
    Line[{{5.889279, 3.475740, 27.309532},{5.660326, 3.495717, 26.789265}}],
    Line[{{5.660326, 3.495717, 26.789265},{5.456357, 3.542009, 26.277075}}],
    Line[{{5.456357, 3.542009, 26.277075},{5.277378, 3.612141, 25.774813}}],
    Line[{{5.277378, 3.612141, 25.774813},{5.123174, 3.704001, 25.284060}}],
    Line[{{5.123174, 3.704001, 25.284060},{4.993367, 3.815840, 24.806190}}],
    Line[{{4.993367, 3.815840, 24.806190},{4.887466, 3.946253, 24.342438}}],
    Line[{{4.887466, 3.946253, 24.342438},{4.804910, 4.094158, 23.893948}}],
    Line[{{4.804910, 4.094158, 23.893948},{4.745099, 4.258769, 23.461805}}],
    Line[{{4.745099, 4.258769, 23.461805},{4.707434, 4.439568, 23.047091}}],
    Line[{{4.707434, 4.439568, 23.047091},{4.691330, 4.636264, 22.650894}}],
    Line[{{4.691330, 4.636264, 22.650894},{4.696244, 4.848770, 22.274359}}],
    Line[{{4.696244, 4.848770, 22.274359},{4.721683, 5.077161, 21.918692}}],
    Line[{{4.721683, 5.077161, 21.918692},{4.767212, 5.321640, 21.585199}}],
    Line[{{4.767212, 5.321640, 21.585199},{4.832467, 5.582503, 21.275299}}],
    Line[{{4.832467, 5.582503, 21.275299},{4.917145, 5.860104, 20.990543}}],
    Line[{{4.917145, 5.860104, 20.990543},{5.021007, 6.154809, 20.732643}}],
    Line[{{5.021007, 6.154809, 20.732643},{5.143875, 6.466961, 20.503477}}],
    Line[{{5.143875, 6.466961, 20.503477},{5.285611, 6.796828, 20.305107}}],
    Line[{{5.285611, 6.796828, 20.305107},{5.446119, 7.144557, 20.139795}}],
    Line[{{5.446119, 7.144557, 20.139795},{5.625306, 7.510111, 20.010014}}],
    Line[{{5.625306, 7.510111, 20.010014},{5.823083, 7.893210, 19.918432}}],
    Line[{{5.823083, 7.893210, 19.918432},{6.039323, 8.293260, 19.867929}}],
    Line[{{6.039323, 8.293260, 19.867929},{6.273837, 8.709268, 19.861561}}],
    Line[{{6.273837, 8.709268, 19.861561},{6.526340, 9.139765, 19.902550}}],
    Line[{{6.526340, 9.139765, 19.902550},{6.796403, 9.582709, 19.994202}}],
    Line[{{6.796403, 9.582709, 19.994202},{7.083416, 10.035389, 20.139885}}],
    Line[{{7.083416, 10.035389, 20.139885},{7.386529, 10.494331, 20.342875}}],
    
    Line[{{7.386529, 10.494331, 20.342875},{7.704604, 10.955193, 20.606295}}],
    
    Line[{{7.704604, 10.955193, 20.606295},{8.036154, 11.412723, 20.932875}}],
    
    Line[{{8.036154, 11.412723, 20.932875},{8.379280, 11.860629, 21.324848}}],
    
    Line[{{8.379280, 11.860629, 21.324848},{8.731630, 12.291681, 21.783625}}],
    
    Line[{{8.731630, 12.291681, 21.783625},{9.090317, 12.697568, 22.309601}}],
    
    Line[{{9.090317, 12.697568, 22.309601},{9.451916, 13.069178, 22.901823}}],
    
    Line[{{9.451916, 13.069178, 22.901823},{9.812411, 13.396635, 23.557714}}],
    
    Line[{{9.812411, 13.396635, 23.557714},{
      10.167208, 13.669622, 24.272774}}],
    Line[{{10.167208, 13.669622, 24.272774},{
      10.511168, 13.877772, 25.040371}}],
    Line[{{10.511168, 13.877772, 25.040371},{
      10.838655, 14.011079, 25.851511}}],
    Line[{{10.838655, 14.011079, 25.851511},{
      11.143670, 14.060509, 26.694847}}],
    Line[{{11.143670, 14.060509, 26.694847},{
      11.419992, 14.018571, 27.556791}}],
    Line[{{11.419992, 14.018571, 27.556791},{
      11.661380, 13.879991, 28.421692}}],
    Line[{{11.661380, 13.879991, 28.421692},{
      11.861814, 13.642239, 29.272442}}],
    Line[{{11.861814, 13.642239, 29.272442},{
      12.015761, 13.306012, 30.091040}}],
    Line[{{12.015761, 13.306012, 30.091040},{
      12.118450, 12.875519, 30.859446}}],
    Line[{{12.118450, 12.875519, 30.859446},{
      12.166135, 12.358521, 31.560472}}],
    Line[{{12.166135, 12.358521, 31.560472},{
      12.156329, 11.766099, 32.178692}}],
    Line[{{12.156329, 11.766099, 32.178692},{
      12.087979, 11.112168, 32.701260}}],
    Line[{{12.087979, 11.112168, 32.701260},{
      11.961564, 10.412759, 33.118572}}],
    Line[{{11.961564, 10.412759, 33.118572},{
      11.779112, 9.685115, 33.424706}}],
    Line[{{11.779112, 9.685115, 33.424706},{11.544118, 8.946740, 33.617519}}],
    
    Line[{{11.544118, 8.946740, 33.617519},{11.261384, 8.214468, 33.698521}}],
    
    Line[{{11.261384, 8.214468, 33.698521},{10.936790, 7.503646, 33.672474}}],
    
    Line[{{10.936790, 7.503646, 33.672474},{10.577019, 6.827498, 33.546814}}],
    
    Line[{{10.577019, 6.827498, 33.546814},{10.189260, 6.196717, 33.330963}}],
    
    Line[{{10.189260, 6.196717, 33.330963},{9.780900, 5.619286, 33.035614}}],
    Line[{{9.780900, 5.619286, 33.035614},{9.359256, 5.100508, 32.672028}}],
    Line[{{9.359256, 5.100508, 32.672028},{8.931328, 4.643204, 32.251472}}],
    Line[{{8.931328, 4.643204, 32.251472},{8.503613, 4.248030, 31.784746}}],
    Line[{{8.503613, 4.248030, 31.784746},{8.081961, 3.913861, 31.281837}}],
    Line[{{8.081961, 3.913861, 31.281837},{7.671490, 3.638197, 30.751728}}],
    Line[{{7.671490, 3.638197, 30.751728},{7.276541, 3.417565, 30.202286}}],
    Line[{{7.276541, 3.417565, 30.202286},{6.900680, 3.247869, 29.640261}}],
    Line[{{6.900680, 3.247869, 29.640261},{6.546727, 3.124703, 29.071337}}],
    Line[{{6.546727, 3.124703, 29.071337},{6.216808, 3.043597, 28.500229}}],
    Line[{{6.216808, 3.043597, 28.500229},{5.912426, 3.000208, 27.930799}}],
    Line[{{5.912426, 3.000208, 27.930799},{5.634543, 2.990464, 27.366180}}],
    Line[{{5.634543, 2.990464, 27.366180},{5.383655, 3.010653, 26.808912}}],
    Line[{{5.383655, 3.010653, 26.808912},{5.159879, 3.057480, 26.261042}}],
    Line[{{5.159879, 3.057480, 26.261042},{4.963027, 3.128096, 25.724241}}],
    Line[{{4.963027, 3.128096, 25.724241},{4.792684, 3.220101, 25.199892}}],
    Line[{{4.792684, 3.220101, 25.199892},{4.648262, 3.331531, 24.689163}}],
    Line[{{4.648262, 3.331531, 24.689163},{4.529066, 3.460836, 24.193073}}],
    Line[{{4.529066, 3.460836, 24.193073},{4.434335, 3.606849, 23.712551}}],
    Line[{{4.434335, 3.606849, 23.712551},{4.363290, 3.768750, 23.248476}}],
    Line[{{4.363290, 3.768750, 23.248476},{4.315162, 3.946032, 22.801714}}],
    Line[{{4.315162, 3.946032, 22.801714},{4.289221, 4.138459, 22.373154}}],
    Line[{{4.289221, 4.138459, 22.373154},{4.284793, 4.346035, 21.963734}}],
    Line[{{4.284793, 4.346035, 21.963734},{4.301283, 4.568962, 21.574463}}],
    Line[{{4.301283, 4.568962, 21.574463},{4.338178, 4.807609, 21.206455}}],
    Line[{{4.338178, 4.807609, 21.206455},{4.395053, 5.062475, 20.860939}}],
    Line[{{4.395053, 5.062475, 20.860939},{4.471580, 5.334153, 20.539286}}],
    Line[{{4.471580, 5.334153, 20.539286},{4.567520, 5.623295, 20.243031}}],
    Line[{{4.567520, 5.623295, 20.243031},{4.682720, 5.930571, 19.973898}}],
    Line[{{4.682720, 5.930571, 19.973898},{4.817102, 6.256634, 19.733809}}],
    Line[{{4.817102, 6.256634, 19.733809},{4.970662, 6.602064, 19.524916}}],
    Line[{{4.970662, 6.602064, 19.524916},{5.143436, 6.967328, 19.349613}}],
    Line[{{5.143436, 6.967328, 19.349613},{5.335503, 7.352705, 19.210552}}],
    Line[{{5.335503, 7.352705, 19.210552},{5.546943, 7.758239, 19.110651}}],
    Line[{{5.546943, 7.758239, 19.110651},{5.777820, 8.183640, 19.053097}}],
    Line[{{5.777820, 8.183640, 19.053097},{6.028145, 8.628213, 19.041340}}],
    Line[{{6.028145, 8.628213, 19.041340},{6.297838, 9.090749, 19.079067}}],
    Line[{{6.297838, 9.090749, 19.079067},{6.586682, 9.569419, 19.170162}}],
    Line[{{6.586682, 9.569419, 19.170162},{6.894272, 10.061652, 19.318647}}],
    Line[{{6.894272, 10.061652, 19.318647},{7.219956, 10.564020, 19.528564}}],
    
    Line[{{7.219956, 10.564020, 19.528564},{7.562771, 11.072092, 19.803890}}],
    
    Line[{{7.562771, 11.072092, 19.803890},{7.921372, 11.580358, 20.148291}}],
    
    Line[{{7.921372, 11.580358, 20.148291},{8.293959, 12.082070, 20.564987}}],
    
    Line[{{8.293959, 12.082070, 20.564987},{8.678202, 12.569265, 21.056396}}],
    
    Line[{{8.678202, 12.569265, 21.056396},{9.071170, 13.032665, 21.623888}}],
    
    Line[{{9.071170, 13.032665, 21.623888},{9.469274, 13.461819, 22.267366}}],
    
    Line[{{9.469274, 13.461819, 22.267366},{9.868212, 13.845218, 22.984924}}],
    
    Line[{{9.868212, 13.845218, 22.984924},{
      10.262963, 14.170615, 23.772429}}],
    Line[{{10.262963, 14.170615, 23.772429},{
      10.647799, 14.425413, 24.623192}}],
    Line[{{10.647799, 14.425413, 24.623192},{
      11.016342, 14.597238, 25.527695}}],
    Line[{{11.016342, 14.597238, 25.527695},{
      11.361678, 14.674609, 26.473415}}],
    Line[{{11.361678, 14.674609, 26.473415},{
      11.676536, 14.647738, 27.444929}}],
    Line[{{11.676536, 14.647738, 27.444929},{
      11.953519, 14.509315, 28.424173}}],
    Line[{{11.953519, 14.509315, 28.424173},{
      12.185394, 14.255364, 29.390928}}],
    Line[{{12.185394, 14.255364, 29.390928},{
      12.365424, 13.885845, 30.323711}}],
    Line[{{12.365424, 13.885845, 30.323711},{
      12.487718, 13.405078, 31.200739}}],
    Line[{{12.487718, 13.405078, 31.200739},{
      12.547575, 12.821912, 32.001114}}],
    Line[{{12.547575, 12.821912, 32.001114},{
      12.541795, 12.149452, 32.706020}}],
    Line[{{12.541795, 12.149452, 32.706020},{
      12.468911, 11.404450, 33.299850}}],
    Line[{{12.468911, 11.404450, 33.299850},{
      12.329333, 10.606376, 33.771046}}],
    Line[{{12.329333, 10.606376, 33.771046},{
      12.125364, 9.776238, 34.112686}}],
    Line[{{12.125364, 9.776238, 34.112686},{11.861115, 8.935336, 34.322643}}],
    
    Line[{{11.861115, 8.935336, 34.322643},{11.542295, 8.104016, 34.403366}}],
    
    Line[{{11.542295, 8.104016, 34.403366},{11.175913, 7.300603, 34.361336}}],
    
    Line[{{11.175913, 7.300603, 34.361336},{10.769930, 6.540633, 34.206245}}],
    
    Line[{{10.769930, 6.540633, 34.206245},{10.332868, 5.836342, 33.950089}}],
    
    Line[{{10.332868, 5.836342, 33.950089},{9.873435, 5.196501, 33.606216}}],
    Line[{{9.873435, 5.196501, 33.606216},{9.400182, 4.626517, 33.188435}}],
    Line[{{9.400182, 4.626517, 33.188435},{8.921209, 4.128748, 32.710297}}],
    Line[{{8.921209, 4.128748, 32.710297},{8.443941, 3.702967, 32.184525}}],
    Line[{{8.443941, 3.702967, 32.184525},{7.974970, 3.346883, 31.622658}}],
    Line[{{7.974970, 3.346883, 31.622658},{7.519965, 3.056679, 31.034834}}],
    Line[{{7.519965, 3.056679, 31.034834},{7.083638, 2.827524, 30.429722}}],
    Line[{{7.083638, 2.827524, 30.429722},{6.669763, 2.654000, 29.814564}}],
    Line[{{6.669763, 2.654000, 29.814564},{6.281226, 2.530477, 29.195290}}],
    Line[{{6.281226, 2.530477, 29.195290},{5.920105, 2.451392, 28.576658}}],
    Line[{{5.920105, 2.451392, 28.576658},{5.587759, 2.411460, 27.962433}}],
    Line[{{5.587759, 2.411460, 27.962433},{5.284939, 2.405814, 27.355556}}],
    Line[{{5.284939, 2.405814, 27.355556},{5.011881, 2.430099, 26.758303}}],
    Line[{{5.011881, 2.430099, 26.758303},{4.768414, 2.480509, 26.172426}}],
    Line[{{4.768414, 2.480509, 26.172426},{4.554046, 2.553806, 25.599283}}],
    Line[{{4.554046, 2.553806, 25.599283},{4.368052, 2.647303, 25.039936}}],
    Line[{{4.368052, 2.647303, 25.039936},{4.209546, 2.758838, 24.495237}}],
    Line[{{4.209546, 2.758838, 24.495237},{4.077543, 2.886738, 23.965904}}],
    Line[{{4.077543, 2.886738, 23.965904},{3.971015, 3.029774, 23.452568}}],
    Line[{{3.971015, 3.029774, 23.452568},{3.888936, 3.187116, 22.955818}}],
    Line[{{3.888936, 3.187116, 22.955818},{3.830315, 3.358291, 22.476246}}],
    Line[{{3.830315, 3.358291, 22.476246},{3.794225, 3.543134, 22.014469}}],
    Line[{{3.794225, 3.543134, 22.014469},{3.779827, 3.741753, 21.571154}}],
    Line[{{3.779827, 3.741753, 21.571154},{3.786381, 3.954487, 21.147047}}],
    Line[{{3.786381, 3.954487, 21.147047},{3.813261, 4.181873, 20.742992}}],
    Line[{{3.813261, 4.181873, 20.742992},{3.859962, 4.424611, 20.359949}}],
    Line[{{3.859962, 4.424611, 20.359949},{3.926096, 4.683532, 19.999023}}],
    Line[{{3.926096, 4.683532, 19.999023},{4.011397, 4.959569, 19.661476}}],
    Line[{{4.011397, 4.959569, 19.661476},{4.115719, 5.253722, 19.348761}}],
    Line[{{4.115719, 5.253722, 19.348761},{4.239026, 5.567024, 19.062531}}],
    Line[{{4.239026, 5.567024, 19.062531},{4.381383, 5.900509, 18.804686}}],
    Line[{{4.381383, 5.900509, 18.804686},{4.542947, 6.255163, 18.577379}}],
    Line[{{4.542947, 6.255163, 18.577379},{4.723948, 6.631885, 18.383051}}],
    Line[{{4.723948, 6.631885, 18.383051},{4.924675, 7.031419, 18.224459}}],
    Line[{{4.924675, 7.031419, 18.224459},{5.145449, 7.454298, 18.104687}}],
    Line[{{5.145449, 7.454298, 18.104687},{5.386598, 7.900757, 18.027174}}],
    Line[{{5.386598, 7.900757, 18.027174},{5.648422, 8.370639, 17.995714}}],
    Line[{{5.648422, 8.370639, 17.995714},{5.931157, 8.863295, 18.014458}}],
    Line[{{5.931157, 8.863295, 18.014458},{6.234923, 9.377446, 18.087887}}],
    Line[{{6.234923, 9.377446, 18.087887},{6.559673, 9.911052, 18.220772}}],
    Line[{{6.559673, 9.911052, 18.220772},{6.905126, 10.461146, 18.418095}}],
    Line[{{6.905126, 10.461146, 18.418095},{7.270693, 11.023681, 18.684912}}],
    
    Line[{{7.270693, 11.023681, 18.684912},{7.655398, 11.593334, 19.026247}}],
    
    Line[{{7.655398, 11.593334, 19.026247},{8.057785, 12.163399, 19.446764}}],
    
    Line[{{8.057785, 12.163399, 19.446764},{8.475820, 12.725562, 19.950602}}],
    
    Line[{{8.475820, 12.725562, 19.950602},{8.906799, 13.269938, 20.540873}}],
    
    Line[{{8.906799, 13.269938, 20.540873},{9.347244, 13.784898, 21.219362}}],
    
    Line[{{9.347244, 13.784898, 21.219362},{9.792831, 14.257321, 21.985924}}],
    
    Line[{{9.792831, 14.257321, 21.985924},{
      10.238338, 14.672734, 22.838036}}],
    Line[{{10.238338, 14.672734, 22.838036},{
      10.677599, 15.015718, 23.770212}}],
    Line[{{10.677599, 15.015718, 23.770212},{
      11.103555, 15.270536, 24.773558}}],
    Line[{{11.103555, 15.270536, 24.773558},{
      11.508340, 15.421929, 25.835461}}],
    Line[{{11.508340, 15.421929, 25.835461},{
      11.883436, 15.456057, 26.939379}}],
    Line[{{11.883436, 15.456057, 26.939379},{
      12.219937, 15.361646, 28.065014}}],
    Line[{{12.219937, 15.361646, 28.065014},{
      12.508883, 15.131066, 29.188879}}],
    Line[{{12.508883, 15.131066, 29.188879},{
      12.741657, 14.761413, 30.285057}}],
    Line[{{12.741657, 14.761413, 30.285057},{
      12.910448, 14.255250, 31.326536}}],
    Line[{{12.910448, 14.255250, 31.326536},{
      13.008718, 13.621050, 32.286682}}],
    Line[{{13.008718, 13.621050, 32.286682},{
      13.031638, 12.873078, 33.140903}}],
    Line[{{13.031638, 12.873078, 33.140903},{
      12.976456, 12.030788, 33.868229}}],
    Line[{{12.976456, 12.030788, 33.868229},{
      12.842739, 11.117679, 34.452671}}],
    Line[{{12.842739, 11.117679, 34.452671},{
      12.632466, 10.159785, 34.884148}}],
    Line[{{12.632466, 10.159785, 34.884148},{
      12.349964, 9.183933, 35.158886}}],
    Line[{{12.349964, 9.183933, 35.158886},{12.001661, 8.216011, 35.279205}}],
    
    Line[{{12.001661, 8.216011, 35.279205},{11.595735, 7.279465, 35.252846}}],
    
    Line[{{11.595735, 7.279465, 35.252846},{11.141644, 6.394130, 35.091888}}],
    
    Line[{{11.141644, 6.394130, 35.091888},{10.649634, 5.575517, 34.811493}}],
    
    Line[{{10.649634, 5.575517, 34.811493},{10.130230, 4.834544, 34.428562}}],
    
    Line[{{10.130230, 4.834544, 34.428562},{9.593773, 4.177679, 33.960522}}],
    Line[{{9.593773, 4.177679, 33.960522},{9.050038, 3.607398, 33.424328}}],
    Line[{{9.050038, 3.607398, 33.424328},{8.507942, 3.122833, 32.835709}}],
    Line[{{8.507942, 3.122833, 32.835709},{7.975335, 2.720490, 32.208710}}],
    Line[{{7.975335, 2.720490, 32.208710},{7.458891, 2.395004, 31.555420}}],
    Line[{{7.458891, 2.395004, 31.555420},{6.964078, 2.139819, 30.885948}}],
    Line[{{6.964078, 2.139819, 30.885948},{6.495183, 1.947761, 30.208511}}],
    Line[{{6.495183, 1.947761, 30.208511},{6.055392, 1.811509, 29.529621}}],
    Line[{{6.055392, 1.811509, 29.529621},{5.646900, 1.723946, 28.854307}}],
    Line[{{5.646900, 1.723946, 28.854307},{5.271034, 1.678403, 28.186375}}],
    Line[{{5.271034, 1.678403, 28.186375},{4.928391, 1.668816, 27.528633}}],
    Line[{{4.928391, 1.668816, 27.528633},{4.618965, 1.689821, 26.883108}}],
    Line[{{4.618965, 1.689821, 26.883108},{4.342276, 1.736781, 26.251240}}],
    Line[{{4.342276, 1.736781, 26.251240},{4.097485, 1.805784, 25.634022}}],
    Line[{{4.097485, 1.805784, 25.634022},{3.883491, 1.893611, 25.032139}}],
    Line[{{3.883491, 1.893611, 25.032139},{3.699025, 1.997689, 24.446062}}],
    Line[{{3.699025, 1.997689, 24.446062},{3.542725, 2.116033, 23.876118}}],
    Line[{{3.542725, 2.116033, 23.876118},{3.413193, 2.247186, 23.322563}}],
    Line[{{3.413193, 2.247186, 23.322563},{3.309048, 2.390160, 22.785612}}],
    Line[{{3.309048, 2.390160, 22.785612},{3.228969, 2.544377, 22.265484}}],
    Line[{{3.228969, 2.544377, 22.265484},{3.171722, 2.709617, 21.762419}}],
    Line[{{3.171722, 2.709617, 21.762419},{3.136186, 2.885974, 21.276712}}],
    Line[{{3.136186, 2.885974, 21.276712},{3.121367, 3.073805, 20.808718}}],
    Line[{{3.121367, 3.073805, 20.808718},{3.126413, 3.273701, 20.358873}}],
    Line[{{3.126413, 3.273701, 20.358873},{3.150618, 3.486451, 19.927719}}],
    Line[{{3.150618, 3.486451, 19.927719},{3.193427, 3.713015, 19.515905}}],
    Line[{{3.193427, 3.713015, 19.515905},{3.254436, 3.954494, 19.124222}}],
    Line[{{3.254436, 3.954494, 19.124222},{3.333392, 4.212114, 18.753605}}],
    Line[{{3.333392, 4.212114, 18.753605},{3.430186, 4.487196, 18.405174}}],
    Line[{{3.430186, 4.487196, 18.405174},{3.544849, 4.781144, 18.080242}}],
    Line[{{3.544849, 4.781144, 18.080242},{3.677545, 5.095405, 17.780357}}],
    Line[{{3.677545, 5.095405, 17.780357},{3.828564, 5.431456, 17.507320}}],
    Line[{{3.828564, 5.431456, 17.507320},{3.998307, 5.790766, 17.263226}}],
    Line[{{3.998307, 5.790766, 17.263226},{4.187273, 6.174750, 17.050501}}],
    Line[{{4.187273, 6.174750, 17.050501},{4.396047, 6.584736, 16.871929}}],
    Line[{{4.396047, 6.584736, 16.871929},{4.625277, 7.021883, 16.730703}}],
    Line[{{4.625277, 7.021883, 16.730703},{4.875646, 7.487115, 16.630449}}],
    Line[{{4.875646, 7.487115, 16.630449},{5.147850, 7.981044, 16.575266}}],
    Line[{{5.147850, 7.981044, 16.575266},{5.442550, 8.503813, 16.569744}}],
    Line[{{5.442550, 8.503813, 16.569744},{5.760337, 9.055004, 16.618975}}],
    Line[{{5.760337, 9.055004, 16.618975},{6.101671, 9.633461, 16.728550}}],
    Line[{{6.101671, 9.633461, 16.728550},{6.466805, 10.237062, 16.904486}}],
    Line[{{6.466805, 10.237062, 16.904486},{6.855729, 10.862584, 17.153208}}],
    
    Line[{{6.855729, 10.862584, 17.153208},{7.268050, 11.505390, 17.481348}}],
    
    Line[{{7.268050, 11.505390, 17.481348},{7.702891, 12.159222, 17.895548}}],
    
    Line[{{7.702891, 12.159222, 17.895548},{8.158793, 12.815961, 18.402262}}],
    
    Line[{{8.158793, 12.815961, 18.402262},{8.633546, 13.465384, 19.007221}}],
    
    Line[{{8.633546, 13.465384, 19.007221},{9.124074, 14.095042, 19.715033}}],
    
    Line[{{9.124074, 14.095042, 19.715033},{9.626300, 14.690180, 20.528563}}],
    
    Line[{{9.626300, 14.690180, 20.528563},{
      10.135022, 15.233828, 21.448223}}],
    Line[{{10.135022, 15.233828, 21.448223},{
      10.643819, 15.707115, 22.471191}}],
    Line[{{10.643819, 15.707115, 22.471191},{
      11.145020, 16.089859, 23.590630}}],
    Line[{{11.145020, 16.089859, 23.590630},{
      11.629730, 16.361389, 24.795010}}],
    Line[{{11.629730, 16.361389, 24.795010},{
      12.087959, 16.501753, 26.067577}}],
    Line[{{12.087959, 16.501753, 26.067577},{
      12.508858, 16.493147, 27.386194}}],
    Line[{{12.508858, 16.493147, 27.386194},{
      12.881087, 16.321569, 28.723600}}],
    Line[{{12.881087, 16.321569, 28.723600},{
      13.193305, 15.978460, 30.048246}}],
    Line[{{13.193305, 15.978460, 30.048246},{
      13.434757, 15.462161, 31.325724}}],
    Line[{{13.434757, 15.462161, 31.325724},{
      13.595933, 14.778936, 32.520733}}],
    Line[{{13.595933, 14.778936, 32.520733},{
      13.669225, 13.943339, 33.599400}}],
    Line[{{13.669225, 13.943339, 33.599400},{
      13.649520, 12.977730, 34.531750}}],
    Line[{{13.649520, 12.977730, 34.531750},{
      13.534648, 11.910991, 35.293911}}],
    Line[{{13.534648, 11.910991, 35.293911},{
      13.325632, 10.776509, 35.869804}}],
    Line[{{13.325632, 10.776509, 35.869804},{
      13.026692, 9.609704, 36.252029}}],
    Line[{{13.026692, 9.609704, 36.252029},{12.645011, 8.445418, 36.441887}}],
    
    Line[{{12.645011, 8.445418, 36.441887},{12.190278, 7.315548, 36.448555}}],
    
    Line[{{12.190278, 7.315548, 36.448555},{11.674074, 6.247169, 36.287582}}],
    
    Line[{{11.674074, 6.247169, 36.287582},{11.109173, 5.261365, 35.978996}}],
    
    Line[{{11.109173, 5.261365, 35.978996},{10.508825, 4.372756, 35.545357}}],
    
    Line[{{10.508825, 4.372756, 35.545357},{9.886106, 3.589679, 35.009895}}],
    Line[{{9.886106, 3.589679, 35.009895},{9.253363, 2.914877, 34.395023}}],
    Line[{{9.253363, 2.914877, 34.395023},{8.621794, 2.346459, 33.721260}}],
    Line[{{8.621794, 2.346459, 33.721260},{8.001173, 1.879017, 33.006550}}],
    Line[{{8.001173, 1.879017, 33.006550},{7.399707, 1.504713, 32.266003}}],
    Line[{{7.399707, 1.504713, 32.266003},{6.823993, 1.214260, 31.511862}}],
    Line[{{6.823993, 1.214260, 31.511862},{6.279084, 0.997731, 30.753731}}],
    Line[{{6.279084, 0.997731, 30.753731},{5.768601, 0.845186, 29.998882}}],
    Line[{{5.768601, 0.845186, 29.998882},{5.294891, 0.747128, 29.252636}}],
    Line[{{5.294891, 0.747128, 29.252636},{4.859211, 0.694802, 28.518732}}],
    Line[{{4.859211, 0.694802, 28.518732},{4.461907, 0.680363, 27.799677}}],
    Line[{{4.461907, 0.680363, 27.799677},{4.102593, 0.696957, 27.097052}}],
    Line[{{4.102593, 0.696957, 27.097052},{3.780315, 0.738732, 26.411758}}],
    Line[{{3.780315, 0.738732, 26.411758},{3.493702, 0.800799, 25.744223}}],
    Line[{{3.493702, 0.800799, 25.744223},{3.241090, 0.879160, 25.094553}}],
    Line[{{3.241090, 0.879160, 25.094553},{3.020633, 0.970634, 24.462652}}],
    Line[{{3.020633, 0.970634, 24.462652},{2.830396, 1.072759, 23.848309}}],
    Line[{{2.830396, 1.072759, 23.848309},{2.668422, 1.183706, 23.251253}}],
    Line[{{2.668422, 1.183706, 23.251253},{2.532796, 1.302197, 22.671202}}],
    Line[{{2.532796, 1.302197, 22.671202},{2.421685, 1.427423, 22.107885}}],
    Line[{{2.421685, 1.427423, 22.107885},{2.333374, 1.558976, 21.561068}}],
    Line[{{2.333374, 1.558976, 21.561068},{2.266290, 1.696788, 21.030552}}],
    Line[{{2.266290, 1.696788, 21.030552},{2.219018, 1.841081, 20.516205}}],
    Line[{{2.219018, 1.841081, 20.516205},{2.190308, 1.992322, 20.017946}}],
    Line[{{2.190308, 1.992322, 20.017946},{2.179088, 2.151186, 19.535767}}],
    Line[{{2.179088, 2.151186, 19.535767},{2.184457, 2.318530, 19.069731}}],
    Line[{{2.184457, 2.318530, 19.069731},{2.205692, 2.495368, 18.619980}}],
    Line[{{2.205692, 2.495368, 18.619980},{2.242242, 2.682854, 18.186750}}],
    Line[{{2.242242, 2.682854, 18.186750},{2.293723, 2.882270, 17.770376}}],
    Line[{{2.293723, 2.882270, 17.770376},{2.359917, 3.095013, 17.371307}}],
    Line[{{2.359917, 3.095013, 17.371307},{2.440763, 3.322590, 16.990124}}],
    Line[{{2.440763, 3.322590, 16.990124},{2.536357, 3.566612, 16.627558}}],
    Line[{{2.536357, 3.566612, 16.627558},{2.646940, 3.828784, 16.284508}}],
    Line[{{2.646940, 3.828784, 16.284508},{2.772902, 4.110908, 15.962078}}],
    Line[{{2.772902, 4.110908, 15.962078},{2.914766, 4.414864, 15.661603}}],
    Line[{{2.914766, 4.414864, 15.661603},{3.073192, 4.742606, 15.384683}}],
    Line[{{3.073192, 4.742606, 15.384683},{3.248964, 5.096142, 15.133224}}],
    Line[{{3.248964, 5.096142, 15.133224},{3.442984, 5.477512, 14.909492}}],
    Line[{{3.442984, 5.477512, 14.909492},{3.656264, 5.888754, 14.716152}}],
    Line[{{3.656264, 5.888754, 14.716152},{3.889910, 6.331856, 14.556338}}],
    Line[{{3.889910, 6.331856, 14.556338},{4.145108, 6.808700, 14.433703}}],
    Line[{{4.145108, 6.808700, 14.433703},{4.423102, 7.320977, 14.352493}}],
    Line[{{4.423102, 7.320977, 14.352493},{4.725164, 7.870072, 14.317596}}],
    Line[{{4.725164, 7.870072, 14.317596},{5.052561, 8.456950, 14.334624}}],
    Line[{{5.052561, 8.456950, 14.334624},{5.406495, 9.081951, 14.409921}}],
    Line[{{5.406495, 9.081951, 14.409921},{5.788059, 9.744615, 14.550658}}],
    Line[{{5.788059, 9.744615, 14.550658},{6.198137, 10.443382, 14.764728}}],
    Line[{{6.198137, 10.443382, 14.764728},{6.637327, 11.175326, 15.060837}}],
    
    Line[{{6.637327, 11.175326, 15.060837},{7.105802, 11.935780, 15.448193}}],
    
    Line[{{7.105802, 11.935780, 15.448193},{7.603178, 12.717919, 15.936518}}],
    
    Line[{{7.603178, 12.717919, 15.936518},{8.128340, 13.512413, 16.535492}}],
    
    Line[{{8.128340, 13.512413, 16.535492},{8.679247, 14.306956, 17.254374}}],
    
    Line[{{8.679247, 14.306956, 17.254374},{9.252727, 15.085930, 18.101332}}],
    
    Line[{{9.252727, 15.085930, 18.101332},{9.844253, 15.830210, 19.082495}}],
    
    Line[{{9.844253, 15.830210, 19.082495},{
      10.447730, 16.517059, 20.200932}}],
    Line[{{10.447730, 16.517059, 20.200932},{
      11.055326, 17.120497, 21.455397}}],
    Line[{{11.055326, 17.120497, 21.455397},{
      11.657347, 17.611977, 22.839014}}],
    Line[{{11.657347, 17.611977, 22.839014},{
      12.242218, 17.961588, 24.337940}}],
    Line[{{12.242218, 17.961588, 24.337940},{
      12.796639, 18.139914, 25.930473}}],
    Line[{{12.796639, 18.139914, 25.930473},{
      13.305883, 18.120283, 27.586493}}],
    Line[{{13.305883, 18.120283, 27.586493},{
      13.754333, 17.881668, 29.267664}}],
    Line[{{13.754333, 17.881668, 29.267664},{
      14.126245, 17.411268, 30.928905}}],
    Line[{{14.126245, 17.411268, 30.928905},{
      14.406651, 16.707220, 32.520580}}],
    Line[{{14.406651, 16.707220, 32.520580},{
      14.582442, 15.780177, 33.991962}}],
    Line[{{14.582442, 15.780177, 33.991962},{
      14.643395, 14.653885, 35.295166}}],
    Line[{{14.643395, 14.653885, 35.295166},{
      14.583119, 13.364041, 36.389366}}],
    Line[{{14.583119, 13.364041, 36.389366},{
      14.399711, 11.955753, 37.244358}}],
    Line[{{14.399711, 11.955753, 37.244358},{
      14.096039, 10.479761, 37.842930}}],
    Line[{{14.096039, 10.479761, 37.842930},{
      13.679630, 8.988026, 38.181850}}],
    Line[{{13.679630, 8.988026, 38.181850},{13.162115, 7.529403, 38.271000}}],
    
    Line[{{13.162115, 7.529403, 38.271000},{12.558373, 6.146027, 38.131298}}],
    
    Line[{{12.558373, 6.146027, 38.131298},{11.885447, 4.870875, 37.791542}}],
    
    Line[{{11.885447, 4.870875, 37.791542},{11.161401, 3.726676, 37.285015}}],
    
    Line[{{11.161401, 3.726676, 37.285015},{10.404253, 2.726065, 36.646217}}],
    
    Line[{{10.404253, 2.726065, 36.646217},{9.631060, 1.872694, 35.908249}}],
    Line[{{9.631060, 1.872694, 35.908249},{8.857236, 1.162915, 35.100937}}],
    Line[{{8.857236, 1.162915, 35.100937},{8.096106, 0.587698, 34.249741}}],
    Line[{{8.096106, 0.587698, 34.249741},{7.358681, 0.134486, 33.375385}}],
    Line[{{7.358681, 0.134486, 33.375385},{6.653626, -0.211186, 32.493973}}],
    Line[{{6.653626, -0.211186, 32.493973},{5.987368, -0.464400, 31.617443}}],
    
    Line[{{5.987368, -0.464400, 31.617443},{5.364292, -0.639911, 30.754210}}],
    
    Line[{{5.364292, -0.639911, 30.754210},{4.787008, -0.751510, 29.909843}}],
    
    Line[{{4.787008, -0.751510, 29.909843},{4.256626, -0.811651, 29.087723}}],
    
    Line[{{4.256626, -0.811651, 29.087723},{3.773039, -0.831270, 28.289608}}],
    
    Line[{{3.773039, -0.831270, 28.289608},{3.335183, -0.819751, 27.516115}}],
    
    Line[{{3.335183, -0.819751, 27.516115},{2.941277, -0.784983, 26.767103}}],
    
    Line[{{2.941277, -0.784983, 26.767103},{2.589025, -0.733469, 26.041948}}],
    
    Line[{{2.589025, -0.733469, 26.041948},{2.275792, -0.670477, 25.339750}}],
    
    Line[{{2.275792, -0.670477, 25.339750},{1.998748, -0.600192, 24.659487}}],
    
    Line[{{1.998748, -0.600192, 24.659487},{1.754977, -0.525867, 24.000099}}],
    
    Line[{{1.754977, -0.525867, 24.000099},{1.541573, -0.449971, 23.360559}}],
    
    Line[{{1.541573, -0.449971, 23.360559},{1.355702, -0.374321, 22.739893}}],
    
    Line[{{1.355702, -0.374321, 22.739893},{1.194655, -0.300195, 22.137209}}],
    
    Line[{{1.194655, -0.300195, 22.137209},{1.055880, -0.228441, 21.551693}}],
    
    Line[{{1.055880, -0.228441, 21.551693},{0.937006, -0.159556, 20.982613}}],
    
    Line[{{0.937006, -0.159556, 20.982613},{0.835852, -0.093765, 20.429308}}],
    
    Line[{{0.835852, -0.093765, 20.429308},{0.750436, -0.031082, 19.891186}}],
    
    Line[{{0.750436, -0.031082, 19.891186},{0.678969, 0.028644, 19.367702}}],
    Line[{{0.678969, 0.028644, 19.367702},{0.619856, 0.085686, 18.858370}}],
    Line[{{0.619856, 0.085686, 18.858370},{0.571682, 0.140405, 18.362740}}],
    Line[{{0.571682, 0.140405, 18.362740},{0.533206, 0.193228, 17.880398}}],
    Line[{{0.533206, 0.193228, 17.880398},{0.503345, 0.244631, 17.410961}}],
    Line[{{0.503345, 0.244631, 17.410961},{0.481171, 0.295118, 16.954069}}],
    Line[{{0.481171, 0.295118, 16.954069},{0.465889, 0.345217, 16.509384}}],
    Line[{{0.465889, 0.345217, 16.509384},{0.456832, 0.395474, 16.076593}}],
    Line[{{0.456832, 0.395474, 16.076593},{0.453451, 0.446446, 15.655397}}],
    Line[{{0.453451, 0.446446, 15.655397},{0.455299, 0.498701, 15.245514}}],
    Line[{{0.455299, 0.498701, 15.245514},{0.462031, 0.552821, 14.846679}}],
    Line[{{0.462031, 0.552821, 14.846679},{0.473387, 0.609402, 14.458641}}],
    Line[{{0.473387, 0.609402, 14.458641},{0.489191, 0.669059, 14.081169}}],
    Line[{{0.489191, 0.669059, 14.081169},{0.509343, 0.732429, 13.714047}}],
    Line[{{0.509343, 0.732429, 13.714047},{0.533815, 0.800180, 13.357080}}],
    Line[{{0.533815, 0.800180, 13.357080},{0.562645, 0.873012, 13.010087}}],
    Line[{{0.562645, 0.873012, 13.010087},{0.595940, 0.951671, 12.672916}}],
    Line[{{0.595940, 0.951671, 12.672916},{0.633865, 1.036950, 12.345436}}],
    Line[{{0.633865, 1.036950, 12.345436},{0.676652, 1.129702, 12.027545}}],
    Line[{{0.676652, 1.129702, 12.027545},{0.724592, 1.230850, 11.719175}}],
    Line[{{0.724592, 1.230850, 11.719175},{0.778043, 1.341393, 11.420296}}],
    Line[{{0.778043, 1.341393, 11.420296},{0.837425, 1.462419, 11.130920}}],
    Line[{{0.837425, 1.462419, 11.130920},{0.903229, 1.595116, 10.851115}}],
    Line[{{0.903229, 1.595116, 10.851115},{0.976016, 1.740785, 10.581010}}],
    Line[{{0.976016, 1.740785, 10.581010},{1.056424, 1.900853, 10.320805}}],
    Line[{{1.056424, 1.900853, 10.320805},{1.145173, 2.076883, 10.070791}}],
    Line[{{1.145173, 2.076883, 10.070791},{1.243070, 2.270593, 9.831367}}],
    Line[{{1.243070, 2.270593, 9.831367},{1.351016, 2.483867, 9.603055}}],
    Line[{{1.351016, 2.483867, 9.603055},{1.470015, 2.718772, 9.386531}}],
    Line[{{1.470015, 2.718772, 9.386531},{1.601183, 2.977571, 9.182655}}],
    Line[{{1.601183, 2.977571, 9.182655},{1.745753, 3.262735, 8.992509}}],
    Line[{{1.745753, 3.262735, 8.992509},{1.905087, 3.576958, 8.817444}}],
    Line[{{1.905087, 3.576958, 8.817444},{2.080684, 3.923162, 8.659124}}],
    Line[{{2.080684, 3.923162, 8.659124},{2.274192, 4.304498, 8.519620}}],
    Line[{{2.274192, 4.304498, 8.519620},{2.487412, 4.724356, 8.401442}}],
    Line[{{2.487412, 4.724356, 8.401442},{2.722306, 5.186321, 8.307688}}],
    Line[{{2.722306, 5.186321, 8.307688},{2.981000, 5.694176, 8.242106}}],
    Line[{{2.981000, 5.694176, 8.242106},{3.265784, 6.251822, 8.209254}}],
    Line[{{3.265784, 6.251822, 8.209254},{3.579104, 6.863205, 8.214633}}],
    Line[{{3.579104, 6.863205, 8.214633},{3.923551, 7.532220, 8.264840}}],
    Line[{{3.923551, 7.532220, 8.264840},{4.301824, 8.262485, 8.367786}}],
    Line[{{4.301824, 8.262485, 8.367786},{4.716688, 9.057138, 8.532858}}],
    Line[{{4.716688, 9.057138, 8.532858},{5.170909, 9.918501, 8.771123}}],
    Line[{{5.170909, 9.918501, 8.771123},{5.667156, 10.847640, 9.095504}}],
    Line[{{5.667156, 10.847640, 9.095504},{6.207860, 11.843798, 9.520911}}],
    Line[{{6.207860, 11.843798, 9.520911},{6.795031, 12.903664, 10.064281}}],
    Line[{{6.795031, 12.903664, 10.064281},{7.430010, 14.020484, 10.744450}}],
    
    Line[{{7.430010, 14.020484, 10.744450},{8.113173, 15.183040, 11.581836}}],
    
    Line[{{8.113173, 15.183040, 11.581836},{8.843515, 16.374414, 12.597721}}],
    
    Line[{{8.843515, 16.374414, 12.597721},{9.618195, 17.570774, 13.813118}}],
    
    Line[{{9.618195, 17.570774, 13.813118},{
      10.431992, 18.740198, 15.247025}}],
    Line[{{10.431992, 18.740198, 15.247025},{
      11.276717, 19.841839, 16.913998}}],
    Line[{{11.276717, 19.841839, 16.913998},{
      12.140630, 20.825747, 18.820984}}],
    Line[{{12.140630, 20.825747, 18.820984},{
      13.007945, 21.633762, 20.963587}}],
    Line[{{13.007945, 21.633762, 20.963587},{
      13.858534, 22.201950, 23.322046}}],
    Line[{{13.858534, 22.201950, 23.322046},{
      14.667994, 22.465015, 25.857599}}],
    Line[{{14.667994, 22.465015, 25.857599},{
      15.408212, 22.362694, 28.510195}}],
    Line[{{15.408212, 22.362694, 28.510195},{
      16.048588, 21.847805, 31.198645}}],
    Line[{{16.048588, 21.847805, 31.198645},{
      16.557919, 20.894861, 33.824150}}],
    Line[{{16.557919, 20.894861, 33.824150},{
      16.906906, 19.507631, 36.277782}}],
    Line[{{16.906906, 19.507631, 36.277782},{
      17.071020, 17.723518, 38.451454}}],
    Line[{{17.071020, 17.723518, 38.451454},{
      17.033245, 15.612978, 40.250595}}],
    Line[{{17.033245, 15.612978, 40.250595},{
      16.786266, 13.273429, 41.606026}}],
    Line[{{16.786266, 13.273429, 41.606026},{
      16.333611, 10.818248, 42.482353}}],
    Line[{{16.333611, 10.818248, 42.482353},{
      15.689485, 8.363170, 42.880810}}],
    Line[{{15.689485, 8.363170, 42.880810},{14.877328, 6.013057, 42.836151}}],
    
    Line[{{14.877328, 6.013057, 42.836151},{13.927374, 3.851752, 42.408661}}],
    
    Line[{{13.927374, 3.851752, 42.408661},{12.873698, 1.936609, 41.673649}}],
    
    Line[{{12.873698, 1.936609, 41.673649},{11.751267, 0.297810, 40.710903}}],
    
    Line[{{11.751267, 0.297810, 40.710903},{
      10.593394, -1.058481, 39.595985}}],
    Line[{{10.593394, -1.058481, 39.595985},{
      9.429859, -2.144734, 38.394421}}],
    Line[{{9.429859, -2.144734, 38.394421},{8.285766, -2.985988, 37.158829}}],
    
    Line[{{8.285766, -2.985988, 37.158829},{7.181067, -3.614263, 35.928490}}],
    
    Line[{{7.181067, -3.614263, 35.928490},{6.130619, -4.064068, 34.730511}}],
    
    Line[{{6.130619, -4.064068, 34.730511},{5.144593, -4.369223, 33.581856}}],
    
    Line[{{5.144593, -4.369223, 33.581856},{4.229091, -4.560864, 32.491661}}],
    
    Line[{{4.229091, -4.560864, 32.491661},{3.386846, -4.666420, 31.463400}}],
    
    Line[{{3.386846, -4.666420, 31.463400},{2.617916, -4.709265, 30.496735}}],
    
    Line[{{2.617916, -4.709265, 30.496735},{1.920322, -4.708802, 29.588980}}],
    
    Line[{{1.920322, -4.708802, 29.588980},{1.290608, -4.680812, 28.736183}}],
    
    Line[{{1.290608, -4.680812, 28.736183},{0.724298, -4.637903, 27.933876}}],
    
    Line[{{0.724298, -4.637903, 27.933876},{0.216280, -4.589993, 27.177570}}],
    
    Line[{{
      0.216280, -4.589993, 27.177570},{-0.238907, -4.544773, 26.463068}}],
    Line[{{-0.238907, -4.544773, 26.463068},{-0.646842, -4.508132, 
        25.786619}}],
    Line[{{-0.646842, -4.508132, 25.786619},{-1.013066, -4.484512, 
        25.144987}}],
    Line[{{-1.013066, -4.484512, 25.144987},{-1.342957, -4.477227, 
        24.535482}}],
    Line[{{-1.342957, -4.477227, 24.535482},{-1.641649, -4.488711, 
        23.955921}}],
    Line[{{-1.641649, -4.488711, 23.955921},{-1.913989, -4.520734, 
        23.404606}}],
    Line[{{-1.913989, -4.520734, 23.404606},{-2.164505, -4.574573, 
        22.880266}}],
    Line[{{-2.164505, -4.574573, 22.880266},{-2.397396, -4.651148, 
        22.382025}}],
    Line[{{-2.397396, -4.651148, 22.382025},{-2.616539, -4.751130, 
        21.909353}}],
    Line[{{-2.616539, -4.751130, 21.909353},{-2.825494, -4.875025, 
        21.462046}}],
    Line[{{-2.825494, -4.875025, 21.462046},{-3.027527, -5.023239, 
        21.040188}}],
    Line[{{-3.027527, -5.023239, 21.040188},{-3.225629, -5.196124, 
        20.644148}}],
    Line[{{-3.225629, -5.196124, 20.644148},{-3.422538, -5.394005, 
        20.274563}}],
    Line[{{-3.422538, -5.394005, 20.274563},{-3.620762, -5.617203, 
        19.932337}}],
    Line[{{-3.620762, -5.617203, 19.932337},{-3.822600, -5.866034, 
        19.618649}}],
    Line[{{-3.822600, -5.866034, 19.618649},{-4.030163, -6.140804, 
        19.334953}}],
    Line[{{-4.030163, -6.140804, 19.334953},{-4.245389, -6.441790, 
        19.083000}}],
    Line[{{-4.245389, -6.441790, 19.083000},{-4.470053, -6.769210, 
        18.864841}}],
    Line[{{-4.470053, -6.769210, 18.864841},{-4.705781, -7.123182, 
        18.682856}}],
    Line[{{-4.705781, -7.123182, 18.682856},{-4.954045, -7.503658, 
        18.539753}}],
    Line[{{-4.954045, -7.503658, 18.539753},{-5.216165, -7.910376, 
        18.438591}}],
    Line[{{-5.216165, -7.910376, 18.438591},{-5.493296, -8.342756, 
        18.382776}}],
    Line[{{-5.493296, -8.342756, 18.382776},{-5.786402, -8.799801, 
        18.376057}}],
    Line[{{-5.786402, -8.799801, 18.376057},{-6.096246, -9.280002, 
        18.422510}}],
    Line[{{-6.096246, -9.280002, 18.422510},{-6.423340, -9.781184, 
        18.526491}}],
    Line[{{-6.423340, -9.781184, 18.526491},{-6.767898, -10.300368, 
        18.692554}}],
    Line[{{-6.767898, -10.300368, 18.692554},{-7.129792, -10.833630, 
        18.925379}}],
    Line[{{-7.129792, -10.833630, 18.925379},{-7.508480, -11.375924, 
        19.229597}}],
    Line[{{-7.508480, -11.375924, 19.229597},{-7.902922, -11.920943, 
        19.609570}}],
    Line[{{-7.902922, -11.920943, 19.609570},{-8.311523, -12.460988, 
        20.069197}}],
    Line[{{-8.311523, -12.460988, 20.069197},{-8.732029, -12.986860, 
        20.611542}}],
    Line[{{-8.732029, -12.986860, 20.611542},{-9.161450, -13.487878, 
        21.238419}}],
    Line[{{-9.161450, -13.487878, 21.238419},{-9.595997, -13.951859, 
        21.950052}}],
    Line[{{-9.595997, -13.951859, 21.950052},{-10.031015, -14.365390, 
        22.744486}}],
    Line[{{-10.031015, -14.365390, 22.744486},{-10.460970, -14.714105, 
        23.617167}}],
    Line[{{-10.460970, -14.714105, 23.617167},{-10.879458, -14.983212, 
        24.560476}}],
    Line[{{-10.879458, -14.983212, 24.560476},{-11.279291, -15.158180, 
        25.563396}}],
    Line[{{-11.279291, -15.158180, 25.563396},{-11.652620, -15.225560, 
        26.611324}}],
    Line[{{-11.652620, -15.225560, 26.611324},{-11.991155, -15.173985, 
        27.686121}}],
    Line[{{-11.991155, -15.173985, 27.686121},{-12.286457, -14.995204, 
        28.766489}}],
    Line[{{-12.286457, -14.995204, 28.766489},{-12.530296, -14.685056, 
        29.828674}}],
    Line[{{-12.530296, -14.685056, 29.828674},{-12.715065, -14.244248, 
        30.847519}}],
    Line[{{-12.715065, -14.244248, 30.847519},{-12.834197, -13.678867, 
        31.797726}}],
    Line[{{-12.834197, -13.678867, 31.797726},{-12.882600, -13.000437, 
        32.655384}}],
    Line[{{-12.882600, -13.000437, 32.655384},{-12.857010, -12.225511, 
        33.399456}}],
    Line[{{-12.857010, -12.225511, 33.399456},{-12.756260, -11.374809, 
        34.013073}}],
    Line[{{-12.756260, -11.374809, 34.013073},{-12.581417, -10.471938, 
        34.484566}}],
    Line[{{-12.581417, -10.471938, 34.484566},{-12.335771, -9.541866, 
        34.807987}}],
    Line[{{-12.335771, -9.541866, 34.807987},{-12.024676, -8.609329, 
        34.983162}}],
    Line[{{-12.024676, -8.609329, 34.983162},{-11.655262, -7.697353, 
        35.015232}}],
    Line[{{-11.655262, -7.697353, 35.015232},{-11.236033, -6.826051, 
        34.913795}}],
    Line[{{-11.236033, -6.826051, 34.913795},{-10.776428, -6.011776, 
        34.691841}}],
    Line[{{-10.776428, -6.011776, 34.691841},{-10.286338, -5.266737, 
        34.364510}}],
    Line[{{-10.286338, -5.266737, 34.364510},{-9.775673, -4.598942, 
        33.947948}}],
    Line[{{-9.775673, -4.598942, 33.947948},{-9.253971, -4.012492, 
        33.458313}}],
    Line[{{-9.253971, -4.012492, 33.458313},{-8.730083, -3.508095, 
        32.910954}}],
    Line[{{-8.730083, -3.508095, 32.910954},{-8.211946, -3.083704, 
        32.319870}}],
    Line[{{-8.211946, -3.083704, 32.319870},{-7.706442, -2.735201, 
        31.697378}}],
    Line[{{-7.706442, -2.735201, 31.697378},{-7.219330, -2.457041, 
        31.053988}}],
    Line[{{-7.219330, -2.457041, 31.053988},{-6.755252, -2.242837, 
        30.398417}}],
    Line[{{-6.755252, -2.242837, 30.398417},{-6.317776, -2.085840, 
        29.737717}}],
    Line[{{-6.317776, -2.085840, 29.737717},{-5.909488, -1.979312, 
        29.077465}}],
    Line[{{-5.909488, -1.979312, 29.077465},{-5.532099, -1.916814, 
        28.421972}}],
    Line[{{-5.532099, -1.916814, 28.421972},{-5.186565, -1.892388, 
        27.774513}}],
    Line[{{-5.186565, -1.892388, 27.774513},{-4.873214, -1.900677, 
        27.137529}}],
    Line[{{-4.873214, -1.900677, 27.137529},{-4.591864, -1.936987, 
        26.512806}}],
    Line[{{-4.591864, -1.936987, 26.512806},{-4.341937, -1.997300, 
        25.901640}}],
    Line[{{-4.341937, -1.997300, 25.901640},{-4.122559, -2.078265, 
        25.304970}}],
    Line[{{-4.122559, -2.078265, 25.304970},{-3.932652, -2.177155, 
        24.723473}}],
    Line[{{-3.932652, -2.177155, 24.723473},{-3.771008, -2.291830, 
        24.157658}}],
    Line[{{-3.771008, -2.291830, 24.157658},{-3.636358, -2.420678, 
        23.607925}}],
    Line[{{-3.636358, -2.420678, 23.607925},{-3.527425, -2.562561, 
        23.074619}}],
    Line[{{-3.527425, -2.562561, 23.074619},{-3.442961, -2.716761, 
        22.558069}}],
    Line[{{-3.442961, -2.716761, 22.558069},{-3.381792, -2.882925, 
        22.058613}}],
    Line[{{-3.381792, -2.882925, 22.058613},{-3.342836, -3.061027, 
        21.576637}}],
    Line[{{-3.342836, -3.061027, 21.576637},{-3.325123, -3.251312, 
        21.112576}}],
    Line[{{-3.325123, -3.251312, 21.112576},{-3.327814, -3.454269, 
        20.666950}}],
    Line[{{-3.327814, -3.454269, 20.666950},{-3.350206, -3.670591, 
        20.240377}}],
    Line[{{-3.350206, -3.670591, 20.240377},{-3.391735, -3.901144, 
        19.833590}}],
    Line[{{-3.391735, -3.901144, 19.833590},{-3.451982, -4.146941, 
        19.447453}}],
    Line[{{-3.451982, -4.146941, 19.447453},{-3.530672, -4.409115, 
        19.082991}}],
    Line[{{-3.530672, -4.409115, 19.082991},{-3.627665, -4.688896, 
        18.741398}}],
    Line[{{-3.627665, -4.688896, 18.741398},{-3.742959, -4.987578, 
        18.424082}}],
    Line[{{-3.742959, -4.987578, 18.424082},{-3.876675, -5.306500, 
        18.132671}}],
    Line[{{-3.876675, -5.306500, 18.132671},{-4.029050, -5.647009, 
        17.869059}}],
    Line[{{-4.029050, -5.647009, 17.869059},{-4.200429, -6.010423, 
        17.635426}}],
    Line[{{-4.200429, -6.010423, 17.635426},{-4.391243, -6.397986, 
        17.434278}}],
    Line[{{-4.391243, -6.397986, 17.434278},{-4.601995, -6.810821, 
        17.268480}}],
    Line[{{-4.601995, -6.810821, 17.268480},{-4.833242, -7.249852, 
        17.141283}}],
    Line[{{-4.833242, -7.249852, 17.141283},{-5.085558, -7.715732, 
        17.056356}}],
    Line[{{-5.085558, -7.715732, 17.056356},{-5.359512, -8.208743, 
        17.017818}}],
    Line[{{-5.359512, -8.208743, 17.017818},{-5.655620, -8.728676, 
        17.030231}}],
    Line[{{-5.655620, -8.728676, 17.030231},{-5.974301, -9.274692, 
        17.098610}}],
    Line[{{-5.974301, -9.274692, 17.098610},{-6.315818, -9.845164, 
        17.228397}}],
    Line[{{-6.315818, -9.845164, 17.228397},{-6.680207, -10.437484, 
        17.425381}}],
    Line[{{-6.680207, -10.437484, 17.425381},{-7.067198, -11.047868, 
        17.695621}}],
    Line[{{-7.067198, -11.047868, 17.695621},{-7.476120, -11.671130, 
        18.045267}}],
    Line[{{-7.476120, -11.671130, 18.045267},{-7.905796, -12.300474, 
        18.480326}}],
    Line[{{-7.905796, -12.300474, 18.480326},{-8.354427, -12.927266, 
        19.006386}}],
    Line[{{-8.354427, -12.927266, 19.006386},{-8.819473, -13.540914, 
        19.628145}}],
    Line[{{-8.819473, -13.540914, 19.628145},{-9.297521, -14.128718, 
        20.348991}}],
    Line[{{-9.297521, -14.128718, 20.348991},{-9.784172, -14.675923, 
        21.170345}}],
    Line[{{-9.784172, -14.675923, 21.170345},{-10.273968, -15.165960, 
        22.091026}}],
    Line[{{-10.273968, -15.165960, 22.091026},{-10.760283, -15.580671, 
        23.106531}}],
    Line[{{-10.760283, -15.580671, 23.106531},{-11.235376, -15.901155, 
        24.208395}}],
    Line[{{-11.235376, -15.901155, 24.208395},{-11.690431, -16.108541, 
        25.383636}}],
    Line[{{-11.690431, -16.108541, 25.383636},{-12.115723, -16.185207, 
        26.614418}}],
    Line[{{-12.115723, -16.185207, 26.614418},{-12.500890, -16.116163, 
        27.878056}}],
    Line[{{-12.500890, -16.116163, 27.878056},{-12.835318, -15.890537, 
        29.147522}}],
    Line[{{-12.835318, -15.890537, 29.147522},{-13.108625, -15.502963, 
        30.392412}}],
    Line[{{-13.108625, -15.502963, 30.392412},{-13.311227, -14.954783, 
        31.580385}}],
    Line[{{-13.311227, -14.954783, 31.580385},{-13.434926, -14.254697, 
        32.679115}}],
    Line[{{-13.434926, -14.254697, 32.679115},{-13.473498, -13.418817, 
        33.658424}}],
    Line[{{-13.473498, -13.418817, 33.658424},{-13.423178, -12.469975, 
        34.492409}}],
    Line[{{-13.423178, -12.469975, 34.492409},{-13.283003, -11.436339, 
        35.161270}}],
    Line[{{-13.283003, -11.436339, 35.161270},{-13.054961, -10.349433, 
        35.652599}}],
    Line[{{-13.054961, -10.349433, 35.652599},{-12.743925, -9.241883, 
        35.961937}}],
    Line[{{-12.743925, -9.241883, 35.961937},{-12.357368, -8.145134, 
        36.092529}}],
    Line[{{-12.357368, -8.145134, 36.092529},{-11.904903, -7.087451, 
        36.054413}}],
    Line[{{-11.904903, -7.087451, 36.054413},{-11.397705, -6.092417, 
        35.862972}}],
    Line[{{-11.397705, -6.092417, 35.862972},{-10.847861, -5.178049, 
        35.537239}}],
    Line[{{-10.847861, -5.178049, 35.537239},{-10.267743, -4.356525, 
        35.098125}}],
    Line[{{-10.267743, -4.356525, 35.098125},{-9.669430, -3.634460, 
        34.566883}}],
    Line[{{-9.669430, -3.634460, 34.566883},{-9.064236, -3.013572, 
        33.963833}}],
    Line[{{-9.064236, -3.013572, 33.963833},{-8.462365, -2.491587, 
        33.307472}}],
    Line[{{-8.462365, -2.491587, 33.307472},{-7.872676, -2.063200, 
        32.613956}}],
    Line[{{-7.872676, -2.063200, 32.613956},{-7.302575, -1.721057, 
        31.896875}}],
    Line[{{-7.302575, -1.721057, 31.896875},{-6.757998, -1.456593, 
        31.167284}}],
    Line[{{-6.757998, -1.456593, 31.167284},{-6.243473, -1.260741, 
        30.433886}}],
    Line[{{-6.243473, -1.260741, 30.433886},{-5.762228, -1.124466, 
        29.703331}}],
    Line[{{-5.762228, -1.124466, 29.703331},{-5.316346, -1.039161, 
        28.980536}}],
    Line[{{-5.316346, -1.039161, 28.980536},{-4.906923, -0.996903, 
        28.269020}}],
    Line[{{-4.906923, -0.996903, 28.269020},{-4.534235, -0.990602, 
        27.571199}}],
    Line[{{-4.534235, -0.990602, 27.571199},{-4.197904, -1.014069, 
        26.888662}}],
    Line[{{-4.197904, -1.014069, 26.888662},{-3.897038, -1.062024, 
        26.222383}}],
    Line[{{-3.897038, -1.062024, 26.222383},{-3.630373, -1.130062, 
        25.572903}}],
    Line[{{-3.630373, -1.130062, 25.572903},{-3.396385, -1.214597, 
        24.940462}}],
    Line[{{-3.396385, -1.214597, 24.940462},{-3.193393, -1.312785, 
        24.325119}}],
    Line[{{-3.193393, -1.312785, 24.325119},{-3.019633, -1.422446, 
        23.726814}}],
    Line[{{-3.019633, -1.422446, 23.726814},{-2.873337, -1.541987, 
        23.145433}}],
    Line[{{-2.873337, -1.541987, 23.145433},{-2.752772, -1.670324, 
        22.580847}}],
    Line[{{-2.752772, -1.670324, 22.580847},{-2.656294, -1.806813, 
        22.032936}}],
    Line[{{-2.656294, -1.806813, 22.032936},{-2.582370, -1.951190, 
        21.501617}}],
    Line[{{-2.582370, -1.951190, 21.501617},{-2.529605, -2.103512, 
        20.986849}}],
    Line[{{-2.529605, -2.103512, 20.986849},{-2.496755, -2.264115, 
        20.488655}}],
    Line[{{-2.496755, -2.264115, 20.488655},{-2.482739, -2.433569, 
        20.007124}}],
    Line[{{-2.482739, -2.433569, 20.007124},{-2.486644, -2.612652, 
        19.542423}}],
    Line[{{-2.486644, -2.612652, 19.542423},{-2.507724, -2.802318, 
        19.094807}}],
    Line[{{-2.507724, -2.802318, 19.094807},{-2.545405, -3.003674, 
        18.664631}}],
    Line[{{-2.545405, -3.003674, 18.664631},{-2.599279, -3.217968, 
        18.252363}}],
    Line[{{-2.599279, -3.217968, 18.252363},{-2.669101, -3.446571, 
        17.858603}}],
    Line[{{-2.669101, -3.446571, 17.858603},{-2.754786, -3.690963, 
        17.484089}}],
    Line[{{-2.754786, -3.690963, 17.484089},{-2.856403, -3.952726, 
        17.129736}}],
    Line[{{-2.856403, -3.952726, 17.129736},{-2.974169, -4.233529, 
        16.796650}}],
    Line[{{-2.974169, -4.233529, 16.796650},{-3.108443, -4.535120, 
        16.486158}}],
    Line[{{-3.108443, -4.535120, 16.486158},{-3.259718, -4.859301, 
        16.199846}}],
    Line[{{-3.259718, -4.859301, 16.199846},{-3.428618, -5.207923, 
        15.939590}}],
    Line[{{-3.428618, -5.207923, 15.939590},{-3.615879, -5.582844, 
        15.707603}}],
    Line[{{-3.615879, -5.582844, 15.707603},{-3.822347, -5.985904, 
        15.506478}}],
    Line[{{-3.822347, -5.985904, 15.506478},{-4.048959, -6.418874, 
        15.339243}}],
    Line[{{-4.048959, -6.418874, 15.339243},{-4.296723, -6.883389, 
        15.209406}}],
    Line[{{-4.296723, -6.883389, 15.209406},{-4.566702, -7.380885, 
        15.121017}}],
    Line[{{-4.566702, -7.380885, 15.121017},{-4.859975, -7.912468, 
        15.078712}}],
    Line[{{-4.859975, -7.912468, 15.078712},{-5.177608, -8.478819, 
        15.087770}}],
    Line[{{-5.177608, -8.478819, 15.087770},{-5.520598, -9.079999, 
        15.154132}}],
    Line[{{-5.520598, -9.079999, 15.154132},{-5.889820, -9.715276, 
        15.284426}}],
    Line[{{-5.889820, -9.715276, 15.284426},{-6.285946, -10.382882, 
        15.485954}}],
    Line[{{-6.285946, -10.382882, 15.485954},{-6.709352, -11.079731, 
        15.766590}}],
    Line[{{-6.709352, -11.079731, 15.766590},{-7.160017, -11.801122, 
        16.134729}}],
    Line[{{-7.160017, -11.801122, 16.134729},{-7.637372, -12.540385, 
        16.598951}}],
    Line[{{-7.637372, -12.540385, 16.598951},{-8.140166, -13.288536, 
        17.167839}}],
    Line[{{-8.140166, -13.288536, 17.167839},{-8.666282, -14.033937, 
        17.849386}}],
    Line[{{-8.666282, -14.033937, 17.849386},{-9.212558, -14.762014, 
        18.650471}}],
    Line[{{-9.212558, -14.762014, 18.650471},{-9.774596, -15.455105, 
        19.576010}}],
    Line[{{-9.774596, -15.455105, 19.576010},{-10.346587, -16.092472, 
        20.628059}}],
    Line[{{-10.346587, -16.092472, 20.628059},{-10.921170, -16.650646, 
        21.804720}}],
    Line[{{-10.921170, -16.650646, 21.804720},{-11.489328, -17.104002, 
        23.099018}}],
    Line[{{-11.489328, -17.104002, 23.099018},{-12.040411, -17.425947, 
        24.497843}}],
    Line[{{-12.040411, -17.425947, 24.497843},{-12.562279, -17.590504, 
        25.981211}}],
    Line[{{-12.562279, -17.590504, 25.981211},{-13.041553, -17.574224, 
        27.521730}}],
    Line[{{-13.041553, -17.574224, 27.521730},{-13.464144, -17.358622, 
        29.085085}}],
    Line[{{-13.464144, -17.358622, 29.085085},{-13.815861, -16.932476, 
        30.631006}}],
    Line[{{-13.815861, -16.932476, 30.631006},{-14.083248, -16.293982, 
        32.115372}}],
    Line[{{-14.083248, -16.293982, 32.115372},{-14.254465, -15.452172, 
        33.493004}}],
    Line[{{-14.254465, -15.452172, 33.493004},{-14.320212, -14.427348, 
        34.721039}}],
    Line[{{-14.320212, -14.427348, 34.721039},{-14.274517, -13.250284, 
        35.762421}}],
    Line[{{-14.274517, -13.250284, 35.762421},{-14.115341, -11.960163, 
        36.589031}}],
    Line[{{-14.115341, -11.960163, 36.589031},{-13.844852, -10.601439, 
        37.183834}}],
    Line[{{-13.844852, -10.601439, 37.183834},{-13.469344, -9.220149, 
        37.541794}}],
    Line[{{-13.469344, -9.220149, 37.541794},{-12.998819, -7.860306, 
        37.669415}}],
    Line[{{-12.998819, -7.860306, 37.669415},{-12.446288, -6.560635, 
        37.583168}}],
    Line[{{-12.446288, -6.560635, 37.583168},{-11.826859, -5.352342, 
        37.306988}}],
    Line[{{-11.826859, -5.352342, 37.306988},{-11.156752, -4.257922, 
        36.869408}}],
    Line[{{-11.156752, -4.257922, 36.869408},{-10.452358, -3.291045, 
        36.300774}}],
    Line[{{-10.452358, -3.291045, 36.300774},{-9.729410, -2.457303, 
        35.630863}}],
    Line[{{-9.729410, -2.457303, 35.630863},{-9.002333, -1.755497, 
        34.887108}}],
    Line[{{-9.002333, -1.755497, 34.887108},{-8.283801, -1.179226, 
        34.093483}}],
    Line[{{-8.283801, -1.179226, 34.093483},{-7.584488, -0.718478, 
        33.269981}}],
    Line[{{-7.584488, -0.718478, 33.269981},{-6.912981, -0.361084, 
        32.432579}}],
    Line[{{-6.912981, -0.361084, 32.432579},{-6.275838, -0.093912, 
        31.593498}}],
    Line[{{-6.275838, -0.093912, 31.593498},{-5.677736, 0.096208, 
        30.761711}}],
    Line[{{-5.677736, 0.096208, 30.761711},{-5.121679, 0.221838, 29.943476}}],
    
    Line[{{-5.121679, 0.221838, 29.943476},{-4.609235, 0.294514, 29.142906}}],
    
    Line[{{-4.609235, 0.294514, 29.142906},{-4.140784, 0.324522, 28.362480}}],
    
    Line[{{-4.140784, 0.324522, 28.362480},{-3.715759, 0.320799, 27.603477}}],
    
    Line[{{-3.715759, 0.320799, 27.603477},{-3.332857, 0.290952, 26.866343}}],
    
    Line[{{-3.332857, 0.290952, 26.866343},{-2.990239, 0.241318, 26.150957}}],
    
    Line[{{-2.990239, 0.241318, 26.150957},{-2.685697, 0.177078, 25.456854}}],
    
    Line[{{-2.685697, 0.177078, 25.456854},{-2.416787, 0.102384, 24.783365}}],
    
    Line[{{-2.416787, 0.102384, 24.783365},{-2.180949, 0.020482, 24.129732}}],
    
    Line[{{-2.180949, 0.020482, 24.129732},{-1.975597, -0.066151, 
        23.495163}}],
    Line[{{-1.975597, -0.066151, 23.495163},{-1.798187, -0.155698, 
        22.878895}}],
    Line[{{-1.798187, -0.155698, 22.878895},{-1.646271, -0.246887, 
        22.280201}}],
    Line[{{-1.646271, -0.246887, 22.280201},{-1.517537, -0.338900, 
        21.698416}}],
    Line[{{-1.517537, -0.338900, 21.698416},{-1.409832, -0.431291, 
        21.132933}}],
    Line[{{-1.409832, -0.431291, 21.132933},{-1.321182, -0.523917, 
        20.583204}}],
    Line[{{-1.321182, -0.523917, 20.583204},{-1.249798, -0.616880, 
        20.048742}}],
    Line[{{-1.249798, -0.616880, 20.048742},{-1.194084, -0.710476, 
        19.529114}}],
    Line[{{-1.194084, -0.710476, 19.529114},{-1.152628, -0.805163, 
        19.023933}}],
    Line[{{-1.152628, -0.805163, 19.023933},{-1.124205, -0.901527, 
        18.532860}}],
    Line[{{-1.124205, -0.901527, 18.532860},{-1.107767, -1.000258, 
        18.055595}}],
    Line[{{-1.107767, -1.000258, 18.055595},{-1.102436, -1.102137, 
        17.591883}}],
    Line[{{-1.102436, -1.102137, 17.591883},{-1.107495, -1.208020, 
        17.141504}}],
    Line[{{-1.107495, -1.208020, 17.141504},{-1.122380, -1.318833, 
        16.704287}}],
    Line[{{-1.122380, -1.318833, 16.704287},{-1.146673, -1.435569, 
        16.280090}}],
    Line[{{-1.146673, -1.435569, 16.280090},{-1.180094, -1.559288, 
        15.868832}}],
    Line[{{-1.180094, -1.559288, 15.868832},{-1.222491, -1.691115, 
        15.470470}}],
    Line[{{-1.222491, -1.691115, 15.470470},{-1.273840, -1.832250, 
        15.085026}}],
    Line[{{-1.273840, -1.832250, 15.085026},{-1.334235, -1.983971, 
        14.712579}}],
    Line[{{-1.334235, -1.983971, 14.712579},{-1.403889, -2.147643, 
        14.353289}}],
    Line[{{-1.403889, -2.147643, 14.353289},{-1.483128, -2.324725, 
        14.007398}}],
    Line[{{-1.483128, -2.324725, 14.007398},{-1.572391, -2.516781, 
        13.675250}}],
    Line[{{-1.572391, -2.516781, 13.675250},{-1.672228, -2.725491, 
        13.357309}}],
    Line[{{-1.672228, -2.725491, 13.357309},{-1.783305, -2.952656, 
        13.054178}}],
    Line[{{-1.783305, -2.952656, 13.054178},{-1.906401, -3.200212, 
        12.766623}}],
    Line[{{-1.906401, -3.200212, 12.766623},{-2.042412, -3.470238, 
        12.495610}}],
    Line[{{-2.042412, -3.470238, 12.495610},{-2.192353, -3.764957, 
        12.242332}}],
    Line[{{-2.192353, -3.764957, 12.242332},{-2.357363, -4.086743, 
        12.008261}}],
    Line[{{-2.357363, -4.086743, 12.008261},{-2.538706, -4.438120, 
        11.795184}}],
    Line[{{-2.538706, -4.438120, 11.795184},{-2.737768, -4.821744, 
        11.605285}}],
    Line[{{-2.737768, -4.821744, 11.605285},{-2.956068, -5.240405, 
        11.441179}}],
    Line[{{-2.956068, -5.240405, 11.441179},{-3.195247, -5.696967, 
        11.306032}}],
    Line[{{-3.195247, -5.696967, 11.306032},{-3.457067, -6.194355, 
        11.203609}}],
    Line[{{-3.457067, -6.194355, 11.203609},{-3.743398, -6.735456, 
        11.138406}}],
    Line[{{-3.743398, -6.735456, 11.138406},{-4.056204, -7.323038, 
        11.115746}}],
    Line[{{-4.056204, -7.323038, 11.115746},{-4.397511, -7.959604, 
        11.141903}}],
    Line[{{-4.397511, -7.959604, 11.141903},{-4.769374, -8.647235, 
        11.224209}}],
    Line[{{-4.769374, -8.647235, 11.224209},{-5.173821, -9.387320, 
        11.371186}}],
    Line[{{-5.173821, -9.387320, 11.371186},{-5.612769, -10.180260, 
        11.592634}}],
    Line[{{-5.612769, -10.180260, 11.592634},{-6.087930, -11.025084, 
        11.899687}}],
    Line[{{-6.087930, -11.025084, 11.899687},{-6.600678, -11.918964, 
        12.304818}}],
    Line[{{-6.600678, -11.918964, 12.304818},{-7.151870, -12.856628, 
        12.821728}}],
    Line[{{-7.151870, -12.856628, 12.821728},{-7.741637, -13.829692, 
        13.465091}}],
    Line[{{-7.741637, -13.829692, 13.465091},{-8.369118, -14.825906, 
        14.250093}}],
    Line[{{-8.369118, -14.825906, 14.250093},{-9.032147, -15.828388, 
        15.191684}}],
    Line[{{-9.032147, -15.828388, 15.191684},{-9.726912, -16.814901, 
        16.303537}}],
    Line[{{-9.726912, -16.814901, 16.303537},{-10.447557, -17.757301, 
        17.596514}}],
    Line[{{-10.447557, -17.757301, 17.596514},{-11.185813, -18.621361, 
        19.076796}}],
    Line[{{-11.185813, -18.621361, 19.076796},{-11.930658, -19.367157, 
        20.743635}}],
    Line[{{-11.930658, -19.367157, 20.743635},{-12.668091, -19.950293, 
        22.586868}}],
    Line[{{-12.668091, -19.950293, 22.586868},{-13.381088, -20.324177, 
        24.584541}}],
    Line[{{-13.381088, -20.324177, 24.584541},{-14.049841, -20.443472, 
        26.701067}}],
    Line[{{-14.049841, -20.443472, 26.701067},{-14.652350, -20.268631, 
        28.886503}}],
    Line[{{-14.652350, -20.268631, 28.886503},{-15.165436, -19.771137, 
        31.077518}}],
    Line[{{-15.165436, -19.771137, 31.077518},{-15.566154, -18.938717, 
        33.200512}}],
    Line[{{-15.566154, -18.938717, 33.200512},{-15.833549, -17.779499, 
        35.177013}}],
    Line[{{-15.833549, -17.779499, 35.177013},{-15.950502, -16.324011, 
        36.930775}}],
    Line[{{-15.950502, -16.324011, 36.930775},{-15.905494, -14.624247, 
        38.395596}}],
    Line[{{-15.905494, -14.624247, 38.395596},{-15.693933, -12.749551, 
        39.522507}}],
    Line[{{-15.693933, -12.749551, 39.522507},{-15.318833, -10.779697, 
        40.284794}}],
    Line[{{-15.318833, -10.779697, 40.284794},{-14.790680, -8.796587, 
        40.679794}}],
    Line[{{-14.790680, -8.796587, 40.679794},{-14.126529, -6.876054, 
        40.727371}}],
    Line[{{-14.126529, -6.876054, 40.727371},{-13.348452, -5.081275, 
        40.465382}}],
    Line[{{-13.348452, -5.081275, 40.465382},{-12.481648, -3.458709, 
        39.943565}}],
    Line[{{-12.481648, -3.458709, 39.943565},{-11.552472, -2.036848, 
        39.216946}}],
    Line[{{-11.552472, -2.036848, 39.216946},{-10.586650, -0.827380, 
        38.340050}}],
    Line[{{-10.586650, -0.827380, 38.340050},{-9.607868, 0.172008, 
        37.362587}}],
    Line[{{-9.607868, 0.172008, 37.362587},{-8.636806, 0.974064, 36.326828}}],
    
    Line[{{-8.636806, 0.974064, 36.326828},{-7.690603, 1.598323, 35.266518}}],
    
    Line[{{-7.690603, 1.598323, 35.266518},{-6.782712, 2.067930, 34.207031}}],
    
    Line[{{-6.782712, 2.067930, 34.207031},{-5.923035, 2.407121, 33.166241}}],
    
    Line[{{-5.923035, 2.407121, 33.166241},{-5.118243, 2.639449, 32.155788}}],
    
    Line[{{-5.118243, 2.639449, 32.155788},{-4.372214, 2.786648, 31.182459}}],
    
    Line[{{-4.372214, 2.786648, 31.182459},{-3.686505, 2.868030, 30.249437}}],
    
    Line[{{-3.686505, 2.868030, 30.249437},{-3.060809, 2.900261, 29.357420}}],
    
    Line[{{-3.060809, 2.900261, 29.357420},{-2.493394, 2.897384, 28.505482}}],
    
    Line[{{-2.493394, 2.897384, 28.505482},{-1.981475, 2.871004, 27.691738}}],
    
    Line[{{-1.981475, 2.871004, 27.691738},{-1.521533, 2.830549, 26.913816}}],
    
    Line[{{-1.521533, 2.830549, 26.913816},{-1.109585, 2.783560, 26.169197}}],
    
    Line[{{-1.109585, 2.783560, 26.169197},{-0.741385, 2.735984, 25.455402}}],
    
    Line[{{-0.741385, 2.735984, 25.455402},{-0.412591, 2.692447, 24.770136}}],
    
    Line[{{-0.412591, 2.692447, 24.770136},{-0.118890, 2.656501, 24.111332}}],
    
    Line[{{-0.118890, 2.656501, 24.111332},{0.143917, 2.630837, 23.477196}}],
    Line[{{0.143917, 2.630837, 23.477196},{0.379851, 2.617475, 22.866194}}],
    Line[{{0.379851, 2.617475, 22.866194},{0.592716, 2.617916, 22.277042}}],
    Line[{{0.592716, 2.617916, 22.277042},{0.786079, 2.633281, 21.708689}}],
    Line[{{0.786079, 2.633281, 21.708689},{0.963259, 2.664412, 21.160284}}],
    Line[{{0.963259, 2.664412, 21.160284},{1.127329, 2.711968, 20.631170}}],
    Line[{{1.127329, 2.711968, 20.631170},{1.281127, 2.776499, 20.120859}}],
    Line[{{1.281127, 2.776499, 20.120859},{1.427271, 2.858500, 19.629011}}],
    Line[{{1.427271, 2.858500, 19.629011},{1.568175, 2.958468, 19.155439}}],
    Line[{{1.568175, 2.958468, 19.155439},{1.706074, 3.076934, 18.700090}}],
    Line[{{1.706074, 3.076934, 18.700090},{1.843041, 3.214493, 18.263054}}],
    Line[{{1.843041, 3.214493, 18.263054},{1.981017, 3.371829, 17.844566}}],
    Line[{{1.981017, 3.371829, 17.844566},{2.121823, 3.549733, 17.445011}}],
    Line[{{2.121823, 3.549733, 17.445011},{2.267191, 3.749111, 17.064939}}],
    Line[{{2.267191, 3.749111, 17.064939},{2.418779, 3.970994, 16.705084}}],
    Line[{{2.418779, 3.970994, 16.705084},{2.578192, 4.216542, 16.366381}}],
    Line[{{2.578192, 4.216542, 16.366381},{2.746999, 4.487035, 16.049997}}],
    Line[{{2.746999, 4.487035, 16.049997},{2.926747, 4.783873, 15.757362}}],
    Line[{{2.926747, 4.783873, 15.757362},{3.118973, 5.108555, 15.490203}}],
    Line[{{3.118973, 5.108555, 15.490203},{3.325215, 5.462657, 15.250589}}],
    Line[{{3.325215, 5.462657, 15.250589},{3.547019, 5.847808, 15.040975}}],
    Line[{{3.547019, 5.847808, 15.040975},{3.785937, 6.265635, 14.864257}}],
    Line[{{3.785937, 6.265635, 14.864257},{4.043525, 6.717706, 14.723830}}],
    Line[{{4.043525, 6.717706, 14.723830},{4.321340, 7.205469, 14.623643}}],
    Line[{{4.321340, 7.205469, 14.623643},{4.620911, 7.730119, 14.568263}}],
    Line[{{4.620911, 7.730119, 14.568263},{4.943723, 8.292506, 14.562929}}],
    Line[{{4.943723, 8.292506, 14.562929},{5.291180, 8.892966, 14.613605}}],
    Line[{{5.291180, 8.892966, 14.613605},{5.664539, 9.531083, 14.726998}}],
    Line[{{5.664539, 9.531083, 14.726998},{6.064872, 10.205534, 14.910586}}],
    Line[{{6.064872, 10.205534, 14.910586},{6.492952, 10.913718, 15.172553}}],
    
    Line[{{6.492952, 10.913718, 15.172553},{6.949162, 11.651479, 15.521709}}],
    
    Line[{{6.949162, 11.651479, 15.521709},{7.433358, 12.412714, 15.967285}}],
    
    Line[{{7.433358, 12.412714, 15.967285},{7.944725, 13.189006, 16.518675}}],
    
    Line[{{7.944725, 13.189006, 16.518675},{8.481596, 13.969202, 17.184978}}],
    
    Line[{{8.481596, 13.969202, 17.184978},{9.041252, 14.739065, 17.974415}}],
    
    Line[{{9.041252, 14.739065, 17.974415},{9.619717, 15.481028, 18.893497}}],
    
    Line[{{9.619717, 15.481028, 18.893497},{
      10.211558, 16.174095, 19.946129}}],
    Line[{{10.211558, 16.174095, 19.946129},{
      10.809697, 16.793972, 21.132437}}],
    Line[{{10.809697, 16.793972, 21.132437},{
      11.405284, 17.313721, 22.447454}}],
    Line[{{11.405284, 17.313721, 22.447454},{
      11.987654, 17.704685, 23.879972}}],
    Line[{{11.987654, 17.704685, 23.879972},{
      12.544409, 17.938074, 25.411428}}],
    Line[{{12.544409, 17.938074, 25.411428},{
      13.061666, 17.987024, 27.015282}}],
    Line[{{13.061666, 17.987024, 27.015282},{
      13.524501, 17.829111, 28.657003}}],
    Line[{{13.524501, 17.829111, 28.657003},{
      13.917595, 17.449032, 30.294981}}],
    Line[{{13.917595, 17.449032, 30.294981},{
      14.226084, 16.841154, 31.882414}}],
    Line[{{14.226084, 16.841154, 31.882414},{
      14.436528, 16.011465, 33.370209}}],
    Line[{{14.436528, 16.011465, 33.370209},{
      14.537947, 14.978413, 34.710686}}],
    Line[{{14.537947, 14.978413, 34.710686},{
      14.522745, 13.772473, 35.861488}}],
    Line[{{14.522745, 13.772473, 35.861488},{
      14.387459, 12.434182, 36.789253}}],
    Line[{{14.387459, 12.434182, 36.789253},{
      14.133177, 11.010935, 37.472424}}],
    Line[{{14.133177, 11.010935, 37.472424},{
      13.765564, 9.552920, 37.902649}}],
    Line[{{13.765564, 9.552920, 37.902649},{13.294482, 8.108891, 38.084644}}],
    
    Line[{{13.294482, 8.108891, 38.084644},{12.733273, 6.722406, 38.034607}}],
    
    Line[{{12.733273, 6.722406, 38.034607},{12.097781, 5.429049, 37.777557}}],
    
    Line[{{12.097781, 5.429049, 37.777557},{11.405278, 4.254873, 37.344151}}],
    
    Line[{{11.405278, 4.254873, 37.344151},{10.673393, 3.216082, 36.767464}}],
    
    Line[{{10.673393, 3.216082, 36.767464},{9.919168, 2.319745, 36.080242}}],
    Line[{{9.919168, 2.319745, 36.080242},{9.158310, 1.565202, 35.312771}}],
    Line[{{9.158310, 1.565202, 35.312771},{8.404663, 0.945837, 34.491547}}],
    Line[{{8.404663, 0.945837, 34.491547},{7.669914, 0.450883, 33.638638}}],
    Line[{{7.669914, 0.450883, 33.638638},{6.963474, 0.067087, 32.771599}}],
    Line[{{6.963474, 0.067087, 32.771599},{6.292539, -0.219927, 31.903790}}],
    Line[{{6.292539, -0.219927, 31.903790},{5.662239, -0.424601, 31.044897}}],
    
    Line[{{5.662239, -0.424601, 31.044897},{5.075868, -0.560713, 30.201590}}],
    
    Line[{{5.075868, -0.560713, 30.201590},{4.535149, -0.640900, 29.378145}}],
    
    Line[{{4.535149, -0.640900, 29.378145},{4.040505, -0.676412, 28.577038}}],
    
    Line[{{4.040505, -0.676412, 28.577038},{3.591317, -0.677011, 27.799433}}],
    
    Line[{{3.591317, -0.677011, 27.799433},{3.186171, -0.650989, 27.045591}}],
    
    Line[{{3.186171, -0.650989, 27.045591},{2.823062, -0.605248, 26.315186}}],
    
    Line[{{2.823062, -0.605248, 26.315186},{2.499586, -0.545431, 25.607525}}],
    
    Line[{{2.499586, -0.545431, 25.607525},{2.213083, -0.476058, 24.921730}}],
    
    Line[{{2.213083, -0.476058, 24.921730},{1.960763, -0.400682, 24.256834}}],
    
    Line[{{1.960763, -0.400682, 24.256834},{1.739809, -0.322022, 23.611868}}],
    
    Line[{{1.739809, -0.322022, 23.611868},{1.547444, -0.242106, 22.985899}}],
    
    Line[{{1.547444, -0.242106, 22.985899},{1.380992, -0.162380, 22.378057}}],
    
    Line[{{1.380992, -0.162380, 22.378057},{1.237919, -0.083820, 21.787542}}],
    
    Line[{{1.237919, -0.083820, 21.787542},{1.115857, -0.007019, 21.213633}}],
    
    Line[{{1.115857, -0.007019, 21.213633},{1.012625, 0.067737, 20.655672}}],
    Line[{{1.012625, 0.067737, 20.655672},{0.926230, 0.140403, 20.113071}}],
    Line[{{0.926230, 0.140403, 20.113071},{0.854877, 0.211121, 19.585300}}],
    Line[{{0.854877, 0.211121, 19.585300},{0.796963, 0.280182, 19.071877}}],
    Line[{{0.796963, 0.280182, 19.071877},{0.751069, 0.347988, 18.572359}}],
    Line[{{0.751069, 0.347988, 18.572359},{0.715954, 0.415026, 18.086351}}],
    Line[{{0.715954, 0.415026, 18.086351},{0.690546, 0.481848, 17.613483}}],
    Line[{{0.690546, 0.481848, 17.613483},{0.673930, 0.549058, 17.153419}}],
    Line[{{0.673930, 0.549058, 17.153419},{0.665336, 0.617298, 16.705845}}],
    Line[{{0.665336, 0.617298, 16.705845},{0.664132, 0.687245, 16.270473}}],
    Line[{{0.664132, 0.687245, 16.270473},{0.669810, 0.759607, 15.847045}}],
    Line[{{0.669810, 0.759607, 15.847045},{0.681982, 0.835122, 15.435315}}],
    Line[{{0.681982, 0.835122, 15.435315},{0.700365, 0.914560, 15.035069}}],
    Line[{{0.700365, 0.914560, 15.035069},{0.724782, 0.998725, 14.646117}}],
    Line[{{0.724782, 0.998725, 14.646117},{0.755147, 1.088465, 14.268293}}],
    Line[{{0.755147, 1.088465, 14.268293},{0.791469, 1.184670, 13.901466}}],
    Line[{{0.791469, 1.184670, 13.901466},{0.833840, 1.288288, 13.545535}}],
    Line[{{0.833840, 1.288288, 13.545535},{0.882440, 1.400328, 13.200439}}],
    Line[{{0.882440, 1.400328, 13.200439},{0.937529, 1.521873, 12.866160}}],
    Line[{{0.937529, 1.521873, 12.866160},{0.999449, 1.654087, 12.542735}}],
    Line[{{0.999449, 1.654087, 12.542735},{1.068625, 1.798230, 12.230258}}],
    Line[{{1.068625, 1.798230, 12.230258},{1.145568, 1.955665, 11.928895}}],
    Line[{{1.145568, 1.955665, 11.928895},{1.230875, 2.127875, 11.638897}}],
    Line[{{1.230875, 2.127875, 11.638897},{1.325231, 2.316474, 11.360616}}],
    Line[{{1.325231, 2.316474, 11.360616},{1.429420, 2.523217, 11.094520}}],
    Line[{{1.429420, 2.523217, 11.094520},{1.544324, 2.750019, 10.841223}}],
    Line[{{1.544324, 2.750019, 10.841223},{1.670931, 2.998962, 10.601503}}],
    Line[{{1.670931, 2.998962, 10.601503},{1.810344, 3.272311, 10.376352}}],
    Line[{{1.810344, 3.272311, 10.376352},{1.963782, 3.572521, 10.166993}}],
    Line[{{1.963782, 3.572521, 10.166993},{2.132595, 3.902243, 9.974949}}],
    Line[{{2.132595, 3.902243, 9.974949},{2.318264, 4.264329, 9.802091}}],
    Line[{{2.318264, 4.264329, 9.802091},{2.522411, 4.661829, 9.650697}}],
    Line[{{2.522411, 4.661829, 9.650697},{2.746802, 5.097965, 9.523564}}],
    Line[{{2.746802, 5.097965, 9.523564},{2.993351, 5.576128, 9.424054}}],
    Line[{{2.993351, 5.576128, 9.424054},{3.264117, 6.099800, 9.356249}}],
    Line[{{3.264117, 6.099800, 9.356249},{3.561297, 6.672516, 9.325043}}],
    Line[{{3.561297, 6.672516, 9.325043},{3.887214, 7.297736, 9.336301}}],
    Line[{{3.887214, 7.297736, 9.336301},{4.244289, 7.978714, 9.397001}}],
    Line[{{4.244289, 7.978714, 9.397001},{4.635003, 8.718277, 9.515409}}],
    Line[{{4.635003, 8.718277, 9.515409},{5.061841, 9.518577, 9.701219}}],
    Line[{{5.061841, 9.518577, 9.701219},{5.527213, 10.380715, 9.965724}}],
    Line[{{5.527213, 10.380715, 9.965724},{6.033327, 11.304270, 10.321922}}],
    Line[{{6.033327, 11.304270, 10.321922},{6.582047, 12.286701, 10.784548}}],
    
    Line[{{6.582047, 12.286701, 10.784548},{7.174690, 13.322642, 11.370006}}],
    
    Line[{{7.174690, 13.322642, 11.370006},{7.811760, 14.403016, 12.096114}}],
    
    Line[{{7.811760, 14.403016, 12.096114},{8.492634, 15.514070, 12.981589}}],
    
    Line[{{8.492634, 15.514070, 12.981589},{9.215171, 16.636320, 14.045164}}],
    
    Line[{{9.215171, 16.636320, 14.045164},{9.975262, 17.743540, 15.304272}}],
    
    Line[{{9.975262, 17.743540, 15.304272},{
      10.766329, 18.801973, 16.773102}}],
    Line[{{10.766329, 18.801973, 16.773102},{
      11.578828, 19.769983, 18.460182}}],
    Line[{{11.578828, 19.769983, 18.460182},{
      12.399796, 20.598480, 20.365335}}],
    Line[{{12.399796, 20.598480, 20.365335},{
      13.212526, 21.232510, 22.476355}}],
    Line[{{13.212526, 21.232510, 22.476355},{
      13.996508, 21.614294, 24.765759}}],
    Line[{{13.996508, 21.614294, 24.765759},{
      14.727727, 21.687960, 27.188328}}],
    Line[{{14.727727, 21.687960, 27.188328},{
      15.379480, 21.405794, 29.680254}}],
    Line[{{15.379480, 21.405794, 29.680254},{
      15.923740, 20.735422, 32.160755}}],
    Line[{{15.923740, 20.735422, 32.160755},{
      16.333109, 19.666756, 34.536915}}],
    Line[{{16.333109, 19.666756, 34.536915},{
      16.583122, 18.217102, 36.711464}}],
    Line[{{16.583122, 18.217102, 36.711464},{
      16.654715, 16.433069, 38.592857}}],
    Line[{{16.654715, 16.433069, 38.592857},{
      16.536396, 14.387877, 40.105942}}],
    Line[{{16.536396, 14.387877, 40.105942},{
      16.225754, 12.174311, 41.200848}}],
    Line[{{16.225754, 12.174311, 41.200848},{
      15.729984, 9.894421, 41.858307}}],
    Line[{{15.729984, 9.894421, 41.858307},{15.065283, 7.647871, 42.090027}}],
    
    Line[{{15.065283, 7.647871, 42.090027},{14.255238, 5.521656, 41.934452}}],
    
    Line[{{14.255238, 5.521656, 41.934452},{13.328555, 3.582812, 41.449226}}],
    
    Line[{{13.328555, 3.582812, 41.449226},{12.316473, 1.875112, 40.702190}}],
    
    Line[{{12.316473, 1.875112, 40.702190},{11.250302, 0.419511, 39.762890}}],
    
    Line[{{11.250302, 0.419511, 39.762890},{
      10.159387, -0.782624, 38.695885}}],
    Line[{{10.159387, -0.782624, 38.695885},{
      9.069649, -1.744790, 37.556515}}],
    Line[{{9.069649, -1.744790, 37.556515},{8.002745, -2.490316, 36.388954}}],
    
    Line[{{8.002745, -2.490316, 36.388954},{6.975760, -3.047841, 35.226135}}],
    
    Line[{{6.975760, -3.047841, 35.226135},{6.001322, -3.447730, 34.090855}}],
    
    Line[{{6.001322, -3.447730, 34.090855},{5.087987, -3.719552, 32.997509}}],
    
    Line[{{5.087987, -3.719552, 32.997509},{4.240789, -3.890495, 31.954010}}],
    
    Line[{{4.240789, -3.890495, 31.954010},{3.461848, -3.984557, 30.963556}}],
    
    Line[{{3.461848, -3.984557, 30.963556},{2.750963, -4.022269, 30.026146}}],
    
    Line[{{2.750963, -4.022269, 30.026146},{2.106165, -4.020761, 29.139774}}],
    
    Line[{{2.106165, -4.020761, 29.139774},{1.524196, -3.994049, 28.301329}}],
    
    Line[{{1.524196, -3.994049, 28.301329},{1.000910, -3.953398, 27.507217}}],
    
    Line[{{1.000910, -3.953398, 27.507217},{0.531600, -3.907732, 26.753780}}],
    
    Line[{{0.531600, -3.907732, 26.753780},{0.111255, -3.864019, 26.037548}}],
    
    Line[{{
      0.111255, -3.864019, 26.037548},{-0.265242, -3.827634, 25.355396}}],
    Line[{{-0.265242, -3.827634, 25.355396},{-0.602968, -3.802668, 
        24.704597}}],
    Line[{{-0.602968, -3.802668, 24.704597},{-0.906857, -3.792199, 
        24.082853}}],
    Line[{{-0.906857, -3.792199, 24.082853},{-1.181625, -3.798523, 
        23.488274}}],
    Line[{{-1.181625, -3.798523, 23.488274},{-1.431728, -3.823339, 
        22.919357}}],
    Line[{{-1.431728, -3.823339, 22.919357},{-1.661337, -3.867905, 
        22.374947}}],
    Line[{{-1.661337, -3.867905, 22.374947},{-1.874329, -3.933168, 
        21.854208}}],
    Line[{{-1.874329, -3.933168, 21.854208},{-2.074294, -4.019860, 
        21.356590}}],
    Line[{{-2.074294, -4.019860, 21.356590},{-2.264540, -4.128583, 
        20.881807}}],
    Line[{{-2.264540, -4.128583, 20.881807},{-2.448114, -4.259872, 
        20.429813}}],
    Line[{{-2.448114, -4.259872, 20.429813},{-2.627825, -4.414240, 
        20.000803}}],
    Line[{{-2.627825, -4.414240, 20.000803},{-2.806262, -4.592211, 
        19.595196}}],
    Line[{{-2.806262, -4.592211, 19.595196},{-2.985819, -4.794351, 
        19.213642}}],
    Line[{{-2.985819, -4.794351, 19.213642},{-3.168719, -5.021269, 
        18.857033}}],
    Line[{{-3.168719, -5.021269, 18.857033},{-3.357033, -5.273633, 
        18.526510}}],
    Line[{{-3.357033, -5.273633, 18.526510},{-3.552703, -5.552149, 
        18.223482}}],
    Line[{{-3.552703, -5.552149, 18.223482},{-3.757553, -5.857558, 
        17.949654}}],
    Line[{{-3.757553, -5.857558, 17.949654},{-3.973304, -6.190600, 
        17.707047}}],
    Line[{{-3.973304, -6.190600, 17.707047},{-4.201583, -6.551980, 
        17.498026}}],
    Line[{{-4.201583, -6.551980, 17.498026},{-4.443926, -6.942319, 
        17.325333}}],
    Line[{{-4.443926, -6.942319, 17.325333},{-4.701775, -7.362084, 
        17.192120}}],
    Line[{{-4.701775, -7.362084, 17.192120},{-4.976467, -7.811516, 
        17.101963}}],
    Line[{{-4.976467, -7.811516, 17.101963},{-5.269224, -8.290522, 
        17.058897}}],
    Line[{{-5.269224, -8.290522, 17.058897},{-5.581116, -8.798553, 
        17.067417}}],
    Line[{{-5.581116, -8.798553, 17.067417},{-5.913035, -9.334475, 
        17.132477}}],
    Line[{{-5.913035, -9.334475, 17.132477},{-6.265648, -9.896395, 
        17.259462}}],
    Line[{{-6.265648, -9.896395, 17.259462},{-6.639326, -10.481463, 
        17.454115}}],
    Line[{{-6.639326, -10.481463, 17.454115},{-7.034088, -11.085691, 
        17.722446}}],
    Line[{{-7.034088, -11.085691, 17.722446},{-7.449500, -11.703696, 
        18.070562}}],
    Line[{{-7.449500, -11.703696, 18.070562},{-7.884587, -12.328524, 
        18.504433}}],
    Line[{{-7.884587, -12.328524, 18.504433},{-8.337713, -12.951393, 
        19.029585}}],
    Line[{{-8.337713, -12.951393, 19.029585},{-8.806473, -13.561558, 
        19.650702}}],
    Line[{{-8.806473, -13.561558, 19.650702},{-9.287569, -14.146241, 
        20.371094}}],
    Line[{{-9.287569, -14.146241, 20.371094},{-9.776697, -14.690574, 
        21.192146}}],
    Line[{{-9.776697, -14.690574, 21.192146},{-10.268458, -15.177865, 
        22.112606}}],
    Line[{{-10.268458, -15.177865, 22.112606},{-10.756312, -15.589980, 
        23.127943}}],
    Line[{{-10.756312, -15.589980, 23.127943},{-11.232546, -15.907887, 
        24.229593}}],
    Line[{{-11.232546, -15.907887, 24.229593},{-11.688395, -16.112738, 
        25.404526}}],
    Line[{{-11.688395, -16.112738, 25.404526},{-12.114158, -16.186878, 
        26.634809}}],
    Line[{{-12.114158, -16.186878, 26.634809},{-12.499512, -16.115353, 
        27.897734}}],
    Line[{{-12.499512, -16.115353, 27.897734},{-12.833876, -15.887319, 
        29.166206}}],
    Line[{{-12.833876, -15.887319, 29.166206},{-13.106904, -15.497479, 
        30.409800}}],
    Line[{{-13.106904, -15.497479, 30.409800},{-13.309042, -14.947210, 
        31.596167}}],
    Line[{{-13.309042, -14.947210, 31.596167},{-13.432138, -14.245328, 
        32.693005}}],
    Line[{{-13.432138, -14.245328, 32.693005},{-13.470012, -13.407982, 
        33.670177}}],
    Line[{{-13.470012, -13.407982, 33.670177},{-13.418937, -12.458067, 
        34.501842}}],
    Line[{{-13.418937, -12.458067, 34.501842},{-13.277996, -11.423769, 
        35.168293}}],
    Line[{{-13.277996, -11.423769, 35.168293},{-13.049220, -10.336622, 
        35.657211}}],
    Line[{{-13.049220, -10.336622, 35.657211},{-12.737516, -9.229232, 
        35.964214}}],
    Line[{{-12.737516, -9.229232, 35.964214},{-12.350387, -8.132997, 
        36.092632}}],
    Line[{{-12.350387, -8.132997, 36.092632},{-11.897470, -7.076124, 
        36.052563}}],
    Line[{{-11.897470, -7.076124, 36.052563},{-11.389948, -6.082126, 
        35.859432}}],
    Line[{{-11.389948, -6.082126, 35.859432},{-10.839918, -5.168940, 
        35.532284}}],
    Line[{{-10.839918, -5.168940, 35.532284},{-10.259749, -4.348675, 
        35.092041}}],
    Line[{{-10.259749, -4.348675, 35.092041},{-9.661510, -3.627885, 
        34.559937}}],
    Line[{{-9.661510, -3.627885, 34.559937},{-9.056506, -3.008237, 
        33.956261}}],
    Line[{{-9.056506, -3.008237, 33.956261},{-8.454921, -2.487411, 
        33.299488}}],
    Line[{{-8.454921, -2.487411, 33.299488},{-7.865597, -2.060083, 
        32.605728}}],
    Line[{{-7.865597, -2.060083, 32.605728},{-7.295921, -1.718887, 
        31.888542}}],
    Line[{{-7.295921, -1.718887, 31.888542},{-6.751812, -1.455254, 
        31.158949}}],
    Line[{{-6.751812, -1.455254, 31.158949},{-6.237782, -1.260117, 
        30.425627}}],
    Line[{{-6.237782, -1.260117, 30.425627},{-5.757050, -1.124449, 
        29.695208}}],
    Line[{{-5.757050, -1.124449, 29.695208},{-5.311685, -1.039653, 
        28.972588}}],
    Line[{{-5.311685, -1.039653, 28.972588},{-4.902773, -0.997816, 
        28.261271}}],
    Line[{{-4.902773, -0.997816, 28.261271},{-4.530585, -0.991861, 
        27.563667}}],
    Line[{{-4.530585, -0.991861, 27.563667},{-4.194735, -1.015610, 
        26.881355}}],
    Line[{{-4.194735, -1.015610, 26.881355},{-3.894328, -1.063796, 
        26.215305}}],
    Line[{{-3.894328, -1.063796, 26.215305},{-3.628099, -1.132025, 
        25.566051}}],
    Line[{{-3.628099, -1.132025, 25.566051},{-3.394522, -1.216719, 
        24.933838}}],
    Line[{{-3.394522, -1.216719, 24.933838},{-3.191915, -1.315043, 
        24.318720}}],
    Line[{{-3.191915, -1.315043, 24.318720},{-3.018517, -1.424824, 
        23.720636}}],
    Line[{{-3.018517, -1.424824, 23.720636},{-2.872558, -1.544477, 
        23.139475}}],
    Line[{{-2.872558, -1.544477, 23.139475},{-2.752309, -1.672921, 
        22.575104}}],
    Line[{{-2.752309, -1.672921, 22.575104},{-2.656127, -1.809519, 
        22.027411}}],
    Line[{{-2.656127, -1.809519, 22.027411},{-2.582482, -1.954008, 
        21.496305}}],
    Line[{{-2.582482, -1.954008, 21.496305},{-2.529979, -2.106452, 
        20.981754}}],
    Line[{{-2.529979, -2.106452, 20.981754},{-2.497380, -2.267187, 
        20.483780}}],
    Line[{{-2.497380, -2.267187, 20.483780},{-2.483604, -2.436787, 
        20.002472}}],
    Line[{{-2.483604, -2.436787, 20.002472},{-2.487740, -2.616030, 
        19.537998}}],
    Line[{{-2.487740, -2.616030, 19.537998},{-2.509045, -2.805875, 
        19.090616}}],
    Line[{{-2.509045, -2.805875, 19.090616},{-2.546948, -3.007429, 
        18.660683}}],
    Line[{{-2.546948, -3.007429, 18.660683},{-2.601043, -3.221941, 
        18.248667}}],
    Line[{{-2.601043, -3.221941, 18.248667},{-2.671086, -3.450784, 
        17.855171}}],
    Line[{{-2.671086, -3.450784, 17.855171},{-2.756996, -3.695439, 
        17.480938}}],
    Line[{{-2.756996, -3.695439, 17.480938},{-2.858843, -3.957489, 
        17.126884}}],
    Line[{{-2.858843, -3.957489, 17.126884},{-2.976845, -4.238604, 
        16.794117}}],
    Line[{{-2.976845, -4.238604, 16.794117},{-3.111363, -4.540531, 
        16.483973}}],
    Line[{{-3.111363, -4.540531, 16.483973},{-3.262894, -4.865077, 
        16.198034}}],
    Line[{{-3.262894, -4.865077, 16.198034},{-3.432059, -5.214087, 
        15.938188}}],
    Line[{{-3.432059, -5.214087, 15.938188},{-3.619599, -5.589420, 
        15.706652}}],
    Line[{{-3.619599, -5.589420, 15.706652},{-3.826360, -5.992919, 
        15.506022}}],
    Line[{{-3.826360, -5.992919, 15.506022},{-4.053278, -6.426342, 
        15.339337}}],
    Line[{{-4.053278, -6.426342, 15.339337},{-4.301365, -6.891334, 
        15.210111}}],
    Line[{{-4.301365, -6.891334, 15.210111},{-4.571682, -7.389319, 
        15.122401}}],
    Line[{{-4.571682, -7.389319, 15.122401},{-4.865305, -7.921391, 
        15.080854}}],
    Line[{{-4.865305, -7.921391, 15.080854},{-5.183303, -8.488234, 
        15.090755}}],
    Line[{{-5.183303, -8.488234, 15.090755},{-5.526669, -9.089885, 
        15.158058}}],
    Line[{{-5.526669, -9.089885, 15.158058},{-5.896275, -9.725607, 
        15.289402}}],
    Line[{{-5.896275, -9.725607, 15.289402},{-6.292788, -10.393604, 
        15.492088}}],
    Line[{{-6.292788, -10.393604, 15.492088},{-6.716582, -11.090776, 
        15.774019}}],
    Line[{{-6.716582, -11.090776, 15.774019},{-7.167619, -11.812381, 
        16.143555}}],
    Line[{{-7.167619, -11.812381, 16.143555},{-7.645326, -12.551721, 
        16.609312}}],
    Line[{{-7.645326, -12.551721, 16.609312},{-8.148438, -13.299775, 
        17.179838}}],
    Line[{{-8.148438, -13.299775, 17.179838},{-8.674822, -14.044859, 
        17.863134}}],
    Line[{{-8.674822, -14.044859, 17.863134},{-9.221296, -14.772362, 
        18.666014}}],
    Line[{{-9.221296, -14.772362, 18.666014},{-9.783447, -15.464586, 
        19.593369}}],
    Line[{{-9.783447, -15.464586, 19.593369},{-10.355442, -16.100729, 
        20.647223}}],
    Line[{{-10.355442, -16.100729, 20.647223},{-10.929889, -16.657286, 
        21.825575}}],
    Line[{{-10.929889, -16.657286, 21.825575},{-11.497752, -17.108637, 
        23.121372}}],
    Line[{{-11.497752, -17.108637, 23.121372},{-12.048364, -17.428200, 
        24.521418}}],
    Line[{{-12.048364, -17.428200, 24.521418},{-12.569553, -17.590002, 
        26.005569}}],
    Line[{{-12.569553, -17.590002, 26.005569},{-13.047947, -17.570696, 
        27.546392}}],
    Line[{{-13.047947, -17.570696, 27.546392},{-13.469442, -17.351881, 
        29.109440}}],
    Line[{{-13.469442, -17.351881, 29.109440},{-13.819863, -16.922478, 
        30.654400}}],
    Line[{{-13.819863, -16.922478, 30.654400},{-14.085769, -16.280830, 
        32.137119}}],
    Line[{{-14.085769, -16.280830, 32.137119},{-14.255357, -15.436152, 
        33.512417}}],
    Line[{{-14.255357, -15.436152, 33.512417},{-14.319375, -14.408920, 
        34.737514}}],
    Line[{{-14.319375, -14.408920, 34.737514},{-14.271918, -13.230052, 
        35.775513}}],
    Line[{{-14.271918, -13.230052, 35.775513},{-14.111008, -11.938808, 
        36.598442}}],
    Line[{{-14.111008, -11.938808, 36.598442},{-13.838874, -10.579685, 
        37.189449}}],
    Line[{{-13.838874, -10.579685, 37.189449},{-13.461872, -9.198732, 
        37.543678}}],
    Line[{{-13.461872, -9.198732, 37.543678},{-12.990061, -7.839866, 
        37.667816}}],
    Line[{{-12.990061, -7.839866, 37.667816},{-12.436485, -6.541702, 
        37.578468}}],
    Line[{{-12.436485, -6.541702, 37.578468},{-11.816275, -5.335286, 
        37.299656}}],
    Line[{{-11.816275, -5.335286, 37.299656},{-11.145653, -4.242981, 
        36.859940}}],
    Line[{{-11.145653, -4.242981, 36.859940},{-10.441001, -3.278323, 
        36.289661}}],
    Line[{{-10.441001, -3.278323, 36.289661},{-9.718030, -2.446787, 
        35.618561}}],
    Line[{{-9.718030, -2.446787, 35.618561},{-8.991138, -1.747087, 
        34.874023}}],
    Line[{{-8.991138, -1.747087, 34.874023},{-8.272965, -1.172757, 
        34.079948}}],
    Line[{{-8.272965, -1.172757, 34.079948},{-7.574153, -0.713748, 
        33.256271}}],
    Line[{{-7.574153, -0.713748, 33.256271},{-6.903255, -0.357873, 
        32.418892}}],
    Line[{{-6.903255, -0.357873, 32.418892},{-6.266796, -0.092000, 
        31.579985}}],
    Line[{{-6.266796, -0.092000, 31.579985},{-5.669428, 0.097031, 
        30.748474}}],
    Line[{{-5.669428, 0.097031, 30.748474},{-5.114128, 0.221766, 29.930582}}],
    
    Line[{{-5.114128, 0.221766, 29.930582},{-4.602445, 0.293719, 29.130390}}],
    
    Line[{{-4.602445, 0.293719, 29.130390},{-4.134746, 0.323151, 28.350359}}],
    
    Line[{{-4.134746, 0.323151, 28.350359},{-3.710448, 0.318979, 27.591757}}],
    
    Line[{{-3.710448, 0.318979, 27.591757},{-3.328242, 0.288784, 26.855015}}],
    
    Line[{{-3.328242, 0.288784, 26.855015},{-2.986283, 0.238885, 26.140009}}],
    
    Line[{{-2.986283, 0.238885, 26.140009},{-2.682359, 0.174446, 25.446274}}],
    
    Line[{{-2.682359, 0.174446, 25.446274},{-2.414024, 0.099601, 24.773136}}],
    
    Line[{{-2.414024, 0.099601, 24.773136},{-2.178720, 0.017585, 24.119835}}],
    
    Line[{{-2.178720, 0.017585, 24.119835},{-1.973860, -0.069139, 
        23.485588}}],
    Line[{{-1.973860, -0.069139, 23.485588},{-1.796903, -0.158761, 
        22.869625}}],
    Line[{{-1.796903, -0.158761, 22.869625},{-1.645404, -0.250018, 
        22.271225}}],
    Line[{{-1.645404, -0.250018, 22.271225},{-1.517052, -0.342099, 
        21.689722}}],
    Line[{{-1.517052, -0.342099, 21.689722},{-1.409701, -0.434564, 
        21.124512}}],
    Line[{{-1.409701, -0.434564, 21.124512},{-1.321378, -0.527273, 
        20.575050}}],
    Line[{{-1.321378, -0.527273, 20.575050},{-1.250300, -0.620332, 
        20.040850}}],
    Line[{{-1.250300, -0.620332, 20.040850},{-1.194872, -0.714041, 
        19.521477}}],
    Line[{{-1.194872, -0.714041, 19.521477},{-1.153687, -0.808861, 
        19.016544}}],
    Line[{{-1.153687, -0.808861, 19.016544},{-1.125523, -0.905379, 
        18.525719}}],
    Line[{{-1.125523, -0.905379, 18.525719},{-1.109335, -1.004290, 
        18.048698}}],
    Line[{{-1.109335, -1.004290, 18.048698},{-1.104248, -1.106374, 
        17.585230}}],
    Line[{{-1.104248, -1.106374, 17.585230},{-1.109548, -1.212491, 
        17.135098}}],
    Line[{{-1.109548, -1.212491, 17.135098},{-1.124676, -1.323569, 
        16.698124}}],
    Line[{{-1.124676, -1.323569, 16.698124},{-1.149216, -1.440604, 
        16.274179}}],
    Line[{{-1.149216, -1.440604, 16.274179},{-1.182889, -1.564656, 
        15.863175}}],
    Line[{{-1.182889, -1.564656, 15.863175},{-1.225549, -1.696855, 
        15.465075}}],
    Line[{{-1.225549, -1.696855, 15.465075},{-1.277173, -1.838403, 
        15.079902}}],
    Line[{{-1.277173, -1.838403, 15.079902},{-1.337859, -1.990581, 
        14.707738}}],
    Line[{{-1.337859, -1.990581, 14.707738},{-1.407821, -2.154757, 
        14.348745}}],
    Line[{{-1.407821, -2.154757, 14.348745},{-1.487389, -2.332395, 
        14.003170}}],
    Line[{{-1.487389, -2.332395, 14.003170},{-1.577005, -2.525062, 
        13.671360}}],
    Line[{{-1.577005, -2.525062, 13.671360},{-1.677223, -2.734442, 
        13.353785}}],
    Line[{{-1.677223, -2.734442, 13.353785},{-1.788712, -2.962340, 
        13.051052}}],
    Line[{{-1.788712, -2.962340, 13.051052},{-1.912253, -3.210699, 
        12.763936}}],
    Line[{{-1.912253, -3.210699, 12.763936},{-2.048747, -3.481601, 
        12.493408}}],
    Line[{{-2.048747, -3.481601, 12.493408},{-2.199213, -3.777272, 
        12.240674}}],
    Line[{{-2.199213, -3.777272, 12.240674},{-2.364791, -4.100096, 
        12.007210}}],
    Line[{{-2.364791, -4.100096, 12.007210},{-2.546751, -4.452594, 
        11.794828}}],
    Line[{{-2.546751, -4.452594, 11.794828},{-2.746483, -4.837436, 
        11.605711}}],
    Line[{{-2.746483, -4.837436, 11.605711},{-2.965510, -5.257401, 
        11.442509}}],
    Line[{{-2.965510, -5.257401, 11.442509},{-3.205474, -5.715364, 
        11.308394}}],
    Line[{{-3.205474, -5.715364, 11.308394},{-3.468144, -6.214249, 
        11.207163}}],
    Line[{{-3.468144, -6.214249, 11.207163},{-3.755390, -6.756928, 
        11.143341}}],
    Line[{{-3.755390, -6.756928, 11.143341},{-4.069177, -7.346167, 
        11.122280}}],
    Line[{{-4.069177, -7.346167, 11.122280},{-4.411535, -7.984462, 
        11.150284}}],
    Line[{{-4.411535, -7.984462, 11.150284},{-4.784515, -8.673854, 
        11.234734}}],
    Line[{{-4.784515, -8.673854, 11.234734},{-5.190136, -9.415696, 
        11.384186}}],
    Line[{{-5.190136, -9.415696, 11.384186},{-5.630315, -10.210360, 
        11.608486}}],
    Line[{{-5.630315, -10.210360, 11.608486},{-6.106753, -11.056811, 
        11.918819}}],
    Line[{{-6.106753, -11.056811, 11.918819},{-6.620800, -11.952130, 
        12.327694}}],
    Line[{{-6.620800, -11.952130, 12.327694},{-7.173292, -12.890942, 
        12.848841}}],
    Line[{{-7.173292, -12.890942, 12.848841},{-7.764324, -13.864733, 
        13.496951}}],
    Line[{{-7.764324, -13.864733, 13.496951},{-8.392992, -14.861107, 
        14.287206}}],
    Line[{{-8.392992, -14.861107, 14.287206},{-9.057078, -15.863001, 
        15.234529}}],
    Line[{{-9.057078, -15.863001, 15.234529},{-9.752699, -16.847971, 
        16.352493}}],
    Line[{{-9.752699, -16.847971, 16.352493},{-10.473916, -17.787668, 
        17.651808}}],
    Line[{{-10.473916, -17.787668, 17.651808},{-11.212368, -18.647665, 
        19.138437}}],
    Line[{{-11.212368, -18.647665, 19.138437},{-11.956932, -19.387871, 
        20.811317}}],
    Line[{{-11.956932, -19.387871, 20.811317},{-12.693500, -19.963795, 
        22.659889}}],
    Line[{{-12.693500, -19.963795, 22.659889},{-13.404949, -20.328859, 
        24.661734}}],
    Line[{{-13.404949, -20.328859, 24.661734},{-14.071389, -20.437893, 
        26.780760}}],
    Line[{{-14.071389, -20.437893, 26.780760},{-14.670773, -20.251696, 
        28.966532}}],
    Line[{{-14.670773, -20.251696, 28.966532},{-15.179917, -19.742287, 
        31.155329}}],
    Line[{{-15.179917, -19.742287, 31.155329},{-15.575937, -18.898096, 
        33.273308}}],
    Line[{{-15.575937, -18.898096, 33.273308},{-15.837998, -17.728027, 
        35.242039}}],
    Line[{{-15.837998, -17.728027, 35.242039},{-15.949173, -16.263418, 
        36.985535}}],
    Line[{{-15.949173, -16.263418, 36.985535},{-15.898182, -14.556960, 
        38.438171}}],
    Line[{{-15.898182, -14.556960, 38.438171},{-15.680704, -12.678413, 
        39.551750}}],
    Line[{{-15.680704, -12.678413, 39.551750},{-15.300023, -10.707711, 
        40.300404}}],
    Line[{{-15.300023, -10.707711, 40.300404},{-14.766885, -8.726628, 
        40.682365}}],
    Line[{{-14.766885, -8.726628, 40.682365},{-14.098540, -6.810569, 
        40.718197}}],
    Line[{{-14.098540, -6.810569, 40.718197},{-13.317188, -5.022119, 
        40.446255}}],
    Line[{{-13.317188, -5.022119, 40.446255},{-12.448088, -3.407069, 
        39.916523}}],
    Line[{{-12.448088, -3.407069, 39.916523},{-11.517579, -1.993268, 
        39.184055}}],
    Line[{{-11.517579, -1.993268, 39.184055},{-10.551321, -0.791853, 
        38.303226}}],
    Line[{{-10.551321, -0.791853, 38.303226},{-9.572893, 0.199916, 
        37.323479}}],
    Line[{{-9.572893, 0.199916, 37.323479},{-8.602843, 0.995064, 36.286751}}],
    
    Line[{{-8.602843, 0.995064, 36.286751},{-7.658172, 1.613286, 35.226479}}],
    
    Line[{{-7.658172, 1.613286, 35.226479},{-6.752198, 2.077783, 34.167736}}],
    
    Line[{{-6.752198, 2.077783, 34.167736},{-5.894697, 2.412772, 33.128151}}],
    
    Line[{{-5.894697, 2.412772, 33.128151},{-5.092233, 2.641738, 32.119171}}],
    
    Line[{{-5.092233, 2.641738, 32.119171},{-4.348594, 2.786323, 31.147425}}],
    
    Line[{{-4.348594, 2.786323, 31.147425},{-3.665263, 2.865736, 30.216005}}],
    
    Line[{{-3.665263, 2.865736, 30.216005},{-3.041881, 2.896539, 29.325542}}],
    
    Line[{{-3.041881, 2.896539, 29.325542},{-2.476673, 2.892678, 28.475069}}],
    
    Line[{{-2.476673, 2.892678, 28.475069},{-1.966826, 2.865672, 27.662682}}],
    
    Line[{{-1.966826, 2.865672, 27.662682},{-1.508806, 2.824873, 26.886009}}],
    
    Line[{{-1.508806, 2.824873, 26.886009},{-1.098618, 2.777759, 26.142525}}],
    
    Line[{{-1.098618, 2.777759, 26.142525},{-0.732013, 2.730223, 25.429764}}],
    
    Line[{{-0.732013, 2.730223, 25.429764},{-0.404653, 2.686850, 24.745436}}],
    
    Line[{{-0.404653, 2.686850, 24.745436},{-0.112229, 2.651156, 24.087488}}],
    
    Line[{{-0.112229, 2.651156, 24.087488},{0.149449, 2.625805, 23.454140}}],
    Line[{{0.149449, 2.625805, 23.454140},{0.384394, 2.612795, 22.843861}}],
    Line[{{0.384394, 2.612795, 22.843861},{0.596399, 2.613612, 22.255383}}],
    Line[{{0.596399, 2.613612, 22.255383},{0.789021, 2.629363, 21.687654}}],
    Line[{{0.789021, 2.629363, 21.687654},{0.965566, 2.660883, 21.139839}}],
    Line[{{0.965566, 2.660883, 21.139839},{1.129100, 2.708827, 20.611284}}],
    Line[{{1.129100, 2.708827, 20.611284},{1.282449, 2.773740, 20.101501}}],
    Line[{{1.282449, 2.773740, 20.101501},{1.428222, 2.856118, 19.610161}}],
    Line[{{1.428222, 2.856118, 19.610161},{1.568827, 2.956456, 19.137075}}],
    Line[{{1.568827, 2.956456, 19.137075},{1.706490, 3.075285, 18.682196}}],
    Line[{{1.706490, 3.075285, 18.682196},{1.843279, 3.213203, 18.245615}}],
    Line[{{1.843279, 3.213203, 18.245615},{1.981126, 3.370897, 17.827570}}],
    Line[{{1.981126, 3.370897, 17.827570},{2.121850, 3.549160, 17.428450}}],
    Line[{{2.121850, 3.549160, 17.428450},{2.267179, 3.748901, 17.048805}}],
    Line[{{2.267179, 3.748901, 17.048805},{2.418766, 3.971156, 16.689371}}],
    Line[{{2.418766, 3.971156, 16.689371},{2.578215, 4.217088, 16.351089}}],
    Line[{{2.578215, 4.217088, 16.351089},{2.747091, 4.487983, 16.035131}}],
    Line[{{2.747091, 4.487983, 16.035131},{2.926941, 4.785243, 15.742926}}],
    Line[{{2.926941, 4.785243, 15.742926},{3.119301, 5.110371, 15.476206}}],
    Line[{{3.119301, 5.110371, 15.476206},{3.325708, 5.464951, 15.237045}}],
    Line[{{3.325708, 5.464951, 15.237045},{3.547708, 5.850610, 15.027905}}],
    Line[{{3.547708, 5.850610, 15.027905},{3.786854, 6.268981, 14.851690}}],
    Line[{{3.786854, 6.268981, 14.851690},{4.044703, 6.721640, 14.711801}}],
    Line[{{4.044703, 6.721640, 14.711801},{4.322809, 7.210025, 14.612196}}],
    Line[{{4.322809, 7.210025, 14.612196},{4.622707, 7.735345, 14.557453}}],
    Line[{{4.622707, 7.735345, 14.557453},{4.945882, 8.298450, 14.552825}}],
    Line[{{4.945882, 8.298450, 14.552825},{5.293734, 8.899653, 14.604285}}],
    Line[{{5.293734, 8.899653, 14.604285},{5.667527, 9.538562, 14.718559}}],
    Line[{{5.667527, 9.538562, 14.718559},{6.068326, 10.213824, 14.903139}}],
    Line[{{6.068326, 10.213824, 14.903139},{6.496907, 10.922834, 15.166230}}],
    
    Line[{{6.496907, 10.922834, 15.166230},{6.953643, 11.661408, 15.516644}}],
    
    Line[{{6.953643, 11.661408, 15.516644},{7.438396, 12.423438, 15.963651}}],
    
    Line[{{7.438396, 12.423438, 15.963651},{7.950343, 13.200465, 16.516663}}],
    
    Line[{{7.950343, 13.200465, 16.516663},{8.487800, 13.981292, 17.184763}}],
    
    Line[{{8.487800, 13.981292, 17.184763},{9.048040, 14.751643, 17.976189}}],
    
    Line[{{9.048040, 14.751643, 17.976189},{9.627071, 15.493887, 18.897461}}],
    
    Line[{{9.627071, 15.493887, 18.897461},{
      10.219440, 16.186954, 19.952456}}],
    Line[{{10.219440, 16.186954, 19.952456},{
      10.818040, 16.806522, 21.141237}}],
    Line[{{10.818040, 16.806522, 21.141237},{
      11.413998, 17.325562, 22.458805}}],
    Line[{{11.413998, 17.325562, 22.458805},{
      11.996613, 17.715361, 23.893856}}],
    Line[{{11.996613, 17.715361, 23.893856},{
      12.553453, 17.947094, 25.427729}}],
    Line[{{12.553453, 17.947094, 25.427729},{
      13.070606, 17.993891, 27.033752}}],
    Line[{{13.070606, 17.993891, 27.033752},{
      13.533117, 17.833349, 28.677271}}],
    Line[{{13.533117, 17.833349, 28.677271},{
      13.925649, 17.450243, 30.316532}}],
    Line[{{13.925649, 17.450243, 30.316532},{
      14.233325, 16.839048, 31.904623}}],
    Line[{{14.233325, 16.839048, 31.904623},{
      14.442714, 16.005888, 33.392387}}],
    Line[{{14.442714, 16.005888, 33.392387},{
      14.542845, 14.969398, 34.732090}}],
    Line[{{14.542845, 14.969398, 34.732090},{
      14.526161, 13.760247, 35.881390}}],
    Line[{{14.526161, 13.760247, 35.881390},{
      14.389249, 12.419150, 36.807022}}],
    Line[{{14.389249, 12.419150, 36.807022},{
      14.133255, 10.993633, 37.487564}}],
    Line[{{14.133255, 10.993633, 37.487564},{
      13.763905, 9.533969, 37.914814}}],
    Line[{{13.763905, 9.533969, 37.914814},{13.291125, 8.088947, 38.093670}}],
    
    Line[{{13.291125, 8.088947, 38.093670},{12.728315, 6.702108, 38.040504}}],
    
    Line[{{12.728315, 6.702108, 38.040504},{12.091371, 5.408970, 37.780483}}],
    
    Line[{{12.091371, 5.408970, 37.780483},{11.397597, 4.235485, 37.344372}}],
    
    Line[{{11.397597, 4.235485, 37.344372},{10.664646, 3.197737, 36.765324}}],
    
    Line[{{10.664646, 3.197737, 36.765324},{9.909568, 2.302677, 36.076107}}],
    Line[{{9.909568, 2.302677, 36.076107},{9.148067, 1.549536, 35.307014}}],
    Line[{{9.148067, 1.549536, 35.307014},{8.393974, 0.931606, 34.484524}}],
    Line[{{8.393974, 0.931606, 34.484524},{7.658956, 0.438049, 33.630653}}],
    Line[{{7.658956, 0.438049, 33.630653},{6.952402, 0.055557, 32.762924}}],
    Line[{{6.952402, 0.055557, 32.762924},{6.281481, -0.230276, 31.894636}}],
    Line[{{6.281481, -0.230276, 31.894636},{5.651299, -0.433915, 31.035442}}],
    
    Line[{{5.651299, -0.433915, 31.035442},{5.065127, -0.569142, 30.191969}}],
    
    Line[{{5.065127, -0.569142, 30.191969},{4.524665, -0.648596, 29.368460}}],
    
    Line[{{4.524665, -0.648596, 29.368460},{4.030316, -0.683519, 28.567364}}],
    
    Line[{{4.030316, -0.683519, 28.567364},{3.581445, -0.683664, 27.789822}}],
    
    Line[{{3.581445, -0.683664, 27.789822},{3.176621, -0.657310, 27.036081}}],
    
    Line[{{3.176621, -0.657310, 27.036081},{2.813832, -0.611349, 26.305801}}],
    
    Line[{{2.813832, -0.611349, 26.305801},{2.490660, -0.551409, 25.598282}}],
    
    Line[{{2.490660, -0.551409, 25.598282},{2.204439, -0.482002, 24.912636}}],
    
    Line[{{2.204439, -0.482002, 24.912636},{1.952375, -0.406669, 24.247894}}],
    
    Line[{{1.952375, -0.406669, 24.247894},{1.731644, -0.328123, 23.603083}}],
    
    Line[{{1.731644, -0.328123, 23.603083},{1.539467, -0.248382, 22.977268}}],
    
    Line[{{1.539467, -0.248382, 22.977268},{1.373167, -0.168888, 22.369577}}],
    
    Line[{{1.373167, -0.168888, 22.369577},{1.230206, -0.090611, 21.779211}}],
    
    Line[{{1.230206, -0.090611, 21.779211},{1.108216, -0.014143, 21.205442}}],
    
    Line[{{1.108216, -0.014143, 21.205442},{1.005015, 0.060233, 20.647619}}],
    Line[{{1.005015, 0.060233, 20.647619},{0.918610, 0.132472, 20.105150}}],
    Line[{{0.918610, 0.132472, 20.105150},{0.847205, 0.202718, 19.577503}}],
    Line[{{0.847205, 0.202718, 19.577503},{0.789196, 0.271260, 19.064196}}],
    Line[{{0.789196, 0.271260, 19.064196},{0.743165, 0.338497, 18.564787}}],
    Line[{{0.743165, 0.338497, 18.564787},{0.707870, 0.404915, 18.078878}}],
    Line[{{0.707870, 0.404915, 18.078878},{0.682237, 0.471061, 17.606100}}],
    Line[{{0.682237, 0.471061, 17.606100},{0.665350, 0.537536, 17.146112}}],
    Line[{{0.665350, 0.537536, 17.146112},{0.656438, 0.604975, 16.698603}}],
    Line[{{0.656438, 0.604975, 16.698603},{0.654866, 0.674052, 16.263281}}],
    Line[{{0.654866, 0.674052, 16.263281},{0.660126, 0.745466, 15.839885}}],
    Line[{{0.660126, 0.745466, 15.839885},{0.671824, 0.819950, 15.428169}}],
    Line[{{0.671824, 0.819950, 15.428169},{0.689677, 0.898263, 15.027916}}],
    Line[{{0.689677, 0.898263, 15.027916},{0.713501, 0.981203, 14.638931}}],
    Line[{{0.713501, 0.981203, 14.638931},{0.743208, 1.069604, 14.261047}}],
    Line[{{0.743208, 1.069604, 14.261047},{0.778802, 1.164349, 13.894126}}],
    Line[{{0.778802, 1.164349, 13.894126},{0.820369, 1.266372, 13.538062}}],
    Line[{{0.820369, 1.266372, 13.538062},{0.868082, 1.376669, 13.192788}}],
    Line[{{0.868082, 1.376669, 13.192788},{0.922195, 1.496308, 12.858279}}],
    Line[{{0.922195, 1.496308, 12.858279},{0.983041, 1.626437, 12.534563}}],
    Line[{{0.983041, 1.626437, 12.534563},{1.051039, 1.768300, 12.221722}}],
    Line[{{1.051039, 1.768300, 12.221722},{1.126689, 1.923240, 11.919911}}],
    Line[{{1.126689, 1.923240, 11.919911},{1.210576, 2.092720, 11.629366}}],
    Line[{{1.210576, 2.092720, 11.629366},{1.303376, 2.278332, 11.350418}}],
    Line[{{1.303376, 2.278332, 11.350418},{1.405859, 2.481809, 11.083517}}],
    Line[{{1.405859, 2.481809, 11.083517},{1.518894, 2.705039, 10.829247}}],
    Line[{{1.518894, 2.705039, 10.829247},{1.643454, 2.950080, 10.588363}}],
    Line[{{1.643454, 2.950080, 10.588363},{1.780626, 3.219170, 10.361808}}],
    Line[{{1.780626, 3.219170, 10.361808},{1.931614, 3.514735, 10.150771}}],
    Line[{{1.931614, 3.514735, 10.150771},{2.097747, 3.839401, 9.956718}}],
    Line[{{2.097747, 3.839401, 9.956718},{2.280489, 4.195994, 9.781458}}],
    Line[{{2.280489, 4.195994, 9.781458},{2.481444, 4.587538, 9.627201}}],
    Line[{{2.481444, 4.587538, 9.627201},{2.702357, 5.017244, 9.496642}}],
    Line[{{2.702357, 5.017244, 9.496642},{2.945122, 5.488480, 9.393056}}],
    Line[{{2.945122, 5.488480, 9.393056},{3.211782, 6.004743, 9.320392}}],
    Line[{{3.211782, 6.004743, 9.320392},{3.504517, 6.569565, 9.283411}}],
    Line[{{3.504517, 6.569565, 9.283411},{3.825641, 7.186465, 9.287809}}],
    Line[{{3.825641, 7.186465, 9.287809},{4.177567, 7.858745, 9.340385}}],
    Line[{{4.177567, 7.858745, 9.340385},{4.562783, 8.589355, 9.449189}}],
    Line[{{4.562783, 8.589355, 9.449189},{4.983790, 9.380606, 9.623694}}],
    Line[{{4.983790, 9.380606, 9.623694},{5.443023, 10.233809, 9.874939}}],
    Line[{{5.443023, 10.233809, 9.874939},{5.942753, 11.148873, 10.215678}}],
    Line[{{5.942753, 11.148873, 10.215678},{6.484927, 12.123669, 10.660399}}],
    
    Line[{{6.484927, 12.123669, 10.660399},{7.070979, 13.153371, 11.225293}}],
    
    Line[{{7.070979, 13.153371, 11.225293},{7.701592, 14.229599, 11.928078}}],
    
    Line[{{7.701592, 14.229599, 11.928078},{8.376363, 15.339423, 12.787429}}],
    
    Line[{{8.376363, 15.339423, 12.787429},{9.093441, 16.464357, 13.822260}}],
    
    Line[{{9.093441, 16.464357, 13.822260},{9.849081, 17.579300, 15.050423}}],
    
    Line[{{9.849081, 17.579300, 15.050423},{
      10.637148, 18.651678, 16.486929}}],
    Line[{{10.637148, 18.651678, 16.486929},{
      11.448608, 19.641006, 18.141537}}],
    Line[{{11.448608, 19.641006, 18.141537},{
      12.271060, 20.499155, 20.015806}}],
    Line[{{12.271060, 20.499155, 20.015806},{
      13.088382, 21.171730, 22.099771}}],
    Line[{{13.088382, 21.171730, 22.099771},{
      13.880612, 21.600853, 24.368628}}],
    Line[{{13.880612, 21.600853, 24.368628},{
      14.624190, 21.729658, 26.780050}}],
    Line[{{14.624190, 21.729658, 26.780050},{
      15.292668, 21.508333, 29.273014}}],
    Line[{{15.292668, 21.508333, 29.273014},{
      15.858006, 20.901270, 31.768961}}],
    Line[{{15.858006, 20.901270, 31.768961},{
      16.292421, 19.894175, 34.176056}}],
    Line[{{16.292421, 19.894175, 34.176056},{
      16.570688, 18.499729, 36.396587}}],
    Line[{{16.570688, 18.499729, 36.396587},{
      16.672607, 16.759995, 38.336910}}],
    Line[{{16.672607, 16.759995, 38.336910},{
      16.585266, 14.744578, 39.918140}}],
    Line[{{16.585266, 14.744578, 39.918140},{
      16.304703, 12.544220, 41.085613}}],
    Line[{{16.304703, 12.544220, 41.085613},{
      15.836587, 10.260758, 41.814854}}],
    Line[{{15.836587, 10.260758, 41.814854},{
      15.195812, 7.995519, 42.112850}}],
    Line[{{15.195812, 7.995519, 42.112850},{14.405026, 5.838531, 42.014462}}],
    
    Line[{{14.405026, 5.838531, 42.014462},{13.492410, 3.860662, 41.575191}}],
    
    Line[{{13.492410, 3.860662, 41.575191},{12.489100, 2.109622, 40.862240}}],
    
    Line[{{12.489100, 2.109622, 40.862240},{11.426679, 0.609874, 39.945759}}],
    
    Line[{{11.426679, 0.609874, 39.945759},{
      10.335028, -0.634451, 38.891758}}],
    Line[{{10.335028, -0.634451, 38.891758},{
      9.240784, -1.634975, 37.757481}}],
    Line[{{9.240784, -1.634975, 37.757481},{8.166384, -2.413965, 36.589081}}],
    
    Line[{{8.166384, -2.413965, 36.589081},{7.129684, -2.999663, 35.421307}}],
    
    Line[{{7.129684, -2.999663, 35.421307},{6.144032, -3.422517, 34.278507}}],
    
    Line[{{6.144032, -3.422517, 34.278507},{5.218601, -3.712491, 33.176273}}],
    
    Line[{{5.218601, -3.712491, 33.176273},{4.358941, -3.897340, 32.123390}}],
    
    Line[{{4.358941, -3.897340, 32.123390},{3.567580, -4.001682, 31.123653}}],
    
    Line[{{3.567580, -4.001682, 31.123653},{2.844629, -4.046662, 30.177431}}],
    
    Line[{{2.844629, -4.046662, 30.177431},{2.188344, -4.049981, 29.282923}}],
    
    Line[{{2.188344, -4.049981, 29.282923},{1.595620, -4.026152, 28.437103}}],
    
    Line[{{1.595620, -4.026152, 28.437103},{1.062404, -3.986869, 27.636387}}],
    
    Line[{{1.062404, -3.986869, 27.636387},{0.584037, -3.941411, 26.877069}}],
    
    Line[{{0.584037, -3.941411, 26.877069},{0.155523, -3.897036, 26.155622}}],
    
    Line[{{
      0.155523, -3.897036, 26.155622},{-0.228271, -3.859351, 25.468836}}],
    Line[{{-0.228271, -3.859351, 25.468836},{-0.572453, -3.832630, 
        24.813906}}],
    Line[{{-0.572453, -3.832630, 24.813906},{-0.882000, -3.820095, 
        24.188459}}],
    Line[{{-0.882000, -3.820095, 24.188459},{-1.161680, -3.824148, 
        23.590536}}],
    Line[{{-1.161680, -3.824148, 23.590536},{-1.416004, -3.846569, 
        23.018570}}],
    Line[{{-1.416004, -3.846569, 23.018570},{-1.649202, -3.888674, 
        22.471355}}],
    Line[{{-1.649202, -3.888674, 22.471355},{-1.865206, -3.951447, 
        21.948011}}],
    Line[{{-1.865206, -3.951447, 21.948011},{-2.067657, -4.035647, 
        21.447948}}],
    Line[{{-2.067657, -4.035647, 21.447948},{-2.259917, -4.141890, 
        20.970846}}],
    Line[{{-2.259917, -4.141890, 20.970846},{-2.445079, -4.270711, 
        20.516634}}],
    Line[{{-2.445079, -4.270711, 20.516634},{-2.625991, -4.422620, 
        20.085476}}],
    Line[{{-2.625991, -4.422620, 20.085476},{-2.805281, -4.598136, 
        19.677771}}],
    Line[{{-2.805281, -4.598136, 19.677771},{-2.985376, -4.797809, 
        19.294146}}],
    Line[{{-2.985376, -4.797809, 19.294146},{-3.168527, -5.022234, 
        18.935471}}],
    Line[{{-3.168527, -5.022234, 18.935471},{-3.356829, -5.272059, 
        18.602863}}],
    Line[{{-3.356829, -5.272059, 18.602863},{-3.552243, -5.547971, 
        18.297712}}],
    Line[{{-3.552243, -5.547971, 18.297712},{-3.756609, -5.850695, 
        18.021694}}],
    Line[{{-3.756609, -5.850695, 18.021694},{-3.971663, -6.180950, 
        17.776798}}],
    Line[{{-3.971663, -6.180950, 17.776798},{-4.199039, -6.539423, 
        17.565365}}],
    Line[{{-4.199039, -6.539423, 17.565365},{-4.440283, -6.926723, 
        17.390095}}],
    Line[{{-4.440283, -6.926723, 17.390095},{-4.696842, -7.343307, 
        17.254099}}],
    Line[{{-4.696842, -7.343307, 17.254099},{-4.970056, -7.789404, 
        17.160912}}],
    Line[{{-4.970056, -7.789404, 17.160912},{-5.261150, -8.264926, 
        17.114513}}],
    Line[{{-5.261150, -8.264926, 17.114513},{-5.571202, -8.769341, 
        17.119349}}],
    Line[{{-5.571202, -8.769341, 17.119349},{-5.901104, -9.301521, 
        17.180304}}],
    Line[{{-5.901104, -9.301521, 17.180304},{-6.251532, -9.859617, 
        17.302704}}],
    Line[{{-6.251532, -9.859617, 17.302704},{-6.622868, -10.440829, 
        17.492222}}],
    Line[{{-6.622868, -10.440829, 17.492222},{-7.015143, -11.041237, 
        17.754799}}],
    Line[{{-7.015143, -11.041237, 17.754799},{-7.427948, -11.655554, 
        18.096483}}],
    Line[{{-7.427948, -11.655554, 18.096483},{-7.860334, -12.276945, 
        18.523184}}],
    Line[{{-7.860334, -12.276945, 18.523184},{-8.310709, -12.896780, 
        19.040403}}],
    Line[{{-8.310709, -12.896780, 19.040403},{-8.776717, -13.504492, 
        19.652803}}],
    Line[{{-8.776717, -13.504492, 19.652803},{-9.255127, -14.087507, 
        20.363724}}],
    Line[{{-9.255127, -14.087507, 20.363724},{-9.741711, -14.631168, 
        21.174620}}],
    Line[{{-9.741711, -14.631168, 21.174620},{-10.231170, -15.119060, 
        22.084375}}],
    Line[{{-10.231170, -15.119060, 22.084375},{-10.717055, -15.533208, 
        23.088636}}],
    Line[{{-10.717055, -15.533208, 23.088636},{-11.191789, -15.854862, 
        24.179142}}],
    Line[{{-11.191789, -15.854862, 24.179142},{-11.646715, -16.065281, 
        25.343178}}],
    Line[{{-11.646715, -16.065281, 25.343178},{-12.072277, -16.146931, 
        26.563278}}],
    Line[{{-12.072277, -16.146931, 26.563278},{-12.458256, -16.084797, 
        27.817162}}],
    Line[{{-12.458256, -16.084797, 27.817162},{-12.794164, -15.867890, 
        29.078226}}],
    Line[{{-12.794164, -15.867890, 29.078226},{-13.069721, -15.490628, 
        30.316473}}],
    Line[{{-13.069721, -15.490628, 30.316473},{-13.275401, -14.953965, 
        31.499954}}],
    Line[{{-13.275401, -14.953965, 31.499954},{-13.403022, -14.266132, 
        32.596607}}],
    Line[{{-13.403022, -14.266132, 32.596607},{-13.446321, -13.442682, 
        33.576389}}],
    Line[{{-13.446321, -13.442682, 33.576389},{-13.401445, -12.505877, 
        34.413364}}],
    Line[{{-13.401445, -12.505877, 34.413364},{-13.267301, -11.483321, 
        35.087559}}],
    Line[{{-13.267301, -11.483321, 35.087559},{-13.045704, -10.406064, 
        35.586227}}],
    Line[{{-13.045704, -10.406064, 35.586227},{-12.741334, -9.306376, 
        35.904461}}],
    Line[{{-12.741334, -9.306376, 35.904461},{-12.361462, -8.215495, 
        36.045002}}],
    Line[{{-12.361462, -8.215495, 36.045002},{-11.915505, -7.161635, 
        36.017365}}],
    Line[{{-11.915505, -7.161635, 36.017365},{-11.414464, -6.168468, 
        35.836456}}],
    Line[{{-11.414464, -6.168468, 35.836456},{-10.870281, -5.254212, 
        35.520889}}],
    Line[{{-10.870281, -5.254212, 35.520889},{-10.295222, -4.431327, 
        35.091274}}],
    Line[{{-10.295222, -4.431327, 35.091274},{-9.701298, -3.706747, 
        34.568645}}],
    Line[{{-9.701298, -3.706747, 34.568645},{-9.099795, -3.082508, 
        33.973209}}],
    Line[{{-9.099795, -3.082508, 33.973209},{-8.500916, -2.556641, 
        33.323425}}],
    Line[{{-8.500916, -2.556641, 33.323425},{-7.913550, -2.124110, 
        32.635483}}],
    Line[{{-7.913550, -2.124110, 32.635483},{-7.345153, -1.777779, 
        31.923040}}],
    Line[{{-7.345153, -1.777779, 31.923040},{-6.801724, -1.509255, 
        31.197250}}],
    Line[{{-6.801724, -1.509255, 31.197250},{-6.287862, -1.309597, 
        30.466928}}],
    Line[{{-6.287862, -1.309597, 30.466928},{-5.806872, -1.169855, 
        29.738834}}],
    Line[{{-5.806872, -1.169855, 29.738834},{-5.360909, -1.081476, 
        29.017994}}],
    Line[{{-5.360909, -1.081476, 29.017994},{-4.951140, -1.036560, 
        28.308020}}],
    Line[{{-4.951140, -1.036560, 28.308020},{-4.577908, -1.028022, 
        27.611412}}],
    Line[{{-4.577908, -1.028022, 27.611412},{-4.240889, -1.049664, 
        26.929831}}],
    Line[{{-4.240889, -1.049664, 26.929831},{-3.939247, -1.096187, 
        26.264311}}],
    Line[{{-3.939247, -1.096187, 26.264311},{-3.671762, -1.163162, 
        25.615437}}],
    Line[{{-3.671762, -1.163162, 25.615437},{-3.436948, -1.246974, 
        24.983498}}],
    Line[{{-3.436948, -1.246974, 24.983498},{-3.233154, -1.344751, 
        24.368580}}],
    Line[{{-3.233154, -1.344751, 24.368580},{-3.058645, -1.454287, 
        23.770653}}],
    Line[{{-3.058645, -1.454287, 23.770653},{-2.911670, -1.573961, 
        23.189621}}],
    Line[{{-2.911670, -1.573961, 23.189621},{-2.790517, -1.702667, 
        22.625378}}],
    Line[{{-2.790517, -1.702667, 22.625378},{-2.693551, -1.839740, 
        22.077822}}],
    Line[{{-2.693551, -1.839740, 22.077822},{-2.619251, -1.984898, 
        21.546879}}],
    Line[{{-2.619251, -1.984898, 21.546879},{-2.566229, -2.138183, 
        21.032530}}],
    Line[{{-2.566229, -2.138183, 21.032530},{-2.533247, -2.299918, 
        20.534807}}],
    Line[{{-2.533247, -2.299918, 20.534807},{-2.519227, -2.470665, 
        20.053814}}],
    Line[{{-2.519227, -2.470665, 20.053814},{-2.523258, -2.651192, 
        19.589733}}],
    Line[{{-2.523258, -2.651192, 19.589733},{-2.544597, -2.842447, 
        19.142838}}],
    Line[{{-2.544597, -2.842447, 19.142838},{-2.582671, -3.045532, 
        18.713495}}],
    Line[{{-2.582671, -3.045532, 18.713495},{-2.637071, -3.261693, 
        18.302195}}],
    Line[{{-2.637071, -3.261693, 18.302195},{-2.707553, -3.492294, 
        17.909554}}],
    Line[{{-2.707553, -3.492294, 17.909554},{-2.794032, -3.738812, 
        17.536337}}],
    Line[{{-2.794032, -3.738812, 17.536337},{-2.896575, -4.002825, 
        17.183481}}],
    Line[{{-2.896575, -4.002825, 17.183481},{-3.015400, -4.285995, 
        16.852119}}],
    Line[{{-3.015400, -4.285995, 16.852119},{-3.150862, -4.590059, 
        16.543610}}],
    Line[{{-3.150862, -4.590059, 16.543610},{-3.303453, -4.916811, 
        16.259573}}],
    Line[{{-3.303453, -4.916811, 16.259573},{-3.473791, -5.268082, 
        16.001921}}],
    Line[{{-3.473791, -5.268082, 16.001921},{-3.662609, -5.645709, 
        15.772904}}],
    Line[{{-3.662609, -5.645709, 15.772904},{-3.870745, -6.051499, 
        15.575165}}],
    Line[{{-3.870745, -6.051499, 15.575165},{-4.099125, -6.487188, 
        15.411771}}],
    Line[{{-4.099125, -6.487188, 15.411771},{-4.348746, -6.954357, 
        15.286282}}],
    Line[{{-4.348746, -6.954357, 15.286282},{-4.620651, -7.454376, 
        15.202796}}],
    Line[{{-4.620651, -7.454376, 15.202796},{-4.915898, -7.988276, 
        15.165999}}],
    Line[{{-4.915898, -7.988276, 15.165999},{-5.235522, -8.556627, 
        15.181211}}],
    Line[{{-5.235522, -8.556627, 15.181211},{-5.580487, -9.159378, 
        15.254416}}],
    Line[{{-5.580487, -9.159378, 15.254416},{-5.951615, -9.795638, 
        15.392261}}],
    Line[{{-5.951615, -9.795638, 15.392261},{-6.349527, -10.463470, 
        15.602058}}],
    Line[{{-6.349527, -10.463470, 15.602058},{-6.774525, -11.159577, 
        15.891660}}],
    Line[{{-6.774525, -11.159577, 15.891660},{-7.226502, -11.879030, 
        16.269392}}],
    Line[{{-7.226502, -11.879030, 16.269392},{-7.704793, -12.614896, 
        16.743750}}],
    Line[{{-7.704793, -12.614896, 16.743750},{-8.208029, -13.357924, 
        17.323103}}],
    Line[{{-8.208029, -13.357924, 17.323103},{-8.733961, -14.096175, 
        18.015234}}],
    Line[{{-8.733961, -14.096175, 18.015234},{-9.279284, -14.814837, 
        18.826635}}],
    Line[{{-9.279284, -14.814837, 18.826635},{-9.839443, -15.496013, 
        19.761797}}],
    Line[{{-9.839443, -15.496013, 19.761797},{-10.408473, -16.118811, 
        20.822210}}],
    Line[{{-10.408473, -16.118811, 20.822210},{-10.978858, -16.659740, 
        22.005316}}],
    Line[{{-10.978858, -16.659740, 22.005316},{-11.541456, -17.093336, 
        23.303431}}],
    Line[{{-11.541456, -17.093336, 23.303431},{-12.085519, -17.393345, 
        24.702673}}],
    Line[{{-12.085519, -17.393345, 24.702673},{-12.598857, -17.534378, 
        26.182299}}],
    Line[{{-12.598857, -17.534378, 26.182299},{-13.068141, -17.493868, 
        27.714375}}],
    Line[{{-13.068141, -17.493868, 27.714375},{-13.479389, -17.254400, 
        29.264162}}],
    Line[{{-13.479389, -17.254400, 29.264162},{-13.818643, -16.806025, 
        30.791328}}],
    Line[{{-13.818643, -16.806025, 30.791328},{-14.072769, -16.148264, 
        32.252064}}],
    Line[{{-14.072769, -16.148264, 32.252064},{-14.230349, -15.291406, 
        33.601910}}],
    Line[{{-14.230349, -15.291406, 33.601910},{-14.282572, -14.256788, 
        34.799133}}],
    Line[{{-14.282572, -14.256788, 34.799133},{-14.223993, -13.075836, 
        35.808094}}],
    Line[{{-14.223993, -13.075836, 35.808094},{-14.053083, -11.787931, 
        36.602207}}],
    Line[{{-14.053083, -11.787931, 36.602207},{-13.772472, -10.437255, 
        37.165985}}],
    Line[{{-13.772472, -10.437255, 37.165985},{-13.388826, -9.069111, 
        37.495739}}],
    Line[{{-13.388826, -9.069111, 37.495739},{-12.912395, -7.726448, 
        37.598995}}],
    Line[{{-12.912395, -7.726448, 37.598995},{-12.356298, -6.446742, 
        37.492847}}],
    Line[{{-12.356298, -6.446742, 37.492847},{-11.735624, -5.259915, 
        37.201439}}],
    Line[{{-11.735624, -5.259915, 37.201439},{-11.066460, -4.187270, 
        36.753155}}],
    Line[{{-11.066460, -4.187270, 36.753155},{-10.364965, -3.241490, 
        36.177917}}],
    Line[{{-10.364965, -3.241490, 36.177917},{-9.646584, -2.427417, 
        35.504917}}],
    Line[{{-9.646584, -2.427417, 35.504917},{-8.925420, -1.743360, 
        34.760902}}],
    Line[{{-8.925420, -1.743360, 34.760902},{-8.213824, -1.182657, 
        33.969181}}],
    Line[{{-8.213824, -1.182657, 33.969181},{-7.522159, -0.735227, 
        33.149128}}],
    Line[{{-7.522159, -0.735227, 33.149128},{-6.858733, -0.388977, 
        32.316189}}],
    Line[{{-6.858733, -0.388977, 32.316189},{-6.229866, -0.130948, 
        31.482164}}],
    Line[{{-6.229866, -0.130948, 31.482164},{-5.640034, 0.051795, 
        30.655697}}],
    Line[{{-5.640034, 0.051795, 30.655697},{-5.092086, 0.171560, 29.842815}}],
    
    Line[{{-5.092086, 0.171560, 29.842815},{-4.587475, 0.239619, 29.047472}}],
    
    Line[{{-4.587475, 0.239619, 29.047472},{-4.126503, 0.266007, 28.272051}}],
    
    Line[{{-4.126503, 0.266007, 28.272051},{-3.708548, 0.259434, 27.517778}}],
    
    Line[{{-3.708548, 0.259434, 27.517778},{-3.332287, 0.227301, 26.785080}}],
    
    Line[{{-3.332287, 0.227301, 26.785080},{-2.995876, 0.175768, 26.073843}}],
    
    Line[{{-2.995876, 0.175768, 26.073843},{-2.697117, 0.109863, 25.383614}}],
    
    Line[{{-2.697117, 0.109863, 25.383614},{-2.433593, 0.033607, 24.713753}}],
    
    Line[{{-2.433593, 0.033607, 24.713753},{-2.202777, -0.049861, 
        24.063528}}],
    Line[{{-2.202777, -0.049861, 24.063528},{-2.002122, -0.138156, 
        23.432182}}],
    Line[{{-2.002122, -0.138156, 23.432182},{-1.829127, -0.229537, 
        22.818979}}],
    Line[{{-1.829127, -0.229537, 22.818979},{-1.681392, -0.322796, 
        22.223223}}],
    Line[{{-1.681392, -0.322796, 22.223223},{-1.556651, -0.417172, 
        21.644274}}],
    Line[{{-1.556651, -0.417172, 21.644274},{-1.452801, -0.512266, 
        21.081553}}],
    Line[{{-1.452801, -0.512266, 21.081553},{-1.367914, -0.607978, 
        20.534534}}],
    Line[{{-1.367914, -0.607978, 20.534534},{-1.300249, -0.704450, 
        20.002756}}],
    Line[{{-1.300249, -0.704450, 20.002756},{-1.248256, -0.802018, 
        19.485806}}],
    Line[{{-1.248256, -0.802018, 19.485806},{-1.210569, -0.901175, 
        18.983320}}],
    Line[{{-1.210569, -0.901175, 18.983320},{-1.186007, -1.002547, 
        18.494984}}],
    Line[{{-1.186007, -1.002547, 18.494984},{-1.173567, -1.106865, 
        18.020521}}],
    Line[{{-1.173567, -1.106865, 18.020521},{-1.172415, -1.214951, 
        17.559704}}],
    Line[{{-1.172415, -1.214951, 17.559704},{-1.181877, -1.327709, 
        17.112347}}],
    Line[{{-1.181877, -1.327709, 17.112347},{-1.201436, -1.446115, 
        16.678301}}],
    Line[{{-1.201436, -1.446115, 16.678301},{-1.230717, -1.571218, 
        16.257475}}],
    Line[{{-1.230717, -1.571218, 16.257475},{-1.269487, -1.704136, 
        15.849822}}],
    Line[{{-1.269487, -1.704136, 15.849822},{-1.317643, -1.846063, 
        15.455353}}],
    Line[{{-1.317643, -1.846063, 15.455353},{-1.375211, -1.998269, 
        15.074144}}],
    Line[{{-1.375211, -1.998269, 15.074144},{-1.442337, -2.162111, 
        14.706347}}],
    Line[{{-1.442337, -2.162111, 14.706347},{-1.519288, -2.339038, 
        14.352199}}],
    Line[{{-1.519288, -2.339038, 14.352199},{-1.606450, -2.530601, 
        14.012032}}],
    Line[{{-1.606450, -2.530601, 14.012032},{-1.704323, -2.738459, 
        13.686301}}],
    Line[{{-1.704323, -2.738459, 13.686301},{-1.813523, -2.964392, 
        13.375599}}],
    Line[{{-1.813523, -2.964392, 13.375599},{-1.934784, -3.210310, 
        13.080677}}],
    Line[{{-1.934784, -3.210310, 13.080677},{-2.068958, -3.478255, 
        12.802481}}],
    Line[{{-2.068958, -3.478255, 12.802481},{-2.217016, -3.770413, 
        12.542184}}],
    Line[{{-2.217016, -3.770413, 12.542184},{-2.380054, -4.089112, 
        12.301225}}],
    Line[{{-2.380054, -4.089112, 12.301225},{-2.559289, -4.436822, 
        12.081362}}],
    Line[{{-2.559289, -4.436822, 12.081362},{-2.756067, -4.816144, 
        11.884725}}],
    Line[{{-2.756067, -4.816144, 11.884725},{-2.971856, -5.229795, 
        11.713883}}],
    Line[{{-2.971856, -5.229795, 11.713883},{-3.208250, -5.680575, 
        11.571921}}],
    Line[{{-3.208250, -5.680575, 11.571921},{-3.466959, -6.171331, 
        11.462522}}],
    Line[{{-3.466959, -6.171331, 11.462522},{-3.749798, -6.704865, 
        11.390074}}],
    Line[{{-3.749798, -6.704865, 11.390074},{-4.058677, -7.283876, 
        11.359757}}],
    Line[{{-4.058677, -7.283876, 11.359757},{-4.395565, -7.910807, 
        11.377676}}],
    Line[{{-4.395565, -7.910807, 11.377676},{-4.762455, -8.587646, 
        11.450968}}],
    Line[{{-4.762455, -8.587646, 11.450968},{-5.161320, -9.315775, 
        11.587904}}],
    Line[{{-5.161320, -9.315775, 11.587904},{-5.594022, -10.095578, 
        11.797995}}],
    Line[{{-5.594022, -10.095578, 11.797995},{-6.062229, -10.926134, 
        12.092039}}],
    Line[{{-6.062229, -10.926134, 12.092039},{-6.567273, -11.804720, 
        12.482121}}],
    Line[{{-6.567273, -11.804720, 12.482121},{-7.109996, -12.726273, 
        12.981503}}],
    Line[{{-7.109996, -12.726273, 12.981503},{-7.690540, -13.682748, 
        13.604398}}],
    Line[{{-7.690540, -13.682748, 13.604398},{-8.308093, -14.662395, 
        14.365530}}],
    Line[{{-8.308093, -14.662395, 14.365530},{-8.960595, -15.649013, 
        15.279435}}],
    Line[{{-8.960595, -15.649013, 15.279435},{-9.644391, -16.621262, 
        16.359409}}],
    Line[{{-9.644391, -16.621262, 16.359409},{-10.353876, -17.552135, 
        17.616152}}],
    Line[{{-10.353876, -17.552135, 17.616152},{-11.081123, -18.408752, 
        19.055941}}],
    Line[{{-11.081123, -18.408752, 19.055941},{-11.815558, -19.152710, 
        20.678503}}],
    Line[{{-11.815558, -19.152710, 20.678503},{-12.543732, -19.741188, 
        22.474634}}],
    Line[{{-12.543732, -19.741188, 22.474634},{-13.249268, -20.129063, 
        24.423922}}],
    Line[{{-13.249268, -20.129063, 24.423922},{-13.913066, -20.272129, 
        26.492920}}],
    Line[{{-13.913066, -20.272129, 26.492920},{-14.513851, -20.131365, 
        28.634342}}],
    Line[{{-14.513851, -20.131365, 28.634342},{-15.029105, -19.677917, 
        30.787823}}],
    Line[{{-15.029105, -19.677917, 30.787823},{-15.436413, -18.898148, 
        32.882790}}],
    Line[{{-15.436413, -18.898148, 32.882790},{-15.715100, -17.797697, 
        34.843323}}],
    Line[{{-15.715100, -17.797697, 34.843323},{-15.848028, -16.403709, 
        36.594830}}],
    Line[{{-15.848028, -16.403709, 36.594830},{-15.823303, -14.764296, 
        38.071552}}],
    Line[{{-15.823303, -14.764296, 38.071552},{-15.635624, -12.944856, 
        39.223591}}],
    Line[{{-15.635624, -12.944856, 39.223591},{-15.287002, -11.021788, 
        40.021980}}],
    Line[{{-15.287002, -11.021788, 40.021980},{-14.786748, -9.074647, 
        40.460880}}],
    Line[{{-14.786748, -9.074647, 40.460880},{-14.150694, -7.178182, 
        40.556545}}],
    Line[{{-14.150694, -7.178182, 40.556545},{-13.399757, -5.395753, 
        40.343296}}],
    Line[{{-13.399757, -5.395753, 40.343296},{-12.558167, -3.775033, 
        39.867867}}],
    Line[{{-12.558167, -3.775033, 39.867867},{-11.651548, -2.346459, 
        39.183056}}],
    Line[{{-11.651548, -2.346459, 39.183056},{-10.705173, -1.123955, 
        38.342049}}],
    Line[{{-10.705173, -1.123955, 38.342049},{-9.742534, -0.107449, 
        37.394001}}],
    Line[{{-9.742534, -0.107449, 37.394001},{-8.784331, 0.713807, 
        36.381256}}],
    Line[{{-8.784331, 0.713807, 36.381256},{-7.847904, 1.357729, 35.338100}}],
    
    Line[{{-7.847904, 1.357729, 35.338100},{-6.947015, 1.846241, 34.290653}}],
    
    Line[{{-6.947015, 1.846241, 34.290653},{-6.091945, 2.202755, 33.257652}}],
    
    Line[{{-6.091945, 2.202755, 33.257652},{-5.289773, 2.450317, 32.251575}}],
    
    Line[{{-5.289773, 2.450317, 32.251575},{-4.544777, 2.610407, 31.279955}}],
    
    Line[{{-4.544777, 2.610407, 31.279955},{-3.858892, 2.702270, 30.346622}}],
    
    Line[{{-3.858892, 2.702270, 30.346622},{-3.232155, 2.742624, 29.452795}}],
    
    Line[{{-3.232155, 2.742624, 29.452795},{-2.663133, 2.745644, 28.597952}}],
    
    Line[{{-2.663133, 2.745644, 28.597952},{-2.149300, 2.723103, 27.780516}}],
    
    Line[{{-2.149300, 2.723103, 27.780516},{-1.687355, 2.684610, 26.998339}}],
    
    Line[{{-1.687355, 2.684610, 26.998339},{-1.273489, 2.637885, 26.249052}}],
    
    Line[{{-1.273489, 2.637885, 26.249052},{-0.903605, 2.589042, 25.530281}}],
    
    Line[{{-0.903605, 2.589042, 25.530281},{-0.573475, 2.542854, 24.839792}}],
    
    Line[{{-0.573475, 2.542854, 24.839792},{-0.278880, 2.502995, 24.175556}}],
    
    Line[{{-0.278880, 2.502995, 24.175556},{-0.015693, 2.472259, 23.535786}}],
    
    Line[{{-0.015693, 2.472259, 23.535786},{0.220049, 2.452743, 22.918941}}],
    Line[{{0.220049, 2.452743, 22.918941},{0.432106, 2.446007, 22.323719}}],
    Line[{{0.432106, 2.446007, 22.323719},{0.624006, 2.453208, 21.749039}}],
    Line[{{0.624006, 2.453208, 21.749039},{0.799038, 2.475208, 21.194010}}],
    Line[{{0.799038, 2.475208, 21.194010},{0.960249, 2.512671, 20.657928}}],
    Line[{{0.960249, 2.512671, 20.657928},{1.110454, 2.566133, 20.140247}}],
    Line[{{1.110454, 2.566133, 20.140247},{1.252244, 2.636071, 19.640562}}],
    Line[{{1.252244, 2.636071, 19.640562},{1.388012, 2.722945, 19.158606}}],
    Line[{{1.388012, 2.722945, 19.158606},{1.519965, 2.827241, 18.694239}}],
    Line[{{1.519965, 2.827241, 18.694239},{1.650151, 2.949505, 18.247452}}],
    Line[{{1.650151, 2.949505, 18.247452},{1.780477, 3.090366, 17.818357}}],
    Line[{{1.780477, 3.090366, 17.818357},{1.912734, 3.250554, 17.407207}}],
    Line[{{1.912734, 3.250554, 17.407207},{2.048619, 3.430916, 17.014399}}],
    Line[{{2.048619, 3.430916, 17.014399},{2.189751, 3.632427, 16.640482}}],
    Line[{{2.189751, 3.632427, 16.640482},{2.337698, 3.856192, 16.286190}}],
    Line[{{2.337698, 3.856192, 16.286190},{2.493986, 4.103453, 15.952456}}],
    Line[{{2.493986, 4.103453, 15.952456},{2.660123, 4.375581, 15.640435}}],
    Line[{{2.660123, 4.375581, 15.640435},{2.837612, 4.674076, 15.351551}}],
    Line[{{2.837612, 4.674076, 15.351551},{3.027956, 5.000542, 15.087523}}],
    Line[{{3.027956, 5.000542, 15.087523},{3.232677, 5.356677, 14.850412}}],
    Line[{{3.232677, 5.356677, 14.850412},{3.453315, 5.744239, 14.642674}}],
    Line[{{3.453315, 5.744239, 14.642674},{3.691432, 6.165002, 14.467214}}],
    Line[{{3.691432, 6.165002, 14.467214},{3.948606, 6.620694, 14.327442}}],
    Line[{{3.948606, 6.620694, 14.327442},{4.226431, 7.112939, 14.227342}}],
    Line[{{4.226431, 7.112939, 14.227342},{4.526489, 7.643140, 14.171535}}],
    Line[{{4.526489, 7.643140, 14.171535},{4.850329, 8.212349, 14.165349}}],
    Line[{{4.850329, 8.212349, 14.165349},{5.199434, 8.821136, 14.214864}}],
    Line[{{5.199434, 8.821136, 14.214864},{5.575167, 9.469358, 14.326966}}],
    Line[{{5.575167, 9.469358, 14.326966},{5.978698, 10.155913, 14.509349}}],
    Line[{{5.978698, 10.155913, 14.509349},{6.410931, 10.878478, 14.770503}}],
    
    Line[{{6.410931, 10.878478, 14.770503},{6.872389, 11.633145, 15.119632}}],
    
    Line[{{6.872389, 11.633145, 15.119632},{7.363073, 12.414008, 15.566446}}],
    
    Line[{{7.363073, 12.414008, 15.566446},{7.882318, 13.212794, 16.120937}}],
    
    Line[{{7.882318, 13.212794, 16.120937},{8.428598, 14.018386, 16.792898}}],
    
    Line[{{8.428598, 14.018386, 16.792898},{8.999322, 14.816440, 17.591351}}],
    
    Line[{{8.999322, 14.816440, 17.591351},{9.590607, 15.589064, 18.523724}}],
    
    Line[{{9.590607, 15.589064, 18.523724},{
      10.197062, 16.314678, 19.594835}}],
    Line[{{10.197062, 16.314678, 19.594835},{
      10.811583, 16.968153, 20.805679}}],
    Line[{{10.811583, 16.968153, 20.805679},{
      11.425189, 17.521280, 22.152105}}],
    Line[{{11.425189, 17.521280, 22.152105},{
      12.026967, 17.943830, 23.623411}}],
    Line[{{12.026967, 17.943830, 23.623411},{
      12.604128, 18.205128, 25.201172}}],
    Line[{{12.604128, 18.205128, 25.201172},{
      13.142242, 18.276207, 26.858442}}],
    Line[{{13.142242, 18.276207, 26.858442},{
      13.625687, 18.132500, 28.559641}}],
    Line[{{13.625687, 18.132500, 28.559641},{
      14.038320, 17.756769, 30.261393}}],
    Line[{{14.038320, 17.756769, 30.261393},{
      14.364363, 17.141903, 31.914474}}],
    Line[{{14.364363, 17.141903, 31.914474},{
      14.589444, 16.293129, 33.466873}}],
    Line[{{14.589444, 16.293129, 33.466873},{
      14.701709, 15.229112, 34.867714}}],
    Line[{{14.701709, 15.229112, 34.867714},{
      14.692843, 13.981528, 36.071606}}],
    Line[{{14.692843, 13.981528, 36.071606},{
      14.558898, 12.593060, 37.042645}}],
    Line[{{14.558898, 12.593060, 37.042645},{
      14.300750, 11.113928, 37.757515}}],
    Line[{{14.300750, 11.113928, 37.757515},{
      13.924172, 9.597528, 38.207127}}],
    Line[{{13.924172, 9.597528, 38.207127},{13.439432, 8.095786, 38.396481}}],
    
    Line[{{13.439432, 8.095786, 38.396481},{12.860518, 6.655043, 38.342964}}],
    
    Line[{{12.860518, 6.655043, 38.342964},{12.204100, 5.313020, 38.073421}}],
    
    Line[{{12.204100, 5.313020, 38.073421},{11.488359, 4.097140, 37.620705}}],
    
    Line[{{11.488359, 4.097140, 37.620705},{10.731844, 3.024212, 37.020138}}],
    
    Line[{{10.731844, 3.024212, 37.020138},{9.952449, 2.101246, 36.306538}}],
    Line[{{9.952449, 2.101246, 36.306538},{9.166624, 1.327022, 35.511936}}],
    Line[{{9.166624, 1.327022, 35.511936},{8.388816, 0.694035, 34.664188}}],
    Line[{{8.388816, 0.694035, 34.664188},{7.631158, 0.190465, 33.786297}}],
    Line[{{7.631158, 0.190465, 33.786297},{6.903368, -0.198033, 32.896408}}],
    Line[{{6.903368, -0.198033, 32.896408},{6.212814, -0.486869, 32.008156}}],
    
    Line[{{6.212814, -0.486869, 32.008156},{5.564690, -0.691413, 31.131306}}],
    
    Line[{{5.564690, -0.691413, 31.131306},{4.962266, -0.826235, 30.272430}}],
    
    Line[{{4.962266, -0.826235, 30.272430},{4.407174, -0.904625, 29.435623}}],
    
    Line[{{4.407174, -0.904625, 29.435623},{3.899698, -0.938352, 28.623121}}],
    
    Line[{{3.899698, -0.938352, 28.623121},{3.439054, -0.937584, 27.835840}}],
    
    Line[{{3.439054, -0.937584, 27.835840},{3.023637, -0.910920, 27.073790}}],
    
    Line[{{3.023637, -0.910920, 27.073790},{2.651252, -0.865495, 26.336411}}],
    
    Line[{{2.651252, -0.865495, 26.336411},{2.319299, -0.807121, 25.622807}}],
    
    Line[{{2.319299, -0.807121, 25.622807},{2.024928, -0.740443, 24.931911}}],
    
    Line[{{2.024928, -0.740443, 24.931911},{1.765169, -0.669108, 24.262608}}],
    
    Line[{{1.765169, -0.669108, 24.262608},{1.537030, -0.595908, 23.613791}}],
    
    Line[{{1.537030, -0.595908, 23.613791},{1.337573, -0.522929, 22.984421}}],
    
    Line[{{1.337573, -0.522929, 22.984421},{1.163972, -0.451675, 22.373533}}],
    
    Line[{{1.163972, -0.451675, 22.373533},{1.013547, -0.383175, 21.780252}}],
    
    Line[{{1.013547, -0.383175, 21.780252},{0.883796, -0.318080, 21.203787}}],
    
    Line[{{0.883796, -0.318080, 21.203787},{0.772409, -0.256746, 20.643423}}],
    
    Line[{{0.772409, -0.256746, 20.643423},{0.677273, -0.199296, 20.098524}}],
    
    Line[{{0.677273, -0.199296, 20.098524},{0.596472, -0.145678, 19.568512}}],
    
    Line[{{0.596472, -0.145678, 19.568512},{0.528287, -0.095711, 19.052862}}],
    
    Line[{{0.528287, -0.095711, 19.052862},{0.471179, -0.049117, 18.551094}}],
    
    Line[{{0.471179, -0.049117, 18.551094},{0.423792, -0.005554, 18.062767}}],
    
    Line[{{0.423792, -0.005554, 18.062767},{0.384929, 0.035363, 17.587471}}],
    Line[{{0.384929, 0.035363, 17.587471},{0.353548, 0.074049, 17.124823}}],
    Line[{{0.353548, 0.074049, 17.124823},{0.328745, 0.110932, 16.674461}}],
    Line[{{0.328745, 0.110932, 16.674461},{0.309742, 0.146447, 16.236048}}],
    Line[{{0.309742, 0.146447, 16.236048},{0.295880, 0.181031, 15.809255}}],
    Line[{{0.295880, 0.181031, 15.809255},{0.286601, 0.215117, 15.393773}}],
    Line[{{0.286601, 0.215117, 15.393773},{0.281442, 0.249138, 14.989307}}],
    Line[{{0.281442, 0.249138, 14.989307},{0.280027, 0.283519, 14.595573}}],
    Line[{{0.280027, 0.283519, 14.595573},{0.282053, 0.318688, 14.212298}}],
    Line[{{0.282053, 0.318688, 14.212298},{0.287288, 0.355072, 13.839221}}],
    Line[{{0.287288, 0.355072, 13.839221},{0.295564, 0.393103, 13.476091}}],
    Line[{{0.295564, 0.393103, 13.476091},{0.306770, 0.433222, 13.122670}}],
    Line[{{0.306770, 0.433222, 13.122670},{0.320846, 0.475879, 12.778730}}],
    Line[{{0.320846, 0.475879, 12.778730},{0.337784, 0.521547, 12.444054}}],
    Line[{{0.337784, 0.521547, 12.444054},{0.357622, 0.570718, 12.118439}}],
    Line[{{0.357622, 0.570718, 12.118439},{0.380442, 0.623914, 11.801694}}],
    Line[{{0.380442, 0.623914, 11.801694},{0.406371, 0.681693, 11.493644}}],
    Line[{{0.406371, 0.681693, 11.493644},{0.435576, 0.744653, 11.194129}}],
    Line[{{0.435576, 0.744653, 11.194129},{0.468270, 0.813442, 10.903008}}],
    Line[{{0.468270, 0.813442, 10.903008},{0.504710, 0.888764, 10.620159}}],
    Line[{{0.504710, 0.888764, 10.620159},{0.545197, 0.971386, 10.345487}}],
    Line[{{0.545197, 0.971386, 10.345487},{0.590081, 1.062151, 10.078919}}],
    Line[{{0.590081, 1.062151, 10.078919},{0.639763, 1.161983, 9.820420}}],
    Line[{{0.639763, 1.161983, 9.820420},{0.694697, 1.271901, 9.569988}}],
    Line[{{0.694697, 1.271901, 9.569988},{0.755397, 1.393027, 9.327666}}],
    Line[{{0.755397, 1.393027, 9.327666},{0.822439, 1.526600, 9.093553}}],
    Line[{{0.822439, 1.526600, 9.093553},{0.896470, 1.673990, 8.867807}}],
    Line[{{0.896470, 1.673990, 8.867807},{0.978212, 1.836710, 8.650665}}],
    Line[{{0.978212, 1.836710, 8.650665},{1.068470, 2.016430, 8.442456}}],
    Line[{{1.068470, 2.016430, 8.442456},{1.168138, 2.214998, 8.243618}}],
    Line[{{1.168138, 2.214998, 8.243618},{1.278212, 2.434448, 8.054723}}],
    Line[{{1.278212, 2.434448, 8.054723},{1.399796, 2.677025, 7.876507}}],
    Line[{{1.399796, 2.677025, 7.876507},{1.534112, 2.945195, 7.709902}}],
    Line[{{1.534112, 2.945195, 7.709902},{1.682514, 3.241666, 7.556081}}],
    Line[{{1.682514, 3.241666, 7.556081},{1.846496, 3.569396, 7.416509}}],
    Line[{{1.846496, 3.569396, 7.416509},{2.027703, 3.931610, 7.293001}}],
    Line[{{2.027703, 3.931610, 7.293001},{2.227946, 4.331800, 7.187800}}],
    Line[{{2.227946, 4.331800, 7.187800},{2.449205, 4.773718, 7.103676}}],
    Line[{{2.449205, 4.773718, 7.103676},{2.693645, 5.261377, 7.044010}}],
    Line[{{2.693645, 5.261377, 7.044010},{2.963616, 5.798991, 7.012953}}],
    Line[{{2.963616, 5.798991, 7.012953},{3.261651, 6.390932, 7.015555}}],
    Line[{{3.261651, 6.390932, 7.015555},{3.590467, 7.041651, 7.057936}}],
    Line[{{3.590467, 7.041651, 7.057936},{3.952936, 7.755486, 7.147501}}],
    Line[{{3.952936, 7.755486, 7.147501},{4.352069, 8.536541, 7.293134}}],
    Line[{{4.352069, 8.536541, 7.293134},{4.790943, 9.388305, 7.505446}}],
    Line[{{4.790943, 9.388305, 7.505446},{5.272645, 10.313352, 7.797003}}],
    Line[{{5.272645, 10.313352, 7.797003},{5.800137, 11.312740, 8.182530}}],
    Line[{{5.800137, 11.312740, 8.182530},{6.376103, 12.385373, 8.679070}}],
    Line[{{6.376103, 12.385373, 8.679070},{7.002726, 13.527103, 9.306001}}],
    Line[{{7.002726, 13.527103, 9.306001},{7.681403, 14.729677, 10.084937}}],
    Line[{{7.681403, 14.729677, 10.084937},{8.412356, 15.979420, 11.039190}}],
    
    Line[{{8.412356, 15.979420, 11.039190},{9.194167, 17.255829, 12.192949}}],
    
    Line[{{9.194167, 17.255829, 12.192949},{
      10.023211, 18.530077, 13.569752}}],
    Line[{{10.023211, 18.530077, 13.569752},{
      10.893006, 19.763693, 15.190268}}],
    Line[{{10.893006, 19.763693, 15.190268},{
      11.793525, 20.907682, 17.069197}}],
    Line[{{11.793525, 20.907682, 17.069197},{
      12.710516, 21.902590, 19.211296}}],
    Line[{{12.710516, 21.902590, 19.211296},{
      13.624973, 22.680052, 21.606749}}],
    Line[{{13.624973, 22.680052, 21.606749},{
      14.512897, 23.166382, 24.226387}}],
    Line[{{14.512897, 23.166382, 24.226387},{
      15.345544, 23.288704, 27.017845}}],
    Line[{{15.345544, 23.288704, 27.017845},{
      16.090338, 22.983297, 29.903597}}],
    Line[{{16.090338, 22.983297, 29.903597},{
      16.712591, 22.205774, 32.782654}}],
    Line[{{16.712591, 22.205774, 32.782654},{
      17.178032, 20.941097, 35.536732}}],
    Line[{{17.178032, 20.941097, 35.536732},{
      17.455980, 19.211260, 38.041183}}],
    Line[{{17.455980, 19.211260, 38.041183},{
      17.522678, 17.077919, 40.179348}}],
    Line[{{17.522678, 17.077919, 40.179348},{
      17.364298, 14.638521, 41.857750}}],
    Line[{{17.364298, 14.638521, 41.857750},{
      16.978920, 12.015672, 43.018486}}],
    Line[{{16.978920, 12.015672, 43.018486},{
      16.377087, 9.341873, 43.645840}}],
    Line[{{16.377087, 9.341873, 43.645840},{15.580754, 6.742991, 43.765564}}],
    
    Line[{{15.580754, 6.742991, 43.765564},{14.620862, 4.324334, 43.437332}}],
    
    Line[{{14.620862, 4.324334, 43.437332},{13.534058, 2.161860, 42.742954}}],
    
    Line[{{13.534058, 2.161860, 42.742954},{12.359170, 0.299432, 41.773319}}],
    
    Line[{{12.359170, 0.299432, 41.773319},{
      11.134046, -1.248661, 40.617092}}],
    Line[{{11.134046, -1.248661, 40.617092},{
      9.893086, -2.491827, 39.352619}}],
    Line[{{9.893086, -2.491827, 39.352619},{8.665671, -3.455925, 38.043564}}],
    
    Line[{{8.665671, -3.455925, 38.043564},{7.475410, -4.176306, 36.737774}}],
    
    Line[{{7.475410, -4.176306, 36.737774},{6.340078, -4.692104, 35.468357}}],
    
    Line[{{6.340078, -4.692104, 35.468357},{5.272027, -5.042129, 34.256023}}],
    
    Line[{{5.272027, -5.042129, 34.256023},{4.278865, -5.262264, 33.111855}}],
    
    Line[{{4.278865, -5.262264, 33.111855},{3.364259, -5.384124, 32.039963}}],
    
    Line[{{3.364259, -5.384124, 32.039963},{2.528748, -5.434580, 31.039812}}],
    
    Line[{{2.528748, -5.434580, 31.039812},{1.770492, -5.435833, 30.107998}}],
    
    Line[{{1.770492, -5.435833, 30.107998},{1.085920, -5.405830, 29.239603}}],
    
    Line[{{1.085920, -5.405830, 29.239603},{0.470277, -5.358818, 28.429115}}],
    
    Line[{{
      0.470277, -5.358818, 28.429115},{-0.081937, -5.305923, 27.671040}}],
    Line[{{-0.081937, -5.305923, 27.671040},{-0.576633, -5.255705, 
        26.960258}}],
    Line[{{-0.576633, -5.255705, 26.960258},{-1.019868, -5.214654, 
        26.292227}}],
    Line[{{-1.019868, -5.214654, 26.292227},{-1.417657, -5.187619, 
        25.663057}}],
    Line[{{-1.417657, -5.187619, 25.663057},{-1.775842, -5.178162, 
        25.069529}}],
    Line[{{-1.775842, -5.178162, 25.069529},{-2.099996, -5.188854, 
        24.509052}}],
    Line[{{-2.099996, -5.188854, 24.509052},{-2.395368, -5.221509, 
        23.979626}}],
    Line[{{-2.395368, -5.221509, 23.979626},{-2.666851, -5.277376, 
        23.479774}}],
    Line[{{-2.666851, -5.277376, 23.479774},{-2.918972, -5.357291, 
        23.008492}}],
    Line[{{-2.918972, -5.357291, 23.008492},{-3.155890, -5.461788, 
        22.565189}}],
    Line[{{-3.155890, -5.461788, 22.565189},{-3.381408, -5.591191, 
        22.149652}}],
    Line[{{-3.381408, -5.591191, 22.149652},{-3.598991, -5.745679, 
        21.762012}}],
    Line[{{-3.598991, -5.745679, 21.762012},{-3.811787, -5.925330, 
        21.402710}}],
    Line[{{-3.811787, -5.925330, 21.402710},{-4.022645, -6.130148, 
        21.072483}}],
    Line[{{-4.022645, -6.130148, 21.072483},{-4.234145, -6.360079, 
        20.772358}}],
    Line[{{-4.234145, -6.360079, 20.772358},{-4.448608, -6.615001, 
        20.503639}}],
    Line[{{-4.448608, -6.615001, 20.503639},{-4.668124, -6.894718, 
        20.267904}}],
    Line[{{-4.668124, -6.894718, 20.267904},{-4.894557, -7.198929, 
        20.067013}}],
    Line[{{-4.894557, -7.198929, 20.067013},{-5.129560, -7.527193, 
        19.903095}}],
    Line[{{-5.129560, -7.527193, 19.903095},{-5.374578, -7.878873, 
        19.778555}}],
    Line[{{-5.374578, -7.878873, 19.778555},{-5.630843, -8.253073, 
        19.696060}}],
    Line[{{-5.630843, -8.253073, 19.696060},{-5.899375, -8.648578, 
        19.658531}}],
    Line[{{-5.899375, -8.648578, 19.658531},{-6.180958, -9.063746, 
        19.669106}}],
    Line[{{-6.180958, -9.063746, 19.669106},{-6.476119, -9.496431, 
        19.731098}}],
    Line[{{-6.476119, -9.496431, 19.731098},{-6.785109, -9.943878, 
        19.847948}}],
    Line[{{-6.785109, -9.943878, 19.847948},{-7.107853, -10.402604, 
        20.023121}}],
    Line[{{-7.107853, -10.402604, 20.023121},{-7.443912, -10.868304, 
        20.259979}}],
    Line[{{-7.443912, -10.868304, 20.259979},{-7.792440, -11.335747, 
        20.561668}}],
    Line[{{-7.792440, -11.335747, 20.561668},{-8.152122, -11.798685, 
        20.930885}}],
    Line[{{-8.152122, -11.798685, 20.930885},{-8.521122, -12.249826, 
        21.369648}}],
    Line[{{-8.521122, -12.249826, 21.369648},{-8.897035, -12.680786, 
        21.879074}}],
    Line[{{-8.897035, -12.680786, 21.879074},{-9.276834, -13.082177, 
        22.459007}}],
    Line[{{-9.276834, -13.082177, 22.459007},{-9.656848, -13.443738, 
        23.107738}}],
    Line[{{-9.656848, -13.443738, 23.107738},{-10.032738, -13.754547, 
        23.821665}}],
    Line[{{-10.032738, -13.754547, 23.821665},{-10.399525, -14.003369, 
        24.594995}}],
    Line[{{-10.399525, -14.003369, 24.594995},{-10.751636, -14.179123, 
        25.419504}}],
    Line[{{-10.751636, -14.179123, 25.419504},{-11.083003, -14.271433, 
        26.284416}}],
    Line[{{-11.083003, -14.271433, 26.284416},{-11.387213, -14.271275, 
        27.176418}}],
    Line[{{-11.387213, -14.271275, 27.176418},{-11.657689, -14.171650, 
        28.079842}}],
    Line[{{-11.657689, -14.171650, 28.079842},{-11.887943, -13.968279, 
        28.977081}}],
    Line[{{-11.887943, -13.968279, 28.977081},{-12.071853, -13.660179, 
        29.849237}}],
    Line[{{-12.071853, -13.660179, 29.849237},{-12.203964, -13.250065, 
        30.676931}}],
    Line[{{-12.203964, -13.250065, 30.676931},{-12.279787, -12.744532, 
        31.441248}}],
    Line[{{-12.279787, -12.744532, 31.441248},{-12.296068, -12.153945, 
        32.124752}}],
    Line[{{-12.296068, -12.153945, 32.124752},{-12.251020, -11.492017, 
        32.712467}}],
    Line[{{-12.251020, -11.492017, 32.712467},{-12.144464, -10.775112, 
        33.192669}}],
    Line[{{-12.144464, -10.775112, 33.192669},{-11.977889, -10.021331, 
        33.557472}}],
    Line[{{-11.977889, -10.021331, 33.557472},{-11.754404, -9.249461, 
        33.803104}}],
    Line[{{-11.754404, -9.249461, 33.803104},{-11.478603, -8.477925, 
        33.929848}}],
    Line[{{-11.478603, -8.477925, 33.929848},{-11.156338, -7.723822, 
        33.941708}}],
    Line[{{-11.156338, -7.723822, 33.941708},{-10.794435, -7.002143, 
        33.845825}}],
    Line[{{-10.794435, -7.002143, 33.845825},{-10.400372, -6.325246, 
        33.651749}}],
    Line[{{-10.400372, -6.325246, 33.651749},{-9.981952, -5.702565, 
        33.370621}}],
    Line[{{-9.981952, -5.702565, 33.370621},{-9.546988, -5.140583, 
        33.014435}}],
    Line[{{-9.546988, -5.140583, 33.014435},{-9.103034, -4.642998, 
        32.595333}}],
    Line[{{-9.103034, -4.642998, 32.595333},{-8.657149, -4.211046, 
        32.125042}}],
    Line[{{-8.657149, -4.211046, 32.125042},{-8.215740, -3.843907, 
        31.614494}}],
    Line[{{-8.215740, -3.843907, 31.614494},{-7.784441, -3.539155, 
        31.073536}}],
    Line[{{-7.784441, -3.539155, 31.073536},{-7.368063, -3.293205, 
        30.510815}}],
    Line[{{-7.368063, -3.293205, 30.510815},{-6.970575, -3.101712, 
        29.933741}}],
    Line[{{-6.970575, -3.101712, 29.933741},{-6.595135, -2.959931, 
        29.348534}}],
    Line[{{-6.595135, -2.959931, 29.348534},{-6.244141, -2.862998, 
        28.760334}}],
    Line[{{-6.244141, -2.862998, 28.760334},{-5.919302, -2.806153, 
        28.173319}}],
    Line[{{-5.919302, -2.806153, 28.173319},{-5.621726, -2.784909, 
        27.590847}}],
    Line[{{-5.621726, -2.784909, 27.590847},{-5.352003, -2.795158, 
        27.015606}}],
    Line[{{-5.352003, -2.795158, 27.015606},{-5.110299, -2.833238, 
        26.449728}}],
    Line[{{-5.110299, -2.833238, 26.449728},{-4.896438, -2.895972, 
        25.894922}}],
    Line[{{-4.896438, -2.895972, 25.894922},{-4.709983, -2.980666, 
        25.352568}}],
    Line[{{-4.709983, -2.980666, 25.352568},{-4.550305, -3.085104, 
        24.823803}}],
    Line[{{-4.550305, -3.085104, 24.823803},{-4.416645, -3.207525, 
        24.309591}}],
    Line[{{-4.416645, -3.207525, 24.309591},{-4.308171, -3.346584, 
        23.810791}}],
    Line[{{-4.308171, -3.346584, 23.810791},{-4.224020, -3.501319, 
        23.328196}}],
    Line[{{-4.224020, -3.501319, 23.328196},{-4.163336, -3.671113, 
        22.862576}}],
    Line[{{-4.163336, -3.671113, 22.862576},{-4.125302, -3.855650, 
        22.414715}}],
    Line[{{-4.125302, -3.855650, 22.414715},{-4.109160, -4.054882, 
        21.985435}}],
    Line[{{-4.109160, -4.054882, 21.985435},{-4.114234, -4.268984, 
        21.575628}}],
    Line[{{-4.114234, -4.268984, 21.575628},{-4.139934, -4.498325, 
        21.186272}}],
    Line[{{-4.139934, -4.498325, 21.186272},{-4.185774, -4.743430, 
        20.818460}}],
    Line[{{-4.185774, -4.743430, 20.818460},{-4.251366, -5.004946, 
        20.473415}}],
    Line[{{-4.251366, -5.004946, 20.473415},{-4.336428, -5.283607, 
        20.152525}}],
    Line[{{-4.336428, -5.283607, 20.152525},{-4.440775, -5.580198, 
        19.857346}}],
    Line[{{-4.440775, -5.580198, 19.857346},{-4.564320, -5.895523, 
        19.589642}}],
    Line[{{-4.564320, -5.895523, 19.589642},{-4.707053, -6.230352, 
        19.351397}}],
    Line[{{-4.707053, -6.230352, 19.351397},{-4.869041, -6.585389, 
        19.144840}}],
    Line[{{-4.869041, -6.585389, 19.144840},{-5.050404, -6.961204, 
        18.972467}}],
    Line[{{-5.050404, -6.961204, 18.972467},{-5.251294, -7.358185, 
        18.837055}}],
    Line[{{-5.251294, -7.358185, 18.837055},{-5.471878, -7.776460, 
        18.741674}}],
    Line[{{-5.471878, -7.776460, 18.741674},{-5.712298, -8.215813, 
        18.689692}}],
    Line[{{-5.712298, -8.215813, 18.689692},{-5.972647, -8.675599, 
        18.684774}}],
    Line[{{-5.972647, -8.675599, 18.684774},{-6.252920, -9.154627, 
        18.730852}}],
    Line[{{-6.252920, -9.154627, 18.730852},{-6.552967, -9.651049, 
        18.832088}}],
    Line[{{-6.552967, -9.651049, 18.832088},{-6.872441, -10.162222, 
        18.992811}}],
    Line[{{-6.872441, -10.162222, 18.992811},{-7.210734, -10.684580, 
        19.217415}}],
    Line[{{-7.210734, -10.684580, 19.217415},{-7.566902, -11.213484, 
        19.510201}}],
    Line[{{-7.566902, -11.213484, 19.510201},{-7.939596, -11.743098, 
        19.875231}}],
    Line[{{-7.939596, -11.743098, 19.875231},{-8.326977, -12.266285, 
        20.316031}}],
    Line[{{-8.326977, -12.266285, 20.316031},{-8.726631, -12.774497, 
        20.835360}}],
    Line[{{-8.726631, -12.774497, 20.835360},{-9.135496, -13.257822, 
        21.434784}}],
    Line[{{-9.135496, -13.257822, 21.434784},{-9.549797, -13.705018, 
        22.114344}}],
    Line[{{-9.549797, -13.705018, 22.114344},{-9.964981, -14.103656, 
        22.872080}}],
    Line[{{-9.964981, -14.103656, 22.872080},{-10.375708, -14.440501, 
        23.703615}}],
    Line[{{-10.375708, -14.440501, 23.703615},{-10.775867, -14.701931, 
        24.601791}}],
    Line[{{-10.775867, -14.701931, 24.601791},{-11.158625, -14.874538, 
        25.556271}}],
    Line[{{-11.158625, -14.874538, 25.556271},{-11.516582, -14.945962, 
        26.553524}}],
    Line[{{-11.516582, -14.945962, 26.553524},{-11.841938, -14.905686, 
        27.576750}}],
    Line[{{-11.841938, -14.905686, 27.576750},{-12.126766, -14.746053, 
        28.606253}}],
    Line[{{-12.126766, -14.746053, 28.606253},{-12.363340, -14.463034, 
        29.620127}}],
    Line[{{-12.363340, -14.463034, 29.620127},{-12.544488, -14.057026, 
        30.595068}}],
    Line[{{-12.544488, -14.057026, 30.595068},{-12.663998, -13.533289, 
        31.507607}}],
    Line[{{-12.663998, -13.533289, 31.507607},{-12.716988, -12.902034, 
        32.335415}}],
    Line[{{-12.716988, -12.902034, 32.335415},{-12.700239, -12.178097, 
        33.058617}}],
    Line[{{-12.700239, -12.178097, 33.058617},{-12.612447, -11.380196, 
        33.661030}}],
    Line[{{-12.612447, -11.380196, 33.661030},{-12.454355, -10.529852, 
        34.131073}}],
    Line[{{-12.454355, -10.529852, 34.131073},{-12.228772, -9.650023, 
        34.462364}}],
    Line[{{-12.228772, -9.650023, 34.462364},{-11.940432, -8.763685, 
        34.653763}}],
    Line[{{-11.940432, -8.763685, 34.653763},{-11.595748, -7.892486, 
        34.709061}}],
    Line[{{-11.595748, -7.892486, 34.709061},{-11.202477, -7.055635, 
        34.636295}}],
    Line[{{-11.202477, -7.055635, 34.636295},{-10.769310, -6.269062, 
        34.446804}}],
    Line[{{-10.769310, -6.269062, 34.446804},{-10.305449, -5.544979, 
        34.154144}}],
    Line[{{-10.305449, -5.544979, 34.154144},{-9.820201, -4.891767, 
        33.773064}}],
    Line[{{-9.820201, -4.891767, 33.773064},{-9.322601, -4.314179, 
        33.318546}}],
    Line[{{-9.322601, -4.314179, 33.318546},{-8.821120, -3.813746, 
        32.805035}}],
    Line[{{-8.821120, -3.813746, 32.805035},{-8.323435, -3.389328, 
        32.245899}}],
    Line[{{-8.323435, -3.389328, 32.245899},{-7.836277, -3.037717, 
        31.653070}}],
    Line[{{-7.836277, -3.037717, 31.653070},{-7.365356, -2.754230, 
        31.036869}}],
    Line[{{-7.365356, -2.754230, 31.036869},{-6.915346, -2.533251, 
        30.405996}}],
    Line[{{-6.915346, -2.533251, 30.405996},{-6.489911, -2.368692, 
        29.767595}}],
    Line[{{-6.489911, -2.368692, 29.767595},{-6.091783, -2.254371, 
        29.127415}}],
    Line[{{-6.091783, -2.254371, 29.127415},{-5.722851, -2.184280, 
        28.489994}}],
    Line[{{-5.722851, -2.184280, 28.489994},{-5.384271, -2.152797, 
        27.858849}}],
    Line[{{-5.384271, -2.152797, 27.858849},{-5.076577, -2.154813, 
        27.236662}}],
    Line[{{-5.076577, -2.154813, 27.236662},{-4.799794, -2.185802, 
        26.625465}}],
    Line[{{-4.799794, -2.185802, 26.625465},{-4.553543, -2.241857, 
        26.026781}}],
    Line[{{-4.553543, -2.241857, 26.026781},{-4.337140, -2.319685, 
        25.441750}}],
    Line[{{-4.337140, -2.319685, 25.441750},{-4.149682, -2.416586, 
        24.871241}}],
    Line[{{-4.149682, -2.416586, 24.871241},{-3.990120, -2.530414, 
        24.315935}}],
    Line[{{-3.990120, -2.530414, 24.315935},{-3.857328, -2.659533, 
        23.776386}}],
    Line[{{-3.857328, -2.659533, 23.776386},{-3.750153, -2.802767, 
        23.253084}}],
    Line[{{-3.750153, -2.802767, 23.253084},{-3.667460, -2.959348, 
        22.746487}}],
    Line[{{-3.667460, -2.959348, 22.746487},{-3.608168, -3.128874, 
        22.257063}}],
    Line[{{-3.608168, -3.128874, 22.257063},{-3.571274, -3.311255, 
        21.785313}}],
    Line[{{-3.571274, -3.311255, 21.785313},{-3.555877, -3.506677, 
        21.331793}}],
    Line[{{-3.555877, -3.506677, 21.331793},{-3.561191, -3.715564, 
        20.897142}}],
    Line[{{-3.561191, -3.715564, 20.897142},{-3.586556, -3.938540, 
        20.482094}}],
    Line[{{-3.586556, -3.938540, 20.482094},{-3.631440, -4.176397, 
        20.087505}}],
    Line[{{-3.631440, -4.176397, 20.087505},{-3.695447, -4.430067, 
        19.714367}}],
    Line[{{-3.695447, -4.430067, 19.714367},{-3.778312, -4.700593, 
        19.363834}}],
    Line[{{-3.778312, -4.700593, 19.363834},{-3.879897, -4.989098, 
        19.037247}}],
    Line[{{-3.879897, -4.989098, 19.037247},{-4.000189, -5.296757, 
        18.736149}}],
    Line[{{-4.000189, -5.296757, 18.736149},{-4.139288, -5.624766, 
        18.462324}}],
    Line[{{-4.139288, -5.624766, 18.462324},{-4.297398, -5.974297, 
        18.217819}}],
    Line[{{-4.297398, -5.974297, 18.217819},{-4.474813, -6.346466, 
        18.004971}}],
    Line[{{-4.474813, -6.346466, 18.004971},{-4.671897, -6.742269, 
        17.826443}}],
    Line[{{-4.671897, -6.742269, 17.826443},{-4.889073, -7.162536, 
        17.685244}}],
    Line[{{-4.889073, -7.162536, 17.685244},{-5.126785, -7.607838, 
        17.584761}}],
    Line[{{-5.126785, -7.607838, 17.584761},{-5.385476, -8.078415, 
        17.528774}}],
    Line[{{-5.385476, -8.078415, 17.528774},{-5.665549, -8.574061, 
        17.521469}}],
    Line[{{-5.665549, -8.574061, 17.521469},{-5.967322, -9.094000, 
        17.567423}}],
    Line[{{-5.967322, -9.094000, 17.567423},{-6.290978, -9.636748, 
        17.671598}}],
    Line[{{-6.290978, -9.636748, 17.671598},{-6.636495, -10.199941, 
        17.839251}}],
    Line[{{-6.636495, -10.199941, 17.839251},{-7.003586, -10.780166, 
        18.075899}}],
    Line[{{-7.003586, -10.780166, 18.075899},{-7.391602, -11.372765, 
        18.387104}}],
    Line[{{-7.391602, -11.372765, 18.387104},{-7.799447, -11.971641, 
        18.778349}}],
    Line[{{-7.799447, -11.971641, 18.778349},{-8.225471, -12.569077, 
        19.254713}}],
    Line[{{-8.225471, -12.569077, 19.254713},{-8.667366, -13.155614, 
        19.820543}}],
    Line[{{-8.667366, -13.155614, 19.820543},{-9.122046, -13.719892, 
        20.479040}}],
    Line[{{-9.122046, -13.719892, 20.479040},{-9.585557, -14.248774, 
        21.231707}}],
    Line[{{-9.585557, -14.248774, 21.231707},{-10.052980, -14.727376, 
        22.077810}}],
    Line[{{-10.052980, -14.727376, 22.077810},{-10.518381, -15.139429, 
        23.013750}}],
    Line[{{-10.518381, -15.139429, 23.013750},{-10.974797, -15.467828, 
        24.032480}}],
    Line[{{-10.974797, -15.467828, 24.032480},{-11.414285, -15.695320, 
        25.123009}}],
    Line[{{-11.414285, -15.695320, 25.123009},{-11.828042, -15.805534, 
        26.270027}}],
    Line[{{-11.828042, -15.805534, 26.270027},{-12.206647, -15.784152, 
        27.453907}}],
    Line[{{-12.206647, -15.784152, 27.453907},{-12.540356, -15.620145, 
        28.651014}}],
    Line[{{-12.540356, -15.620145, 28.651014},{-12.819515, -15.307145, 
        29.834328}}],
    Line[{{-12.819515, -15.307145, 29.834328},{-13.035053, -14.844402, 
        30.974779}}],
    Line[{{-13.035053, -14.844402, 30.974779},{-13.178997, -14.237620, 
        32.042706}}],
    Line[{{-13.178997, -14.237620, 32.042706},{-13.244998, -13.499137, 
        33.009724}}],
    Line[{{-13.244998, -13.499137, 33.009724},{-13.228791, -12.647562, 
        33.850574}}],
    Line[{{-13.228791, -12.647562, 33.850574},{-13.128558, -11.706778, 
        34.544899}}],
    Line[{{-13.128558, -11.706778, 34.544899},{-12.945121, -10.704373, 
        35.078545}}],
    Line[{{-12.945121, -10.704373, 35.078545},{-12.681949, -9.669757, 
        35.444286}}],
    Line[{{-12.681949, -9.669757, 35.444286},{-12.344987, -8.632133, 
        35.641933}}],
    Line[{{-12.344987, -8.632133, 35.641933},{-11.942307, -7.618661, 
        35.677761}}],
    Line[{{-11.942307, -7.618661, 35.677761},{-11.483636, -6.652894, 
        35.563469}}],
    Line[{{-11.483636, -6.652894, 35.563469},{-10.979797, -5.753768, 
        35.314751}}],
    Line[{{-10.979797, -5.753768, 35.314751},{-10.442142, -4.935094, 
        34.949783}}],
    Line[{{-10.442142, -4.935094, 34.949783},{-9.882006, -4.205575, 
        34.487778}}],
    Line[{{-9.882006, -4.205575, 34.487778},{-9.310240, -3.569209, 
        33.947712}}],
    Line[{{-9.310240, -3.569209, 33.947712},{-8.736846, -3.025984, 
        33.347389}}],
    Line[{{-8.736846, -3.025984, 33.347389},{-8.170711, -2.572691, 
        32.702793}}],
    Line[{{-8.170711, -2.572691, 32.702793},{-7.619448, -2.203794, 
        32.027752}}],
    Line[{{-7.619448, -2.203794, 32.027752},{-7.089344, -1.912228, 
        31.333822}}],
    Line[{{-7.089344, -1.912228, 31.333822},{-6.585364, -1.690095, 
        30.630381}}],
    Line[{{-6.585364, -1.690095, 30.630381},{-6.111238, -1.529226, 
        29.924816}}],
    Line[{{-6.111238, -1.529226, 29.924816},{-5.669562, -1.421613, 
        29.222788}}],
    Line[{{-5.669562, -1.421613, 29.222788},{-5.261948, -1.359709, 
        28.528519}}],
    Line[{{-5.261948, -1.359709, 28.528519},{-4.889166, -1.336619, 
        27.845074}}],
    Line[{{-4.889166, -1.336619, 27.845074},{-4.551292, -1.346219, 
        27.174601}}],
    Line[{{-4.551292, -1.346219, 27.174601},{-4.247851, -1.383199, 
        26.518560}}],
    Line[{{-4.247851, -1.383199, 26.518560},{-3.977947, -1.443056, 
        25.877909}}],
    Line[{{-3.977947, -1.443056, 25.877909},{-3.740381, -1.522066, 
        25.253237}}],
    Line[{{-3.740381, -1.522066, 25.253237},{-3.533746, -1.617224, 
        24.644892}}],
    Line[{{-3.533746, -1.617224, 24.644892},{-3.356518, -1.726184, 
        24.053064}}],
    Line[{{-3.356518, -1.726184, 24.053064},{-3.207120, -1.847186, 
        23.477846}}],
    Line[{{-3.207120, -1.847186, 23.477846},{-3.083988, -1.978993, 
        22.919296}}],
    Line[{{-3.083988, -1.978993, 22.919296},{-2.985608, -2.120818, 
        22.377455}}],
    Line[{{-2.985608, -2.120818, 22.377455},{-2.910556, -2.272270, 
        21.852390}}],
    Line[{{-2.910556, -2.272270, 21.852390},{-2.857523, -2.433298, 
        21.344206}}],
    Line[{{-2.857523, -2.433298, 21.344206},{-2.825335, -2.604144, 
        20.853062}}],
    Line[{{-2.825335, -2.604144, 20.853062},{-2.812963, -2.785303, 
        20.379187}}],
    Line[{{-2.812963, -2.785303, 20.379187},{-2.819538, -2.977487, 
        19.922897}}],
    Line[{{-2.819538, -2.977487, 19.922897},{-2.844346, -3.181595, 
        19.484600}}],
    Line[{{-2.844346, -3.181595, 19.484600},{-2.886838, -3.398691, 
        19.064817}}],
    Line[{{-2.886838, -3.398691, 19.064817},{-2.946623, -3.629977, 
        18.664196}}],
    Line[{{-2.946623, -3.629977, 18.664196},{-3.023471, -3.876782, 
        18.283529}}],
    Line[{{-3.023471, -3.876782, 18.283529},{-3.117301, -4.140535, 
        17.923777}}],
    Line[{{-3.117301, -4.140535, 17.923777},{-3.228185, -4.422758, 
        17.586088}}],
    Line[{{-3.228185, -4.422758, 17.586088},{-3.356333, -4.725039, 
        17.271832}}],
    Line[{{-3.356333, -4.725039, 17.271832},{-3.502090, -5.049017, 
        16.982622}}],
    Line[{{-3.502090, -5.049017, 16.982622},{-3.665926, -5.396358, 
        16.720362}}],
    Line[{{-3.665926, -5.396358, 16.720362},{-3.848423, -5.768715, 
        16.487270}}],
    Line[{{-3.848423, -5.768715, 16.487270},{-4.050265, -6.167702, 
        16.285933}}],
    Line[{{-4.050265, -6.167702, 16.285933},{-4.272220, -6.594828, 
        16.119335}}],
    Line[{{-4.272220, -6.594828, 16.119335},{-4.515118, -7.051445, 
        15.990922}}],
    Line[{{-4.515118, -7.051445, 15.990922},{-4.779829, -7.538660, 
        15.904625}}],
    Line[{{-4.779829, -7.538660, 15.904625},{-5.067228, -8.057232, 
        15.864912}}],
    Line[{{-5.067228, -8.057232, 15.864912},{-5.378159, -8.607448, 
        15.876820}}],
    Line[{{-5.378159, -8.607448, 15.876820},{-5.713384, -9.188968, 
        15.945969}}],
    Line[{{-5.713384, -9.188968, 15.945969},{-6.073519, -9.800632, 
        16.078539}}],
    Line[{{-6.073519, -9.800632, 16.078539},{-6.458970, -10.440259, 
        16.281290}}],
    Line[{{-6.458970, -10.440259, 16.281290},{-6.869826, -11.104385, 
        16.561363}}],
    Line[{{-6.869826, -11.104385, 16.561363},{-7.305778, -11.787974, 
        16.926302}}],
    Line[{{-7.305778, -11.787974, 16.926302},{-7.765972, -12.484197, 
        17.383606}}],
    Line[{{-7.765972, -12.484197, 17.383606},{-8.248881, -13.183993, 
        17.940645}}],
    Line[{{-8.248881, -13.183993, 17.940645},{-8.752159, -13.876006, 
        18.603987}}],
    Line[{{-8.752159, -13.876006, 18.603987},{-9.272466, -14.546230, 
        19.378962}}],
    Line[{{-9.272466, -14.546230, 19.378962},{-9.805321, -15.177992, 
        20.268888}}],
    Line[{{-9.805321, -15.177992, 20.268888},{-10.344969, -15.752131, 
        21.274250}}],
    Line[{{-10.344969, -15.752131, 21.274250},{-10.884250, -16.247208, 
        22.391781}}],
    Line[{{-10.884250, -16.247208, 22.391781},{-11.414573, -16.640320, 
        23.613516}}],
    Line[{{-11.414573, -16.640320, 23.613516},{-11.925972, -16.908155, 
        24.926060}}],
    Line[{{-11.925972, -16.908155, 24.926060},{-12.407203, -17.028284, 
        26.309803}}],
    Line[{{-12.407203, -17.028284, 26.309803},{-12.846112, -16.981106, 
        27.739021}}],
    Line[{{-12.846112, -16.981106, 27.739021},{-13.230035, -16.751684, 
        29.182091}}],
    Line[{{-13.230035, -16.751684, 29.182091},{-13.546404, -16.331741, 
        30.602709}}],
    Line[{{-13.546404, -16.331741, 30.602709},{-13.783440, -15.721295, 
        31.961634}}],
    Line[{{-13.783440, -15.721295, 31.961634},{-13.930943, -14.929782, 
        33.219196}}],
    Line[{{-13.930943, -14.929782, 33.219196},{-13.981052, -13.976207, 
        34.338150}}],
    Line[{{-13.981052, -13.976207, 34.338150},{-13.928890, -12.888323, 
        35.286545}}],
    Line[{{-13.928890, -12.888323, 35.286545},{-13.773044, -11.700825, 
        36.040195}}],
    Line[{{-13.773044, -11.700825, 36.040195},{-13.515760, -10.452750, 
        36.584419}}],
    Line[{{-13.515760, -10.452750, 36.584419},{-13.162888, -9.184364, 
        36.914841}}],
    Line[{{-13.162888, -9.184364, 36.914841},{-12.723474, -7.934167, 
        37.036865}}],
    Line[{{-12.723474, -7.934167, 37.036865},{-12.209178, -6.736236, 
        36.964420}}],
    Line[{{-12.209178, -6.736236, 36.964420},{-11.633498, -5.618315, 
        36.717922}}],
    Line[{{-11.633498, -5.618315, 36.717922},{-11.010940, -4.600791, 
        36.321907}}],
    Line[{{-11.010940, -4.600791, 36.321907},{-10.356198, -3.696543, 
        35.802711}}],
    Line[{{-10.356198, -3.696543, 35.802711},{-9.683455, -2.911459, 
        35.186462}}],
    Line[{{-9.683455, -2.911459, 35.186462},{-9.005802, -2.245487, 
        34.497547}}],
    Line[{{-9.005802, -2.245487, 34.497547},{-8.334849, -1.693896, 
        33.757584}}],
    Line[{{-8.334849, -1.693896, 33.757584},{-7.680473, -1.248619, 
        32.984909}}],
    Line[{{-7.680473, -1.248619, 32.984909},{-7.050735, -0.899483, 
        32.194458}}],
    Line[{{-7.050735, -0.899483, 32.194458},{-6.451900, -0.635254, 
        31.397953}}],
    Line[{{-6.451900, -0.635254, 31.397953},{-5.888554, -0.444473, 
        30.604227}}],
    Line[{{-5.888554, -0.444473, 30.604227},{-5.363766, -0.316041, 
        29.819695}}],
    Line[{{-5.363766, -0.316041, 29.819695},{-4.879296, -0.239642, 
        29.048788}}],
    Line[{{-4.879296, -0.239642, 29.048788},{-4.435799, -0.205975, 
        28.294409}}],
    Line[{{-4.435799, -0.205975, 28.294409},{-4.033039, -0.206872, 
        27.558298}}],
    Line[{{-4.033039, -0.206872, 27.558298},{-3.670079, -0.235322, 
        26.841362}}],
    Line[{{-3.670079, -0.235322, 26.841362},{-3.345461, -0.285435, 
        26.143921}}],
    Line[{{-3.345461, -0.285435, 26.143921},{-3.057354, -0.352362, 
        25.465910}}],
    Line[{{-3.057354, -0.352362, 25.465910},{-2.803689, -0.432200, 
        24.807020}}],
    Line[{{-2.803689, -0.432200, 24.807020},{-2.582261, -0.521885, 
        24.166811}}],
    Line[{{-2.582261, -0.521885, 24.166811},{-2.390822, -0.619080, 
        23.544777}}],
    Line[{{-2.390822, -0.619080, 23.544777},{-2.227144, -0.722083, 
        22.940395}}],
    Line[{{-2.227144, -0.722083, 22.940395},{-2.089078, -0.829720, 
        22.353168}}],
    Line[{{-2.089078, -0.829720, 22.353168},{-1.974591, -0.941272, 
        21.782629}}],
    Line[{{-1.974591, -0.941272, 21.782629},{-1.881790, -1.056395, 
        21.228357}}],
    Line[{{-1.881790, -1.056395, 21.228357},{-1.808948, -1.175061, 
        20.689985}}],
    Line[{{-1.808948, -1.175061, 20.689985},{-1.754511, -1.297505, 
        20.167202}}],
    Line[{{-1.754511, -1.297505, 20.167202},{-1.717110, -1.424175, 
        19.659752}}],
    Line[{{-1.717110, -1.424175, 19.659752},{-1.695553, -1.555709, 
        19.167435}}],
    Line[{{-1.695553, -1.555709, 19.167435},{-1.688832, -1.692897, 
        18.690111}}],
    Line[{{-1.688832, -1.692897, 18.690111},{-1.696119, -1.836665, 
        18.227699}}],
    Line[{{-1.696119, -1.836665, 18.227699},{-1.716754, -1.988059, 
        17.780186}}],
    Line[{{-1.716754, -1.988059, 17.780186},{-1.750249, -2.148235, 
        17.347626}}],
    Line[{{-1.750249, -2.148235, 17.347626},{-1.796276, -2.318450, 
        16.930151}}],
    Line[{{-1.796276, -2.318450, 16.930151},{-1.854662, -2.500060, 
        16.527983}}],
    Line[{{-1.854662, -2.500060, 16.527983},{-1.925386, -2.694522, 
        16.141439}}],
    Line[{{-1.925386, -2.694522, 16.141439},{-2.008570, -2.903391, 
        15.770956}}],
    Line[{{-2.008570, -2.903391, 15.770956},{-2.104479, -3.128325, 
        15.417096}}],
    Line[{{-2.104479, -3.128325, 15.417096},{-2.213516, -3.371085, 
        15.080580}}],
    Line[{{-2.213516, -3.371085, 15.080580},{-2.336217, -3.633541, 
        14.762304}}],
    Line[{{-2.336217, -3.633541, 14.762304},{-2.473251, -3.917667, 
        14.463379}}],
    Line[{{-2.473251, -3.917667, 14.463379},{-2.625417, -4.225546, 
        14.185150}}],
    Line[{{-2.625417, -4.225546, 14.185150},{-2.793638, -4.559355, 
        13.929260}}],
    Line[{{-2.793638, -4.559355, 13.929260},{-2.978965, -4.921365, 
        13.697672}}],
    Line[{{-2.978965, -4.921365, 13.697672},{-3.182565, -5.313911, 
        13.492743}}],
    Line[{{-3.182565, -5.313911, 13.492743},{-3.405720, -5.739362, 
        13.317279}}],
    Line[{{-3.405720, -5.739362, 13.317279},{-3.649817, -6.200097, 
        13.174593}}],
    Line[{{-3.649817, -6.200097, 13.174593},{-3.916329, -6.698395, 
        13.068608}}],
    Line[{{-3.916329, -6.698395, 13.068608},{-4.206809, -7.236427, 
        13.003901}}],
    Line[{{-4.206809, -7.236427, 13.003901},{-4.522848, -7.816061, 
        12.985820}}],
    Line[{{-4.522848, -7.816061, 12.985820},{-4.866045, -8.438758, 
        13.020552}}],
    Line[{{-4.866045, -8.438758, 13.020552},{-5.237965, -9.105379, 
        13.115195}}],
    Line[{{-5.237965, -9.105379, 13.115195},{-5.640062, -9.815934, 
        13.277828}}],
    Line[{{-5.640062, -9.815934, 13.277828},{-6.073600, -10.569274, 
        13.517522}}],
    Line[{{-6.073600, -10.569274, 13.517522},{-6.539539, -11.362724, 
        13.844312}}],
    Line[{{-6.539539, -11.362724, 13.844312},{-7.038413, -12.191689, 
        14.269117}}],
    Line[{{-7.038413, -12.191689, 14.269117},{-7.570148, -13.049117, 
        14.803511}}],
    Line[{{-7.570148, -13.049117, 14.803511},{-8.133862, -13.924972, 
        15.459322}}],
    Line[{{-8.133862, -13.924972, 15.459322},{-8.727644, -14.805717, 
        16.248156}}],
    Line[{{-8.727644, -14.805717, 16.248156},{-9.348281, -15.673786, 
        17.180523}}],
    Line[{{-9.348281, -15.673786, 17.180523},{-9.990983, -16.507219, 
        18.264822}}],
    Line[{{-9.990983, -16.507219, 18.264822},{-10.649110, -17.279531, 
        19.505997}}],
    Line[{{-10.649110, -17.279531, 19.505997},{-11.313920, -17.959974, 
        20.903938}}],
    Line[{{-11.313920, -17.959974, 20.903938},{-11.974398, -18.514303, 
        22.451761}}],
    Line[{{-11.974398, -18.514303, 22.451761},{-12.617212, -18.906336, 
        24.134100}}],
    Line[{{-12.617212, -18.906336, 24.134100},{-13.226846, -19.100145, 
        25.925711}}],
    Line[{{-13.226846, -19.100145, 25.925711},{-13.785975, -19.063112, 
        27.790739}}],
    Line[{{-13.785975, -19.063112, 27.790739},{-14.276120, -18.769499, 
        29.683018}}],
    Line[{{-14.276120, -18.769499, 29.683018},{-14.678598, -18.204178, 
        31.547718}}],
    Line[{{-14.678598, -18.204178, 31.547718},{-14.975712, -17.365921, 
        33.324505}}],
    Line[{{-14.975712, -17.365921, 33.324505},{-15.152099, -16.269609, 
        34.952042}}],
    Line[{{-15.152099, -16.269609, 34.952042},{-15.196080, -14.946606, 
        36.373390}}],
    Line[{{-15.196080, -14.946606, 36.373390},{-15.100812, -13.443060, 
        37.541386}}],
    Line[{{-15.100812, -13.443060, 37.541386},{-14.865062, -11.816175, 
        38.423168}}],
    Line[{{-14.865062, -11.816175, 38.423168},{-14.493489, -10.128936, 
        39.002960}}],
    Line[{{-14.493489, -10.128936, 39.002960},{-13.996340, -8.444172, 
        39.282612}}],
    Line[{{-13.996340, -8.444172, 39.282612},{-13.388632, -6.819048, 
        39.279964}}],
    Line[{{-13.388632, -6.819048, 39.279964},{-12.688936, -5.300783, 
        39.025410}}],
    Line[{{-12.688936, -5.300783, 39.025410},{-11.917965, -3.924110, 
        38.557514}}],
    Line[{{-11.917965, -3.924110, 38.557514},{-11.097122, -2.710609, 
        37.918499}}],
    Line[{{-11.097122, -2.710609, 37.918499},{-10.247223, -1.669559, 
        37.150223}}],
    Line[{{-10.247223, -1.669559, 37.150223},{-9.387468, -0.799902, 
        36.291225}}],
    Line[{{-9.387468, -0.799902, 36.291225},{-8.534725, -0.092699, 
        35.374817}}],
    Line[{{-8.534725, -0.092699, 35.374817},{-7.703129, 0.466327, 
        34.428253}}],
    Line[{{-7.703129, 0.466327, 34.428253},{-6.903950, 0.894514, 33.472683}}],
    
    Line[{{-6.903950, 0.894514, 33.472683},{-6.145658, 1.210403, 32.523670}}],
    
    Line[{{-6.145658, 1.210403, 32.523670},{-5.434158, 1.432370, 31.592018}}],
    
    Line[{{-5.434158, 1.432370, 31.592018},{-4.773086, 1.577698, 30.684673}}],
    
    Line[{{-4.773086, 1.577698, 30.684673},{-4.164165, 1.662028, 29.805643}}],
    
    Line[{{-4.164165, 1.662028, 29.805643},{-3.607558, 1.699098, 28.956779}}],
    
    Line[{{-3.607558, 1.699098, 28.956779},{-3.102199, 1.700682, 28.138453}}],
    
    Line[{{-3.102199, 1.700682, 28.138453},{-2.646095, 1.676665, 27.350065}}],
    
    Line[{{-2.646095, 1.676665, 27.350065},{-2.236587, 1.635191, 26.590439}}],
    
    Line[{{-2.236587, 1.635191, 26.590439},{-1.870572, 1.582862, 25.858095}}],
    
    Line[{{-1.870572, 1.582862, 25.858095},{-1.544679, 1.524942, 25.151445}}],
    
    Line[{{-1.544679, 1.524942, 25.151445},{-1.255413, 1.465555, 24.468920}}],
    
    Line[{{-1.255413, 1.465555, 24.468920},{-0.999268, 1.407879, 23.809029}}],
    
    Line[{{-0.999268, 1.407879, 23.809029},{-0.772808, 1.354315, 23.170406}}],
    
    Line[{{-0.772808, 1.354315, 23.170406},{-0.572725, 1.306637, 22.551830}}],
    
    Line[{{-0.572725, 1.306637, 22.551830},{-0.395884, 1.266123, 21.952215}}],
    
    Line[{{-0.395884, 1.266123, 21.952215},{-0.239345, 1.233666, 21.370605}}],
    
    Line[{{-0.239345, 1.233666, 21.370605},{-0.100378, 1.209870, 20.806170}}],
    
    Line[{{-0.100378, 1.209870, 20.806170},{0.023534, 1.195124, 20.258177}}],
    Line[{{0.023534, 1.195124, 20.258177},{0.134698, 1.189671, 19.725988}}],
    Line[{{0.134698, 1.189671, 19.725988},{0.235219, 1.193659, 19.209049}}],
    Line[{{0.235219, 1.193659, 19.209049},{0.327014, 1.207183, 18.706867}}],
    Line[{{0.327014, 1.207183, 18.706867},{0.411824, 1.230326, 18.219011}}],
    Line[{{0.411824, 1.230326, 18.219011},{0.491234, 1.263179, 17.745106}}],
    Line[{{0.491234, 1.263179, 17.745106},{0.566688, 1.305872, 17.284821}}],
    Line[{{0.566688, 1.305872, 17.284821},{0.639507, 1.358586, 16.837872}}],
    Line[{{0.639507, 1.358586, 16.837872},{0.710908, 1.421573, 16.404016}}],
    Line[{{0.710908, 1.421573, 16.404016},{0.782018, 1.495167, 15.983058}}],
    Line[{{0.782018, 1.495167, 15.983058},{0.853894, 1.579793, 15.574845}}],
    Line[{{0.853894, 1.579793, 15.574845},{0.927538, 1.675978, 15.179273}}],
    Line[{{0.927538, 1.675978, 15.179273},{1.003913, 1.784360, 14.796289}}],
    Line[{{1.003913, 1.784360, 14.796289},{1.083953, 1.905694, 14.425902}}],
    Line[{{1.083953, 1.905694, 14.425902},{1.168585, 2.040861, 14.068186}}],
    Line[{{1.168585, 2.040861, 14.068186},{1.258736, 2.190877, 13.723291}}],
    Line[{{1.258736, 2.190877, 13.723291},{1.355350, 2.356897, 13.391460}}],
    Line[{{1.355350, 2.356897, 13.391460},{1.459395, 2.540228, 13.073038}}],
    Line[{{1.459395, 2.540228, 13.073038},{1.571882, 2.742332, 12.768493}}],
    Line[{{1.571882, 2.742332, 12.768493},{1.693872, 2.964837, 12.478436}}],
    Line[{{1.693872, 2.964837, 12.478436},{1.826486, 3.209542, 12.203655}}],
    Line[{{1.826486, 3.209542, 12.203655},{1.970922, 3.478423, 11.945132}}],
    Line[{{1.970922, 3.478423, 11.945132},{2.128458, 3.773636, 11.704102}}],
    Line[{{2.128458, 3.773636, 11.704102},{2.300464, 4.097522, 11.482069}}],
    Line[{{2.300464, 4.097522, 11.482069},{2.488413, 4.452598, 11.280888}}],
    Line[{{2.488413, 4.452598, 11.280888},{2.693884, 4.841542, 11.102812}}],
    Line[{{2.693884, 4.841542, 11.102812},{2.918570, 5.267192, 10.950554}}],
    Line[{{2.918570, 5.267192, 10.950554},{3.164274, 5.732476, 10.827408}}],
    Line[{{3.164274, 5.732476, 10.827408},{3.432917, 6.240413, 10.737289}}],
    Line[{{3.432917, 6.240413, 10.737289},{3.726518, 6.793988, 10.684896}}],
    Line[{{3.726518, 6.793988, 10.684896},{4.047185, 7.396069, 10.675797}}],
    Line[{{4.047185, 7.396069, 10.675797},{4.397089, 8.049275, 10.716563}}],
    Line[{{4.397089, 8.049275, 10.716563},{4.778422, 8.755770, 10.814901}}],
    Line[{{4.778422, 8.755770, 10.814901},{5.193340, 9.516986, 10.979779}}],
    Line[{{5.193340, 9.516986, 10.979779},{5.643882, 10.333323, 11.221527}}],
    Line[{{5.643882, 10.333323, 11.221527},{6.131872, 11.203739, 11.551912}}],
    
    Line[{{6.131872, 11.203739, 11.551912},{6.658760, 12.125167, 11.984120}}],
    
    Line[{{6.658760, 12.125167, 11.984120},{7.225448, 13.091944, 12.532652}}],
    
    Line[{{7.225448, 13.091944, 12.532652},{7.832057, 14.095051, 13.213037}}],
    
    Line[{{7.832057, 14.095051, 13.213037},{8.477644, 15.121321, 14.041326}}],
    
    Line[{{8.477644, 15.121321, 14.041326},{9.159869, 16.152594, 15.033284}}],
    
    Line[{{9.159869, 16.152594, 15.033284},{9.874615, 17.164940, 16.203226}}],
    
    Line[{{9.874615, 17.164940, 16.203226},{
      10.615571, 18.128096, 17.562315}}],
    Line[{{10.615571, 18.128096, 17.562315},{
      11.373833, 19.005304, 19.116545}}],
    Line[{{11.373833, 19.005304, 19.116545},{
      12.137550, 19.753807, 20.864248}}],
    Line[{{12.137550, 19.753807, 20.864248},{
      12.891693, 20.326283, 22.793411}}],
    Line[{{12.891693, 20.326283, 22.793411},{
      13.618037, 20.673437, 24.879152}}],
    Line[{{13.618037, 20.673437, 24.879152},{
      14.295460, 20.747900, 27.081833}}],
    Line[{{14.295460, 20.747900, 27.081833},{
      14.900629, 20.509270, 29.346497}}],
    Line[{{14.900629, 20.509270, 29.346497},{
      15.409158, 19.929832, 31.604229}}],
    Line[{{15.409158, 19.929832, 31.604229},{
      15.797182, 19.000109, 33.775963}}],
    Line[{{15.797182, 19.000109, 33.775963},{
      16.043272, 17.733019, 35.778656}}],
    Line[{{16.043272, 17.733019, 35.778656},{
      16.130426, 16.165503, 37.533218}}],
    Line[{{16.130426, 16.165503, 37.533218},{
      16.047888, 14.356901, 38.972984}}],
    Line[{{16.047888, 14.356901, 38.972984},{
      15.792460, 12.383716, 40.051128}}],
    Line[{{15.792460, 12.383716, 40.051128},{
      15.369042, 10.331695, 40.745373}}],
    Line[{{15.369042, 10.331695, 40.745373},{
      14.790310, 8.286729, 41.059155}}],
    Line[{{14.790310, 8.286729, 41.059155},{14.075563, 6.326240, 41.019062}}],
    
    Line[{{14.075563, 6.326240, 41.019062},{13.248941, 4.512674, 40.669373}}],
    
    Line[{{13.248941, 4.512674, 40.669373},{12.337351, 2.889918, 40.065113}}],
    
    Line[{{12.337351, 2.889918, 40.065113},{11.368383, 1.482734, 39.265091}}],
    
    Line[{{11.368383, 1.482734, 39.265091},{10.368505, 0.298620, 38.325993}}],
    
    Line[{{10.368505, 0.298620, 38.325993},{9.361670, -0.668798, 37.298248}}],
    
    Line[{{9.361670, -0.668798, 37.298248},{8.368443, -1.435801, 36.223759}}],
    
    Line[{{8.368443, -1.435801, 36.223759},{7.405552, -2.024740, 35.135170}}],
    
    Line[{{7.405552, -2.024740, 35.135170},{6.485850, -2.460816, 34.056389}}],
    
    Line[{{6.485850, -2.460816, 34.056389},{5.618532, -2.769632, 33.003712}}],
    
    Line[{{5.618532, -2.769632, 33.003712},{4.809530, -2.975536, 31.987259}}],
    
    Line[{{4.809530, -2.975536, 31.987259},{4.062002, -3.100622, 31.012472}}],
    
    Line[{{4.062002, -3.100622, 31.012472},{3.376827, -3.164257, 30.081417}}],
    
    Line[{{3.376827, -3.164257, 30.081417},{2.753098, -3.182955, 29.193888}}],
    
    Line[{{2.753098, -3.182955, 29.193888},{2.188558, -3.170495, 28.348269}}],
    
    Line[{{2.188558, -3.170495, 28.348269},{1.679973, -3.138159, 27.542156}}],
    
    Line[{{1.679973, -3.138159, 27.542156},{1.223455, -3.095037, 26.772816}}],
    
    Line[{{1.223455, -3.095037, 26.772816},{0.814712, -3.048345, 26.037474}}],
    
    Line[{{0.814712, -3.048345, 26.037474},{0.449251, -3.003734, 25.333490}}],
    
    Line[{{0.449251, -3.003734, 25.333490},{0.122537, -2.965570, 24.658474}}],
    
    Line[{{
      0.122537, -2.965570, 24.658474},{-0.169902, -2.937187, 24.010321}}],
    Line[{{-0.169902, -2.937187, 24.010321},{-0.432385, -2.921100, 
        23.387226}}],
    Line[{{-0.432385, -2.921100, 23.387226},{-0.669030, -2.919190, 
        22.787683}}],
    Line[{{-0.669030, -2.919190, 22.787683},{-0.883714, -2.932862, 
        22.210457}}],
    Line[{{-0.883714, -2.932862, 22.210457},{-1.080066, -2.963169, 
        21.654558}}],
    Line[{{-1.080066, -2.963169, 21.654558},{-1.261453, -3.010917, 
        21.119226}}],
    Line[{{-1.261453, -3.010917, 21.119226},{-1.430992, -3.076757, 
        20.603903}}],
    Line[{{-1.430992, -3.076757, 20.603903},{-1.591560, -3.161252, 
        20.108212}}],
    Line[{{-1.591560, -3.161252, 20.108212},{-1.745812, -3.264934, 
        19.631954}}],
    Line[{{-1.745812, -3.264934, 19.631954},{-1.896201, -3.388343, 
        19.175097}}],
    Line[{{-1.896201, -3.388343, 19.175097},{-2.045001, -3.532075, 
        18.737764}}],
    Line[{{-2.045001, -3.532075, 18.737764},{-2.194327, -3.696793, 
        18.320251}}],
    Line[{{-2.194327, -3.696793, 18.320251},{-2.346164, -3.883254, 
        17.923027}}],
    Line[{{-2.346164, -3.883254, 17.923027},{-2.502383, -4.092317, 
        17.546745}}],
    Line[{{-2.502383, -4.092317, 17.546745},{-2.664763, -4.324955, 
        17.192261}}],
    Line[{{-2.664763, -4.324955, 17.192261},{-2.835013, -4.582245, 
        16.860657}}],
    Line[{{-2.835013, -4.582245, 16.860657},{-3.014787, -4.865376, 
        16.553268}}],
    Line[{{-3.014787, -4.865376, 16.553268},{-3.205700, -5.175624, 
        16.271709}}],
    Line[{{-3.205700, -5.175624, 16.271709},{-3.409335, -5.514331, 
        16.017925}}],
    Line[{{-3.409335, -5.514331, 16.017925},{-3.627259, -5.882887, 
        15.794210}}],
    Line[{{-3.627259, -5.882887, 15.794210},{-3.861018, -6.282675, 
        15.603277}}],
    Line[{{-3.861018, -6.282675, 15.603277},{-4.112143, -6.715016, 
        15.448289}}],
    Line[{{-4.112143, -6.715016, 15.448289},{-4.382140, -7.181117, 
        15.332918}}],
    Line[{{-4.382140, -7.181117, 15.332918},{-4.672472, -7.681942, 
        15.261396}}],
    Line[{{-4.672472, -7.681942, 15.261396},{-4.984544, -8.218128, 
        15.238557}}],
    Line[{{-4.984544, -8.218128, 15.238557},{-5.319667, -8.789837, 
        15.269881}}],
    Line[{{-5.319667, -8.789837, 15.269881},{-5.679003, -9.396540, 
        15.361510}}],
    Line[{{-5.679003, -9.396540, 15.361510},{-6.063523, -10.036862, 
        15.520251}}],
    Line[{{-6.063523, -10.036862, 15.520251},{-6.473922, -10.708300, 
        15.753545}}],
    Line[{{-6.473922, -10.708300, 15.753545},{-6.910509, -11.406898, 
        16.069319}}],
    Line[{{-6.910509, -11.406898, 16.069319},{-7.373132, -12.127021, 
        16.475924}}],
    Line[{{-7.373132, -12.127021, 16.475924},{-7.860999, -12.860913, 
        16.981754}}],
    Line[{{-7.860999, -12.860913, 16.981754},{-8.372546, -13.598418, 
        17.594938}}],
    Line[{{-8.372546, -13.598418, 17.594938},{-8.905263, -14.326663, 
        18.322779}}],
    Line[{{-8.905263, -14.326663, 18.322779},{-9.455514, -15.029833, 
        19.171118}}],
    Line[{{-9.455514, -15.029833, 19.171118},{-10.018356, -15.689086, 
        20.143456}}],
    Line[{{-10.018356, -15.689086, 20.143456},{-10.587382, -16.282713, 
        21.239973}}],
    Line[{{-10.587382, -16.282713, 21.239973},{-11.154608, -16.786610, 
        22.456469}}],
    Line[{{-11.154608, -16.786610, 22.456469},{-11.710431, -17.175102, 
        23.783283}}],
    Line[{{-11.710431, -17.175102, 23.783283},{-12.243694, -17.422247, 
        25.204382}}],
    Line[{{-12.243694, -17.422247, 25.204382},{-12.741889, -17.503569, 
        26.696745}}],
    Line[{{-12.741889, -17.503569, 26.696745},{-13.191523, -17.398165, 
        28.230288}}],
    Line[{{-13.191523, -17.398165, 28.230288},{-13.578661, -17.091021, 
        29.768520}}],
    Line[{{-13.578661, -17.091021, 29.768520},{-13.889646, -16.575222, 
        31.270020}}],
    Line[{{-13.889646, -16.575222, 31.270020},{-14.111927, -15.853756, 
        32.690784}}],
    Line[{{-14.111927, -15.853756, 32.690784},{-14.234954, -14.940494, 
        33.987240}}],
    Line[{{-14.234954, -14.940494, 33.987240},{-14.251032, -13.860061, 
        35.119656}}],
    Line[{{-14.251032, -13.860061, 35.119656},{-14.156009, -12.646484, 
        36.055386}}],
    Line[{{-14.156009, -12.646484, 36.055386},{-13.949727, -11.340709, 
        36.771511}}],
    Line[{{-13.949727, -11.340709, 36.771511},{-13.636141, -9.987281, 
        37.256439}}],
    Line[{{-13.636141, -9.987281, 37.256439},{-13.223095, -8.630729, 
        37.510216}}],
    Line[{{-13.223095, -8.630729, 37.510216},{-12.721786, -7.312139, 
        37.543587}}],
    Line[{{-12.721786, -7.312139, 37.543587},{-12.145977, -6.066407, 
        37.376019}}],
    Line[{{-12.145977, -6.066407, 37.376019},{-11.511061, -4.920528, 
        37.033051}}],
    Line[{{-11.511061, -4.920528, 37.033051},{-10.833123, -3.892867, 
        36.543556}}],
    Line[{{-10.833123, -3.892867, 36.543556},{-10.128057, -2.993433, 
        35.937164}}],
    Line[{{-10.128057, -2.993433, 35.937164},{-9.410829, -2.224844, 
        35.242180}}],
    Line[{{-9.410829, -2.224844, 35.242180},{-8.694925, -1.583731, 
        34.484131}}],
    Line[{{-8.694925, -1.583731, 34.484131},{-7.992006, -1.062288, 
        33.684937}}],
    Line[{{-7.992006, -1.062288, 33.684937},{-7.311720, -0.649784, 
        32.862579}}],
    Line[{{-7.311720, -0.649784, 32.862579},{-6.661695, -0.333873, 
        32.031235}}],
    Line[{{-6.661695, -0.333873, 32.031235},{-6.047619, -0.101648, 
        31.201603}}],
    Line[{{-6.047619, -0.101648, 31.201603},{-5.473418, 0.059566, 
        30.381418}}],
    Line[{{-5.473418, 0.059566, 30.381418},{-4.941471, 0.161679, 29.576000}}],
    
    Line[{{-4.941471, 0.161679, 29.576000},{-4.452848, 0.215503, 28.788769}}],
    
    Line[{{-4.452848, 0.215503, 28.788769},{-4.007552, 0.230585, 28.021721}}],
    
    Line[{{-4.007552, 0.230585, 28.021721},{-3.604735, 0.215159, 27.275829}}],
    
    Line[{{-3.604735, 0.215159, 27.275829},{-3.242913, 0.176179, 26.551344}}],
    
    Line[{{-3.242913, 0.176179, 26.551344},{-2.920138, 0.119398, 25.848057}}],
    
    Line[{{-2.920138, 0.119398, 25.848057},{-2.634154, 0.049486, 25.165468}}],
    
    Line[{{-2.634154, 0.049486, 25.165468},{-2.382524, -0.029850, 
        24.502922}}],
    Line[{{-2.382524, -0.029850, 24.502922},{-2.162729, -0.115741, 
        23.859692}}],
    Line[{{-2.162729, -0.115741, 23.859692},{-1.972253, -0.206030, 
        23.235041}}],
    Line[{{-1.972253, -0.206030, 23.235041},{-1.808646, -0.299167, 
        22.628262}}],
    Line[{{-1.808646, -0.299167, 22.628262},{-1.669568, -0.394104, 
        22.038689}}],
    Line[{{-1.669568, -0.394104, 22.038689},{-1.552821, -0.490213, 
        21.465714}}],
    Line[{{-1.552821, -0.490213, 21.465714},{-1.456377, -0.587206, 
        20.908787}}],
    Line[{{-1.456377, -0.587206, 20.908787},{-1.378384, -0.685077, 
        20.367418}}],
    Line[{{-1.378384, -0.685077, 20.367418},{-1.317179, -0.784044, 
        19.841167}}],
    Line[{{-1.317179, -0.784044, 19.841167},{-1.271286, -0.884511, 
        19.329653}}],
    Line[{{-1.271286, -0.884511, 19.329653},{-1.239417, -0.987030, 
        18.832537}}],
    Line[{{-1.239417, -0.987030, 18.832537},{-1.220464, -1.092281, 
        18.349531}}],
    Line[{{-1.220464, -1.092281, 18.349531},{-1.213495, -1.201043, 
        17.880388}}],
    Line[{{-1.213495, -1.201043, 17.880388},{-1.217746, -1.314188, 
        17.424908}}],
    Line[{{-1.217746, -1.314188, 17.424908},{-1.232610, -1.432667, 
        16.982933}}],
    Line[{{-1.232610, -1.432667, 16.982933},{-1.257635, -1.557508, 16.554354}}
      ],
    Line[{{-1.257635, -1.557508, 16.554354},{-1.292511, -1.689811, 
        16.139114}}],
    Line[{{-1.292511, -1.689811, 16.139114},{-1.337068, -1.830750, 
        15.737211}}],
    Line[{{-1.337068, -1.830750, 15.737211},{-1.391266, -1.981580, 
        15.348706}}],
    Line[{{-1.391266, -1.981580, 15.348706},{-1.455192, -2.143636, 
        14.973733}}],
    Line[{{-1.455192, -2.143636, 14.973733},{-1.529059, -2.318347, 
        14.612509}}],
    Line[{{-1.529059, -2.318347, 14.612509},{-1.613196, -2.507236, 
        14.265348}}],
    Line[{{-1.613196, -2.507236, 14.265348},{-1.708054, -2.711937, 
        13.932679}}],
    Line[{{-1.708054, -2.711937, 13.932679},{-1.814202, -2.934198, 
        13.615062}}],
    Line[{{-1.814202, -2.934198, 13.615062},{-1.932325, -3.175888, 
        13.313215}}],
    Line[{{-1.932325, -3.175888, 13.313215},{-2.063228, -3.439013, 
        13.028038}}],
    Line[{{-2.063228, -3.439013, 13.028038},{-2.207838, -3.725710, 
        12.760656}}],
    Line[{{-2.207838, -3.725710, 12.760656},{-2.367203, -4.038260, 
        12.512444}}],
    Line[{{-2.367203, -4.038260, 12.512444},{-2.542494, -4.379081, 
        12.285087}}],
    Line[{{-2.542494, -4.379081, 12.285087},{-2.735009, -4.750718, 
        12.080623}}],
    Line[{{-2.735009, -4.750718, 12.080623},{-2.946170, -5.155839, 
        11.901514}}],
    Line[{{-2.946170, -5.155839, 11.901514},{-3.177520, -5.597185, 
        11.750724}}],
    Line[{{-3.177520, -5.597185, 11.750724},{-3.430723, -6.077564, 
        11.631774}}],
    Line[{{-3.430723, -6.077564, 11.631774},{-3.707546, -6.599744, 
        11.548875}}],
    Line[{{-3.707546, -6.599744, 11.548875},{-4.009851, -7.166399, 
        11.506999}}],
    Line[{{-4.009851, -7.166399, 11.506999},{-4.339568, -7.779979, 
        11.511999}}],
    Line[{{-4.339568, -7.779979, 11.511999},{-4.698655, -8.442540, 
        11.570726}}],
    Line[{{-4.698655, -8.442540, 11.570726},{-5.089052, -9.155520, 
        11.691126}}],
    Line[{{-5.089052, -9.155520, 11.691126},{-5.512619, -9.919502, 
        11.882339}}],
    Line[{{-5.512619, -9.919502, 11.882339},{-5.971032, -10.733822, 
        12.154771}}],
    Line[{{-5.971032, -10.733822, 12.154771},{-6.465663, -11.596129, 
        12.520079}}],
    Line[{{-6.465663, -11.596129, 12.520079},{-6.997436, -12.501890, 
        12.991106}}],
    Line[{{-6.997436, -12.501890, 12.991106},{-7.566619, -13.443758, 
        13.581671}}],
    Line[{{-7.566619, -13.443758, 13.581671},{-8.172595, -14.410890, 
        14.306180}}],
    Line[{{-8.172595, -14.410890, 14.306180},{-8.813575, -15.388218, 
        15.178991}}],
    Line[{{-8.813575, -15.388218, 15.178991},{-9.486272, -16.355762, 
        16.213482}}],
    Line[{{-9.486272, -16.355762, 16.213482},{-10.185552, -17.288071, 
        17.420744}}],
    Line[{{-10.185552, -17.288071, 17.420744},{-10.904066, -18.153957, 
        18.807913}}],
    Line[{{-10.904066, -18.153957, 18.807913},{-11.631929, -18.916706, 
        20.376135}}],
    Line[{{-11.631929, -18.916706, 20.376135},{-12.356468, -19.535011, 
        22.118280}}],
    Line[{{-12.356468, -19.535011, 22.118280},{-13.062132, -19.964806, 
        24.016678}}],
    Line[{{-13.062132, -19.964806, 24.016678},{-13.730637, -20.162193, 
        26.041206}}],
    Line[{{-13.730637, -20.162193, 26.041206},{-14.341427, -20.087412, 
        28.148270}}],
    Line[{{-14.341427, -20.087412, 28.148270},{-14.872505, -19.709581, 
        30.281183}}],
    Line[{{-14.872505, -19.709581, 30.281183},{-15.301660, -19.011667, 
        32.372440}}],
    Line[{{-15.301660, -19.011667, 32.372440},{-15.608026, -17.994768, 
        34.348145}}],
    Line[{{-15.608026, -17.994768, 34.348145},{-15.773818, -16.680721, 
        36.134132}}],
    Line[{{-15.773818, -16.680721, 36.134132},{-15.786041, -15.112213, 
        37.663200}}],
    Line[{{-15.786041, -15.112213, 37.663200},{-15.637910, -13.349962, 
        38.882168}}],
    Line[{{-15.637910, -13.349962, 38.882168},{-15.329712, -11.467051, 
        39.757408}}],
    Line[{{-15.329712, -11.467051, 39.757408},{-14.868966, -9.541524, 
        40.277672}}],
    Line[{{-14.868966, -9.541524, 40.277672},{-14.269824, -7.648549, 
        40.453812}}],
    Line[{{-14.269824, -7.648549, 40.453812},{-13.551823, -5.853542, 
        40.315556}}],
    Line[{{-13.551823, -5.853542, 40.315556},{-12.738186, -4.207419, 
        39.906212}}],
    Line[{{-12.738186, -4.207419, 39.906212},{-11.853973, -2.744378, 
        39.276596}}],
    Line[{{-11.853973, -2.744378, 39.276596},{-10.924308, -1.482121, 
        38.479233}}],
    Line[{{-10.924308, -1.482121, 38.479233},{-9.972885, -0.423908, 
        37.563694}}],
    Line[{{-9.972885, -0.423908, 37.563694},{-9.020881, 0.438337, 
        36.573479}}],
    Line[{{-9.020881, 0.438337, 36.573479},{-8.086275, 1.120596, 35.544415}}],
    
    Line[{{-8.086275, 1.120596, 35.544415},{-7.183568, 1.643566, 34.504303}}],
    
    Line[{{-7.183568, 1.643566, 34.504303},{-6.323788, 2.030009, 33.473465}}],
    
    Line[{{-6.323788, 2.030009, 33.473465},{-5.514735, 2.302770, 32.465778}}],
    
    Line[{{-5.514735, 2.302770, 32.465778},{-4.761340, 2.483447, 31.489933}}],
    
    Line[{{-4.761340, 2.483447, 31.489933},{-4.066107, 2.591594, 30.550669}}],
    
    Line[{{-4.066107, 2.591594, 30.550669},{-3.429553, 2.644348, 29.649881}}],
    
    Line[{{-3.429553, 2.644348, 29.649881},{-2.850638, 2.656344, 28.787531}}],
    
    Line[{{-2.850638, 2.656344, 28.787531},{-2.327146, 2.639814, 27.962370}}],
    
    Line[{{-2.327146, 2.639814, 27.962370},{-1.856015, 2.604797, 27.172461}}],
    
    Line[{{-1.856015, 2.604797, 27.172461},{-1.433614, 2.559399, 26.415554}}],
    
    Line[{{-1.433614, 2.559399, 26.415554},{-1.055970, 2.510069, 25.689337}}],
    
    Line[{{-1.055970, 2.510069, 25.689337},{-0.718942, 2.461866, 24.991590}}],
    
    Line[{{-0.718942, 2.461866, 24.991590},{-0.418361, 2.418700, 24.320274}}],
    
    Line[{{-0.418361, 2.418700, 24.320274},{-0.150127, 2.383555, 23.673574}}],
    
    Line[{{-0.150127, 2.383555, 23.673574},{0.089715, 2.358676, 23.049913}}],
    Line[{{0.089715, 2.358676, 23.049913},{0.304930, 2.345736, 22.447943}}],
    Line[{{0.304930, 2.345736, 22.447943},{0.499059, 2.345972, 21.866535}}],
    Line[{{0.499059, 2.345972, 21.866535},{0.675412, 2.360300, 21.304749}}],
    Line[{{0.675412, 2.360300, 21.304749},{0.837054, 2.389413, 20.761827}}],
    Line[{{0.837054, 2.389413, 20.761827},{0.986821, 2.433859, 20.237169}}],
    Line[{{0.986821, 2.433859, 20.237169},{1.127326, 2.494105, 19.730312}}],
    Line[{{1.127326, 2.494105, 19.730312},{1.260974, 2.570589, 19.240931}}],
    Line[{{1.260974, 2.570589, 19.240931},{1.389986, 2.663766, 18.768814}}],
    Line[{{1.389986, 2.663766, 18.768814},{1.516415, 2.774137, 18.313877}}],
    Line[{{1.516415, 2.774137, 18.313877},{1.642170, 2.902278, 17.876150}}],
    Line[{{1.642170, 2.902278, 17.876150},{1.769039, 3.048862, 17.455790}}],
    Line[{{1.769039, 3.048862, 17.455790},{1.898708, 3.214676, 17.053082}}],
    Line[{{1.898708, 3.214676, 17.053082},{2.032783, 3.400629, 16.668457}}],
    Line[{{2.032783, 3.400629, 16.668457},{2.172812, 3.607765, 16.302502}}],
    Line[{{2.172812, 3.607765, 16.302502},{2.320299, 3.837263, 15.955987}}],
    Line[{{2.320299, 3.837263, 15.955987},{2.476726, 4.090445, 15.629882}}],
    Line[{{2.476726, 4.090445, 15.629882},{2.643566, 4.368762, 15.325392}}],
    Line[{{2.643566, 4.368762, 15.325392},{2.822294, 4.673798, 15.043990}}],
    Line[{{2.822294, 4.673798, 15.043990},{3.014404, 5.007245, 14.787458}}],
    Line[{{3.014404, 5.007245, 14.787458},{3.221412, 5.370888, 14.557930}}],
    Line[{{3.221412, 5.370888, 14.557930},{3.444862, 5.766572, 14.357950}}],
    Line[{{3.444862, 5.766572, 14.357950},{3.686329, 6.196153, 14.190524}}],
    Line[{{3.686329, 6.196153, 14.190524},{3.947413, 6.661451, 14.059187}}],
    Line[{{3.947413, 6.661451, 14.059187},{4.229729, 7.164155, 13.968072}}],
    Line[{{4.229729, 7.164155, 13.968072},{4.534889, 7.705729, 13.921976}}],
    Line[{{4.534889, 7.705729, 13.921976},{4.864477, 8.287284, 13.926427}}],
    Line[{{4.864477, 8.287284, 13.926427},{5.220005, 8.909395, 13.987749}}],
    Line[{{5.220005, 8.909395, 13.987749},{5.602859, 9.571891, 14.113097}}],
    Line[{{5.602859, 9.571891, 14.113097},{6.014242, 10.273624, 14.310485}}],
    Line[{{6.014242, 10.273624, 14.310485},{6.455063, 11.012123, 14.588751}}],
    
    Line[{{6.455063, 11.012123, 14.588751},{6.925827, 11.783229, 14.957438}}],
    
    Line[{{6.925827, 11.783229, 14.957438},{7.426515, 12.580743, 15.426682}}],
    
    Line[{{7.426515, 12.580743, 15.426682},{7.956388, 13.395906, 16.006844}}],
    
    Line[{{7.956388, 13.395906, 16.006844},{8.513804, 14.216980, 16.708046}}],
    
    Line[{{8.513804, 14.216980, 16.708046},{9.096004, 15.028833, 17.539564}}],
    
    Line[{{9.096004, 15.028833, 17.539564},{9.698866, 15.812611, 18.508930}}],
    
    Line[{{9.698866, 15.812611, 18.508930},{
      10.316686, 16.545599, 19.620872}}],
    Line[{{10.316686, 16.545599, 19.620872},{
      10.941956, 17.201391, 20.875996}}],
    Line[{{10.941956, 17.201391, 20.875996},{
      11.565211, 17.750465, 22.269367}}],
    Line[{{11.565211, 17.750465, 22.269367},{
      12.174975, 18.161341, 23.789085}}],
    Line[{{12.174975, 18.161341, 23.789085},{
      12.757837, 18.402277, 25.415058}}],
    Line[{{12.757837, 18.402277, 25.415058},{
      13.298723, 18.443661, 27.118223}}],
    Line[{{13.298723, 18.443661, 27.118223},{
      13.781393, 18.260860, 28.860561}}],
    Line[{{13.781393, 18.260860, 28.860561},{
      14.189174, 17.837324, 30.596113}}],
    Line[{{14.189174, 17.837324, 30.596113},{
      14.505913, 17.167482, 32.273209}}],
    Line[{{14.505913, 17.167482, 32.273209},{
      14.717092, 16.258917, 33.837849}}],
    Line[{{14.717092, 16.258917, 33.837849},{
      14.810972, 15.133302, 35.237930}}],
    Line[{{14.810972, 15.133302, 35.237930},{
      14.779659, 13.825690, 36.427837}}],
    Line[{{14.779659, 13.825690, 36.427837},{
      14.619902, 12.382105, 37.372540}}],
    Line[{{14.619902, 12.382105, 37.372540},{
      14.333512, 10.855663, 38.050613}}],
    Line[{{14.333512, 10.855663, 38.050613},{
      13.927344, 9.301867, 38.455616}}],
    Line[{{13.927344, 9.301867, 38.455616},{13.412801, 7.773763, 38.595634}}],
    
    Line[{{13.412801, 7.773763, 38.595634},{12.804952, 6.317800, 38.491131}}],
    
    Line[{{12.804952, 6.317800, 38.491131},{12.121412, 4.970894, 38.171741}}],
    
    Line[{{12.121412, 4.970894, 38.171741},{11.381111, 3.758991, 37.672520}}],
    
    Line[{{11.381111, 3.758991, 37.672520},{10.603105, 2.697041, 37.030323}}],
    
    Line[{{10.603105, 2.697041, 37.030323},{9.805566, 1.790055, 36.280815}}],
    Line[{{9.805566, 1.790055, 36.280815},{9.005011, 1.034926, 35.456291}}],
    Line[{{9.005011, 1.034926, 35.456291},{8.215774, 0.422489, 34.584412}}],
    Line[{{8.215774, 0.422489, 34.584412},{7.449744, -0.060417, 33.687679}}],
    Line[{{7.449744, -0.060417, 33.687679},{6.716310, -0.429156, 32.783577}}],
    
    Line[{{6.716310, -0.429156, 32.783577},{6.022455, -0.699841, 31.885006}}],
    
    Line[{{6.022455, -0.699841, 31.885006},{5.372975, -0.888292, 31.001013}}],
    
    Line[{{5.372975, -0.888292, 31.001013},{4.770746, -1.009310, 30.137518}}],
    
    Line[{{4.770746, -1.009310, 30.137518},{4.217030, -1.076267, 29.298048}}],
    
    Line[{{4.217030, -1.076267, 29.298048},{3.711773, -1.100904, 28.484367}}],
    
    Line[{{3.711773, -1.100904, 28.484367},{3.253891, -1.093288, 27.697012}}],
    
    Line[{{3.253891, -1.093288, 27.697012},{2.841524, -1.061878, 26.935694}}],
    
    Line[{{2.841524, -1.061878, 26.935694},{2.472255, -1.013650, 26.199623}}],
    
    Line[{{2.472255, -1.013650, 26.199623},{2.143300, -0.954253, 25.487730}}],
    
    Line[{{2.143300, -0.954253, 25.487730},{1.851660, -0.888183, 24.798826}}],
    
    Line[{{1.851660, -0.888183, 24.798826},{1.594241, -0.818946, 24.131701}}],
    
    Line[{{1.594241, -0.818946, 24.131701},{1.367952, -0.749219, 23.485182}}],
    
    Line[{{1.367952, -0.749219, 23.485182},{1.169777, -0.680988, 22.858183}}],
    
    Line[{{1.169777, -0.680988, 22.858183},{0.996823, -0.615684, 22.249708}}],
    
    Line[{{0.996823, -0.615684, 22.249708},{0.846363, -0.554282, 21.658854}}],
    
    Line[{{0.846363, -0.554282, 21.658854},{0.715851, -0.497404, 21.084816}}],
    
    Line[{{0.715851, -0.497404, 21.084816},{0.602939, -0.445394, 20.526869}}],
    
    Line[{{0.602939, -0.445394, 20.526869},{0.505482, -0.398385, 19.984364}}],
    
    Line[{{0.505482, -0.398385, 19.984364},{0.421532, -0.356354, 19.456717}}],
    
    Line[{{0.421532, -0.356354, 19.456717},{0.349336, -0.319165, 18.943396}}],
    
    Line[{{0.349336, -0.319165, 18.943396},{0.287325, -0.286607, 18.443916}}],
    
    Line[{{0.287325, -0.286607, 18.443916},{0.234100, -0.258421, 17.957830}}],
    
    Line[{{0.234100, -0.258421, 17.957830},{0.188423, -0.234318, 17.484726}}],
    
    Line[{{0.188423, -0.234318, 17.484726},{0.149202, -0.214005, 17.024210}}],
    
    Line[{{0.149202, -0.214005, 17.024210},{0.115475, -0.197187, 16.575920}}],
    
    Line[{{0.115475, -0.197187, 16.575920},{0.086401, -0.183583, 16.139505}}],
    
    Line[{{0.086401, -0.183583, 16.139505},{0.061244, -0.172934, 15.714635}}],
    
    Line[{{0.061244, -0.172934, 15.714635},{0.039361, -0.165000, 15.300991}}],
    
    Line[{{0.039361, -0.165000, 15.300991},{0.020194, -0.159570, 14.898271}}],
    
    Line[{{0.020194, -0.159570, 14.898271},{0.003253, -0.156460, 14.506177}}],
    
    Line[{{
      0.003253, -0.156460, 14.506177},{-0.011885, -0.155515, 14.124427}}],
    Line[{{-0.011885, -0.155515, 14.124427},{-0.025591, -0.156611, 
        13.752746}}],
    Line[{{-0.025591, -0.156611, 13.752746},{-0.038193, -0.159648, 
        13.390866}}],
    Line[{{-0.038193, -0.159648, 13.390866},{-0.049975, -0.164559, 
        13.038531}}],
    Line[{{-0.049975, -0.164559, 13.038531},{-0.061192, -0.171303, 
        12.695491}}],
    Line[{{-0.061192, -0.171303, 12.695491},{-0.072071, -0.179865, 
        12.361501}}],
    Line[{{-0.072071, -0.179865, 12.361501},{-0.082818, -0.190258, 
        12.036326}}],
    Line[{{-0.082818, -0.190258, 12.036326},{-0.093621, -0.202521, 
        11.719740}}],
    Line[{{-0.093621, -0.202521, 11.719740},{-0.104657, -0.216720, 
        11.411518}}],
    Line[{{-0.104657, -0.216720, 11.411518},{-0.116090, -0.232947, 
        11.111448}}],
    Line[{{-0.116090, -0.232947, 11.111448},{-0.128083, -0.251321, 
        10.819322}}],
    Line[{{-0.128083, -0.251321, 10.819322},{-0.140793, -0.271989, 
        10.534938}}],
    Line[{{-0.140793, -0.271989, 10.534938},{-0.154378, -0.295128, 
        10.258104}}],
    Line[{{-0.154378, -0.295128, 10.258104},{-0.169001, -0.320945, 
        9.988635}}],
    Line[{{-0.169001, -0.320945, 9.988635},{-0.184827, -0.349679, 9.726351}}],
    
    Line[{{-0.184827, -0.349679, 9.726351},{-0.202035, -0.381605, 9.471082}}],
    
    Line[{{-0.202035, -0.381605, 9.471082},{-0.220810, -0.417034, 9.222666}}],
    
    Line[{{-0.220810, -0.417034, 9.222666},{-0.241353, -0.456321, 8.980949}}],
    
    Line[{{-0.241353, -0.456321, 8.980949},{-0.263883, -0.499863, 8.745790}}],
    
    Line[{{-0.263883, -0.499863, 8.745790},{-0.288637, -0.548108, 8.517057}}],
    
    Line[{{-0.288637, -0.548108, 8.517057},{-0.315874, -0.601558, 8.294629}}],
    
    Line[{{-0.315874, -0.601558, 8.294629},{-0.345879, -0.660775, 8.078401}}],
    
    Line[{{-0.345879, -0.660775, 8.078401},{-0.378969, -0.726386, 7.868283}}],
    
    Line[{{-0.378969, -0.726386, 7.868283},{-0.415492, -0.799094, 7.664203}}],
    
    Line[{{-0.415492, -0.799094, 7.664203},{-0.455833, -0.879683, 7.466113}}],
    
    Line[{{-0.455833, -0.879683, 7.466113},{-0.500421, -0.969026, 7.273989}}],
    
    Line[{{-0.500421, -0.969026, 7.273989},{-0.549731, -1.068099, 7.087836}}],
    
    Line[{{-0.549731, -1.068099, 7.087836},{-0.604291, -1.177989, 6.907700}}],
    
    Line[{{-0.604291, -1.177989, 6.907700},{-0.664689, -1.299907, 6.733665}}],
    
    Line[{{-0.664689, -1.299907, 6.733665},{-0.731577, -1.435201, 6.565875}}],
    
    Line[{{-0.731577, -1.435201, 6.565875},{-0.805683, -1.585373, 6.404533}}],
    
    Line[{{-0.805683, -1.585373, 6.404533},{-0.887815, -1.752095, 6.249926}}],
    
    Line[{{-0.887815, -1.752095, 6.249926},{-0.978872, -1.937219, 6.102430}}],
    
    Line[{{-0.978872, -1.937219, 6.102430},{-1.079855, -2.142810, 5.962549}}],
    
    Line[{{-1.079855, -2.142810, 5.962549},{-1.191875, -2.371153, 5.830921}}],
    
    Line[{{-1.191875, -2.371153, 5.830921},{-1.316167, -2.624775, 5.708372}}],
    
    Line[{{-1.316167, -2.624775, 5.708372},{-1.454103, -2.906478, 5.595932}}],
    
    Line[{{-1.454103, -2.906478, 5.595932},{-1.607204, -3.219337, 5.494915}}],
    
    Line[{{-1.607204, -3.219337, 5.494915},{-1.777152, -3.566742, 5.406941}}],
    
    Line[{{-1.777152, -3.566742, 5.406941},{-1.965808, -3.952387, 5.334060}}],
    
    Line[{{-1.965808, -3.952387, 5.334060},{-2.175224, -4.380309, 5.278777}}],
    
    Line[{{-2.175224, -4.380309, 5.278777},{-2.407653, -4.854843, 5.244239}}],
    
    Line[{{-2.407653, -4.854843, 5.244239},{-2.665569, -5.380667, 5.234286}}],
    
    Line[{{-2.665569, -5.380667, 5.234286},{-2.951660, -5.962693, 5.253678}}],
    
    Line[{{-2.951660, -5.962693, 5.253678},{-3.268842, -6.606053, 5.308239}}],
    
    Line[{{-3.268842, -6.606053, 5.308239},{-3.620245, -7.315955, 5.405085}}],
    
    Line[{{-3.620245, -7.315955, 5.405085},{-4.009193, -8.097528, 5.552873}}],
    
    Line[{{-4.009193, -8.097528, 5.552873},{-4.439174, -8.955572, 5.762082}}],
    
    Line[{{-4.439174, -8.955572, 5.762082},{-4.913756, -9.894145, 6.045291}}],
    
    Line[{{-4.913756, -9.894145, 6.045291},{-5.436523, -10.916175, 
        6.417504}}],
    Line[{{-5.436523, -10.916175, 6.417504},{-6.010893, -12.022655, 
        6.896388}}],
    Line[{{-6.010893, -12.022655, 6.896388},{-6.639931, -13.211826, 
        7.502467}}],
    Line[{{-6.639931, -13.211826, 7.502467},{-7.326068, -14.478026, 
        8.259161}}],
    Line[{{-7.326068, -14.478026, 8.259161},{-8.070720, -15.810266, 
        9.192554}}],
    Line[{{-8.070720, -15.810266, 9.192554},{-8.873793, -17.190542, 
        10.330668}}],
    Line[{{-8.873793, -17.190542, 10.330668},{-9.733077, -18.591999, 
        11.702242}}],
    Line[{{-9.733077, -18.591999, 11.702242},{-10.643512, -19.977043, 
        13.334566}}],
    Line[{{-10.643512, -19.977043, 13.334566},{-11.596356, -21.295778, 
        15.250329}}],
    Line[{{-11.596356, -21.295778, 15.250329},{-12.578321, -22.485226, 
        17.463270}}],
    Line[{{-12.578321, -22.485226, 17.463270},{-13.570775, -23.470026, 
        19.972748}}],
    Line[{{-13.570775, -23.470026, 19.972748},{-14.549198, -24.165403, 
        22.757677}}],
    Line[{{-14.549198, -24.165403, 22.757677},{-15.483109, -24.483120, 
        25.770735}}],
    Line[{{-15.483109, -24.483120, 25.770735},{-16.336710, -24.340734, 
        28.934328}}],
    Line[{{-16.336710, -24.340734, 28.934328},{-17.070545, -23.673744, 
        32.140396}}],
    Line[{{-17.070545, -23.673744, 32.140396},{-17.644176, -22.448788, 
        35.255573}}],
    Line[{{-17.644176, -22.448788, 35.255573},{-18.019817, -20.675077, 
        38.132748}}],
    Line[{{-18.019817, -20.675077, 38.132748},{-18.166502, -18.410595, 
        40.628151}}],
    Line[{{-18.166502, -18.410595, 40.628151},{-18.064039, -15.760021, 
        42.620872}}],
    Line[{{-18.064039, -15.760021, 42.620872},{-17.705967, -12.863592, 
        44.030380}}],
    Line[{{-17.705967, -12.863592, 44.030380},{-17.100775, -9.878693, 
        44.827194}}],
    Line[{{-17.100775, -9.878693, 44.827194},{-16.271091, -6.958640, 
        45.034149}}],
    Line[{{-16.271091, -6.958640, 45.034149},{-15.251004, -4.233793, 
        44.718212}}],
    Line[{{-15.251004, -4.233793, 44.718212},{-14.082113, -1.799100, 
        43.975849}}],
    Line[{{-14.082113, -1.799100, 43.975849},{-12.809177, 0.290292, 
        42.916264}}],
    Line[{{-12.809177, 0.290292, 42.916264},{-11.476106, 2.016264, 
        41.646450}}],
    Line[{{-11.476106, 2.016264, 41.646450},{-10.122855, 3.390258, 
        40.260609}}],
    Line[{{-10.122855, 3.390258, 40.260609},{-8.783435, 4.443933, 
        38.834461}}],
    Line[{{-8.783435, 4.443933, 38.834461},{-7.484994, 5.220240, 37.423904}}],
    
    Line[{{-7.484994, 5.220240, 37.423904},{-6.247764, 5.766184, 36.066555}}],
    
    Line[{{-6.247764, 5.766184, 36.066555},{-5.085597, 6.127761, 34.784908}}],
    
    Line[{{-5.085597, 6.127761, 34.784908},{-4.006825, 6.346893, 33.589939}}],
    
    Line[{{-4.006825, 6.346893, 33.589939},{-3.015264, 6.459937, 32.484505}}],
    
    Line[{{-3.015264, 6.459937, 32.484505},{-2.111193, 6.497301, 31.466219}}],
    
    Line[{{-2.111193, 6.497301, 31.466219},{-1.292248, 6.483699, 30.529623}}],
    
    Line[{{-1.292248, 6.483699, 30.529623},{-0.554190, 6.438778, 29.667788}}],
    
    Line[{{-0.554190, 6.438778, 29.667788},{0.108471, 6.377863, 28.873371}}],
    Line[{{0.108471, 6.377863, 28.873371},{0.701982, 6.312707, 28.139284}}],
    Line[{{0.701982, 6.312707, 28.139284},{1.232970, 6.252179, 27.459076}}],
    Line[{{1.232970, 6.252179, 27.459076},{1.708160, 6.202856, 26.827112}}],
    Line[{{1.708160, 6.202856, 26.827112},{2.134172, 6.169523, 26.238646}}],
    Line[{{2.134172, 6.169523, 26.238646},{2.517384, 6.155577, 25.689783}}],
    Line[{{2.517384, 6.155577, 25.689783},{2.863834, 6.163353, 25.177433}}],
    Line[{{2.863834, 6.163353, 25.177433},{3.179167, 6.194377, 24.699224}}],
    Line[{{3.179167, 6.194377, 24.699224},{3.468606, 6.249570, 24.253428}}],
    Line[{{3.468606, 6.249570, 24.253428},{3.736940, 6.329399, 23.838863}}],
    Line[{{3.736940, 6.329399, 23.838863},{3.988533, 6.433995, 23.454838}}],
    Line[{{3.988533, 6.433995, 23.454838},{4.227330, 6.563237, 23.101084}}],
    Line[{{4.227330, 6.563237, 23.101084},{4.456880, 6.716813, 22.777704}}],
    Line[{{4.456880, 6.716813, 22.777704},{4.680359, 6.894258, 22.485126}}],
    Line[{{4.680359, 6.894258, 22.485126},{4.900588, 7.094975, 22.224083}}],
    Line[{{4.900588, 7.094975, 22.224083},{5.120057, 7.318244, 21.995558}}],
    Line[{{5.120057, 7.318244, 21.995558},{5.340944, 7.563207, 21.800789}}],
    Line[{{5.340944, 7.563207, 21.800789},{5.565133, 7.828858, 21.641226}}],
    Line[{{5.565133, 7.828858, 21.641226},{5.794220, 8.114000, 21.518513}}],
    Line[{{5.794220, 8.114000, 21.518513},{6.029530, 8.417225, 21.434467}}],
    Line[{{6.029530, 8.417225, 21.434467},{6.272110, 8.736849, 21.391035}}],
    Line[{{6.272110, 8.736849, 21.391035},{6.522738, 9.070869, 21.390270}}],
    Line[{{6.522738, 9.070869, 21.390270},{6.781901, 9.416906, 21.434259}}],
    Line[{{6.781901, 9.416906, 21.434259},{7.049805, 9.772147, 21.525091}}],
    Line[{{7.049805, 9.772147, 21.525091},{7.326332, 10.133282, 21.664742}}],
    Line[{{7.326332, 10.133282, 21.664742},{7.611043, 10.496461, 21.855011}}],
    
    Line[{{7.611043, 10.496461, 21.855011},{7.903146, 10.857244, 22.097391}}],
    
    Line[{{7.903146, 10.857244, 22.097391},{8.201468, 11.210598, 22.392914}}],
    
    Line[{{8.201468, 11.210598, 22.392914},{8.504440, 11.550854, 22.742060}}],
    
    Line[{{8.504440, 11.550854, 22.742060},{8.810081, 11.871816, 23.144497}}],
    
    Line[{{8.810081, 11.871816, 23.144497},{9.115975, 12.166732, 23.599007}}],
    
    Line[{{9.115975, 12.166732, 23.599007},{9.419277, 12.428515, 24.103224}}],
    
    Line[{{9.419277, 12.428515, 24.103224},{9.716732, 12.649865, 24.653524}}],
    
    Line[{{9.716732, 12.649865, 24.653524},{
      10.004694, 12.823514, 25.244875}}],
    Line[{{10.004694, 12.823514, 25.244875},{
      10.279184, 12.942486, 25.870739}}],
    Line[{{10.279184, 12.942486, 25.870739},{
      10.535967, 13.000463, 26.523067}}],
    Line[{{10.535967, 13.000463, 26.523067},{
      10.770662, 12.992134, 27.192373}}],
    Line[{{10.770662, 12.992134, 27.192373},{
      10.978854, 12.913533, 27.867857}}],
    Line[{{10.978854, 12.913533, 27.867857},{
      11.156251, 12.762419, 28.537685}}],
    Line[{{11.156251, 12.762419, 28.537685},{
      11.298854, 12.538543, 29.189379}}],
    Line[{{11.298854, 12.538543, 29.189379},{
      11.403129, 12.243828, 29.810276}}],
    Line[{{11.403129, 12.243828, 29.810276},{
      11.466164, 11.882501, 30.387978}}],
    Line[{{11.466164, 11.882501, 30.387978},{
      11.485839, 11.460952, 30.910986}}],
    Line[{{11.485839, 11.460952, 30.910986},{
      11.460940, 10.987574, 31.369156}}],
    Line[{{11.460940, 10.987574, 31.369156},{
      11.391252, 10.472389, 31.754169}}],
    Line[{{11.391252, 10.472389, 31.754169},{
      11.277592, 9.926596, 32.059868}}],
    Line[{{11.277592, 9.926596, 32.059868},{11.121801, 9.362027, 32.282455}}],
    
    Line[{{11.121801, 9.362027, 32.282455},{10.926681, 8.790595, 32.420551}}],
    
    Line[{{10.926681, 8.790595, 32.420551},{10.695883, 8.223753, 32.475086}}],
    
    Line[{{10.695883, 8.223753, 32.475086},{10.433755, 7.672022, 32.449070}}],
    
    Line[{{10.433755, 7.672022, 32.449070},{10.145176, 7.144626, 32.347252}}],
    
    Line[{{10.145176, 7.144626, 32.347252},{9.835362, 6.649240, 32.175743}}],
    Line[{{9.835362, 6.649240, 32.175743},{9.509686, 6.191865, 31.941591}}],
    Line[{{9.509686, 6.191865, 31.941591},{9.173495, 5.776814, 31.652374}}],
    Line[{{9.173495, 5.776814, 31.652374},{8.831963, 5.406803, 31.315857}}],
    Line[{{8.831963, 5.406803, 31.315857},{8.489956, 5.083104, 30.939678}}],
    Line[{{8.489956, 5.083104, 30.939678},{8.151938, 4.805758, 30.531122}}],
    Line[{{8.151938, 4.805758, 30.531122},{7.821902, 4.573804, 30.096954}}],
    Line[{{7.821902, 4.573804, 30.096954},{7.503330, 4.385516, 29.643326}}],
    Line[{{7.503330, 4.385516, 29.643326},{7.199178, 4.238626, 29.175728}}],
    Line[{{7.199178, 4.238626, 29.175728},{6.911891, 4.130523, 28.698990}}],
    Line[{{6.911891, 4.130523, 28.698990},{6.643423, 4.058429, 28.217316}}],
    Line[{{6.643423, 4.058429, 28.217316},{6.395271, 4.019538, 27.734327}}],
    Line[{{6.395271, 4.019538, 27.734327},{6.168530, 4.011128, 27.253134}}],
    Line[{{6.168530, 4.011128, 27.253134},{5.963939, 4.030638, 26.776409}}],
    Line[{{5.963939, 4.030638, 26.776409},{5.781931, 4.075732, 26.306444}}],
    Line[{{5.781931, 4.075732, 26.306444},{5.622688, 4.144325, 25.845236}}],
    Line[{{5.622688, 4.144325, 25.845236},{5.486192, 4.234617, 25.394535}}],
    Line[{{5.486192, 4.234617, 25.394535},{5.372267, 4.345072, 24.955908}}],
    Line[{{5.372267, 4.345072, 24.955908},{5.280621, 4.474439, 24.530785}}],
    Line[{{5.280621, 4.474439, 24.530785},{5.210881, 4.621713, 24.120506}}],
    Line[{{5.210881, 4.621713, 24.120506},{5.162630, 4.786130, 23.726364}}],
    Line[{{5.162630, 4.786130, 23.726364},{5.135425, 4.967137, 23.349627}}],
    Line[{{5.135425, 4.967137, 23.349627},{5.128823, 5.164362, 22.991577}}],
    Line[{{5.128823, 5.164362, 22.991577},{5.142395, 5.377587, 22.653530}}],
    Line[{{5.142395, 5.377587, 22.653530},{5.175737, 5.606712, 22.336868}}],
    Line[{{5.175737, 5.606712, 22.336868},{5.228481, 5.851725, 22.043051}}],
    Line[{{5.228481, 5.851725, 22.043051},{5.300294, 6.112661, 21.773634}}],
    Line[{{5.300294, 6.112661, 21.773634},{5.390878, 6.389570, 21.530294}}],
    Line[{{5.390878, 6.389570, 21.530294},{5.499969, 6.682472, 21.314837}}],
    Line[{{5.499969, 6.682472, 21.314837},{5.627325, 6.991309, 21.129202}}],
    Line[{{5.627325, 6.991309, 21.129202},{5.772717, 7.315908, 20.975481}}],
    Line[{{5.772717, 7.315908, 20.975481},{5.935914, 7.655917, 20.855906}}],
    Line[{{5.935914, 7.655917, 20.855906},{6.116661, 8.010756, 20.772858}}],
    Line[{{6.116661, 8.010756, 20.772858},{6.314660, 8.379546, 20.728842}}],
    Line[{{6.314660, 8.379546, 20.728842},{6.529541, 8.761059, 20.726479}}],
    Line[{{6.529541, 8.761059, 20.726479},{6.760829, 9.153625, 20.768446}}],
    Line[{{6.760829, 9.153625, 20.768446},{7.007917, 9.555079, 20.857458}}],
    Line[{{7.007917, 9.555079, 20.857458},{7.270018, 9.962677, 20.996159}}],
    Line[{{7.270018, 9.962677, 20.996159},{7.546128, 10.373027, 21.187071}}],
    Line[{{7.546128, 10.373027, 21.187071},{7.834986, 10.782043, 21.432440}}],
    
    Line[{{7.834986, 10.782043, 21.432440},{8.135021, 11.184865, 21.734138}}],
    
    Line[{{8.135021, 11.184865, 21.734138},{8.444317, 11.575891, 22.093452}}],
    
    Line[{{8.444317, 11.575891, 22.093452},{8.760564, 11.948720, 22.510942}}],
    
    Line[{{8.760564, 11.948720, 22.510942},{9.081036, 12.296275, 22.986195}}],
    
    Line[{{9.081036, 12.296275, 22.986195},{9.402548, 12.610832, 23.517628}}],
    
    Line[{{9.402548, 12.610832, 23.517628},{9.721474, 12.884270, 24.102272}}],
    
    Line[{{9.721474, 12.884270, 24.102272},{
      10.033747, 13.108253, 24.735590}}],
    Line[{{10.033747, 13.108253, 24.735590},{
      10.334888, 13.274543, 25.411287}}],
    Line[{{10.334888, 13.274543, 25.411287},{
      10.620089, 13.375408, 26.121284}}],
    Line[{{10.620089, 13.375408, 26.121284},{
      10.884300, 13.404004, 26.855684}}],
    Line[{{10.884300, 13.404004, 26.855684},{
      11.122361, 13.354873, 27.602884}}],
    Line[{{11.122361, 13.354873, 27.602884},{
      11.329172, 13.224335, 28.349903}}],
    Line[{{11.329172, 13.224335, 28.349903},{
      11.499869, 13.010963, 29.082655}}],
    Line[{{11.499869, 13.010963, 29.082655},{
      11.630041, 12.715843, 29.786570}}],
    Line[{{11.630041, 12.715843, 29.786570},{
      11.715922, 12.342726, 30.447132}}],
    Line[{{11.715922, 12.342726, 30.447132},{
      11.754598, 11.898079, 31.050571}}],
    Line[{{11.754598, 11.898079, 31.050571},{
      11.744168, 11.390877, 31.584522}}],
    Line[{{11.744168, 11.390877, 31.584522},{
      11.683877, 10.832221, 32.038612}}],
    Line[{{11.683877, 10.832221, 32.038612},{
      11.574175, 10.234830, 32.404938}}],
    Line[{{11.574175, 10.234830, 32.404938},{
      11.416737, 9.612392, 32.678375}}],
    Line[{{11.416737, 9.612392, 32.678375},{11.214398, 8.978860, 32.856712}}],
    
    Line[{{11.214398, 8.978860, 32.856712},{10.971037, 8.347779, 32.940540}}],
    
    Line[{{10.971037, 8.347779, 32.940540},{10.691407, 7.731683, 32.933010}}],
    
    Line[{{10.691407, 7.731683, 32.933010},{10.380933, 7.141600, 32.839443}}],
    
    Line[{{10.380933, 7.141600, 32.839443},{10.045485, 6.586716, 32.666840}}],
    
    Line[{{10.045485, 6.586716, 32.666840},{9.691155, 6.074196, 32.423370}}],
    Line[{{9.691155, 6.074196, 32.423370},{9.324035, 5.609160, 32.117867}}],
    Line[{{9.324035, 5.609160, 32.117867},{8.950027, 5.194778, 31.759361}}],
    Line[{{8.950027, 5.194778, 31.759361},{8.574693, 4.832470, 31.356724}}],
    Line[{{8.574693, 4.832470, 31.356724},{8.203119, 4.522163, 30.918365}}],
    Line[{{8.203119, 4.522163, 30.918365},{7.839845, 4.262581, 30.452036}}],
    Line[{{7.839845, 4.262581, 30.452036},{7.488808, 4.051541, 29.964716}}],
    Line[{{7.488808, 4.051541, 29.964716},{7.153330, 3.886225, 29.462563}}],
    Line[{{7.153330, 3.886225, 29.462563},{6.836131, 3.763432, 28.950920}}],
    Line[{{6.836131, 3.763432, 28.950920},{6.539354, 3.679784, 28.434364}}],
    Line[{{6.539354, 3.679784, 28.434364},{6.264617, 3.631897, 27.916771}}],
    Line[{{6.264617, 3.631897, 27.916771},{6.013067, 3.616510, 27.401411}}],
    Line[{{6.013067, 3.616510, 27.401411},{5.785441, 3.630582, 26.891024}}],
    Line[{{5.785441, 3.630582, 26.891024},{5.582131, 3.671353, 26.387917}}],
    Line[{{5.582131, 3.671353, 26.387917},{5.403241, 3.736384, 25.894049}}],
    Line[{{5.403241, 3.736384, 25.894049},{5.248653, 3.823575, 25.411095}}],
    Line[{{5.248653, 3.823575, 25.411095},{5.118076, 3.931165, 24.940527}}],
    Line[{{5.118076, 3.931165, 24.940527},{5.011092, 4.057722, 24.483658}}],
    Line[{{5.011092, 4.057722, 24.483658},{4.927206, 4.202127, 24.041704}}],
    Line[{{4.927206, 4.202127, 24.041704},{4.865876, 4.363544, 23.615820}}],
    Line[{{4.865876, 4.363544, 23.615820},{4.826543, 4.541394, 23.207136}}],
    Line[{{4.826543, 4.541394, 23.207136},{4.808660, 4.735329, 22.816795}}],
    Line[{{4.808660, 4.735329, 22.816795},{4.811707, 4.945189, 22.445978}}],
    Line[{{4.811707, 4.945189, 22.445978},{4.835208, 5.170979, 22.095928}}],
    Line[{{4.835208, 5.170979, 22.095928},{4.878736, 5.412825, 21.767975}}],
    Line[{{4.878736, 5.412825, 21.767975},{4.941922, 5.670943, 21.463558}}],
    Line[{{4.941922, 5.670943, 21.463558},{5.024459, 5.945604, 21.184244}}],
    Line[{{5.024459, 5.945604, 21.184244},{5.126095, 6.237088, 20.931746}}],
    Line[{{5.126095, 6.237088, 20.931746},{5.246622, 6.545647, 20.707928}}],
    Line[{{5.246622, 6.545647, 20.707928},{5.385878, 6.871453, 20.514843}}],
    Line[{{5.385878, 6.871453, 20.514843},{5.543724, 7.214557, 20.354721}}],
    Line[{{5.543724, 7.214557, 20.354721},{5.720033, 7.574817, 20.229979}}],
    Line[{{5.720033, 7.574817, 20.229979},{5.914666, 7.951854, 20.143232}}],
    Line[{{5.914666, 7.951854, 20.143232},{6.127442, 8.344967, 20.097267}}],
    Line[{{6.127442, 8.344967, 20.097267},{6.358118, 8.753068, 20.095045}}],
    Line[{{6.358118, 8.753068, 20.095045},{6.606342, 9.174593, 20.139635}}],
    Line[{{6.606342, 9.174593, 20.139635},{6.871627, 9.607416, 20.234211}}],
    Line[{{6.871627, 9.607416, 20.234211},{7.153293, 10.048764, 20.381914}}],
    Line[{{7.153293, 10.048764, 20.381914},{7.450430, 10.495116, 20.585835}}],
    
    Line[{{7.450430, 10.495116, 20.585835},{7.761838, 10.942139, 20.848808}}],
    
    Line[{{7.761838, 10.942139, 20.848808},{8.085979, 11.384603, 21.173311}}],
    
    Line[{{8.085979, 11.384603, 21.173311},{8.420913, 11.816336, 21.561262}}],
    
    Line[{{8.420913, 11.816336, 21.561262},{8.764258, 12.230249, 22.013754}}],
    
    Line[{{8.764258, 12.230249, 22.013754},{9.113137, 12.618322, 22.530880}}],
    
    Line[{{9.113137, 12.618322, 22.530880},{9.464142, 12.971732, 23.111401}}],
    
    Line[{{9.464142, 12.971732, 23.111401},{9.813320, 13.281067, 23.752487}}],
    
    Line[{{9.813320, 13.281067, 23.752487},{
      10.156179, 13.536541, 24.449480}}],
    Line[{{10.156179, 13.536541, 24.449480},{
      10.487720, 13.728376, 25.195662}}],
    Line[{{10.487720, 13.728376, 25.195662},{
      10.802506, 13.847260, 25.982122}}],
    Line[{{10.802506, 13.847260, 25.982122},{
      11.094775, 13.884857, 26.797750}}],
    Line[{{11.094775, 13.884857, 26.797750},{
      11.358594, 13.834395, 27.629349}}],
    Line[{{11.358594, 13.834395, 27.629349},{
      11.588045, 13.691209, 28.461903}}],
    Line[{{11.588045, 13.691209, 28.461903},{
      11.777451, 13.453288, 29.279045}}],
    Line[{{11.777451, 13.453288, 29.279045},{
      11.921631, 13.121678, 30.063705}}],
    Line[{{11.921631, 13.121678, 30.063705},{
      12.016158, 12.700709, 30.798862}}],
    Line[{{12.016158, 12.700709, 30.798862},{
      12.057596, 12.198005, 31.468372}}],
    Line[{{12.057596, 12.198005, 31.468372},{
      12.043715, 11.624262, 32.057804}}],
    Line[{{12.043715, 11.624262, 32.057804},{
      11.973641, 10.992767, 32.555202}}],
    Line[{{11.973641, 10.992767, 32.555202},{
      11.847952, 10.318727, 32.951668}}],
    Line[{{11.847952, 10.318727, 32.951668},{
      11.668674, 9.618431, 33.241722}}],
    Line[{{11.668674, 9.618431, 33.241722},{11.439207, 8.908381, 33.423435}}],
    
    Line[{{11.439207, 8.908381, 33.423435},{11.164179, 8.204421, 33.498272}}],
    
    Line[{{11.164179, 8.204421, 33.498272},{10.849215, 7.521001, 33.470722}}],
    
    Line[{{10.849215, 7.521001, 33.470722},{10.500691, 6.870593, 33.347771}}],
    
    Line[{{10.500691, 6.870593, 33.347771},{10.125454, 6.263318, 33.138252}}],
    
    Line[{{10.125454, 6.263318, 33.138252},{9.730537, 5.706781, 32.852207}}],
    Line[{{9.730537, 5.706781, 32.852207},{9.322910, 5.206088, 32.500248}}],
    Line[{{9.322910, 5.206088, 32.500248},{8.909249, 4.764029, 32.093006}}],
    Line[{{8.909249, 4.764029, 32.093006},{8.495760, 4.381363, 31.640722}}],
    Line[{{8.495760, 4.381363, 31.640722},{8.088047, 4.057169, 31.152899}}],
    Line[{{8.088047, 4.057169, 31.152899},{7.691025, 3.789223, 30.638126}}],
    Line[{{7.691025, 3.789223, 30.638126},{7.308884, 3.574361, 30.103973}}],
    Line[{{7.308884, 3.574361, 30.103973},{6.945079, 3.408815, 29.556974}}],
    Line[{{6.945079, 3.408815, 29.556974},{6.602365, 3.288498, 29.002672}}],
    Line[{{6.602365, 3.288498, 29.002672},{6.282835, 3.209240, 28.445694}}],
    Line[{{6.282835, 3.209240, 28.445694},{5.987994, 3.166970, 27.889872}}],
    Line[{{5.987994, 3.166970, 27.889872},{5.718823, 3.157854, 27.338343}}],
    Line[{{5.718823, 3.157854, 27.338343},{5.475863, 3.178383, 26.793673}}],
    Line[{{5.475863, 3.178383, 26.793673},{5.259284, 3.225432, 26.257959}}],
    Line[{{5.259284, 3.225432, 26.257959},{5.068968, 3.296289, 25.732935}}],
    Line[{{5.068968, 3.296289, 25.732935},{4.904566, 3.388661, 25.220051}}],
    Line[{{4.904566, 3.388661, 25.220051},{4.765564, 3.500665, 24.720549}}],
    Line[{{4.765564, 3.500665, 24.720549},{4.651339, 3.630806, 24.235523}}],
    Line[{{4.651339, 3.630806, 24.235523},{4.561201, 3.777954, 23.765978}}],
    Line[{{4.561201, 3.777954, 23.765978},{4.494435, 3.941308, 23.312866}}],
    Line[{{4.494435, 3.941308, 23.312866},{4.450332, 4.120360, 22.877131}}],
    Line[{{4.450332, 4.120360, 22.877131},{4.428216, 4.314865, 22.459734}}],
    Line[{{4.428216, 4.314865, 22.459734},{4.427462, 4.524799, 22.061687}}],
    Line[{{4.427462, 4.524799, 22.061687},{4.447512, 4.750328, 21.684078}}],
    Line[{{4.447512, 4.750328, 21.684078},{4.487885, 4.991770, 21.328087}}],
    Line[{{4.487885, 4.991770, 21.328087},{4.548180, 5.249559, 20.995018}}],
    Line[{{4.548180, 5.249559, 20.995018},{4.628084, 5.524211, 20.686316}}],
    Line[{{4.628084, 5.524211, 20.686316},{4.727359, 5.816288, 20.403584}}],
    Line[{{4.727359, 5.816288, 20.403584},{4.845850, 6.126348, 20.148613}}],
    Line[{{4.845850, 6.126348, 20.148613},{4.983464, 6.454920, 19.923389}}],
    Line[{{4.983464, 6.454920, 19.923389},{5.140165, 6.802431, 19.730120}}],
    Line[{{5.140165, 6.802431, 19.730120},{5.315955, 7.169180, 19.571247}}],
    Line[{{5.315955, 7.169180, 19.571247},{5.510853, 7.555247, 19.449446}}],
    Line[{{5.510853, 7.555247, 19.449446},{5.724874, 7.960454, 19.367657}}],
    Line[{{5.724874, 7.960454, 19.367657},{5.957995, 8.384254, 19.329039}}],
    Line[{{5.957995, 8.384254, 19.329039},{6.210127, 8.825676, 19.337004}}],
    Line[{{6.210127, 8.825676, 19.337004},{6.481066, 9.283191, 19.395128}}],
    Line[{{6.481066, 9.283191, 19.395128},{6.770457, 9.754638, 19.507170}}],
    Line[{{6.770457, 9.754638, 19.507170},{7.077732, 10.237091, 19.676901}}],
    Line[{{7.077732, 10.237091, 19.676901},{7.402062, 10.726744, 19.908106}}],
    
    Line[{{7.402062, 10.726744, 19.908106},{7.742287, 11.218829, 20.204317}}],
    
    Line[{{7.742287, 11.218829, 20.204317},{8.096848, 11.707457, 20.568764}}],
    
    Line[{{8.096848, 11.707457, 20.568764},{8.463727, 12.185655, 21.003994}}],
    
    Line[{{8.463727, 12.185655, 21.003994},{8.840364, 12.645174, 21.511744}}],
    
    Line[{{8.840364, 12.645174, 21.511744},{9.223616, 13.076716, 22.092506}}],
    
    Line[{{9.223616, 13.076716, 22.092506},{9.609693, 13.469892, 22.745258}}],
    
    Line[{{9.609693, 13.469892, 22.745258},{9.994136, 13.813480, 23.467070}}],
    
    Line[{{9.994136, 13.813480, 23.467070},{
      10.371825, 14.095798, 24.252798}}],
    Line[{{10.371825, 14.095798, 24.252798},{
      10.736994, 14.305055, 25.094749}}],
    Line[{{10.736994, 14.305055, 25.094749},{
      11.083328, 14.430006, 25.982533}}],
    Line[{{11.083328, 14.430006, 25.982533},{
      11.404105, 14.460584, 26.903038}}],
    Line[{{11.404105, 14.460584, 26.903038},{
      11.692355, 14.388661, 27.840462}}],
    Line[{{11.692355, 14.388661, 27.840462},{
      11.941135, 14.208775, 28.776842}}],
    Line[{{11.941135, 14.208775, 28.776842},{
      12.143792, 13.918807, 29.692533}}],
    Line[{{12.143792, 13.918807, 29.692533},{
      12.294294, 13.520500, 30.567114}}],
    Line[{{12.294294, 13.520500, 30.567114},{
      12.387545, 13.019736, 31.380350}}],
    Line[{{12.387545, 13.019736, 31.380350},{
      12.419693, 12.426494, 32.113308}}],
    Line[{{12.419693, 12.426494, 32.113308},{
      12.388391, 11.754498, 32.749405}}],
    Line[{{12.388391, 11.754498, 32.749405},{
      12.292970, 11.020529, 33.275368}}],
    Line[{{12.292970, 11.020529, 33.275368},{
      12.134539, 10.243484, 33.681919}}],
    Line[{{12.134539, 10.243484, 33.681919},{
      11.915953, 9.443243, 33.964165}}],
    Line[{{11.915953, 9.443243, 33.964165},{11.641691, 8.639535, 34.121586}}],
    
    Line[{{11.641691, 8.639535, 34.121586},{11.317628, 7.850852, 34.157764}}],
    
    Line[{{11.317628, 7.850852, 34.157764},{10.950747, 7.093574, 34.079765}}],
    
    Line[{{10.950747, 7.093574, 34.079765},{10.548796, 6.381317, 33.897388}}],
    
    Line[{{10.548796, 6.381317, 33.897388},{10.119925, 5.724577, 33.622284}}],
    
    Line[{{10.119925, 5.724577, 33.622284},{9.672363, 5.130673, 33.267101}}],
    Line[{{9.672363, 5.130673, 33.267101},{9.214096, 4.603891, 32.844753}}],
    Line[{{9.214096, 4.603891, 32.844753},{8.752629, 4.145809, 32.367771}}],
    Line[{{8.752629, 4.145809, 32.367771},{8.294788, 3.755739, 31.847830}}],
    Line[{{8.294788, 3.755739, 31.847830},{7.846593, 3.431213, 31.295475}}],
    Line[{{7.846593, 3.431213, 31.295475},{7.413190, 3.168467, 30.719948}}],
    Line[{{7.413190, 3.168467, 30.719948},{6.998834, 2.962890, 30.129143}}],
    Line[{{6.998834, 2.962890, 30.129143},{6.606909, 2.809410, 29.529673}}],
    Line[{{6.606909, 2.809410, 29.529673},{6.239987, 2.702812, 28.926962}}],
    Line[{{6.239987, 2.702812, 28.926962},{5.899900, 2.637985, 28.325394}}],
    Line[{{5.899900, 2.637985, 28.325394},{5.587835, 2.610097, 27.728464}}],
    Line[{{5.587835, 2.610097, 27.728464},{5.304421, 2.614727, 27.138931}}],
    Line[{{5.304421, 2.614727, 27.138931},{5.049832, 2.647925, 26.558968}}],
    Line[{{5.049832, 2.647925, 26.558968},{4.823874, 2.706262, 25.990273}}],
    Line[{{4.823874, 2.706262, 25.990273},{4.626069, 2.786827, 25.434200}}],
    Line[{{4.626069, 2.786827, 25.434200},{4.455733, 2.887219, 24.891842}}],
    Line[{{4.455733, 2.887219, 24.891842},{4.312043, 3.005526, 24.364101}}],
    Line[{{4.312043, 3.005526, 24.364101},{4.194094, 3.140280, 23.851765}}],
    Line[{{4.194094, 3.140280, 23.851765},{4.100945, 3.290422, 23.355551}}],
    Line[{{4.100945, 3.290422, 23.355551},{4.031667, 3.455263, 22.876144}}],
    Line[{{4.031667, 3.455263, 22.876144},{3.985365, 3.634434, 22.414240}}],
    Line[{{3.985365, 3.634434, 22.414240},{3.961210, 3.827853, 21.970570}}],
    Line[{{3.961210, 3.827853, 21.970570},{3.958458, 4.035686, 21.545925}}],
    Line[{{3.958458, 4.035686, 21.545925},{3.976459, 4.258302, 21.141182}}],
    Line[{{3.976459, 4.258302, 21.141182},{4.014670, 4.496249, 20.757324}}],
    Line[{{4.014670, 4.496249, 20.757324},{4.072659, 4.750214, 20.395464}}],
    Line[{{4.072659, 4.750214, 20.395464},{4.150106, 5.020990, 20.056866}}],
    Line[{{4.150106, 5.020990, 20.056866},{4.246801, 5.309445, 19.742962}}],
    Line[{{4.246801, 5.309445, 19.742962},{4.362638, 5.616485, 19.455389}}],
    Line[{{4.362638, 5.616485, 19.455389},{4.497608, 5.943017, 19.195997}}],
    Line[{{4.497608, 5.943017, 19.195997},{4.651787, 6.289908, 18.966883}}],
    Line[{{4.651787, 6.289908, 18.966883},{4.825324, 6.657931, 18.770409}}],
    Line[{{4.825324, 6.657931, 18.770409},{5.018419, 7.047719, 18.609226}}],
    Line[{{5.018419, 7.047719, 18.609226},{5.231304, 7.459692, 18.486294}}],
    Line[{{5.231304, 7.459692, 18.486294},{5.464217, 7.893979, 18.404894}}],
    Line[{{5.464217, 7.893979, 18.404894},{5.717366, 8.350341, 18.368631}}],
    Line[{{5.717366, 8.350341, 18.368631},{5.990897, 8.828054, 18.381428}}],
    Line[{{5.990897, 8.828054, 18.381428},{6.284842, 9.325803, 18.447502}}],
    Line[{{6.284842, 9.325803, 18.447502},{6.599073, 9.841542, 18.571325}}],
    Line[{{6.599073, 9.841542, 18.571325},{6.933239, 10.372357, 18.757524}}],
    Line[{{6.933239, 10.372357, 18.757524},{7.286695, 10.914312, 19.010803}}],
    
    Line[{{7.286695, 10.914312, 19.010803},{7.658427, 11.462301, 19.335747}}],
    
    Line[{{7.658427, 11.462301, 19.335747},{8.046973, 12.009901, 19.736641}}],
    
    Line[{{8.046973, 12.009901, 19.736641},{8.450325, 12.549250, 20.217180}}],
    
    Line[{{8.450325, 12.549250, 20.217180},{8.865852, 13.071011, 20.780130}}],
    
    Line[{{8.865852, 13.071011, 20.780130},{9.290201, 13.564281, 21.426958}}],
    
    Line[{{9.290201, 13.564281, 21.426958},{9.719246, 14.016821, 22.157356}}],
    
    Line[{{9.719246, 14.016821, 22.157356},{
      10.148010, 14.415112, 22.968781}}],
    Line[{{10.148010, 14.415112, 22.968781},{
      10.570674, 14.744879, 23.855974}}],
    Line[{{10.570674, 14.744879, 23.855974},{
      10.980591, 14.991542, 24.810568}}],
    Line[{{10.980591, 14.991542, 24.810568},{
      11.370377, 15.140973, 25.820753}}],
    Line[{{11.370377, 15.140973, 25.820753},{
      11.732057, 15.180364, 26.871151}}],
    Line[{{11.732057, 15.180364, 26.871151},{
      12.057302, 15.099220, 27.942987}}],
    Line[{{12.057302, 15.099220, 27.942987},{
      12.337732, 14.890335, 29.014524}}],
    Line[{{12.337732, 14.890335, 29.014524},{
      12.565274, 14.550793, 30.061785}}],
    Line[{{12.565274, 14.550793, 30.061785},{
      12.732588, 14.082636, 31.059727}}],
    Line[{{12.732588, 14.082636, 31.059727},{
      12.833476, 13.493225, 31.983543}}],
    Line[{{12.833476, 13.493225, 31.983543},{
      12.863295, 12.795263, 32.810150}}],
    Line[{{12.863295, 12.795263, 32.810150},{
      12.819287, 12.006227, 33.519619}}],
    Line[{{12.819287, 12.006227, 33.519619},{
      12.700819, 11.147441, 34.096439}}],
    Line[{{12.700819, 11.147441, 34.096439},{
      12.509477, 10.242721, 34.530392}}],
    Line[{{12.509477, 10.242721, 34.530392},{
      12.249022, 9.316845, 34.816959}}],
    Line[{{12.249022, 9.316845, 34.816959},{11.925201, 8.394008, 34.957241}}],
    
    Line[{{11.925201, 8.394008, 34.957241},{11.545427, 7.496409, 34.957420}}],
    
    Line[{{11.545427, 7.496409, 34.957420},{11.118379, 6.643152, 34.827862}}],
    
    Line[{{11.118379, 6.643152, 34.827862},{10.653545, 5.849508, 34.581985}}],
    
    Line[{{10.653545, 5.849508, 34.581985},{10.160770, 5.126605, 34.235085}}],
    
    Line[{{10.160770, 5.126605, 34.235085},{9.649817, 4.481471, 33.803219}}],
    Line[{{9.649817, 4.481471, 33.803219},{9.130001, 3.917377, 33.302238}}],
    Line[{{9.130001, 3.917377, 33.302238},{8.609905, 3.434379, 32.747078}}],
    Line[{{8.609905, 3.434379, 32.747078},{8.097171, 3.029964, 32.151245}}],
    Line[{{8.097171, 3.029964, 32.151245},{7.598373, 2.699714, 31.526552}}],
    Line[{{7.598373, 2.699714, 31.526552},{7.118978, 2.437937, 30.883017}}],
    Line[{{7.118978, 2.437937, 30.883017},{6.663347, 2.238215, 30.228920}}],
    Line[{{6.663347, 2.238215, 30.228920},{6.234804, 2.093860, 29.570930}}],
    Line[{{6.234804, 2.093860, 29.570930},{5.835718, 1.998263, 28.914307}}],
    Line[{{5.835718, 1.998263, 28.914307},{5.467618, 1.945150, 28.263103}}],
    Line[{{5.467618, 1.945150, 28.263103},{5.131316, 1.928757, 27.620399}}],
    Line[{{5.131316, 1.928757, 27.620399},{4.827026, 1.943923, 26.988480}}],
    Line[{{4.827026, 1.943923, 26.988480},{4.554481, 1.986150, 26.369030}}],
    Line[{{4.554481, 1.986150, 26.369030},{4.313045, 2.051610, 25.763271}}],
    Line[{{4.313045, 2.051610, 25.763271},{4.101809, 2.137121, 25.172094}}],
    Line[{{4.101809, 2.137121, 25.172094},{3.919680, 2.240119, 24.596153}}],
    Line[{{3.919680, 2.240119, 24.596153},{3.765449, 2.358603, 24.035944}}],
    Line[{{3.765449, 2.358603, 24.035944},{3.637861, 2.491086, 23.491873}}],
    Line[{{3.637861, 2.491086, 23.491873},{3.535657, 2.636537, 22.964296}}],
    Line[{{3.535657, 2.636537, 22.964296},{3.457624, 2.794331, 22.453562}}],
    Line[{{3.457624, 2.794331, 22.453562},{3.402620, 2.964197, 21.960037}}],
    Line[{{3.402620, 2.964197, 21.960037},{3.369602, 3.146176, 21.484131}}],
    Line[{{3.369602, 3.146176, 21.484131},{3.357642, 3.340572, 21.026321}}],
    Line[{{3.357642, 3.340572, 21.026321},{3.365944, 3.547920, 20.587170}}],
    Line[{{3.365944, 3.547920, 20.587170},{3.393844, 3.768953, 20.167336}}],
    Line[{{3.393844, 3.768953, 20.167336},{3.440823, 4.004568, 19.767605}}],
    Line[{{3.440823, 4.004568, 19.767605},{3.506502, 4.255800, 19.388901}}],
    Line[{{3.506502, 4.255800, 19.388901},{3.590641, 4.523799, 19.032307}}],
    Line[{{3.590641, 4.523799, 19.032307},{3.693140, 4.809797, 18.699099}}],
    Line[{{3.693140, 4.809797, 18.699099},{3.814026, 5.115090, 18.390755}}],
    Line[{{3.814026, 5.115090, 18.390755},{3.953448, 5.440999, 18.108997}}],
    Line[{{3.953448, 5.440999, 18.108997},{4.111670, 5.788843, 17.855814}}],
    Line[{{4.111670, 5.788843, 17.855814},{4.289052, 6.159898, 17.633492}}],
    Line[{{4.289052, 6.159898, 17.633492},{4.486036, 6.555344, 17.444653}}],
    Line[{{4.486036, 6.555344, 17.444653},{4.703131, 6.976217, 17.292286}}],
    Line[{{4.703131, 6.976217, 17.292286},{4.940884, 7.423327, 17.179770}}],
    Line[{{4.940884, 7.423327, 17.179770},{5.199853, 7.897178, 17.110909}}],
    Line[{{5.199853, 7.897178, 17.110909},{5.480573, 8.397864, 17.089951}}],
    Line[{{5.480573, 8.397864, 17.089951},{5.783508, 8.924937, 17.121582}}],
    Line[{{5.783508, 8.924937, 17.121582},{6.109011, 9.477275, 17.210934}}],
    Line[{{6.109011, 9.477275, 17.210934},{6.457247, 10.052896, 17.363522}}],
    Line[{{6.457247, 10.052896, 17.363522},{6.828133, 10.648782, 17.585178}}],
    
    Line[{{6.828133, 10.648782, 17.585178},{7.221246, 11.260665, 17.881947}}],
    
    Line[{{7.221246, 11.260665, 17.881947},{7.635728, 11.882820, 18.259848}}],
    
    Line[{{7.635728, 11.882820, 18.259848},{8.070180, 12.507835, 18.724701}}],
    
    Line[{{8.070180, 12.507835, 18.724701},{8.522539, 13.126445, 19.281702}}],
    
    Line[{{8.522539, 13.126445, 19.281702},{8.989966, 13.727389, 19.935043}}],
    
    Line[{{8.989966, 13.727389, 19.935043},{9.468712, 14.297320, 20.687372}}],
    
    Line[{{9.468712, 14.297320, 20.687372},{9.954026, 14.820972, 21.539154}}],
    
    Line[{{9.954026, 14.820972, 21.539154},{
      10.440069, 15.281327, 22.488041}}],
    Line[{{10.440069, 15.281327, 22.488041},{
      10.919868, 15.660117, 23.528154}}],
    Line[{{10.919868, 15.660117, 23.528154},{
      11.385348, 15.938581, 24.649477}}],
    Line[{{11.385348, 15.938581, 24.649477},{
      11.827435, 16.098431, 25.837421}}],
    Line[{{11.827435, 16.098431, 25.837421},{
      12.236239, 16.123083, 27.072550}}],
    Line[{{12.236239, 16.123083, 27.072550},{
      12.601380, 15.999104, 28.330797}}],
    Line[{{12.601380, 15.999104, 28.330797},{
      12.912400, 15.717623, 29.584137}}],
    Line[{{12.912400, 15.717623, 29.584137},{
      13.159263, 15.275666, 30.801657}}],
    Line[{{13.159263, 15.275666, 30.801657},{
      13.332934, 14.677148, 31.951225}}],
    Line[{{13.332934, 14.677148, 31.951225},{
      13.425965, 13.933321, 33.001469}}],
    Line[{{13.425965, 13.933321, 33.001469},{
      13.433039, 13.062564, 33.923885}}],
    Line[{{13.433039, 13.062564, 33.923885},{
      13.351400, 12.089452, 34.694874}}],
    Line[{{13.351400, 12.089452, 34.694874},{
      13.181135, 11.043159, 35.297356}}],
    Line[{{13.181135, 11.043159, 35.297356},{
      12.925236, 9.955410, 35.721798}}],
    Line[{{12.925236, 9.955410, 35.721798},{12.589463, 8.858213, 35.966480}}],
    
    Line[{{12.589463, 8.858213, 35.966480},{12.181999, 7.781700, 36.037022}}],
    
    Line[{{12.181999, 7.781700, 36.037022},{11.712951, 6.752296, 35.945290}}],
    
    Line[{{11.712951, 6.752296, 35.945290},{11.193742, 5.791455, 35.707848}}],
    
    Line[{{11.193742, 5.791455, 35.707848},{10.636481, 4.915011, 35.344238}}],
    
    Line[{{10.636481, 4.915011, 35.344238},{10.053358, 4.133105, 34.875347}}],
    
    Line[{{10.053358, 4.133105, 34.875347},{9.456104, 3.450590, 34.321934}}],
    Line[{{9.456104, 3.450590, 34.321934},{8.855572, 2.867778, 33.703529}}],
    Line[{{8.855572, 2.867778, 33.703529},{8.261428, 2.381357, 33.037663}}],
    Line[{{8.261428, 2.381357, 33.037663},{7.681966, 1.985362, 32.339474}}],
    Line[{{7.681966, 1.985362, 32.339474},{7.124032, 1.672091, 31.621561}}],
    Line[{{7.124032, 1.672091, 31.621561},{6.593038, 1.432889, 30.894083}}],
    Line[{{6.593038, 1.432889, 30.894083},{6.093035, 1.258786, 30.164976}}],
    Line[{{6.093035, 1.258786, 30.164976},{5.626840, 1.140992, 29.440250}}],
    Line[{{5.626840, 1.140992, 29.440250},{5.196189, 1.071216, 28.724325}}],
    Line[{{5.196189, 1.071216, 28.724325},{4.801897, 1.041901, 28.020329}}],
    Line[{{4.801897, 1.041901, 28.020329},{4.444024, 1.046335, 27.330402}}],
    Line[{{4.444024, 1.046335, 27.330402},{4.122025, 1.078704, 26.655930}}],
    Line[{{4.122025, 1.078704, 26.655930},{3.834901, 1.134078, 25.997755}}],
    Line[{{3.834901, 1.134078, 25.997755},{3.581318, 1.208379, 25.356337}}],
    Line[{{3.581318, 1.208379, 25.356337},{3.359720, 1.298308, 24.731876}}],
    Line[{{3.359720, 1.298308, 24.731876},{3.168419, 1.401280, 24.124413}}],
    Line[{{3.168419, 1.401280, 24.124413},{3.005674, 1.515341, 23.533892}}],
    Line[{{3.005674, 1.515341, 23.533892},{2.869751, 1.639090, 22.960213}}],
    Line[{{2.869751, 1.639090, 22.960213},{2.758971, 1.771611, 22.403276}}],
    Line[{{2.758971, 1.771611, 22.403276},{2.671750, 1.912405, 21.862997}}],
    Line[{{2.671750, 1.912405, 21.862997},{2.606622, 2.061330, 21.339325}}],
    Line[{{2.606622, 2.061330, 21.339325},{2.562264, 2.218548, 20.832270}}],
    Line[{{2.562264, 2.218548, 20.832270},{2.537509, 2.384485, 20.341896}}],
    Line[{{2.537509, 2.384485, 20.341896},{2.531349, 2.559793, 19.868345}}],
    Line[{{2.531349, 2.559793, 19.868345},{2.542948, 2.745318, 19.411842}}],
    Line[{{2.542948, 2.745318, 19.411842},{2.571632, 2.942074, 18.972706}}],
    Line[{{2.571632, 2.942074, 18.972706},{2.616904, 3.151225, 18.551359}}],
    Line[{{2.616904, 3.151225, 18.551359},{2.678423, 3.374068, 18.148352}}],
    Line[{{2.678423, 3.374068, 18.148352},{2.756014, 3.612017, 17.764366}}],
    Line[{{2.756014, 3.612017, 17.764366},{2.849659, 3.866590, 17.400249}}],
    Line[{{2.849659, 3.866590, 17.400249},{2.959489, 4.139404, 17.057028}}],
    Line[{{2.959489, 4.139404, 17.057028},{3.085781, 4.432148, 16.735935}}],
    Line[{{3.085781, 4.432148, 16.735935},{3.228950, 4.746585, 16.438450}}],
    Line[{{3.228950, 4.746585, 16.438450},{3.389541, 5.084522, 16.166325}}],
    Line[{{3.389541, 5.084522, 16.166325},{3.568221, 5.447789, 15.921625}}],
    Line[{{3.568221, 5.447789, 15.921625},{3.765768, 5.838209, 15.706777}}],
    Line[{{3.765768, 5.838209, 15.706777},{3.983056, 6.257548, 15.524613}}],
    Line[{{3.983056, 6.257548, 15.524613},{4.221041, 6.707477, 15.378427}}],
    Line[{{4.221041, 6.707477, 15.378427},{4.480737, 7.189470, 15.272013}}],
    Line[{{4.480737, 7.189470, 15.272013},{4.763192, 7.704747, 15.209735}}],
    Line[{{4.763192, 7.704747, 15.209735},{5.069449, 8.254124, 15.196563}}],
    Line[{{5.069449, 8.254124, 15.196563},{5.400508, 8.837890, 15.238110}}],
    Line[{{5.400508, 8.837890, 15.238110},{5.757269, 9.455615, 15.340663}}],
    Line[{{5.757269, 9.455615, 15.340663},{6.140455, 10.105931, 15.511151}}],
    Line[{{6.140455, 10.105931, 15.511151},{6.550547, 10.786296, 15.757152}}],
    
    Line[{{6.550547, 10.786296, 15.757152},{6.987655, 11.492671, 16.086697}}],
    
    Line[{{6.987655, 11.492671, 16.086697},{7.451423, 12.219230, 16.508221}}],
    
    Line[{{7.451423, 12.219230, 16.508221},{7.940863, 12.957992, 17.030142}}],
    
    Line[{{7.940863, 12.957992, 17.030142},{8.454211, 13.698505, 17.660582}}],
    
    Line[{{8.454211, 13.698505, 17.660582},{8.988739, 14.427514, 18.406755}}],
    
    Line[{{8.988739, 14.427514, 18.406755},{9.540579, 15.128816, 19.274269}}],
    
    Line[{{9.540579, 15.128816, 19.274269},{
      10.104535, 15.783150, 20.266272}}],
    Line[{{10.104535, 15.783150, 20.266272},{
      10.673935, 16.368399, 21.382450}}],
    Line[{{10.673935, 16.368399, 21.382450},{
      11.240524, 16.860147, 22.617931}}],
    Line[{{11.240524, 16.860147, 22.617931},{
      11.794425, 17.232513, 23.962250}}],
    Line[{{11.794425, 17.232513, 23.962250},{
      12.324218, 17.459539, 25.398386}}],
    Line[{{12.324218, 17.459539, 25.398386},{
      12.817170, 17.517038, 26.902262}}],
    Line[{{12.817170, 17.517038, 26.902262},{
      13.259641, 17.384684, 28.442827}}],
    Line[{{13.259641, 17.384684, 28.442827},{
      13.637613, 17.048414, 29.982576}}],
    Line[{{13.637613, 17.048414, 29.982576},{
      13.937475, 16.502560, 31.479473}}],
    Line[{{13.937475, 16.502560, 31.479473},{
      14.146846, 15.751603, 32.889202}}],
    Line[{{14.146846, 15.751603, 32.889202},{
      14.255479, 14.810996, 34.168373}}],
    Line[{{14.255479, 14.810996, 34.168373},{
      14.256097, 13.706891, 35.277897}}],
    Line[{{14.256097, 13.706891, 35.277897},{
      14.145064, 12.474598, 36.186226}}],
    Line[{{14.145064, 12.474598, 36.186226},{
      13.922792, 11.155962, 36.871880}}],
    Line[{{13.922792, 11.155962, 36.871880},{
      13.593819, 9.795948, 37.324898}}],
    Line[{{13.593819, 9.795948, 37.324898},{13.166526, 8.438937, 37.546974}}],
    
    Line[{{13.166526, 8.438937, 37.546974},{12.652558, 7.125459, 37.550278}}],
    
    Line[{{12.652558, 7.125459, 37.550278},{12.066013, 5.889516, 37.355392}}],
    
    Line[{{12.066013, 5.889516, 37.355392},{11.422495, 4.756967, 36.988644}}],
    
    Line[{{11.422495, 4.756967, 36.988644},{10.738166, 3.744999, 36.479290}}],
    
    Line[{{10.738166, 3.744999, 36.479290},{10.028878, 2.862502, 35.857002}}],
    
    Line[{{10.028878, 2.862502, 35.857002},{9.309461, 2.111125, 35.149879}}],
    Line[{{9.309461, 2.111125, 35.149879},{8.593197, 1.486722, 34.383053}}],
    Line[{{8.593197, 1.486722, 34.383053},{7.891493, 0.980922, 33.577957}}],
    Line[{{7.891493, 0.980922, 33.577957},{7.213730, 0.582626, 32.752056}}],
    Line[{{7.213730, 0.582626, 32.752056},{6.567261, 0.279287, 31.919029}}],
    Line[{{6.567261, 0.279287, 31.919029},{5.957517, 0.057933, 31.089125}}],
    Line[{{5.957517, 0.057933, 31.089125},{5.388188, -0.094081, 30.269703}}],
    Line[{{5.388188, -0.094081, 30.269703},{4.861448, -0.188564, 29.465771}}],
    
    Line[{{4.861448, -0.188564, 29.465771},{4.378194, -0.236188, 28.680506}}],
    
    Line[{{4.378194, -0.236188, 28.680506},{3.938281, -0.246342, 27.915726}}],
    
    Line[{{3.938281, -0.246342, 27.915726},{3.540751, -0.227094, 27.172262}}],
    
    Line[{{3.540751, -0.227094, 27.172262},{3.184028, -0.185236, 26.450277}}],
    
    Line[{{3.184028, -0.185236, 26.450277},{2.866102, -0.126373, 25.749496}}],
    
    Line[{{2.866102, -0.126373, 25.749496},{2.584671, -0.055037, 25.069378}}],
    
    Line[{{2.584671, -0.055037, 25.069378},{2.337269, 0.025186, 24.409243}}],
    Line[{{2.337269, 0.025186, 24.409243},{2.121362, 0.111530, 23.768351}}],
    Line[{{2.121362, 0.111530, 23.768351},{1.934431, 0.201928, 23.145960}}],
    Line[{{1.934431, 0.201928, 23.145960},{1.774027, 0.294902, 22.541359}}],
    Line[{{1.774027, 0.294902, 22.541359},{1.637822, 0.389469, 21.953886}}],
    Line[{{1.637822, 0.389469, 21.953886},{1.523631, 0.485048, 21.382935}}],
    Line[{{1.523631, 0.485048, 21.382935},{1.429443, 0.581394, 20.827957}}],
    Line[{{1.429443, 0.581394, 20.827957},{1.353425, 0.678529, 20.288467}}],
    Line[{{1.353425, 0.678529, 20.288467},{1.293934, 0.776695, 19.764030}}],
    Line[{{1.293934, 0.776695, 19.764030},{1.249513, 0.876317, 19.254263}}],
    Line[{{1.249513, 0.876317, 19.254263},{1.218894, 0.977957, 18.758831}}],
    Line[{{1.218894, 0.977957, 18.758831},{1.200988, 1.082304, 18.277447}}],
    Line[{{1.200988, 1.082304, 18.277447},{1.194879, 1.190143, 17.809862}}],
    Line[{{1.194879, 1.190143, 17.809862},{1.199818, 1.302347, 17.355877}}],
    Line[{{1.199818, 1.302347, 17.355877},{1.215215, 1.419869, 16.915333}}],
    Line[{{1.215215, 1.419869, 16.915333},{1.240630, 1.543733, 16.488119}}],
    Line[{{1.240630, 1.543733, 16.488119},{1.275766, 1.675037, 16.074175}}],
    Line[{{1.275766, 1.675037, 16.074175},{1.320461, 1.814953, 15.673495}}],
    Line[{{1.320461, 1.814953, 15.673495},{1.374685, 1.964730, 15.286139}}],
    Line[{{1.374685, 1.964730, 15.286139},{1.438534, 2.125700, 14.912232}}],
    Line[{{1.438534, 2.125700, 14.912232},{1.512225, 2.299283, 14.551990}}],
    Line[{{1.512225, 2.299283, 14.551990},{1.596093, 2.487002, 14.205716}}],
    Line[{{1.596093, 2.487002, 14.205716},{1.690595, 2.690483, 13.873834}}],
    Line[{{1.690595, 2.690483, 13.873834},{1.796301, 2.911469, 13.556892}}],
    Line[{{1.796301, 2.911469, 13.556892},{1.913900, 3.151827, 13.255600}}],
    Line[{{1.913900, 3.151827, 13.255600},{2.044200, 3.413557, 12.970847}}],
    Line[{{2.044200, 3.413557, 12.970847},{2.188129, 3.698798, 12.703736}}],
    Line[{{2.188129, 3.698798, 12.703736},{2.346735, 4.009827, 12.455634}}],
    Line[{{2.346735, 4.009827, 12.455634},{2.521192, 4.349064, 12.228202}}],
    Line[{{2.521192, 4.349064, 12.228202},{2.712799, 4.719063, 12.023457}}],
    Line[{{2.712799, 4.719063, 12.023457},{2.922979, 5.122488, 11.843843}}],
    Line[{{2.922979, 5.122488, 11.843843},{3.153280, 5.562108, 11.692281}}],
    Line[{{3.153280, 5.562108, 11.692281},{3.405366, 6.040732, 11.572278}}],
    Line[{{3.405366, 6.040732, 11.572278},{3.681012, 6.561158, 11.488006}}],
    Line[{{3.681012, 6.561158, 11.488006},{3.982087, 7.126102, 11.444394}}],
    Line[{{3.982087, 7.126102, 11.444394},{4.310530, 7.738044, 11.447268}}],
    Line[{{4.310530, 7.738044, 11.447268},{4.668315, 8.399103, 11.503428}}],
    Line[{{4.668315, 8.399103, 11.503428},{5.057405, 9.110800, 11.620791}}],
    Line[{{5.057405, 9.110800, 11.620791},{5.479678, 9.873797, 11.808466}}],
    Line[{{5.479678, 9.873797, 11.808466},{5.936844, 10.687538, 12.076828}}],
    Line[{{5.936844, 10.687538, 12.076828},{6.430316, 11.549813, 12.437523}}],
    
    Line[{{6.430316, 11.549813, 12.437523},{6.961070, 12.456257, 12.903411}}],
    
    Line[{{6.961070, 12.456257, 12.903411},{7.529440, 13.399713, 13.488362}}],
    
    Line[{{7.529440, 13.399713, 13.488362},{8.134884, 14.369543, 14.206878}}],
    
    Line[{{8.134884, 14.369543, 14.206878},{8.775702, 15.350904, 15.073457}}],
    
    Line[{{8.775702, 15.350904, 15.073457},{9.448711, 16.324047, 16.101702}}],
    
    Line[{{9.448711, 16.324047, 16.101702},{
      10.148889, 17.263723, 17.303015}}],
    Line[{{10.148889, 17.263723, 17.303015},{
      10.869009, 18.138906, 18.684946}}],
    Line[{{10.869009, 18.138906, 18.684946},{
      11.599307, 18.912951, 20.249146}}],
    Line[{{11.599307, 18.912951, 20.249146},{
      12.327219, 19.544477, 21.989073}}],
    Line[{{12.327219, 19.544477, 21.989073},{
      13.037275, 19.989157, 23.887691}}],
    Line[{{13.037275, 19.989157, 23.887691},{
      13.711231, 20.202616, 25.915489}}],
    Line[{{13.711231, 20.202616, 25.915489},{
      14.328511, 20.144379, 28.029373}}],
    Line[{{14.328511, 20.144379, 28.029373},{
      14.867021, 19.782623, 30.172966}}],
    Line[{{14.867021, 19.782623, 30.172966},{
      15.304366, 19.099222, 32.278793}}],
    Line[{{15.304366, 19.099222, 32.278793},{
      15.619405, 18.094114, 34.272572}}],
    Line[{{15.619405, 18.094114, 34.272572},{
      15.793993, 16.788134, 36.079346}}],
    Line[{{15.793993, 16.788134, 36.079346},{
      15.814735, 15.223266, 37.630806}}],
    Line[{{15.814735, 15.223266, 37.630806},{
      15.674426, 13.459857, 38.872459}}],
    Line[{{15.674426, 13.459857, 38.872459},{
      15.372968, 11.571142, 39.769306}}],
    Line[{{15.372968, 11.571142, 39.769306},{
      14.917566, 9.635772, 40.308910}}],
    Line[{{14.917566, 9.635772, 40.308910},{14.322165, 7.729850, 40.501228}}],
    
    Line[{{14.322165, 7.729850, 40.501228},{13.606210, 5.919929, 40.375484}}],
    
    Line[{{13.606210, 5.919929, 40.375484},{12.792955, 4.258054, 39.974903}}],
    
    Line[{{12.792955, 4.258054, 39.974903},{11.907592, 2.779438, 39.350559}}],
    
    Line[{{11.907592, 2.779438, 39.350559},{10.975444, 1.502570, 38.555466}}],
    
    Line[{{10.975444, 1.502570, 38.555466},{10.020452, 0.431242, 37.639809}}],
    
    Line[{{10.020452, 0.431242, 37.639809},{9.064055, -0.442331, 36.647736}}],
    
    Line[{{9.064055, -0.442331, 36.647736},{8.124489, -1.134051, 35.615654}}],
    
    Line[{{8.124489, -1.134051, 35.615654},{7.216480, -1.664679, 34.571865}}],
    
    Line[{{7.216480, -1.664679, 34.571865},{6.351256, -2.057142, 33.537083}}],
    
    Line[{{6.351256, -2.057142, 33.537083},{5.536773, -2.334505, 32.525463}}],
    
    Line[{{5.536773, -2.334505, 32.525463},{4.778087, -2.518602, 31.545885}}],
    
    Line[{{4.778087, -2.518602, 31.545885},{4.077787, -2.629217, 30.603205}}],
    
    Line[{{4.077787, -2.629217, 30.603205},{3.436453, -2.683698, 29.699369}}],
    
    Line[{{3.436453, -2.683698, 29.699369},{2.853076, -2.696867, 28.834358}}],
    
    Line[{{2.853076, -2.696867, 28.834358},{2.325455, -2.681113, 28.006912}}],
    
    Line[{{2.325455, -2.681113, 28.006912},{1.850528, -2.646606, 27.215071}}],
    
    Line[{{1.850528, -2.646606, 27.215071},{1.424652, -2.601561, 26.456551}}],
    
    Line[{{1.424652, -2.601561, 26.456551},{1.043834, -2.552513, 25.729006}}],
    
    Line[{{1.043834, -2.552513, 25.729006},{0.703909, -2.504589, 25.030182}}],
    
    Line[{{0.703909, -2.504589, 25.030182},{0.400677, -2.461754, 24.358013}}],
    
    Line[{{0.400677, -2.461754, 24.358013},{0.130009, -2.427033, 23.710657}}],
    
    Line[{{
      0.130009, -2.427033, 23.710657},{-0.112082, -2.402707, 23.086515}}],
    Line[{{-0.112082, -2.402707, 23.086515},{-0.329391, -2.390474, 
        22.484222}}],
    Line[{{-0.329391, -2.390474, 22.484222},{-0.525492, -2.391592, 
        21.902639}}],
    Line[{{-0.525492, -2.391592, 21.902639},{-0.703720, -2.406993, 
        21.340820}}],
    Line[{{-0.703720, -2.406993, 21.340820},{-0.867173, -2.437386, 
        20.798002}}],
    Line[{{-0.867173, -2.437386, 20.798002},{-1.018710, -2.483330, 
        20.273584}}],
    Line[{{-1.018710, -2.483330, 20.273584},{-1.160970, -2.545301, 
        19.767107}}],
    Line[{{-1.160970, -2.545301, 19.767107},{-1.296381, -2.623750, 
        19.278252}}],
    Line[{{-1.296381, -2.623750, 19.278252},{-1.427188, -2.719138, 
        18.806822}}],
    Line[{{-1.427188, -2.719138, 18.806822},{-1.555463, -2.831977, 
        18.352739}}],
    Line[{{-1.555463, -2.831977, 18.352739},{-1.683137, -2.962852, 
        17.916058}}],
    Line[{{-1.683137, -2.962852, 17.916058},{-1.812016, -3.112446, 
        17.496948}}],
    Line[{{-1.812016, -3.112446, 17.496948},{-1.943803, -3.281554, 
        17.095728}}],
    Line[{{-1.943803, -3.281554, 17.095728},{-2.080122, -3.471094, 
        16.712852}}],
    Line[{{-2.080122, -3.471094, 16.712852},{-2.222538, -3.682118, 
        16.348944}}],
    Line[{{-2.222538, -3.682118, 16.348944},{-2.372569, -3.915813, 
        16.004812}}],
    Line[{{-2.372569, -3.915813, 16.004812},{-2.531713, -4.173503, 
        15.681475}}],
    Line[{{-2.531713, -4.173503, 15.681475},{-2.701455, -4.456643, 
        15.380190}}],
    Line[{{-2.701455, -4.456643, 15.380190},{-2.883284, -4.766811, 
        15.102489}}],
    Line[{{-2.883284, -4.766811, 15.102489},{-3.078702, -5.105692, 
        14.850225}}],
    Line[{{-3.078702, -5.105692, 14.850225},{-3.289234, -5.475052, 
        14.625611}}],
    Line[{{-3.289234, -5.475052, 14.625611},{-3.516430, -5.876706, 
        14.431277}}],
    Line[{{-3.516430, -5.876706, 14.431277},{-3.761866, -6.312470, 
        14.270329}}],
    Line[{{-3.761866, -6.312470, 14.270329},{-4.027136, -6.784094, 
        14.146409}}],
    Line[{{-4.027136, -6.784094, 14.146409},{-4.313845, -7.293187, 
        14.063766}}],
    Line[{{-4.313845, -7.293187, 14.063766},{-4.623589, -7.841103, 
        14.027323}}],
    Line[{{-4.623589, -7.841103, 14.027323},{-4.957917, -8.428788, 
        14.042736}}],
    Line[{{-4.957917, -8.428788, 14.042736},{-5.318299, -9.056627, 
        14.116454}}],
    Line[{{-5.318299, -9.056627, 14.116454},{-5.706067, -9.724220, 
        14.255758}}],
    Line[{{-5.706067, -9.724220, 14.255758},{-6.122334, -10.430092, 
        14.468760}}],
    Line[{{-6.122334, -10.430092, 14.468760},{-6.567903, -11.171392, 
        14.764349}}],
    Line[{{-6.567903, -11.171392, 14.764349},{-7.043157, -11.943550, 
        15.152117}}],
    Line[{{-7.043157, -11.943550, 15.152117},{-7.547898, -12.739816, 
        15.642118}}],
    Line[{{-7.547898, -12.739816, 15.642118},{-8.081183, -13.550841, 
        16.244520}}],
    Line[{{-8.081183, -13.550841, 16.244520},{-8.641129, -14.364250, 
        16.969145}}],
    Line[{{-8.641129, -14.364250, 16.969145},{-9.224688, -15.164231, 
        17.824764}}],
    Line[{{-9.224688, -15.164231, 17.824764},{-9.827420, -15.931268, 
        18.818199}}],
    Line[{{-9.827420, -15.931268, 18.818199},{-10.443270, -16.642065, 
        19.953197}}],
    Line[{{-10.443270, -16.642065, 19.953197},{-11.064363, -17.269810, 
        21.229132}}],
    Line[{{-11.064363, -17.269810, 21.229132},{-11.680882, -17.784864, 
        22.639587}}],
    Line[{{-11.680882, -17.784864, 22.639587},{-12.281033, -18.156000, 
        24.171005}}],
    Line[{{-12.281033, -18.156000, 24.171005},{-12.851167, -18.352251, 
        25.801548}}],
    Line[{{-12.851167, -18.352251, 25.801548},{-13.376096, -18.345354, 
        27.500515}}],
    Line[{{-13.376096, -18.345354, 27.500515},{-13.839636, -18.112631, 
        29.228542}}],
    Line[{{-13.839636, -18.112631, 29.228542},{-14.225375, -17.640011, 
        30.938881}}],
    Line[{{-14.225375, -17.640011, 30.938881},{-14.517653, -16.924757, 
        32.579826}}],
    Line[{{-14.517653, -16.924757, 32.579826},{-14.702671, -15.977366, 
        34.098255}}],
    Line[{{-14.702671, -15.977366, 34.098255},{-14.769613, -14.822117, 
        35.443913}}],
    Line[{{-14.769613, -14.822117, 35.443913},{-14.711632, -13.496030, 
        36.573792}}],
    Line[{{-14.711632, -13.496030, 36.573792},{-14.526571, -12.046206, 
        37.456013}}],
    Line[{{-14.526571, -12.046206, 37.456013},{-14.217293, -10.525779, 
        38.072479}}],
    Line[{{-14.217293, -10.525779, 38.072479},{-13.791542, -8.989211, 
        38.419827}}],
    Line[{{-13.791542, -8.989211, 38.419827},{-13.261386, -7.487674, 
        38.508598}}],
    Line[{{-13.261386, -7.487674, 38.508598},{-12.642294, -6.065182, 
        38.360958}}],
    Line[{{-12.642294, -6.065182, 38.360958},{-11.951997, -4.756028, 
        38.007339}}],
    Line[{{-11.951997, -4.756028, 38.007339},{-11.209276, -3.583645, 
        37.482780}}],
    Line[{{-11.209276, -3.583645, 37.482780},{-10.432837, -2.560813, 
        36.823502}}],
    Line[{{-10.432837, -2.560813, 36.823502},{-9.640352, -1.690868, 
        36.064083}}],
    Line[{{-9.640352, -1.690868, 36.064083},{-8.847744, -0.969536, 
        35.235538}}],
    Line[{{-8.847744, -0.969536, 35.235538},{-8.068728, -0.386982, 
        34.364189}}],
    Line[{{-8.068728, -0.386982, 34.364189},{-7.314591, 0.070218, 
        33.471310}}],
    Line[{{-7.314591, 0.070218, 33.471310},{-6.594162, 0.417373, 32.573299}}],
    
    Line[{{-6.594162, 0.417373, 32.573299},{-5.913940, 0.670337, 31.682196}}],
    
    Line[{{-5.913940, 0.670337, 31.682196},{-5.278311, 0.844528, 30.806370}}],
    
    Line[{{-5.278311, 0.844528, 30.806370},{-4.689824, 0.954289, 29.951256}}],
    
    Line[{{-4.689824, 0.954289, 29.951256},{-4.149486, 1.012514, 29.120045}}],
    
    Line[{{-4.149486, 1.012514, 29.120045},{-3.657062, 1.030483, 28.314293}}],
    
    Line[{{-3.657062, 1.030483, 28.314293},{-3.211344, 1.017840, 27.534409}}],
    
    Line[{{-3.211344, 1.017840, 27.534409},{-2.810397, 0.982663, 26.780058}}],
    
    Line[{{-2.810397, 0.982663, 26.780058},{-2.451772, 0.931599, 26.050436}}],
    
    Line[{{-2.451772, 0.931599, 26.050436},{-2.132685, 0.870015, 25.344500}}],
    
    Line[{{-2.132685, 0.870015, 25.344500},{-1.850160, 0.802169, 24.661089}}],
    
    Line[{{-1.850160, 0.802169, 24.661089},{-1.601147, 0.731368, 23.999039}}],
    
    Line[{{-1.601147, 0.731368, 23.999039},{-1.382609, 0.660123, 23.357225}}],
    
    Line[{{-1.382609, 0.660123, 23.357225},{-1.191594, 0.590288, 22.734604}}],
    
    Line[{{-1.191594, 0.590288, 22.734604},{-1.025281, 0.523178, 22.130219}}],
    
    Line[{{-1.025281, 0.523178, 22.130219},{-0.881014, 0.459679, 21.543205}}],
    
    Line[{{-0.881014, 0.459679, 21.543205},{-0.756324, 0.400333, 20.972788}}],
    
    Line[{{-0.756324, 0.400333, 20.972788},{-0.648935, 0.345418, 20.418268}}],
    
    Line[{{-0.648935, 0.345418, 20.418268},{-0.556775, 0.295010, 19.879023}}],
    
    Line[{{-0.556775, 0.295010, 19.879023},{-0.477968, 0.249031, 19.354483}}],
    
    Line[{{-0.477968, 0.249031, 19.354483},{-0.410830, 0.207299, 18.844135}}],
    
    Line[{{-0.410830, 0.207299, 18.844135},{-0.353859, 0.169551, 18.347507}}],
    
    Line[{{-0.353859, 0.169551, 18.347507},{-0.305721, 0.135479, 17.864164}}],
    
    Line[{{-0.305721, 0.135479, 17.864164},{-0.265243, 0.104745, 17.393698}}],
    
    Line[{{-0.265243, 0.104745, 17.393698},{-0.231396, 0.076995, 16.935728}}],
    
    Line[{{-0.231396, 0.076995, 16.935728},{-0.203280, 0.051878, 16.489895}}],
    
    Line[{{-0.203280, 0.051878, 16.489895},{-0.180118, 0.029043, 16.055857}}],
    
    Line[{{-0.180118, 0.029043, 16.055857},{-0.161237, 0.008155, 15.633286}}],
    
    Line[{{-0.161237, 0.008155, 15.633286},{-0.146059, -0.011108, 
        15.221869}}],
    Line[{{-0.146059, -0.011108, 15.221869},{-0.134093, -0.029052, 
        14.821305}}],
    Line[{{-0.134093, -0.029052, 14.821305},{-0.124921, -0.045967, 
        14.431303}}],
    Line[{{-0.124921, -0.045967, 14.431303},{-0.118194, -0.062125, 
        14.051581}}],
    Line[{{-0.118194, -0.062125, 14.051581},{-0.113618, -0.077784, 
        13.681869}}],
    Line[{{-0.113618, -0.077784, 13.681869},{-0.110954, -0.093188, 
        13.321899}}],
    Line[{{-0.110954, -0.093188, 13.321899},{-0.110006, -0.108571, 
        12.971418}}],
    Line[{{-0.110006, -0.108571, 12.971418},{-0.110621, -0.124158, 
        12.630178}}],
    Line[{{-0.110621, -0.124158, 12.630178},{-0.112680, -0.140168, 
        12.297937}}],
    Line[{{-0.112680, -0.140168, 12.297937},{-0.116096, -0.156816, 
        11.974462}}],
    Line[{{-0.116096, -0.156816, 11.974462},{-0.120810, -0.174316, 
        11.659525}}],
    Line[{{-0.120810, -0.174316, 11.659525},{-0.126791, -0.192888, 
        11.352907}}],
    Line[{{-0.126791, -0.192888, 11.352907},{-0.134032, -0.212752, 
        11.054396}}],
    Line[{{-0.134032, -0.212752, 11.054396},{-0.142545, -0.234140, 
        10.763783}}],
    Line[{{-0.142545, -0.234140, 10.763783},{-0.152368, -0.257296, 
        10.480872}}],
    Line[{{-0.152368, -0.257296, 10.480872},{-0.163555, -0.282475, 
        10.205469}}],
    Line[{{-0.163555, -0.282475, 10.205469},{-0.176183, -0.309954, 
        9.937389}}],
    Line[{{-0.176183, -0.309954, 9.937389},{-0.190347, -0.340031, 9.676456}}],
    
    Line[{{-0.190347, -0.340031, 9.676456},{-0.206165, -0.373029, 9.422500}}],
    
    Line[{{-0.206165, -0.373029, 9.422500},{-0.223773, -0.409301, 9.175359}}],
    
    Line[{{-0.223773, -0.409301, 9.175359},{-0.243331, -0.449235, 8.934881}}],
    
    Line[{{-0.243331, -0.449235, 8.934881},{-0.265023, -0.493257, 8.700925}}],
    
    Line[{{-0.265023, -0.493257, 8.700925},{-0.289057, -0.541838, 8.473358}}],
    
    Line[{{-0.289057, -0.541838, 8.473358},{-0.315668, -0.595499, 8.252063}}],
    
    Line[{{-0.315668, -0.595499, 8.252063},{-0.345122, -0.654818, 8.036932}}],
    
    Line[{{-0.345122, -0.654818, 8.036932},{-0.377718, -0.720435, 7.827877}}],
    
    Line[{{-0.377718, -0.720435, 7.827877},{-0.413790, -0.793061, 7.624826}}],
    
    Line[{{-0.413790, -0.793061, 7.624826},{-0.453712, -0.873488, 7.427731}}],
    
    Line[{{-0.453712, -0.873488, 7.427731},{-0.497901, -0.962595, 7.236565}}],
    
    Line[{{-0.497901, -0.962595, 7.236565},{-0.546824, -1.061362, 7.051336}}],
    
    Line[{{-0.546824, -1.061362, 7.051336},{-0.601002, -1.170877, 6.872087}}],
    
    Line[{{-0.601002, -1.170877, 6.872087},{-0.661015, -1.292352, 6.698901}}],
    
    Line[{{-0.661015, -1.292352, 6.698901},{-0.727510, -1.427137, 6.531920}}],
    
    Line[{{-0.727510, -1.427137, 6.531920},{-0.801208, -1.576730, 6.371345}}],
    
    Line[{{-0.801208, -1.576730, 6.371345},{-0.882913, -1.742801, 6.217460}}],
    
    Line[{{-0.882913, -1.742801, 6.217460},{-0.973517, -1.927202, 6.070636}}],
    
    Line[{{-0.973517, -1.927202, 6.070636},{-1.074018, -2.131989, 5.931374}}],
    
    Line[{{-1.074018, -2.131989, 5.931374},{-1.185522, -2.359447, 5.800306}}],
    
    Line[{{-1.185522, -2.359447, 5.800306},{-1.309258, -2.612096, 5.678248}}],
    
    Line[{{-1.309258, -2.612096, 5.678248},{-1.446594, -2.892732, 5.566225}}],
    
    Line[{{-1.446594, -2.892732, 5.566225},{-1.599046, -3.204426, 5.465538}}],
    
    Line[{{-1.599046, -3.204426, 5.465538},{-1.768290, -3.550560, 5.377796}}],
    
    Line[{{-1.768290, -3.550560, 5.377796},{-1.956184, -3.934824, 5.305026}}],
    
    Line[{{-1.956184, -3.934824, 5.305026},{-2.164773, -4.361248, 5.249725}}],
    
    Line[{{-2.164773, -4.361248, 5.249725},{-2.396306, -4.834169, 5.215006}}],
    
    Line[{{-2.396306, -4.834169, 5.215006},{-2.653250, -5.358255, 5.204691}}],
    
    Line[{{-2.653250, -5.358255, 5.204691},{-2.938292, -5.938429, 5.223498}}],
    
    Line[{{-2.938292, -5.938429, 5.223498},{-3.254344, -6.579824, 5.277217}}],
    
    Line[{{-3.254344, -6.579824, 5.277217},{-3.604530, -7.287659, 5.372920}}],
    
    Line[{{-3.604530, -7.287659, 5.372920},{-3.992179, -8.067092, 5.519209}}],
    
    Line[{{-3.992179, -8.067092, 5.519209},{-4.420776, -8.922946, 5.726505}}],
    
    Line[{{-4.420776, -8.922946, 5.726505},{-4.893899, -9.859343, 6.007322}}],
    
    Line[{{-4.893899, -9.859343, 6.007322},{-5.415142, -10.879274, 
        6.376593}}],
    Line[{{-5.415142, -10.879274, 6.376593},{-5.987939, -11.983829, 
        6.851911}}],
    Line[{{-5.987939, -11.983829, 6.851911},{-6.615385, -13.171387, 
        7.453733}}],
    Line[{{-6.615385, -13.171387, 7.453733},{-7.299950, -14.436460, 
        8.205431}}],
    Line[{{-7.299950, -14.436460, 8.205431},{-8.043104, -15.768273, 
        9.133052}}],
    Line[{{-8.043104, -15.768273, 9.133052},{-8.844827, -17.149096, 
        10.264640}}],
    Line[{{-8.844827, -17.149096, 10.264640},{-9.703000, -18.552389, 
        11.629015}}],
    Line[{{-9.703000, -18.552389, 11.629015},{-10.612682, -19.940916, 
        13.253654}}],
    Line[{{-10.612682, -19.940916, 13.253654},{-11.565270, -21.265141, 
        15.161561}}],
    Line[{{-11.565270, -21.265141, 15.161561},{-12.547637, -22.462416, 
        17.366949}}],
    Line[{{-12.547637, -22.462416, 17.366949},{-13.541323, -23.457605, 
        19.869839}}],
    Line[{{-13.541323, -23.457605, 19.869839},{-14.521976, -24.165962, 
        22.649956}}],
    Line[{{-14.521976, -24.165962, 22.649956},{-15.459253, -24.498981, 
        25.660896}}],
    Line[{{-15.459253, -24.498981, 25.660896},{-16.317446, -24.373596, 
        28.825968}}],
    Line[{{-16.317446, -24.373596, 28.825968},{-17.057096, -23.724264, 
        32.037868}}],
    Line[{{-17.057096, -23.724264, 32.037868},{-17.637646, -22.516220, 
        35.163589}}],
    Line[{{-17.637646, -22.516220, 35.163589},{-18.021057, -20.757107, 
        38.055820}}],
    Line[{{-18.021057, -20.757107, 38.055820},{-18.175987, -18.503403, 
        40.569969}}],
    Line[{{-18.175987, -18.503403, 40.569969},{-18.081779, -15.858666, 
        42.583740}}],
    Line[{{-18.081779, -15.858666, 42.583740},{-17.731470, -12.962623, 
        44.014843}}],
    Line[{{-17.731470, -12.962623, 44.014843},{-17.133080, -9.972882, 
        44.832012}}],
    Line[{{-17.133080, -9.972882, 44.832012},{-16.308872, -7.043639, 
        45.056595}}],
    Line[{{-16.308872, -7.043639, 45.056595},{-15.292704, -4.306561, 
        44.754597}}],
    Line[{{-15.292704, -4.306561, 44.754597},{-14.126108, -1.858046, 
        44.022125}}],
    Line[{{-14.126108, -1.858046, 44.022125},{-12.853911, 0.245433, 
        42.968552}}],
    Line[{{-12.853911, 0.245433, 42.968552},{-11.520199, 1.984717, 
        41.701439}}],
    Line[{{-11.520199, 1.984717, 41.701439},{-10.165168, 3.370567, 
        40.315720}}],
    Line[{{-10.165168, 3.370567, 40.315720},{-8.823093, 4.434299, 
        38.887901}}],
    Line[{{-8.823093, 4.434299, 38.887901},{-7.521386, 5.218780, 37.474556}}],
    
    Line[{{-7.521386, 5.218780, 37.474556},{-6.280509, 5.771115, 36.113876}}],
    
    Line[{{-6.280509, 5.771115, 36.113876},{-5.114511, 6.137508, 34.828758}}],
    
    Line[{{-5.114511, 6.137508, 34.828758},{-4.031882, 6.360126, 33.630451}}],
    
    Line[{{-4.031882, 6.360126, 33.630451},{-3.036553, 6.475574, 32.521984}}],
    
    Line[{{-3.036553, 6.475574, 32.521984},{-2.128886, 6.514480, 31.501045}}],
    
    Line[{{-2.128886, 6.514480, 31.501045},{-1.306574, 6.501760, 30.562206}}],
    
    Line[{{-1.306574, 6.501760, 30.562206},{-0.565411, 6.457221, 29.698532}}],
    
    Line[{{-0.565411, 6.457221, 29.698532},{0.100076, 6.396315, 28.902645}}],
    Line[{{0.100076, 6.396315, 28.902645},{0.696132, 6.330897, 28.167414}}],
    Line[{{0.696132, 6.330897, 28.167414},{1.229387, 6.269912, 27.486345}}],
    Line[{{1.229387, 6.269912, 27.486345},{1.706577, 6.219997, 26.853764}}],
    Line[{{1.706577, 6.219997, 26.853764},{2.134339, 6.185979, 26.264874}}],
    Line[{{2.134339, 6.185979, 26.264874},{2.519065, 6.171285, 25.715748}}],
    Line[{{2.519065, 6.171285, 25.715748},{2.866812, 6.178270, 25.203264}}],
    Line[{{2.866812, 6.178270, 25.203264},{3.183242, 6.208477, 24.725027}}],
    Line[{{3.183242, 6.208477, 24.725027},{3.473594, 6.262835, 24.279278}}],
    Line[{{3.473594, 6.262835, 24.279278},{3.742675, 6.341814, 23.864824}}],
    Line[{{3.742675, 6.341814, 23.864824},{3.994862, 6.445546, 23.480953}}],
    Line[{{3.994862, 6.445546, 23.480953},{4.234113, 6.573908, 23.127384}}],
    Line[{{4.234113, 6.573908, 23.127384},{4.463990, 6.726586, 22.804207}}],
    Line[{{4.463990, 6.726586, 22.804207},{4.687678, 6.903109, 22.511839}}],
    Line[{{4.687678, 6.903109, 22.511839},{4.908007, 7.102873, 22.250996}}],
    Line[{{4.908007, 7.102873, 22.250996},{5.127474, 7.325150, 22.022657}}],
    Line[{{5.127474, 7.325150, 22.022657},{5.348263, 7.569075, 21.828047}}],
    Line[{{5.348263, 7.569075, 21.828047},{5.572261, 7.833634, 21.668602}}],
    Line[{{5.572261, 7.833634, 21.668602},{5.801070, 8.117627, 21.545956}}],
    Line[{{5.801070, 8.117627, 21.545956},{6.036013, 8.419631, 21.461906}}],
    Line[{{6.036013, 8.419631, 21.461906},{6.278144, 8.737963, 21.418390}}],
    Line[{{6.278144, 8.737963, 21.418390},{6.528238, 9.070615, 21.417439}}],
    Line[{{6.528238, 9.070615, 21.417439},{6.786786, 9.415206, 21.461126}}],
    Line[{{6.786786, 9.415206, 21.461126},{7.053988, 9.768923, 21.551508}}],
    Line[{{7.053988, 9.768923, 21.551508},{7.329735, 10.128462, 21.690557}}],
    Line[{{7.329735, 10.128462, 21.690557},{7.613583, 10.489985, 21.880026}}],
    
    Line[{{7.613583, 10.489985, 21.880026},{7.904746, 10.849062, 22.121407}}],
    
    Line[{{7.904746, 10.849062, 22.121407},{8.202052, 11.200685, 22.415695}}],
    
    Line[{{8.202052, 11.200685, 22.415695},{8.503942, 11.539215, 22.763353}}],
    
    Line[{{8.503942, 11.539215, 22.763353},{8.808439, 11.858470, 23.164043}}],
    
    Line[{{8.808439, 11.858470, 23.164043},{9.113141, 12.151766, 23.616518}}],
    
    Line[{{9.113141, 12.151766, 23.616518},{9.415215, 12.412050, 24.118418}}],
    
    Line[{{9.415215, 12.412050, 24.118418},{9.711422, 12.632069, 24.666117}}],
    
    Line[{{9.711422, 12.632069, 24.666117},{9.998141, 12.804619, 25.254602}}],
    
    Line[{{9.998141, 12.804619, 25.254602},{
      10.271416, 12.922782, 25.877367}}],
    Line[{{10.271416, 12.922782, 25.877367},{
      10.527039, 12.980290, 26.526403}}],
    Line[{{10.527039, 12.980290, 26.526403},{
      10.760654, 12.971882, 27.192272}}],
    Line[{{10.760654, 12.971882, 27.192272},{
      10.967886, 12.893636, 27.864262}}],
    Line[{{10.967886, 12.893636, 27.864262},{
      11.144468, 12.743330, 28.530613}}],
    Line[{{11.144468, 12.743330, 28.530613},{
      11.286435, 12.520729, 29.178932}}],
    Line[{{11.286435, 12.520729, 29.178932},{
      11.390276, 12.227745, 29.796652}}],
    Line[{{11.390276, 12.227745, 29.796652},{
      11.453105, 11.868565, 30.371473}}],
    Line[{{11.453105, 11.868565, 30.371473},{
      11.472815, 11.449530, 30.891973}}],
    Line[{{11.472815, 11.449530, 30.891973},{
      11.448202, 10.978959, 31.348080}}],
    Line[{{11.448202, 10.978959, 31.348080},{
      11.379050, 10.466792, 31.731524}}],
    Line[{{11.379050, 10.466792, 31.731524},{
      11.266171, 9.924131, 32.036175}}],
    Line[{{11.266171, 9.924131, 32.036175},{11.111385, 9.362714, 32.258247}}],
    
    Line[{{11.111385, 9.362714, 32.258247},{10.917472, 8.794360, 32.396343}}],
    
    Line[{{10.917472, 8.794360, 32.396343},{10.688050, 8.230440, 32.451359}}],
    
    Line[{{10.688050, 8.230440, 32.451359},{10.427438, 7.681407, 32.426250}}],
    
    Line[{{10.427438, 7.681407, 32.426250},{10.140472, 7.156433, 32.325706}}],
    
    Line[{{10.140472, 7.156433, 32.325706},{9.832335, 6.663160, 32.155773}}],
    Line[{{9.832335, 6.663160, 32.155773},{9.508360, 6.207572, 31.923424}}],
    Line[{{9.508360, 6.207572, 31.923424},{9.173863, 5.793982, 31.636173}}],
    Line[{{9.173863, 5.793982, 31.636173},{8.833988, 5.425118, 31.301729}}],
    Line[{{8.833988, 5.425118, 31.301729},{8.493575, 5.102276, 30.927671}}],
    Line[{{8.493575, 5.102276, 30.927671},{8.157068, 4.825527, 30.521246}}],
    Line[{{8.157068, 4.825527, 30.521246},{7.828445, 4.593945, 30.089182}}],
    Line[{{7.828445, 4.593945, 30.089182},{7.511177, 4.405838, 29.637609}}],
    Line[{{7.511177, 4.405838, 29.637609},{7.208215, 4.258972, 29.171997}}],
    Line[{{7.208215, 4.258972, 29.171997},{6.922001, 4.150773, 28.697170}}],
    Line[{{6.922001, 4.150773, 28.697170},{6.654489, 4.078491, 28.217321}}],
    Line[{{6.654489, 4.078491, 28.217321},{6.407181, 4.039347, 27.736074}}],
    Line[{{6.407181, 4.039347, 27.736074},{6.181178, 4.030640, 27.256544}}],
    Line[{{6.181178, 4.030640, 27.256544},{5.977225, 4.049829, 26.781404}}],
    Line[{{5.977225, 4.049829, 26.781404},{5.795763, 4.094592, 26.312956}}],
    Line[{{5.795763, 4.094592, 26.312956},{5.636982, 4.162855, 25.853201}}],
    Line[{{5.636982, 4.162855, 25.853201},{5.500874, 4.252827, 25.403898}}],
    Line[{{5.500874, 4.252827, 25.403898},{5.387269, 4.362975, 24.966621}}],
    Line[{{5.387269, 4.362975, 24.966621},{5.295885, 4.492050, 24.542810}}],
    Line[{{5.295885, 4.492050, 24.542810},{5.226356, 4.639048, 24.133814}}],
    Line[{{5.226356, 4.639048, 24.133814},{5.178269, 4.803203, 23.740927}}],
    Line[{{5.178269, 4.803203, 23.740927},{5.151188, 4.983958, 23.365425}}],
    Line[{{5.151188, 4.983958, 23.365425},{5.144675, 5.180935, 23.008596}}],
    Line[{{5.144675, 5.180935, 23.008596},{5.158303, 5.393910, 22.671764}}],
    Line[{{5.158303, 5.393910, 22.671764},{5.191672, 5.622775, 22.356312}}],
    Line[{{5.191672, 5.622775, 22.356312},{5.244415, 5.867509, 22.063704}}],
    Line[{{5.244415, 5.867509, 22.063704},{5.316199, 6.128137, 21.795498}}],
    Line[{{5.316199, 6.128137, 21.795498},{5.406726, 6.404697, 21.553373}}],
    Line[{{5.406726, 6.404697, 21.553373},{5.515729, 6.697196, 21.339130}}],
    Line[{{5.515729, 6.697196, 21.339130},{5.642964, 7.005564, 21.154715}}],
    Line[{{5.642964, 7.005564, 21.154715},{5.788199, 7.329612, 21.002209}}],
    Line[{{5.788199, 7.329612, 21.002209},{5.951196, 7.668973, 20.883841}}],
    Line[{{5.951196, 7.668973, 20.883841},{6.131696, 8.023051, 20.801987}}],
    Line[{{6.131696, 8.023051, 20.801987},{6.329392, 8.390952, 20.759136}}],
    Line[{{6.329392, 8.390952, 20.759136},{6.543907, 8.771428, 20.757898}}],
    Line[{{6.543907, 8.771428, 20.757898},{6.774759, 9.162795, 20.800934}}],
    Line[{{6.774759, 9.162795, 20.800934},{7.021328, 9.562872, 20.890930}}],
    Line[{{7.021328, 9.562872, 20.890930},{7.282820, 9.968902, 21.030508}}],
    Line[{{7.282820, 9.968902, 21.030508},{7.558220, 10.377484, 21.222157}}],
    Line[{{7.558220, 10.377484, 21.222157},{7.846257, 10.784519, 21.468090}}],
    
    Line[{{7.846257, 10.784519, 21.468090},{8.145352, 11.185161, 21.770128}}],
    
    Line[{{8.145352, 11.185161, 21.770128},{8.453578, 11.573795, 22.129526}}],
    
    Line[{{8.453578, 11.573795, 22.129526},{8.768622, 11.944059, 22.546785}}],
    
    Line[{{8.768622, 11.944059, 22.546785},{9.087749, 12.288879, 23.021446}}],
    
    Line[{{9.087749, 12.288879, 23.021446},{9.407784, 12.600595, 23.551884}}],
    
    Line[{{9.407784, 12.600595, 23.551884},{9.725097, 12.871125, 24.135078}}],
    
    Line[{{9.725097, 12.871125, 24.135078},{
      10.035632, 13.092203, 24.766460}}],
    Line[{{10.035632, 13.092203, 24.766460},{
      10.334929, 13.255675, 25.439718}}],
    Line[{{10.334929, 13.255675, 25.439718},{
      10.618200, 13.353895, 26.146748}}],
    Line[{{10.618200, 13.353895, 26.146748},{
      10.880427, 13.380119, 26.877687}}],
    Line[{{10.880427, 13.380119, 26.877687},{
      11.116484, 13.328990, 27.620960}}],
    Line[{{11.116484, 13.328990, 27.620960},{
      11.321313, 13.196939, 28.363640}}],
    Line[{{11.321313, 13.196939, 28.363640},{
      11.490099, 12.982600, 29.091745}}],
    Line[{{11.490099, 12.982600, 29.091745},{
      11.618481, 12.687151, 29.790804}}],
    Line[{{11.618481, 12.687151, 29.790804},{
      11.702744, 12.314378, 30.446434}}],
    Line[{{11.702744, 12.314378, 30.446434},{
      11.740020, 11.870764, 31.045002}}],
    Line[{{11.740020, 11.870764, 31.045002},{
      11.728456, 11.365262, 31.574284}}],
    Line[{{11.728456, 11.365262, 31.574284},{
      11.667328, 10.808925, 32.024040}}],
    Line[{{11.667328, 10.808925, 32.024040},{
      11.557119, 10.214388, 32.386490}}],
    Line[{{11.557119, 10.214388, 32.386490},{
      11.399514, 9.595232, 32.656597}}],
    Line[{{11.399514, 9.595232, 32.656597},{11.197353, 8.965295, 32.832218}}],
    
    Line[{{11.197353, 8.965295, 32.832218},{10.954506, 8.337992, 32.913975}}],
    
    Line[{{10.954506, 8.337992, 32.913975},{10.675703, 7.725729, 32.905025}}],
    
    Line[{{10.675703, 7.725729, 32.905025},{10.366340, 7.139422, 32.810658}}],
    
    Line[{{10.366340, 7.139422, 32.810658},{10.032250, 6.588158, 32.637833}}],
    
    Line[{{10.032250, 6.588158, 32.637833},{9.679482, 6.079024, 32.394657}}],
    Line[{{9.679482, 6.079024, 32.394657},{9.314085, 5.617083, 32.089882}}],
    Line[{{9.314085, 5.617083, 32.089882},{8.941916, 5.205471, 31.732471}}],
    Line[{{8.941916, 5.205471, 31.732471},{8.568491, 4.845595, 31.331221}}],
    Line[{{8.568491, 4.845595, 31.331221},{8.198860, 4.537384, 30.894464}}],
    Line[{{8.198860, 4.537384, 30.894464},{7.837528, 4.279577, 30.429897}}],
    Line[{{7.837528, 4.279577, 30.429897},{7.488402, 4.070016, 29.944447}}],
    Line[{{7.488402, 4.070016, 29.944447},{7.154783, 3.905915, 29.444227}}],
    Line[{{7.154783, 3.905915, 29.444227},{6.839368, 3.784107, 28.934551}}],
    Line[{{6.839368, 3.784107, 28.934551},{6.544291, 3.701250, 28.419968}}],
    Line[{{6.544291, 3.701250, 28.419968},{6.271159, 3.653995, 27.904339}}],
    Line[{{6.271159, 3.653995, 27.904339},{6.021115, 3.639115, 27.390921}}],
    Line[{{6.021115, 3.639115, 27.390921},{5.794895, 3.653597, 26.882452}}],
    Line[{{5.794895, 3.653597, 26.882452},{5.592892, 3.694708, 26.381239}}],
    Line[{{5.592892, 3.694708, 26.381239},{5.415215, 3.760033, 25.889238}}],
    Line[{{5.415215, 3.760033, 25.889238},{5.261752, 3.847489, 25.408133}}],
    Line[{{5.261752, 3.847489, 25.408133},{5.132215, 3.955331, 24.939396}}],
    Line[{{5.132215, 3.955331, 24.939396},{5.026198, 4.082138, 24.484350}}],
    Line[{{5.026198, 4.082138, 24.484350},{4.943211, 4.226799, 24.044220}}],
    Line[{{4.943211, 4.226799, 24.044220},{4.882718, 4.388485, 23.620165}}],
    Line[{{4.882718, 4.388485, 23.620165},{4.844170, 4.566621, 23.213327}}],
    Line[{{4.844170, 4.566621, 23.213327},{4.827024, 4.760855, 22.824858}}],
    Line[{{4.827024, 4.760855, 22.824858},{4.830769, 4.971029, 22.455946}}],
    Line[{{4.830769, 4.971029, 22.455946},{4.854929, 5.197141, 22.107845}}],
    Line[{{4.854929, 5.197141, 22.107845},{4.899086, 5.439311, 21.781893}}],
    Line[{{4.899086, 5.439311, 21.781893},{4.962872, 5.697745, 21.479534}}],
    Line[{{4.962872, 5.697745, 21.479534},{5.045982, 5.972703, 21.202349}}],
    Line[{{5.045982, 5.972703, 21.202349},{5.148161, 6.264450, 20.952053}}],
    Line[{{5.148161, 6.264450, 20.952053},{5.269201, 6.573221, 20.730522}}],
    Line[{{5.269201, 6.573221, 20.730522},{5.408941, 6.899169, 20.539810}}],
    Line[{{5.408941, 6.899169, 20.539810},{5.567232, 7.242320, 20.382151}}],
    Line[{{5.567232, 7.242320, 20.382151},{5.743945, 7.602508, 20.259966}}],
    Line[{{5.743945, 7.602508, 20.259966},{5.938927, 7.979323, 20.175865}}],
    Line[{{5.938927, 7.979323, 20.175865},{6.151991, 8.372033, 20.132633}}],
    Line[{{6.151991, 8.372033, 20.132633},{6.382878, 8.779512, 20.133215}}],
    Line[{{6.382878, 8.779512, 20.133215},{6.631223, 9.200158, 20.180672}}],
    Line[{{6.631223, 9.200158, 20.180672},{6.896518, 9.631805, 20.278137}}],
    Line[{{6.896518, 9.631805, 20.278137},{7.178066, 10.071632, 20.428745}}],
    Line[{{7.178066, 10.071632, 20.428745},{7.474933, 10.516087, 20.635511}}],
    
    Line[{{7.474933, 10.516087, 20.635511},{7.785896, 10.960780, 20.901247}}],
    
    Line[{{7.785896, 10.960780, 20.901247},{8.109391, 11.400464, 21.228344}}],
    
    Line[{{8.109391, 11.400464, 21.228344},{8.443452, 11.828924, 21.618643}}],
    
    Line[{{8.443452, 11.828924, 21.618643},{8.785676, 12.239071, 22.073154}}],
    
    Line[{{8.785676, 12.239071, 22.073154},{9.133150, 12.622851, 22.591858}}],
    
    Line[{{9.133150, 12.622851, 22.591858},{9.482463, 12.971529, 23.173405}}],
    
    Line[{{9.482463, 12.971529, 23.173405},{9.829629, 13.275665, 23.814840}}],
    
    Line[{{9.829629, 13.275665, 23.814840},{
      10.170156, 13.525588, 24.511391}}],
    Line[{{10.170156, 13.525588, 24.511391},{
      10.499045, 13.711625, 25.256239}}],
    Line[{{10.499045, 13.711625, 25.256239},{
      10.810871, 13.824597, 26.040369}}],
    Line[{{10.810871, 13.824597, 26.040369},{
      11.099903, 13.856354, 26.852625}}],
    Line[{{11.099903, 13.856354, 26.852625},{
      11.360247, 13.800297, 27.679770}}],
    Line[{{11.360247, 13.800297, 27.679770},{
      11.586038, 13.652004, 28.506796}}],
    Line[{{11.586038, 13.652004, 28.506796},{
      11.771678, 13.409650, 29.317446}}],
    Line[{{11.771678, 13.409650, 29.317446},{
      11.912074, 13.074511, 30.094763}}],
    Line[{{11.912074, 13.074511, 30.094763},{
      12.002892, 12.651066, 30.821913}}],
    Line[{{12.002892, 12.651066, 30.821913},{
      12.040796, 12.147080, 31.482983}}],
    Line[{{12.040796, 12.147080, 31.482983},{
      12.023655, 11.573307, 32.063797}}],
    Line[{{12.023655, 11.573307, 32.063797},{
      11.950691, 10.943049, 32.552658}}],
    Line[{{11.950691, 10.943049, 32.552658},{
      11.822564, 10.271450, 32.940937}}],
    Line[{{11.822564, 10.271450, 32.940937},{
      11.641367, 9.574676, 33.223404}}],
    Line[{{11.641367, 9.574676, 33.223404},{11.410546, 8.869051, 33.398308}}],
    
    Line[{{11.410546, 8.869051, 33.398308},{11.134748, 8.170232, 33.467258}}],
    
    Line[{{11.134748, 8.170232, 33.467258},{10.819601, 7.492434, 33.434834}}],
    
    Line[{{10.819601, 7.492434, 33.434834},{10.471461, 6.847915, 33.308041}}],
    
    Line[{{10.471461, 6.847915, 33.308041},{10.097136, 6.246593, 33.095699}}],
    
    Line[{{10.097136, 6.246593, 33.095699},{9.703608, 5.695893, 32.807793}}],
    Line[{{9.703608, 5.695893, 32.807793},{9.297780, 5.200777, 32.454842}}],
    Line[{{9.297780, 5.200777, 32.454842},{8.886261, 4.763927, 32.047375}}],
    Line[{{8.886261, 4.763927, 32.047375},{8.475184, 4.386031, 31.595505}}],
    Line[{{8.475184, 4.386031, 31.595505},{8.070086, 4.066130, 31.108629}}],
    Line[{{8.070086, 4.066130, 31.108629},{7.675814, 3.801991, 30.595224}}],
    Line[{{7.675814, 3.801991, 30.595224},{7.296500, 3.590464, 30.062769}}],
    Line[{{7.296500, 3.590464, 30.062769},{6.935550, 3.427809, 29.517712}}],
    Line[{{6.935550, 3.427809, 29.517712},{6.595673, 3.309981, 28.965527}}],
    Line[{{6.595673, 3.309981, 28.965527},{6.278931, 3.232856, 28.410789}}],
    Line[{{6.278931, 3.232856, 28.410789},{5.986799, 3.192417, 27.857292}}],
    Line[{{5.986799, 3.192417, 27.857292},{5.720242, 3.184877, 27.308140}}],
    Line[{{5.720242, 3.184877, 27.308140},{5.479786, 3.206779, 26.765879}}],
    Line[{{5.479786, 3.206779, 26.765879},{5.265597, 3.255042, 26.232597}}],
    Line[{{5.265597, 3.255042, 26.232597},{5.077552, 3.326996, 25.710020}}],
    Line[{{5.077552, 3.326996, 25.710020},{4.915305, 3.420384, 25.199596}}],
    Line[{{4.915305, 3.420384, 25.199596},{4.778347, 3.533354, 24.702572}}],
    Line[{{4.778347, 3.533354, 24.702572},{4.666061, 3.664438, 24.220049}}],
    Line[{{4.666061, 3.664438, 24.220049},{4.577768, 3.812529, 23.753036}}],
    Line[{{4.577768, 3.812529, 23.753036},{4.512762, 3.976840, 23.302502}}],
    Line[{{4.512762, 3.976840, 23.302502},{4.470343, 4.156880, 22.869396}}],
    Line[{{4.470343, 4.156880, 22.869396},{4.449847, 4.352411, 22.454700}}],
    Line[{{4.449847, 4.352411, 22.454700},{4.450659, 4.563415, 22.059435}}],
    Line[{{4.450659, 4.563415, 22.059435},{4.472229, 4.790057, 21.684706}}],
    Line[{{4.472229, 4.790057, 21.684706},{4.514085, 5.032655, 21.331707}}],
    Line[{{4.514085, 5.032655, 21.331707},{4.575836, 5.291637, 21.001764}}],
    Line[{{4.575836, 5.291637, 21.001764},{4.657169, 5.567509, 20.696337}}],
    Line[{{4.657169, 5.567509, 20.696337},{4.757858, 5.860816, 20.417049}}],
    Line[{{4.757858, 5.860816, 20.417049},{4.877744, 6.172101, 20.165707}}],
    Line[{{4.877744, 6.172101, 20.165707},{5.016736, 6.501863, 19.944321}}],
    Line[{{5.016736, 6.501863, 19.944321},{5.174793, 6.850509, 19.755112}}],
    Line[{{5.174793, 6.850509, 19.755112},{5.351914, 7.218291, 19.600536}}],
    Line[{{5.351914, 7.218291, 19.600536},{5.548109, 7.605256, 19.483295}}],
    Line[{{5.548109, 7.605256, 19.483295},{5.763380, 8.011163, 19.406322}}],
    Line[{{5.763380, 8.011163, 19.406322},{5.997687, 8.435419, 19.372805}}],
    Line[{{5.997687, 8.435419, 19.372805},{6.250919, 8.876971, 19.386127}}],
    Line[{{6.250919, 8.876971, 19.386127},{6.522850, 9.334227, 19.449886}}],
    Line[{{6.522850, 9.334227, 19.449886},{6.813089, 9.804933, 19.567781}}],
    Line[{{6.813089, 9.804933, 19.567781},{7.121036, 10.286068, 19.743584}}],
    Line[{{7.121036, 10.286068, 19.743584},{7.445816, 10.773739, 19.980984}}],
    
    Line[{{7.445816, 10.773739, 19.980984},{7.786222, 11.263057, 20.283472}}],
    
    Line[{{7.786222, 11.263057, 20.283472},{8.140643, 11.748058, 20.654133}}],
    
    Line[{{8.140643, 11.748058, 20.654133},{8.507002, 12.221644, 21.095413}}],
    
    Line[{{8.507002, 12.221644, 21.095413},{8.882681, 12.675527, 21.608854}}],
    
    Line[{{8.882681, 12.675527, 21.608854},{9.264478, 13.100329, 22.194771}}],
    
    Line[{{9.264478, 13.100329, 22.194771},{9.648540, 13.485646, 22.851898}}],
    
    Line[{{9.648540, 13.485646, 22.851898},{
      10.030363, 13.820300, 23.577066}}],
    Line[{{10.030363, 13.820300, 23.577066},{
      10.404779, 14.092674, 24.364861}}],
    Line[{{10.404779, 14.092674, 24.364861},{
      10.765996, 14.291142, 25.207317}}],
    Line[{{10.765996, 14.291142, 25.207317},{
      11.107700, 14.404692, 26.093819}}],
    Line[{{11.107700, 14.404692, 26.093819},{
      11.423182, 14.423551, 27.011021}}],
    Line[{{11.423182, 14.423551, 27.011021},{
      11.705524, 14.339971, 27.943001}}],
    Line[{{11.705524, 14.339971, 27.943001},{
      11.947870, 14.148894, 28.871744}}],
    Line[{{11.947870, 14.148894, 28.871744},{
      12.143682, 13.848676, 29.777655}}],
    Line[{{12.143682, 13.848676, 29.777655},{
      12.287078, 13.441497, 30.640488}}],
    Line[{{12.287078, 13.441497, 30.640488},{
      12.373138, 12.933650, 31.440306}}],
    Line[{{12.373138, 12.933650, 31.440306},{
      12.398207, 12.335443, 32.158577}}],
    Line[{{12.398207, 12.335443, 32.158577},{
      12.360135, 11.660826, 32.779194}}],
    Line[{{12.360135, 11.660826, 32.779194},{
      12.258460, 10.926681, 33.289417}}],
    Line[{{12.258460, 10.926681, 33.289417},{
      12.094471, 10.151850, 33.680515}}],
    Line[{{12.094471, 10.151850, 33.680515},{
      11.871176, 9.356038, 33.948074}}],
    Line[{{11.871176, 9.356038, 33.948074},{11.593169, 8.558694, 34.091999}}],
    
    Line[{{11.593169, 8.558694, 34.091999},{11.266403, 7.777937, 34.116203}}],
    
    Line[{{11.266403, 7.777937, 34.116203},{10.897888, 7.029728, 34.027969}}],
    
    Line[{{10.897888, 7.029728, 34.027969},{10.495358, 6.327260, 33.837181}}],
    
    Line[{{10.495358, 6.327260, 33.837181},{10.066916, 5.680632, 33.555496}}],
    
    Line[{{10.066916, 5.680632, 33.555496},{9.620704, 5.096807, 33.195488}}],
    Line[{{9.620704, 5.096807, 33.195488},{9.164606, 4.579773, 32.769913}}],
    Line[{{9.164606, 4.579773, 32.769913},{8.706005, 4.130887, 32.291103}}],
    Line[{{8.706005, 4.130887, 32.291103},{8.251598, 3.749309, 31.770544}}],
    Line[{{8.251598, 3.749309, 31.770544},{7.807282, 3.432482, 31.218565}}],
    Line[{{7.807282, 3.432482, 31.218565},{7.378082, 3.176609, 30.644207}}],
    Line[{{7.378082, 3.176609, 30.644207},{6.968142, 2.977090, 30.055199}}],
    Line[{{6.968142, 2.977090, 30.055199},{6.580751, 2.828897, 29.457996}}],
    Line[{{6.580751, 2.828897, 29.457996},{6.218400, 2.726878, 28.857903}}],
    Line[{{6.218400, 2.726878, 28.857903},{5.882855, 2.666003, 28.259201}}],
    Line[{{5.882855, 2.666003, 28.259201},{5.575247, 2.641529, 27.665312}}],
    Line[{{5.575247, 2.641529, 27.665312},{5.296169, 2.649118, 27.078939}}],
    Line[{{5.296169, 2.649118, 27.078939},{5.045767, 2.684909, 26.502216}}],
    Line[{{5.045767, 2.684909, 26.502216},{4.823829, 2.745548, 25.936819}}],
    Line[{{4.823829, 2.745548, 25.936819},{4.629869, 2.828200, 25.384087}}],
    Line[{{4.629869, 2.828200, 25.384087},{4.463204, 2.930533, 24.845102}}],
    Line[{{4.463204, 2.930533, 24.845102},{4.323015, 3.050687, 24.320778}}],
    Line[{{4.323015, 3.050687, 24.320778},{4.208406, 3.187248, 23.811903}}],
    Line[{{4.208406, 3.187248, 23.811903},{4.118453, 3.339199, 23.319208}}],
    Line[{{4.118453, 3.339199, 23.319208},{4.052238, 3.505885, 22.843395}}],
    Line[{{4.052238, 3.505885, 22.843395},{4.008887, 3.686969, 22.385176}}],
    Line[{{4.008887, 3.686969, 22.385176},{3.987590, 3.882390, 21.945301}}],
    Line[{{3.987590, 3.882390, 21.945301},{3.987618, 4.092331, 21.524586}}],
    Line[{{3.987618, 4.092331, 21.524586},{4.008341, 4.317175, 21.123930}}],
    Line[{{4.008341, 4.317175, 21.123930},{4.049233, 4.557476, 20.744349}}],
    Line[{{4.049233, 4.557476, 20.744349},{4.109879, 4.813920, 20.386982}}],
    Line[{{4.109879, 4.813920, 20.386982},{4.189973, 5.087298, 20.053127}}],
    Line[{{4.189973, 5.087298, 20.053127},{4.289314, 5.378468, 19.744253}}],
    Line[{{4.289314, 5.378468, 19.744253},{4.407810, 5.688316, 19.462032}}],
    Line[{{4.407810, 5.688316, 19.462032},{4.545455, 6.017728, 19.208355}}],
    Line[{{4.545455, 6.017728, 19.208355},{4.702332, 6.367534, 18.985361}}],
    Line[{{4.702332, 6.367534, 18.985361},{4.878587, 6.738467, 18.795456}}],
    Line[{{4.878587, 6.738467, 18.795456},{5.074416, 7.131104, 18.641335}}],
    Line[{{5.074416, 7.131104, 18.641335},{5.290040, 7.545792, 18.526001}}],
    Line[{{5.290040, 7.545792, 18.526001},{5.525681, 7.982585, 18.452772}}],
    Line[{{5.525681, 7.982585, 18.452772},{5.781522, 8.441138, 18.425291}}],
    Line[{{5.781522, 8.441138, 18.425291},{6.057677, 8.920609, 18.447504}}],
    Line[{{6.057677, 8.920609, 18.447504},{6.354138, 9.419540, 18.523649}}],
    Line[{{6.354138, 9.419540, 18.523649},{6.670723, 9.935727, 18.658173}}],
    Line[{{6.670723, 9.935727, 18.658173},{7.007019, 10.466070, 18.855694}}],
    Line[{{7.007019, 10.466070, 18.855694},{7.362304, 11.006433, 19.120827}}],
    
    Line[{{7.362304, 11.006433, 19.120827},{7.735478, 11.551491, 19.458073}}],
    
    Line[{{7.735478, 11.551491, 19.458073},{8.124974, 12.094584, 19.871548}}],
    
    Line[{{8.124974, 12.094584, 19.871548},{8.528675, 12.627647, 20.364723}}],
    
    Line[{{8.528675, 12.627647, 20.364723},{8.943817, 13.141079, 20.940100}}],
    
    Line[{{8.943817, 13.141079, 20.940100},{9.366931, 13.623872, 21.598763}}],
    
    Line[{{9.366931, 13.623872, 21.598763},{9.793737, 14.063571, 22.339981}}],
    
    Line[{{9.793737, 14.063571, 22.339981},{
      10.219145, 14.446682, 23.160706}}],
    Line[{{10.219145, 14.446682, 23.160706},{
      10.637217, 14.758973, 24.055140}}],
    Line[{{10.637217, 14.758973, 24.055140},{
      11.041212, 14.986066, 25.014309}}],
    Line[{{11.041212, 14.986066, 25.014309},{
      11.423686, 15.114198, 26.025820}}],
    Line[{{11.423686, 15.114198, 26.025820},{
      11.776664, 15.131095, 27.073814}}],
    Line[{{11.776664, 15.131095, 27.073814},{
      12.091864, 15.026944, 28.139091}}],
    Line[{{12.091864, 15.026944, 28.139091},{
      12.361023, 14.795421, 29.199640}}],
    Line[{{12.361023, 14.795421, 29.199640},{
      12.576269, 14.434517, 30.231508}}],
    Line[{{12.576269, 14.434517, 30.231508},{
      12.730522, 13.947223, 31.209864}}],
    Line[{{12.730522, 13.947223, 31.209864},{
      12.817917, 13.341833, 32.110401}}],
    Line[{{12.817917, 13.341833, 32.110401},{
      12.834191, 12.631817, 32.910782}}],
    Line[{{12.834191, 12.631817, 32.910782},{
      12.776995, 11.835215, 33.592041}}],
    Line[{{12.776995, 11.835215, 33.592041},{
      12.646103, 10.973626, 34.139721}}],
    Line[{{12.646103, 10.973626, 34.139721},{
      12.443484, 10.070851, 34.544708}}],
    Line[{{12.443484, 10.070851, 34.544708},{
      12.173230, 9.151371, 34.803509}}],
    Line[{{12.173230, 9.151371, 34.803509},{11.841344, 8.238839, 34.918121}}],
    
    Line[{{11.841344, 8.238839, 34.918121},{11.455413, 7.354712, 34.895412}}],
    
    Line[{{11.455413, 7.354712, 34.895412},{11.024195, 6.517265, 34.746193}}],
    
    Line[{{11.024195, 6.517265, 34.746193},{10.557174, 5.740920, 34.484089}}],
    
    Line[{{10.557174, 5.740920, 34.484089},{10.064103, 5.035995, 34.124397}}],
    
    Line[{{10.064103, 5.035995, 34.124397},{9.554597, 4.408816, 33.682991}}],
    Line[{{9.554597, 4.408816, 33.682991},{9.037775, 3.862080, 33.175426}}],
    Line[{{9.037775, 3.862080, 33.175426},{8.521994, 3.395416, 32.616261}}],
    Line[{{8.521994, 3.395416, 32.616261},{8.014654, 3.006019, 32.018593}}],
    Line[{{8.014654, 3.006019, 32.018593},{7.522098, 2.689312, 31.393835}}],
    Line[{{7.522098, 2.689312, 31.393835},{7.049564, 2.439545, 30.751640}}],
    Line[{{7.049564, 2.439545, 30.751640},{6.601213, 2.250329, 30.099953}}],
    Line[{{6.601213, 2.250329, 30.099953},{6.180187, 2.115062, 29.445166}}],
    Line[{{6.180187, 2.115062, 29.445166},{5.788703, 2.027264, 28.792313}}],
    Line[{{5.788703, 2.027264, 28.792313},{5.428169, 1.980811, 28.145273}}],
    Line[{{5.428169, 1.980811, 28.145273},{5.099298, 1.970099, 27.506990}}],
    Line[{{5.099298, 1.970099, 27.506990},{4.802230, 1.990132, 26.879654}}],
    Line[{{4.802230, 1.990132, 26.879654},{4.536651, 2.036569, 26.264883}}],
    Line[{{4.536651, 2.036569, 26.264883},{4.301893, 2.105726, 25.663857}}],
    Line[{{4.301893, 2.105726, 25.663857},{4.097032, 2.194555, 25.077444}}],
    Line[{{4.097032, 2.194555, 25.077444},{3.920973, 2.300611, 24.506289}}],
    Line[{{3.920973, 2.300611, 24.506289},{3.772517, 2.421996, 23.950891}}],
    Line[{{3.772517, 2.421996, 23.950891},{3.650427, 2.557315, 23.411667}}],
    Line[{{3.650427, 2.557315, 23.411667},{3.553468, 2.705617, 22.888990}}],
    Line[{{3.553468, 2.705617, 22.888990},{3.480455, 2.866345, 22.383230}}],
    Line[{{3.480455, 2.866345, 22.383230},{3.430279, 3.039284, 21.894781}}],
    Line[{{3.430279, 3.039284, 21.894781},{3.401931, 3.224522, 21.424082}}],
    Line[{{3.401931, 3.224522, 21.424082},{3.394518, 3.422403, 20.971647}}],
    Line[{{3.394518, 3.422403, 20.971647},{3.407277, 3.633495, 20.538071}}],
    Line[{{3.407277, 3.633495, 20.538071},{3.439580, 3.858555, 20.124060}}],
    Line[{{3.439580, 3.858555, 20.124060},{3.490942, 4.098498, 19.730444}}],
    Line[{{3.490942, 4.098498, 19.730444},{3.561012, 4.354373, 19.358198}}],
    Line[{{3.561012, 4.354373, 19.358198},{3.649582, 4.627334, 19.008465}}],
    Line[{{3.649582, 4.627334, 19.008465},{3.756578, 4.918611, 18.682581}}],
    Line[{{3.756578, 4.918611, 18.682581},{3.882050, 5.229486, 18.382097}}],
    Line[{{3.882050, 5.229486, 18.382097},{4.026167, 5.561262, 18.108810}}],
    Line[{{4.026167, 5.561262, 18.108810},{4.189208, 5.915222, 17.864794}}],
    Line[{{4.189208, 5.915222, 17.864794},{4.371542, 6.292594, 17.652426}}],
    Line[{{4.371542, 6.292594, 17.652426},{4.573616, 6.694492, 17.474424}}],
    Line[{{4.573616, 6.694492, 17.474424},{4.795934, 7.121864, 17.333879}}],
    Line[{{4.795934, 7.121864, 17.333879},{5.039029, 7.575406, 17.234278}}],
    Line[{{5.039029, 7.575406, 17.234278},{5.303433, 8.055475, 17.179529}}],
    Line[{{5.303433, 8.055475, 17.179529},{5.589646, 8.561991, 17.173985}}],
    Line[{{5.589646, 8.561991, 17.173985},{5.898078, 9.094276, 17.222418}}],
    Line[{{5.898078, 9.094276, 17.222418},{6.229012, 9.650949, 17.330040}}],
    Line[{{6.229012, 9.650949, 17.330040},{6.582517, 10.229703, 17.502392}}],
    Line[{{6.582517, 10.229703, 17.502392},{6.958398, 10.827152, 17.745335}}],
    
    Line[{{6.958398, 10.827152, 17.745335},{7.356084, 11.438603, 18.064806}}],
    
    Line[{{7.356084, 11.438603, 18.064806},{7.774550, 12.057851, 18.466730}}],
    
    Line[{{7.774550, 12.057851, 18.466730},{8.212189, 12.676974, 18.956635}}],
    
    Line[{{8.212189, 12.676974, 18.956635},{8.666706, 13.286176, 19.539360}}],
    
    Line[{{8.666706, 13.286176, 19.539360},{9.134995, 13.873635, 20.218567}}],
    
    Line[{{9.134995, 13.873635, 20.218567},{9.613025, 14.425566, 20.996189}}],
    
    Line[{{9.613025, 14.425566, 20.996189},{
      10.095741, 14.926288, 21.871809}}],
    Line[{{10.095741, 14.926288, 21.871809},{
      10.577000, 15.358553, 22.842007}}],
    Line[{{10.577000, 15.358553, 22.842007},{
      11.049553, 15.704146, 23.899696}}],
    Line[{{11.049553, 15.704146, 23.899696},{
      11.505081, 15.944587, 25.033546}}],
    Line[{{11.505081, 15.944587, 25.033546},{
      11.934330, 16.062273, 26.227591}}],
    Line[{{11.934330, 16.062273, 26.227591},{
      12.327352, 16.041729, 27.461195}}],
    Line[{{12.327352, 16.041729, 27.461195},{
      12.673824, 15.870983, 28.709297}}],
    Line[{{12.673824, 15.870983, 28.709297},{
      12.963498, 15.543058, 29.943178}}],
    Line[{{12.963498, 15.543058, 29.943178},{
      13.186725, 15.057051, 31.131847}}],
    Line[{{13.186725, 15.057051, 31.131847},{
      13.335022, 14.419053, 32.243645}}],
    Line[{{13.335022, 14.419053, 32.243645},{
      13.401643, 13.642354, 33.248310}}],
    Line[{{13.401643, 13.642354, 33.248310},{
      13.382079, 12.747046, 34.119015}}],
    Line[{{13.382079, 12.747046, 34.119015},{
      13.274455, 11.758893, 34.834301}}],
    Line[{{13.274455, 11.758893, 34.834301},{
      13.079730, 10.707601, 35.379482}}],
    Line[{{13.079730, 10.707601, 35.379482},{
      12.801705, 9.624717, 35.747433}}],
    Line[{{12.801705, 9.624717, 35.747433},{12.446822, 8.541412, 35.938641}}],
    
    Line[{{12.446822, 8.541412, 35.938641},{12.023771, 7.486470, 35.960526}}],
    
    Line[{{12.023771, 7.486470, 35.960526},{11.542974, 6.484610, 35.826241}}],
    
    Line[{{11.542974, 6.484610, 35.826241},{11.015970, 5.555438, 35.553082}}],
    
    Line[{{11.015970, 5.555438, 35.553082},{10.454796, 4.712961, 35.160816}}],
    
    Line[{{10.454796, 4.712961, 35.160816},{9.871408, 3.965668, 34.670097}}],
    Line[{{9.871408, 3.965668, 34.670097},{9.277184, 3.317035, 34.101124}}],
    Line[{{9.277184, 3.317035, 34.101124},{8.682540, 2.766320, 33.472641}}],
    Line[{{8.682540, 2.766320, 33.472641},{8.096661, 2.309479, 32.801323}}],
    Line[{{8.096661, 2.309479, 32.801323},{7.527352, 1.940120, 32.101418}}],
    Line[{{7.527352, 1.940120, 32.101418},{6.980990, 1.650356, 31.384706}}],
    Line[{{6.980990, 1.650356, 31.384706},{6.462552, 1.431547, 30.660620}}],
    Line[{{6.462552, 1.431547, 30.660620},{5.975705, 1.274883, 29.936476}}],
    Line[{{5.975705, 1.274883, 29.936476},{5.522942, 1.171817, 29.217798}}],
    Line[{{5.522942, 1.171817, 29.217798},{5.105727, 1.114371, 28.508614}}],
    Line[{{5.105727, 1.114371, 28.508614},{4.724663, 1.095316, 27.811769}}],
    Line[{{4.724663, 1.095316, 27.811769},{4.379648, 1.108273, 27.129196}}],
    Line[{{4.379648, 1.108273, 27.129196},{4.070025, 1.147747, 26.462143}}],
    Line[{{4.070025, 1.147747, 26.462143},{3.794719, 1.209108, 25.811361}}],
    Line[{{3.794719, 1.209108, 25.811361},{3.552355, 1.288546, 25.177265}}],
    Line[{{3.552355, 1.288546, 25.177265},{3.341366, 1.383002, 24.560028}}],
    Line[{{3.341366, 1.383002, 24.560028},{3.160074, 1.490103, 23.959692}}],
    Line[{{3.160074, 1.490103, 23.959692},{3.006767, 1.608079, 23.376215}}],
    Line[{{3.006767, 1.608079, 23.376215},{2.879752, 1.735686, 22.809523}}],
    Line[{{2.879752, 1.735686, 22.809523},{2.777403, 1.872146, 22.259541}}],
    Line[{{2.777403, 1.872146, 22.259541},{2.698193, 2.017075, 21.726221}}],
    Line[{{2.698193, 2.017075, 21.726221},{2.640722, 2.170429, 21.209558}}],
    Line[{{2.640722, 2.170429, 21.209558},{2.603732, 2.332459, 20.709600}}],
    Line[{{2.603732, 2.332459, 20.709600},{2.586122, 2.503663, 20.226461}}],
    Line[{{2.586122, 2.503663, 20.226461},{2.586953, 2.684758, 19.760334}}],
    Line[{{2.586953, 2.684758, 19.760334},{2.605455, 2.876647, 19.311502}}],
    Line[{{2.605455, 2.876647, 19.311502},{2.641023, 3.080395, 18.880344}}],
    Line[{{2.641023, 3.080395, 18.880344},{2.693219, 3.297210, 18.467360}}],
    Line[{{2.693219, 3.297210, 18.467360},{2.761768, 3.528430, 18.073172}}],
    Line[{{2.761768, 3.528430, 18.073172},{2.846554, 3.775502, 17.698559}}],
    Line[{{2.846554, 3.775502, 17.698559},{2.947614, 4.039974, 17.344465}}],
    Line[{{2.947614, 4.039974, 17.344465},{3.065134, 4.323483, 17.012033}}],
    Line[{{3.065134, 4.323483, 17.012033},{3.199441, 4.627735, 16.702629}}],
    Line[{{3.199441, 4.627735, 16.702629},{3.350996, 4.954491, 16.417877}}],
    Line[{{3.350996, 4.954491, 16.417877},{3.520387, 5.305546, 16.159697}}],
    Line[{{3.520387, 5.305546, 16.159697},{3.708316, 5.682698, 15.930342}}],
    Line[{{3.708316, 5.682698, 15.930342},{3.915587, 6.087710, 15.732448}}],
    Line[{{3.915587, 6.087710, 15.732448},{4.143094, 6.522260, 15.569078}}],
    Line[{{4.143094, 6.522260, 15.569078},{4.391798, 6.987882, 15.443781}}],
    Line[{{4.391798, 6.987882, 15.443781},{4.662701, 7.485868, 15.360625}}],
    Line[{{4.662701, 7.485868, 15.360625},{4.956824, 8.017191, 15.324274}}],
    Line[{{4.956824, 8.017191, 15.324274},{5.275155, 8.582331, 15.339983}}],
    Line[{{5.275155, 8.582331, 15.339983},{5.618610, 9.181158, 15.413689}}],
    Line[{{5.618610, 9.181158, 15.413689},{5.987962, 9.812699, 15.551936}}],
    Line[{{5.987962, 9.812699, 15.551936},{6.383773, 10.474924, 15.761929}}],
    Line[{{6.383773, 10.474924, 15.761929},{6.806294, 11.164469, 16.051386}}],
    
    Line[{{6.806294, 11.164469, 16.051386},{7.255354, 11.876327, 16.428431}}],
    
    Line[{{7.255354, 11.876327, 16.428431},{7.730233, 12.603525, 16.901379}}],
    
    Line[{{7.730233, 12.603525, 16.901379},{8.229506, 13.336826, 17.478306}}],
    
    Line[{{8.229506, 13.336826, 17.478306},{8.750873, 14.064303, 18.166740}}],
    
    Line[{{8.750873, 14.064303, 18.166740},{9.290993, 14.771277, 18.972841}}],
    
    Line[{{9.290993, 14.771277, 18.972841},{9.845300, 15.440074, 19.900774}}],
    
    Line[{{9.845300, 15.440074, 19.900774},{
      10.407831, 16.050097, 20.951706}}],
    Line[{{10.407831, 16.050097, 20.951706},{
      10.971115, 16.578281, 22.122791}}],
    Line[{{10.971115, 16.578281, 22.122791},{
      11.526096, 16.999720, 23.406137}}],
    Line[{{11.526096, 16.999720, 23.406137},{
      12.062170, 17.288857, 24.787819}}],
    Line[{{12.062170, 17.288857, 24.787819},{
      12.567337, 17.421024, 26.247202}}],
    Line[{{12.567337, 17.421024, 26.247202},{
      13.028511, 17.374435, 27.756666}}],
    Line[{{13.028511, 17.374435, 27.756666},{
      13.432011, 17.132410, 29.282049}}],
    Line[{{13.432011, 17.132410, 29.282049},{
      13.764206, 16.685595, 30.783846}}],
    Line[{{13.764206, 16.685595, 30.783846},{
      14.012307, 16.033869, 32.219265}}],
    Line[{{14.012307, 16.033869, 32.219265},{
      14.165232, 15.187570, 33.544983}}],
    Line[{{14.165232, 15.187570, 33.544983},{
      14.214456, 14.167743, 34.720406}}],
    Line[{{14.214456, 14.167743, 34.720406},{
      14.154752, 13.005166, 35.710938}}],
    Line[{{14.154752, 13.005166, 35.710938},{
      13.984712, 11.738272, 36.490784}}],
    Line[{{13.984712, 11.738272, 36.490784},{
      13.706967, 10.410098, 37.044891}}],
    Line[{{13.706967, 10.410098, 37.044891},{
      13.328079, 9.064802, 37.369644}}],
    Line[{{13.328079, 9.064802, 37.369644},{12.858097, 7.744193, 37.472324}}],
    
    Line[{{12.858097, 7.744193, 37.472324},{12.309860, 6.484819, 37.369469}}],
    
    Line[{{12.309860, 6.484819, 37.369469},{11.698121, 5.315917, 37.084476}}],
    
    Line[{{11.698121, 5.315917, 37.084476},{11.038611, 4.258406, 36.644901}}],
    
    Line[{{11.038611, 4.258406, 36.644901},{10.347151, 3.324840, 36.079845}}],
    
    Line[{{10.347151, 3.324840, 36.079845},{9.638872, 2.520155, 35.417763}}],
    Line[{{9.638872, 2.520155, 35.417763},{8.927616, 1.842917, 34.684803}}],
    Line[{{8.927616, 1.842917, 34.684803},{8.225525, 1.286824, 33.903809}}],
    Line[{{8.225525, 1.286824, 33.903809},{7.542807, 0.842198, 33.093842}}],
    Line[{{7.542807, 0.842198, 33.093842},{6.887674, 0.497354, 32.270161}}],
    Line[{{6.887674, 0.497354, 32.270161},{6.266392, 0.239718, 31.444473}}],
    Line[{{6.266392, 0.239718, 31.444473},{5.683426, 0.056692, 30.625414}}],
    Line[{{5.683426, 0.056692, 30.625414},{5.141644, -0.063734, 29.819046}}],
    Line[{{5.141644, -0.063734, 29.819046},{4.642540, -0.132598, 29.029404}}],
    
    Line[{{4.642540, -0.132598, 29.029404},{4.186474, -0.159741, 28.258951}}],
    
    Line[{{4.186474, -0.159741, 28.258951},{3.772897, -0.153725, 27.509020}}],
    
    Line[{{3.772897, -0.153725, 27.509020},{3.400557, -0.121835, 26.780123}}],
    
    Line[{{3.400557, -0.121835, 26.780123},{3.067690, -0.070147, 26.072239}}],
    
    Line[{{3.067690, -0.070147, 26.072239},{2.772175, -0.003626, 25.384996}}],
    
    Line[{{2.772175, -0.003626, 25.384996},{2.511669, 0.073753, 24.717823}}],
    Line[{{2.511669, 0.073753, 24.717823},{2.283716, 0.158887, 24.070053}}],
    Line[{{2.283716, 0.158887, 24.070053},{2.085837, 0.249418, 23.440983}}],
    Line[{{2.085837, 0.249418, 23.440983},{1.915596, 0.343626, 22.829924}}],
    Line[{{1.915596, 0.343626, 22.829924},{1.770651, 0.440325, 22.236221}}],
    Line[{{1.770651, 0.440325, 22.236221},{1.648793, 0.538771, 21.659277}}],
    Line[{{1.648793, 0.538771, 21.659277},{1.547969, 0.638588, 21.098541}}],
    Line[{{1.547969, 0.638588, 21.098541},{1.466303, 0.739703, 20.553528}}],
    Line[{{1.466303, 0.739703, 20.553528},{1.402101, 0.842283, 20.023802}}],
    Line[{{1.402101, 0.842283, 20.023802},{1.353857, 0.946699, 19.508987}}],
    Line[{{1.353857, 0.946699, 19.508987},{1.320252, 1.053484, 19.008753}}],
    Line[{{1.320252, 1.053484, 19.008753},{1.300149, 1.163308, 18.522820}}],
    Line[{{1.300149, 1.163308, 18.522820},{1.292590, 1.276954, 18.050953}}],
    Line[{{1.292590, 1.276954, 18.050953},{1.296787, 1.395302, 17.592966}}],
    Line[{{1.296787, 1.395302, 17.592966},{1.312114, 1.519323, 17.148722}}],
    Line[{{1.312114, 1.519323, 17.148722},{1.338102, 1.650067, 16.718130}}],
    Line[{{1.338102, 1.650067, 16.718130},{1.374430, 1.788664, 16.301161}}],
    Line[{{1.374430, 1.788664, 16.301161},{1.420920, 1.936323, 15.897841}}],
    Line[{{1.420920, 1.936323, 15.897841},{1.477529, 2.094337, 15.508269}}],
    Line[{{1.477529, 2.094337, 15.508269},{1.544345, 2.264082, 15.132619}}],
    Line[{{1.544345, 2.264082, 15.132619},{1.621583, 2.447030, 14.771158}}],
    Line[{{1.621583, 2.447030, 14.771158},{1.709584, 2.644754, 14.424258}}],
    Line[{{1.709584, 2.644754, 14.424258},{1.808810, 2.858933, 14.092413}}],
    Line[{{1.808810, 2.858933, 14.092413},{1.919845, 3.091362, 13.776263}}],
    Line[{{1.919845, 3.091362, 13.776263},{2.043392, 3.343962, 13.476617}}],
    Line[{{2.043392, 3.343962, 13.476617},{2.180280, 3.618780, 13.194486}}],
    Line[{{2.180280, 3.618780, 13.194486},{2.331458, 3.917996, 12.931114}}],
    Line[{{2.331458, 3.917996, 12.931114},{2.497998, 4.243924, 12.688027}}],
    Line[{{2.497998, 4.243924, 12.688027},{2.681098, 4.599005, 12.467077}}],
    Line[{{2.681098, 4.599005, 12.467077},{2.882078, 4.985792, 12.270499}}],
    Line[{{2.882078, 4.985792, 12.270499},{3.102383, 5.406937, 12.100981}}],
    Line[{{3.102383, 5.406937, 12.100981},{3.343575, 5.865146, 11.961738}}],
    Line[{{3.343575, 5.865146, 11.961738},{3.607322, 6.363130, 11.856595}}],
    Line[{{3.607322, 6.363130, 11.856595},{3.895394, 6.903534, 11.790084}}],
    Line[{{3.895394, 6.903534, 11.790084},{4.209634, 7.488833, 11.767546}}],
    Line[{{4.209634, 7.488833, 11.767546},{4.551930, 8.121179, 11.795233}}],
    Line[{{4.551930, 8.121179, 11.795233},{4.924180, 8.802245, 11.880423}}],
    Line[{{4.924180, 8.802245, 11.880423},{5.328214, 9.532940, 12.031496}}],
    Line[{{5.328214, 9.532940, 12.031496},{5.765740, 10.313149, 12.258038}}],
    Line[{{5.765740, 10.313149, 12.258038},{6.238219, 11.141315, 12.570842}}],
    
    Line[{{6.238219, 11.141315, 12.570842},{6.746736, 12.013977, 12.981863}}],
    
    Line[{{6.746736, 12.013977, 12.981863},{7.291838, 12.925241, 13.504142}}],
    
    Line[{{7.291838, 12.925241, 13.504142},{7.873306, 13.866114, 14.151394}}],
    
    Line[{{7.873306, 13.866114, 14.151394},{8.489913, 14.823856, 14.937605}}],
    
    Line[{{8.489913, 14.823856, 14.937605},{9.139128, 15.781278, 15.876245}}],
    
    Line[{{9.139128, 15.781278, 15.876245},{9.816780, 16.716137, 16.979164}}],
    
    Line[{{9.816780, 16.716137, 16.979164},{
      10.516727, 17.600790, 18.255152}}],
    Line[{{10.516727, 17.600790, 18.255152},{
      11.230502, 18.402069, 19.708185}}],
    Line[{{11.230502, 18.402069, 19.708185},{
      11.947050, 19.081942, 21.335285}}],
    Line[{{11.947050, 19.081942, 21.335285},{
      12.652560, 19.598764, 23.124344}}],
    Line[{{12.652560, 19.598764, 23.124344},{
      13.330485, 19.909630, 25.052080}}],
    Line[{{13.330485, 19.909630, 25.052080},{
      13.961842, 19.973669, 27.082615}}],
    Line[{{13.961842, 19.973669, 27.082615},{
      14.525826, 19.756275, 29.167130}}],
    Line[{{14.525826, 19.756275, 29.167130},{
      15.000818, 19.233799, 31.245146}}],
    Line[{{15.000818, 19.233799, 31.245146},{
      15.365717, 18.398090, 33.247650}}],
    Line[{{15.365717, 18.398090, 33.247650},{
      15.601549, 17.259884, 35.102234}}],
    Line[{{15.601549, 17.259884, 35.102234},{
      15.693151, 15.850190, 36.739590}}],
    Line[{{15.693151, 15.850190, 36.739590},{
      15.630696, 14.219066, 38.100433}}],
    Line[{{15.630696, 14.219066, 38.100433},{
      15.410822, 12.431537, 39.141701}}],
    Line[{{15.410822, 12.431537, 39.141701},{
      15.037151, 10.561325, 39.840694}}],
    Line[{{15.037151, 10.561325, 39.840694},{
      14.520102, 8.683395, 40.196426}}],
    Line[{{14.520102, 8.683395, 40.196426},{13.875994, 6.866810, 40.227970}}],
    
    Line[{{13.875994, 6.866810, 40.227970},{13.125647, 5.168962, 39.970436}}],
    
    Line[{{13.125647, 5.168962, 39.970436},{12.292642, 3.632094, 39.469425}}],
    
    Line[{{12.292642, 3.632094, 39.469425},{11.401554, 2.282276, 38.775253}}],
    
    Line[{{11.401554, 2.282276, 38.775253},{10.476354, 1.130434, 37.937828}}],
    
    Line[{{10.476354, 1.130434, 37.937828},{9.539133, 0.174822, 37.002815}}],
    Line[{{9.539133, 0.174822, 37.002815},{8.609230, -0.595827, 36.009289}}],
    Line[{{8.609230, -0.595827, 36.009289},{7.702738, -1.199075, 34.988728}}],
    
    Line[{{7.702738, -1.199075, 34.988728},{6.832363, -1.655924, 33.965073}}],
    
    Line[{{6.832363, -1.655924, 33.965073},{6.007530, -1.988549, 32.955456}}],
    
    Line[{{6.007530, -1.988549, 32.955456},{5.234668, -2.218642, 31.971300}}],
    
    Line[{{5.234668, -2.218642, 31.971300},{4.517599, -2.366371, 31.019518}}],
    
    Line[{{4.517599, -2.366371, 31.019518},{3.857960, -2.449776, 30.103653}}],
    
    Line[{{3.857960, -2.449776, 30.103653},{3.255632, -2.484519, 29.224859}}],
    
    Line[{{3.255632, -2.484519, 29.224859},{2.709130, -2.483881, 28.382706}}],
    
    Line[{{2.709130, -2.483881, 28.382706},{2.215957, -2.458899, 27.575787}}],
    
    Line[{{2.215957, -2.458899, 27.575787},{1.772903, -2.418586, 26.802166}}],
    
    Line[{{1.772903, -2.418586, 26.802166},{1.376295, -2.370191, 26.059698}}],
    
    Line[{{1.376295, -2.370191, 26.059698},{1.022191, -2.319451, 25.346222}}],
    
    Line[{{1.022191, -2.319451, 25.346222},{0.706545, -2.270845, 24.659687}}],
    
    Line[{{0.706545, -2.270845, 24.659687},{0.425320, -2.227820, 23.998228}}],
    
    Line[{{0.425320, -2.227820, 23.998228},{0.174575, -2.192990, 23.360188}}],
    
    Line[{{
      0.174575, -2.192990, 23.360188},{-0.049469, -2.168312, 22.744125}}],
    Line[{{-0.049469, -2.168312, 22.744125},{-0.250393, -2.155231, 
        22.148815}}],
    Line[{{-0.250393, -2.155231, 22.148815},{-0.431555, -2.154809, 
        21.573217}}],
    Line[{{-0.431555, -2.154809, 21.573217},{-0.596081, -2.167830, 
        21.016468}}],
    Line[{{-0.596081, -2.167830, 21.016468},{-0.746862, -2.194884, 
        20.477861}}],
    Line[{{-0.746862, -2.194884, 20.477861},{-0.886567, -2.236442, 
        19.956827}}],
    Line[{{-0.886567, -2.236442, 19.956827},{-1.017649, -2.292913, 
        19.452921}}],
    Line[{{-1.017649, -2.292913, 19.452921},{-1.142367, -2.364689, 
        18.965815}}],
    Line[{{-1.142367, -2.364689, 18.965815},{-1.262804, -2.452188, 
        18.495287}}],
    Line[{{-1.262804, -2.452188, 18.495287},{-1.380886, -2.555886, 
        18.041218}}],
    Line[{{-1.380886, -2.555886, 18.041218},{-1.498404, -2.676332, 
        17.603601}}],
    Line[{{-1.498404, -2.676332, 17.603601},{-1.617038, -2.814181, 
        17.182529}}],
    Line[{{-1.617038, -2.814181, 17.182529},{-1.738372, -2.970199, 
        16.778221}}],
    Line[{{-1.738372, -2.970199, 16.778221},{-1.863923, -3.145283, 
        16.391014}}],
    Line[{{-1.863923, -3.145283, 16.391014},{-1.995151, -3.340463, 
        16.021395}}],
    Line[{{-1.995151, -3.340463, 16.021395},{-2.133484, -3.556913, 
        15.670007}}],
    Line[{{-2.133484, -3.556913, 15.670007},{-2.280334, -3.795951, 
        15.337675}}],
    Line[{{-2.280334, -3.795951, 15.337675},{-2.437108, -4.059042, 
        15.025438}}],
    Line[{{-2.437108, -4.059042, 15.025438},{-2.605229, -4.347791, 
        14.734576}}],
    Line[{{-2.605229, -4.347791, 14.734576},{-2.786142, -4.663935, 
        14.466650}}],
    Line[{{-2.786142, -4.663935, 14.466650},{-2.981324, -5.009328, 
        14.223548}}],
    Line[{{-2.981324, -5.009328, 14.223548},{-3.192296, -5.385922, 
        14.007527}}],
    Line[{{-3.192296, -5.385922, 14.007527},{-3.420621, -5.795726, 
        13.821285}}],
    Line[{{-3.420621, -5.795726, 13.821285},{-3.667906, -6.240761, 
        13.668013}}],
    Line[{{-3.667906, -6.240761, 13.668013},{-3.935796, -6.723008, 
        13.551464}}],
    Line[{{-3.935796, -6.723008, 13.551464},{-4.225963, -7.244311, 
        13.476037}}],
    Line[{{-4.225963, -7.244311, 13.476037},{-4.540080, -7.806256, 
        13.446848}}],
    Line[{{-4.540080, -7.806256, 13.446848},{-4.879801, -8.410060, 
        13.469800}}],
    Line[{{-4.879801, -8.410060, 13.469800},{-5.246711, -9.056359, 
        13.551661}}],
    Line[{{-5.246711, -9.056359, 13.551661},{-5.642259, -9.744963, 
        13.700096}}],
    Line[{{-5.642259, -9.744963, 13.700096},{-6.067699, -10.474623, 
        13.923706}}],
    Line[{{-6.067699, -10.474623, 13.923706},{-6.523980, -11.242653, 
        14.231988}}],
    Line[{{-6.523980, -11.242653, 14.231988},{-7.011605, -12.044502, 
        14.635199}}],
    Line[{{-7.011605, -12.044502, 14.635199},{-7.530512, -12.873386, 
        15.144228}}],
    Line[{{-7.530512, -12.873386, 15.144228},{-8.079851, -13.719702, 
        15.770164}}],
    Line[{{-8.079851, -13.719702, 15.770164},{-8.657793, -14.570585, 
        16.523830}}],
    Line[{{-8.657793, -14.570585, 16.523830},{-9.261277, -15.409435, 
        17.415037}}],
    Line[{{-9.261277, -15.409435, 17.415037},{-9.885759, -16.215588, 
        18.451584}}],
    Line[{{-9.885759, -16.215588, 18.451584},{-10.524963, -16.964203, 
        19.638067}}],
    Line[{{-10.524963, -16.964203, 19.638067},{-11.170645, -17.626448, 
        20.974445}}],
    Line[{{-11.170645, -17.626448, 20.974445},{-11.812440, -18.170309, 
        22.454378}}],
    Line[{{-11.812440, -18.170309, 22.454378},{-12.437819, -18.561863, 
        24.063753}}],
    Line[{{-12.437819, -18.561863, 24.063753},{-13.032205, -18.767344, 
        25.779356}}],
    Line[{{-13.032205, -18.767344, 25.779356},{-13.579307, -18.755848, 
        27.568169}}],
    Line[{{-13.579307, -18.755848, 27.568169},{-14.061714, -18.502596, 
        29.387568}}],
    Line[{{-14.061714, -18.502596, 29.387568},{-14.461748, -17.992321, 
        31.186729}}],
    Line[{{-14.461748, -17.992321, 31.186729},{-14.762546, -17.222351, 
        32.909393}}],
    Line[{{-14.762546, -17.222351, 32.909393},{-14.949295, -16.204742, 
        34.497841}}],
    Line[{{-14.949295, -16.204742, 34.497841},{-15.010489, -14.966831, 
        35.897781}}],
    Line[{{-15.010489, -14.966831, 35.897781},{-14.939009, -13.549973, 
        37.063286}}],
    Line[{{-14.939009, -13.549973, 37.063286},{-14.732908, -12.006358, 
        37.961090}}],
    Line[{{-14.732908, -12.006358, 37.961090},{-14.395732, -10.394371, 
        38.573406}}],
    Line[{{-14.395732, -10.394371, 38.573406},{-13.936327, -8.773257, 
        38.898788}}],
    Line[{{-13.936327, -8.773257, 38.898788},{-13.368171, -7.197942, 
        38.951027}}],
    Line[{{-13.368171, -7.197942, 38.951027},{-12.708301, -5.714839, 
        38.756237}}],
    Line[{{-12.708301, -5.714839, 38.756237},{-11.976019, -4.359243, 
        38.349010}}],
    Line[{{-11.976019, -4.359243, 38.349010},{-11.191567, -3.154301, 
        37.768284}}],
    Line[{{-11.191567, -3.154301, 37.768284},{-10.374895, -2.111510, 
        37.053528}}],
    Line[{{-10.374895, -2.111510, 37.053528},{-9.544639, -1.232292, 
        36.241791}}],
    Line[{{-9.544639, -1.232292, 36.241791},{-8.717400, -0.510158, 
        35.365715}}],
    Line[{{-8.717400, -0.510158, 35.365715},{-7.907291, 0.066969, 
        34.452511}}],
    Line[{{-7.907291, 0.066969, 34.452511},{-7.125753, 0.514585, 33.523739}}],
    
    Line[{{-7.125753, 0.514585, 33.523739},{-6.381571, 0.849787, 32.595646}}],
    
    Line[{{-6.381571, 0.849787, 32.595646},{-5.681048, 1.089893, 31.679834}}],
    
    Line[{{-5.681048, 1.089893, 31.679834},{-5.028271, 1.251457, 30.784079}}],
    
    Line[{{-5.028271, 1.251457, 30.784079},{-4.425421, 1.349665, 29.913160}}],
    
    Line[{{-4.425421, 1.349665, 29.913160},{-3.873112, 1.398006, 29.069626}}],
    
    Line[{{-3.873112, 1.398006, 29.069626},{-3.370699, 1.408155, 28.254431}}],
    
    Line[{{-3.370699, 1.408155, 28.254431},{-2.916576, 1.390002, 27.467459}}],
    
    Line[{{-2.916576, 1.390002, 27.467459},{-2.508431, 1.351761, 26.707918}}],
    
    Line[{{-2.508431, 1.351761, 26.707918},{-2.143465, 1.300138, 25.974636}}],
    
    Line[{{-2.143465, 1.300138, 25.974636},{-1.818571, 1.240512, 25.266256}}],
    
    Line[{{-1.818571, 1.240512, 25.266256},{-1.530483, 1.177127, 24.581379}}],
    
    Line[{{-1.530483, 1.177127, 24.581379},{-1.275892, 1.113265, 23.918642}}],
    
    Line[{{-1.275892, 1.113265, 23.918642},{-1.051528, 1.051413, 23.276772}}],
    
    Line[{{-1.051528, 1.051413, 23.276772},{-0.854231, 0.993411, 22.654608}}],
    
    Line[{{-0.854231, 0.993411, 22.654608},{-0.680990, 0.940574, 22.051104}}],
    
    Line[{{-0.680990, 0.940574, 22.051104},{-0.528976, 0.893810, 21.465328}}],
    
    Line[{{-0.528976, 0.893810, 21.465328},{-0.395562, 0.853707, 20.896456}}],
    
    Line[{{-0.395562, 0.853707, 20.896456},{-0.278324, 0.820614, 20.343756}}],
    
    Line[{{-0.278324, 0.820614, 20.343756},{-0.175047, 0.794705, 19.806574}}],
    
    Line[{{-0.175047, 0.794705, 19.806574},{-0.083715, 0.776033, 19.284334}}],
    
    Line[{{-0.083715, 0.776033, 19.284334},{-0.002503, 0.764571, 18.776510}}],
    
    Line[{{-0.002503, 0.764571, 18.776510},{0.070235, 0.760251, 18.282631}}],
    Line[{{0.070235, 0.760251, 18.282631},{0.135982, 0.762988, 17.802269}}],
    Line[{{0.135982, 0.762988, 17.802269},{0.196070, 0.772704, 17.335032}}],
    Line[{{0.196070, 0.772704, 17.335032},{0.251700, 0.789346, 16.880558}}],
    Line[{{0.251700, 0.789346, 16.880558},{0.303953, 0.812899, 16.438513}}],
    Line[{{0.303953, 0.812899, 16.438513},{0.353810, 0.843397, 16.008593}}],
    Line[{{0.353810, 0.843397, 16.008593},{0.402165, 0.880933, 15.590515}}],
    Line[{{0.402165, 0.880933, 15.590515},{0.449836, 0.925664, 15.184020}}],
    Line[{{0.449836, 0.925664, 15.184020},{0.497584, 0.977820, 14.788874}}],
    Line[{{0.497584, 0.977820, 14.788874},{0.546124, 1.037707, 14.404867}}],
    Line[{{0.546124, 1.037707, 14.404867},{0.596132, 1.105715, 14.031816}}],
    Line[{{0.596132, 1.105715, 14.031816},{0.648266, 1.182319, 13.669567}}],
    Line[{{0.648266, 1.182319, 13.669567},{0.703167, 1.268089, 13.317996}}],
    Line[{{0.703167, 1.268089, 13.317996},{0.761476, 1.363693, 12.977016}}],
    Line[{{0.761476, 1.363693, 12.977016},{0.823841, 1.469904, 12.646582}}],
    Line[{{0.823841, 1.469904, 12.646582},{0.890927, 1.587607, 12.326695}}],
    Line[{{0.890927, 1.587607, 12.326695},{0.963427, 1.717808, 12.017414}}],
    Line[{{0.963427, 1.717808, 12.017414},{1.042068, 1.861640, 11.718859}}],
    Line[{{1.042068, 1.861640, 11.718859},{1.127624, 2.020375, 11.431229}}],
    Line[{{1.127624, 2.020375, 11.431229},{1.220922, 2.195432, 11.154816}}],
    Line[{{1.220922, 2.195432, 11.154816},{1.322854, 2.388390, 10.890014}}],
    Line[{{1.322854, 2.388390, 10.890014},{1.434385, 2.600997, 10.637353}}],
    Line[{{1.434385, 2.600997, 10.637353},{1.556564, 2.835183, 10.397513}}],
    Line[{{1.556564, 2.835183, 10.397513},{1.690532, 3.093071, 10.171359}}],
    Line[{{1.690532, 3.093071, 10.171359},{1.837533, 3.376983, 9.959980}}],
    Line[{{1.837533, 3.376983, 9.959980},{1.998925, 3.689452, 9.764731}}],
    Line[{{1.998925, 3.689452, 9.764731},{2.176187, 4.033228, 9.587276}}],
    Line[{{2.176187, 4.033228, 9.587276},{2.370929, 4.411268, 9.429680}}],
    Line[{{2.370929, 4.411268, 9.429680},{2.584902, 4.826746, 9.294433}}],
    Line[{{2.584902, 4.826746, 9.294433},{2.819996, 5.282999, 9.184613}}],
    Line[{{2.819996, 5.282999, 9.184613},{3.078254, 5.783549, 9.103892}}],
    Line[{{3.078254, 5.783549, 9.103892},{3.361859, 6.331981, 9.056753}}],
    Line[{{3.361859, 6.331981, 9.056753},{3.673130, 6.931901, 9.048564}}],
    Line[{{3.673130, 6.931901, 9.048564},{4.014506, 7.586811, 9.085738}}],
    Line[{{4.014506, 7.586811, 9.085738},{4.388514, 8.299928, 9.175917}}],
    Line[{{4.388514, 8.299928, 9.175917},{4.797719, 9.073925, 9.328125}}],
    Line[{{4.797719, 9.073925, 9.328125},{5.244671, 9.910686, 9.552938}}],
    Line[{{5.244671, 9.910686, 9.552938},{5.731787, 10.810797, 9.862638}}],
    Line[{{5.731787, 10.810797, 9.862638},{6.261235, 11.773082, 10.271297}}],
    Line[{{6.261235, 11.773082, 10.271297},{6.834748, 12.793899, 10.794785}}],
    
    Line[{{6.834748, 12.793899, 10.794785},{7.453400, 13.866333, 11.450640}}],
    
    Line[{{7.453400, 13.866333, 11.450640},{8.117303, 14.979241, 12.257681}}],
    
    Line[{{8.117303, 14.979241, 12.257681},{8.825258, 16.116203, 13.235373}}],
    
    Line[{{8.825258, 16.116203, 13.235373},{9.574312, 17.254406, 14.402693}}],
    
    Line[{{9.574312, 17.254406, 14.402693},{
      10.359273, 18.363672, 15.776525}}],
    Line[{{10.359273, 18.363672, 15.776525},{
      11.172186, 19.405771, 17.369446}}],
    Line[{{11.172186, 19.405771, 17.369446},{
      12.001820, 20.334362, 19.186865}}],
    Line[{{12.001820, 20.334362, 19.186865},{
      12.833240, 21.095894, 21.223709}}],
    Line[{{12.833240, 21.095894, 21.223709},{
      13.647572, 21.631874, 23.460897}}],
    Line[{{13.647572, 21.631874, 23.460897},{
      14.422085, 21.882851, 25.862206}}],
    Line[{{14.422085, 21.882851, 25.862206},{
      15.130733, 21.794092, 28.372332}}],
    Line[{{15.130733, 21.794092, 28.372332},{
      15.745257, 21.322666, 30.917095}}],
    Line[{{15.745257, 21.322666, 30.917095},{
      16.236864, 20.444984, 33.406532}}],
    Line[{{16.236864, 20.444984, 33.406532},{
      16.578480, 19.163473, 35.741459}}],
    Line[{{16.578480, 19.163473, 35.741459},{
      16.747265, 17.510452, 37.822971}}],
    Line[{{16.747265, 17.510452, 37.822971},{
      16.727095, 15.547989, 39.563484}}],
    Line[{{16.727095, 15.547989, 39.563484},{
      16.510530, 13.362777, 40.897327}}],
    Line[{{16.510530, 13.362777, 40.897327},{
      16.099928, 11.056872, 41.788406}}],
    Line[{{16.099928, 11.056872, 41.788406},{
      15.507396, 8.735911, 42.233269}}],
    Line[{{15.507396, 8.735911, 42.233269},{14.753641, 6.497353, 42.259018}}],
    
    Line[{{14.753641, 6.497353, 42.259018},{13.865881, 4.421103, 41.916840}}],
    
    Line[{{13.865881, 4.421103, 41.916840},{12.875259, 2.563993, 41.273075}}],
    
    Line[{{12.875259, 2.563993, 41.273075},{11.814181, 0.958468, 40.399826}}],
    
    Line[{{11.814181, 0.958468, 40.399826},{
      10.713951, -0.385246, 39.366959}}],
    Line[{{10.713951, -0.385246, 39.366959},{
      9.602963, -1.474756, 38.236435}}],
    Line[{{9.602963, -1.474756, 38.236435},{8.505539, -2.330241, 37.059216}}],
    
    Line[{{8.505539, -2.330241, 37.059216},{7.441360, -2.979397, 35.874386}}],
    
    Line[{{7.441360, -2.979397, 35.874386},{6.425411, -3.453216, 34.709843}}],
    
    Line[{{6.425411, -3.453216, 34.709843},{5.468276, -3.782860, 33.583900}}],
    
    Line[{{5.468276, -3.782860, 33.583900},{4.576639, -3.997602, 32.507263}}],
    
    Line[{{4.576639, -3.997602, 32.507263},{3.753908, -4.123671, 31.484976}}],
    
    Line[{{3.753908, -4.123671, 31.484976},{3.000837, -4.183747, 30.518126}}],
    
    Line[{{3.000837, -4.183747, 30.518126},{2.316126, -4.196912, 29.605265}}],
    
    Line[{{2.316126, -4.196912, 29.605265},{1.696949, -4.178876, 28.743443}}],
    
    Line[{{1.696949, -4.178876, 28.743443},{1.139402, -4.142332, 27.928999}}],
    
    Line[{{1.139402, -4.142332, 27.928999},{0.638873, -4.097378, 27.158054}}],
    
    Line[{{0.638873, -4.097378, 27.158054},{0.190337, -4.051933, 26.426857}}],
    
    Line[{{
      0.190337, -4.051933, 26.426857},{-0.211415, -4.012121, 25.731974}}],
    Line[{{-0.211415, -4.012121, 25.731974},{-0.571610, -3.982623, 
        25.070381}}],
    Line[{{-0.571610, -3.982623, 25.070381},{-0.895363, -3.966968, 
        24.439507}}],
    Line[{{-0.895363, -3.966968, 24.439507},{-1.187593, -3.967792, 
        23.837219}}],
    Line[{{-1.187593, -3.967792, 23.837219},{-1.452968, -3.987042, 
        23.261810}}],
    Line[{{-1.452968, -3.987042, 23.261810},{-1.695870, -4.026154, 
        22.711958}}],
    Line[{{-1.695870, -4.026154, 22.711958},{-1.920382, -4.086190, 
        22.186686}}],
    Line[{{-1.920382, -4.086190, 22.186686},{-2.130286, -4.167954, 
        21.685335}}],
    Line[{{-2.130286, -4.167954, 21.685335},{-2.329072, -4.272081, 
        21.207537}}],
    Line[{{-2.329072, -4.272081, 21.207537},{-2.519953, -4.399106, 
        20.753180}}],
    Line[{{-2.519953, -4.399106, 20.753180},{-2.705884, -4.549520, 
        20.322411}}],
    Line[{{-2.705884, -4.549520, 20.322411},{-2.889587, -4.723805, 
        19.915613}}],
    Line[{{-2.889587, -4.723805, 19.915613},{-3.073568, -4.922464, 
        19.533411}}],
    Line[{{-3.073568, -4.922464, 19.533411},{-3.260147, -5.146036, 
        19.176680}}],
    Line[{{-3.260147, -5.146036, 19.176680},{-3.451474, -5.395096, 
        18.846542}}],
    Line[{{-3.451474, -5.395096, 18.846542},{-3.649554, -5.670252, 
        18.544401}}],
    Line[{{-3.649554, -5.670252, 18.544401},{-3.856258, -5.972132, 
        18.271942}}],
    Line[{{-3.856258, -5.972132, 18.271942},{-4.073337, -6.301351, 
        18.031170}}],
    Line[{{-4.073337, -6.301351, 18.031170},{-4.302434, -6.658477, 
        17.824425}}],
    Line[{{-4.302434, -6.658477, 17.824425},{-4.545086, -7.043984, 
        17.654415}}],
    Line[{{-4.545086, -7.043984, 17.654415},{-4.802720, -7.458176, 
        17.524237}}],
    Line[{{-4.802720, -7.458176, 17.524237},{-5.076644, -7.901116, 
        17.437397}}],
    Line[{{-5.076644, -7.901116, 17.437397},{-5.368036, -8.372531, 
        17.397835}}],
    Line[{{-5.368036, -8.372531, 17.397835},{-5.677911, -8.871681, 
        17.409916}}],
    Line[{{-5.677911, -8.871681, 17.409916},{-6.007089, -9.397227, 
        17.478424}}],
    Line[{{-6.007089, -9.397227, 17.478424},{-6.356152, -9.947079, 
        17.608526}}],
    Line[{{-6.356152, -9.947079, 17.608526},{-6.725383, -10.518208, 
        17.805704}}],
    Line[{{-6.725383, -10.518208, 17.805704},{-7.114695, -11.106450, 
        18.075621}}],
    Line[{{-7.114695, -11.106450, 18.075621},{-7.523551, -11.706305, 
        18.423992}}],
    Line[{{-7.523551, -11.706305, 18.423992},{-7.950869, -12.310740, 
        18.856316}}],
    Line[{{-7.950869, -12.310740, 18.856316},{-8.394918, -12.911007, 
        19.377573}}],
    Line[{{-8.394918, -12.911007, 19.377573},{-8.853211, -13.496483, 
        19.991852}}],
    Line[{{-8.853211, -13.496483, 19.991852},{-9.322397, -14.054667, 
        20.701822}}],
    Line[{{-9.322397, -14.054667, 20.701822},{-9.798159, -14.571162, 
        21.508223}}],
    Line[{{-9.798159, -14.571162, 21.508223},{-10.275132, -15.029912, 
        22.409187}}],
    Line[{{-10.275132, -15.029912, 22.409187},{-10.746894, -15.413684, 
        23.399673}}],
    Line[{{-10.746894, -15.413684, 23.399673},{-11.205924, -15.704538, 
        24.470778}}],
    Line[{{-11.205924, -15.704538, 24.470778},{-11.643739, -15.884896, 
        25.609354}}],
    Line[{{-11.643739, -15.884896, 25.609354},{-12.051040, -15.938541, 
        26.797747}}],
    Line[{{-12.051040, -15.938541, 26.797747},{-12.417989, -15.851956, 
        28.013863}}],
    Line[{{-12.417989, -15.851956, 28.013863},{-12.734584, -15.615659, 
        29.231678}}],
    Line[{{-12.734584, -15.615659, 29.231678},{-12.991125, -15.225475, 
        30.422247}}],
    Line[{{-12.991125, -15.225475, 30.422247},{-13.178726, -14.683506, 
        31.555063}}],
    Line[{{-13.178726, -14.683506, 31.555063},{-13.289888, -13.998785, 
        32.599876}}],
    Line[{{-13.289888, -13.998785, 32.599876},{-13.319013, -13.187092, 
        33.528660}}],
    Line[{{-13.319013, -13.187092, 33.528660},{-13.262836, -12.270351, 
        34.317528}}],
    Line[{{-13.262836, -12.270351, 34.317528},{-13.120744, -11.275257, 
        34.948376}}],
    Line[{{-13.120744, -11.275257, 34.948376},{-12.894872, -10.231470, 
        35.409992}}],
    Line[{{-12.894872, -10.231470, 35.409992},{-12.590040, -9.169526, 
        35.698517}}],
    Line[{{-12.590040, -9.169526, 35.698517},{-12.213472, -8.118777, 
        35.817204}}],
    Line[{{-12.213472, -8.118777, 35.817204},{-11.774366, -7.105586, 
        35.775528}}],
    Line[{{-11.774366, -7.105586, 35.775528},{-11.283349, -6.151958, 
        35.587898}}],
    Line[{{-11.283349, -6.151958, 35.587898},{-10.751889, -5.274761, 
        35.272072}}],
    Line[{{-10.751889, -5.274761, 35.272072},{-10.191710, -4.485478, 
        34.847580}}],
    Line[{{-10.191710, -4.485478, 34.847580},{-9.614254, -3.790449, 
        34.334297}}],
    Line[{{-9.614254, -3.790449, 34.334297},{-9.030257, -3.191473, 
        33.751286}}],
    Line[{{-9.030257, -3.191473, 33.751286},{-8.449417, -2.686624, 
        33.115986}}],
    Line[{{-8.449417, -2.686624, 33.115986},{-7.880179, -2.271138, 
        32.443699}}],
    Line[{{-7.880179, -2.271138, 32.443699},{-7.329631, -1.938299, 
        31.747389}}],
    Line[{{-7.329631, -1.938299, 31.747389},{-6.803484, -1.680217, 
        31.037674}}],
    Line[{{-6.803484, -1.680217, 31.037674},{-6.306126, -1.488479, 
        30.323008}}],
    Line[{{-6.306126, -1.488479, 30.323008},{-5.840722, -1.354663, 
        29.609919}}],
    Line[{{-5.840722, -1.354663, 29.609919},{-5.409350, -1.270702, 
        28.903305}}],
    Line[{{-5.409350, -1.270702, 28.903305},{-5.013149, -1.229143, 
        28.206739}}],
    Line[{{-5.013149, -1.229143, 28.206739},{-4.652477, -1.223289, 
        27.522736}}],
    Line[{{-4.652477, -1.223289, 27.522736},{-4.327061, -1.247274, 
        26.853008}}],
    Line[{{-4.327061, -1.247274, 26.853008},{-4.036134, -1.296079, 
        26.198673}}],
    Line[{{-4.036134, -1.296079, 26.198673},{-3.778569, -1.365505, 
        25.560410}}],
    Line[{{-3.778569, -1.365505, 25.560410},{-3.552979, -1.452127, 
        24.938606}}],
    Line[{{-3.552979, -1.452127, 24.938606},{-3.357823, -1.553227, 
        24.333454}}],
    Line[{{-3.357823, -1.553227, 24.333454},{-3.191476, -1.666721, 
        23.745022}}],
    Line[{{-3.191476, -1.666721, 23.745022},{-3.052297, -1.791090, 
        23.173319}}],
    Line[{{-3.052297, -1.791090, 23.173319},{-2.938684, -1.925308, 
        22.618332}}],
    Line[{{-2.938684, -1.925308, 22.618332},{-2.849108, -2.068779, 
        22.080057}}],
    Line[{{-2.849108, -2.068779, 22.080057},{-2.782148, -2.221275, 
        21.558521}}],
    Line[{{-2.782148, -2.221275, 21.558521},{-2.736514, -2.382887, 
        21.053799}}],
    Line[{{-2.736514, -2.382887, 21.053799},{-2.711059, -2.553982, 
        20.566025}}],
    Line[{{-2.711059, -2.553982, 20.566025},{-2.704791, -2.735159, 
        20.095411}}],
    Line[{{-2.704791, -2.735159, 20.095411},{-2.716883, -2.927221, 
        19.642252}}],
    Line[{{-2.716883, -2.927221, 19.642252},{-2.746669, -3.131148, 
        19.206944}}],
    Line[{{-2.746669, -3.131148, 19.206944},{-2.793647, -3.348074, 
        18.789991}}],
    Line[{{-2.793647, -3.348074, 18.789991},{-2.857479, -3.579266, 
        18.392031}}],
    Line[{{-2.857479, -3.579266, 18.392031},{-2.937985, -3.826108, 
        18.013845}}],
    Line[{{-2.937985, -3.826108, 18.013845},{-3.035138, -4.090090, 
        17.656387}}],
    Line[{{-3.035138, -4.090090, 17.656387},{-3.149061, -4.372785, 
        17.320801}}],
    Line[{{-3.149061, -4.372785, 17.320801},{-3.280018, -4.675840, 
        17.008446}}],
    Line[{{-3.280018, -4.675840, 17.008446},{-3.428407, -5.000952, 
        16.720945}}],
    Line[{{-3.428407, -5.000952, 16.720945},{-3.594752, -5.349847, 
        16.460203}}],
    Line[{{-3.594752, -5.349847, 16.460203},{-3.779692, -5.724251, 
        16.228451}}],
    Line[{{-3.779692, -5.724251, 16.228451},{-3.983964, -6.125843, 
        16.028296}}],
    Line[{{-3.983964, -6.125843, 16.028296},{-4.208396, -6.556220, 
        15.862757}}],
    Line[{{-4.208396, -6.556220, 15.862757},{-4.453881, -7.016818, 
        15.735320}}],
    Line[{{-4.453881, -7.016818, 15.735320},{-4.721347, -7.508831, 
        15.649981}}],
    Line[{{-4.721347, -7.508831, 15.649981},{-5.011743, -8.033128, 
        15.611291}}],
    Line[{{-5.011743, -8.033128, 15.611291},{-5.325977, -8.590088, 
        15.624389}}],
    Line[{{-5.325977, -8.590088, 15.624389},{-5.664884, -9.179469, 
        15.695024}}],
    Line[{{-5.664884, -9.179469, 15.695024},{-6.029162, -9.800226, 
        15.829571}}],
    Line[{{-6.029162, -9.800226, 15.829571},{-6.419281, -10.450233, 
        16.034952}}],
    Line[{{-6.419281, -10.450233, 16.034952},{-6.835419, -11.126097, 
        16.318609}}],
    Line[{{-6.835419, -11.126097, 16.318609},{-7.277335, -11.822824, 
        16.688343}}],
    Line[{{-7.277335, -11.822824, 16.688343},{-7.744239, -12.533508, 
        17.152039}}],
    Line[{{-7.744239, -12.533508, 17.152039},{-8.234660, -13.249048, 
        17.717384}}],
    Line[{{-8.234660, -13.249048, 17.717384},{-8.746284, -13.957847, 
        18.391409}}],
    Line[{{-8.746284, -13.957847, 18.391409},{-9.275780, -14.645595, 
        19.179859}}],
    Line[{{-9.275780, -14.645595, 19.179859},{-9.818638, -15.295184, 
        20.086451}}],
    Line[{{-9.818638, -15.295184, 20.086451},{-10.369020, -15.886823, 
        21.112011}}],
    Line[{{-10.369020, -15.886823, 21.112011},{-10.919634, -16.398300, 
        22.253538}}],
    Line[{{-10.919634, -16.398300, 22.253538},{-11.461687, -16.805830, 
        23.503138}}],
    Line[{{-11.461687, -16.805830, 23.503138},{-11.984921, -17.085022, 
        24.847198}}],
    Line[{{-11.984921, -17.085022, 24.847198},{-12.477765, -17.212425, 
        26.265738}}],
    Line[{{-12.477765, -17.212425, 26.265738},{-12.927634, -17.167370, 
        27.732193}}],
    Line[{{-12.927634, -17.167370, 27.732193},{-13.321394, -16.934053, 
        29.213835}}],
    Line[{{-13.321394, -16.934053, 29.213835},{-13.645973, -16.503613, 
        30.672903}}],
    Line[{{-13.645973, -16.503613, 30.672903},{-13.889114, -15.875914, 
        32.068531}}],
    Line[{{-13.889114, -15.875914, 32.068531},{-14.040185, -15.060711, 
        33.359341}}],
    Line[{{-14.040185, -15.060711, 33.359341},{-14.090984, -14.077829, 
        34.506500}}],
    Line[{{-14.090984, -14.077829, 34.506500},{-14.036437, -12.956335, 
        35.476742}}],
    Line[{{-14.036437, -12.956335, 35.476742},{-13.875087, -11.732589, 
        36.245029}}],
    Line[{{-13.875087, -11.732589, 36.245029},{-13.609324, -10.447453, 
        36.796398}}],
    Line[{{-13.609324, -10.447453, 36.796398},{-13.245281, -9.143018, 
        37.126675}}],
    Line[{{-13.245281, -9.143018, 37.126675},{-12.792444, -7.859356, 
        37.242035}}],
    Line[{{-12.792444, -7.859356, 37.242035},{-12.262995, -6.631763, 
        37.157524}}],
    Line[{{-12.262995, -6.631763, 37.157524},{-11.671000, -5.488768, 
        36.894875}}],
    Line[{{-11.671000, -5.488768, 36.894875},{-11.031528, -4.451106, 
        36.479992}}],
    Line[{{-11.031528, -4.451106, 36.479992},{-10.359806, -3.531605, 
        35.940498}}],
    Line[{{-10.359806, -3.531605, 35.940498},{-9.670468, -2.735795, 
        35.303616}}],
    Line[{{-9.670468, -2.735795, 35.303616},{-8.976979, -2.063053, 
        34.594601}}],
    Line[{{-8.976979, -2.063053, 34.594601},{-8.291213, -1.507963, 
        33.835674}}],
    Line[{{-8.291213, -1.507963, 33.835674},{-7.623231, -1.061742, 
        33.045570}}],
    Line[{{-7.623231, -1.061742, 33.045570},{-6.981187, -0.713525, 
        32.239426}}],
    Line[{{-6.981187, -0.713525, 32.239426},{-6.371370, -0.451461, 
        31.428993}}],
    Line[{{-6.371370, -0.451461, 31.428993},{-5.798331, -0.263549, 
        30.623056}}],
    Line[{{-5.798331, -0.263549, 30.623056},{-5.265062, -0.138252, 
        29.827892}}],
    Line[{{-5.265062, -0.138252, 29.827892},{-4.773214, -0.064900, 
        29.047771}}],
    Line[{{-4.773214, -0.064900, 29.047771},{-4.323317, -0.033925, 
        28.285406}}],
    Line[{{-4.323317, -0.033925, 28.285406},{-3.914996, -0.036955, 
        27.542360}}],
    Line[{{-3.914996, -0.036955, 27.542360},{-3.547174, -0.066836, 
        26.819361}}],
    Line[{{-3.547174, -0.066836, 26.819361},{-3.218255, -0.117573, 
        26.116573}}],
    Line[{{-3.218255, -0.117573, 26.116573},{-2.926274, -0.184253, 
        25.433792}}],
    Line[{{-2.926274, -0.184253, 25.433792},{-2.669036, -0.262926, 
        24.770584}}],
    Line[{{-2.669036, -0.262926, 24.770584},{-2.444219, -0.350499, 
        24.126402}}],
    Line[{{-2.444219, -0.350499, 24.126402},{-2.249465, -0.444621, 
        23.500647}}],
    Line[{{-2.249465, -0.444621, 23.500647},{-2.082448, -0.543572, 
        22.892715}}],
    Line[{{-2.082448, -0.543572, 22.892715},{-1.940928, -0.646170, 
        22.302034}}],
    Line[{{-1.940928, -0.646170, 22.302034},{-1.822787, -0.751679, 
        21.728069}}],
    Line[{{-1.822787, -0.751679, 21.728069},{-1.726057, -0.859741, 
        21.170341}}],
    Line[{{-1.726057, -0.859741, 21.170341},{-1.648936, -0.970303, 
        20.628420}}],
    Line[{{-1.648936, -0.970303, 20.628420},{-1.589806, -1.083569, 
        20.101936}}],
    Line[{{-1.589806, -1.083569, 20.101936},{-1.547230, -1.199953, 
        19.590570}}],
    Line[{{-1.547230, -1.199953, 19.590570},{-1.519958, -1.320043, 
        19.094057}}],
    Line[{{-1.519958, -1.320043, 19.094057},{-1.506918, -1.444577, 
        18.612188}}],
    Line[{{-1.506918, -1.444577, 18.612188},{-1.507221, -1.574416, 
        18.144808}}],
    Line[{{-1.507221, -1.574416, 18.144808},{-1.520147, -1.710535, 
        17.691811}}],
    Line[{{-1.520147, -1.710535, 17.691811},{-1.545145, -1.854006, 
        17.253157}}],
    Line[{{-1.545145, -1.854006, 17.253157},{-1.581820, -2.005997, 
        16.828869}}],
    Line[{{-1.581820, -2.005997, 16.828869},{-1.629933, -2.167767, 
        16.419041}}],
    Line[{{-1.629933, -2.167767, 16.419041},{-1.689390, -2.340664, 
        16.023844}}],
    Line[{{-1.689390, -2.340664, 16.023844},{-1.760240, -2.526134, 
        15.643548}}],
    Line[{{-1.760240, -2.526134, 15.643548},{-1.842669, -2.725717, 
        15.278522}}],
    Line[{{-1.842669, -2.725717, 15.278522},{-1.936996, -2.941056, 
        14.929262}}],
    Line[{{-1.936996, -2.941056, 14.929262},{-2.043673, -3.173902, 
        14.596402}}],
    Line[{{-2.043673, -3.173902, 14.596402},{-2.163280, -3.426118, 
        14.280750}}],
    Line[{{-2.163280, -3.426118, 14.280750},{-2.296523, -3.699682, 
        13.983306}}],
    Line[{{-2.296523, -3.699682, 13.983306},{-2.444239, -3.996693, 
        13.705297}}],
    Line[{{-2.444239, -3.996693, 13.705297},{-2.607386, -4.319359, 
        13.448232}}],
    Line[{{-2.607386, -4.319359, 13.448232},{-2.787049, -4.670003, 
        13.213921}}],
    Line[{{-2.787049, -4.670003, 13.213921},{-2.984436, -5.051041, 
        13.004553}}],
    Line[{{-2.984436, -5.051041, 13.004553},{-3.200872, -5.464954, 
        12.822750}}],
    Line[{{-3.200872, -5.464954, 12.822750},{-3.437794, -5.914274, 
        12.671627}}],
    Line[{{-3.437794, -5.914274, 12.671627},{-3.696745, -6.401501, 
        12.554885}}],
    Line[{{-3.696745, -6.401501, 12.554885},{-3.979352, -6.929049, 
        12.476886}}],
    Line[{{-3.979352, -6.929049, 12.476886},{-4.287315, -7.499160, 
        12.442746}}],
    Line[{{-4.287315, -7.499160, 12.442746},{-4.622364, -8.113725, 
        12.458437}}],
    Line[{{-4.622364, -8.113725, 12.458437},{-4.986223, -8.774143, 
        12.530865}}],
    Line[{{-4.986223, -8.774143, 12.530865},{-5.380556, -9.481095, 
        12.667959}}],
    Line[{{-5.380556, -9.481095, 12.667959},{-5.806885, -10.234243, 
        12.878728}}],
    Line[{{-5.806885, -10.234243, 12.878728},{-6.266489, -11.031873, 
        13.173267}}],
    Line[{{-6.266489, -11.031873, 13.173267},{-6.760278, -11.870472, 
        13.562705}}],
    Line[{{-6.760278, -11.870472, 13.562705},{-7.288643, -12.744249, 
        14.059076}}],
    Line[{{-7.288643, -12.744249, 14.059076},{-7.851249, -13.644543, 
        14.675019}}],
    Line[{{-7.851249, -13.644543, 14.675019},{-8.446799, -14.559214, 
        15.423282}}],
    Line[{{-8.446799, -14.559214, 15.423282},{-9.072781, -15.472073, 
        16.316048}}],
    Line[{{-9.072781, -15.472073, 16.316048},{-9.725156, -16.362349, 
        17.363924}}],
    Line[{{-9.725156, -16.362349, 17.363924},{-10.398062, -17.204372, 
        18.574657}}],
    Line[{{-10.398062, -17.204372, 18.574657},{-11.083512, -17.967581, 
        19.951519}}],
    Line[{{-11.083512, -17.967581, 19.951519},{-11.771155, -18.617035, 
        21.491461}}],
    Line[{{-11.771155, -18.617035, 21.491461},{-12.448122, -19.114592, 
        23.183163}}],
    Line[{{-12.448122, -19.114592, 23.183163},{-13.099079, -19.421047, 
        25.005251}}],
    Line[{{-13.099079, -19.421047, 25.005251},{-13.706475, -19.498970, 
        26.925049}}],
    Line[{{-13.706475, -19.498970, 26.925049},{-14.251102, -19.316435, 
        28.898264}}],
    Line[{{-14.251102, -19.316435, 28.898264},{-14.712972, -18.851154, 
        30.870022}}],
    Line[{{-14.712972, -18.851154, 30.870022},{-15.072510, -18.094492, 
        32.777592}}],
    Line[{{-15.072510, -18.094492, 32.777592},{-15.311975, -17.054546, 
        34.554752}}],
    Line[{{-15.311975, -17.054546, 34.554752},{-15.416961, -15.757592, 
        36.137409}}],
    Line[{{-15.416961, -15.757592, 36.137409},{-15.377784, -14.247167, 
        37.469761}}],
    Line[{{-15.377784, -14.247167, 37.469761},{-15.190547, -12.580898, 
        38.509827}}],
    Line[{{-15.190547, -12.580898, 38.509827},{-14.857674, -10.825149, 
        39.233437}}],
    Line[{{-14.857674, -10.825149, 39.233437},{-14.387839, -9.048594, 
        39.635841}}],
    Line[{{-14.387839, -9.048594, 39.635841},{-13.795280, -7.315769, 
        39.730740}}],
    Line[{{-13.795280, -7.315769, 39.730740},{-13.098589, -5.681712, 
        39.547070}}],
    Line[{{-13.098589, -5.681712, 39.547070},{-12.319223, -4.188452, 
        39.124386}}],
    Line[{{-12.319223, -4.188452, 39.124386},{-11.479900, -2.863581, 
        38.507736}}],
    Line[{{-11.479900, -2.863581, 38.507736},{-10.603118, -1.720767, 
        37.742981}}],
    Line[{{-10.603118, -1.720767, 37.742981},{-9.709931, -0.761618, 
        36.873077}}],
    Line[{{-9.709931, -0.761618, 36.873077},{-8.819067, 0.021653, 
        35.935635}}],
    Line[{{-8.819067, 0.021653, 35.935635},{-7.946391, 0.643377, 34.961704}}],
    
    Line[{{-7.946391, 0.643377, 34.961704},{-7.104685, 1.121796, 33.975544}}],
    
    Line[{{-7.104685, 1.121796, 33.975544},{-6.303682, 1.476868, 32.995079}}],
    
    Line[{{-6.303682, 1.476868, 32.995079},{-5.550273, 1.728630, 32.032764}}],
    
    Line[{{-5.550273, 1.728630, 32.032764},{-4.848830, 1.896072, 31.096626}}],
    
    Line[{{-4.848830, 1.896072, 31.096626},{-4.201582, 1.996461, 30.191284}}],
    
    Line[{{-4.201582, 1.996461, 30.191284},{-3.608999, 2.045005, 29.318855}}],
    
    Line[{{-3.608999, 2.045005, 29.318855},{-3.070166, 2.054757, 28.479742}}],
    
    Line[{{-3.070166, 2.054757, 28.479742},{-2.583111, 2.036689, 27.673227}}],
    
    Line[{{-2.583111, 2.036689, 27.673227},{-2.145102, 1.999852, 26.897924}}],
    
    Line[{{-2.145102, 1.999852, 26.897924},{-1.752889, 1.951587, 26.152117}}],
    
    Line[{{-1.752889, 1.951587, 26.152117},{-1.402908, 1.897758, 25.433966}}],
    
    Line[{{-1.402908, 1.897758, 25.433966},{-1.091437, 1.842971, 24.741661}}],
    
    Line[{{-1.091437, 1.842971, 24.741661},{-0.814722, 1.790796, 24.073503}}],
    
    Line[{{-0.814722, 1.790796, 24.073503},{-0.569068, 1.743946, 23.427944}}],
    
    Line[{{-0.569068, 1.743946, 23.427944},{-0.350911, 1.704450, 22.803608}}],
    
    Line[{{-0.350911, 1.704450, 22.803608},{-0.156857, 1.673800, 22.199293}}],
    
    Line[{{-0.156857, 1.673800, 22.199293},{0.016285, 1.653072, 21.613955}}],
    Line[{{0.016285, 1.653072, 21.613955},{0.171487, 1.643028, 21.046696}}],
    Line[{{0.171487, 1.643028, 21.046696},{0.311503, 1.644208, 20.496752}}],
    Line[{{0.311503, 1.644208, 20.496752},{0.438864, 1.657001, 19.963472}}],
    Line[{{0.438864, 1.657001, 19.963472},{0.555896, 1.681699, 19.446306}}],
    Line[{{0.555896, 1.681699, 19.446306},{0.664725, 1.718552, 18.944792}}],
    Line[{{0.664725, 1.718552, 18.944792},{0.767303, 1.767805, 18.458551}}],
    Line[{{0.767303, 1.767805, 18.458551},{0.865417, 1.829729, 17.987280}}],
    Line[{{0.865417, 1.829729, 17.987280},{0.960712, 1.904647, 17.530741}}],
    Line[{{0.960712, 1.904647, 17.530741},{1.054712, 1.992958, 17.088770}}],
    Line[{{1.054712, 1.992958, 17.088770},{1.148838, 2.095151, 16.661272}}],
    Line[{{1.148838, 2.095151, 16.661272},{1.244427, 2.211822, 16.248230}}],
    Line[{{1.244427, 2.211822, 16.248230},{1.342752, 2.343683, 15.849703}}],
    Line[{{1.342752, 2.343683, 15.849703},{1.445036, 2.491575, 15.465840}}],
    Line[{{1.445036, 2.491575, 15.465840},{1.552475, 2.656478, 15.096892}}],
    Line[{{1.552475, 2.656478, 15.096892},{1.666252, 2.839515, 14.743225}}],
    Line[{{1.666252, 2.839515, 14.743225},{1.787547, 3.041960, 14.405335}}],
    Line[{{1.787547, 3.041960, 14.405335},{1.917563, 3.265244, 14.083874}}],
    Line[{{1.917563, 3.265244, 14.083874},{2.057526, 3.510960, 13.779669}}],
    Line[{{2.057526, 3.510960, 13.779669},{2.208710, 3.780862, 13.493762}}],
    Line[{{2.208710, 3.780862, 13.493762},{2.372440, 4.076865, 13.227438}}],
    Line[{{2.372440, 4.076865, 13.227438},{2.550104, 4.401041, 12.982269}}],
    Line[{{2.550104, 4.401041, 12.982269},{2.743164, 4.755609, 12.760165}}],
    Line[{{2.743164, 4.755609, 12.760165},{2.953159, 5.142909, 12.563436}}],
    Line[{{2.953159, 5.142909, 12.563436},{3.181711, 5.565387, 12.394845}}],
    Line[{{3.181711, 5.565387, 12.394845},{3.430522, 6.025547, 12.257695}}],
    Line[{{3.430522, 6.025547, 12.257695},{3.701371, 6.525881, 12.155914}}],
    Line[{{3.701371, 6.525881, 12.155914},{3.996102, 7.068802, 12.094134}}],
    Line[{{3.996102, 7.068802, 12.094134},{4.316606, 7.656533, 12.077801}}],
    Line[{{4.316606, 7.656533, 12.077801},{4.664786, 8.290934, 12.113273}}],
    Line[{{4.664786, 8.290934, 12.113273},{5.042518, 8.973323, 12.207912}}],
    Line[{{5.042518, 8.973323, 12.207912},{5.451594, 9.704247, 12.370177}}],
    Line[{{5.451594, 9.704247, 12.370177},{5.893631, 10.483116, 12.609674}}],
    Line[{{5.893631, 10.483116, 12.609674},{6.369966, 11.307845, 12.937161}}],
    
    Line[{{6.369966, 11.307845, 12.937161},{6.881522, 12.174380, 13.364487}}],
    
    Line[{{6.881522, 12.174380, 13.364487},{7.428630, 13.076146, 13.904413}}],
    
    Line[{{7.428630, 13.076146, 13.904413},{8.010818, 14.003429, 14.570272}}],
    
    Line[{{8.010818, 14.003429, 14.570272},{8.626554, 14.942730, 15.375430}}],
    
    Line[{{8.626554, 14.942730, 15.375430},{9.272961, 15.876128, 16.332458}}],
    
    Line[{{9.272961, 15.876128, 16.332458},{9.945492, 16.780773, 17.452024}}],
    
    Line[{{9.945492, 16.780773, 17.452024},{
      10.637608, 17.628557, 18.741463}}],
    Line[{{10.637608, 17.628557, 18.741463},{
      11.340465, 18.386272, 20.202919}}],
    Line[{{11.340465, 18.386272, 20.202919},{
      12.042679, 19.016283, 21.831375}}],
    Line[{{12.042679, 19.016283, 21.831375},{
      12.730210, 19.478024, 23.612568}}],
    Line[{{12.730210, 19.478024, 23.612568},{
      13.386447, 19.730421, 25.521177}}],
    Line[{{13.386447, 19.730421, 25.521177},{
      13.992556, 19.735266, 27.519674}}],
    Line[{{13.992556, 19.735266, 27.519674},{
      14.528165, 19.461349, 29.558346}}],
    Line[{{14.528165, 19.461349, 29.558346},{
      14.972384, 18.888939, 31.576851}}],
    Line[{{14.972384, 18.888939, 31.576851},{
      15.305168, 18.013885, 33.507706}}],
    Line[{{15.305168, 18.013885, 33.507706},{
      15.508859, 16.850504, 35.281384}}],
    Line[{{15.508859, 16.850504, 35.281384},{
      15.569777, 15.432393, 36.832653}}],
    Line[{{15.569777, 15.432393, 36.832653},{
      15.479615, 13.810698, 38.107098}}],
    Line[{{15.479615, 13.810698, 38.107098},{
      15.236409, 12.049834, 39.066616}}],
    Line[{{15.236409, 12.049834, 39.066616},{
      14.844914, 10.221297, 39.692963}}],
    Line[{{14.844914, 10.221297, 39.692963},{
      14.316294, 8.396524, 39.988499}}],
    Line[{{14.316294, 8.396524, 39.988499},{13.667161, 6.640311, 39.974133}}],
    
    Line[{{13.667161, 6.640311, 39.974133},{12.918183, 5.005692, 39.685307}}],
    
    Line[{{12.918183, 5.005692, 39.685307},{12.092416, 3.531039, 39.166637}}],
    
    Line[{{12.092416, 3.531039, 39.166637},{11.213620, 2.239347, 38.466526}}],
    
    Line[{{11.213620, 2.239347, 38.466526},{10.304790, 1.139470, 37.632450}}],
    
    Line[{{10.304790, 1.139470, 37.632450},{9.386980, 0.228540, 36.707531}}],
    Line[{{9.386980, 0.228540, 36.707531},{8.478524, -0.505009, 35.728485}}],
    Line[{{8.478524, -0.505009, 35.728485},{7.594614, -1.078434, 34.724792}}],
    
    Line[{{7.594614, -1.078434, 34.724792},{6.747185, -1.512032, 33.718822}}],
    
    Line[{{6.747185, -1.512032, 33.718822},{5.945045, -1.827063, 32.726585}}],
    
    Line[{{5.945045, -1.827063, 32.726585},{5.194156, -2.044240, 31.758753}}],
    
    Line[{{5.194156, -2.044240, 31.758753},{4.498013, -2.182767, 30.821800}}],
    
    Line[{{4.498013, -2.182767, 30.821800},{3.858040, -2.259802, 29.919062}}],
    
    Line[{{3.858040, -2.259802, 29.919062},{3.274006, -2.290238, 29.051651}}],
    
    Line[{{3.274006, -2.290238, 29.051651},{2.744394, -2.286703, 28.219198}}],
    
    Line[{{2.744394, -2.286703, 28.219198},{2.266734, -2.259696, 27.420420}}],
    
    Line[{{2.266734, -2.259696, 27.420420},{1.837885, -2.217791, 26.653532}}],
    
    Line[{{1.837885, -2.217791, 26.653532},{1.454275, -2.167882, 25.916550}}],
    
    Line[{{1.454275, -2.167882, 25.916550},{1.112084, -2.115430, 25.207458}}],
    
    Line[{{1.112084, -2.115430, 25.207458},{0.807399, -2.064694, 24.524347}}],
    
    Line[{{0.807399, -2.064694, 24.524347},{0.536321, -2.018948, 23.865465}}],
    
    Line[{{0.536321, -2.018948, 23.865465},{0.295051, -1.980668, 23.229250}}],
    
    Line[{{0.295051, -1.980668, 23.229250},{0.079948, -1.951701, 22.614336}}],
    
    Line[{{
      0.079948, -1.951701, 22.614336},{-0.112433, -1.933401, 22.019548}}],
    Line[{{-0.112433, -1.933401, 22.019548},{-0.285320, -1.926756, 
        21.443884}}],
    Line[{{-0.285320, -1.926756, 21.443884},{-0.441715, -1.932480, 
        20.886499}}],
    Line[{{-0.441715, -1.932480, 20.886499},{-0.584391, -1.951104, 
        20.346687}}],
    Line[{{-0.584391, -1.951104, 20.346687},{-0.715901, -1.983037, 
        19.823866}}],
    Line[{{-0.715901, -1.983037, 19.823866},{-0.838592, -2.028628, 
        19.317564}}],
    Line[{{-0.838592, -2.028628, 19.317564},{-0.954620, -2.088207, 
        18.827412}}],
    Line[{{-0.954620, -2.088207, 18.827412},{-1.065966, -2.162127, 
        18.353130}}],
    Line[{{-1.065966, -2.162127, 18.353130},{-1.174460, -2.250791, 
        17.894531}}],
    Line[{{-1.174460, -2.250791, 17.894531},{-1.281799, -2.354674, 
        17.451517}}],
    Line[{{-1.281799, -2.354674, 17.451517},{-1.389569, -2.474348, 
        17.024075}}],
    Line[{{-1.389569, -2.474348, 17.024075},{-1.499262, -2.610495, 
        16.612293}}],
    Line[{{-1.499262, -2.610495, 16.612293},{-1.612302, -2.763920, 
        16.216364}}],
    Line[{{-1.612302, -2.763920, 16.216364},{-1.730058, -2.935561, 
        15.836591}}],
    Line[{{-1.730058, -2.935561, 15.836591},{-1.853867, -3.126497, 
        15.473413}}],
    Line[{{-1.853867, -3.126497, 15.473413},{-1.985048, -3.337957, 
        15.127417}}],
    Line[{{-1.985048, -3.337957, 15.127417},{-2.124917, -3.571321, 
        14.799355}}],
    Line[{{-2.124917, -3.571321, 14.799355},{-2.274804, -3.828121, 
        14.490184}}],
    Line[{{-2.274804, -3.828121, 14.490184},{-2.436069, -4.110042, 
        14.201088}}],
    Line[{{-2.436069, -4.110042, 14.201088},{-2.610105, -4.418914, 
        13.933517}}],
    Line[{{-2.610105, -4.418914, 13.933517},{-2.798356, -4.756703, 
        13.689239}}],
    Line[{{-2.798356, -4.756703, 13.689239},{-3.002322, -5.125492, 
        13.470375}}],
    Line[{{-3.002322, -5.125492, 13.470375},{-3.223562, -5.527457, 
        13.279471}}],
    Line[{{-3.223562, -5.527457, 13.279471},{-3.463697, -5.964821, 
        13.119563}}],
    Line[{{-3.463697, -5.964821, 13.119563},{-3.724404, -6.439806, 
        12.994240}}],
    Line[{{-3.724404, -6.439806, 12.994240},{-4.007412, -6.954563, 
        12.907731}}],
    Line[{{-4.007412, -6.954563, 12.907731},{-4.314481, -7.511052, 
        12.864992}}],
    Line[{{-4.314481, -7.511052, 12.864992},{-4.647373, -8.110925, 
        12.871786}}],
    Line[{{-4.647373, -8.110925, 12.871786},{-5.007824, -8.755366, 
        12.934769}}],
    Line[{{-5.007824, -8.755366, 12.934769},{-5.397482, -9.444841, 
        13.061563}}],
    Line[{{-5.397482, -9.444841, 13.061563},{-5.817832, -10.178831, 
        13.260792}}],
    Line[{{-5.817832, -10.178831, 13.260792},{-6.270123, -10.955542, 
        13.542117}}],
    Line[{{-6.270123, -10.955542, 13.542117},{-6.755221, -11.771420, 
        13.916143}}],
    Line[{{-6.755221, -11.771420, 13.916143},{-7.273473, -12.620744, 
        14.394293}}],
    Line[{{-7.273473, -12.620744, 14.394293},{-7.824521, -13.495068, 
        14.988510}}],
    Line[{{-7.824521, -13.495068, 14.988510},{-8.407085, -14.382681, 
        15.710825}}],
    Line[{{-8.407085, -14.382681, 15.710825},{-9.018714, -15.268049, 
        16.572685}}],
    Line[{{-9.018714, -15.268049, 16.572685},{-9.655503, -16.131338, 
        17.584011}}],
    Line[{{-9.655503, -16.131338, 17.584011},{-10.311811, -16.948126, 
        18.751991}}],
    Line[{{-10.311811, -16.948126, 18.751991},{-10.979991, -17.689440, 
        20.079567}}],
    Line[{{-10.979991, -17.689440, 20.079567},{-11.650156, -18.322220, 
        21.563778}}],
    Line[{{-11.650156, -18.322220, 21.563778},{-12.310064, -18.810459, 
        23.193911}}],
    Line[{{-12.310064, -18.810459, 23.193911},{-12.945142, -19.117088, 
        24.949883}}],
    Line[{{-12.945142, -19.117088, 24.949883},{-13.538727, -19.206640, 
        26.801069}}],
    Line[{{-13.538727, -19.206640, 26.801069},{-14.072580, -19.048674, 
        28.705980}}],
    Line[{{-14.072580, -19.048674, 28.705980},{-14.527698, -18.621567, 
        30.613184}}],
    Line[{{-14.527698, -18.621567, 30.613184},{-14.885404, -17.916233, 
        32.463722}}],
    Line[{{-14.885404, -17.916233, 32.463722},{-15.128667, -16.939070, 
        34.195030}}],
    Line[{{-15.128667, -16.939070, 34.195030},{-15.243503, -15.713350, 
        35.746124}}],
    Line[{{-15.243503, -15.713350, 35.746124},{-15.220269, -14.278657, 
        37.063202}}],
    Line[{{-15.220269, -14.278657, 37.063202},{-15.054698, -12.688088, 
        38.104862}}],
    Line[{{-15.054698, -12.688088, 38.104862},{-14.748451, -11.003565, 
        38.845997}}],
    Line[{{-14.748451, -11.003565, 38.845997},{-14.309114, -9.289926, 
        39.279549}}],
    Line[{{-14.309114, -9.289926, 39.279549},{-13.749617, -7.608953, 
        39.415897}}],
    Line[{{-13.749617, -7.608953, 39.415897},{-13.087178, -6.014230, 
        39.280220}}],
    Line[{{-13.087178, -6.014230, 39.280220},{-12.341932, -4.547622, 
        38.908329}}],
    Line[{{-12.341932, -4.547622, 38.908329},{-11.535439, -3.237654, 
        38.341999}}],
    Line[{{-11.535439, -3.237654, 38.341999},{-10.689277, -2.099672, 
        37.624542}}],
    Line[{{-10.689277, -2.099672, 37.624542},{-9.823853, -1.137372, 
        36.797192}}],
    Line[{{-9.823853, -1.137372, 36.797192},{-8.957513, -0.345144, 
        35.896614}}],
    Line[{{-8.957513, -0.345144, 35.896614},{-8.105976, 0.289306, 
        34.953552}}],
    Line[{{-8.105976, 0.289306, 34.953552},{-7.282078, 0.782454, 33.992439}}],
    
    Line[{{-7.282078, 0.782454, 33.992439},{-6.495748, 1.152836, 33.031673}}],
    
    Line[{{-6.495748, 1.152836, 33.031673},{-5.754174, 1.419411, 32.084362}}],
    
    Line[{{-5.754174, 1.419411, 32.084362},{-5.062087, 1.600403, 31.159245}}],
    
    Line[{{-5.062087, 1.600403, 31.159245},{-4.422096, 1.712574, 30.261614}}],
    
    Line[{{-4.422096, 1.712574, 30.261614},{-3.835058, 1.770828, 29.394220}}],
    
    Line[{{-3.835058, 1.770828, 29.394220},{-3.300424, 1.788070, 28.558002}}],
    
    Line[{{-3.300424, 1.788070, 28.558002},{-2.816565, 1.775223, 27.752693}}],
    
    Line[{{-2.816565, 1.775223, 27.752693},{-2.381060, 1.741363, 26.977272}}],
    
    Line[{{-2.381060, 1.741363, 26.977272},{-1.990936, 1.693896, 26.230305}}],
    
    Line[{{-1.990936, 1.693896, 26.230305},{-1.642870, 1.638768, 25.510172}}],
    
    Line[{{-1.642870, 1.638768, 25.510172},{-1.333354, 1.580678, 24.815229}}],
    
    Line[{{-1.333354, 1.580678, 24.815229},{-1.058815, 1.523275, 24.143894}}],
    
    Line[{{-1.058815, 1.523275, 24.143894},{-0.815719, 1.469344, 23.494701}}],
    
    Line[{{-0.815719, 1.469344, 23.494701},{-0.600638, 1.420969, 22.866329}}],
    
    Line[{{-0.600638, 1.420969, 22.866329},{-0.410297, 1.379674, 22.257605}}],
    
    Line[{{-0.410297, 1.379674, 22.257605},{-0.241613, 1.346547, 21.667496}}],
    
    Line[{{-0.241613, 1.346547, 21.667496},{-0.091710, 1.322342, 21.095102}}],
    
    Line[{{-0.091710, 1.322342, 21.095102},{0.042077, 1.307567, 20.539642}}],
    Line[{{0.042077, 1.307567, 20.539642},{0.162195, 1.302555, 20.000435}}],
    Line[{{0.162195, 1.302555, 20.000435},{0.270885, 1.307525, 19.476889}}],
    Line[{{0.270885, 1.307525, 19.476889},{0.370193, 1.322626, 18.968489}}],
    Line[{{0.370193, 1.322626, 18.968489},{0.461983, 1.347985, 18.474789}}],
    Line[{{0.461983, 1.347985, 18.474789},{0.547952, 1.383729, 17.995405}}],
    Line[{{0.547952, 1.383729, 17.995405},{0.629649, 1.430020, 17.530003}}],
    Line[{{0.629649, 1.430020, 17.530003},{0.708495, 1.487069, 17.078302}}],
    Line[{{0.708495, 1.487069, 17.078302},{0.785799, 1.555157, 16.640074}}],
    Line[{{0.785799, 1.555157, 16.640074},{0.862773, 1.634649, 16.215134}}],
    Line[{{0.862773, 1.634649, 16.215134},{0.940558, 1.726005, 15.803354}}],
    Line[{{0.940558, 1.726005, 15.803354},{1.020230, 1.829789, 15.404660}}],
    Line[{{1.020230, 1.829789, 15.404660},{1.102825, 1.946681, 15.019036}}],
    Line[{{1.102825, 1.946681, 15.019036},{1.189350, 2.077483, 14.646536}}],
    Line[{{1.189350, 2.077483, 14.646536},{1.280800, 2.223131, 14.287290}}],
    Line[{{1.280800, 2.223131, 14.287290},{1.378168, 2.384698, 13.941514}}],
    Line[{{1.378168, 2.384698, 13.941514},{1.482466, 2.563402, 13.609530}}],
    Line[{{1.482466, 2.563402, 13.609530},{1.594729, 2.760619, 13.291780}}],
    Line[{{1.594729, 2.760619, 13.291780},{1.716034, 2.977883, 12.988842}}],
    Line[{{1.716034, 2.977883, 12.988842},{1.847510, 3.216896, 12.701466}}],
    Line[{{1.847510, 3.216896, 12.701466},{1.990347, 3.479532, 12.430592}}],
    Line[{{1.990347, 3.479532, 12.430592},{2.145811, 3.767842, 12.177395}}],
    Line[{{2.145811, 3.767842, 12.177395},{2.315250, 4.084053, 11.943317}}],
    Line[{{2.315250, 4.084053, 11.943317},{2.500103, 4.430557, 11.730138}}],
    Line[{{2.500103, 4.430557, 11.730138},{2.701909, 4.809915, 11.539998}}],
    Line[{{2.701909, 4.809915, 11.539998},{2.922310, 5.224824, 11.375506}}],
    Line[{{2.922310, 5.224824, 11.375506},{3.163056, 5.678088, 11.239792}}],
    Line[{{3.163056, 5.678088, 11.239792},{3.426001, 6.172584, 11.136594}}],
    Line[{{3.426001, 6.172584, 11.136594},{3.713089, 6.711154, 11.070392}}],
    Line[{{3.713089, 6.711154, 11.070392},{4.026360, 7.296574, 11.046468}}],
    Line[{{4.026360, 7.296574, 11.046468},{4.367899, 7.931345, 11.071072}}],
    Line[{{4.367899, 7.931345, 11.071072},{4.739821, 8.617558, 11.151516}}],
    Line[{{4.739821, 8.617558, 11.151516},{5.144202, 9.356640, 11.296301}}],
    Line[{{5.144202, 9.356640, 11.296301},{5.583019, 10.149065, 11.515213}}],
    Line[{{5.583019, 10.149065, 11.515213},{6.058042, 10.993944, 11.819393}}],
    
    Line[{{6.058042, 10.993944, 11.819393},{6.570699, 11.888539, 12.221329}}],
    
    Line[{{6.570699, 11.888539, 12.221329},{7.121910, 12.827692, 12.734753}}],
    
    Line[{{7.121910, 12.827692, 12.734753},{7.711884, 13.803179, 13.374439}}],
    
    Line[{{7.711884, 13.803179, 13.374439},{8.339832, 14.802884, 14.155680}}],
    
    Line[{{8.339832, 14.802884, 14.155680},{9.003677, 15.810081, 15.093615}}],
    
    Line[{{9.003677, 15.810081, 15.093615},{9.699692, 16.802660, 16.202137}}],
    
    Line[{{9.699692, 16.802660, 16.202137},{
      10.422113, 17.752575, 17.492428}}],
    Line[{{10.422113, 17.752575, 17.492428},{
      11.162765, 18.625622, 18.971056}}],
    Line[{{11.162765, 18.625622, 18.971056},{
      11.910701, 19.381804, 20.637705}}],
    Line[{{11.910701, 19.381804, 20.637705},{
      12.651978, 19.976503, 22.482691}}],
    Line[{{12.651978, 19.976503, 22.482691},{
      13.369595, 20.362749, 24.484516}}],
    Line[{{13.369595, 20.362749, 24.484516},{
      14.043718, 20.494638, 26.607969}}],
    Line[{{14.043718, 20.494638, 26.607969},{
      14.652267, 20.331881, 28.803333}}],
    Line[{{14.652267, 20.331881, 28.803333},{
      15.171907, 19.845098, 31.007277}}],
    Line[{{15.171907, 19.845098, 31.007277},{
      15.579479, 19.021101, 33.145924}}],
    Line[{{15.579479, 19.021101, 33.145924},{
      15.853730, 17.867172, 35.140167}}],
    Line[{{15.853730, 17.867172, 35.140167},{
      15.977217, 16.413265, 36.912807}}],
    Line[{{15.977217, 16.413265, 36.912807},{
      15.938080, 14.711104, 38.396572}}],
    Line[{{15.938080, 14.711104, 38.396572},{
      15.731409, 12.830116, 39.541340}}],
    Line[{{15.731409, 12.830116, 39.541340},{
      15.359969, 10.850614, 40.319374}}],
    Line[{{15.359969, 10.850614, 40.319374},{
      14.834078, 8.855317, 40.727253}}],
    Line[{{14.834078, 8.855317, 40.727253},{14.170728, 6.921063, 40.784397}}],
    
    Line[{{14.170728, 6.921063, 40.784397},{13.392038, 5.112019, 40.528660}}],
    
    Line[{{13.392038, 5.112019, 40.528660},{12.523335, 3.475549, 40.010014}}],
    
    Line[{{12.523335, 3.475549, 40.010014},{11.591161, 2.040839, 39.283966}}],
    
    Line[{{11.591161, 2.040839, 39.283966},{10.621474, 0.820032, 38.405632}}],
    
    Line[{{10.621474, 0.820032, 38.405632},{9.638200, -0.188966, 37.425323}}],
    
    Line[{{9.638200, -0.188966, 37.425323},{8.662243, -0.998862, 36.385857}}],
    
    Line[{{8.662243, -0.998862, 36.385857},{7.710947, -1.629297, 35.321438}}],
    
    Line[{{7.710947, -1.629297, 35.321438},{6.797934, -2.103605, 34.257793}}],
    
    Line[{{6.797934, -2.103605, 34.257793},{5.933236, -2.446250, 33.213036}}],
    
    Line[{{5.933236, -2.446250, 33.213036},{5.123624, -2.681023, 32.198963}}],
    
    Line[{{5.123624, -2.681023, 32.198963},{4.373042, -2.829884, 31.222427}}],
    
    Line[{{4.373042, -2.829884, 31.222427},{3.683082, -2.912349, 30.286654}}],
    
    Line[{{3.683082, -2.912349, 30.286654},{3.053459, -2.945251, 29.392330}}],
    
    Line[{{3.053459, -2.945251, 29.392330},{2.482441, -2.942778, 28.538504}}],
    
    Line[{{2.482441, -2.942778, 28.538504},{1.967231, -2.916650, 27.723253}}],
    
    Line[{{1.967231, -2.916650, 27.723253},{1.504292, -2.876385, 26.944168}}],
    
    Line[{{1.504292, -2.876385, 26.944168},{1.089614, -2.829598, 26.198681}}],
    
    Line[{{1.089614, -2.829598, 26.198681},{0.718920, -2.782290, 25.484282}}],
    
    Line[{{0.718920, -2.782290, 25.484282},{0.387841, -2.739130, 24.798634}}],
    
    Line[{{0.387841, -2.739130, 24.798634},{0.092029, -2.703703, 24.139652}}],
    
    Line[{{
      0.092029, -2.703703, 24.139652},{-0.172745, -2.678725, 23.505520}}],
    Line[{{-0.172745, -2.678725, 23.505520},{-0.410533, -2.666236, 
        22.894684}}],
    Line[{{-0.410533, -2.666236, 22.894684},{-0.625169, -2.667751, 
        22.305853}}],
    Line[{{-0.625169, -2.667751, 22.305853},{-0.820246, -2.684403, 
        21.737963}}],
    Line[{{-0.820246, -2.684403, 21.737963},{-0.999111, -2.717045, 
        21.190170}}],
    Line[{{-0.999111, -2.717045, 21.190170},{-1.164860, -2.766346, 
        20.661818}}],
    Line[{{-1.164860, -2.766346, 20.661818},{-1.320355, -2.832862, 
        20.152418}}],
    Line[{{-1.320355, -2.832862, 20.152418},{-1.468236, -2.917101, 
        19.661646}}],
    Line[{{-1.468236, -2.917101, 19.661646},{-1.610937, -3.019564, 
        19.189325}}],
    Line[{{-1.610937, -3.019564, 19.189325},{-1.750712, -3.140789, 
        18.735422}}],
    Line[{{-1.750712, -3.140789, 18.735422},{-1.889653, -3.281381, 
        18.300047}}],
    Line[{{-1.889653, -3.281381, 18.300047},{-2.029716, -3.442030, 
        17.883459}}],
    Line[{{-2.029716, -3.442030, 17.883459},{-2.172740, -3.623532, 
        17.486074}}],
    Line[{{-2.172740, -3.623532, 17.486074},{-2.320472, -3.826802, 
        17.108477}}],
    Line[{{-2.320472, -3.826802, 17.108477},{-2.474584, -4.052875, 
        16.751440}}],
    Line[{{-2.474584, -4.052875, 16.751440},{-2.636693, -4.302909, 
        16.415947}}],
    Line[{{-2.636693, -4.302909, 16.415947},{-2.808382, -4.578186, 
        16.103216}}],
    Line[{{-2.808382, -4.578186, 16.103216},{-2.991206, -4.880096, 
        15.814740}}],
    Line[{{-2.991206, -4.880096, 15.814740},{-3.186712, -5.210127, 
        15.552311}}],
    Line[{{-3.186712, -5.210127, 15.552311},{-3.396443, -5.569830, 
        15.318077}}],
    Line[{{-3.396443, -5.569830, 15.318077},{-3.621948, -5.960803, 
        15.114575}}],
    Line[{{-3.621948, -5.960803, 15.114575},{-3.864777, -6.384619, 
        14.944801}}],
    Line[{{-3.864777, -6.384619, 14.944801},{-4.126480, -6.842782, 
        14.812249}}],
    Line[{{-4.126480, -6.842782, 14.812249},{-4.408600, -7.336647, 
        14.720979}}],
    Line[{{-4.408600, -7.336647, 14.720979},{-4.712641, -7.867289, 
        14.675673}}],
    Line[{{-4.712641, -7.867289, 14.675673},{-5.040058, -8.435402, 
        14.681688}}],
    Line[{{-5.040058, -8.435402, 14.681688},{-5.392205, -9.041124, 
        14.745102}}],
    Line[{{-5.392205, -9.041124, 14.745102},{-5.770277, -9.683791, 
        14.872724}}],
    Line[{{-5.770277, -9.683791, 14.872724},{-6.175261, -10.361779, 
        15.072114}}],
    Line[{{-6.175261, -10.361779, 15.072114},{-6.607822, -11.072119, 
        15.351502}}],
    Line[{{-6.607822, -11.072119, 15.351502},{-7.068207, -11.810221, 
        15.719688}}],
    Line[{{-7.068207, -11.810221, 15.719688},{-7.556106, -12.569485, 
        16.185816}}],
    Line[{{-7.556106, -12.569485, 16.185816},{-8.070502, -13.340932, 
        16.759079}}],
    Line[{{-8.070502, -13.340932, 16.759079},{-8.609489, -14.112805, 
        17.448252}}],
    Line[{{-8.609489, -14.112805, 17.448252},{-9.170074, -14.870243, 
        18.261040}}],
    Line[{{-9.170074, -14.870243, 18.261040},{-9.747974, -15.595080, 
        19.203247}}],
    Line[{{-9.747974, -15.595080, 19.203247},{-10.337427, -16.265816, 
        20.277834}}],
    Line[{{-10.337427, -16.265816, 20.277834},{-10.931012, -16.857805, 
        21.483749}}],
    Line[{{-10.931012, -16.857805, 21.483749},{-11.519551, -17.344044, 
        22.814634}}],
    Line[{{-11.519551, -17.344044, 22.814634},{-12.092093, -17.696169, 
        24.257725}}],
    Line[{{-12.092093, -17.696169, 24.257725},{-12.636030, -17.886147, 
        25.792854}}],
    Line[{{-12.636030, -17.886147, 25.792854},{-13.137386, -17.888407, 
        27.391970}}],
    Line[{{-13.137386, -17.888407, 27.391970},{-13.581302, -17.682358, 
        29.019329}}],
    Line[{{-13.581302, -17.682358, 29.019329},{-13.952719, -17.255007, 
        30.632599}}],
    Line[{{-13.952719, -17.255007, 30.632599},{-14.237242, -16.603346, 
        32.184963}}],
    Line[{{-14.237242, -16.603346, 32.184963},{-14.422113, -15.736050, 
        33.628132}}],
    Line[{{-14.422113, -15.736050, 33.628132},{-14.497211, -14.674003, 
        34.916096}}],
    Line[{{-14.497211, -14.674003, 34.916096},{-14.455931, -13.449554, 
        36.008881}}],
    Line[{{-14.455931, -13.449554, 36.008881},{-14.295841, -12.104314, 
        36.876041}}],
    Line[{{-14.295841, -12.104314, 36.876041},{-14.019023, -10.685779, 
        37.499100}}],
    Line[{{-14.019023, -10.685779, 37.499100},{-13.632000, -9.243278, 
        37.872604}}],
    Line[{{-13.632000, -9.243278, 37.872604},{-13.145290, -7.823913, 
        38.003674}}],
    Line[{{-13.145290, -7.823913, 38.003674},{-12.572642, -6.469057, 
        37.910191}}],
    Line[{{-12.572642, -6.469057, 37.910191},{-11.930049, -5.211848, 
        37.618080}}],
    Line[{{-11.930049, -5.211848, 37.618080},{-11.234683, -4.075966, 
        37.158127}}],
    Line[{{-11.234683, -4.075966, 37.158127},{-10.503868, -3.075511, 
        36.562939}}],
    Line[{{-10.503868, -3.075511, 36.562939},{-9.754192, -2.215867, 
        35.864330}}],
    Line[{{-9.754192, -2.215867, 35.864330},{-9.000813, -1.495175, 
        35.091427}}],
    Line[{{-9.000813, -1.495175, 35.091427},{-8.256986, -0.906070, 
        34.269489}}],
    Line[{{-8.256986, -0.906070, 34.269489},{-7.533811, -0.437444, 
        33.419399}}],
    Line[{{-7.533811, -0.437444, 33.419399},{-6.840158, -0.076010, 
        32.557663}}],
    Line[{{-6.840158, -0.076010, 32.557663},{-6.182737, 0.192411, 
        31.696758}}],
    Line[{{-6.182737, 0.192411, 31.696758},{-5.566264, 0.381921, 30.845688}}],
    
    Line[{{-5.566264, 0.381921, 30.845688},{-4.993700, 0.505878, 30.010607}}],
    
    Line[{{-4.993700, 0.505878, 30.010607},{-4.466502, 0.576472, 29.195423}}],
    
    Line[{{-4.466502, 0.576472, 29.195423},{-3.984900, 0.604505, 28.402372}}],
    
    Line[{{-3.984900, 0.604505, 28.402372},{-3.548139, 0.599324, 27.632475}}],
    
    Line[{{-3.548139, 0.599324, 27.632475},{-3.154721, 0.568841, 26.885914}}],
    
    Line[{{-3.154721, 0.568841, 26.885914},{-2.802598, 0.519625, 26.162334}}],
    
    Line[{{-2.802598, 0.519625, 26.162334},{-2.489357, 0.457027, 25.461056}}],
    
    Line[{{-2.489357, 0.457027, 25.461056},{-2.212356, 0.385324, 24.781216}}],
    
    Line[{{-2.212356, 0.385324, 24.781216},{-1.968844, 0.307857, 24.121893}}],
    
    Line[{{-1.968844, 0.307857, 24.121893},{-1.756052, 0.227173, 23.482157}}],
    
    Line[{{-1.756052, 0.227173, 23.482157},{-1.571268, 0.145152, 22.861118}}],
    
    Line[{{-1.571268, 0.145152, 22.861118},{-1.411886, 0.063122, 22.257948}}],
    
    Line[{{-1.411886, 0.063122, 22.257948},{-1.275443, -0.018045, 
        21.671885}}],
    Line[{{-1.275443, -0.018045, 21.671885},{-1.159647, -0.097842, 
        21.102240}}],
    Line[{{-1.159647, -0.097842, 21.102240},{-1.062390, -0.176056, 
        20.548391}}],
    Line[{{-1.062390, -0.176056, 20.548391},{-0.981756, -0.252708, 
        20.009779}}],
    Line[{{-0.981756, -0.252708, 20.009779},{-0.916023, -0.328001, 
        19.485899}}],
    Line[{{-0.916023, -0.328001, 19.485899},{-0.863660, -0.402280, 
        18.976294}}],
    Line[{{-0.863660, -0.402280, 18.976294},{-0.823319, -0.476006, 
        18.480547}}],
    Line[{{-0.823319, -0.476006, 18.480547},{-0.793829, -0.549719, 
        17.998283}}],
    Line[{{-0.793829, -0.549719, 17.998283},{-0.774184, -0.624032, 
        17.529161}}],
    Line[{{-0.774184, -0.624032, 17.529161},{-0.763538, -0.699610, 
        17.072866}}],
    Line[{{-0.763538, -0.699610, 17.072866},{-0.761187, -0.777165, 
        16.629112}}],
    Line[{{-0.761187, -0.777165, 16.629112},{-0.766567, -0.857447, 
        16.197641}}],
    Line[{{-0.766567, -0.857447, 16.197641},{-0.779239, -0.941248, 
        15.778226}}],
    Line[{{-0.779239, -0.941248, 15.778226},{-0.798885, -1.029396, 
        15.370661}}],
    Line[{{-0.798885, -1.029396, 15.370661},{-0.825295, -1.122764, 
        14.974771}}],
    Line[{{-0.825295, -1.122764, 14.974771},{-0.858367, -1.222268, 
        14.590419}}],
    Line[{{-0.858367, -1.222268, 14.590419},{-0.898097, -1.328879, 
        14.217494}}],
    Line[{{-0.898097, -1.328879, 14.217494},{-0.944578, -1.443627, 
        13.855933}}],
    Line[{{-0.944578, -1.443627, 13.855933},{-0.997994, -1.567612, 
        13.505713}}],
    Line[{{-0.997994, -1.567612, 13.505713},{-1.058620, -1.702011, 
        13.166869}}],
    Line[{{-1.058620, -1.702011, 13.166869},{-1.126822, -1.848091, 
        12.839493}}],
    Line[{{-1.126822, -1.848091, 12.839493},{-1.203055, -2.007217, 
        12.523749}}],
    Line[{{-1.203055, -2.007217, 12.523749},{-1.287868, -2.180868, 
        12.219893}}],
    Line[{{-1.287868, -2.180868, 12.219893},{-1.381903, -2.370646, 
        11.928272}}],
    Line[{{-1.381903, -2.370646, 11.928272},{-1.485900, -2.578290, 
        11.649361}}],
    Line[{{-1.485900, -2.578290, 11.649361},{-1.600701, -2.805687, 
        11.383773}}],
    Line[{{-1.600701, -2.805687, 11.383773},{-1.727256, -3.054886, 
        11.132290}}],
    Line[{{-1.727256, -3.054886, 11.132290},{-1.866627, -3.328108, 
        10.895902}}],
    Line[{{-1.866627, -3.328108, 10.895902},{-2.019996, -3.627751, 
        10.675835}}],
    Line[{{-2.019996, -3.627751, 10.675835},{-2.188667, -3.956403, 
        10.473603}}],
    Line[{{-2.188667, -3.956403, 10.473603},{-2.374079, -4.316833, 
        10.291078}}],
    Line[{{-2.374079, -4.316833, 10.291078},{-2.577804, -4.712001, 
        10.130520}}],
    Line[{{-2.577804, -4.712001, 10.130520},{-2.801554, -5.145019, 
        9.994700}}],
    Line[{{-2.801554, -5.145019, 9.994700},{-3.047183, -5.619144, 9.886953}}],
    
    Line[{{-3.047183, -5.619144, 9.886953},{-3.316683, -6.137731, 9.811299}}],
    
    Line[{{-3.316683, -6.137731, 9.811299},{-3.612175, -6.704134, 9.772568}}],
    
    Line[{{-3.612175, -6.704134, 9.772568},{-3.935897, -7.321639, 9.776516}}],
    
    Line[{{-3.935897, -7.321639, 9.776516},{-4.290177, -7.993301, 9.829980}}],
    
    Line[{{-4.290177, -7.993301, 9.829980},{-4.677390, -8.721739, 9.941031}}],
    
    Line[{{-4.677390, -8.721739, 9.941031},{-5.099903, -9.508874, 
        10.119113}}],
    Line[{{-5.099903, -9.508874, 10.119113},{-5.560000, -10.355598, 
        10.375188}}],
    Line[{{-5.560000, -10.355598, 10.375188},{-6.059760, -11.261299, 
        10.721833}}],
    Line[{{-6.059760, -11.261299, 10.721833},{-6.600908, -12.223282, 
        11.173254}}],
    Line[{{-6.600908, -12.223282, 11.173254},{-7.184623, -13.236110, 
        11.745210}}],
    Line[{{-7.184623, -13.236110, 11.745210},{-7.811288, -14.290758, 
        12.454743}}],
    Line[{{-7.811288, -14.290758, 12.454743},{-8.480182, -15.373717, 
        13.319674}}],
    Line[{{-8.480182, -15.373717, 13.319674},{-9.189108, -16.465998, 
        14.357746}}],
    Line[{{-9.189108, -16.465998, 14.357746},{-9.933973, -17.542208, 
        15.585361}}],
    Line[{{-9.933973, -17.542208, 15.585361},{-10.708310, -18.569834, 
        17.015726}}],
    Line[{{-10.708310, -18.569834, 17.015726},{-11.502817, -19.508953, 
        18.656574}}],
    Line[{{-11.502817, -19.508953, 18.656574},{-12.304935, -20.312685, 
        20.507317}}],
    Line[{{-12.304935, -20.312685, 20.507317},{-13.098558, -20.928699, 
        22.555939}}],
    Line[{{-13.098558, -20.928699, 22.555939},{-13.863978, -21.302109, 
        24.776005}}],
    Line[{{-13.863978, -21.302109, 24.776005},{-14.578189, -21.379877, 
        27.124380}}],
    Line[{{-14.578189, -21.379877, 27.124380},{-15.215645, -21.116648, 
        29.540457}}],
    Line[{{-15.215645, -21.116648, 29.540457},{-15.749550, -20.481417, 
        31.947657}}],
    Line[{{-15.749550, -20.481417, 31.947657},{-16.153677, -19.464005, 
        34.257881}}],
    Line[{{-16.153677, -19.464005, 34.257881},{-16.404539, -18.079844, 
        36.378693}}],
    Line[{{-16.404539, -18.079844, 36.378693},{-16.483679, -16.371880, 
        38.222614}}],
    Line[{{-16.483679, -16.371880, 38.222614},{-16.379742, -14.408291, 
        39.717075}}],
    Line[{{-16.379742, -14.408291, 39.717075},{-16.089914, -12.276111, 
        40.812798}}],
    Line[{{-16.089914, -12.276111, 40.812798},{-15.620483, -10.071826, 
        41.488987}}],
    Line[{{-15.620483, -10.071826, 41.488987},{-14.986342, -7.890592, 
        41.754097}}],
    Line[{{-14.986342, -7.890592, 41.754097},{-14.209543, -5.816470, 
        41.642159}}],
    Line[{{-14.209543, -5.816470, 41.642159},{-13.317206, -3.915356, 
        41.206070}}],
    Line[{{-13.317206, -3.915356, 41.206070},{-12.339111, -2.231489, 
        40.509289}}],
    Line[{{-12.339111, -2.231489, 40.509289},{-11.305353, -0.787493, 
        39.617821}}],
    Line[{{-11.305353, -0.787493, 39.617821},{-10.244371, 0.412901, 
        38.593754}}],
    Line[{{-10.244371, 0.412901, 38.593754},{-9.181513, 1.380596, 
        37.491013}}],
    Line[{{-9.181513, 1.380596, 37.491013},{-8.138152, 2.136456, 36.353249}}],
    
    Line[{{-8.138152, 2.136456, 36.353249},{-7.131343, 2.706995, 35.213524}}],
    
    Line[{{-7.131343, 2.706995, 35.213524},{-6.173861, 3.120888, 34.095184}}],
    
    Line[{{-6.173861, 3.120888, 34.095184},{-5.274540, 3.406450, 33.013405}}],
    
    Line[{{-5.274540, 3.406450, 33.013405},{-4.438765, 3.590010, 31.976927}}],
    
    Line[{{-4.438765, 3.590010, 31.976927},{-3.669035, 3.695022, 30.989759}}],
    
    Line[{{-3.669035, 3.695022, 30.989759},{-2.965537, 3.741712, 30.052622}}],
    
    Line[{{-2.965537, 3.741712, 30.052622},{-2.326669, 3.747084, 29.164127}}],
    
    Line[{{-2.326669, 3.747084, 29.164127},{-1.749513, 3.725137, 28.321657}}],
    
    Line[{{-1.749513, 3.725137, 28.321657},{-1.230229, 3.687197, 27.522011}}],
    
    Line[{{-1.230229, 3.687197, 27.522011},{-0.764378, 3.642285, 26.761822}}],
    
    Line[{{-0.764378, 3.642285, 26.761822},{-0.347180, 3.597488, 26.037836}}],
    
    Line[{{-0.347180, 3.597488, 26.037836},{0.026281, 3.558299, 25.347076}}],
    Line[{{0.026281, 3.558299, 25.347076},{0.360916, 3.528924, 24.686916}}],
    Line[{{0.360916, 3.528924, 24.686916},{0.661514, 3.512545, 24.055101}}],
    Line[{{0.661514, 3.512545, 24.055101},{0.932673, 3.511545, 23.449762}}],
    Line[{{0.932673, 3.511545, 23.449762},{1.178748, 3.527699, 22.869383}}],
    Line[{{1.178748, 3.527699, 22.869383},{1.403826, 3.562329, 22.312769}}],
    Line[{{1.403826, 3.562329, 22.312769},{1.611714, 3.616428, 21.779024}}],
    Line[{{1.611714, 3.616428, 21.779024},{1.805939, 3.690772, 21.267521}}],
    Line[{{1.805939, 3.690772, 21.267521},{1.989761, 3.785995, 20.777872}}],
    Line[{{1.989761, 3.785995, 20.777872},{2.166183, 3.902661, 20.309919}}],
    Line[{{2.166183, 3.902661, 20.309919},{2.337978, 4.041311, 19.863716}}],
    Line[{{2.337978, 4.041311, 19.863716},{2.507704, 4.202506, 19.439528}}],
    Line[{{2.507704, 4.202506, 19.439528},{2.677733, 4.386849, 19.037825}}],
    Line[{{2.677733, 4.386849, 19.037825},{2.850271, 4.595009, 18.659302}}],
    Line[{{2.850271, 4.595009, 18.659302},{3.027382, 4.827723, 18.304876}}],
    Line[{{3.027382, 4.827723, 18.304876},{3.211004, 5.085802, 17.975712}}],
    Line[{{3.211004, 5.085802, 17.975712},{3.402975, 5.370122, 17.673243}}],
    Line[{{3.402975, 5.370122, 17.673243},{3.605042, 5.681606, 17.399197}}],
    Line[{{3.605042, 5.681606, 17.399197},{3.818874, 6.021195, 17.155624}}],
    Line[{{3.818874, 6.021195, 17.155624},{4.046072, 6.389820, 16.944935}}],
    Line[{{4.046072, 6.389820, 16.944935},{4.288169, 6.788335, 16.769932}}],
    Line[{{4.288169, 6.788335, 16.769932},{4.546629, 7.217474, 16.633850}}],
    Line[{{4.546629, 7.217474, 16.633850},{4.822837, 7.677752, 16.540388}}],
    Line[{{4.822837, 7.677752, 16.540388},{5.118078, 8.169372, 16.493736}}],
    Line[{{5.118078, 8.169372, 16.493736},{5.433517, 8.692094, 16.498600}}],
    Line[{{5.433517, 8.692094, 16.498600},{5.770160, 9.245106, 16.560217}}],
    Line[{{5.770160, 9.245106, 16.560217},{6.128799, 9.826818, 16.684313}}],
    Line[{{6.128799, 9.826818, 16.684313},{6.509959, 10.434690, 16.877077}}],
    Line[{{6.509959, 10.434690, 16.877077},{6.913815, 11.064977, 17.145063}}],
    
    Line[{{6.913815, 11.064977, 17.145063},{7.340104, 11.712511, 17.495024}}],
    
    Line[{{7.340104, 11.712511, 17.495024},{7.788012, 12.370420, 17.933701}}],
    
    Line[{{7.788012, 12.370420, 17.933701},{8.256059, 13.029881, 18.467514}}],
    
    Line[{{8.256059, 13.029881, 18.467514},{8.741966, 13.679943, 19.102097}}],
    
    Line[{{8.741966, 13.679943, 19.102097},{9.242514, 14.307316, 19.841833}}],
    
    Line[{{9.242514, 14.307316, 19.841833},{9.753409, 14.896379, 20.689150}}],
    
    Line[{{9.753409, 14.896379, 20.689150},{
      10.269187, 15.429365, 21.643801}}],
    Line[{{10.269187, 15.429365, 21.643801},{
      10.783093, 15.886580, 22.702059}}],
    Line[{{10.783093, 15.886580, 22.702059},{
      11.287100, 16.247229, 23.855930}}],
    Line[{{11.287100, 16.247229, 23.855930},{
      11.771936, 16.490253, 25.092472}}],
    Line[{{11.771936, 16.490253, 25.092472},{
      12.227255, 16.595659, 26.393339}}],
    Line[{{12.227255, 16.595659, 26.393339},{
      12.641893, 16.546041, 27.734663}}],
    Line[{{12.641893, 16.546041, 27.734663},{
      13.004295, 16.328304, 29.087498}}],
    Line[{{13.004295, 16.328304, 29.087498},{
      13.303035, 15.935333, 30.418823}}],
    Line[{{13.303035, 15.935333, 30.418823},{
      13.527439, 15.367345, 31.693148}}],
    Line[{{13.527439, 15.367345, 31.693148},{
      13.668277, 14.632912, 32.874626}}],
    Line[{{13.668277, 14.632912, 32.874626},{
      13.718414, 13.748980, 33.929554}}],
    Line[{{13.718414, 13.748980, 33.929554},{
      13.673394, 12.740252, 34.828815}}],
    Line[{{13.673394, 12.740252, 34.828815},{
      13.531850, 11.637630, 35.550076}}],
    Line[{{13.531850, 11.637630, 35.550076},{
      13.295698, 10.475982, 36.079304}}],
    Line[{{13.295698, 10.475982, 36.079304},{
      12.970077, 9.291518, 36.411457}}],
    Line[{{12.970077, 9.291518, 36.411457},{12.563039, 8.119161, 36.550251}}],
    
    Line[{{12.563039, 8.119161, 36.550251},{12.085036, 6.990208, 36.507080}}],
    
    Line[{{12.085036, 6.990208, 36.507080},{11.548255, 5.930610, 36.299335}}],
    
    Line[{{11.548255, 5.930610, 36.299335},{10.965892, 4.959960, 35.948433}}],
    
    Line[{{10.965892, 4.959960, 35.948433},{10.351427, 4.091227, 35.477764}}],
    
    Line[{{10.351427, 4.091227, 35.477764},{9.717987, 3.331113, 34.910931}}],
    Line[{{9.717987, 3.331113, 34.910931},{9.077815, 2.680853, 34.270306}}],
    Line[{{9.077815, 2.680853, 34.270306},{8.441884, 2.137285, 33.576061}}],
    Line[{{8.441884, 2.137285, 33.576061},{7.819656, 1.693989, 32.845608}}],
    Line[{{7.819656, 1.693989, 32.845608},{7.218967, 1.342388, 32.093403}}],
    Line[{{7.218967, 1.342388, 32.093403},{6.646027, 1.072700, 31.331022}}],
    Line[{{6.646027, 1.072700, 31.331022},{6.105498, 0.874715, 30.567429}}],
    Line[{{6.105498, 0.874715, 30.567429},{5.600630, 0.738384, 29.809311}}],
    Line[{{5.600630, 0.738384, 29.809311},{5.133432, 0.654225, 29.061487}}],
    Line[{{5.133432, 0.654225, 29.061487},{4.704859, 0.613579, 28.327276}}],
    Line[{{4.704859, 0.613579, 28.327276},{4.314996, 0.608763, 27.608850}}],
    Line[{{4.314996, 0.608763, 27.608850},{3.963239, 0.633114, 26.907518}}],
    Line[{{3.963239, 0.633114, 26.907518},{3.648455, 0.680986, 26.223978}}],
    Line[{{3.648455, 0.680986, 26.223978},{3.369130, 0.747693, 25.558498}}],
    Line[{{3.369130, 0.747693, 25.558498},{3.123492, 0.829434, 24.911070}}],
    Line[{{3.123492, 0.829434, 24.911070},{2.909615, 0.923208, 24.281515}}],
    Line[{{2.909615, 0.923208, 24.281515},{2.725503, 1.026719, 23.669554}}],
    Line[{{2.725503, 1.026719, 23.669554},{2.569165, 1.138281, 23.074877}}],
    Line[{{2.569165, 1.138281, 23.074877},{2.438665, 1.256740, 22.497162}}],
    Line[{{2.438665, 1.256740, 22.497162},{2.332163, 1.381396, 21.936115}}],
    Line[{{2.332163, 1.381396, 21.936115},{2.247946, 1.511929, 21.391479}}],
    Line[{{2.247946, 1.511929, 21.391479},{2.184450, 1.648347, 20.863043}}],
    Line[{{2.184450, 1.648347, 20.863043},{2.140276, 1.790932, 20.350653}}],
    Line[{{2.140276, 1.790932, 20.350653},{2.114194, 1.940199, 19.854216}}],
    Line[{{2.114194, 1.940199, 19.854216},{2.105152, 2.096862, 19.373705}}],
    Line[{{2.105152, 2.096862, 19.373705},{2.112273, 2.261808, 18.909168}}],
    Line[{{2.112273, 2.261808, 18.909168},{2.134857, 2.436075, 18.460732}}],
    Line[{{2.134857, 2.436075, 18.460732},{2.172374, 2.620834, 18.028608}}],
    Line[{{2.172374, 2.620834, 18.028608},{2.224465, 2.817379, 17.613111}}],
    Line[{{2.224465, 2.817379, 17.613111},{2.290930, 3.027120, 17.214666}}],
    Line[{{2.290930, 3.027120, 17.214666},{2.371730, 3.251572, 16.833824}}],
    Line[{{2.371730, 3.251572, 16.833824},{2.466979, 3.492354, 16.471285}}],
    Line[{{2.466979, 3.492354, 16.471285},{2.576937, 3.751185, 16.127916}}],
    Line[{{2.576937, 3.751185, 16.127916},{2.702010, 4.029875, 15.804784}}],
    Line[{{2.702010, 4.029875, 15.804784},{2.842740, 4.330324, 15.503179}}],
    Line[{{2.842740, 4.330324, 15.503179},{2.999803, 4.654506, 15.224655}}],
    Line[{{2.999803, 4.654506, 15.224655},{3.174001, 5.004459, 14.971070}}],
    Line[{{3.174001, 5.004459, 14.971070},{3.366258, 5.382263, 14.744633}}],
    Line[{{3.366258, 5.382263, 14.744633},{3.577604, 5.790005, 14.547952}}],
    Line[{{3.577604, 5.790005, 14.547952},{3.809175, 6.229743, 14.384099}}],
    Line[{{3.809175, 6.229743, 14.384099},{4.062184, 6.703440, 14.256664}}],
    Line[{{4.062184, 6.703440, 14.256664},{4.337913, 7.212892, 14.169831}}],
    Line[{{4.337913, 7.212892, 14.169831},{4.637678, 7.759618, 14.128431}}],
    Line[{{4.637678, 7.759618, 14.128431},{4.962798, 8.344739, 14.138020}}],
    Line[{{4.962798, 8.344739, 14.138020},{5.314544, 8.968794, 14.204914}}],
    Line[{{5.314544, 8.968794, 14.204914},{5.694085, 9.631549, 14.336256}}],
    Line[{{5.694085, 9.631549, 14.336256},{6.102404, 10.331722, 14.539983}}],
    Line[{{6.102404, 10.331722, 14.539983},{6.540211, 11.066696, 14.824830}}],
    
    Line[{{6.540211, 11.066696, 14.824830},{7.007815, 11.832147, 15.200183}}],
    
    Line[{{7.007815, 11.832147, 15.200183},{7.504992, 12.621657, 15.675920}}],
    
    Line[{{7.504992, 12.621657, 15.675920},{8.030803, 13.426275, 16.262066}}],
    
    Line[{{8.030803, 13.426275, 16.262066},{8.583413, 14.234109, 16.968328}}],
    
    Line[{{8.583413, 14.234109, 16.968328},{9.159863, 15.029882, 17.803448}}],
    
    Line[{{9.159863, 15.029882, 17.803448},{9.755858, 15.794744, 18.774315}}],
    
    Line[{{9.755858, 15.794744, 18.774315},{
      10.365530, 16.506111, 19.884905}}],
    Line[{{10.365530, 16.506111, 19.884905},{
      10.981248, 17.137892, 21.135019}}],
    Line[{{10.981248, 17.137892, 21.135019},{
      11.593486, 17.661177, 22.518902}}],
    Line[{{11.593486, 17.661177, 22.518902},{
      12.190779, 18.045349, 24.023928}}],
    Line[{{12.190779, 18.045349, 24.023928},{
      12.759812, 18.259815, 25.629408}}],
    Line[{{12.759812, 18.259815, 25.629408},{
      13.285732, 18.276419, 27.305979}}],
    Line[{{13.285732, 18.276419, 27.305979},{
      13.752648, 18.072168, 29.015776}}],
    Line[{{13.752648, 18.072168, 29.015776},{
      14.144361, 17.632196, 30.713470}}],
    Line[{{14.144361, 17.632196, 30.713470},{
      14.445304, 16.952484, 32.348606}}],
    Line[{{14.445304, 16.952484, 32.348606},{
      14.641617, 16.041805, 33.868866}}],
    Line[{{14.641617, 16.041805, 33.868866},{
      14.722249, 14.922481, 35.224243}}],
    Line[{{14.722249, 14.922481, 35.224243},{
      14.679956, 13.629539, 36.371357}}],
    Line[{{14.679956, 13.629539, 36.371357},{
      14.512037, 12.208247, 37.277325}}],
    Line[{{14.512037, 12.208247, 37.277325},{
      14.220705, 10.710325, 37.922512}}],
    Line[{{14.220705, 10.710325, 37.922512},{
      13.813007, 9.189379, 38.301701}}],
    Line[{{13.813007, 9.189379, 38.301701},{13.300331, 7.696412, 38.423477}}],
    
    Line[{{13.300331, 7.696412, 38.423477},{12.697544, 6.275850, 38.308201}}],
    
    Line[{{12.697544, 6.275850, 38.308201},{12.021894, 4.962849, 37.984825}}],
    
    Line[{{12.021894, 4.962849, 37.984825},{11.291827, 3.782015, 37.487331}}],
    
    Line[{{11.291827, 3.782015, 37.487331},{10.525863, 2.747409, 36.851330}}],
    
    Line[{{10.525863, 2.747409, 36.851330},{9.741625, 1.863625, 36.111191}}],
    Line[{{9.741625, 1.863625, 36.111191},{8.955108, 1.127502, 35.298019}}],
    Line[{{8.955108, 1.127502, 35.298019},{8.180188, 0.530117, 34.438473}}],
    Line[{{8.180188, 0.530117, 34.438473},{7.428371, 0.058738, 33.554272}}],
    Line[{{7.428371, 0.058738, 33.554272},{6.708745, -0.301467, 32.662327}}],
    Line[{{6.708745, -0.301467, 32.662327},{6.028075, -0.566056, 31.775167}}],
    
    Line[{{6.028075, -0.566056, 31.775167},{5.391009, -0.750296, 30.901625}}],
    
    Line[{{5.391009, -0.750296, 30.901625},{4.800343, -0.868492, 30.047527}}],
    
    Line[{{4.800343, -0.868492, 30.047527},{4.257308, -0.933578, 29.216393}}],
    
    Line[{{4.257308, -0.933578, 29.216393},{3.761866, -0.956921, 28.410044}}],
    
    Line[{{3.761866, -0.956921, 28.410044},{3.312972, -0.948280, 27.629089}}],
    
    Line[{{3.312972, -0.948280, 27.629089},{2.908832, -0.915864, 26.873348}}],
    
    Line[{{2.908832, -0.915864, 26.873348},{2.547111, -0.866446, 26.142132}}],
    
    Line[{{2.547111, -0.866446, 26.142132},{2.225112, -0.805514, 25.434469}}],
    
    Line[{{2.225112, -0.805514, 25.434469},{1.939933, -0.737435, 24.749262}}],
    
    Line[{{1.939933, -0.737435, 24.749262},{1.688580, -0.665616, 24.085384}}],
    
    Line[{{1.688580, -0.665616, 24.085384},{1.468056, -0.592648, 23.441742}}],
    
    Line[{{1.468056, -0.592648, 23.441742},{1.275441, -0.520452, 22.817301}}],
    
    Line[{{1.275441, -0.520452, 22.817301},{1.107933, -0.450395, 22.211119}}],
    
    Line[{{1.107933, -0.450395, 22.211119},{0.962892, -0.383399, 21.622337}}],
    
    Line[{{0.962892, -0.383399, 21.622337},{0.837860, -0.320033, 21.050184}}],
    
    Line[{{0.837860, -0.320033, 21.050184},{0.730569, -0.260585, 20.493967}}],
    
    Line[{{0.730569, -0.260585, 20.493967},{0.638954, -0.205131, 19.953058}}],
    
    Line[{{0.638954, -0.205131, 19.953058},{0.561145, -0.153588, 19.426897}}],
    
    Line[{{0.561145, -0.153588, 19.426897},{0.495465, -0.105750, 18.914967}}],
    
    Line[{{0.495465, -0.105750, 18.914967},{0.440421, -0.061330, 18.416800}}],
    
    Line[{{0.440421, -0.061330, 18.416800},{0.394692, -0.019979, 17.931959}}],
    
    Line[{{0.394692, -0.019979, 17.931959},{0.357118, 0.018686, 17.460045}}],
    Line[{{0.357118, 0.018686, 17.460045},{0.326685, 0.055072, 17.000675}}],
    Line[{{0.326685, 0.055072, 17.000675},{0.302519, 0.089598, 16.553495}}],
    Line[{{0.302519, 0.089598, 16.553495},{0.283865, 0.122683, 16.118166}}],
    Line[{{0.283865, 0.122683, 16.118166},{0.270083, 0.154746, 15.694366}}],
    Line[{{0.270083, 0.154746, 15.694366},{0.260631, 0.186202, 15.281785}}],
    Line[{{0.260631, 0.186202, 15.281785},{0.255060, 0.217459, 14.880130}}],
    Line[{{0.255060, 0.217459, 14.880130},{0.253000, 0.248920, 14.489116}}],
    Line[{{0.253000, 0.248920, 14.489116},{0.254156, 0.280984, 14.108470}}],
    Line[{{0.254156, 0.280984, 14.108470},{0.258300, 0.314052, 13.737931}}],
    Line[{{0.258300, 0.314052, 13.737931},{0.265261, 0.348522, 13.377248}}],
    Line[{{0.265261, 0.348522, 13.377248},{0.274924, 0.384802, 13.026177}}],
    Line[{{0.274924, 0.384802, 13.026177},{0.287225, 0.423308, 12.684489}}],
    Line[{{0.287225, 0.423308, 12.684489},{0.302145, 0.464470, 12.351964}}],
    Line[{{0.302145, 0.464470, 12.351964},{0.319709, 0.508740, 12.028391}}],
    Line[{{0.319709, 0.508740, 12.028391},{0.339984, 0.556593, 11.713575}}],
    Line[{{0.339984, 0.556593, 11.713575},{0.363077, 0.608535, 11.407331}}],
    Line[{{0.363077, 0.608535, 11.407331},{0.389136, 0.665109, 11.109488}}],
    Line[{{0.389136, 0.665109, 11.109488},{0.418346, 0.726902, 10.819894}}],
    Line[{{0.418346, 0.726902, 10.819894},{0.450936, 0.794550, 10.538410}}],
    Line[{{0.450936, 0.794550, 10.538410},{0.487173, 0.868748, 10.264920}}],
    Line[{{0.487173, 0.868748, 10.264920},{0.527370, 0.950257, 9.999331}}],
    Line[{{0.527370, 0.950257, 9.999331},{0.571886, 1.039913, 9.741575}}],
    Line[{{0.571886, 1.039913, 9.741575},{0.621129, 1.138634, 9.491618}}],
    Line[{{0.621129, 1.138634, 9.491618},{0.675561, 1.247438, 9.249459}}],
    Line[{{0.675561, 1.247438, 9.249459},{0.735700, 1.367444, 9.015143}}],
    Line[{{0.735700, 1.367444, 9.015143},{0.802127, 1.499891, 8.788768}}],
    Line[{{0.802127, 1.499891, 8.788768},{0.875496, 1.646152, 8.570493}}],
    Line[{{0.875496, 1.646152, 8.570493},{0.956530, 1.807740, 8.360549}}],
    Line[{{0.956530, 1.807740, 8.360549},{1.046039, 1.986333, 8.159265}}],
    Line[{{1.046039, 1.986333, 8.159265},{1.144924, 2.183784, 7.967072}}],
    Line[{{1.144924, 2.183784, 7.967072},{1.254183, 2.402138, 7.784537}}],
    Line[{{1.254183, 2.402138, 7.784537},{1.374927, 2.643654, 7.612391}}],
    Line[{{1.374927, 2.643654, 7.612391},{1.508385, 2.910813, 7.451552}}],
    Line[{{1.508385, 2.910813, 7.451552},{1.655917, 3.206344, 7.303191}}],
    Line[{{1.655917, 3.206344, 7.303191},{1.819027, 3.533231, 7.168750}}],
    Line[{{1.819027, 3.533231, 7.168750},{1.999371, 3.894729, 7.050040}}],
    Line[{{1.999371, 3.894729, 7.050040},{2.198772, 4.294368, 6.949291}}],
    Line[{{2.198772, 4.294368, 6.949291},{2.419227, 4.735950, 6.869255}}],
    Line[{{2.419227, 4.735950, 6.869255},{2.662920, 5.223534, 6.813310}}],
    Line[{{2.662920, 5.223534, 6.813310},{2.932223, 5.761410, 6.785588}}],
    Line[{{2.932223, 5.761410, 6.785588},{3.229697, 6.354024, 6.791136}}],
    Line[{{3.229697, 6.354024, 6.791136},{3.558095, 7.005925, 6.836075}}],
    Line[{{3.558095, 7.005925, 6.836075},{3.920328, 7.721569, 6.927819}}],
    Line[{{3.920328, 7.721569, 6.927819},{4.319452, 8.505168, 7.075284}}],
    Line[{{4.319452, 8.505168, 7.075284},{4.758608, 9.360387, 7.289128}}],
    Line[{{4.758608, 9.360387, 7.289128},{5.240937, 10.289930, 7.581992}}],
    Line[{{5.240937, 10.289930, 7.581992},{5.769484, 11.295071, 7.968729}}],
    Line[{{5.769484, 11.295071, 7.968729},{6.347021, 12.374894, 8.466556}}],
    Line[{{6.347021, 12.374894, 8.466556},{6.975829, 13.525451, 9.095102}}],
    Line[{{6.975829, 13.525451, 9.095102},{7.657407, 14.738655, 9.876288}}],
    Line[{{7.657407, 14.738655, 9.876288},{8.392091, 16.000978, 10.833878}}],
    Line[{{8.392091, 16.000978, 10.833878},{9.178572, 17.291965, 11.992590}}],
    
    Line[{{9.178572, 17.291965, 11.992590},{
      10.013323, 18.582714, 13.376608}}],
    Line[{{10.013323, 18.582714, 13.376608},{
      10.889937, 19.834492, 15.007333}}],
    Line[{{10.889937, 19.834492, 15.007333},{
      11.798409, 20.997732, 16.900270}}],
    Line[{{11.798409, 20.997732, 16.900270},{
      12.724448, 22.012148, 19.060896}}],
    Line[{{12.724448, 22.012148, 19.060896},{
      13.648914, 22.808144, 21.479971}}],
    Line[{{13.648914, 22.808144, 21.479971},{
      14.547553, 23.310467, 24.128595}}],
    Line[{{14.547553, 23.310467, 24.128595},{
      15.391220, 23.444347, 26.954092}}],
    Line[{{15.391220, 23.444347, 26.954092},{
      16.146793, 23.144159, 29.877974}}],
    Line[{{16.146793, 23.144159, 29.877974},{
      16.778915, 22.363815, 32.797497}}],
    Line[{{16.778915, 22.363815, 32.797497},{
      17.252588, 21.087254, 35.591919}}],
    Line[{{17.252588, 21.087254, 35.591919},{
      17.536398, 19.336252, 38.133743}}],
    Line[{{17.536398, 19.336252, 38.133743},{
      17.605972, 17.173471, 40.303436}}],
    Line[{{17.605972, 17.173471, 40.303436},{
      17.447071, 14.698464, 42.005138}}],
    Line[{{17.447071, 14.698464, 42.005138},{
      17.057650, 12.036699, 43.179581}}],
    Line[{{17.057650, 12.036699, 43.179581},{
      16.448423, 9.323822, 43.810871}}],
    Line[{{16.448423, 9.323822, 43.810871},{15.641793, 6.688615, 43.925751}}],
    
    Line[{{15.641793, 6.688615, 43.925751},{14.669353, 4.238577, 43.585770}}],
    
    Line[{{14.669353, 4.238577, 43.585770},{13.568500, 2.050926, 42.875050}}],
    
    Line[{{13.568500, 2.050926, 42.875050},{12.378823, 0.169858, 41.886822}}],
    
    Line[{{12.378823, 0.169858, 41.886822},{
      11.138845, -1.390757, 40.711761}}],
    Line[{{11.138845, -1.390757, 40.711761},{
      9.883516, -2.641215, 39.429707}}],
    Line[{{9.883516, -2.641215, 39.429707},{8.642612, -3.608482, 38.105301}}],
    
    Line[{{8.642612, -3.608482, 38.105301},{7.439998, -4.329042, 36.786884}}],
    
    Line[{{7.439998, -4.329042, 36.786884},{6.293576, -4.843034, 35.507698}}],
    
    Line[{{6.293576, -4.843034, 35.507698},{5.215724, -5.190092, 34.288334}}],
    
    Line[{{5.215724, -5.190092, 34.288334},{4.214004, -5.406737, 33.139610}}],
    
    Line[{{4.214004, -5.406737, 33.139610},{3.291994, -5.525033, 32.065331}}],
    
    Line[{{3.291994, -5.525033, 32.065331},{2.450115, -5.572149, 31.064613}}],
    
    Line[{{2.450115, -5.572149, 31.064613},{1.686395, -5.570470, 30.133751}}],
    
    Line[{{1.686395, -5.570470, 30.133751},{0.997134, -5.538051, 29.267550}}],
    
    Line[{{0.997134, -5.538051, 29.267550},{0.377453, -5.489175, 28.460270}}],
    
    Line[{{
      0.377453, -5.489175, 28.460270},{-0.178266, -5.434971, 27.706234}}],
    Line[{{-0.178266, -5.434971, 27.706234},{-0.676034, -5.383978, 
        27.000177}}],
    Line[{{-0.676034, -5.383978, 27.000177},{-1.122000, -5.342649, 
        26.337444}}],
    Line[{{-1.122000, -5.342649, 26.337444},{-1.522256, -5.315790, 
        25.714069}}],
    Line[{{-1.522256, -5.315790, 25.714069},{-1.882709, -5.306914, 
        25.126768}}],
    Line[{{-1.882709, -5.306914, 25.126768},{-2.208988, -5.318542, 
        24.572918}}],
    Line[{{-2.208988, -5.318542, 24.572918},{-2.506387, -5.352438, 
        24.050497}}],
    Line[{{-2.506387, -5.352438, 24.050497},{-2.779836, -5.409803, 
        23.558018}}],
    Line[{{-2.779836, -5.409803, 23.558018},{-3.033889, -5.491419, 
        23.094481}}],
    Line[{{-3.033889, -5.491419, 23.094481},{-3.272723, -5.597769, 
        22.659304}}],
    Line[{{-3.272723, -5.597769, 22.659304},{-3.500157, -5.729121, 
        22.252293}}],
    Line[{{-3.500157, -5.729121, 22.252293},{-3.719662, -5.885591, 
        21.873598}}],
    Line[{{-3.719662, -5.885591, 21.873598},{-3.934384, -6.067192, 
        21.523684}}],
    Line[{{-3.934384, -6.067192, 21.523684},{-4.147166, -6.273854, 
        21.203318}}],
    Line[{{-4.147166, -6.273854, 21.203318},{-4.360573, -6.505438, 
        20.913551}}],
    Line[{{-4.360573, -6.505438, 20.913551},{-4.576907, -6.761728, 
        20.655712}}],
    Line[{{-4.576907, -6.761728, 20.655712},{-4.798227, -7.042418, 
        20.431400}}],
    Line[{{-4.798227, -7.042418, 20.431400},{-5.026362, -7.347088, 
        20.242487}}],
    Line[{{-5.026362, -7.347088, 20.242487},{-5.262918, -7.675155, 
        20.091105}}],
    Line[{{-5.262918, -7.675155, 20.091105},{-5.509283, -8.025823, 
        19.979647}}],
    Line[{{-5.509283, -8.025823, 19.979647},{-5.766625, -8.398026, 
        19.910753}}],
    Line[{{-5.766625, -8.398026, 19.910753},{-6.035888, -8.790352, 
        19.887283}}],
    Line[{{-6.035888, -8.790352, 19.887283},{-6.317760, -9.200949, 
        19.912291}}],
    Line[{{-6.317760, -9.200949, 19.912291},{-6.612675, -9.627449, 
        19.988968}}],
    Line[{{-6.612675, -9.627449, 19.988968},{-6.920766, -10.066860, 
        20.120584}}],
    Line[{{-6.920766, -10.066860, 20.120584},{-7.241829, -10.515463, 
        20.310368}}],
    Line[{{-7.241829, -10.515463, 20.310368},{-7.575297, -10.968724, 
        20.561409}}],
    Line[{{-7.575297, -10.968724, 20.561409},{-7.920176, -11.421200, 
        20.876490}}],
    Line[{{-7.920176, -11.421200, 20.876490},{-8.275001, -11.866482, 
        21.257862}}],
    Line[{{-8.275001, -11.866482, 21.257862},{-8.637792, -12.297156, 
        21.707066}}],
    Line[{{-8.637792, -12.297156, 21.707066},{-9.006000, -12.704814, 
        22.224625}}],
    Line[{{-9.006000, -12.704814, 22.224625},{-9.376480, -13.080181, 
        22.809740}}],
    Line[{{-9.376480, -13.080181, 22.809740},{-9.745456, -13.413182, 
        23.460047}}],
    Line[{{-9.745456, -13.413182, 23.460047},{-10.108536, -13.693310, 
        24.171255}}],
    Line[{{-10.108536, -13.693310, 24.171255},{-10.460730, -13.909907, 
        24.936924}}],
    Line[{{-10.460730, -13.909907, 24.936924},{-10.796527, -14.052667, 
        25.748278}}],
    Line[{{-10.796527, -14.052667, 25.748278},{-11.109996, -14.112169, 
        26.594131}}],
    Line[{{-11.109996, -14.112169, 26.594131},{-11.394939, -14.080499, 
        27.460964}}],
    Line[{{-11.394939, -14.080499, 27.460964},{-11.645095, -13.951890, 
        28.333170}}],
    Line[{{-11.645095, -13.951890, 28.333170},{-11.854377, -13.723330, 
        29.193527}}],
    Line[{{-11.854377, -13.723330, 29.193527},{-12.017148, -13.395041, 
        30.023846}}],
    Line[{{-12.017148, -13.395041, 30.023846},{-12.128496, -12.970784, 
        30.805779}}],
    Line[{{-12.128496, -12.970784, 30.805779},{-12.184512, -12.457974, 
        31.521706}}],
    Line[{{-12.184512, -12.457974, 31.521706},{-12.182532, -11.867440, 
        32.155708}}],
    Line[{{-12.182532, -11.867440, 32.155708},{-12.121325, -11.212976, 
        32.694397}}],
    Line[{{-12.121325, -11.212976, 32.694397},{-12.001207, -10.510624, 
        33.127628}}],
    Line[{{-12.001207, -10.510624, 33.127628},{-11.824060, -9.777785, 
        33.448948}}],
    Line[{{-11.824060, -9.777785, 33.448948},{-11.593272, -9.032233, 
        33.655766}}],
    Line[{{-11.593272, -9.032233, 33.655766},{-11.313581, -8.291159, 
        33.749237}}],
    Line[{{-11.313581, -8.291159, 33.749237},{-10.990840, -7.570317, 
        33.733875}}],
    Line[{{-10.990840, -7.570317, 33.733875},{-10.631752, -6.883361, 
        33.616997}}],
    Line[{{-10.631752, -6.883361, 33.616997},{-10.243560, -6.241400, 
        33.407990}}],
    Line[{{-10.243560, -6.241400, 33.407990},{-9.833742, -5.652793, 
        33.117607}}],
    Line[{{-9.833742, -5.652793, 33.117607},{-9.409729, -5.123160, 
        32.757259}}],
    Line[{{-9.409729, -5.123160, 32.757259},{-8.978650, -4.655568, 
        32.338398}}],
    Line[{{-8.978650, -4.655568, 32.338398},{-8.547139, -4.250846, 
        31.872030}}],
    Line[{{-8.547139, -4.250846, 31.872030},{-8.121184, -3.907976, 
        31.368359}}],
    Line[{{-8.121184, -3.907976, 31.368359},{-7.706035, -3.624509, 
        30.836576}}],
    Line[{{-7.706035, -3.624509, 30.836576},{-7.306155, -3.396967, 
        30.284742}}],
    Line[{{-7.306155, -3.396967, 30.284742},{-6.925216, -3.221220, 
        29.719774}}],
    Line[{{-6.925216, -3.221220, 29.719774},{-6.566131, -3.092795, 
        29.147497}}],
    Line[{{-6.566131, -3.092795, 29.147497},{-6.231102, -3.007140, 
        28.572737}}],
    Line[{{-6.231102, -3.007140, 28.572737},{-5.921697, -2.959821, 
        27.999443}}],
    Line[{{-5.921697, -2.959821, 27.999443},{-5.638918, -2.946669, 
        27.430817}}],
    Line[{{-5.638918, -2.946669, 27.430817},{-5.383298, -2.963878, 
        26.869442}}],
    Line[{{-5.383298, -2.963878, 26.869442},{-5.154974, -3.008066, 
        26.317398}}],
    Line[{{-5.154974, -3.008066, 26.317398},{-4.953771, -3.076302, 
        25.776375}}],
    Line[{{-4.953771, -3.076302, 25.776375},{-4.779271, -3.166113, 
        25.247759}}],
    Line[{{-4.779271, -3.166113, 25.247759},{-4.630887, -3.275470, 
        24.732718}}],
    Line[{{-4.630887, -3.275470, 24.732718},{-4.507911, -3.402769, 
        24.232264}}],
    Line[{{-4.507911, -3.402769, 24.232264},{-4.409572, -3.546793, 
        23.747313}}],
    Line[{{-4.409572, -3.546793, 23.747313},{-4.335073, -3.706684, 
        23.278725}}],
    Line[{{-4.335073, -3.706684, 23.278725},{-4.283624, -3.881904, 
        22.827347}}],
    Line[{{-4.283624, -3.881904, 22.827347},{-4.254479, -4.072194, 
        22.394043}}],
    Line[{{-4.254479, -4.072194, 22.394043},{-4.246945, -4.277540, 
        21.979729}}],
    Line[{{-4.246945, -4.277540, 21.979729},{-4.260407, -4.498137, 
        21.585384}}],
    Line[{{-4.260407, -4.498137, 21.585384},{-4.294334, -4.734348, 
        21.212088}}],
    Line[{{-4.294334, -4.734348, 21.212088},{-4.348289, -4.986676, 
        20.861040}}],
    Line[{{-4.348289, -4.986676, 20.861040},{-4.421926, -5.255727, 
        20.533573}}],
    Line[{{-4.421926, -5.255727, 20.533573},{-4.514998, -5.542167, 
        20.231190}}],
    Line[{{-4.514998, -5.542167, 20.231190},{-4.627342, -5.846699, 
        19.955570}}],
    Line[{{-4.627342, -5.846699, 19.955570},{-4.758880, -6.170004, 
        19.708599}}],
    Line[{{-4.758880, -6.170004, 19.708599},{-4.909602, -6.512715, 
        19.492388}}],
    Line[{{-4.909602, -6.512715, 19.492388},{-5.079556, -6.875349, 
        19.309288}}],
    Line[{{-5.079556, -6.875349, 19.309288},{-5.268828, -7.258265, 
        19.161915}}],
    Line[{{-5.268828, -7.258265, 19.161915},{-5.477516, -7.661583, 
        19.053150}}],
    Line[{{-5.477516, -7.661583, 19.053150},{-5.705709, -8.085124, 
        18.986156}}],
    Line[{{-5.705709, -8.085124, 18.986156},{-5.953449, -8.528306, 
        18.964357}}],
    Line[{{-5.953449, -8.528306, 18.964357},{-6.220699, -8.990063, 
        18.991444}}],
    Line[{{-6.220699, -8.990063, 18.991444},{-6.507294, -9.468720, 
        19.071306}}],
    Line[{{-6.507294, -9.468720, 19.071306},{-6.812893, -9.961889, 
        19.208008}}],
    Line[{{-6.812893, -9.961889, 19.208008},{-7.136918, -10.466329, 
        19.405666}}],
    Line[{{-7.136918, -10.466329, 19.405666},{-7.478492, -10.977831, 
        19.668354}}],
    Line[{{-7.478492, -10.977831, 19.668354},{-7.836370, -11.491079, 
        19.999918}}],
    Line[{{-7.836370, -11.491079, 19.999918},{-8.208864, -11.999578, 
        20.403763}}],
    Line[{{-8.208864, -11.999578, 20.403763},{-8.593760, -12.495516, 
        20.882612}}],
    Line[{{-8.593760, -12.495516, 20.882612},{-8.988256, -12.969831, 
        21.438158}}],
    Line[{{-8.988256, -12.969831, 21.438158},{-9.388887, -13.412169, 
        22.070724}}],
    Line[{{-9.388887, -13.412169, 22.070724},{-9.791482, -13.811082, 
        22.778881}}],
    Line[{{-9.791482, -13.811082, 22.778881},{-10.191133, -14.154273, 
        23.559032}}],
    Line[{{-10.191133, -14.154273, 23.559032},{-10.582196, -14.428952, 
        24.405033}}],
    Line[{{-10.582196, -14.428952, 24.405033},{-10.958356, -14.622439, 
        25.307932}}],
    Line[{{-10.958356, -14.622439, 25.307932},{-11.312714, -14.722761, 
        26.255745}}],
    Line[{{-11.312714, -14.722761, 26.255745},{-11.637954, -14.719497, 
        27.233433}}],
    Line[{{-11.637954, -14.719497, 27.233433},{-11.926581, -14.604554, 
        28.223251}}],
    Line[{{-11.926581, -14.604554, 28.223251},{-12.171184, -14.373078, 
        29.205048}}],
    Line[{{-12.171184, -14.373078, 29.205048},{-12.364780, -14.024066, 
        30.157215}}],
    Line[{{-12.364780, -14.024066, 30.157215},{-12.501170, -13.560941, 
        31.057571}}],
    Line[{{-12.501170, -13.560941, 31.057571},{-12.575289, -12.991710, 
        31.884584}}],
    Line[{{-12.575289, -12.991710, 31.884584},{-12.583529, -12.328827, 
        32.618572}}],
    Line[{{-12.583529, -12.328827, 32.618572},{-12.524015, -11.588644, 
        33.242912}}],
    Line[{{-12.524015, -11.588644, 33.242912},{-12.396757, -10.790492, 
        33.744968}}],
    Line[{{-12.396757, -10.790492, 33.744968},{-12.203696, -9.955534, 
        34.116745}}],
    Line[{{-12.203696, -9.955534, 34.116745},{-11.948645, -9.105478, 
        34.355129}}],
    Line[{{-11.948645, -9.105478, 34.355129},{-11.637092, -8.261315, 
        34.461761}}],
    Line[{{-11.637092, -8.261315, 34.461761},{-11.275919, -7.442151, 
        34.442528}}],
    Line[{{-11.275919, -7.442151, 34.442528},{-10.873042, -6.664358, 
        34.306763}}],
    Line[{{-10.873042, -6.664358, 34.306763},{-10.437027, -5.941023, 
        34.066322}}],
    Line[{{-10.437027, -5.941023, 34.066322},{-9.976703, -5.281705, 
        33.734604}}],
    Line[{{-9.976703, -5.281705, 33.734604},{-9.500796, -4.692484, 
        33.325653}}],
    Line[{{-9.500796, -4.692484, 33.325653},{-9.017626, -4.176255, 
        32.853340}}],
    Line[{{-9.017626, -4.176255, 32.853340},{-8.534855, -3.733197, 
        32.330780}}],
    Line[{{-8.534855, -3.733197, 32.330780},{-8.059328, -3.361270, 
        31.769928}}],
    Line[{{-8.059328, -3.361270, 31.769928},{-7.596960, -3.056796, 
        31.181326}}],
    Line[{{-7.596960, -3.056796, 31.181326},{-7.152690, -2.814973, 
        30.574017}}],
    Line[{{-7.152690, -2.814973, 30.574017},{-6.730499, -2.630342, 
        29.955568}}],
    Line[{{-6.730499, -2.630342, 29.955568},{-6.333453, -2.497172, 
        29.332186}}],
    Line[{{-6.333453, -2.497172, 29.332186},{-5.963778, -2.409760, 
        28.708851}}],
    Line[{{-5.963778, -2.409760, 28.708851},{-5.622959, -2.362659, 
        28.089504}}],
    Line[{{-5.622959, -2.362659, 28.089504},{-5.311838, -2.350836, 
        27.477219}}],
    Line[{{-5.311838, -2.350836, 27.477219},{-5.030723, -2.369764, 
        26.874365}}],
    Line[{{-5.030723, -2.369764, 26.874365},{-4.779488, -2.415478, 
        26.282761}}],
    Line[{{-4.779488, -2.415478, 26.282761},{-4.557672, -2.484584, 
        25.703802}}],
    Line[{{-4.557672, -2.484584, 25.703802},{-4.364557, -2.574260, 
        25.138573}}],
    Line[{{-4.364557, -2.574260, 25.138573},{-4.199258, -2.682222, 
        24.587934}}],
    Line[{{-4.199258, -2.682222, 24.587934},{-4.060776, -2.806688, 
        24.052593}}],
    Line[{{-4.060776, -2.806688, 24.052593},{-3.948062, -2.946337, 
        23.533165}}],
    Line[{{-3.948062, -2.946337, 23.533165},{-3.860062, -3.100259, 
        23.030220}}],
    Line[{{-3.860062, -3.100259, 23.030220},{-3.795754, -3.267914, 
        22.544321}}],
    Line[{{-3.795754, -3.267914, 22.544321},{-3.754177, -3.449081, 
        22.076046}}],
    Line[{{-3.754177, -3.449081, 22.076046},{-3.734453, -3.643825, 
        21.626030}}],
    Line[{{-3.734453, -3.643825, 21.626030},{-3.735809, -3.852450, 
        21.194973}}],
    Line[{{-3.735809, -3.852450, 21.194973},{-3.757583, -4.075466, 
        20.783670}}],
    Line[{{-3.757583, -4.075466, 20.783670},{-3.799232, -4.313559, 
        20.393032}}],
    Line[{{-3.799232, -4.313559, 20.393032},{-3.860340, -4.567552, 
        20.024103}}],
    Line[{{-3.860340, -4.567552, 20.024103},{-3.940612, -4.838380, 
        19.678083}}],
    Line[{{-3.940612, -4.838380, 19.678083},{-4.039874, -5.127057, 
        19.356356}}],
    Line[{{-4.039874, -5.127057, 19.356356},{-4.158069, -5.434640, 
        19.060501}}],
    Line[{{-4.158069, -5.434640, 19.060501},{-4.295247, -5.762202, 
        18.792337}}],
    Line[{{-4.295247, -5.762202, 18.792337},{-4.451552, -6.110785, 
        18.553930}}],
    Line[{{-4.451552, -6.110785, 18.553930},{-4.627213, -6.481355, 
        18.347631}}],
    Line[{{-4.627213, -6.481355, 18.347631},{-4.822523, -6.874755, 
        18.176104}}],
    Line[{{-4.822523, -6.874755, 18.176104},{-5.037817, -7.291636, 
        18.042337}}],
    Line[{{-5.037817, -7.291636, 18.042337},{-5.273447, -7.732376, 
        17.949675}}],
    Line[{{-5.273447, -7.732376, 17.949675},{-5.529757, -8.197012, 
        17.901829}}],
    Line[{{-5.529757, -8.197012, 17.901829},{-5.807033, -8.685103, 
        17.902872}}],
    Line[{{-5.807033, -8.685103, 17.902872},{-6.105468, -9.195641, 
        17.957233}}],
    Line[{{-6.105468, -9.195641, 17.957233},{-6.425111, -9.726894, 
        18.069670}}],
    Line[{{-6.425111, -9.726894, 18.069670},{-6.765789, -10.276243, 
        18.245163}}],
    Line[{{-6.765789, -10.276243, 18.245163},{-7.127062, -10.840049, 
        18.488886}}],
    Line[{{-7.127062, -10.840049, 18.488886},{-7.508119, -11.413438, 
        18.805992}}],
    Line[{{-7.508119, -11.413438, 18.805992},{-7.907694, -11.990159, 
        19.201406}}],
    Line[{{-7.907694, -11.990159, 19.201406},{-8.323984, -12.562419, 
        19.679647}}],
    Line[{{-8.323984, -12.562419, 19.679647},{-8.754526, -13.120771, 
        20.244341}}],
    Line[{{-8.754526, -13.120771, 20.244341},{-9.196117, -13.654087, 
        20.897909}}],
    Line[{{-9.196117, -13.654087, 20.897909},{-9.644714, -14.149520, 
        21.641085}}],
    Line[{{-9.644714, -14.149520, 21.641085},{-10.095365, -14.592818, 
        22.472284}}],
    Line[{{-10.095365, -14.592818, 22.472284},{-10.542173, -14.968564, 
        23.387159}}],
    Line[{{-10.542173, -14.968564, 23.387159},{-10.978308, -15.260754, 
        24.378033}}],
    Line[{{-10.978308, -15.260754, 24.378033},{-11.396054, -15.453510, 
        25.433506}}],
    Line[{{-11.396054, -15.453510, 25.433506},{-11.786974, -15.532048, 
        26.538210}}],
    Line[{{-11.786974, -15.532048, 26.538210},{-12.142115, -15.483762, 
        27.672838}}],
    Line[{{-12.142115, -15.483762, 27.672838},{-12.452333, -15.299383, 
        28.814537}}],
    Line[{{-12.452333, -15.299383, 28.814537},{-12.708682, -14.974099, 
        29.937662}}],
    Line[{{-12.708682, -14.974099, 29.937662},{-12.902858, -14.508451, 
        31.014908}}],
    Line[{{-12.902858, -14.508451, 31.014908},{-13.027682, -13.908967, 
        32.018757}}],
    Line[{{-13.027682, -13.908967, 32.018757},{-13.077580, -13.188186, 
        32.923222}}],
    Line[{{-13.077580, -13.188186, 32.923222},{-13.048977, -12.364251, 
        33.705490}}],
    Line[{{-13.048977, -12.364251, 33.705490},{-12.940595, -11.459909, 
        34.347404}}],
    Line[{{-12.940595, -11.459909, 34.347404},{-12.753608, -10.501058, 
        34.836613}}],
    Line[{{-12.753608, -10.501058, 34.836613},{-12.491629, -9.515015, 
        35.167137}}],
    Line[{{-12.491629, -9.515015, 35.167137},{-12.160520, -8.528714, 
        35.339386}}],
    Line[{{-12.160520, -8.528714, 35.339386},{-11.768062, -7.567049, 
        35.359608}}],
    Line[{{-11.768062, -7.567049, 35.359608},{-11.323511, -6.651540, 
        35.238884}}],
    Line[{{-11.323511, -6.651540, 35.238884},{-10.837089, -5.799447, 
        34.991875}}],
    Line[{{-10.837089, -5.799447, 34.991875},{-10.319462, -5.023369, 
        34.635422}}],
    Line[{{-10.319462, -5.023369, 34.635422},{-9.781255, -4.331259, 
        34.187290}}],
    Line[{{-9.781255, -4.331259, 34.187290},{-9.232627, -3.726799, 
        33.665028}}],
    Line[{{-9.232627, -3.726799, 33.665028},{-8.682940, -3.210025, 
        33.085133}}],
    Line[{{-8.682940, -3.210025, 33.085133},{-8.140521, -2.778062, 
        32.462463}}],
    Line[{{-8.140521, -2.778062, 32.462463},{-7.612521, -2.425898, 
        31.809937}}],
    Line[{{-7.612521, -2.425898, 31.809937},{-7.104860, -2.147104, 
        31.138430}}],
    Line[{{-7.104860, -2.147104, 31.138430},{-6.622240, -1.934463, 
        30.456831}}],
    Line[{{-6.622240, -1.934463, 30.456831},{-6.168212, -1.780483, 
        29.772217}}],
    Line[{{-6.168212, -1.780483, 29.772217},{-5.745278, -1.677793, 
        29.090082}}],
    Line[{{-5.745278, -1.677793, 29.090082},{-5.355020, -1.619419, 
        28.414587}}],
    Line[{{-5.355020, -1.619419, 28.414587},{-4.998231, -1.598976, 
        27.748814}}],
    Line[{{-4.998231, -1.598976, 27.748814},{-4.675054, -1.610774, 
        27.094980}}],
    Line[{{-4.675054, -1.610774, 27.094980},{-4.385114, -1.649862, 
        26.454659}}],
    Line[{{-4.385114, -1.649862, 26.454659},{-4.127635, -1.712039, 
        25.828928}}],
    Line[{{-4.127635, -1.712039, 25.828928},{-3.901552, -1.793819, 
        25.218521}}],
    Line[{{-3.901552, -1.793819, 25.218521},{-3.705601, -1.892392, 
        24.623924}}],
    Line[{{-3.705601, -1.892392, 24.623924},{-3.538402, -2.005566, 
        24.045467}}],
    Line[{{-3.538402, -2.005566, 24.045467},{-3.398524, -2.131700, 
        23.483383}}],
    Line[{{-3.398524, -2.131700, 23.483383},{-3.284542, -2.269649, 
        22.937862}}],
    Line[{{-3.284542, -2.269649, 22.937862},{-3.195078, -2.418701, 
        22.409081}}],
    Line[{{-3.195078, -2.418701, 22.409081},{-3.128836, -2.578521, 
        21.897238}}],
    Line[{{-3.128836, -2.578521, 21.897238},{-3.084628, -2.749103, 
        21.402573}}],
    Line[{{-3.084628, -2.749103, 21.402573},{-3.061393, -2.930722, 
        20.925381}}],
    Line[{{-3.061393, -2.930722, 20.925381},{-3.058208, -3.123900, 
        20.466040}}],
    Line[{{-3.058208, -3.123900, 20.466040},{-3.074300, -3.329368, 
        20.025011}}],
    Line[{{-3.074300, -3.329368, 20.025011},{-3.109046, -3.548036, 
        19.602873}}],
    Line[{{-3.109046, -3.548036, 19.602873},{-3.161976, -3.780972, 
        19.200317}}],
    Line[{{-3.161976, -3.780972, 19.200317},{-3.232777, -4.029372, 
        18.818190}}],
    Line[{{-3.232777, -4.029372, 18.818190},{-3.321280, -4.294542, 
        18.457493}}],
    Line[{{-3.321280, -4.294542, 18.457493},{-3.427465, -4.577879, 
        18.119421}}],
    Line[{{-3.427465, -4.577879, 18.119421},{-3.551447, -4.880846, 
        17.805378}}],
    Line[{{-3.551447, -4.880846, 17.805378},{-3.693474, -5.204943, 
        17.517015}}],
    Line[{{-3.693474, -5.204943, 17.517015},{-3.853912, -5.551689, 
        17.256260}}],
    Line[{{-3.853912, -5.551689, 17.256260},{-4.033238, -5.922579, 
        17.025349}}],
    Line[{{-4.033238, -5.922579, 17.025349},{-4.232021, -6.319039, 
        16.826866}}],
    Line[{{-4.232021, -6.319039, 16.826866},{-4.450909, -6.742387, 
        16.663786}}],
    Line[{{-4.450909, -6.742387, 16.663786},{-4.690602, -7.193742, 
        16.539505}}],
    Line[{{-4.690602, -7.193742, 16.539505},{-4.951829, -7.673962, 
        16.457884}}],
    Line[{{-4.951829, -7.673962, 16.457884},{-5.235318, -8.183537, 
        16.423277}}],
    Line[{{-5.235318, -8.183537, 16.423277},{-5.541743, -8.722445, 
        16.440548}}],
    Line[{{-5.541743, -8.722445, 16.440548},{-5.871689, -9.290033, 
        16.515081}}],
    Line[{{-5.871689, -9.290033, 16.515081},{-6.225586, -9.884823, 
        16.652765}}],
    Line[{{-6.225586, -9.884823, 16.652765},{-6.603623, -10.504283, 
        16.859907}}],
    Line[{{-6.603623, -10.504283, 16.859907},{-7.005686, -11.144658, 
        17.143190}}],
    Line[{{-7.005686, -11.144658, 17.143190},{-7.431236, -11.800669, 
        17.509472}}],
    Line[{{-7.431236, -11.800669, 17.509472},{-7.879193, -12.465261, 
        17.965502}}],
    Line[{{-7.879193, -12.465261, 17.965502},{-8.347832, -13.129395, 
        18.517733}}],
    Line[{{-8.347832, -13.129395, 18.517733},{-8.834606, -13.781796, 
        19.171707}}],
    Line[{{-8.834606, -13.781796, 19.171707},{-9.336036, -14.408847, 
        19.931612}}],
    Line[{{-9.336036, -14.408847, 19.931612},{-9.847559, -14.994582, 
        20.799564}}],
    Line[{{-9.847559, -14.994582, 20.799564},{-10.363421, -15.520846, 
        21.774891}}],
    Line[{{-10.363421, -15.520846, 21.774891},{-10.876593, -15.967673, 
        22.853294}}],
    Line[{{-10.876593, -15.967673, 22.853294},{-11.378760, -16.314062, 
        24.026041}}],
    Line[{{-11.378760, -16.314062, 24.026041},{-11.860389, -16.538927, 
        25.279335}}],
    Line[{{-11.860389, -16.538927, 25.279335},{-12.310890, -16.622454, 
        26.593880}}],
    Line[{{-12.310890, -16.622454, 26.593880},{-12.718928, -16.547701, 
        27.944870}}],
    Line[{{-12.718928, -16.547701, 27.944870},{-13.072839, -16.302315, 
        29.302481}}],
    Line[{{-13.072839, -16.302315, 29.302481},{-13.361181, -15.880198, 
        30.632980}}],
    Line[{{-13.361181, -15.880198, 30.632980},{-13.573386, -15.282870, 
        31.900444}}],
    Line[{{-13.573386, -15.282870, 31.900444},{-13.700436, -14.520283, 
        33.068977}}],
    Line[{{-13.700436, -14.520283, 33.068977},{-13.735534, -13.610818, 
        34.105236}}],
    Line[{{-13.735534, -13.610818, 34.105236},{-13.674654, -12.580475, 
        34.980877}}],
    Line[{{-13.674654, -12.580475, 34.980877},{-13.516934, -11.461172, 
        35.674698}}],
    Line[{{-13.516934, -11.461172, 35.674698},{-13.264822, -10.288419, 
        36.174019}}],
    Line[{{-13.264822, -10.288419, 36.174019},{-12.923984, -9.098648, 
        36.475269}}],
    Line[{{-12.923984, -9.098648, 36.475269},{-12.502946, -7.926561, 
        36.583576}}],
    Line[{{-12.502946, -7.926561, 36.583576},{-12.012548, -6.802880, 
        36.511543}}],
    Line[{{-12.012548, -6.802880, 36.511543},{-11.465262, -5.752702, 
        36.277527}}],
    Line[{{-11.465262, -5.752702, 36.277527},{-10.874452, -4.794626, 
        35.903561}}],
    Line[{{-10.874452, -4.794626, 35.903561},{-10.253652, -3.940593, 
        35.413361}}],
    Line[{{-10.253652, -3.940593, 35.413361},{-9.615942, -3.196329, 
        34.830566}}],
    Line[{{-9.615942, -3.196329, 34.830566},{-8.973437, -2.562230, 
        34.177380}}],
    Line[{{-8.973437, -2.562230, 34.177380},{-8.336920, -2.034452, 
        33.473644}}],
    Line[{{-8.336920, -2.034452, 33.473644},{-7.715625, -1.606070, 
        32.736366}}],
    Line[{{-7.715625, -1.606070, 32.736366},{-7.117143, -1.268166, 
        31.979574}}],
    Line[{{-7.117143, -1.268166, 31.979574},{-6.547436, -1.010761, 
        31.214418}}],
    Line[{{-6.547436, -1.010761, 31.214418},{-6.010929, -0.823562, 
        30.449471}}],
    Line[{{-6.010929, -0.823562, 30.449471},{-5.510654, -0.696522, 
        29.691090}}],
    Line[{{-5.510654, -0.696522, 29.691090},{-5.048428, -0.620225, 
        28.943810}}],
    Line[{{-5.048428, -0.620225, 28.943810},{-4.625036, -0.586123, 
        28.210722}}],
    Line[{{-4.625036, -0.586123, 28.210722},{-4.240426, -0.586662, 
        27.493822}}],
    Line[{{-4.240426, -0.586662, 27.493822},{-3.893879, -0.615319, 
        26.794283}}],
    Line[{{-3.893879, -0.615319, 26.794283},{-3.584175, -0.666589, 
        26.112700}}],
    Line[{{-3.584175, -0.666589, 26.112700},{-3.309732, -0.735921, 
        25.449274}}],
    Line[{{-3.309732, -0.735921, 25.449274},{-3.068729, -0.819640, 
        24.803942}}],
    Line[{{-3.068729, -0.819640, 24.803942},{-2.859205, -0.914859, 
        24.176487}}],
    Line[{{-2.859205, -0.914859, 24.176487},{-2.679147, -1.019381, 
        23.566612}}],
    Line[{{-2.679147, -1.019381, 23.566612},{-2.526557, -1.131608, 
        22.973989}}],
    Line[{{-2.526557, -1.131608, 22.973989},{-2.399498, -1.250461, 
        22.398291}}],
    Line[{{-2.399498, -1.250461, 22.398291},{-2.296136, -1.375303, 
        21.839214}}],
    Line[{{-2.296136, -1.375303, 21.839214},{-2.214770, -1.505869, 
        21.296499}}],
    Line[{{-2.214770, -1.505869, 21.296499},{-2.153852, -1.642212, 
        20.769936}}],
    Line[{{-2.153852, -1.642212, 20.769936},{-2.111999, -1.784650, 
        20.259365}}],
    Line[{{-2.111999, -1.784650, 20.259365},{-2.088002, -1.933728, 
        19.764698}}],
    Line[{{-2.088002, -1.933728, 19.764698},{-2.080827, -2.090188, 
        19.285908}}],
    Line[{{-2.080827, -2.090188, 19.285908},{-2.089619, -2.254935, 
        18.823038}}],
    Line[{{-2.089619, -2.254935, 18.823038},{-2.113696, -2.429024, 
        18.376217}}],
    Line[{{-2.113696, -2.429024, 18.376217},{-2.152549, -2.613641, 
        17.945658}}],
    Line[{{-2.152549, -2.613641, 17.945658},{-2.205837, -2.810093, 
        17.531672}}],
    Line[{{-2.205837, -2.810093, 17.531672},{-2.273379, -3.019799, 
        17.134687}}],
    Line[{{-2.273379, -3.019799, 17.134687},{-2.355154, -3.244286, 
        16.755255}}],
    Line[{{-2.355154, -3.244286, 16.755255},{-2.451292, -3.485182, 
        16.394075}}],
    Line[{{-2.451292, -3.485182, 16.394075},{-2.562069, -3.744214, 
        16.052019}}],
    Line[{{-2.562069, -3.744214, 16.052019},{-2.687907, -4.023204, 
        15.730152}}],
    Line[{{-2.687907, -4.023204, 15.730152},{-2.829364, -4.324061, 
        15.429770}}],
    Line[{{-2.829364, -4.324061, 15.429770},{-2.987128, -4.648773, 
        15.152430}}],
    Line[{{-2.987128, -4.648773, 15.152430},{-3.162018, -4.999391, 
        14.899995}}],
    Line[{{-3.162018, -4.999391, 14.899995},{-3.354970, -5.378006, 
        14.674684}}],
    Line[{{-3.354970, -5.378006, 14.674684},{-3.567032, -5.786728, 
        14.479113}}],
    Line[{{-3.567032, -5.786728, 14.479113},{-3.799349, -6.227621, 
        14.316371}}],
    Line[{{-3.799349, -6.227621, 14.316371},{-4.053155, -6.702675, 
        14.190063}}],
    Line[{{-4.053155, -6.702675, 14.190063},{-4.329745, -7.213706, 
        14.104393}}],
    Line[{{-4.329745, -7.213706, 14.104393},{-4.630447, -7.762240, 
        14.064224}}],
    Line[{{-4.630447, -7.762240, 14.064224},{-4.956603, -8.349437, 
        14.075141}}],
    Line[{{-4.956603, -8.349437, 14.075141},{-5.309497, -8.975843, 
        14.143511}}],
    Line[{{-5.309497, -8.975843, 14.143511},{-5.690312, -9.641232, 
        14.276514}}],
    Line[{{-5.690312, -9.641232, 14.276514},{-6.100050, -10.344337, 
        14.482161}}],
    Line[{{-6.100050, -10.344337, 14.482161},{-6.539434, -11.082539, 
        14.769249}}],
    Line[{{-6.539434, -11.082539, 14.769249},{-7.008788, -11.851497, 
        15.147257}}],
    Line[{{-7.008788, -11.851497, 15.147257},{-7.507888, -12.644754, 
        15.626132}}],
    Line[{{-7.507888, -12.644754, 15.626132},{-8.035808, -13.453318, 
        16.216009}}],
    Line[{{-8.035808, -13.453318, 16.216009},{-8.590707, -14.265194, 
        16.926706}}],
    Line[{{-8.590707, -14.265194, 16.926706},{-9.169616, -15.065008, 
        17.767052}}],
    Line[{{-9.169616, -15.065008, 17.767052},{-9.768211, -15.833729, 
        18.744019}}],
    Line[{{-9.768211, -15.833729, 18.744019},{-10.380588, -16.548571, 
        19.861641}}],
    Line[{{-10.380588, -16.548571, 19.861641},{-10.999059, -17.183218, 
        21.119730}}],
    Line[{{-10.999059, -17.183218, 21.119730},{-11.614019, -17.708466, 
        22.512489}}],
    Line[{{-11.614019, -17.708466, 22.512489},{-12.213902, -18.093390, 
        24.027140}}],
    Line[{{-12.213902, -18.093390, 24.027140},{-12.785287, -18.307129, 
        25.642788}}],
    Line[{{-12.785287, -18.307129, 25.642788},{-13.313187, -18.321262, 
        27.329765}}],
    Line[{{-13.313187, -18.321262, 27.329765},{-13.781569, -18.112621, 
        29.049753}}],
    Line[{{-13.781569, -18.112621, 29.049753},{-14.174090, -17.666302, 
        30.756910}}],
    Line[{{-14.174090, -17.666302, 30.756910},{-14.475071, -16.978397, 
        32.400265}}],
    Line[{{-14.475071, -16.978397, 32.400265},{-14.670561, -16.057974, 
        33.927010}}],
    Line[{{-14.670561, -16.057974, 33.927010},{-14.749464, -14.927793, 
        35.286751}}],
    Line[{{-14.749464, -14.927793, 35.286751},{-14.704539, -13.623426, 
        36.435844}}],
    Line[{{-14.704539, -13.623426, 36.435844},{-14.533146, -12.190771, 
        37.341339}}],
    Line[{{-14.533146, -12.190771, 37.341339},{-14.237613, -10.682174, 
        37.983742}}],
    Line[{{-14.237613, -10.682174, 37.983742},{-13.825152, -9.151801, 
        38.358162}}],
    Line[{{-13.825152, -9.151801, 38.358162},{-13.307350, -7.650996, 
        38.473679}}],
    Line[{{-13.307350, -7.650996, 38.473679},{-12.699265, -6.224392, 
        38.351143}}],
    Line[{{-12.699265, -6.224392, 38.351143},{-12.018334, -4.907185, 
        38.020035}}],
    Line[{{-12.018334, -4.907185, 38.020035},{-11.283175, -3.723862, 
        37.514801}}],
    Line[{{-11.283175, -3.723862, 37.514801},{-10.512442, -2.688270, 
        36.871403}}],
    Line[{{-10.512442, -2.688270, 36.871403},{-9.723856, -1.804715, 
        36.124481}}],
    Line[{{-9.723856, -1.804715, 36.124481},{-8.933474, -1.069739, 
        35.305305}}],
    Line[{{-8.933474, -1.069739, 35.305305},{-8.155197, -0.474127, 
        34.440578}}],
    Line[{{-8.155197, -0.474127, 34.440578},{-7.400533, -0.004888, 
        33.552040}}],
    Line[{{-7.400533, -0.004888, 33.552040},{-6.678542, 0.353024, 
        32.656528}}],
    Line[{{-6.678542, 0.353024, 32.656528},{-5.995950, 0.615333, 31.766508}}],
    
    Line[{{-5.995950, 0.615333, 31.766508},{-5.357357, 0.797436, 30.890713}}],
    
    Line[{{-5.357357, 0.797436, 30.890713},{-4.765501, 0.913727, 30.034872}}],
    
    Line[{{-4.765501, 0.913727, 30.034872},{-4.221558, 0.977196, 29.202419}}],
    
    Line[{{-4.221558, 0.977196, 29.202419},{-3.725430, 0.999242, 28.395090}}],
    
    Line[{{-3.725430, 0.999242, 28.395090},{-3.276024, 0.989641, 27.613430}}],
    
    Line[{{-3.276024, 0.989641, 27.613430},{-2.871495, 0.956604, 26.857197}}],
    
    Line[{{-2.871495, 0.956604, 26.857197},{-2.509464, 0.906901, 26.125656}}],
    
    Line[{{-2.509464, 0.906901, 26.125656},{-2.187198, 0.846012, 25.417803}}],
    
    Line[{{-2.187198, 0.846012, 25.417803},{-1.901759, 0.778293, 24.732508}}],
    
    Line[{{-1.901759, 0.778293, 24.732508},{-1.650120, 0.707138, 24.068615}}],
    
    Line[{{-1.650120, 0.707138, 24.068615},{-1.429261, 0.635130, 23.425016}}],
    
    Line[{{-1.429261, 0.635130, 23.425016},{-1.236236, 0.564182, 22.800665}}],
    
    Line[{{-1.236236, 0.564182, 22.800665},{-1.068226, 0.495654, 22.194605}}],
    
    Line[{{-1.068226, 0.495654, 22.194605},{-0.922572, 0.430468, 21.605968}}],
    
    Line[{{-0.922572, 0.430468, 21.605968},{-0.796797, 0.369191, 21.033981}}],
    
    Line[{{-0.796797, 0.369191, 21.033981},{-0.688623, 0.312121, 20.477940}}],
    
    Line[{{-0.688623, 0.312121, 20.477940},{-0.595968, 0.259339, 19.937216}}],
    
    Line[{{-0.595968, 0.259339, 19.937216},{-0.516950, 0.210774, 19.411243}}],
    
    Line[{{-0.516950, 0.210774, 19.411243},{-0.449877, 0.166237, 18.899504}}],
    
    Line[{{-0.449877, 0.166237, 18.899504},{-0.393242, 0.125459, 18.401522}}],
    
    Line[{{-0.393242, 0.125459, 18.401522},{-0.345709, 0.088115, 17.916862}}],
    
    Line[{{-0.345709, 0.088115, 17.916862},{-0.306102, 0.053850, 17.445120}}],
    
    Line[{{-0.306102, 0.053850, 17.445120},{-0.273391, 0.022288, 16.985910}}],
    
    Line[{{-0.273391, 0.022288, 16.985910},{-0.246682, -0.006952, 
        16.538876}}],
    Line[{{-0.246682, -0.006952, 16.538876},{-0.225201, -0.034249, 
        16.103672}}],
    Line[{{-0.225201, -0.034249, 16.103672},{-0.208284, -0.059976, 
        15.679976}}],
    Line[{{-0.208284, -0.059976, 15.679976},{-0.195363, -0.084494, 
        15.267471}}],
    Line[{{-0.195363, -0.084494, 15.267471},{-0.185962, -0.108155, 
        14.865860}}],
    Line[{{-0.185962, -0.108155, 14.865860},{-0.179679, -0.131296, 
        14.474854}}],
    Line[{{-0.179679, -0.131296, 14.474854},{-0.176185, -0.154245, 
        14.094172}}],
    Line[{{-0.176185, -0.154245, 14.094172},{-0.175211, -0.177320, 
        13.723544}}],
    Line[{{-0.175211, -0.177320, 13.723544},{-0.176545, -0.200834, 
        13.362712}}],
    Line[{{-0.176545, -0.200834, 13.362712},{-0.180023, -0.225093, 
        13.011422}}],
    Line[{{-0.180023, -0.225093, 13.011422},{-0.185527, -0.250405, 
        12.669431}}],
    Line[{{-0.185527, -0.250405, 12.669431},{-0.192980, -0.277079, 
        12.336503}}],
    Line[{{-0.192980, -0.277079, 12.336503},{-0.202341, -0.305430, 
        12.012413}}],
    Line[{{-0.202341, -0.305430, 12.012413},{-0.213603, -0.335786, 
        11.696942}}],
    Line[{{-0.213603, -0.335786, 11.696942},{-0.226794, -0.368485, 
        11.389880}}],
    Line[{{-0.226794, -0.368485, 11.389880},{-0.241968, -0.403887, 
        11.091027}}],
    Line[{{-0.241968, -0.403887, 11.091027},{-0.259214, -0.442375, 
        10.800193}}],
    Line[{{-0.259214, -0.442375, 10.800193},{-0.278648, -0.484359, 
        10.517195}}],
    Line[{{-0.278648, -0.484359, 10.517195},{-0.300414, -0.530282, 
        10.241864}}],
    Line[{{-0.300414, -0.530282, 10.241864},{-0.324690, -0.580626, 
        9.974043}}],
    Line[{{-0.324690, -0.580626, 9.974043},{-0.351681, -0.635920, 9.713587}}],
    
    Line[{{-0.351681, -0.635920, 9.713587},{-0.381629, -0.696741, 9.460366}}],
    
    Line[{{-0.381629, -0.696741, 9.460366},{-0.414808, -0.763726, 9.214268}}],
    
    Line[{{-0.414808, -0.763726, 9.214268},{-0.451530, -0.837576, 8.975199}}],
    
    Line[{{-0.451530, -0.837576, 8.975199},{-0.492149, -0.919067, 8.743088}}],
    
    Line[{{-0.492149, -0.919067, 8.743088},{-0.537062, -1.009058, 8.517891}}],
    
    Line[{{-0.537062, -1.009058, 8.517891},{-0.586715, -1.108501, 8.299596}}],
    
    Line[{{-0.586715, -1.108501, 8.299596},{-0.641606, -1.218450, 8.088225}}],
    
    Line[{{-0.641606, -1.218450, 8.088225},{-0.702292, -1.340076, 7.883850}}],
    
    Line[{{-0.702292, -1.340076, 7.883850},{-0.769394, -1.474678, 7.686587}}],
    
    Line[{{-0.769394, -1.474678, 7.686587},{-0.843606, -1.623698, 7.496626}}],
    
    Line[{{-0.843606, -1.623698, 7.496626},{-0.925700, -1.788733, 7.314229}}],
    
    Line[{{-0.925700, -1.788733, 7.314229},{-1.016532, -1.971556, 7.139753}}],
    
    Line[{{-1.016532, -1.971556, 7.139753},{-1.117059, -2.174131, 6.973673}}],
    
    Line[{{-1.117059, -2.174131, 6.973673},{-1.228340, -2.398630, 6.816596}}],
    
    Line[{{-1.228340, -2.398630, 6.816596},{-1.351554, -2.647455, 6.669313}}],
    
    Line[{{-1.351554, -2.647455, 6.669313},{-1.488004, -2.923250, 6.532808}}],
    
    Line[{{-1.488004, -2.923250, 6.532808},{-1.639138, -3.228929, 6.408333}}],
    
    Line[{{-1.639138, -3.228929, 6.408333},{-1.806554, -3.567682, 6.297445}}],
    
    Line[{{-1.806554, -3.567682, 6.297445},{-1.992016, -3.942994, 6.202074}}],
    
    Line[{{-1.992016, -3.942994, 6.202074},{-2.197467, -4.358645, 6.124636}}],
    
    Line[{{-2.197467, -4.358645, 6.124636},{-2.425038, -4.818722, 6.068075}}],
    
    Line[{{-2.425038, -4.818722, 6.068075},{-2.677062, -5.327579, 6.036053}}],
    
    Line[{{-2.677062, -5.327579, 6.036053},{-2.956073, -5.889819, 6.033047}}],
    
    Line[{{-2.956073, -5.889819, 6.033047},{-3.264816, -6.510228, 6.064524}}],
    
    Line[{{-3.264816, -6.510228, 6.064524},{-3.606232, -7.193666, 6.137155}}],
    
    Line[{{-3.606232, -7.193666, 6.137155},{-3.983438, -7.944895, 6.259030}}],
    
    Line[{{-3.983438, -7.944895, 6.259030},{-4.399706, -8.768396, 6.439890}}],
    
    Line[{{-4.399706, -8.768396, 6.439890},{-4.858385, -9.667983, 6.691423}}],
    
    Line[{{-4.858385, -9.667983, 6.691423},{-5.362823, -10.646396, 
        7.027506}}],
    Line[{{-5.362823, -10.646396, 7.027506},{-5.916234, -11.704679, 
        7.464457}}],
    Line[{{-5.916234, -11.704679, 7.464457},{-6.521513, -12.841386, 
        8.021201}}],
    Line[{{-6.521513, -12.841386, 8.021201},{-7.180977, -14.051561, 
        8.719299}}],
    Line[{{-7.180977, -14.051561, 8.719299},{-7.896039, -15.325502, 
        9.582762}}],
    Line[{{-7.896039, -15.325502, 9.582762},{-8.666759, -16.647245, 
        10.637463}}],
    Line[{{-8.666759, -16.647245, 10.637463},{-9.491302, -17.992912, 
        11.910057}}],
    Line[{{-9.491302, -17.992912, 11.910057},{-10.365289, -19.329027, 
        13.426160}}],
    Line[{{-10.365289, -19.329027, 13.426160},{-11.281040, -20.611040, 
        15.207626}}],
    Line[{{-11.281040, -20.611040, 15.207626},{-12.226797, -21.782492, 
        17.268797}}],
    Line[{{-12.226797, -21.782492, 17.268797},{-13.185977, -22.775373, 
        19.611765}}],
    Line[{{-13.185977, -22.775373, 19.611765},{-14.136627, -23.512413, 
        22.220943}}],
    Line[{{-14.136627, -23.512413, 22.220943},{-15.051266, -23.911875, 
        25.057758}}],
    Line[{{-15.051266, -23.911875, 25.057758},{-15.897336, -23.895287, 
        28.056614}}],
    Line[{{-15.897336, -23.895287, 28.056614},{-16.638468, -23.397783, 
        31.123709}}],
    Line[{{-16.638468, -23.397783, 31.123709},{-17.236725, -22.380016, 
        34.140465}}],
    Line[{{-17.236725, -22.380016, 34.140465},{-17.655727, -20.839062, 
        36.972527}}],
    Line[{{-17.655727, -20.839062, 36.972527},{-17.864347, -18.815599, 
        39.483837}}],
    Line[{{-17.864347, -18.815599, 39.483837},{-17.840454, -16.394279, 
        41.554020}}],
    Line[{{-17.840454, -16.394279, 41.554020},{-17.573927, -13.696068, 
        43.095070}}],
    Line[{{-17.573927, -13.696068, 43.095070},{-17.068300, -10.863462, 
        44.063190}}],
    Line[{{-17.068300, -10.863462, 44.063190},{-16.340628, -8.041783, 
        44.462910}}],
    Line[{{-16.340628, -8.041783, 44.462910},{-15.419550, -5.360996, 
        44.342361}}],
    Line[{{-15.419550, -5.360996, 44.342361},{-14.342042, -2.922199, 
        43.781914}}],
    Line[{{-14.342042, -2.922199, 43.781914},{-13.149482, -0.790950, 
        42.879391}}],
    Line[{{-13.149482, -0.790950, 42.879391},{-11.883817, 1.002556, 
        41.735718}}],
    Line[{{-11.883817, 1.002556, 41.735718},{-10.584360, 2.458197, 
        40.443703}}],
    Line[{{-10.584360, 2.458197, 40.443703},{-9.285561, 3.597999, 
        39.081104}}],
    Line[{{-9.285561, 3.597999, 39.081104},{-8.015759, 4.457782, 37.707882}}],
    
    Line[{{-8.015759, 4.457782, 37.707882},{-6.796824, 5.079915, 36.366543}}],
    
    Line[{{-6.796824, 5.079915, 36.366543},{-5.644421, 5.507855, 35.084408}}],
    
    Line[{{-5.644421, 5.507855, 35.084408},{-4.568688, 5.782568, 33.876759}}],
    
    Line[{{-4.568688, 5.782568, 33.876759},{-3.575106, 5.940527, 32.749996}}],
    
    Line[{{-3.575106, 5.940527, 32.749996},{-2.665418, 6.012898, 31.704472}}],
    
    Line[{{-2.665418, 6.012898, 31.704472},{-1.838494, 6.025503, 30.736767}}],
    
    Line[{{-1.838494, 6.025503, 30.736767},{-1.091099, 5.999208, 29.841387}}],
    
    Line[{{-1.091099, 5.999208, 29.841387},{-0.418535, 5.950551, 29.011951}}],
    
    Line[{{-0.418535, 5.950551, 29.011951},{0.184841, 5.892406, 28.241989}}],
    Line[{{0.184841, 5.892406, 28.241989},{0.725210, 5.834646, 27.525410}}],
    Line[{{0.725210, 5.834646, 27.525410},{1.208981, 5.784718, 26.856762}}],
    Line[{{1.208981, 5.784718, 26.856762},{1.642568, 5.748153, 26.231359}}],
    Line[{{1.642568, 5.748153, 26.231359},{2.032225, 5.728981, 25.645298}}],
    Line[{{2.032225, 5.728981, 25.645298},{2.383934, 5.730071, 25.095419}}],
    Line[{{2.383934, 5.730071, 25.095419},{2.703338, 5.753406, 24.579260}}],
    Line[{{2.703338, 5.753406, 24.579260},{2.995696, 5.800304, 24.094975}}],
    Line[{{2.995696, 5.800304, 24.094975},{3.265867, 5.871581, 23.641272}}],
    Line[{{3.265867, 5.871581, 23.641272},{3.518309, 5.967690, 23.217340}}],
    Line[{{3.518309, 5.967690, 23.217340},{3.757082, 6.088810, 22.822794}}],
    Line[{{3.757082, 6.088810, 22.822794},{3.985868, 6.234931, 22.457630}}],
    Line[{{3.985868, 6.234931, 22.457630},{4.207990, 6.405892, 22.122183}}],
    Line[{{4.207990, 6.405892, 22.122183},{4.426434, 6.601416, 21.817101}}],
    Line[{{4.426434, 6.601416, 21.817101},{4.643869, 6.821126, 21.543318}}],
    Line[{{4.643869, 6.821126, 21.543318},{4.862672, 7.064540, 21.302046}}],
    Line[{{4.862672, 7.064540, 21.302046},{5.084940, 7.331061, 21.094746}}],
    Line[{{5.084940, 7.331061, 21.094746},{5.312510, 7.619955, 20.923124}}],
    Line[{{5.312510, 7.619955, 20.923124},{5.546961, 7.930301, 20.789120}}],
    Line[{{5.546961, 7.930301, 20.789120},{5.789627, 8.260956, 20.694878}}],
    Line[{{5.789627, 8.260956, 20.694878},{6.041594, 8.610497, 20.642740}}],
    Line[{{6.041594, 8.610497, 20.642740},{6.303691, 8.977152, 20.635201}}],
    Line[{{6.303691, 8.977152, 20.635201},{6.576479, 9.358728, 20.674864}}],
    Line[{{6.576479, 9.358728, 20.674864},{6.860237, 9.752540, 20.764387}}],
    Line[{{6.860237, 9.752540, 20.764387},{7.154932, 10.155327, 20.906408}}],
    Line[{{7.154932, 10.155327, 20.906408},{7.460194, 10.563185, 21.103426}}],
    
    Line[{{7.460194, 10.563185, 21.103426},{7.775280, 10.971477, 21.357695}}],
    
    Line[{{7.775280, 10.971477, 21.357695},{8.099047, 11.374830, 21.671061}}],
    
    Line[{{8.099047, 11.374830, 21.671061},{8.429898, 11.767043, 22.044781}}],
    
    Line[{{8.429898, 11.767043, 22.044781},{8.765775, 12.141163, 22.479322}}],
    
    Line[{{8.765775, 12.141163, 22.479322},{9.104107, 12.489489, 22.974138}}],
    
    Line[{{9.104107, 12.489489, 22.974138},{9.441806, 12.803710, 23.527422}}],
    
    Line[{{9.441806, 12.803710, 23.527422},{9.775274, 13.075109, 24.135910}}],
    
    Line[{{9.775274, 13.075109, 24.135910},{
      10.100396, 13.294750, 24.794607}}],
    Line[{{10.100396, 13.294750, 24.794607},{
      10.412630, 13.453921, 25.496742}}],
    Line[{{10.412630, 13.453921, 25.496742},{
      10.707029, 13.544431, 26.233524}}],
    Line[{{10.707029, 13.544431, 26.233524},{
      10.978409, 13.559157, 26.994331}}],
    Line[{{10.978409, 13.559157, 26.994331},{
      11.221461, 13.492476, 27.766750}}],
    Line[{{11.221461, 13.492476, 27.766750},{
      11.430941, 13.340796, 28.536875}}],
    Line[{{11.430941, 13.340796, 28.536875},{
      11.601876, 13.102908, 29.289803}}],
    Line[{{11.601876, 13.102908, 29.289803},{
      11.729784, 12.780374, 30.010126}}],
    Line[{{11.729784, 12.780374, 30.010126},{
      11.810895, 12.377614, 30.682657}}],
    Line[{{11.810895, 12.377614, 30.682657},{
      11.842359, 11.901926, 31.293119}}],
    Line[{{11.842359, 11.901926, 31.293119},{
      11.822419, 11.363209, 31.828856}}],
    Line[{{11.822419, 11.363209, 31.828856},{
      11.750538, 10.773561, 32.279438}}],
    Line[{{11.750538, 10.773561, 32.279438},{
      11.627465, 10.146663, 32.637180}}],
    Line[{{11.627465, 10.146663, 32.637180},{
      11.455229, 9.497057, 32.897396}}],
    Line[{{11.455229, 9.497057, 32.897396},{11.237058, 8.839414, 33.058483}}],
    
    Line[{{11.237058, 8.839414, 33.058483},{10.977246, 8.187819, 33.121796}}],
    
    Line[{{10.977246, 8.187819, 33.121796},{10.680965, 7.555098, 33.091309}}],
    
    Line[{{10.680965, 7.555098, 33.091309},{10.354036, 6.952381, 32.973190}}],
    
    Line[{{10.354036, 6.952381, 32.973190},{10.002687, 6.388758, 32.775230}}],
    
    Line[{{10.002687, 6.388758, 32.775230},{9.633316, 5.871138, 32.506310}}],
    Line[{{9.633316, 5.871138, 32.506310},{9.252261, 5.404259, 32.175854}}],
    Line[{{9.252261, 5.404259, 32.175854},{8.865610, 4.990836, 31.793367}}],
    Line[{{8.865610, 4.990836, 31.793367},{8.479042, 4.631797, 31.368053}}],
    Line[{{8.479042, 4.631797, 31.368053},{8.097707, 4.326571, 30.908541}}],
    Line[{{8.097707, 4.326571, 30.908541},{7.726151, 4.073413, 30.422697}}],
    Line[{{7.726151, 4.073413, 30.422697},{7.368279, 3.869710, 29.917526}}],
    Line[{{7.368279, 3.869710, 29.917526},{7.027345, 3.712272, 29.399151}}],
    Line[{{7.027345, 3.712272, 29.399151},{6.705972, 3.597587, 28.872831}}],
    Line[{{6.705972, 3.597587, 28.872831},{6.406190, 3.522026, 28.343029}}],
    Line[{{6.406190, 3.522026, 28.343029},{6.129496, 3.482013, 27.813492}}],
    Line[{{6.129496, 3.482013, 27.813492},{5.876908, 3.474150, 27.287348}}],
    Line[{{5.876908, 3.474150, 27.287348},{5.649039, 3.495300, 26.767199}}],
    Line[{{5.649039, 3.495300, 26.767199},{5.446157, 3.542652, 26.255224}}],
    Line[{{5.446157, 3.542652, 26.255224},{5.268257, 3.613744, 25.753258}}],
    Line[{{5.268257, 3.613744, 25.753258},{5.115117, 3.706482, 25.262865}}],
    Line[{{5.115117, 3.706482, 25.262865},{4.986352, 3.819129, 24.785418}}],
    Line[{{4.986352, 3.819129, 24.785418},{4.881469, 3.950296, 24.322144}}],
    Line[{{4.881469, 3.950296, 24.322144},{4.799902, 4.098913, 23.874178}}],
    Line[{{4.799902, 4.098913, 23.874178},{4.741055, 4.264208, 23.442612}}],
    Line[{{4.741055, 4.264208, 23.442612},{4.704323, 4.445670, 23.028515}}],
    Line[{{4.704323, 4.445670, 23.028515},{4.689128, 4.643023, 22.632988}}],
    Line[{{4.689128, 4.643023, 22.632988},{4.694928, 4.856185, 22.257170}}],
    Line[{{4.694928, 4.856185, 22.257170},{4.721229, 5.085238, 21.902273}}],
    Line[{{4.721229, 5.085238, 21.902273},{4.767603, 5.330390, 21.569605}}],
    Line[{{4.767603, 5.330390, 21.569605},{4.833686, 5.591943, 21.260590}}],
    Line[{{4.833686, 5.591943, 21.260590},{4.919181, 5.870252, 20.976786}}],
    Line[{{4.919181, 5.870252, 20.976786},{5.023850, 6.165685, 20.719908}}],
    Line[{{5.023850, 6.165685, 20.719908},{5.147518, 6.478584, 20.491842}}],
    Line[{{5.147518, 6.478584, 20.491842},{5.290053, 6.809215, 20.294662}}],
    Line[{{5.290053, 6.809215, 20.294662},{5.451353, 7.157720, 20.130638}}],
    Line[{{5.451353, 7.157720, 20.130638},{5.631333, 7.524054, 20.002243}}],
    Line[{{5.631333, 7.524054, 20.002243},{5.829900, 7.907929, 19.912167}}],
    Line[{{5.829900, 7.907929, 19.912167},{6.046928, 8.308736, 19.863287}}],
    Line[{{6.046928, 8.308736, 19.863287},{6.282228, 8.725469, 19.858681}}],
    Line[{{6.282228, 8.725469, 19.858681},{6.535506, 9.156637, 19.901560}}],
    Line[{{6.535506, 9.156637, 19.901560},{6.806333, 9.600177, 19.995258}}],
    Line[{{6.806333, 9.600177, 19.995258},{7.094088, 10.053350, 20.143118}}],
    Line[{{7.094088, 10.053350, 20.143118},{7.397913, 10.512644, 20.348450}}],
    
    Line[{{7.397913, 10.512644, 20.348450},{7.716659, 10.973700, 20.614325}}],
    
    Line[{{7.716659, 10.973700, 20.614325},{8.048820, 11.431189, 20.943512}}],
    
    Line[{{8.048820, 11.431189, 20.943512},{8.392492, 11.878839, 21.338171}}],
    
    Line[{{8.392492, 11.878839, 21.338171},{8.745286, 12.309293, 21.799723}}],
    
    Line[{{8.745286, 12.309293, 21.799723},{9.104311, 12.714282, 22.328495}}],
    
    Line[{{9.104311, 12.714282, 22.328495},{9.466109, 13.084606, 22.923491}}],
    
    Line[{{9.466109, 13.084606, 22.923491},{9.826642, 13.410367, 23.582056}}],
    
    Line[{{9.826642, 13.410367, 23.582056},{
      10.181297, 13.681255, 24.299637}}],
    Line[{{10.181297, 13.681255, 24.299637},{
      10.524900, 13.886861, 25.069469}}],
    Line[{{10.524900, 13.886861, 25.069469},{
      10.851808, 14.017221, 25.882504}}],
    Line[{{10.851808, 14.017221, 25.882504},{
      11.155999, 14.063325, 26.727301}}],
    Line[{{11.155999, 14.063325, 26.727301},{
      11.431242, 14.017772, 27.590117}}],
    Line[{{11.431242, 14.017772, 27.590117},{
      11.671298, 13.875336, 28.455307}}],
    Line[{{11.671298, 13.875336, 28.455307},{
      11.870155, 13.633636, 29.305635}}],
    Line[{{11.870155, 13.633636, 29.305635},{
      12.022300, 13.293486, 30.123104}}],
    Line[{{12.022300, 13.293486, 30.123104},{
      12.122992, 12.859240, 30.889666}}],
    Line[{{12.122992, 12.859240, 30.889666},{
      12.168524, 12.338783, 31.588169}}],
    Line[{{12.168524, 12.338783, 31.588169},{
      12.156460, 11.743339, 32.203247}}],
    Line[{{12.156460, 11.743339, 32.203247},{
      12.085806, 11.086935, 32.722172}}],
    Line[{{12.085806, 11.086935, 32.722172},{
      11.957103, 10.385674, 33.135475}}],
    Line[{{11.957103, 10.385674, 33.135475},{
      11.772436, 9.656838, 33.437366}}],
    Line[{{11.772436, 9.656838, 33.437366},{11.535357, 8.917956, 33.625847}}],
    
    Line[{{11.535357, 8.917956, 33.625847},{11.250717, 8.185820, 33.702572}}],
    
    Line[{{11.250717, 8.185820, 33.702572},{10.924442, 7.475717, 33.672421}}],
    
    Line[{{10.924442, 7.475717, 33.672421},{10.563244, 6.800790, 33.542934}}],
    
    Line[{{10.563244, 6.800790, 33.542934},{10.174330, 6.171636, 33.323612}}],
    
    Line[{{10.174330, 6.171636, 33.323612},{9.765096, 5.596134, 33.025181}}],
    Line[{{9.765096, 5.596134, 33.025181},{9.342854, 5.079488, 32.658936}}],
    Line[{{9.342854, 5.079488, 32.658936},{8.914595, 4.624425, 32.236134}}],
    Line[{{8.914595, 4.624425, 32.236134},{8.486794, 4.231521, 31.767561}}],
    Line[{{8.486794, 4.231521, 31.767561},{8.065281, 3.899584, 31.263174}}],
    Line[{{8.065281, 3.899584, 31.263174},{7.655143, 3.626065, 30.731916}}],
    Line[{{7.655143, 3.626065, 30.731916},{7.260694, 3.407455, 30.181618}}],
    Line[{{7.260694, 3.407455, 30.181618},{6.885471, 3.239634, 29.618986}}],
    Line[{{6.885471, 3.239634, 29.618986},{6.532266, 3.118186, 29.049667}}],
    Line[{{6.532266, 3.118186, 29.049667},{6.203179, 3.038635, 28.478342}}],
    Line[{{6.203179, 3.038635, 28.478342},{5.899692, 2.996646, 27.908842}}],
    Line[{{5.899692, 2.996646, 27.908842},{5.622743, 2.988154, 27.344273}}],
    Line[{{5.622743, 2.988154, 27.344273},{5.372813, 3.009458, 26.787149}}],
    Line[{{5.372813, 3.009458, 26.787149},{5.150003, 3.057279, 26.239508}}],
    Line[{{5.150003, 3.057279, 26.239508},{4.954117, 3.128787, 25.703001}}],
    Line[{{4.954117, 3.128787, 25.703001},{4.784727, 3.221593, 25.178999}}],
    Line[{{4.784727, 3.221593, 25.178999},{4.641240, 3.333752, 24.668665}}],
    Line[{{4.641240, 3.333752, 24.668665},{4.522956, 3.463728, 24.173012}}],
    Line[{{4.522956, 3.463728, 24.173012},{4.429114, 3.610367, 23.692963}}],
    Line[{{4.429114, 3.610367, 23.692963},{4.358931, 3.772864, 23.229395}}],
    Line[{{4.358931, 3.772864, 23.229395},{4.311637, 3.950721, 22.783175}}],
    Line[{{4.311637, 3.950721, 22.783175},{4.286506, 4.143715, 22.355190}}],
    Line[{{4.286506, 4.143715, 22.355190},{4.282866, 4.351858, 21.946381}}],
    Line[{{4.282866, 4.351858, 21.946381},{4.300121, 4.575358, 21.557758}}],
    Line[{{4.300121, 4.575358, 21.557758},{4.337764, 4.814594, 21.190439}}],
    Line[{{4.337764, 4.814594, 21.190439},{4.395373, 5.070067, 20.845657}}],
    Line[{{4.395373, 5.070067, 20.845657},{4.472623, 5.342377, 20.524786}}],
    Line[{{4.472623, 5.342377, 20.524786},{4.569278, 5.632176, 20.229372}}],
    Line[{{4.569278, 5.632176, 20.229372},{4.685187, 5.940139, 19.961140}}],
    Line[{{4.685187, 5.940139, 19.961140},{4.820281, 6.266916, 19.722021}}],
    Line[{{4.820281, 6.266916, 19.722021},{4.974551, 6.613088, 19.514177}}],
    Line[{{4.974551, 6.613088, 19.514177},{5.148042, 6.979115, 19.340014}}],
    Line[{{5.148042, 6.979115, 19.340014},{5.340829, 7.365276, 19.202185}}],
    Line[{{5.340829, 7.365276, 19.202185},{5.552998, 7.771602, 19.103626}}],
    Line[{{5.552998, 7.771602, 19.103626},{5.784609, 8.197795, 19.047533}}],
    Line[{{5.784609, 8.197795, 19.047533},{6.035673, 8.643147, 19.037365}}],
    Line[{{6.035673, 8.643147, 19.037365},{6.306108, 9.106428, 19.076820}}],
    Line[{{6.306108, 9.106428, 19.076820},{6.595691, 9.585791, 19.169792}}],
    Line[{{6.595691, 9.585791, 19.169792},{6.904012, 10.078635, 19.320305}}],
    Line[{{6.904012, 10.078635, 19.320305},{7.230411, 10.581503, 19.532410}}],
    
    Line[{{7.230411, 10.581503, 19.532410},{7.573913, 11.089930, 19.810076}}],
    
    Line[{{7.573913, 11.089930, 19.810076},{7.933161, 11.598362, 20.156969}}],
    
    Line[{{7.933161, 11.598362, 20.156969},{8.306337, 12.100008, 20.576288}}],
    
    Line[{{8.306337, 12.100008, 20.576288},{8.691094, 12.586853, 21.070435}}],
    
    Line[{{8.691094, 12.586853, 21.070435},{9.084478, 13.049578, 21.640728}}],
    
    Line[{{9.084478, 13.049578, 21.640728},{9.482876, 13.477683, 22.287029}}],
    
    Line[{{9.482876, 13.477683, 22.287029},{9.881965, 13.859634, 23.007368}}],
    
    Line[{{9.881965, 13.859634, 23.007368},{
      10.276690, 14.183127, 23.797523}}],
    Line[{{10.276690, 14.183127, 23.797523},{
      10.661305, 14.435583, 24.650740}}],
    Line[{{10.661305, 14.435583, 24.650740},{
      11.029399, 14.604601, 25.557362}}],
    Line[{{11.029399, 14.604601, 25.557362},{
      11.374040, 14.678748, 26.504776}}],
    Line[{{11.374040, 14.678748, 26.504776},{
      11.687948, 14.648271, 27.477488}}],
    Line[{{11.687948, 14.648271, 27.477488},{
      11.963712, 14.505997, 28.457253}}],
    Line[{{11.963712, 14.505997, 28.457253},{
      12.194108, 14.248029, 29.423847}}],
    Line[{{12.194108, 14.248029, 29.423847},{
      12.372414, 13.874460, 30.355715}}],
    Line[{{12.372414, 13.874460, 30.355715},{
      12.492766, 13.389772, 31.231068}}],
    Line[{{12.492766, 13.389772, 31.231068},{
      12.550508, 12.802978, 32.029041}}],
    Line[{{12.550508, 12.802978, 32.029041},{
      12.542488, 12.127326, 32.730892}}],
    Line[{{12.542488, 12.127326, 32.730892},{
      12.467301, 11.379691, 33.321117}}],
    Line[{{12.467301, 11.379691, 33.321117},{
      12.325417, 10.579636, 33.788288}}],
    Line[{{12.325417, 10.579636, 33.788288},{
      12.119207, 9.748235, 34.125648}}],
    Line[{{12.119207, 9.748235, 34.125648},{11.852847, 8.906778, 34.331245}}],
    
    Line[{{11.852847, 8.906778, 34.331245},{11.532096, 8.075575, 34.407673}}],
    
    Line[{{11.532096, 8.075575, 34.407673},{11.164009, 7.272893, 34.361538}}],
    
    Line[{{11.164009, 7.272893, 34.361538},{10.756581, 6.514181, 34.202648}}],
    
    Line[{{10.756581, 6.514181, 34.202648},{10.318353, 5.811554, 33.943081}}],
    
    Line[{{10.318353, 5.811554, 33.943081},{9.858037, 5.173671, 33.596210}}],
    Line[{{9.858037, 5.173671, 33.596210},{9.384179, 4.605835, 33.175865}}],
    Line[{{9.384179, 4.605835, 33.175865},{8.904869, 4.110309, 32.695591}}],
    Line[{{8.904869, 4.110309, 32.695591},{8.427508, 3.686780, 32.168091}}],
    Line[{{8.427508, 3.686780, 32.168091},{7.958666, 3.332890, 31.604866}}],
    Line[{{7.958666, 3.332890, 31.604866},{7.503982, 3.044772, 31.016010}}],
    Line[{{7.503982, 3.044772, 31.016010},{7.068138, 2.817556, 30.410151}}],
    Line[{{7.068138, 2.817556, 30.410151},{6.654876, 2.645808, 29.794483}}],
    Line[{{6.654876, 2.645808, 29.794483},{6.267056, 2.523885, 29.174896}}],
    Line[{{6.267056, 2.523885, 29.174896},{5.906726, 2.446228, 28.556110}}],
    Line[{{5.906726, 2.446228, 28.556110},{5.575224, 2.407556, 27.941860}}],
    Line[{{5.575224, 2.407556, 27.941860},{5.273280, 2.403017, 27.335060}}],
    Line[{{5.273280, 2.403017, 27.335060},{5.001113, 2.428270, 26.737961}}],
    Line[{{5.001113, 2.428270, 26.737961},{4.758539, 2.479525, 26.152304}}],
    Line[{{4.758539, 2.479525, 26.152304},{4.545054, 2.553559, 25.579428}}],
    Line[{{4.545054, 2.553559, 25.579428},{4.359925, 2.647704, 25.020386}}],
    Line[{{4.359925, 2.647704, 25.020386},{4.202258, 2.759813, 24.476027}}],
    Line[{{4.202258, 2.759813, 24.476027},{4.071067, 2.888229, 23.947060}}],
    Line[{{4.071067, 2.888229, 23.947060},{3.965322, 3.031736, 23.434111}}],
    Line[{{3.965322, 3.031736, 23.434111},{3.883993, 3.189519, 22.937771}}],
    Line[{{3.883993, 3.189519, 22.937771},{3.826092, 3.361113, 22.458626}}],
    Line[{{3.826092, 3.361113, 22.458626},{3.790694, 3.546365, 21.997295}}],
    Line[{{3.790694, 3.546365, 21.997295},{3.776959, 3.745393, 21.554445}}],
    Line[{{3.776959, 3.745393, 21.554445},{3.784153, 3.958542, 21.130825}}],
    Line[{{3.784153, 3.958542, 21.130825},{3.811652, 4.186356, 20.727282}}],
    Line[{{3.811652, 4.186356, 20.727282},{3.858954, 4.429542, 20.344774}}],
    Line[{{3.858954, 4.429542, 20.344774},{3.925674, 4.688936, 19.984413}}],
    Line[{{3.925674, 4.688936, 19.984413},{4.011554, 4.965474, 19.647467}}],
    Line[{{4.011554, 4.965474, 19.647467},{4.116449, 5.260159, 19.335388}}],
    Line[{{4.116449, 5.260159, 19.335388},{4.240326, 5.574028, 19.049843}}],
    Line[{{4.240326, 5.574028, 19.049843},{4.383255, 5.908114, 18.792732}}],
    Line[{{4.383255, 5.908114, 18.792732},{4.545395, 6.263407, 18.566217}}],
    Line[{{4.545395, 6.263407, 18.566217},{4.726980, 6.640802, 18.372751}}],
    Line[{{4.726980, 6.640802, 18.372751},{4.928301, 7.041041, 18.215096}}],
    Line[{{4.928301, 7.041041, 18.215096},{5.149681, 7.464653, 18.096350}}],
    Line[{{5.149681, 7.464653, 18.096350},{5.391449, 7.911865, 18.019958}}],
    Line[{{5.391449, 7.911865, 18.019958},{5.653906, 8.382513, 17.989729}}],
    Line[{{5.653906, 8.382513, 17.989729},{5.937286, 8.875936, 18.009827}}],
    Line[{{5.937286, 8.875936, 18.009827},{6.241709, 9.390837, 18.084740}}],
    Line[{{6.241709, 9.390837, 18.084740},{6.567122, 9.925156, 18.219255}}],
    Line[{{6.567122, 9.925156, 18.219255},{6.913240, 10.475903, 18.418358}}],
    Line[{{6.913240, 10.475903, 18.418358},{7.279467, 11.038995, 18.687124}}],
    
    Line[{{7.279467, 11.038995, 18.687124},{7.664817, 11.609083, 19.030561}}],
    
    Line[{{7.664817, 11.609083, 19.030561},{8.067821, 12.179409, 19.453346}}],
    
    Line[{{8.067821, 12.179409, 19.453346},{8.486428, 12.741627, 19.959589}}],
    
    Line[{{8.486428, 12.741627, 19.959589},{8.917918, 13.285784, 20.552397}}],
    
    Line[{{8.917918, 13.285784, 20.552397},{9.358792, 13.800234, 21.233505}}],
    
    Line[{{9.358792, 13.800234, 21.233505},{9.804702, 14.271773, 22.002731}}],
    
    Line[{{9.804702, 14.271773, 22.002731},{
      10.250394, 14.685896, 22.857477}}],
    Line[{{10.250394, 14.685896, 22.857477},{
      10.689680, 15.027156, 23.792185}}],
    Line[{{10.689680, 15.027156, 23.792185},{
      11.115473, 15.279791, 24.797867}}],
    Line[{{11.115473, 15.279791, 24.797867},{
      11.519878, 15.428552, 25.861794}}],
    Line[{{11.519878, 15.428552, 25.861794},{
      11.894362, 15.459627, 26.967321}}],
    Line[{{11.894362, 15.459627, 26.967321},{
      12.230000, 15.361802, 28.094051}}],
    Line[{{12.230000, 15.361802, 28.094051},{
      12.517827, 15.127564, 29.218369}}],
    Line[{{12.517827, 15.127564, 29.218369},{
      12.749230, 14.754082, 30.314323}}],
    Line[{{12.749230, 14.754082, 30.314323},{
      12.916419, 14.244126, 31.354834}}],
    Line[{{12.916419, 14.244126, 31.354834},{
      13.012885, 13.606293, 32.313278}}],
    Line[{{13.012885, 13.606293, 32.313278},{
      13.033841, 12.855021, 33.165100}}],
    Line[{{13.033841, 12.855021, 33.165100},{
      12.976590, 12.009903, 33.889427}}],
    Line[{{12.976590, 12.009903, 33.889427},{
      12.840759, 11.094555, 34.470398}}],
    Line[{{12.840759, 11.094555, 34.470398},{
      12.628394, 10.135077, 34.898087}}],
    Line[{{12.628394, 10.135077, 34.898087},{
      12.343880, 9.158332, 35.168865}}],
    Line[{{12.343880, 9.158332, 35.168865},{11.993704, 8.190203, 35.285225}}],
    
    Line[{{11.993704, 8.190203, 35.285225},{11.586092, 7.254069, 35.255043}}],
    
    Line[{{11.586092, 7.254069, 35.255043},{11.130544, 6.369687, 35.090527}}],
    
    Line[{{11.130544, 6.369687, 35.090527},{10.637327, 5.552459, 34.806915}}],
    
    Line[{{10.637327, 5.552459, 34.806915},{10.116979, 4.813186, 34.421169}}],
    
    Line[{{10.116979, 4.813186, 34.421169},{9.579840, 4.158226, 33.950729}}],
    Line[{{9.579840, 4.158226, 33.950729},{9.035677, 3.589951, 33.412552}}],
    Line[{{9.035677, 3.589951, 33.412552},{8.493385, 3.107399, 32.822346}}],
    Line[{{8.493385, 3.107399, 32.822346},{7.960790, 2.707011, 32.194107}}],
    Line[{{7.960790, 2.707011, 32.194107},{7.444539, 2.383375, 31.539883}}],
    Line[{{7.444539, 2.383375, 31.539883},{6.950068, 2.129898, 30.869740}}],
    Line[{{6.950068, 2.129898, 30.869740},{6.481638, 1.939387, 30.191847}}],
    Line[{{6.481638, 1.939387, 30.191847},{6.042408, 1.804515, 29.512674}}],
    Line[{{6.042408, 1.804515, 29.512674},{5.634545, 1.718161, 28.837219}}],
    Line[{{5.634545, 1.718161, 28.837219},{5.259357, 1.673664, 28.169252}}],
    Line[{{5.259357, 1.673664, 28.169252},{4.917418, 1.664976, 27.511559}}],
    Line[{{4.917418, 1.664976, 27.511559},{4.608709, 1.686742, 26.866146}}],
    Line[{{4.608709, 1.686742, 26.866146},{4.332736, 1.734343, 26.234436}}],
    Line[{{4.332736, 1.734343, 26.234436},{4.088646, 1.803882, 25.617411}}],
    Line[{{4.088646, 1.803882, 25.617411},{3.875335, 1.892156, 25.015745}}],
    Line[{{3.875335, 1.892156, 25.015745},{3.691526, 1.996607, 24.429901}}],
    Line[{{3.691526, 1.996607, 24.429901},{3.535852, 2.115263, 23.860205}}],
    Line[{{3.535852, 2.115263, 23.860205},{3.406913, 2.246681, 23.306904}}],
    Line[{{3.406913, 2.246681, 23.306904},{3.303330, 2.389884, 22.770216}}],
    Line[{{3.303330, 2.389884, 22.770216},{3.223779, 2.544302, 22.250353}}],
    Line[{{3.223779, 2.544302, 22.250353},{3.167028, 2.709726, 21.747561}}],
    Line[{{3.167028, 2.709726, 21.747561},{3.131957, 2.886255, 21.262127}}],
    Line[{{3.131957, 2.886255, 21.262127},{3.117575, 3.074255, 20.794409}}],
    Line[{{3.117575, 3.074255, 20.794409},{3.123033, 3.274322, 20.344847}}],
    Line[{{3.123033, 3.274322, 20.344847},{3.147627, 3.487250, 19.913977}}],
    Line[{{3.147627, 3.487250, 19.913977},{3.190805, 3.714003, 19.502455}}],
    Line[{{3.190805, 3.714003, 19.502455},{3.252169, 3.955687, 19.111067}}],
    Line[{{3.252169, 3.955687, 19.111067},{3.331464, 4.213532, 18.740755}}],
    Line[{{3.331464, 4.213532, 18.740755},{3.428588, 4.488863, 18.392637}}],
    Line[{{3.428588, 4.488863, 18.392637},{3.543575, 4.783082, 18.068031}}],
    Line[{{3.543575, 4.783082, 18.068031},{3.676592, 5.097646, 17.768488}}],
    Line[{{3.676592, 5.097646, 17.768488},{3.827930, 5.434029, 17.495810}}],
    Line[{{3.827930, 5.434029, 17.495810},{3.997996, 5.793705, 17.252100}}],
    Line[{{3.997996, 5.793705, 17.252100},{4.187291, 6.178091, 17.039783}}],
    Line[{{4.187291, 6.178091, 17.039783},{4.396402, 6.588512, 16.861656}}],
    Line[{{4.396402, 6.588512, 16.861656},{4.625980, 7.026132, 16.720915}}],
    Line[{{4.625980, 7.026132, 16.720915},{4.876712, 7.491876, 16.621193}}],
    Line[{{4.876712, 7.491876, 16.621193},{5.149294, 7.986346, 16.566599}}],
    Line[{{5.149294, 7.986346, 16.566599},{5.444391, 8.509692, 16.561731}}],
    Line[{{5.444391, 8.509692, 16.561731},{5.762593, 9.061490, 16.611694}}],
    Line[{{5.762593, 9.061490, 16.611694},{6.104360, 9.640565, 16.722086}}],
    Line[{{6.104360, 9.640565, 16.722086},{6.469949, 10.244805, 16.898947}}],
    Line[{{6.469949, 10.244805, 16.898947},{6.859344, 10.870955, 17.148705}}],
    
    Line[{{6.859344, 10.870955, 17.148705},{7.272147, 11.514368, 17.477987}}],
    
    Line[{{7.272147, 11.514368, 17.477987},{7.707488, 12.168764, 17.893494}}],
    
    Line[{{7.707488, 12.168764, 17.893494},{8.163885, 12.825992, 18.401621}}],
    
    Line[{{8.163885, 12.825992, 18.401621},{8.639130, 13.475810, 19.008135}}],
    
    Line[{{8.639130, 13.475810, 19.008135},{9.130132, 14.105701, 19.717649}}],
    
    Line[{{9.130132, 14.105701, 19.717649},{9.632801, 14.700891, 20.533005}}],
    
    Line[{{9.632801, 14.700891, 20.533005},{
      10.141917, 15.244365, 21.454584}}],
    Line[{{10.141917, 15.244365, 21.454584},{
      10.651042, 15.717207, 22.479528}}],
    Line[{{10.651042, 15.717207, 22.479528},{
      11.152482, 16.099197, 23.600950}}],
    Line[{{11.152482, 16.099197, 23.600950},{
      11.637325, 16.369640, 24.807272}}],
    Line[{{11.637325, 16.369640, 24.807272},{
      12.095550, 16.508551, 26.081644}}],
    Line[{{12.095550, 16.508551, 26.081644},{
      12.516286, 16.498146, 27.401825}}],
    Line[{{12.516286, 16.498146, 27.401825},{
      12.888184, 16.324436, 28.740509}}],
    Line[{{12.888184, 16.324436, 28.740509},{
      13.199882, 15.978941, 30.066010}}],
    Line[{{13.199882, 15.978941, 30.066010},{
      13.440627, 15.460079, 31.343872}}],
    Line[{{13.440627, 15.460079, 31.343872},{
      13.600916, 14.774232, 32.538742}}],
    Line[{{13.600916, 14.774232, 32.538742},{
      13.673159, 13.936058, 33.616749}}],
    Line[{{13.673159, 13.936058, 33.616749},{
      13.652267, 12.968042, 34.547935}}],
    Line[{{13.652267, 12.968042, 34.547935},{
      13.536107, 11.899175, 35.308487}}],
    Line[{{13.536107, 11.899175, 35.308487},{
      13.325739, 10.762943, 35.882389}}],
    Line[{{13.325739, 10.762943, 35.882389},{
      13.025432, 9.594832, 36.262363}}],
    Line[{{13.025432, 9.594832, 36.262363},{12.642411, 8.429687, 36.449841}}],
    
    Line[{{12.642411, 8.429687, 36.449841},{12.186407, 7.299409, 36.454098}}],
    
    Line[{{12.186407, 7.299409, 36.454098},{11.669034, 6.231046, 36.290775}}],
    
    Line[{{11.669034, 6.231046, 36.290775},{11.103094, 5.245613, 35.980003}}],
    
    Line[{{11.103094, 5.245613, 35.980003},{10.501856, 4.357661, 35.544384}}],
    
    Line[{{10.501856, 4.357661, 35.544384},{9.878405, 3.575453, 35.007183}}],
    Line[{{9.878405, 3.575453, 35.007183},{9.245087, 2.901653, 34.390831}}],
    Line[{{9.245087, 2.901653, 34.390831},{8.613098, 2.334307, 33.715836}}],
    Line[{{8.613098, 2.334307, 33.715836},{7.992201, 1.867948, 33.000134}}],
    Line[{{7.992201, 1.867948, 33.000134},{7.390586, 1.494695, 32.258804}}],
    Line[{{7.390586, 1.494695, 32.258804},{6.814835, 1.205227, 31.504063}}],
    Line[{{6.814835, 1.205227, 31.504063},{6.269982, 0.989595, 30.745483}}],
    Line[{{6.269982, 0.989595, 30.745483},{5.759630, 0.837849, 29.990311}}],
    Line[{{5.759630, 0.837849, 29.990311},{5.286110, 0.740487, 29.243839}}],
    Line[{{5.286110, 0.740487, 29.243839},{4.850663, 0.688750, 28.509789}}],
    Line[{{4.850663, 0.688750, 28.509789},{4.453621, 0.674800, 27.790648}}],
    Line[{{4.453621, 0.674800, 27.790648},{4.094586, 0.691789, 27.087978}}],
    Line[{{4.094586, 0.691789, 27.087978},{3.772594, 0.733874, 26.402674}}],
    Line[{{3.772594, 0.733874, 26.402674},{3.486265, 0.796171, 25.735149}}],
    Line[{{3.486265, 0.796171, 25.735149},{3.233928, 0.874694, 25.085506}}],
    Line[{{3.233928, 0.874694, 25.085506},{3.013734, 0.966266, 24.453644}}],
    Line[{{3.013734, 0.966266, 24.453644},{2.823740, 1.068436, 23.839346}}],
    Line[{{2.823740, 1.068436, 23.839346},{2.661988, 1.179380, 23.242336}}],
    Line[{{2.661988, 1.179380, 23.242336},{2.526561, 1.297827, 22.662331}}],
    Line[{{2.526561, 1.297827, 22.662331},{2.415623, 1.422970, 22.099058}}],
    Line[{{2.415623, 1.422970, 22.099058},{2.327460, 1.554407, 21.552279}}],
    Line[{{2.327460, 1.554407, 21.552279},{2.260498, 1.692075, 21.021795}}],
    Line[{{2.260498, 1.692075, 21.021795},{2.213320, 1.836197, 20.507473}}],
    Line[{{2.213320, 1.836197, 20.507473},{2.184678, 1.987241, 20.009230}}],
    Line[{{2.184678, 1.987241, 20.009230},{2.173499, 2.145885, 19.527052}}],
    Line[{{2.173499, 2.145885, 19.527052},{2.178885, 2.312988, 19.061007}}],
    Line[{{2.178885, 2.312988, 19.061007},{2.200110, 2.489563, 18.611231}}],
    Line[{{2.200110, 2.489563, 18.611231},{2.236625, 2.676766, 18.177958}}],
    Line[{{2.236625, 2.676766, 18.177958},{2.288047, 2.875878, 17.761522}}],
    Line[{{2.288047, 2.875878, 17.761522},{2.354157, 3.088297, 17.362368}}],
    Line[{{2.354157, 3.088297, 17.362368},{2.434896, 3.315529, 16.981073}}],
    Line[{{2.434896, 3.315529, 16.981073},{2.530358, 3.559185, 16.618364}}],
    Line[{{2.530358, 3.559185, 16.618364},{2.640788, 3.820973, 16.275141}}],
    Line[{{2.640788, 3.820973, 16.275141},{2.766572, 4.102691, 15.952500}}],
    Line[{{2.766572, 4.102691, 15.952500},{2.908236, 4.406223, 15.651771}}],
    Line[{{2.908236, 4.406223, 15.651771},{3.066440, 4.733523, 15.374548}}],
    Line[{{3.066440, 4.733523, 15.374548},{3.241968, 5.086601, 15.122733}}],
    Line[{{3.241968, 5.086601, 15.122733},{3.435723, 5.467502, 14.898582}}],
    Line[{{3.435723, 5.467502, 14.898582},{3.648718, 5.878263, 14.704756}}],
    Line[{{3.648718, 5.878263, 14.704756},{3.882061, 6.320885, 14.544379}}],
    Line[{{3.882061, 6.320885, 14.544379},{4.136939, 6.797251, 14.421097}}],
    Line[{{4.136939, 6.797251, 14.421097},{4.414598, 7.309064, 14.339145}}],
    Line[{{4.414598, 7.309064, 14.339145},{4.716316, 7.857725, 14.303404}}],
    Line[{{4.716316, 7.857725, 14.303404},{5.043359, 8.444208, 14.319471}}],
    Line[{{5.043359, 8.444208, 14.319471},{5.396942, 9.068880, 14.393696}}],
    Line[{{5.396942, 9.068880, 14.393696},{5.778158, 9.731298, 14.533221}}],
    Line[{{5.778158, 9.731298, 14.533221},{6.187905, 10.429939, 14.745971}}],
    Line[{{6.187905, 10.429939, 14.745971},{6.626790, 11.161908, 15.040602}}],
    
    Line[{{6.626790, 11.161908, 15.040602},{7.095000, 11.922565, 15.426395}}],
    
    Line[{{7.095000, 11.922565, 15.426395},{7.592168, 12.705166, 15.913013}}],
    
    Line[{{7.592168, 12.705166, 15.913013},{8.117196, 13.500389, 16.510208}}],
    
    Line[{{8.117196, 13.500389, 16.510208},{8.668073, 14.296021, 17.227266}}],
    
    Line[{{8.668073, 14.296021, 17.227266},{9.241641, 15.076453, 18.072412}}],
    
    Line[{{9.241641, 15.076453, 18.072412},{9.833408, 15.822624, 19.051853}}],
    
    Line[{{9.833408, 15.822624, 19.051853},{
      10.437309, 16.511845, 20.168756}}],
    Line[{{10.437309, 16.511845, 20.168756},{
      11.045535, 17.118126, 21.421988}}],
    Line[{{11.045535, 17.118126, 21.421988},{
      11.648414, 17.612900, 22.804771}}],
    Line[{{11.648414, 17.612900, 22.804771},{
      12.234407, 17.966242, 24.303471}}],
    Line[{{12.234407, 17.966242, 24.303471},{
      12.790214, 18.148590, 25.896486}}],
    Line[{{12.790214, 18.148590, 25.896486},{
      13.301098, 18.133173, 27.553753}}],
    Line[{{13.301098, 18.133173, 27.553753},{
      13.751434, 17.898703, 29.237118}}],
    Line[{{13.751434, 17.898703, 29.237118},{
      14.125433, 17.432205, 30.901455}}],
    Line[{{14.125433, 17.432205, 30.901455},{
      14.408079, 16.731546, 32.497112}}],
    Line[{{14.408079, 16.731546, 32.497112},{
      14.586183, 15.807171, 33.973202}}],
    Line[{{14.586183, 15.807171, 33.973202},{
      14.649437, 14.682613, 35.281666}}],
    Line[{{14.649437, 14.682613, 35.281666},{
      14.591356, 13.393467, 36.381409}}],
    Line[{{14.591356, 13.393467, 36.381409},{
      14.409946, 11.984814, 37.241936}}],
    Line[{{14.409946, 11.984814, 37.241936},{
      14.108003, 10.507446, 37.845791}}],
    Line[{{14.108003, 10.507446, 37.845791},{
      13.692983, 9.013429, 38.189495}}],
    Line[{{13.692983, 9.013429, 38.189495},{13.176475, 7.551835, 38.282753}}],
    
    Line[{{13.176475, 7.551835, 38.282753},{12.573338, 6.165019, 38.146366}}],
    
    Line[{{12.573338, 6.165019, 38.146366},{11.900618, 4.886185, 37.809113}}],
    
    Line[{{11.900618, 4.886185, 37.809113},{11.176406, 3.738274, 37.304295}}],
    
    Line[{{11.176406, 3.738274, 37.304295},{10.418759, 2.734095, 36.666504}}],
    
    Line[{{10.418759, 2.734095, 36.666504},{9.644788, 1.877429, 35.928951}}],
    Line[{{9.644788, 1.877429, 35.928951},{8.869963, 1.164705, 35.121590}}],
    Line[{{8.869963, 1.164705, 35.121590},{8.107665, 0.586932, 34.269997}}],
    Line[{{8.107665, 0.586932, 34.269997},{7.368960, 0.131558, 33.395004}}],
    Line[{{7.368960, 0.131558, 33.395004},{6.662560, -0.215899, 32.512806}}],
    Line[{{6.662560, -0.215899, 32.512806},{5.994929, -0.470558, 31.635412}}],
    
    Line[{{5.994929, -0.470558, 31.635412},{5.370490, -0.647217, 30.771290}}],
    
    Line[{{5.370490, -0.647217, 30.771290},{4.791875, -0.759714, 29.926046}}],
    
    Line[{{4.791875, -0.759714, 29.926046},{4.260215, -0.820548, 29.103085}}],
    
    Line[{{4.260215, -0.820548, 29.103085},{3.775413, -0.840697, 28.304178}}],
    
    Line[{{3.775413, -0.840697, 28.304178},{3.336413, -0.829586, 27.529951}}],
    
    Line[{{3.336413, -0.829586, 27.529951},{2.941438, -0.795135, 26.780260}}],
    
    Line[{{2.941438, -0.795135, 26.780260},{2.588191, -0.743880, 26.054480}}],
    
    Line[{{2.588191, -0.743880, 26.054480},{2.274036, -0.681111, 25.351709}}],
    
    Line[{{2.274036, -0.681111, 25.351709},{1.996137, -0.611033, 24.670919}}],
    
    Line[{{1.996137, -0.611033, 24.670919},{1.751573, -0.536919, 24.011047}}],
    
    Line[{{1.751573, -0.536919, 24.011047},{1.537430, -0.461251, 23.371056}}],
    
    Line[{{1.537430, -0.461251, 23.371056},{1.350868, -0.385857, 22.749969}}],
    
    Line[{{1.350868, -0.385857, 22.749969},{1.189169, -0.312028, 22.146891}}],
    
    Line[{{1.189169, -0.312028, 22.146891},{1.049774, -0.240617, 21.561003}}],
    
    Line[{{1.049774, -0.240617, 21.561003},{0.930303, -0.172130, 20.991570}}],
    
    Line[{{0.930303, -0.172130, 20.991570},{0.828569, -0.106800, 20.437927}}],
    
    Line[{{0.828569, -0.106800, 20.437927},{0.742580, -0.044644, 19.899479}}],
    
    Line[{{0.742580, -0.044644, 19.899479},{0.670543, 0.014481, 19.375683}}],
    Line[{{0.670543, 0.014481, 19.375683},{0.610851, 0.070843, 18.866043}}],
    Line[{{0.610851, 0.070843, 18.866043},{0.562086, 0.124796, 18.370113}}],
    Line[{{0.562086, 0.124796, 18.370113},{0.522996, 0.176763, 17.887476}}],
    Line[{{0.522996, 0.176763, 17.887476},{0.492495, 0.227209, 17.417746}}],
    Line[{{0.492495, 0.227209, 17.417746},{0.469645, 0.276633, 16.960560}}],
    Line[{{0.469645, 0.276633, 16.960560},{0.453644, 0.325554, 16.515581}}],
    Line[{{0.453644, 0.325554, 16.515581},{0.443819, 0.374509, 16.082491}}],
    Line[{{0.443819, 0.374509, 16.082491},{0.439613, 0.424042, 15.660989}}],
    Line[{{0.439613, 0.424042, 15.660989},{0.440571, 0.474713, 15.250792}}],
    Line[{{0.440571, 0.474713, 15.250792},{0.446338, 0.527088, 14.851628}}],
    Line[{{0.446338, 0.527088, 14.851628},{0.456647, 0.581750, 14.463249}}],
    Line[{{0.456647, 0.581750, 14.463249},{0.471312, 0.639297, 14.085416}}],
    Line[{{0.471312, 0.639297, 14.085416},{0.490223, 0.700349, 13.717908}}],
    Line[{{0.490223, 0.700349, 13.717908},{0.513340, 0.765552, 13.360523}}],
    Line[{{0.513340, 0.765552, 13.360523},{0.540690, 0.835585, 13.013078}}],
    Line[{{0.540690, 0.835585, 13.013078},{0.572366, 0.911167, 12.675409}}],
    Line[{{0.572366, 0.911167, 12.675409},{0.608519, 0.993067, 12.347378}}],
    Line[{{0.608519, 0.993067, 12.347378},{0.649364, 1.082106, 12.028872}}],
    Line[{{0.649364, 1.082106, 12.028872},{0.695178, 1.179173, 11.719808}}],
    Line[{{0.695178, 1.179173, 11.719808},{0.746296, 1.285230, 11.420139}}],
    Line[{{0.746296, 1.285230, 11.420139},{0.803120, 1.401324, 11.129864}}],
    Line[{{0.803120, 1.401324, 11.129864},{0.866116, 1.528601, 10.849022}}],
    Line[{{0.866116, 1.528601, 10.849022},{0.935821, 1.668310, 10.577717}}],
    Line[{{0.935821, 1.668310, 10.577717},{1.012844, 1.821825, 10.316118}}],
    Line[{{1.012844, 1.821825, 10.316118},{1.097876, 1.990652, 10.064476}}],
    Line[{{1.097876, 1.990652, 10.064476},{1.191690, 2.176445, 9.823141}}],
    Line[{{1.191690, 2.176445, 9.823141},{1.295151, 2.381020, 9.592579}}],
    Line[{{1.295151, 2.381020, 9.592579},{1.409224, 2.606371, 9.373397}}],
    Line[{{1.409224, 2.606371, 9.373397},{1.534980, 2.854682, 9.166372}}],
    Line[{{1.534980, 2.854682, 9.166372},{1.673607, 3.128347, 8.972486}}],
    Line[{{1.673607, 3.128347, 8.972486},{1.826416, 3.429971, 8.792972}}],
    Line[{{1.826416, 3.429971, 8.792972},{1.994856, 3.762395, 8.629351}}],
    Line[{{1.994856, 3.762395, 8.629351},{2.180515, 4.128688, 8.483514}}],
    Line[{{2.180515, 4.128688, 8.483514},{2.385136, 4.532156, 8.357778}}],
    Line[{{2.385136, 4.532156, 8.357778},{2.610622, 4.976328, 8.254982}}],
    Line[{{2.610622, 4.976328, 8.254982},{2.859040, 5.464929, 8.178592}}],
    Line[{{2.859040, 5.464929, 8.178592},{3.132624, 6.001851, 8.132808}}],
    Line[{{3.132624, 6.001851, 8.132808},{3.433766, 6.591060, 8.122727}}],
    Line[{{3.433766, 6.591060, 8.122727},{3.765016, 7.236530, 8.154478}}],
    Line[{{3.765016, 7.236530, 8.154478},{4.129046, 7.942055, 8.235420}}],
    Line[{{4.129046, 7.942055, 8.235420},{4.528621, 8.711056, 8.374316}}],
    Line[{{4.528621, 8.711056, 8.374316},{4.966545, 9.546309, 8.581553}}],
    Line[{{4.966545, 9.546309, 8.581553},{5.445560, 10.449499, 8.869301}}],
    Line[{{5.445560, 10.449499, 8.869301},{5.968245, 11.420768, 9.251699}}],
    Line[{{5.968245, 11.420768, 9.251699},{6.536844, 12.458024, 9.744933}}],
    Line[{{6.536844, 12.458024, 9.744933},{7.153041, 13.556110, 10.367178}}],
    Line[{{7.153041, 13.556110, 10.367178},{7.817691, 14.705841, 11.138388}}],
    
    Line[{{7.817691, 14.705841, 11.138388},{8.530449, 15.892820, 12.079795}}],
    
    Line[{{8.530449, 15.892820, 12.079795},{9.289328, 17.096210, 13.212882}}],
    
    Line[{{9.289328, 17.096210, 13.212882},{
      10.090186, 18.287487, 14.557981}}],
    Line[{{10.090186, 18.287487, 14.557981},{
      10.926145, 19.429411, 16.132069}}],
    Line[{{10.926145, 19.429411, 16.132069},{
      11.786995, 20.475521, 17.945925}}],
    Line[{{11.786995, 20.475521, 17.945925},{
      12.658638, 21.370481, 20.000547}}],
    Line[{{12.658638, 21.370481, 20.000547},{
      13.522683, 22.051851, 22.283136}}],
    Line[{{13.522683, 22.051851, 22.283136},{
      14.356344, 22.453646, 24.763157}}],
    Line[{{14.356344, 22.453646, 24.763157},{
      15.132761, 22.511971, 27.389269}}],
    Line[{{15.132761, 22.511971, 27.389269},{
      15.821964, 22.172575, 30.088387}}],
    Line[{{15.821964, 22.172575, 30.088387},{
      16.392481, 21.399477, 32.767582}}],
    Line[{{16.392481, 21.399477, 32.767582},{
      16.813639, 20.183352, 35.320080}}],
    Line[{{16.813639, 20.183352, 35.320080},{
      17.058344, 18.547510, 37.634960}}],
    Line[{{17.058344, 18.547510, 37.634960},{
      17.105968, 16.549641, 39.609550}}],
    Line[{{17.105968, 16.549641, 39.609550},{
      16.944870, 14.277929, 41.162140}}],
    Line[{{16.944870, 14.277929, 41.162140},{
      16.574032, 11.841754, 42.242352}}],
    Line[{{16.574032, 11.841754, 42.242352},{
      16.003431, 9.358663, 42.836315}}],
    Line[{{16.003431, 9.358663, 42.836315},{15.253127, 6.940455, 42.966084}}],
    
    Line[{{15.253127, 6.940455, 42.966084},{14.351128, 4.681343, 42.683262}}],
    
    Line[{{14.351128, 4.681343, 42.683262},{13.330568, 2.650369, 42.059124}}],
    
    Line[{{13.330568, 2.650369, 42.059124},{12.226664, 0.888830, 41.173626}}],
    
    Line[{{12.226664, 0.888830, 41.173626},{
      11.073918, -0.587916, 40.105656}}],
    Line[{{11.073918, -0.587916, 40.105656},{
      9.903950, -1.785703, 38.925922}}],
    Line[{{9.903950, -1.785703, 38.925922},{8.744024, -2.725510, 37.692894}}],
    
    Line[{{8.744024, -2.725510, 37.692894},{7.616333, -3.437498, 36.451466}}],
    
    Line[{{7.616333, -3.437498, 36.451466},{6.537844, -3.955976, 35.233604}}],
    
    Line[{{6.537844, -3.955976, 35.233604},{5.520604, -4.315661, 34.060146}}],
    
    Line[{{5.520604, -4.315661, 34.060146},{4.572293, -4.549208, 32.943096}}],
    
    Line[{{4.572293, -4.549208, 32.943096},{3.696913, -4.685822, 31.887896}}],
    
    Line[{{3.696913, -4.685822, 31.887896},{2.895497, -4.750677, 30.895466}}],
    
    Line[{{2.895497, -4.750677, 30.895466},{2.166784, -4.764862, 29.963823}}],
    
    Line[{{2.166784, -4.764862, 29.963823},{1.507812, -4.745644, 29.089333}}],
    
    Line[{{1.507812, -4.745644, 29.089333},{0.914427, -4.706903, 28.267578}}],
    
    Line[{{0.914427, -4.706903, 28.267578},{0.381693, -4.659614, 27.493967}}],
    
    Line[{{
      0.381693, -4.659614, 27.493967},{-0.095781, -4.612331, 26.764101}}],
    Line[{{-0.095781, -4.612331, 26.764101},{-0.523584, -4.571629, 
        26.073994}}],
    Line[{{-0.523584, -4.571629, 26.073994},{-0.907325, -4.542492, 
        25.420160}}],
    Line[{{-0.907325, -4.542492, 25.420160},{-1.252487, -4.528653, 
        24.799669}}],
    Line[{{-1.252487, -4.528653, 24.799669},{-1.564337, -4.532866, 
        24.210119}}],
    Line[{{-1.564337, -4.532866, 24.210119},{-1.847865, -4.557137, 
        23.649612}}],
    Line[{{-1.847865, -4.557137, 23.649612},{-2.107750, -4.602914, 
        23.116709}}],
    Line[{{-2.107750, -4.602914, 23.116709},{-2.348342, -4.671236, 
        22.610374}}],
    Line[{{-2.348342, -4.671236, 22.610374},{-2.573661, -4.762850, 
        22.129953}}],
    Line[{{-2.573661, -4.762850, 22.129953},{-2.787405, -4.878308, 
        21.675121}}],
    Line[{{-2.787405, -4.878308, 21.675121},{-2.992965, -5.018036, 
        21.245859}}],
    Line[{{-2.992965, -5.018036, 21.245859},{-3.193449, -5.182385, 
        20.842438}}],
    Line[{{-3.193449, -5.182385, 20.842438},{-3.391698, -5.371671, 
        20.465405}}],
    Line[{{-3.391698, -5.371671, 20.465405},{-3.590312, -5.586191, 
        20.115576}}],
    Line[{{-3.590312, -5.586191, 20.115576},{-3.791672, -5.826239, 
        19.794039}}],
    Line[{{-3.791672, -5.826239, 19.794039},{-3.997961, -6.092093, 
        19.502159}}],
    Line[{{-3.997961, -6.092093, 19.502159},{-4.211178, -6.384010, 
        19.241589}}],
    Line[{{-4.211178, -6.384010, 19.241589},{-4.433154, -6.702191, 
        19.014278}}],
    Line[{{-4.433154, -6.702191, 19.014278},{-4.665562, -7.046750, 
        18.822498}}],
    Line[{{-4.665562, -7.046750, 18.822498},{-4.909917, -7.417648, 
        18.668839}}],
    Line[{{-4.909917, -7.417648, 18.668839},{-5.167582, -7.814651, 
        18.556234}}],
    Line[{{-5.167582, -7.814651, 18.556234},{-5.439752, -8.237231, 
        18.487961}}],
    Line[{{-5.439752, -8.237231, 18.487961},{-5.727437, -8.684475, 
        18.467628}}],
    Line[{{-5.727437, -8.684475, 18.467628},{-6.031447, -9.154988, 
        18.499174}}],
    Line[{{-6.031447, -9.154988, 18.499174},{-6.352352, -9.646756, 
        18.586819}}],
    Line[{{-6.352352, -9.646756, 18.586819},{-6.690435, -10.157003, 
        18.734993}}],
    Line[{{-6.690435, -10.157003, 18.734993},{-7.045654, -10.682063, 
        18.948269}}],
    Line[{{-7.045654, -10.682063, 18.948269},{-7.417568, -11.217207, 
        19.231205}}],
    Line[{{-7.417568, -11.217207, 19.231205},{-7.805268, -11.756498, 
        19.588142}}],
    Line[{{-7.805268, -11.756498, 19.588142},{-8.207308, -12.292667, 
        20.023020}}],
    Line[{{-8.207308, -12.292667, 20.023020},{-8.621617, -12.816998, 
        20.539032}}],
    Line[{{-8.621617, -12.816998, 20.539032},{-9.045419, -13.319315, 
        21.138237}}],
    Line[{{-9.045419, -13.319315, 21.138237},{-9.475163, -13.787972, 
        21.821236}}],
    Line[{{-9.475163, -13.787972, 21.821236},{-9.906466, -14.210058, 
        22.586597}}],
    Line[{{-9.906466, -14.210058, 22.586597},{-10.334077, -14.571650, 
        23.430462}}],
    Line[{{-10.334077, -14.571650, 23.430462},{-10.751895, -14.858283, 
        24.346064}}],
    Line[{{-10.751895, -14.858283, 24.346064},{-11.153022, -15.055577, 
        25.323385}}],
    Line[{{-11.153022, -15.055577, 25.323385},{-11.529875, -15.150003, 
        26.348921}}],
    Line[{{-11.529875, -15.150003, 26.348921},{-11.874387, -15.129829, 
        27.405678}}],
    Line[{{-11.874387, -15.129829, 27.405678},{-12.178270, -14.986127, 
        28.473461}}],
    Line[{{-12.178270, -14.986127, 28.473461},{-12.433353, -14.713738, 
        29.529482}}],
    Line[{{-12.433353, -14.713738, 29.529482},{-12.631968, -14.312080, 
        30.549301}}],
    Line[{{-12.631968, -14.312080, 30.549301},{-12.767361, -13.785749, 
        31.507971}}],
    Line[{{-12.767361, -13.785749, 31.507971},{-12.834124, -13.144664, 
        32.381546}}],
    Line[{{-12.834124, -13.144664, 32.381546},{-12.828554, -12.403812, 
        33.148491}}],
    Line[{{-12.828554, -12.403812, 33.148491},{-12.748946, -11.582514, 
        33.791046}}],
    Line[{{-12.748946, -11.582514, 33.791046},{-12.595758, -10.703274, 
        34.296280}}],
    Line[{{-12.595758, -10.703274, 34.296280},{-12.371647, -9.790352, 
        34.656769}}],
    Line[{{-12.371647, -9.790352, 34.656769},{-12.081343, -8.868211, 
        34.870750}}],
    Line[{{-12.081343, -8.868211, 34.870750},{-11.731407, -7.960030, 
        34.941830}}],
    Line[{{-11.731407, -7.960030, 34.941830},{-11.329866, -7.086448, 
        34.878239}}],
    Line[{{-11.329866, -7.086448, 34.878239},{-10.885786, -6.264634, 
        34.691833}}],
    Line[{{-10.885786, -6.264634, 34.691833},{-10.408811, -5.507791, 
        34.396935}}],
    Line[{{-10.408811, -5.507791, 34.396935},{-9.908727, -4.824995, 
        34.009178}}],
    Line[{{-9.908727, -4.824995, 34.009178},{-9.395060, -4.221399, 
        33.544483}}],
    Line[{{-9.395060, -4.221399, 33.544483},{-8.876745, -3.698674, 
        33.018204}}],
    Line[{{-8.876745, -3.698674, 33.018204},{-8.361884, -3.255601, 
        32.444534}}],
    Line[{{-8.361884, -3.255601, 32.444534},{-7.857576, -2.888732, 
        31.836098}}],
    Line[{{-7.857576, -2.888732, 31.836098},{-7.369836, -2.593031, 
        31.203787}}],
    Line[{{-7.369836, -2.593031, 31.203787},{-6.903574, -2.362468, 
        30.556726}}],
    Line[{{-6.903574, -2.362468, 30.556726},{-6.462633, -2.190515, 
        29.902376}}],
    Line[{{-6.462633, -2.190515, 29.902376},{-6.049859, -2.070551, 
        29.246685}}],
    Line[{{-6.049859, -2.070551, 29.246685},{-5.667206, -1.996159, 
        28.594307}}],
    Line[{{-5.667206, -1.996159, 28.594307},{-5.315850, -1.961342, 
        27.948807}}],
    Line[{{-5.315850, -1.961342, 27.948807},{-4.996313, -1.960659, 
        27.312868}}],
    Line[{{-4.996313, -1.960659, 27.312868},{-4.708575, -1.989300, 
        26.688480}}],
    Line[{{-4.708575, -1.989300, 26.688480},{-4.452196, -2.043117, 
        26.077106}}],
    Line[{{-4.452196, -2.043117, 26.077106},{-4.226413, -2.118617, 
        25.479809}}],
    Line[{{-4.226413, -2.118617, 25.479809},{-4.030234, -2.212936, 
        24.897371}}],
    Line[{{-4.030234, -2.212936, 24.897371},{-3.862519, -2.323800, 
        24.330378}}],
    Line[{{-3.862519, -2.323800, 24.330378},{-3.722045, -2.449469, 
        23.779293}}],
    Line[{{-3.722045, -2.449469, 23.779293},{-3.607563, -2.588687, 
        23.244505}}],
    Line[{{-3.607563, -2.588687, 23.244505},{-3.517847, -2.740630, 
        22.726377}}],
    Line[{{-3.517847, -2.740630, 22.726377},{-3.451727, -2.904852, 
        22.225279}}],
    Line[{{-3.451727, -2.904852, 22.225279},{-3.408117, -3.081235, 
        21.741608}}],
    Line[{{-3.408117, -3.081235, 21.741608},{-3.386038, -3.269951, 
        21.275818}}],
    Line[{{-3.386038, -3.269951, 21.275818},{-3.384633, -3.471419, 
        20.828442}}],
    Line[{{-3.384633, -3.471419, 20.828442},{-3.403178, -3.686269, 
        20.400095}}],
    Line[{{-3.403178, -3.686269, 20.400095},{-3.441085, -3.915312, 
        19.991518}}],
    Line[{{-3.441085, -3.915312, 19.991518},{-3.497908, -4.159510, 
        19.603573}}],
    Line[{{-3.497908, -4.159510, 19.603573},{-3.573340, -4.419950, 
        19.237278}}],
    Line[{{-3.573340, -4.419950, 19.237278},{-3.667213, -4.697817, 
        18.893822}}],
    Line[{{-3.667213, -4.697817, 18.893822},{-3.779491, -4.994365, 
        18.574596}}],
    Line[{{-3.779491, -4.994365, 18.574596},{-3.910262, -5.310892, 
        18.281218}}],
    Line[{{-3.910262, -5.310892, 18.281218},{-4.059731, -5.648705, 
        18.015551}}],
    Line[{{-4.059731, -5.648705, 18.015551},{-4.228207, -6.009087, 
        17.779751}}],
    Line[{{-4.228207, -6.009087, 17.779751},{-4.416088, -6.393250, 
        17.576286}}],
    Line[{{-4.416088, -6.393250, 17.576286},{-4.623843, -6.802272, 
        17.407976}}],
    Line[{{-4.623843, -6.802272, 17.407976},{-4.851995, -7.237061, 
        17.278015}}],
    Line[{{-4.851995, -7.237061, 17.278015},{-5.101083, -7.698231, 
        17.190014}}],
    Line[{{-5.101083, -7.698231, 17.190014},{-5.371645, -8.186049, 
        17.148005}}],
    Line[{{-5.371645, -8.186049, 17.148005},{-5.664168, -8.700301, 
        17.156466}}],
    Line[{{-5.664168, -8.700301, 17.156466},{-5.979035, -9.240134, 
        17.220299}}],
    Line[{{-5.979035, -9.240134, 17.220299},{-6.316494, -9.803960, 
        17.344837}}],
    Line[{{-6.316494, -9.803960, 17.344837},{-6.676554, -10.389196, 
        17.535732}}],
    Line[{{-6.676554, -10.389196, 17.535732},{-7.058935, -10.992137, 
        17.798897}}],
    Line[{{-7.058935, -10.992137, 17.798897},{-7.462968, -11.607708, 
        18.140354}}],
    Line[{{-7.462968, -11.607708, 18.140354},{-7.887481, -12.229252, 
        18.565945}}],
    Line[{{-7.887481, -12.229252, 18.565945},{-8.330702, -12.848349, 
        19.081104}}],
    Line[{{-8.330702, -12.848349, 19.081104},{-8.790133, -13.454644, 
        19.690445}}],
    Line[{{-8.790133, -13.454644, 19.690445},{-9.262430, -14.035760, 
        20.397255}}],
    Line[{{-9.262430, -14.035760, 20.397255},{-9.743294, -14.577349, 
        21.202923}}],
    Line[{{-9.743294, -14.577349, 21.202923},{-10.227375, -15.063188, 
        22.106352}}],
    Line[{{-10.227375, -15.063188, 22.106352},{-10.708219, -15.475655, 
        23.103203}}],
    Line[{{-10.708219, -15.475655, 23.103203},{-11.178260, -15.796269, 
        24.185303}}],
    Line[{{-11.178260, -15.796269, 24.185303},{-11.628888, -16.006601, 
        25.340092}}],
    Line[{{-11.628888, -16.006601, 25.340092},{-12.050605, -16.089384, 
        26.550312}}],
    Line[{{-12.050605, -16.089384, 26.550312},{-12.433284, -16.029854, 
        27.794001}}],
    Line[{{-12.433284, -16.029854, 27.794001},{-12.766535, -15.817174, 
        29.044933}}],
    Line[{{-12.766535, -15.817174, 29.044933},{-13.040172, -15.445810, 
        30.273535}}],
    Line[{{-13.040172, -15.445810, 30.273535},{-13.244753, -14.916665, 
        31.448288}}],
    Line[{{-13.244753, -14.916665, 31.448288},{-13.372166, -14.237799, 
        32.537537}}],
    Line[{{-13.372166, -14.237799, 32.537537},{-13.416187, -13.424459, 
        33.511608}}],
    Line[{{-13.416187, -13.424459, 33.511608},{-13.372966, -12.498492, 
        34.344837}}],
    Line[{{-13.372966, -12.498492, 34.344837},{-13.241364, -11.487044, 
        35.017365}}],
    Line[{{-13.241364, -11.487044, 35.017365},{-13.023119, -10.420688, 
        35.516441}}],
    Line[{{-13.023119, -10.420688, 35.516441},{-12.722789, -9.331249, 
        35.837017}}],
    Line[{{-12.722789, -9.331249, 35.837017},{-12.347501, -8.249595, 
        35.981571}}],
    Line[{{-12.347501, -8.249595, 35.981571},{-11.906509, -7.203666, 
        35.959286}}],
    Line[{{-11.906509, -7.203666, 35.959286},{-11.410646, -6.216968, 
        35.784698}}],
    Line[{{-11.410646, -6.216968, 35.784698},{-10.871695, -5.307687, 
        35.476040}}],
    Line[{{-10.871695, -5.307687, 35.476040},{-10.301770, -4.488334, 
        35.053570}}],
    Line[{{-10.301770, -4.488334, 35.053570},{-9.712766, -3.765980, 
        34.538040}}],
    Line[{{-9.712766, -3.765980, 34.538040},{-9.115870, -3.142846, 
        33.949425}}],
    Line[{{-9.115870, -3.142846, 33.949425},{-8.521218, -2.617163, 
        33.306034}}],
    Line[{{-8.521218, -2.617163, 33.306034},{-7.937660, -2.184111, 
        32.623959}}],
    Line[{{-7.937660, -2.184111, 32.623959},{-7.372633, -1.836759, 
        31.916809}}],
    Line[{{-7.372633, -1.836759, 31.916809},{-6.832139, -1.566896, 
        31.195736}}],
    Line[{{-6.832139, -1.566896, 31.195736},{-6.320796, -1.365733, 
        30.469584}}],
    Line[{{-6.320796, -1.365733, 30.469584},{-5.841939, -1.224448, 
        29.745157}}],
    Line[{{-5.841939, -1.224448, 29.745157},{-5.397761, -1.134591, 
        29.027533}}],
    Line[{{-5.397761, -1.134591, 29.027533},{-4.989474, -1.088333, 
        28.320383}}],
    Line[{{-4.989474, -1.088333, 28.320383},{-4.617463, -1.078647, 
        27.626270}}],
    Line[{{-4.617463, -1.078647, 27.626270},{-4.281452, -1.099371, 
        26.946909}}],
    Line[{{-4.281452, -1.099371, 26.946909},{-3.980646, -1.145230, 
        26.283382}}],
    Line[{{-3.980646, -1.145230, 26.283382},{-3.713867, -1.211810, 
        25.636324}}],
    Line[{{-3.713867, -1.211810, 25.636324},{-3.479668, -1.295502, 
        25.006062}}],
    Line[{{-3.479668, -1.295502, 25.006062},{-3.276432, -1.393435, 
        24.392717}}],
    Line[{{-3.276432, -1.393435, 24.392717},{-3.102456, -1.503401, 
        23.796293}}],
    Line[{{-3.102456, -1.503401, 23.796293},{-2.956017, -1.623775, 
        23.216722}}],
    Line[{{-2.956017, -1.623775, 23.216722},{-2.835428, -1.753447, 
        22.653923}}],
    Line[{{-2.835428, -1.753447, 22.653923},{-2.739079, -1.891746, 
        22.107817}}],
    Line[{{-2.739079, -1.891746, 22.107817},{-2.665465, -2.038386, 
        21.578356}}],
    Line[{{-2.665465, -2.038386, 21.578356},{-2.613217, -2.193405, 
        21.065540}}],
    Line[{{-2.613217, -2.193405, 21.065540},{-2.581112, -2.357124, 
        20.569426}}],
    Line[{{-2.581112, -2.357124, 20.569426},{-2.568088, -2.530102, 
        20.090141}}],
    Line[{{-2.568088, -2.530102, 20.090141},{-2.573243, -2.713109, 
        19.627892}}],
    Line[{{-2.573243, -2.713109, 19.627892},{-2.595848, -2.907091, 
        19.182976}}],
    Line[{{-2.595848, -2.907091, 19.182976},{-2.635338, -3.113153, 
        18.755793}}],
    Line[{{-2.635338, -3.113153, 18.755793},{-2.691315, -3.332538, 
        18.346861}}],
    Line[{{-2.691315, -3.332538, 18.346861},{-2.763544, -3.566615, 
        17.956833}}],
    Line[{{-2.763544, -3.566615, 17.956833},{-2.851945, -3.816858, 
        17.586514}}],
    Line[{{-2.851945, -3.816858, 17.586514},{-2.956595, -4.084842, 
        17.236881}}],
    Line[{{-2.956595, -4.084842, 17.236881},{-3.077715, -4.372225, 
        16.909119}}],
    Line[{{-3.077715, -4.372225, 16.909119},{-3.215666, -4.680733, 
        16.604641}}],
    Line[{{-3.215666, -4.680733, 16.604641},{-3.370944, -5.012146, 
        16.325121}}],
    Line[{{-3.370944, -5.012146, 16.325121},{-3.544165, -5.368269, 
        16.072542}}],
    Line[{{-3.544165, -5.368269, 16.072542},{-3.736061, -5.750906, 
        15.849232}}],
    Line[{{-3.736061, -5.750906, 15.849232},{-3.947466, -6.161825, 
        15.657901}}],
    Line[{{-3.947466, -6.161825, 15.657901},{-4.179293, -6.602684, 
        15.501713}}],
    Line[{{-4.179293, -6.602684, 15.501713},{-4.432526, -7.075002, 
        15.384312}}],
    Line[{{-4.432526, -7.075002, 15.384312},{-4.708183, -7.580034, 
        15.309892}}],
    Line[{{-4.708183, -7.580034, 15.309892},{-5.007288, -8.118669, 
        15.283232}}],
    Line[{{-5.007288, -8.118669, 15.283232},{-5.330837, -8.691328, 
        15.309746}}],
    Line[{{-5.330837, -8.691328, 15.309746},{-5.679729, -9.297725, 
        15.395490}}],
    Line[{{-5.679729, -9.297725, 15.395490},{-6.054721, -9.936742, 
        15.547186}}],
    Line[{{-6.054721, -9.936742, 15.547186},{-6.456334, -10.606120, 
        15.772162}}],
    Line[{{-6.456334, -10.606120, 15.772162},{-6.884758, -11.302217, 
        16.078281}}],
    Line[{{-6.884758, -11.302217, 16.078281},{-7.339738, -12.019676, 
        16.473757}}],
    Line[{{-7.339738, -12.019676, 16.473757},{-7.820444, -12.751121, 
        16.966942}}],
    Line[{{-7.820444, -12.751121, 16.966942},{-8.325306, -13.486791, 
        17.565945}}],
    Line[{{-8.325306, -13.486791, 17.565945},{-8.851848, -14.214252, 
        18.278111}}],
    Line[{{-8.851848, -14.214252, 18.278111},{-9.396506, -14.918188, 
        19.109360}}],
    Line[{{-9.396506, -14.918188, 19.109360},{-9.954458, -15.580277, 
        20.063438}}],
    Line[{{-9.954458, -15.580277, 20.063438},{-10.519449, -16.179310, 
        21.140905}}],
    Line[{{-10.519449, -16.179310, 21.140905},{-11.083683, -16.691679, 
        22.338057}}],
    Line[{{-11.083683, -16.691679, 22.338057},{-11.637770, -17.092098, 
        23.645927}}],
    Line[{{-11.637770, -17.092098, 23.645927},{-12.170775, -17.354874, 
        25.049322}}],
    Line[{{-12.170775, -17.354874, 25.049322},{-12.670405, -17.455551, 
        26.526188}}],
    Line[{{-12.670405, -17.455551, 26.526188},{-13.123351, -17.372976, 
        28.047478}}],
    Line[{{-13.123351, -17.372976, 28.047478},{-13.515805, -17.091558, 
        29.577700}}],
    Line[{{-13.515805, -17.091558, 29.577700},{-13.834153, -16.603479, 
        31.076296}}],
    Line[{{-13.834153, -16.603479, 31.076296},{-14.065784, -15.910525, 
        32.499863}}],
    Line[{{-14.065784, -15.910525, 32.499863},{-14.199966, -15.025174, 
        33.805046}}],
    Line[{{-14.199966, -15.025174, 33.805046},{-14.228706, -13.970593, 
        34.951900}}],
    Line[{{-14.228706, -13.970593, 34.951900},{-14.147445, -12.779456, 
        35.907116}}],
    Line[{{-14.147445, -12.779456, 35.907116},{-13.955540, -11.491608, 
        36.646721}}],
    Line[{{-13.955540, -11.491608, 36.646721},{-13.656419, -10.150882, 
        37.157791}}],
    Line[{{-13.656419, -10.150882, 37.157791},{-13.257405, -8.801533, 
        37.438942}}],
    Line[{{-13.257405, -8.801533, 37.438942},{-12.769218, -7.484821, 
        37.499516}}],
    Line[{{-12.769218, -7.484821, 37.499516},{-12.205223, -6.236197, 
        37.357773}}],
    Line[{{-12.205223, -6.236197, 37.357773},{-11.580523, -5.083465, 
        37.038334}}],
    Line[{{-11.580523, -5.083465, 37.038334},{-10.911026, -4.045955, 
        36.569458}}],
    Line[{{-10.911026, -4.045955, 36.569458},{-10.212554, -3.134665, 
        35.980492}}],
    Line[{{-10.212554, -3.134665, 35.980492},{-9.500104, -2.353130, 
        35.299713}}],
    Line[{{-9.500104, -2.353130, 35.299713},{-8.787272, -1.698769, 
        34.552830}}],
    Line[{{-8.787272, -1.698769, 34.552830},{-8.085882, -1.164402, 
        33.762070}}],
    Line[{{-8.085882, -1.164402, 33.762070},{-7.405786, -0.739756, 
        32.945805}}],
    Line[{{-7.405786, -0.739756, 32.945805},{-6.754827, -0.412787, 
        32.118614}}],
    Line[{{-6.754827, -0.412787, 32.118614},{-6.138913, -0.170764, 
        31.291574}}],
    Line[{{-6.138913, -0.170764, 31.291574},{-5.562181, -0.001081, 
        30.472776}}],
    Line[{{-5.562181, -0.001081, 30.472776},{-5.027202, 0.108180, 
        29.667831}}],
    Line[{{-5.027202, 0.108180, 29.667831},{-4.535217, 0.167889, 28.880404}}],
    
    Line[{{-4.535217, 0.167889, 28.880404},{-4.086376, 0.187685, 28.112686}}],
    
    Line[{{-4.086376, 0.187685, 28.112686},{-3.679956, 0.175911, 27.365799}}],
    
    Line[{{-3.679956, 0.175911, 27.365799},{-3.314572, 0.139635, 26.640108}}],
    
    Line[{{-3.314572, 0.139635, 26.640108},{-2.988359, 0.084726, 25.935488}}],
    
    Line[{{-2.988359, 0.084726, 25.935488},{-2.699121, 0.015960, 25.251495}}],
    
    Line[{{-2.699121, 0.015960, 25.251495},{-2.444469, -0.062860, 
        24.587521}}],
    Line[{{-2.444469, -0.062860, 24.587521},{-2.221917, -0.148777, 
        23.942865}}],
    Line[{{-2.221917, -0.148777, 23.942865},{-2.028973, -0.239562, 
        23.316813}}],
    Line[{{-2.028973, -0.239562, 23.316813},{-1.863200, -0.333601, 
        22.708672}}],
    Line[{{-1.863200, -0.333601, 22.708672},{-1.722265, -0.429797, 
        22.117785}}],
    Line[{{-1.722265, -0.429797, 22.117785},{-1.603975, -0.527480, 
        21.543552}}],
    Line[{{-1.603975, -0.527480, 21.543552},{-1.506296, -0.626333, 
        20.985432}}],
    Line[{{-1.506296, -0.626333, 20.985432},{-1.427376, -0.726327, 
        20.442936}}],
    Line[{{-1.427376, -0.726327, 20.442936},{-1.365547, -0.827666, 
        19.915634}}],
    Line[{{-1.365547, -0.827666, 19.915634},{-1.319327, -0.930746, 
        19.403151}}],
    Line[{{-1.319327, -0.930746, 19.403151},{-1.287423, -1.036120, 
        18.905157}}],
    Line[{{-1.287423, -1.036120, 18.905157},{-1.268721, -1.144469, 
        18.421371}}],
    Line[{{-1.268721, -1.144469, 18.421371},{-1.262287, -1.256584, 
        17.951559}}],
    Line[{{-1.262287, -1.256584, 17.951559},{-1.267352, -1.373350, 
        17.495529}}],
    Line[{{-1.267352, -1.373350, 17.495529},{-1.283312, -1.495735, 
        17.053144}}],
    Line[{{-1.283312, -1.495735, 17.053144},{-1.309715, -1.624787, 
        16.624310}}],
    Line[{{-1.309715, -1.624787, 16.624310},{-1.346255, -1.761631, 
        16.208988}}],
    Line[{{-1.346255, -1.761631, 16.208988},{-1.392766, -1.907471, 
        15.807199}}],
    Line[{{-1.392766, -1.907471, 15.807199},{-1.449217, -2.063588, 
        15.419033}}],
    Line[{{-1.449217, -2.063588, 15.419033},{-1.515706, -2.231354, 
        15.044655}}],
    Line[{{-1.515706, -2.231354, 15.044655},{-1.592456, -2.412230, 
        14.684320}}],
    Line[{{-1.592456, -2.412230, 14.684320},{-1.679813, -2.607778, 
        14.338387}}],
    Line[{{-1.679813, -2.607778, 14.338387},{-1.778244, -2.819670, 
        14.007332}}],
    Line[{{-1.778244, -2.819670, 14.007332},{-1.888335, -3.049691, 
        13.691778}}],
    Line[{{-1.888335, -3.049691, 13.691778},{-2.010794, -3.299756, 
        13.392513}}],
    Line[{{-2.010794, -3.299756, 13.392513},{-2.146449, -3.571904, 
        13.110522}}],
    Line[{{-2.146449, -3.571904, 13.110522},{-2.296251, -3.868312, 
        12.847020}}],
    Line[{{-2.296251, -3.868312, 12.847020},{-2.461271, -4.191292, 
        12.603498}}],
    Line[{{-2.461271, -4.191292, 12.603498},{-2.642709, -4.543285, 
        12.381774}}],
    Line[{{-2.642709, -4.543285, 12.381774},{-2.841885, -4.926859, 
        12.184031}}],
    Line[{{-2.841885, -4.926859, 12.184031},{-3.060245, -5.344667, 
        12.012919}}],
    Line[{{-3.060245, -5.344667, 12.012919},{-3.299355, -5.799452, 
        11.871584}}],
    Line[{{-3.299355, -5.799452, 11.871584},{-3.560888, -6.293945, 
        11.763803}}],
    Line[{{-3.560888, -6.293945, 11.763803},{-3.846625, -6.830853, 
        11.694025}}],
    Line[{{-3.846625, -6.830853, 11.694025},{-4.158422, -7.412705, 
        11.667526}}],
    Line[{{-4.158422, -7.412705, 11.667526},{-4.498187, -8.041746, 
        11.690482}}],
    Line[{{-4.498187, -8.041746, 11.690482},{-4.867838, -8.719746, 
        11.770088}}],
    Line[{{-4.867838, -8.719746, 11.770088},{-5.269251, -9.447780, 
        11.914658}}],
    Line[{{-5.269251, -9.447780, 11.914658},{-5.704178, -10.225906, 
        12.133704}}],
    Line[{{-5.704178, -10.225906, 12.133704},{-6.174140, -11.052775, 
        12.437968}}],
    Line[{{-6.174140, -11.052775, 12.437968},{-6.680307, -11.925220, 
        12.839404}}],
    Line[{{-6.680307, -11.925220, 12.839404},{-7.223328, -12.837666, 
        13.351063}}],
    Line[{{-7.223328, -12.837666, 13.351063},{-7.803108, -13.781487, 
        13.986775}}],
    Line[{{-7.803108, -13.781487, 13.986775},{-8.418570, -14.744358, 
        14.760716}}],
    Line[{{-8.418570, -14.744358, 14.760716},{-9.067358, -15.709524, 
        15.686646}}],
    Line[{{-9.067358, -15.709524, 15.686646},{-9.745507, -16.655197, 
        16.776875}}],
    Line[{{-9.745507, -16.655197, 16.776875},{-10.447095, -17.554096, 
        18.040842}}],
    Line[{{-10.447095, -17.554096, 18.040842},{-11.163893, -18.373356, 
        19.483332}}],
    Line[{{-11.163893, -18.373356, 19.483332},{-11.885069, -19.074984, 
        21.102375}}],
    Line[{{-11.885069, -19.074984, 21.102375},{-12.597014, -19.617176, 
        22.886982}}],
    Line[{{-12.597014, -19.617176, 22.886982},{-13.283332, -19.956450, 
        24.815075}}],
    Line[{{-13.283332, -19.956450, 24.815075},{-13.925096, -20.050945, 
        26.851894}}],
    Line[{{-13.925096, -20.050945, 26.851894},{-14.501440, -19.864609, 
        28.949514}}],
    Line[{{-14.501440, -19.864609, 28.949514},{-14.990529, -19.371965, 
        31.047897}}],
    Line[{{-14.990529, -19.371965, 31.047897},{-15.370880, -18.562780, 
        33.077892}}],
    Line[{{-15.370880, -18.562780, 33.077892},{-15.622973, -17.445740, 
        34.966213}}],
    Line[{{-15.622973, -17.445740, 34.966213},{-15.730970, -16.050110, 
        36.641968}}],
    Line[{{-15.730970, -16.050110, 36.641968},{-15.684291, -14.424742, 
        38.043751}}],
    Line[{{-15.684291, -14.424742, 38.043751},{-15.478814, -12.634272, 
        39.126049}}],
    Line[{{-15.478814, -12.634272, 39.126049},{-15.117488, -10.752891, 
        39.863758}}],
    Line[{{-15.117488, -10.752891, 39.863758},{-14.610189, -8.856799, 
        40.253826}}],
    Line[{{-14.610189, -8.856799, 40.253826},{-13.972909, -7.016819, 
        40.313892}}],
    Line[{{-13.972909, -7.016819, 40.313892},{-13.226343, -5.292339, 
        40.078346}}],
    Line[{{-13.226343, -5.292339, 40.078346},{-12.394150, -3.727606, 
        39.592728}}],
    Line[{{-12.394150, -3.727606, 39.592728},{-11.501157, -2.350405, 
        38.907883}}],
    Line[{{-11.501157, -2.350405, 38.907883},{-10.571705, -1.172976, 
        38.074615}}],
    Line[{{-10.571705, -1.172976, 38.074615},{-9.628326, -0.194442, 
        37.139671}}],
    Line[{{-9.628326, -0.194442, 37.139671},{-8.690822, 0.596009, 
        36.143238}}],
    Line[{{-8.690822, 0.596009, 36.143238},{-7.775723, 1.215821, 35.117767}}],
    
    Line[{{-7.775723, 1.215821, 35.117767},{-6.896133, 1.686124, 34.088039}}],
    
    Line[{{-6.896133, 1.686124, 34.088039},{-6.061822, 2.029379, 33.071846}}],
    
    Line[{{-6.061822, 2.029379, 33.071846},{-5.279494, 2.267655, 32.081081}}],
    
    Line[{{-5.279494, 2.267655, 32.081081},{-4.553183, 2.421516, 31.122972}}],
    
    Line[{{-4.553183, 2.421516, 31.122972},{-3.884682, 2.509389, 30.201256}}],
    
    Line[{{-3.884682, 2.509389, 30.201256},{-3.273975, 2.547297, 29.317186}}],
    
    Line[{{-3.273975, 2.547297, 29.317186},{-2.719640, 2.548835, 28.470362}}],
    
    Line[{{-2.719640, 2.548835, 28.470362},{-2.219209, 2.525311, 27.659369}}],
    
    Line[{{-2.219209, 2.525311, 27.659369},{-1.769475, 2.485964, 26.882236}}],
    
    Line[{{-1.769475, 2.485964, 26.882236},{-1.366746, 2.438227, 26.136770}}],
    
    Line[{{-1.366746, 2.438227, 26.136770},{-1.007050, 2.387990, 25.420753}}],
    
    Line[{{-1.007050, 2.387990, 25.420753},{-0.686299, 2.339851, 24.732084}}],
    
    Line[{{-0.686299, 2.339851, 24.732084},{-0.400408, 2.297354, 24.068851}}],
    
    Line[{{-0.400408, 2.297354, 24.068851},{-0.145385, 2.263187, 23.429356}}],
    
    Line[{{-0.145385, 2.263187, 23.429356},{0.082602, 2.239369, 22.812124}}],
    Line[{{0.082602, 2.239369, 22.812124},{0.287187, 2.227391, 22.215902}}],
    Line[{{0.287187, 2.227391, 22.215902},{0.471780, 2.228354, 21.639631}}],
    Line[{{0.471780, 2.228354, 21.639631},{0.639556, 2.243073, 21.082438}}],
    Line[{{0.639556, 2.243073, 21.082438},{0.793457, 2.272163, 20.543604}}],
    Line[{{0.793457, 2.272163, 20.543604},{0.936195, 2.316115, 20.022562}}],
    Line[{{0.936195, 2.316115, 20.022562},{1.070268, 2.375358, 19.518871}}],
    Line[{{1.070268, 2.375358, 19.518871},{1.197975, 2.450303, 19.032213}}],
    Line[{{1.197975, 2.450303, 19.032213},{1.321438, 2.541384, 18.562382}}],
    Line[{{1.321438, 2.541384, 18.562382},{1.442619, 2.649093, 18.109280}}],
    Line[{{1.442619, 2.649093, 18.109280},{1.563345, 2.774001, 17.672922}}],
    Line[{{1.563345, 2.774001, 17.672922},{1.685328, 2.916777, 17.253437}}],
    Line[{{1.685328, 2.916777, 17.253437},{1.810185, 3.078207, 16.851076}}],
    Line[{{1.810185, 3.078207, 16.851076},{1.939462, 3.259206, 16.466228}}],
    Line[{{1.939462, 3.259206, 16.466228},{2.074650, 3.460820, 16.099432}}],
    Line[{{2.074650, 3.460820, 16.099432},{2.217205, 3.684241, 15.751389}}],
    Line[{{2.217205, 3.684241, 15.751389},{2.368564, 3.930803, 15.423000}}],
    Line[{{2.368564, 3.930803, 15.423000},{2.530162, 4.201978, 15.115389}}],
    Line[{{2.530162, 4.201978, 15.115389},{2.703445, 4.499380, 14.829927}}],
    Line[{{2.703445, 4.499380, 14.829927},{2.889878, 4.824740, 14.568294}}],
    Line[{{2.889878, 4.824740, 14.568294},{3.090959, 5.179898, 14.332497}}],
    Line[{{3.090959, 5.179898, 14.332497},{3.308225, 5.566778, 14.124940}}],
    Line[{{3.308225, 5.566778, 14.124940},{3.543244, 5.987330, 13.948486}}],
    Line[{{3.543244, 5.987330, 13.948486},{3.797631, 6.443512, 13.806500}}],
    Line[{{3.797631, 6.443512, 13.806500},{4.073022, 6.937185, 13.702942}}],
    Line[{{4.073022, 6.937185, 13.702942},{4.371068, 7.470026, 13.642424}}],
    Line[{{4.371068, 7.470026, 13.642424},{4.693415, 8.043443, 13.630290}}],
    Line[{{4.693415, 8.043443, 13.630290},{5.041659, 8.658351, 13.672690}}],
    Line[{{5.041659, 8.658351, 13.672690},{5.417303, 9.315022, 13.776624}}],
    Line[{{5.417303, 9.315022, 13.776624},{5.821691, 10.012834, 13.949986}}],
    Line[{{5.821691, 10.012834, 13.949986},{6.255928, 10.749955, 14.201566}}],
    
    Line[{{6.255928, 10.749955, 14.201566},{6.720763, 11.522993, 14.540976}}],
    
    Line[{{6.720763, 11.522993, 14.540976},{7.216456, 12.326583, 14.978504}}],
    
    Line[{{7.216456, 12.326583, 14.978504},{7.742628, 13.152948, 15.524894}}],
    
    Line[{{7.742628, 13.152948, 15.524894},{8.298054, 13.991393, 16.190916}}],
    
    Line[{{8.298054, 13.991393, 16.190916},{8.880444, 14.827841, 16.986769}}],
    
    Line[{{8.880444, 14.827841, 16.986769},{9.486211, 15.644442, 17.921289}}],
    
    Line[{{9.486211, 15.644442, 17.921289},{
      10.110216, 16.419325, 19.000902}}],
    Line[{{10.110216, 16.419325, 19.000902},{
      10.745532, 17.126608, 20.228336}}],
    Line[{{10.745532, 17.126608, 20.228336},{
      11.383247, 17.736811, 21.601175}}],
    Line[{{11.383247, 17.736811, 21.601175},{
      12.012357, 18.217779, 23.110306}}],
    Line[{{12.012357, 18.217779, 23.110306},{
      12.619771, 18.536245, 24.738501}}],
    Line[{{12.619771, 18.536245, 24.738501},{
      13.190514, 18.660076, 26.459352}}],
    Line[{{13.190514, 18.660076, 26.459352},{
      13.708145, 18.561115, 28.236904}}],
    Line[{{13.708145, 18.561115, 28.236904},{
      14.155427, 18.218428, 30.026245}}],
    Line[{{14.155427, 18.218428, 30.026245},{
      14.515261, 17.621538, 31.775455}}],
    Line[{{14.515261, 17.621538, 31.775455},{
      14.771791, 16.773067, 33.428661}}],
    Line[{{14.771791, 16.773067, 33.428661},{
      14.911622, 15.690291, 34.930290}}],
    Line[{{14.911622, 15.690291, 34.930290},{
      14.924993, 14.405061, 36.229858}}],
    Line[{{14.924993, 14.405061, 36.229858},{
      14.806738, 12.961898, 37.286625}}],
    Line[{{14.806738, 12.961898, 37.286625},{
      14.556890, 11.414305, 38.073288}}],
    Line[{{14.556890, 11.414305, 38.073288},{
      14.180811, 9.820000, 38.578033}}],
    Line[{{14.180811, 9.820000, 38.578033},{13.688845, 8.235735, 38.804737}}],
    
    Line[{{13.688845, 8.235735, 38.804737},{13.095508, 6.712552, 38.771183}}],
    
    Line[{{13.095508, 6.712552, 38.771183},{12.418364, 5.292239, 38.505932}}],
    
    Line[{{12.418364, 5.292239, 38.505932},{11.676749, 4.005303, 38.044437}}],
    
    Line[{{11.676749, 4.005303, 38.044437},{10.890493, 2.870519, 37.425087}}],
    
    Line[{{10.890493, 2.870519, 37.425087},{10.078787, 1.895779, 36.685791}}],
    
    Line[{{10.078787, 1.895779, 36.685791},{9.259288, 1.079852, 35.861420}}],
    Line[{{9.259288, 1.079852, 35.861420},{8.447502, 0.414542, 34.982182}}],
    Line[{{8.447502, 0.414542, 34.982182},{7.656434, -0.113092, 34.072922}}],
    Line[{{7.656434, -0.113092, 34.072922},{6.896470, -0.518738, 33.153065}}],
    
    Line[{{6.896470, -0.518738, 33.153065},{6.175449, -0.819199, 32.237080}}],
    
    Line[{{6.175449, -0.819199, 32.237080},{5.498865, -1.031178, 31.335161}}],
    
    Line[{{5.498865, -1.031178, 31.335161},{4.870135, -1.170443, 30.454033}}],
    
    Line[{{4.870135, -1.170443, 30.454033},{4.290920, -1.251324, 29.597742}}],
    
    Line[{{4.290920, -1.251324, 29.597742},{3.761439, -1.286462, 28.768351}}],
    
    Line[{{3.761439, -1.286462, 28.768351},{3.280771, -1.286735, 27.966528}}],
    
    Line[{{3.280771, -1.286735, 27.966528},{2.847133, -1.261310, 27.192013}}],
    
    Line[{{2.847133, -1.261310, 27.192013},{2.458115, -1.217771, 26.443968}}],
    
    Line[{{2.458115, -1.217771, 26.443968},{2.110886, -1.162281, 25.721233}}],
    
    Line[{{2.110886, -1.162281, 25.721233},{1.802359, -1.099761, 25.022512}}],
    
    Line[{{1.802359, -1.099761, 25.022512},{1.529325, -1.034070, 24.346481}}],
    
    Line[{{1.529325, -1.034070, 24.346481},{1.288559, -0.968175, 23.691858}}],
    
    Line[{{1.288559, -0.968175, 23.691858},{1.076895, -0.904302, 23.057455}}],
    
    Line[{{1.076895, -0.904302, 23.057455},{0.891289, -0.844078, 22.442183}}],
    
    Line[{{0.891289, -0.844078, 22.442183},{0.728854, -0.788648, 21.845062}}],
    
    Line[{{0.728854, -0.788648, 21.845062},{0.586890, -0.738774, 21.265224}}],
    
    Line[{{0.586890, -0.738774, 21.265224},{0.462895, -0.694927, 20.701887}}],
    
    Line[{{0.462895, -0.694927, 20.701887},{0.354571, -0.657355, 20.154360}}],
    
    Line[{{0.354571, -0.657355, 20.154360},{0.259825, -0.626143, 19.622023}}],
    
    Line[{{0.259825, -0.626143, 19.622023},{0.176759, -0.601267, 19.104317}}],
    
    Line[{{0.176759, -0.601267, 19.104317},{0.103664, -0.582624, 18.600737}}],
    
    Line[{{0.103664, -0.582624, 18.600737},{0.039004, -0.570072, 18.110823}}],
    
    Line[{{
      0.039004, -0.570072, 18.110823},{-0.018596, -0.563452, 17.634150}}],
    Line[{{-0.018596, -0.563452, 17.634150},{-0.070365, -0.562607, 
        17.170324}}],
    Line[{{-0.070365, -0.562607, 17.170324},{-0.117400, -0.567399, 
        16.718981}}],
    Line[{{-0.117400, -0.567399, 16.718981},{-0.160683, -0.577718, 
        16.279778}}],
    Line[{{-0.160683, -0.577718, 16.279778},{-0.201093, -0.593496, 
        15.852392}}],
    Line[{{-0.201093, -0.593496, 15.852392},{-0.239422, -0.614709, 
        15.436522}}],
    Line[{{-0.239422, -0.614709, 15.436522},{-0.276386, -0.641385, 
        15.031880}}],
    Line[{{-0.276386, -0.641385, 15.031880},{-0.312638, -0.673609, 
        14.638200}}],
    Line[{{-0.312638, -0.673609, 14.638200},{-0.348780, -0.711526, 
        14.255229}}],
    Line[{{-0.348780, -0.711526, 14.255229},{-0.385376, -0.755345, 
        13.882733}}],
    Line[{{-0.385376, -0.755345, 13.882733},{-0.422955, -0.805341, 
        13.520496}}],
    Line[{{-0.422955, -0.805341, 13.520496},{-0.462028, -0.861860, 
        13.168319}}],
    Line[{{-0.462028, -0.861860, 13.168319},{-0.503094, -0.925322, 
        12.826025}}],
    Line[{{-0.503094, -0.925322, 12.826025},{-0.546647, -0.996226, 
        12.493460}}],
    Line[{{-0.546647, -0.996226, 12.493460},{-0.593187, -1.075153, 
        12.170495}}],
    Line[{{-0.593187, -1.075153, 12.170495},{-0.643223, -1.162775, 
        11.857031}}],
    Line[{{-0.643223, -1.162775, 11.857031},{-0.697288, -1.259859, 
        11.553000}}],
    Line[{{-0.697288, -1.259859, 11.553000},{-0.755940, -1.367272, 
        11.258379}}],
    Line[{{-0.755940, -1.367272, 11.258379},{-0.819771, -1.485995, 
        10.973183}}],
    Line[{{-0.819771, -1.485995, 10.973183},{-0.889418, -1.617127, 
        10.697484}}],
    Line[{{-0.889418, -1.617127, 10.697484},{-0.965566, -1.761896, 
        10.431419}}],
    Line[{{-0.965566, -1.761896, 10.431419},{-1.048959, -1.921673, 
        10.175199}}],
    Line[{{-1.048959, -1.921673, 10.175199},{-1.140409, -2.097981, 
        9.929125}}],
    Line[{{-1.140409, -2.097981, 9.929125},{-1.240802, -2.292506, 9.693606}}],
    
    Line[{{-1.240802, -2.292506, 9.693606},{-1.351110, -2.507117, 9.469182}}],
    
    Line[{{-1.351110, -2.507117, 9.469182},{-1.472399, -2.743872, 9.256554}}],
    
    Line[{{-1.472399, -2.743872, 9.256554},{-1.605839, -3.005037, 9.056593}}],
    
    Line[{{-1.605839, -3.005037, 9.056593},{-1.752715, -3.293092, 8.870429}}],
    
    Line[{{-1.752715, -3.293092, 8.870429},{-1.914437, -3.610751, 8.699425}}],
    
    Line[{{-1.914437, -3.610751, 8.699425},{-2.092550, -3.960957, 8.545321}}],
    
    Line[{{-2.092550, -3.960957, 8.545321},{-2.288744, -4.346902, 8.410205}}],
    
    Line[{{-2.288744, -4.346902, 8.410205},{-2.504863, -4.771995, 8.296688}}],
    
    Line[{{-2.504863, -4.771995, 8.296688},{-2.742910, -5.239872, 8.207929}}],
    
    Line[{{-2.742910, -5.239872, 8.207929},{-3.005054, -5.754347, 8.147782}}],
    
    Line[{{-3.005054, -5.754347, 8.147782},{-3.293625, -6.319350, 8.120931}}],
    
    Line[{{-3.293625, -6.319350, 8.120931},{-3.611111, -6.938876, 8.133002}}],
    
    Line[{{-3.611111, -6.938876, 8.133002},{-3.960139, -7.616807, 8.190788}}],
    
    Line[{{-3.960139, -7.616807, 8.190788},{-4.343441, -8.356760, 8.302394}}],
    
    Line[{{-4.343441, -8.356760, 8.302394},{-4.763815, -9.161836, 8.477449}}],
    
    Line[{{-4.763815, -9.161836, 8.477449},{-5.224047, -10.034271, 
        8.727299}}],
    Line[{{-5.224047, -10.034271, 8.727299},{-5.726813, -10.974983, 
        9.065183}}],
    Line[{{-5.726813, -10.974983, 9.065183},{-6.274528, -11.982959, 
        9.506357}}],
    Line[{{-6.274528, -11.982959, 9.506357},{-6.869167, -13.054547, 
        10.068119}}],
    Line[{{-6.869167, -13.054547, 10.068119},{-7.512000, -14.182508, 
        10.769676}}],
    Line[{{-7.512000, -14.182508, 10.769676},{-8.203270, -15.354940, 
        11.631762}}],
    Line[{{-8.203270, -15.354940, 11.631762},{-8.941792, -16.554070, 
        12.675896}}],
    Line[{{-8.941792, -16.554070, 12.675896},{-9.724468, -17.754978, 
        13.923180}}],
    Line[{{-9.724468, -17.754978, 13.923180},{-10.545726, -18.924454, 
        15.392404}}],
    Line[{{-10.545726, -18.924454, 15.392404},{-11.396931, -20.020199, 
        17.097548}}],
    Line[{{-11.396931, -20.020199, 17.097548},{-12.265797, -20.990747, 
        19.044497}}],
    Line[{{-12.265797, -20.990747, 19.044497},{-13.135901, -21.776531, 
        21.227180}}],
    Line[{{-13.135901, -21.776531, 21.227180},{-13.986427, -22.312582, 
        23.623508}}],
    Line[{{-13.986427, -22.312582, 23.623508},{-14.792274, -22.533230, 
        26.191814}}],
    Line[{{-14.792274, -22.533230, 26.191814},{-15.524712, -22.378817, 
        28.868748}}],
    Line[{{-15.524712, -22.378817, 28.868748},{-16.152691, -21.804022, 
        31.569822}}],
    Line[{{-16.152691, -21.804022, 31.569822},{-16.644844, -20.786556, 
        34.193485}}],
    Line[{{-16.644844, -20.786556, 34.193485},{-16.972097, -19.334526, 
        36.629230}}],
    Line[{{-16.972097, -19.334526, 36.629230},{-17.110563, -17.490259, 
        38.769035}}],
    Line[{{-17.110563, -17.490259, 38.769035},{-17.044279, -15.329059, 
        40.520245}}],
    Line[{{-17.044279, -15.329059, 40.520245},{-16.767309, -12.952262, 
        41.817333}}],
    Line[{{-16.767309, -12.952262, 41.817333},{-16.284714, -10.475486, 
        42.629677}}],
    Line[{{-16.284714, -10.475486, 42.629677},{-15.612227, -8.014810, 
        42.963699}}],
    Line[{{-15.612227, -8.014810, 42.963699},{-14.774596, -5.673603, 
        42.858749}}],
    Line[{{-14.774596, -5.673603, 42.858749},{-13.803030, -3.532876, 
        42.378613}}],
    Line[{{-13.803030, -3.532876, 42.378613},{-12.732179, -1.646438, 
        41.600674}}],
    Line[{{-12.732179, -1.646438, 41.600674},{-11.597187, -0.040877, 
        40.605377}}],
    Line[{{-11.597187, -0.040877, 40.605377},{-10.431200, 1.280809, 
        39.467815}}],
    Line[{{-10.431200, 1.280809, 39.467815},{-9.263579, 2.333548, 
        38.252285}}],
    Line[{{-9.263579, 2.333548, 38.252285},{-8.118855, 3.144066, 37.009830}}],
    
    Line[{{-8.118855, 3.144066, 37.009830},{-7.016335, 3.745358, 35.778065}}],
    
    Line[{{-7.016335, 3.745358, 35.778065},{-5.970226, 4.172342, 34.582573}}],
    
    Line[{{-5.970226, 4.172342, 34.582573},{-4.990095, 4.458839, 33.439049}}],
    
    Line[{{-4.990095, 4.458839, 33.439049},{-4.081511, 4.635726, 32.355610}}],
    
    Line[{{-4.081511, 4.635726, 32.355610},{-3.246757, 4.730027, 31.334991}}],
    
    Line[{{-3.246757, 4.730027, 31.334991},{-2.485526, 4.764654, 30.376339}}],
    
    Line[{{-2.485526, 4.764654, 30.376339},{-1.795552, 4.758553, 29.476624}}],
    
    Line[{{-1.795552, 4.758553, 29.476624},{-1.173161, 4.727070, 28.631695}}],
    
    Line[{{-1.173161, 4.727070, 28.631695},{-0.613723, 4.682428, 27.836983}}],
    
    Line[{{-0.613723, 4.682428, 27.836983},{-0.112016, 4.634214, 27.087961}}],
    
    Line[{{-0.112016, 4.634214, 27.087961},{0.337489, 4.589843, 26.380438}}],
    Line[{{0.337489, 4.589843, 26.380438},{0.740411, 4.554971, 25.710695}}],
    Line[{{0.740411, 4.554971, 25.710695},{1.102304, 4.533857, 25.075554}}],
    Line[{{1.102304, 4.533857, 25.075554},{1.428543, 4.529663, 24.472374}}],
    Line[{{1.428543, 4.529663, 24.472374},{1.724249, 4.544706, 23.899036}}],
    Line[{{1.724249, 4.544706, 23.899036},{1.994245, 4.580666, 23.353899}}],
    Line[{{1.994245, 4.580666, 23.353899},{2.243030, 4.638749, 22.835752}}],
    Line[{{2.243030, 4.638749, 22.835752},{2.474771, 4.719820, 22.343775}}],
    Line[{{2.474771, 4.719820, 22.343775},{2.693311, 4.824508, 21.877497}}],
    Line[{{2.693311, 4.824508, 21.877497},{2.902178, 4.953288, 21.436762}}],
    Line[{{2.902178, 4.953288, 21.436762},{3.104604, 5.106539, 21.021719}}],
    Line[{{3.104604, 5.106539, 21.021719},{3.303548, 5.284590, 20.632786}}],
    Line[{{3.303548, 5.284590, 20.632786},{3.501715, 5.487743, 20.270662}}],
    Line[{{3.501715, 5.487743, 20.270662},{3.701583, 5.716292, 19.936314}}],
    Line[{{3.701583, 5.716292, 19.936314},{3.905421, 5.970526, 19.630976}}],
    Line[{{3.905421, 5.970526, 19.630976},{4.115308, 6.250710, 19.356174}}],
    Line[{{4.115308, 6.250710, 19.356174},{4.333151, 6.557076, 19.113722}}],
    Line[{{4.333151, 6.557076, 19.113722},{4.560691, 6.889778, 18.905746}}],
    Line[{{4.560691, 6.889778, 18.905746},{4.799516, 7.248855, 18.734692}}],
    Line[{{4.799516, 7.248855, 18.734692},{5.051057, 7.634170, 18.603336}}],
    Line[{{5.051057, 7.634170, 18.603336},{5.316584, 8.045331, 18.514801}}],
    Line[{{5.316584, 8.045331, 18.514801},{5.597193, 8.481611, 18.472548}}],
    Line[{{5.597193, 8.481611, 18.472548},{5.893790, 8.941851, 18.480373}}],
    Line[{{5.893790, 8.941851, 18.480373},{6.207051, 9.424319, 18.542372}}],
    Line[{{6.207051, 9.424319, 18.542372},{6.537395, 9.926603, 18.662888}}],
    Line[{{6.537395, 9.926603, 18.662888},{6.884937, 10.445457, 18.846449}}],
    Line[{{6.884937, 10.445457, 18.846449},{7.249416, 10.976638, 19.097628}}],
    
    Line[{{7.249416, 10.976638, 19.097628},{7.630143, 11.514773, 19.420887}}],
    
    Line[{{7.630143, 11.514773, 19.420887},{8.025926, 12.053205, 19.820395}}],
    
    Line[{{8.025926, 12.053205, 19.820395},{8.434978, 12.583871, 20.299694}}],
    
    Line[{{8.434978, 12.583871, 20.299694},{8.854851, 13.097263, 20.861401}}],
    
    Line[{{8.854851, 13.097263, 20.861401},{9.282350, 13.582368, 21.506842}}],
    
    Line[{{9.282350, 13.582368, 21.506842},{9.713468, 14.026827, 22.235525}}],
    
    Line[{{9.713468, 14.026827, 22.235525},{
      10.143347, 14.417129, 23.044750}}],
    Line[{{10.143347, 14.417129, 23.044750},{
      10.566264, 14.738990, 23.929100}}],
    Line[{{10.566264, 14.738990, 23.929100},{
      10.975665, 14.977901, 24.880049}}],
    Line[{{10.975665, 14.977901, 24.880049},{
      11.364258, 15.119853, 25.885660}}],
    Line[{{11.364258, 15.119853, 25.885660},{
      11.724166, 15.152201, 26.930492}}],
    Line[{{11.724166, 15.152201, 26.930492},{
      12.047168, 15.064648, 27.995737}}],
    Line[{{12.047168, 15.064648, 27.995737},{
      12.325000, 14.850237, 29.059689}}],
    Line[{{12.325000, 14.850237, 29.059689},{
      12.549719, 14.506248, 30.098511}}],
    Line[{{12.549719, 14.506248, 30.098511},{
      12.714111, 14.034907, 31.087328}}],
    Line[{{12.714111, 14.034907, 31.087328},{
      12.812121, 13.443774, 32.001572}}],
    Line[{{12.812121, 13.443774, 32.001572},{
      12.839245, 12.745614, 32.818466}}],
    Line[{{12.839245, 12.745614, 32.818466},{
      12.792854, 11.957922, 33.518414}}],
    Line[{{12.792854, 11.957922, 33.518414},{
      12.672428, 11.101931, 34.086224}}],
    Line[{{12.672428, 11.101931, 34.086224},{
      12.479643, 10.201291, 34.511955}}],
    Line[{{12.479643, 10.201291, 34.511955},{
      12.218324, 9.280557, 34.791328}}],
    Line[{{12.218324, 9.280557, 34.791328},{11.894249, 8.363645, 34.925606}}],
    
    Line[{{11.894249, 8.363645, 34.925606},{11.514836, 7.472457, 34.921055}}],
    
    Line[{{11.514836, 7.472457, 34.921055},{11.088737, 6.625805, 34.788044}}],
    
    Line[{{11.088737, 6.625805, 34.788044},{10.625392, 5.838700, 34.539921}}],
    
    Line[{{10.625392, 5.838700, 34.539921},{10.134573, 5.122053, 34.191872}}],
    
    Line[{{10.134573, 5.122053, 34.191872},{9.625964, 4.482731, 33.759796}}],
    Line[{{9.625964, 4.482731, 33.759796},{9.108797, 3.923897, 33.259388}}],
    Line[{{9.108797, 3.923897, 33.259388},{8.591569, 3.445551, 32.705414}}],
    Line[{{8.591569, 3.445551, 32.705414},{8.081841, 3.045164, 32.111225}}],
    Line[{{8.081841, 3.045164, 32.111225},{7.586120, 2.718336, 31.488506}}],
    Line[{{7.586120, 2.718336, 31.488506},{7.109806, 2.459419, 30.847158}}],
    Line[{{7.109806, 2.459419, 30.847158},{6.657211, 2.262057, 30.195370}}],
    Line[{{6.657211, 2.262057, 30.195370},{6.231617, 2.119630, 29.539742}}],
    Line[{{6.231617, 2.119630, 29.539742},{5.835365, 2.025602, 28.885485}}],
    Line[{{5.835365, 2.025602, 28.885485},{5.469965, 1.973768, 28.236622}}],
    Line[{{5.469965, 1.973768, 28.236622},{5.136216, 1.958429, 27.596209}}],
    Line[{{5.136216, 1.958429, 27.596209},{4.834327, 1.974487, 26.966524}}],
    Line[{{4.834327, 1.974487, 26.966524},{4.564034, 2.017498, 26.349251}}],
    Line[{{4.564034, 2.017498, 26.349251},{4.324708, 2.083679, 25.745613}}],
    Line[{{4.324708, 2.083679, 25.745613},{4.115448, 2.169890, 25.156511}}],
    Line[{{4.115448, 2.169890, 25.156511},{3.935174, 2.273598, 24.582609}}],
    Line[{{3.935174, 2.273598, 24.582609},{3.782691, 2.392832, 24.024418}}],
    Line[{{3.782691, 2.392832, 24.024418},{3.656758, 2.526127, 23.482353}}],
    Line[{{3.656758, 2.526127, 23.482353},{3.556133, 2.672470, 22.956787}}],
    Line[{{3.556133, 2.672470, 22.956787},{3.479618, 2.831253, 22.448084}}],
    Line[{{3.479618, 2.831253, 22.448084},{3.426087, 3.002217, 21.956625}}],
    Line[{{3.426087, 3.002217, 21.956625},{3.394511, 3.185410, 21.482838}}],
    Line[{{3.394511, 3.185410, 21.482838},{3.383979, 3.381143, 21.027216}}],
    Line[{{3.383979, 3.381143, 21.027216},{3.393705, 3.589957, 20.590340}}],
    Line[{{3.393705, 3.589957, 20.590340},{3.423040, 3.812585, 20.172892}}],
    Line[{{3.423040, 3.812585, 20.172892},{3.471476, 4.049925, 19.775675}}],
    Line[{{3.471476, 4.049925, 19.775675},{3.538642, 4.303010, 19.399637}}],
    Line[{{3.538642, 4.303010, 19.399637},{3.624311, 4.572985, 19.045891}}],
    Line[{{3.624311, 4.572985, 19.045891},{3.728386, 4.861075, 18.715734}}],
    Line[{{3.728386, 4.861075, 18.715734},{3.850903, 5.168563, 18.410677}}],
    Line[{{3.850903, 5.168563, 18.410677},{3.992014, 5.496754, 18.132473}}],
    Line[{{3.992014, 5.496754, 18.132473},{4.151985, 5.846948, 17.883144}}],
    Line[{{4.151985, 5.846948, 17.883144},{4.331175, 6.220390, 17.665016}}],
    Line[{{4.331175, 6.220390, 17.665016},{4.530023, 6.618227, 17.480747}}],
    Line[{{4.530023, 6.618227, 17.480747},{4.749031, 7.041449, 17.333363}}],
    Line[{{4.749031, 7.041449, 17.333363},{4.988733, 7.490811, 17.226286}}],
    Line[{{4.988733, 7.490811, 17.226286},{5.249672, 7.966744, 17.163355}}],
    Line[{{5.249672, 7.966744, 17.163355},{5.532362, 8.469265, 17.148853}}],
    Line[{{5.532362, 8.469265, 17.148853},{5.837238, 8.997820, 17.187494}}],
    Line[{{5.837238, 8.997820, 17.187494},{6.164614, 9.551163, 17.284422}}],
    Line[{{6.164614, 9.551163, 17.284422},{6.514615, 10.127183, 17.445160}}],
    Line[{{6.514615, 10.127183, 17.445160},{6.887097, 10.722689, 17.675512}}],
    
    Line[{{6.887097, 10.722689, 17.675512},{7.281573, 11.333242, 17.981466}}],
    
    Line[{{7.281573, 11.333242, 17.981466},{7.697111, 11.952916, 18.368992}}],
    
    Line[{{7.697111, 11.952916, 18.368992},{8.132214, 12.574092, 18.843718}}],
    
    Line[{{8.132214, 12.574092, 18.843718},{8.584725, 13.187299, 19.410686}}],
    
    Line[{{8.584725, 13.187299, 19.410686},{9.051689, 13.781053, 20.073849}}],
    
    Line[{{9.051689, 13.781053, 20.073849},{9.529243, 14.341873, 20.835493}}],
    
    Line[{{9.529243, 14.341873, 20.835493},{
      10.012513, 14.854356, 21.695702}}],
    Line[{{10.012513, 14.854356, 21.695702},{
      10.495542, 15.301438, 22.651657}}],
    Line[{{10.495542, 15.301438, 22.651657},{
      10.971250, 15.664920, 23.696960}}],
    Line[{{10.971250, 15.664920, 23.696960},{
      11.431482, 15.926250, 24.821053}}],
    Line[{{11.431482, 15.926250, 24.821053},{
      11.867113, 16.067499, 26.008783}}],
    Line[{{11.867113, 16.067499, 26.008783},{
      12.268257, 16.072630, 27.240257}}],
    Line[{{12.268257, 16.072630, 27.240257},{
      12.624595, 15.928895, 28.491066}}],
    Line[{{12.624595, 15.928895, 28.491066},{
      12.925791, 15.628257, 29.732983}}],
    Line[{{12.925791, 15.628257, 29.732983},{
      13.162007, 15.168655, 30.935160}}],
    Line[{{13.162007, 15.168655, 30.935160},{
      13.324476, 14.554920, 32.065784}}],
    Line[{{13.324476, 14.554920, 32.065784},{
      13.406075, 13.799135, 33.094063}}],
    Line[{{13.406075, 13.799135, 33.094063},{
      13.401850, 12.920348, 33.992310}}],
    Line[{{13.401850, 12.920348, 33.992310},{
      13.309431, 11.943538, 34.737907}}],
    Line[{{13.309431, 11.943538, 34.737907},{
      13.129273, 10.897994, 35.314854}}],
    Line[{{13.129273, 10.897994, 35.314854},{
      12.864703, 9.815246, 35.714657}}],
    Line[{{12.864703, 9.815246, 35.714657},{12.521747, 8.726831, 35.936512}}],
    
    Line[{{12.521747, 8.726831, 35.936512},{12.108775, 7.662192, 35.986771}}],
    
    Line[{{12.108775, 7.662192, 35.986771},{11.635988, 6.646946, 35.877769}}],
    
    Line[{{11.635988, 6.646946, 35.877769},{11.114820, 5.701706, 35.626301}}],
    
    Line[{{11.114820, 5.701706, 35.626301},{10.557310, 4.841496, 35.251915}}],
    
    Line[{{10.557310, 4.841496, 35.251915},{9.975508, 4.075745, 34.775314}}],
    Line[{{9.975508, 4.075745, 34.775314},{9.380960, 3.408733, 34.216938}}],
    Line[{{9.380960, 3.408733, 34.216938},{8.784305, 2.840353, 33.595917}}],
    Line[{{8.784305, 2.840353, 33.595917},{8.194979, 2.367023, 32.929359}}],
    Line[{{8.194979, 2.367023, 32.929359},{7.621051, 1.982645, 32.231995}}],
    Line[{{7.621051, 1.982645, 32.231995},{7.069159, 1.679485, 31.516047}}],
    Line[{{7.069159, 1.679485, 31.516047},{6.544521, 1.448943, 30.791349}}],
    Line[{{6.544521, 1.448943, 30.791349},{6.051027, 1.282160, 30.065575}}],
    Line[{{6.051027, 1.282160, 30.065575},{5.591360, 1.170480, 29.344530}}],
    Line[{{5.591360, 1.170480, 29.344530},{5.167145, 1.105780, 28.632475}}],
    Line[{{5.167145, 1.105780, 28.632475},{4.779117, 1.080665, 27.932428}}],
    Line[{{4.779117, 1.080665, 27.932428},{4.427274, 1.088588, 27.246450}}],
    Line[{{4.427274, 1.088588, 27.246450},{4.111037, 1.123882, 26.575886}}],
    Line[{{4.111037, 1.123882, 26.575886},{3.829382, 1.181758, 25.921545}}],
    Line[{{3.829382, 1.181758, 25.921545},{3.580971, 1.258259, 25.283882}}],
    Line[{{3.580971, 1.258259, 25.283882},{3.364250, 1.350195, 24.663099}}],
    Line[{{3.364250, 1.350195, 24.663099},{3.177549, 1.455076, 24.059240}}],
    Line[{{3.177549, 1.455076, 24.059240},{3.019146, 1.571026, 23.472269}}],
    Line[{{3.019146, 1.571026, 23.472269},{2.887334, 1.696717, 22.902105}}],
    Line[{{2.887334, 1.696717, 22.902105},{2.780463, 1.831291, 22.348665}}],
    Line[{{2.780463, 1.831291, 22.348665},{2.696981, 1.974298, 21.811888}}],
    Line[{{2.696981, 1.974298, 21.811888},{2.635458, 2.125639, 21.291752}}],
    Line[{{2.635458, 2.125639, 21.291752},{2.594603, 2.285516, 20.788286}}],
    Line[{{2.594603, 2.285516, 20.788286},{2.573282, 2.454385, 20.301588}}],
    Line[{{2.573282, 2.454385, 20.301588},{2.570525, 2.632926, 19.831827}}],
    Line[{{2.570525, 2.632926, 19.831827},{2.585524, 2.822012, 19.379259}}],
    Line[{{2.585524, 2.822012, 19.379259},{2.617643, 3.022679, 18.944241}}],
    Line[{{2.617643, 3.022679, 18.944241},{2.666410, 3.236112, 18.527237}}],
    Line[{{2.666410, 3.236112, 18.527237},{2.731519, 3.463624, 18.128836}}],
    Line[{{2.731519, 3.463624, 18.128836},{2.812823, 3.706646, 17.749777}}],
    Line[{{2.812823, 3.706646, 17.749777},{2.910330, 3.966709, 17.390961}}],
    Line[{{2.910330, 3.966709, 17.390961},{3.024197, 4.245436, 17.053476}}],
    Line[{{3.024197, 4.245436, 17.053476},{3.154725, 4.544524, 16.738632}}],
    Line[{{3.154725, 4.544524, 16.738632},{3.302352, 4.865730, 16.447989}}],
    Line[{{3.302352, 4.865730, 16.447989},{3.467641, 5.210854, 16.183384}}],
    Line[{{3.467641, 5.210854, 16.183384},{3.651274, 5.581698, 15.946995}}],
    Line[{{3.651274, 5.581698, 15.946995},{3.854043, 5.980058, 15.741355}}],
    Line[{{3.854043, 5.980058, 15.741355},{4.076825, 6.407637, 15.569428}}],
    Line[{{4.076825, 6.407637, 15.569428},{4.320577, 6.866030, 15.434639}}],
    Line[{{4.320577, 6.866030, 15.434639},{4.586305, 7.356613, 15.340938}}],
    Line[{{4.586305, 7.356613, 15.340938},{4.875034, 7.880453, 15.292841}}],
    Line[{{4.875034, 7.880453, 15.292841},{5.187776, 8.438188, 15.295479}}],
    Line[{{5.187776, 8.438188, 15.295479},{5.525480, 9.029865, 15.354630}}],
    Line[{{5.525480, 9.029865, 15.354630},{5.888968, 9.654745, 15.476718}}],
    Line[{{5.888968, 9.654745, 15.476718},{6.278875, 10.311100, 15.668814}}],
    Line[{{6.278875, 10.311100, 15.668814},{6.695549, 10.995932, 15.938562}}],
    
    Line[{{6.695549, 10.995932, 15.938562},{7.138941, 11.704660, 16.294039}}],
    
    Line[{{7.138941, 11.704660, 16.294039},{7.608488, 12.430836, 16.743568}}],
    
    Line[{{7.608488, 12.430836, 16.743568},{8.102964, 13.165778, 17.295422}}],
    
    Line[{{8.102964, 13.165778, 17.295422},{8.620306, 13.898249, 17.957329}}],
    
    Line[{{8.620306, 13.898249, 17.957329},{9.157448, 14.614210, 18.735928}}],
    
    Line[{{9.157448, 14.614210, 18.735928},{9.710134, 15.296652, 19.636011}}],
    
    Line[{{9.710134, 15.296652, 19.636011},{
      10.272753, 15.925613, 20.659626}}],
    Line[{{10.272753, 15.925613, 20.659626},{
      10.838192, 16.478466, 21.805063}}],
    Line[{{10.838192, 16.478466, 21.805063},{
      11.397761, 16.930538, 23.065773}}],
    Line[{{11.397761, 16.930538, 23.065773},{
      11.941186, 17.256147, 24.429369}}],
    Line[{{11.941186, 17.256147, 24.429369},{
      12.456736, 17.430088, 25.876844}}],
    Line[{{12.456736, 17.430088, 25.876844},{
      12.931499, 17.429522, 27.382185}}],
    Line[{{12.931499, 17.429522, 27.382185},{
      13.351817, 17.236166, 28.912601}}],
    Line[{{13.351817, 17.236166, 28.912601},{
      13.703909, 16.838579, 30.429543}}],
    Line[{{13.703909, 16.838579, 30.429543},{
      13.974627, 16.234188, 31.890543}}],
    Line[{{13.974627, 16.234188, 31.890543},{
      14.152324, 15.430738, 33.251873}}],
    Line[{{14.152324, 15.430738, 33.251873},{
      14.227719, 14.446803, 34.471714}}],
    Line[{{14.227719, 14.446803, 34.471714},{
      14.194694, 13.311137, 35.513523}}],
    Line[{{14.194694, 13.311137, 35.513523},{
      14.050856, 12.060763, 36.348988}}],
    Line[{{14.050856, 12.060763, 36.348988},{
      13.797863, 10.738182, 36.960251}}],
    Line[{{13.797863, 10.738182, 36.960251},{
      13.441385, 9.387877, 37.340939}}],
    Line[{{13.441385, 9.387877, 37.340939},{12.990732, 8.052770, 37.495872}}],
    
    Line[{{12.990732, 8.052770, 37.495872},{12.458213, 6.771106, 37.439690}}],
    
    Line[{{12.458213, 6.771106, 37.439690},{11.858280, 5.574174, 37.194550}}],
    
    Line[{{11.858280, 5.574174, 37.194550},{11.206594, 4.485019, 36.787445}}],
    
    Line[{{11.206594, 4.485019, 36.787445},{10.519111, 3.518195, 36.247517}}],
    
    Line[{{10.519111, 3.518195, 36.247517},{9.811256, 2.680344, 35.603710}}],
    Line[{{9.811256, 2.680344, 35.603710},{9.097290, 1.971380, 34.882984}}],
    Line[{{9.097290, 1.971380, 34.882984},{8.389834, 1.385947, 34.109150}}],
    Line[{{8.389834, 1.385947, 34.109150},{7.699613, 0.914954, 33.302265}}],
    Line[{{7.699613, 0.914954, 33.302265},{7.035336, 0.546993, 32.478527}}],
    Line[{{7.035336, 0.546993, 32.478527},{6.403739, 0.269526, 31.650490}}],
    Line[{{6.403739, 0.269526, 31.650490},{5.809708, 0.069816, 30.827478}}],
    Line[{{5.809708, 0.069816, 30.827478},{5.256467, -0.064399, 30.016117}}],
    Line[{{5.256467, -0.064399, 30.016117},{4.745811, -0.144471, 29.220863}}],
    
    Line[{{4.745811, -0.144471, 29.220863},{4.278337, -0.180585, 28.444498}}],
    
    Line[{{4.278337, -0.180585, 28.444498},{3.853678, -0.181648, 27.688568}}],
    
    Line[{{3.853678, -0.181648, 27.688568},{3.470717, -0.155274, 26.953735}}],
    
    Line[{{3.470717, -0.155274, 26.953735},{3.127777, -0.107839, 26.240061}}],
    
    Line[{{3.127777, -0.107839, 26.240061},{2.822791, -0.044580, 25.547226}}],
    
    Line[{{2.822791, -0.044580, 25.547226},{2.553445, 0.030293, 24.874681}}],
    Line[{{2.553445, 0.030293, 24.874681},{2.317281, 0.113470, 24.221758}}],
    Line[{{2.317281, 0.113470, 24.221758},{2.111806, 0.202420, 23.587746}}],
    Line[{{2.111806, 0.202420, 23.587746},{1.934554, 0.295274, 22.971937}}],
    Line[{{1.934554, 0.295274, 22.971937},{1.783142, 0.390721, 22.373661}}],
    Line[{{1.783142, 0.390721, 22.373661},{1.655314, 0.487917, 21.792294}}],
    Line[{{1.655314, 0.487917, 21.792294},{1.548966, 0.586400, 21.227264}}],
    Line[{{1.548966, 0.586400, 21.227264},{1.462167, 0.686021, 20.678066}}],
    Line[{{1.462167, 0.686021, 20.678066},{1.393169, 0.786891, 20.144245}}],
    Line[{{1.393169, 0.786891, 20.144245},{1.340411, 0.889328, 19.625402}}],
    Line[{{1.340411, 0.889328, 19.625402},{1.302517, 0.993821, 19.121189}}],
    Line[{{1.302517, 0.993821, 19.121189},{1.278299, 1.100999, 18.631304}}],
    Line[{{1.278299, 1.100999, 18.631304},{1.266746, 1.211609, 18.155495}}],
    Line[{{1.266746, 1.211609, 18.155495},{1.267019, 1.326497, 17.693552}}],
    Line[{{1.267019, 1.326497, 17.693552},{1.278445, 1.446597, 17.245316}}],
    Line[{{1.278445, 1.446597, 17.245316},{1.300506, 1.572926, 16.810673}}],
    Line[{{1.300506, 1.572926, 16.810673},{1.332836, 1.706578, 16.389563}}],
    Line[{{1.332836, 1.706578, 16.389563},{1.375210, 1.848722, 15.981980}}],
    Line[{{1.375210, 1.848722, 15.981980},{1.427541, 2.000609, 15.587989}}],
    Line[{{1.427541, 2.000609, 15.587989},{1.489871, 2.163573, 15.207720}}],
    Line[{{1.489871, 2.163573, 15.207720},{1.562372, 2.339039, 14.841393}}],
    Line[{{1.562372, 2.339039, 14.841393},{1.645339, 2.528526, 14.489319}}],
    Line[{{1.645339, 2.528526, 14.489319},{1.739186, 2.733660, 14.151929}}],
    Line[{{1.739186, 2.733660, 14.151929},{1.844452, 2.956182, 13.829782}}],
    Line[{{1.844452, 2.956182, 13.829782},{1.961794, 3.197950, 13.523596}}],
    Line[{{1.961794, 3.197950, 13.523596},{2.091988, 3.460951, 13.234273}}],
    Line[{{2.091988, 3.460951, 13.234273},{2.235934, 3.747309, 12.962932}}],
    Line[{{2.235934, 3.747309, 12.962932},{2.394654, 4.059276, 12.710947}}],
    Line[{{2.394654, 4.059276, 12.710947},{2.569294, 4.399244, 12.479996}}],
    Line[{{2.569294, 4.399244, 12.479996},{2.761124, 4.769727, 12.272108}}],
    Line[{{2.761124, 4.769727, 12.272108},{2.971538, 5.173345, 12.089739}}],
    Line[{{2.971538, 5.173345, 12.089739},{3.202053, 5.612812, 11.935817}}],
    Line[{{3.202053, 5.612812, 11.935817},{3.454297, 6.090854, 11.813865}}],
    Line[{{3.454297, 6.090854, 11.813865},{3.730010, 6.610215, 11.728032}}],
    Line[{{3.730010, 6.610215, 11.728032},{4.031016, 7.173491, 11.683260}}],
    Line[{{4.031016, 7.173491, 11.683260},{4.359203, 7.783055, 11.685338}}],
    Line[{{4.359203, 7.783055, 11.685338},{4.716491, 8.440900, 11.741035}}],
    Line[{{4.716491, 8.440900, 11.741035},{5.104780, 9.148408, 11.858200}}],
    Line[{{5.104780, 9.148408, 11.858200},{5.525873, 9.906065, 12.045845}}],
    Line[{{5.525873, 9.906065, 12.045845},{5.981400, 10.713150, 12.314205}}],
    Line[{{5.981400, 10.713150, 12.314205},{6.472690, 11.567296, 12.674753}}],
    
    Line[{{6.472690, 11.567296, 12.674753},{7.000616, 12.463950, 13.140101}}],
    
    Line[{{7.000616, 12.463950, 13.140101},{7.565408, 13.395799, 13.723788}}],
    
    Line[{{7.565408, 13.395799, 13.723788},{8.166417, 14.352100, 14.439906}}],
    
    Line[{{8.166417, 14.352100, 14.439906},{8.801839, 15.317978, 15.302475}}],
    
    Line[{{8.801839, 15.317978, 15.302475},{9.468400, 16.273750, 16.324522}}],
    
    Line[{{9.468400, 16.273750, 16.324522},{
      10.161008, 17.194405, 17.516813}}],
    Line[{{10.161008, 17.194405, 17.516813},{
      10.872406, 18.049330, 18.886227}}],
    Line[{{10.872406, 18.049330, 18.886227},{
      11.592850, 18.802561, 20.433750}}],
    Line[{{11.592850, 18.802561, 20.433750},{
      12.309873, 19.413662, 22.152313}}],
    Line[{{12.309873, 19.413662, 22.152313},{
      13.008202, 19.839550, 24.024546}}],
    Line[{{13.008202, 19.839550, 24.024546},{
      13.669897, 20.037312, 26.020960}}],
    Line[{{13.669897, 20.037312, 26.020960},{
      14.274802, 19.968054, 28.098955}}],
    Line[{{14.274802, 19.968054, 28.098955},{
      14.801357, 19.601498, 30.203194}}],
    Line[{{14.801357, 19.601498, 30.203194},{
      15.227782, 18.920778, 32.267792}}],
    Line[{{15.227782, 18.920778, 32.267792},{
      15.533588, 17.926605, 34.220535}}],
    Line[{{15.533588, 17.926605, 34.220535},{
      15.701268, 16.639860, 35.988811}}],
    Line[{{15.701268, 16.639860, 35.988811},{
      15.717963, 15.101742, 37.506622}}],
    Line[{{15.717963, 15.101742, 37.506622},{
      15.576843, 13.371061, 38.721436}}],
    Line[{{15.576843, 13.371061, 38.721436},{
      15.277965, 11.518883, 39.599537}}],
    Line[{{15.277965, 11.518883, 39.599537},{
      14.828464, 9.621433, 40.128986}}],
    Line[{{14.828464, 9.621433, 40.128986},{14.241981, 7.752431, 40.319370}}],
    
    Line[{{14.241981, 7.752431, 40.319370},{13.537475, 5.976416, 40.198826}}],
    
    Line[{{13.537475, 5.976416, 40.198826},{12.737602, 4.343986, 39.809048}}],
    
    Line[{{12.737602, 4.343986, 39.809048},{11.866898, 2.889564, 39.199337}}],
    
    Line[{{11.866898, 2.889564, 39.199337},{10.950053, 1.631458, 38.421009}}],
    
    Line[{{10.950053, 1.631458, 38.421009},{10.010443, 0.573762, 37.522781}}],
    
    Line[{{10.010443, 0.573762, 37.522781},{9.069036, -0.290686, 36.547649}}],
    
    Line[{{9.069036, -0.290686, 36.547649},{8.143721, -0.976994, 35.531235}}],
    
    Line[{{8.143721, -0.976994, 35.531235},{7.248971, -1.505081, 34.501335}}],
    
    Line[{{7.248971, -1.505081, 34.501335},{6.395880, -1.897075, 33.478451}}],
    
    Line[{{6.395880, -1.897075, 33.478451},{5.592349, -2.175341, 32.476715}}],
    
    Line[{{5.592349, -2.175341, 32.476715},{4.843444, -2.361127, 31.505110}}],
    
    Line[{{4.843444, -2.361127, 31.505110},{4.151815, -2.473755, 30.568661}}],
    
    Line[{{4.151815, -2.473755, 30.568661},{3.518133, -2.530221, 29.669523}}],
    
    Line[{{3.518133, -2.530221, 29.669523},{2.941504, -2.545081, 28.807890}}],
    
    Line[{{2.941504, -2.545081, 28.807890},{2.419849, -2.530540, 27.982698}}],
    
    Line[{{2.419849, -2.530540, 27.982698},{1.950233, -2.496639, 27.192169}}],
    
    Line[{{1.950233, -2.496639, 27.192169},{1.529139, -2.451507, 26.434172}}],
    
    Line[{{1.529139, -2.451507, 26.434172},{1.152692, -2.401623, 25.706484}}],
    
    Line[{{1.152692, -2.401623, 25.706484},{0.816838, -2.352080, 25.006952}}],
    
    Line[{{0.816838, -2.352080, 25.006952},{0.517483, -2.306820, 24.333584}}],
    
    Line[{{0.517483, -2.306820, 24.333584},{0.250593, -2.268856, 23.684595}}],
    
    Line[{{0.250593, -2.268856, 23.684595},{0.012270, -2.240457, 23.058422}}],
    
    Line[{{
      0.012270, -2.240457, 23.058422},{-0.201201, -2.223310, 22.453728}}],
    Line[{{-0.201201, -2.223310, 22.453728},{-0.393321, -2.218660, 
        21.869373}}],
    Line[{{-0.393321, -2.218660, 21.869373},{-0.567356, -2.227425, 
        21.304413}}],
    Line[{{-0.567356, -2.227425, 21.304413},{-0.726340, -2.250290, 
        20.758068}}],
    Line[{{-0.726340, -2.250290, 20.758068},{-0.873073, -2.287789, 
        20.229712}}],
    Line[{{-0.873073, -2.287789, 20.229712},{-1.010136, -2.340366, 
        19.718851}}],
    Line[{{-1.010136, -2.340366, 19.718851},{-1.139905, -2.408432, 
        19.225117}}],
    Line[{{-1.139905, -2.408432, 19.225117},{-1.264568, -2.492407, 
        18.748255}}],
    Line[{{-1.264568, -2.492407, 18.748255},{-1.386146, -2.592754, 
        18.288122}}],
    Line[{{-1.386146, -2.592754, 18.288122},{-1.506517, -2.710006, 
        17.844685}}],
    Line[{{-1.506517, -2.710006, 17.844685},{-1.627434, -2.844788, 
        17.418018}}],
    Line[{{-1.627434, -2.844788, 17.418018},{-1.750547, -2.997833, 
        17.008320}}],
    Line[{{-1.750547, -2.997833, 17.008320},{-1.877427, -3.170000, 
        16.615915}}],
    Line[{{-1.877427, -3.170000, 16.615915},{-2.009582, -3.362277, 
        16.241272}}],
    Line[{{-2.009582, -3.362277, 16.241272},{-2.148476, -3.575797, 
        15.885015}}],
    Line[{{-2.148476, -3.575797, 15.885015},{-2.295551, -3.811828, 
        15.547956}}],
    Line[{{-2.295551, -3.811828, 15.547956},{-2.452238, -4.071789, 
        15.231110}}],
    Line[{{-2.452238, -4.071789, 15.231110},{-2.619974, -4.357234, 
        14.935733}}],
    Line[{{-2.619974, -4.357234, 14.935733},{-2.800213, -4.669845, 
        14.663362}}],
    Line[{{-2.800213, -4.669845, 14.663362},{-2.994437, -5.011426, 
        14.415844}}],
    Line[{{-2.994437, -5.011426, 14.415844},{-3.204162, -5.383867, 
        14.195406}}],
    Line[{{-3.204162, -5.383867, 14.195406},{-3.430945, -5.789122, 
        14.004692}}],
    Line[{{-3.430945, -5.789122, 14.004692},{-3.676382, -6.229162, 
        13.846830}}],
    Line[{{-3.676382, -6.229162, 13.846830},{-3.942097, -6.705897, 
        13.725512}}],
    Line[{{-3.942097, -6.705897, 13.725512},{-4.229746, -7.221127, 
        13.645041}}],
    Line[{{-4.229746, -7.221127, 13.645041},{-4.540980, -7.776396, 
        13.610430}}],
    Line[{{-4.540980, -7.776396, 13.610430},{-4.877425, -8.372871, 
        13.627460}}],
    Line[{{-4.877425, -8.372871, 13.627460},{-5.240638, -9.011162, 
        13.702751}}],
    Line[{{-5.240638, -9.011162, 13.702751},{-5.632052, -9.691094, 
        13.843801}}],
    Line[{{-5.632052, -9.691094, 13.843801},{-6.052893, -10.411425, 
        14.059011}}],
    Line[{{-6.052893, -10.411425, 14.059011},{-6.504088, -11.169524, 
        14.357641}}],
    Line[{{-6.504088, -11.169524, 14.357641},{-6.986152, -11.960992, 
        14.749731}}],
    Line[{{-6.986152, -11.960992, 14.749731},{-7.499019, -12.779203, 
        15.245893}}],
    Line[{{-7.499019, -12.779203, 15.245893},{-8.041874, -13.614833, 
        15.856956}}],
    Line[{{-8.041874, -13.614833, 15.856956},{-8.612942, -14.455389, 
        16.593483}}],
    Line[{{-8.612942, -14.455389, 16.593483},{-9.209263, -15.284756, 
        17.465124}}],
    Line[{{-9.209263, -15.284756, 17.465124},{-9.826427, -16.082869, 
        18.479549}}],
    Line[{{-9.826427, -16.082869, 18.479549},{-10.458341, -16.825596, 
        19.641382}}],
    Line[{{-10.458341, -16.825596, 19.641382},{-11.097005, -17.484943, 
        20.950748}}],
    Line[{{-11.097005, -17.484943, 20.950748},{-11.732353, -18.029743, 
        22.401775}}],
    Line[{{-11.732353, -18.029743, 22.401775},{-12.352209, -18.426907, 
        23.981064}}],
    Line[{{-12.352209, -18.426907, 23.981064},{-12.942386, -18.643375, 
        25.666430}}],
    Line[{{-12.942386, -18.643375, 25.666430},{-13.487003, -18.648716, 
        27.426176}}],
    Line[{{-13.487003, -18.648716, 27.426176},{-13.969052, -18.418228, 
        29.219219}}],
    Line[{{-13.969052, -18.418228, 29.219219},{-14.371202, -17.936258, 
        30.996382}}],
    Line[{{-14.371202, -17.936258, 30.996382},{-14.676839, -17.199192, 
        32.702957}}],
    Line[{{-14.676839, -17.199192, 32.702957},{-14.871266, -16.217600, 
        34.282516}}],
    Line[{{-14.871266, -16.217600, 34.282516},{-14.942909, -15.016926, 
        35.681522}}],
    Line[{{-14.942909, -15.016926, 35.681522},{-14.884403, -13.636427, 
        36.854168}}],
    Line[{{-14.884403, -13.636427, 36.854168},{-14.693377, -12.126228, 
        37.766628}}],
    Line[{{-14.693377, -12.126228, 37.766628},{-14.372805, -10.542945, 
        38.399914}}],
    Line[{{-14.372805, -10.542945, 38.399914},{-13.930875, -8.944561, 
        38.750935}}],
    Line[{{-13.930875, -8.944561, 38.750935},{-13.380377, -7.385363, 
        38.831577}}],
    Line[{{-13.380377, -7.385363, 38.831577},{-12.737694, -5.911778, 
        38.666084}}],
    Line[{{-12.737694, -5.911778, 38.666084},{-12.021568, -4.559627, 
        38.287411}}],
    Line[{{-12.021568, -4.559627, 38.287411},{-11.251807, -3.352968, 
        37.733212}}],
    Line[{{-11.251807, -3.352968, 37.733212},{-10.448058, -2.304433, 
        37.042091}}],
    Line[{{-10.448058, -2.304433, 37.042091},{-9.628801, -1.416625, 
        36.250645}}],
    Line[{{-9.628801, -1.416625, 36.250645},{-8.810605, -0.684159, 
        35.391388}}],
    Line[{{-8.810605, -0.684159, 35.391388},{-8.007650, -0.095913, 
        34.491684}}],
    Line[{{-8.007650, -0.095913, 34.491684},{-7.231521, 0.362845, 
        33.573399}}],
    Line[{{-7.231521, 0.362845, 33.573399},{-6.491195, 0.708648, 32.653168}}],
    
    Line[{{-6.491195, 0.708648, 32.653168},{-5.793195, 0.958417, 31.743027}}],
    
    Line[{{-5.793195, 0.958417, 31.743027},{-5.141837, 1.128464, 30.851152}}],
    
    Line[{{-5.141837, 1.128464, 30.851152},{-4.539527, 1.233844, 29.982697}}],
    
    Line[{{-4.539527, 1.233844, 29.982697},{-3.987088, 1.288005, 29.140522}}],
    
    Line[{{-3.987088, 1.288005, 29.140522},{-3.484070, 1.302638, 28.325850}}],
    
    Line[{{-3.484070, 1.302638, 28.325850},{-3.029035, 1.287687, 27.538769}}],
    
    Line[{{-3.029035, 1.287687, 27.538769},{-2.619819, 1.251439, 26.778656}}],
    
    Line[{{-2.619819, 1.251439, 26.778656},{-2.253749, 1.200685, 26.044456}}],
    
    Line[{{-2.253749, 1.200685, 26.044456},{-1.927825, 1.140887, 25.334913}}],
    
    Line[{{-1.927825, 1.140887, 25.334913},{-1.638869, 1.076365, 24.648687}}],
    
    Line[{{-1.638869, 1.076365, 24.648687},{-1.383644, 1.010472, 23.984472}}],
    
    Line[{{-1.383644, 1.010472, 23.984472},{-1.158941, 0.945751, 23.341024}}],
    
    Line[{{-1.158941, 0.945751, 23.341024},{-0.961648, 0.884086, 22.717207}}],
    
    Line[{{-0.961648, 0.884086, 22.717207},{-0.788795, 0.826826, 22.111990}}],
    
    Line[{{-0.788795, 0.826826, 22.111990},{-0.637591, 0.774897, 21.524448}}],
    
    Line[{{-0.637591, 0.774897, 21.524448},{-0.505437, 0.728895, 20.953764}}],
    
    Line[{{-0.505437, 0.728895, 20.953764},{-0.389936, 0.689162, 20.399204}}],
    
    Line[{{-0.389936, 0.689162, 20.399204},{-0.288899, 0.655855, 19.860115}}],
    
    Line[{{-0.288899, 0.655855, 19.860115},{-0.200336, 0.628997, 19.335917}}],
    
    Line[{{-0.200336, 0.628997, 19.335917},{-0.122447, 0.608522, 18.826077}}],
    
    Line[{{-0.122447, 0.608522, 18.826077},{-0.053616, 0.594310, 18.330114}}],
    
    Line[{{-0.053616, 0.594310, 18.330114},{0.007608, 0.586214, 17.847593}}],
    Line[{{0.007608, 0.586214, 17.847593},{0.062525, 0.584081, 17.378107}}],
    Line[{{0.062525, 0.584081, 17.378107},{0.112295, 0.587772, 16.921278}}],
    Line[{{0.112295, 0.587772, 16.921278},{0.157957, 0.597176, 16.476755}}],
    Line[{{0.157957, 0.597176, 16.476755},{0.200442, 0.612217, 16.044210}}],
    Line[{{0.200442, 0.612217, 16.044210},{0.240585, 0.632862, 15.623333}}],
    Line[{{0.240585, 0.632862, 15.623333},{0.279145, 0.659132, 15.213834}}],
    Line[{{0.279145, 0.659132, 15.213834},{0.316810, 0.691104, 14.815440}}],
    Line[{{0.316810, 0.691104, 14.815440},{0.354214, 0.728913, 14.427896}}],
    Line[{{0.354214, 0.728913, 14.427896},{0.391948, 0.772761, 14.050963}}],
    Line[{{0.391948, 0.772761, 14.050963},{0.430565, 0.822914, 13.684424}}],
    Line[{{0.430565, 0.822914, 13.684424},{0.470600, 0.879714, 13.328078}}],
    Line[{{0.470600, 0.879714, 13.328078},{0.512567, 0.943576, 12.981748}}],
    Line[{{0.512567, 0.943576, 12.981748},{0.556980, 1.014992, 12.645275}}],
    Line[{{0.556980, 1.014992, 12.645275},{0.604351, 1.094544, 12.318535}}],
    Line[{{0.604351, 1.094544, 12.318535},{0.655206, 1.182899, 12.001425}}],
    Line[{{0.655206, 1.182899, 12.001425},{0.710086, 1.280824, 11.693882}}],
    Line[{{0.710086, 1.280824, 11.693882},{0.769560, 1.389186, 11.395880}}],
    Line[{{0.769560, 1.389186, 11.395880},{0.834231, 1.508966, 11.107440}}],
    Line[{{0.834231, 1.508966, 11.107440},{0.904743, 1.641266, 10.828639}}],
    Line[{{0.904743, 1.641266, 10.828639},{0.981790, 1.787316, 10.559616}}],
    Line[{{0.981790, 1.787316, 10.559616},{1.066125, 1.948489, 10.300589}}],
    Line[{{1.066125, 1.948489, 10.300589},{1.158566, 2.126312, 10.051868}}],
    Line[{{1.158566, 2.126312, 10.051868},{1.260005, 2.322475, 9.813871}}],
    Line[{{1.260005, 2.322475, 9.813871},{1.371422, 2.538851, 9.587152}}],
    Line[{{1.371422, 2.538851, 9.587152},{1.493889, 2.777500, 9.372418}}],
    Line[{{1.493889, 2.777500, 9.372418},{1.628581, 3.040693, 9.170576}}],
    Line[{{1.628581, 3.040693, 9.170576},{1.776790, 3.330912, 8.982748}}],
    Line[{{1.776790, 3.330912, 8.982748},{1.939930, 3.650869, 8.810356}}],
    Line[{{1.939930, 3.650869, 8.810356},{2.119552, 4.003512, 8.655131}}],
    Line[{{2.119552, 4.003512, 8.655131},{2.317349, 4.392016, 8.519236}}],
    Line[{{2.317349, 4.392016, 8.519236},{2.535168, 4.819796, 8.405281}}],
    Line[{{2.535168, 4.819796, 8.405281},{2.775015, 5.290465, 8.316492}}],
    Line[{{2.775015, 5.290465, 8.316492},{3.039056, 5.807807, 8.256780}}],
    Line[{{3.039056, 5.807807, 8.256780},{3.329621, 6.375738, 8.230865}}],
    Line[{{3.329621, 6.375738, 8.230865},{3.649189, 6.998184, 8.244460}}],
    Line[{{3.649189, 6.998184, 8.244460},{4.000376, 7.678974, 8.304419}}],
    Line[{{4.000376, 7.678974, 8.304419},{4.385898, 8.421639, 8.418922}}],
    Line[{{4.385898, 8.421639, 8.418922},{4.808528, 9.229171, 8.597677}}],
    Line[{{4.808528, 9.229171, 8.597677},{5.271018, 10.103655, 8.852108}}],
    Line[{{5.271018, 10.103655, 8.852108},{5.775990, 11.045809, 9.195516}}],
    Line[{{5.775990, 11.045809, 9.195516},{6.325801, 12.054395, 9.643198}}],
    Line[{{6.325801, 12.054395, 9.643198},{6.922342, 13.125479, 10.212466}}],
    Line[{{6.922342, 13.125479, 10.212466},{7.566784, 14.251487, 10.922495}}],
    
    Line[{{7.566784, 14.251487, 10.922495},{8.259238, 15.420110, 11.793886}}],
    
    Line[{{8.259238, 15.420110, 11.793886},{8.998362, 16.613138, 12.847930}}],
    
    Line[{{8.998362, 16.613138, 12.847930},{9.780869, 17.805195, 14.105330}}],
    
    Line[{{9.780869, 17.805195, 14.105330},{
      10.600984, 18.962635, 15.584336}}],
    Line[{{10.600984, 18.962635, 15.584336},{
      11.449839, 20.042807, 17.298166}}],
    Line[{{11.449839, 20.042807, 17.298166},{
      12.314918, 20.994064, 19.251722}}],
    Line[{{12.314918, 20.994064, 19.251722},{
      13.179581, 21.756918, 21.437767}}],
    Line[{{13.179581, 21.756918, 21.437767},{
      14.022841, 22.266916, 23.832922}}],
    Line[{{14.022841, 22.266916, 23.832922},{
      14.819523, 22.459377, 26.394270}}],
    Line[{{14.819523, 22.459377, 26.394270},{
      15.540944, 22.276186, 29.057480}}],
    Line[{{15.540944, 22.276186, 29.057480},{
      16.156263, 21.674007, 31.737511}}],
    Line[{{16.156263, 21.674007, 31.737511},{
      16.634518, 20.632872, 34.333008}}],
    Line[{{16.634518, 20.632872, 34.333008},{
      16.947216, 19.163160, 36.734547}}],
    Line[{{16.947216, 19.163160, 36.734547},{
      17.071201, 17.309113, 38.836006}}],
    Line[{{17.071201, 17.309113, 38.836006},{
      16.991316, 15.147163, 40.547302}}],
    Line[{{16.991316, 15.147163, 40.547302},{
      16.702406, 12.778689, 41.805740}}],
    Line[{{16.702406, 12.778689, 41.805740},{
      16.210213, 10.318386, 42.583370}}],
    Line[{{16.210213, 10.318386, 42.583370},{
      15.530926, 7.880490, 42.888580}}],
    Line[{{15.530926, 7.880490, 42.888580},{14.689521, 5.566054, 42.761902}}],
    
    Line[{{14.689521, 5.566054, 42.761902},{13.717183, 3.453679, 42.267326}}],
    
    Line[{{13.717183, 3.453679, 42.267326},{12.648323, 1.595064, 41.481667}}],
    
    Line[{{12.648323, 1.595064, 41.481667},{11.517687, 0.015188, 40.484253}}],
    
    Line[{{11.517687, 0.015188, 40.484253},{
      10.357939, -1.283963, 39.348816}}],
    Line[{{10.357939, -1.283963, 39.348816},{
      9.197935, -2.317790, 38.138294}}],
    Line[{{9.197935, -2.317790, 38.138294},{8.061724, -3.113057, 36.902508}}],
    
    Line[{{8.061724, -3.113057, 36.902508},{6.968190, -3.702501, 35.678108}}],
    
    Line[{{6.968190, -3.702501, 35.678108},{5.931192, -4.120614, 34.489967}}],
    
    Line[{{5.931192, -4.120614, 34.489967},{4.960026, -4.400726, 33.353298}}],
    
    Line[{{4.960026, -4.400726, 33.353298},{4.060061, -4.573224, 32.275955}}],
    
    Line[{{4.060061, -4.573224, 32.275955},{3.233445, -4.664685, 31.260534}}],
    
    Line[{{3.233445, -4.664685, 31.260534},{2.479788, -4.697637, 30.306145}}],
    
    Line[{{2.479788, -4.697637, 30.306145},{1.796785, -4.690701, 29.409800}}],
    
    Line[{{1.796785, -4.690701, 29.409800},{1.180750, -4.658968, 28.567417}}],
    
    Line[{{1.180750, -4.658968, 28.567417},{0.627067, -4.614457, 27.774508}}],
    
    Line[{{0.627067, -4.614457, 27.774508},{0.130543, -4.566600, 27.026644}}],
    
    Line[{{
      0.130543, -4.566600, 27.026644},{-0.314313, -4.522693, 26.319719}}],
    Line[{{-0.314313, -4.522693, 26.319719},{-0.713073, -4.488307, 
        25.650093}}],
    Line[{{-0.713073, -4.488307, 25.650093},{-1.071245, -4.467636, 
        25.014648}}],
    Line[{{-1.071245, -4.467636, 25.014648},{-1.394156, -4.463799, 
        24.410801}}],
    Line[{{-1.394156, -4.463799, 24.410801},{-1.686879, -4.479085, 
        23.836475}}],
    Line[{{-1.686879, -4.479085, 23.836475},{-1.954193, -4.515156, 
        23.290060}}],
    Line[{{-1.954193, -4.515156, 23.290060},{-2.200554, -4.573210, 
        22.770372}}],
    Line[{{-2.200554, -4.573210, 22.770372},{-2.430094, -4.654112, 
        22.276602}}],
    Line[{{-2.430094, -4.654112, 22.276602},{-2.646619, -4.758497, 
        21.808289}}],
    Line[{{-2.646619, -4.758497, 21.808289},{-2.853627, -4.886851, 
        21.365280}}],
    Line[{{-2.853627, -4.886851, 21.365280},{-3.054326, -5.039570, 
        20.947720}}],
    Line[{{-3.054326, -5.039570, 20.947720},{-3.251652, -5.217003, 
        20.556023}}],
    Line[{{-3.251652, -5.217003, 20.556023},{-3.448293, -5.419481, 
        20.190874}}],
    Line[{{-3.448293, -5.419481, 20.190874},{-3.646715, -5.647328, 
        19.853228}}],
    Line[{{-3.646715, -5.647328, 19.853228},{-3.849177, -5.900867, 
        19.544310}}],
    Line[{{-3.849177, -5.900867, 19.544310},{-4.057756, -6.180412, 
        19.265627}}],
    Line[{{-4.057756, -6.180412, 19.265627},{-4.274359, -6.486241, 
        19.018980}}],
    Line[{{-4.274359, -6.486241, 19.018980},{-4.500734, -6.818569, 
        18.806482}}],
    Line[{{-4.500734, -6.818569, 18.806482},{-4.738479, -7.177499, 
        18.630568}}],
    Line[{{-4.738479, -7.177499, 18.630568},{-4.989042, -7.562970, 
        18.494011}}],
    Line[{{-4.989042, -7.562970, 18.494011},{-5.253719, -7.974684, 
        18.399937}}],
    Line[{{-5.253719, -7.974684, 18.399937},{-5.533634, -8.412005, 
        18.351816}}],
    Line[{{-5.533634, -8.412005, 18.351816},{-5.829727, -8.873882, 
        18.353472}}],
    Line[{{-5.829727, -8.873882, 18.353472},{-6.142726, -9.358713, 
        18.409042}}],
    Line[{{-6.142726, -9.358713, 18.409042},{-6.473097, -9.864206, 
        18.522938}}],
    Line[{{-6.473097, -9.864206, 18.522938},{-6.821012, -10.387254, 
        18.699770}}],
    Line[{{-6.821012, -10.387254, 18.699770},{-7.186285, -10.923759, 
        18.944252}}],
    Line[{{-7.186285, -10.923759, 18.944252},{-7.568295, -11.468478, 
        19.260996}}],
    Line[{{-7.568295, -11.468478, 19.260996},{-7.965931, -12.014882, 
        19.654364}}],
    Line[{{-7.965931, -12.014882, 19.654364},{-8.377492, -12.555010, 
        20.128176}}],
    Line[{{-8.377492, -12.555010, 20.128176},{-8.800609, -13.079412, 
        20.685329}}],
    Line[{{-8.800609, -13.079412, 20.685329},{-9.232168, -13.577111, 
        21.327477}}],
    Line[{{-9.232168, -13.577111, 21.327477},{-9.668232, -14.035657, 
        22.054541}}],
    Line[{{-9.668232, -14.035657, 22.054541},{-10.103992, -14.441403, 
        22.864197}}],
    Line[{{-10.103992, -14.441403, 22.864197},{-10.533758, -14.779810, 
        23.751434}}],
    Line[{{-10.533758, -14.779810, 23.751434},{-10.950971, -15.036000, 
        24.708103}}],
    Line[{{-10.950971, -15.036000, 24.708103},{-11.348290, -15.195454, 
        25.722582}}],
    Line[{{-11.348290, -15.195454, 25.722582},{-11.717749, -15.244913, 
        26.779629}}],
    Line[{{-11.717749, -15.244913, 26.779629},{-12.050974, -15.173373, 
        27.860491}}],
    Line[{{-12.050974, -15.173373, 27.860491},{-12.339493, -14.973120, 
        28.943321}}],
    Line[{{-12.339493, -14.973120, 28.943321},{-12.575109, -14.640689, 
        30.003948}}],
    Line[{{-12.575109, -14.640689, 30.003948},{-12.750309, -14.177618, 
        31.016966}}],
    Line[{{-12.750309, -14.177618, 31.016966},{-12.858703, -13.590919, 
        31.957048}}],
    Line[{{-12.858703, -13.590919, 31.957048},{-12.895444, -12.893026, 
        32.800537}}],
    Line[{{-12.895444, -12.893026, 32.800537},{-12.857574, -12.101336, 
        33.526871}}],
    Line[{{-12.857574, -12.101336, 33.526871},{-12.744276, -11.237251, 
        34.119896}}],
    Line[{{-12.744276, -11.237251, 34.119896},{-12.556989, -10.324843, 
        34.568798}}],
    Line[{{-12.556989, -10.324843, 34.568798},{-12.299372, -9.389291, 
        34.868576}}],
    Line[{{-12.299372, -9.389291, 34.868576},{-11.977118, -8.455280, 
        35.019989}}],
    Line[{{-11.977118, -8.455280, 35.019989},{-11.597651, -7.545550, 
        35.029026}}],
    Line[{{-11.597651, -7.545550, 35.029026},{-11.169701, -6.679736, 
        34.906013}}],
    Line[{{-11.169701, -6.679736, 34.906013},{-10.702858, -5.873595, 
        34.664455}}],
    Line[{{-10.702858, -5.873595, 34.664455},{-10.207094, -5.138672, 
        34.319839}}],
    Line[{{-10.207094, -5.138672, 34.319839},{-9.692329, -4.482316, 
        33.888477}}],
    Line[{{-9.692329, -4.482316, 33.888477},{-9.168044, -3.908013, 
        33.386517}}],
    Line[{{-9.168044, -3.908013, 33.386517},{-8.642987, -3.415944, 
        32.829201}}],
    Line[{{-8.642987, -3.415944, 32.829201},{-8.124958, -3.003632, 
        32.230316}}],
    Line[{{-8.124958, -3.003632, 32.230316},{-7.620675, -2.666630, 
        31.601938}}],
    Line[{{-7.620675, -2.666630, 31.601938},{-7.135725, -2.399170, 
        30.954296}}],
    Line[{{-7.135725, -2.399170, 30.954296},{-6.674576, -2.194725, 
        30.295841}}],
    Line[{{-6.674576, -2.194725, 30.295841},{-6.240631, -2.046483, 
        29.633375}}],
    Line[{{-6.240631, -2.046483, 29.633375},{-5.836322, -1.947699, 
        28.972252}}],
    Line[{{-5.836322, -1.947699, 28.972252},{-5.463223, -1.891967, 
        28.316597}}],
    Line[{{-5.463223, -1.891967, 28.316597},{-5.122169, -1.873394, 
        27.669519}}],
    Line[{{-5.122169, -1.873394, 27.669519},{-4.813388, -1.886706, 
        27.033331}}],
    Line[{{-4.813388, -1.886706, 27.033331},{-4.536615, -1.927303, 
        26.409718}}],
    Line[{{-4.536615, -1.927303, 26.409718},{-4.291205, -1.991265, 
        25.799898}}],
    Line[{{-4.291205, -1.991265, 25.799898},{-4.076235, -2.075335, 
        25.204746}}],
    Line[{{-4.076235, -2.075335, 25.204746},{-3.890589, -2.176881, 
        24.624899}}],
    Line[{{-3.890589, -2.176881, 24.624899},{-3.733036, -2.293847, 
        24.060829}}],
    Line[{{-3.733036, -2.293847, 24.060829},{-3.602290, -2.424700, 
        23.512917}}],
    Line[{{-3.602290, -2.424700, 23.512917},{-3.497068, -2.568372, 
        22.981493}}],
    Line[{{-3.497068, -2.568372, 22.981493},{-3.416127, -2.724209, 
        22.466875}}],
    Line[{{-3.416127, -2.724209, 22.466875},{-3.358295, -2.891916, 
        21.969398}}],
    Line[{{-3.358295, -2.891916, 21.969398},{-3.322502, -3.071512, 
        21.489449}}],
    Line[{{-3.322502, -3.071512, 21.489449},{-3.307794, -3.263288, 
        21.027462}}],
    Line[{{-3.307794, -3.263288, 21.027462},{-3.313348, -3.467770, 
        20.583969}}],
    Line[{{-3.313348, -3.467770, 20.583969},{-3.338476, -3.685685, 
        20.159590}}],
    Line[{{-3.338476, -3.685685, 20.159590},{-3.382638, -3.917927, 
        19.755068}}],
    Line[{{-3.382638, -3.917927, 19.755068},{-3.445436, -4.165534, 
        19.371283}}],
    Line[{{-3.445436, -4.165534, 19.371283},{-3.526610, -4.429664, 
        19.009275}}],
    Line[{{-3.526610, -4.429664, 19.009275},{-3.626048, -4.711560, 
        18.670259}}],
    Line[{{-3.626048, -4.711560, 18.670259},{-3.743762, -5.012538, 
        18.355661}}],
    Line[{{-3.743762, -5.012538, 18.355661},{-3.879895, -5.333946, 
        18.067141}}],
    Line[{{-3.879895, -5.333946, 18.067141},{-4.034705, -5.677143, 
        17.806616}}],
    Line[{{-4.034705, -5.677143, 17.806616},{-4.208550, -6.043450, 
        17.576309}}],
    Line[{{-4.208550, -6.043450, 17.576309},{-4.401883, -6.434116, 
        17.378761}}],
    Line[{{-4.401883, -6.434116, 17.378761},{-4.615220, -6.850259, 
        17.216883}}],
    Line[{{-4.615220, -6.850259, 17.216883},{-4.849127, -7.292786, 
        17.093977}}],
    Line[{{-4.849127, -7.292786, 17.093977},{-5.104194, -7.762335, 
        17.013771}}],
    Line[{{-5.104194, -7.762335, 17.013771},{-5.380992, -8.259158, 
        16.980440}}],
    Line[{{-5.380992, -8.259158, 16.980440},{-5.680040, -8.782988, 
        16.998611}}],
    Line[{{-5.680040, -8.782988, 16.998611},{-6.001756, -9.332939, 
        17.073374}}],
    Line[{{-6.001756, -9.332939, 17.073374},{-6.346390, -9.907292, 
        17.210228}}],
    Line[{{-6.346390, -9.907292, 17.210228},{-6.713960, -10.503332, 
        17.415028}}],
    Line[{{-6.713960, -10.503332, 17.415028},{-7.104174, -11.117153, 
        17.693905}}],
    Line[{{-7.104174, -11.117153, 17.693905},{-7.516315, -11.743394, 
        18.053020}}],
    Line[{{-7.516315, -11.743394, 18.053020},{-7.949159, -12.375073, 
        18.498419}}],
    Line[{{-7.949159, -12.375073, 18.498419},{-8.400842, -13.003337, 
        19.035677}}],
    Line[{{-8.400842, -13.003337, 19.035677},{-8.868733, -13.617325, 
        19.669426}}],
    Line[{{-8.868733, -13.617325, 19.669426},{-9.349325, -14.204086, 
        20.402918}}],
    Line[{{-9.349325, -14.204086, 20.402918},{-9.838104, -14.748594, 
        21.237391}}],
    Line[{{-9.838104, -14.748594, 21.237391},{-10.329467, -15.233961, 
        22.171383}}],
    Line[{{-10.329467, -15.233961, 22.171383},{-10.816662, -15.641860, 
        23.200027}}],
    Line[{{-10.816662, -15.641860, 23.200027},{-11.291790, -15.953194, 
        24.314404}}],
    Line[{{-11.291790, -15.953194, 24.314404},{-11.745889, -16.149031, 
        25.500982}}],
    Line[{{-11.745889, -16.149031, 25.500982},{-12.169103, -16.211832, 
        26.741333}}],
    Line[{{-12.169103, -16.211832, 26.741333},{-12.550968, -16.126837, 
        28.012186}}],
    Line[{{-12.550968, -16.126837, 28.012186},{-12.880807, -15.883581, 
        29.285940}}],
    Line[{{-12.880807, -15.883581, 29.285940},{-13.148229, -15.477306, 
        30.531708}}],
    Line[{{-13.148229, -15.477306, 30.531708},{-13.343699, -14.910087, 
        31.716852}}],
    Line[{{-13.343699, -14.910087, 31.716852},{-13.459151, -14.191463, 
        32.808952}}],
    Line[{{-13.459151, -14.191463, 32.808952},{-13.488558, -13.338433, 
        33.777969}}],
    Line[{{-13.488558, -13.338433, 33.777969},{-13.428410, -12.374631, 
        34.598408}}],
    Line[{{-13.428410, -12.374631, 34.598408},{-13.278050, -11.328885, 
        35.251099}}],
    Line[{{-13.278050, -11.328885, 35.251099},{-13.039799, -10.233181, 
        35.724415}}],
    Line[{{-13.039799, -10.233181, 35.724415},{-12.718857, -9.120353, 
        36.014763}}],
    Line[{{-12.718857, -9.120353, 36.014763},{-12.323004, -8.021797, 
        36.126244}}],
    Line[{{-12.323004, -8.021797, 36.126244},{-11.862113, -6.965508, 
        36.069664}}],
    Line[{{-11.862113, -6.965508, 36.069664},{-11.347561, -5.974618, 
        35.861046}}],
    Line[{{-11.347561, -5.974618, 35.861046},{-10.791568, -5.066589, 
        35.519855}}],
    Line[{{-10.791568, -5.066589, 35.519855},{-10.206572, -4.252995, 
        35.067287}}],
    Line[{{-10.206572, -4.252995, 35.067287},{-9.604652, -3.539870, 
        34.524681}}],
    Line[{{-9.604652, -3.539870, 34.524681},{-8.997076, -2.928399, 
        33.912327}}],
    Line[{{-8.997076, -2.928399, 33.912327},{-8.393949, -2.415855, 
        33.248581}}],
    Line[{{-8.393949, -2.415855, 33.248581},{-7.804009, -1.996593, 
        32.549393}}],
    Line[{{-7.804009, -1.996593, 32.549393},{-7.234524, -1.663002, 
        31.828121}}],
    Line[{{-7.234524, -1.663002, 31.828121},{-6.691284, -1.406356, 
        31.095570}}],
    Line[{{-6.691284, -1.406356, 31.095570},{-6.178671, -1.217494, 
        30.360216}}],
    Line[{{-6.178671, -1.217494, 30.360216},{-5.699781, -1.087349, 
        29.628502}}],
    Line[{{-5.699781, -1.087349, 29.628502},{-5.256572, -1.007324, 
        28.905167}}],
    Line[{{-5.256572, -1.007324, 28.905167},{-4.850030, -0.969537, 
        28.193577}}],
    Line[{{-4.850030, -0.969537, 28.193577},{-4.480339, -0.966960, 
        27.496029}}],
    Line[{{-4.480339, -0.966960, 27.496029},{-4.147039, -0.993476, 
        26.814014}}],
    Line[{{-4.147039, -0.993476, 26.814014},{-3.849177, -1.043882, 
        26.148434}}],
    Line[{{-3.849177, -1.043882, 26.148434},{-3.585437, -1.113850, 
        25.499767}}],
    Line[{{-3.585437, -1.113850, 25.499767},{-3.354259, -1.199866, 
        24.868221}}],
    Line[{{-3.354259, -1.199866, 24.868221},{-3.153929, -1.299157, 
        24.253819}}],
    Line[{{-3.153929, -1.299157, 24.253819},{-2.982669, -1.409604, 
        23.656475}}],
    Line[{{-2.982669, -1.409604, 23.656475},{-2.838695, -1.529670, 
        23.076061}}],
    Line[{{-2.838695, -1.529670, 23.076061},{-2.720272, -1.658319, 
        22.512436}}],
    Line[{{-2.720272, -1.658319, 22.512436},{-2.625752, -1.794949, 
        21.965471}}],
    Line[{{-2.625752, -1.794949, 21.965471},{-2.553607, -1.939332, 
        21.435074}}],
    Line[{{-2.553607, -1.939332, 21.435074},{-2.502446, -2.091555, 
        20.921202}}],
    Line[{{-2.502446, -2.091555, 20.921202},{-2.471035, -2.251981, 
        20.423872}}],
    Line[{{-2.471035, -2.251981, 20.423872},{-2.458301, -2.421200, 
        19.943167}}],
    Line[{{-2.458301, -2.421200, 19.943167},{-2.463342, -2.600008, 
        19.479252}}],
    Line[{{-2.463342, -2.600008, 19.479252},{-2.485422, -2.789376, 
        19.032377}}],
    Line[{{-2.485422, -2.789376, 19.032377},{-2.523979, -2.990424, 
        18.602894}}],
    Line[{{-2.523979, -2.990424, 18.602894},{-2.578616, -3.204412, 
        18.191269}}],
    Line[{{-2.578616, -3.204412, 18.191269},{-2.649100, -3.432718, 
        17.798094}}],
    Line[{{-2.649100, -3.432718, 17.798094},{-2.735356, -3.676836, 
        17.424107}}],
    Line[{{-2.735356, -3.676836, 17.424107},{-2.837466, -3.938354, 
        17.070217}}],
    Line[{{-2.837466, -3.938354, 17.070217},{-2.955656, -4.218954, 
        16.737528}}],
    Line[{{-2.955656, -4.218954, 16.737528},{-3.090297, -4.520390, 
        16.427362}}],
    Line[{{-3.090297, -4.520390, 16.427362},{-3.241893, -4.844480, 
        16.141302}}],
    Line[{{-3.241893, -4.844480, 16.141302},{-3.411077, -5.193081, 
        15.881223}}],
    Line[{{-3.411077, -5.193081, 15.881223},{-3.598598, -5.568075, 
        15.649333}}],
    Line[{{-3.598598, -5.568075, 15.649333},{-3.805312, -5.971307, 
        15.448229}}],
    Line[{{-3.805312, -5.971307, 15.448229},{-4.032168, -6.404574, 
        15.280932}}],
    Line[{{-4.032168, -6.404574, 15.280932},{-4.280190, -6.869534, 
        15.150961}}],
    Line[{{-4.280190, -6.869534, 15.150961},{-4.550449, -7.367637, 
        15.062366}}],
    Line[{{-4.550449, -7.367637, 15.062366},{-4.844047, -7.900037, 
        15.019796}}],
    Line[{{-4.844047, -7.900037, 15.019796},{-5.162060, -8.467423, 
        15.028543}}],
    Line[{{-5.162060, -8.467423, 15.028543},{-5.505505, -9.069900, 
        15.094569}}],
    Line[{{-5.505505, -9.069900, 15.094569},{-5.875277, -9.706772, 
        15.224536}}],
    Line[{{-5.875277, -9.706772, 15.224536},{-6.272068, -10.376303, 
        15.425776}}],
    Line[{{-6.272068, -10.376303, 15.425776},{-6.696276, -11.075438, 
        15.706223}}],
    Line[{{-6.696276, -11.075438, 15.706223},{-7.147901, -11.799514, 
        16.074312}}],
    Line[{{-7.147901, -11.799514, 16.074312},{-7.626403, -12.541884, 
        16.538748}}],
    Line[{{-7.626403, -12.541884, 16.538748},{-8.130549, -13.293573, 
        17.108156}}],
    Line[{{-8.130549, -13.293573, 17.108156},{-8.658245, -14.042944, 
        17.790649}}],
    Line[{{-8.658245, -14.042944, 17.790649},{-9.206350, -14.775391, 
        18.593252}}],
    Line[{{-9.206350, -14.775391, 18.593252},{-9.770477, -15.473192, 
        19.520996}}],
    Line[{{-9.770477, -15.473192, 19.520996},{-10.344820, -16.115511, 
        20.576071}}],
    Line[{{-10.344820, -16.115511, 20.576071},{-10.922002, -16.678705, 
        21.756699}}],
    Line[{{-10.922002, -16.678705, 21.756699},{-11.492990, -17.136986, 
        23.056004}}],
    Line[{{-11.492990, -17.136986, 23.056004},{-12.047093, -17.463528, 
        24.460957}}],
    Line[{{-12.047093, -17.463528, 24.460957},{-12.572092, -17.632017, 
        25.951511}}],
    Line[{{-12.572092, -17.632017, 25.951511},{-13.054539, -17.618742, 
        27.500252}}],
    Line[{{-13.054539, -17.618742, 27.500252},{-13.480228, -17.404902, 
        29.072643}}],
    Line[{{-13.480228, -17.404902, 29.072643},{-13.834849, -16.979015, 
        30.628159}}],
    Line[{{-13.834849, -16.979015, 30.628159},{-14.104806, -16.339085, 
        32.122288}}],
    Line[{{-14.104806, -16.339085, 32.122288},{-14.278127, -15.494072, 
        33.509415}}],
    Line[{{-14.278127, -15.494072, 33.509415},{-14.345387, -14.464349, 
        34.746227}}],
    Line[{{-14.345387, -14.464349, 34.746227},{-14.300526, -13.280911, 
        35.795273}}],
    Line[{{-14.300526, -13.280911, 35.795273},{-14.141438, -11.983238, 
        36.628078}}],
    Line[{{-14.141438, -11.983238, 36.628078},{-13.870265, -10.616195, 
        37.227360}}],
    Line[{{-13.870265, -10.616195, 37.227360},{-13.493325, -9.226315, 
        37.588001}}],
    Line[{{-13.493325, -9.226315, 37.588001},{-13.020693, -7.858027, 
        37.716595}}],
    Line[{{-13.020693, -7.858027, 37.716595},{-12.465475, -6.550440, 
        37.629780}}],
    Line[{{-12.465475, -6.550440, 37.629780},{-11.842897, -5.335044, 
        37.351753}}],
    Line[{{-11.842897, -5.335044, 37.351753},{-11.169314, -4.234521, 
        36.911358}}],
    Line[{{-11.169314, -4.234521, 36.911358},{-10.461246, -3.262622, 
        36.339245}}],
    Line[{{-10.461246, -3.262622, 36.339245},{-9.734548, -2.424925, 
        35.665482}}],
    Line[{{-9.734548, -2.424925, 35.665482},{-9.003748, -1.720157, 
        34.917747}}],
    Line[{{-9.003748, -1.720157, 34.917747},{-8.281610, -1.141794, 
        34.120201}}],
    Line[{{-8.281610, -1.141794, 34.120201},{-7.578870, -0.679677, 
        33.292976}}],
    Line[{{-7.578870, -0.679677, 33.292976},{-6.904162, -0.321484, 
        32.452126}}],
    Line[{{-6.904162, -0.321484, 32.452126},{-6.264069, -0.053939, 
        31.609926}}],
    Line[{{-6.264069, -0.053939, 31.609926},{-5.663277, 0.136261, 
        30.775352}}],
    Line[{{-5.663277, 0.136261, 30.775352},{-5.104788, 0.261790, 29.954660}}],
    
    Line[{{-5.104788, 0.261790, 29.954660},{-4.590157, 0.334281, 29.151937}}],
    
    Line[{{-4.590157, 0.334281, 29.151937},{-4.119747, 0.364094, 28.369631}}],
    
    Line[{{-4.119747, 0.364094, 28.369631},{-3.692965, 0.360229, 27.608992}}],
    
    Line[{{-3.692965, 0.360229, 27.608992},{-3.308483, 0.330337, 26.870422}}],
    
    Line[{{-3.308483, 0.330337, 26.870422},{-2.964434, 0.280793, 26.153778}}],
    
    Line[{{-2.964434, 0.280793, 26.153778},{-2.658579, 0.216804, 25.458557}}],
    
    Line[{{-2.658579, 0.216804, 25.458557},{-2.388449, 0.142541, 24.784069}}],
    
    Line[{{-2.388449, 0.142541, 24.784069},{-2.151458, 0.061266, 24.129528}}],
    
    Line[{{-2.151458, 0.061266, 24.129528},{-1.944992, -0.024533, 
        23.494127}}],
    Line[{{-1.944992, -0.024533, 23.494127},{-1.766484, -0.113028, 
        22.877081}}],
    Line[{{-1.766484, -0.113028, 22.877081},{-1.613464, -0.202937, 
        22.277651}}],
    Line[{{-1.613464, -0.202937, 22.277651},{-1.483598, -0.293435, 
        21.695152}}],
    Line[{{-1.483598, -0.293435, 21.695152},{-1.374712, -0.384067, 
        21.128971}}],
    Line[{{-1.374712, -0.384067, 21.128971},{-1.284816, -0.474678, 
        20.578547}}],
    Line[{{-1.284816, -0.474678, 20.578547},{-1.212099, -0.565360, 
        20.043381}}],
    Line[{{-1.212099, -0.565360, 20.043381},{-1.154948, -0.656397, 
        19.523027}}],
    Line[{{-1.154948, -0.656397, 19.523027},{-1.111934, -0.748230, 
        19.017088}}],
    Line[{{-1.111934, -0.748230, 19.017088},{-1.081815, -0.841426, 
        18.525211}}],
    Line[{{-1.081815, -0.841426, 18.525211},{-1.063525, -0.936658, 
        18.047089}}],
    Line[{{-1.063525, -0.936658, 18.047089},{-1.056168, -1.034681, 
        17.582445}}],
    Line[{{-1.056168, -1.034681, 17.582445},{-1.059008, -1.136327, 
        17.131050}}],
    Line[{{-1.059008, -1.136327, 17.131050},{-1.071464, -1.242491, 
        16.692709}}],
    Line[{{-1.071464, -1.242491, 16.692709},{-1.093094, -1.354136, 
        16.267267}}],
    Line[{{-1.093094, -1.354136, 16.267267},{-1.123598, -1.472283, 
        15.854612}}],
    Line[{{-1.123598, -1.472283, 15.854612},{-1.162801, -1.598019, 
        15.454679}}],
    Line[{{-1.162801, -1.598019, 15.454679},{-1.210654, -1.732500, 
        15.067452}}],
    Line[{{-1.210654, -1.732500, 15.067452},{-1.267223, -1.876956, 
        14.692980}}],
    Line[{{-1.267223, -1.876956, 14.692980},{-1.332692, -2.032702, 
        14.331374}}],
    Line[{{-1.332692, -2.032702, 14.331374},{-1.407356, -2.201140, 
        13.982826}}],
    Line[{{-1.407356, -2.201140, 13.982826},{-1.491618, -2.383776, 
        13.647622}}],
    Line[{{-1.491618, -2.383776, 13.647622},{-1.585995, -2.582226, 
        13.326152}}],
    Line[{{-1.585995, -2.582226, 13.326152},{-1.691111, -2.798226, 
        13.018935}}],
    Line[{{-1.691111, -2.798226, 13.018935},{-1.807705, -3.033645, 
        12.726644}}],
    Line[{{-1.807705, -3.033645, 12.726644},{-1.936627, -3.290491, 
        12.450119}}],
    Line[{{-1.936627, -3.290491, 12.450119},{-2.078848, -3.570919, 
        12.190426}}],
    Line[{{-2.078848, -3.570919, 12.190426},{-2.235455, -3.877239, 
        11.948866}}],
    Line[{{-2.235455, -3.877239, 11.948866},{-2.407662, -4.211915, 
        11.727046}}],
    Line[{{-2.407662, -4.211915, 11.727046},{-2.596809, -4.577559, 
        11.526919}}],
    Line[{{-2.596809, -4.577559, 11.526919},{-2.804362, -4.976926, 
        11.350848}}],
    Line[{{-2.804362, -4.976926, 11.350848},{-3.031916, -5.412876, 
        11.201696}}],
    Line[{{-3.031916, -5.412876, 11.201696},{-3.281194, -5.888365, 
        11.082878}}],
    Line[{{-3.281194, -5.888365, 11.082878},{-3.554032, -6.406356, 
        10.998497}}],
    Line[{{-3.554032, -6.406356, 10.998497},{-3.852377, -6.969768, 
        10.953415}}],
    Line[{{-3.852377, -6.969768, 10.953415},{-4.178259, -7.581343, 
        10.953396}}],
    Line[{{-4.178259, -7.581343, 10.953396},{-4.533761, -8.243503, 
        11.005216}}],
    Line[{{-4.533761, -8.243503, 11.005216},{-4.920971, -8.958124, 
        11.116788}}],
    Line[{{-4.920971, -8.958124, 11.116788},{-5.341928, -9.726305, 
        11.297275}}],
    Line[{{-5.341928, -9.726305, 11.297275},{-5.798526, -10.547990, 
        11.557181}}],
    Line[{{-5.798526, -10.547990, 11.557181},{-6.292400, -11.421530, 
        11.908396}}],
    Line[{{-6.292400, -11.421530, 11.908396},{-6.824768, -12.343149, 
        12.364130}}],
    Line[{{-6.824768, -12.343149, 12.364130},{-7.396263, -13.306361, 
        12.938817}}],
    Line[{{-7.396263, -13.306361, 12.938817},{-8.006661, -14.301154, 
        13.647699}}],
    Line[{{-8.006661, -14.301154, 13.647699},{-8.654613, -15.313272, 
        14.506310}}],
    Line[{{-8.654613, -15.313272, 14.506310},{-9.337302, -16.323391, 
        15.529559}}],
    Line[{{-9.337302, -16.323391, 15.529559},{-10.050068, -17.306450, 
        16.730469}}],
    Line[{{-10.050068, -17.306450, 16.730469},{-10.786011, -18.231194, 
        18.118475}}],
    Line[{{-10.786011, -18.231194, 18.118475},{-11.535613, -19.060221, 
        19.697317}}],
    Line[{{-11.535613, -19.060221, 19.697317},{-12.286427, -19.750647, 
        21.462610}}],
    Line[{{-12.286427, -19.750647, 21.462610},{-13.022914, -20.255857, 
        23.399252}}],
    Line[{{-13.022914, -20.255857, 23.399252},{-13.726501, -20.528311, 
        25.479164}}],
    Line[{{-13.726501, -20.528311, 25.479164},{-14.375977, -20.523594, 
        27.659798}}],
    Line[{{-14.375977, -20.523594, 27.659798},{-14.948269, -20.205479, 
        29.884056}}],
    Line[{{-14.948269, -20.205479, 29.884056},{-15.419678, -19.551420, 
        32.082214}}],
    Line[{{-15.419678, -19.551420, 32.082214},{-15.767481, -18.557596, 
        34.176155}}],
    Line[{{-15.767481, -18.557596, 34.176155},{-15.971807, -17.242350, 
        36.085773}}],
    Line[{{-15.971807, -17.242350, 36.085773},{-16.017544, -15.647002, 
        37.736816}}],
    Line[{{-16.017544, -15.647002, 37.736816},{-15.895980, -13.833403, 
        39.068855}}],
    Line[{{-15.895980, -13.833403, 39.068855},{-15.605880, -11.878230, 
        40.041782}}],
    Line[{{-15.605880, -11.878230, 40.041782},{-15.153841, -9.865118, 
        40.639664}}],
    Line[{{-15.153841, -9.865118, 40.639664},{-14.553770, -7.875858, 
        40.870941}}],
    Line[{{-14.553770, -7.875858, 40.870941},{-13.825614, -5.982588, 
        40.765282}}],
    Line[{{-13.825614, -5.982588, 40.765282},{-12.993585, -4.242104, 
        40.368050}}],
    Line[{{-12.993585, -4.242104, 40.368050},{-12.084128, -2.693107, 
        39.733517}}],
    Line[{{-12.084128, -2.693107, 39.733517},{-11.123969, -1.356154, 
        38.918381}}],
    Line[{{-11.123969, -1.356154, 38.918381},{-10.138448, -0.235782, 
        37.976448}}],
    Line[{{-10.138448, -0.235782, 37.976448},{-9.150283, 0.676101, 
        36.955032}}],
    Line[{{-9.150283, 0.676101, 36.955032},{-8.178807, 1.396423, 35.893078}}],
    
    Line[{{-8.178807, 1.396423, 35.893078},{-7.239615, 1.947376, 34.820709}}],
    
    Line[{{-7.239615, 1.947376, 34.820709},{-6.344579, 2.353466, 33.759827}}],
    
    Line[{{-6.344579, 2.353466, 33.759827},{-5.502085, 2.639299, 32.725239}}],
    
    Line[{{-5.502085, 2.639299, 32.725239},{-4.717440, 2.828110, 31.726080}}],
    
    Line[{{-4.717440, 2.828110, 31.726080},{-3.993335, 2.940888, 30.767176}}],
    
    Line[{{-3.993335, 2.940888, 30.767176},{-3.330338, 2.995971, 29.850277}}],
    
    Line[{{-3.330338, 2.995971, 29.850277},{-2.727345, 3.008973, 28.975067}}],
    
    Line[{{-2.727345, 3.008973, 28.975067},{-2.182002, 2.992902, 28.139957}}],
    
    Line[{{-2.182002, 2.992902, 28.139957},{-1.691058, 2.958400, 27.342659}}],
    
    Line[{{-1.691058, 2.958400, 27.342659},{-1.250658, 2.914036, 26.580587}}],
    
    Line[{{-1.250658, 2.914036, 26.580587},{-0.856590, 2.866607, 25.851131}}],
    
    Line[{{-0.856590, 2.866607, 25.851131},{-0.504468, 2.821434, 25.151814}}],
    
    Line[{{-0.504468, 2.821434, 25.151814},{-0.189878, 2.782625, 24.480391}}],
    
    Line[{{-0.189878, 2.782625, 24.480391},{0.091515, 2.753312, 23.834883}}],
    Line[{{0.091515, 2.753312, 23.834883},{0.343896, 2.735854, 23.213593}}],
    Line[{{0.343896, 2.735854, 23.213593},{0.571243, 2.732017, 22.615088}}],
    Line[{{0.571243, 2.732017, 22.615088},{0.777301, 2.743112, 22.038197}}],
    Line[{{0.777301, 2.743112, 22.038197},{0.965568, 2.770125, 21.481970}}],
    Line[{{0.965568, 2.770125, 21.481970},{1.139289, 2.813812, 20.945662}}],
    Line[{{1.139289, 2.813812, 20.945662},{1.301467, 2.874785, 20.428720}}],
    Line[{{1.301467, 2.874785, 20.428720},{1.454871, 2.953576, 19.930756}}],
    Line[{{1.454871, 2.953576, 19.930756},{1.602056, 3.050695, 19.451540}}],
    Line[{{1.602056, 3.050695, 19.451540},{1.745384, 3.166668, 18.990993}}],
    Line[{{1.745384, 3.166668, 18.990993},{1.887044, 3.302075, 18.549185}}],
    Line[{{1.887044, 3.302075, 18.549185},{2.029076, 3.457572, 18.126339}}],
    Line[{{2.029076, 3.457572, 18.126339},{2.173391, 3.633914, 17.722832}}],
    Line[{{2.173391, 3.633914, 17.722832},{2.321797, 3.831964, 17.339214}}],
    Line[{{2.321797, 3.831964, 17.339214},{2.476017, 4.052707, 16.976219}}],
    Line[{{2.476017, 4.052707, 16.976219},{2.637710, 4.297246, 16.634789}}],
    Line[{{2.637710, 4.297246, 16.634789},{2.808488, 4.566802, 16.316095}}],
    Line[{{2.808488, 4.566802, 16.316095},{2.989930, 4.862709, 16.021578}}],
    Line[{{2.989930, 4.862709, 16.021578},{3.183598, 5.186389, 15.752972}}],
    Line[{{3.183598, 5.186389, 15.752972},{3.391045, 5.539347, 15.512350}}],
    Line[{{3.391045, 5.539347, 15.512350},{3.613817, 5.923111, 15.302176}}],
    Line[{{3.613817, 5.923111, 15.302176},{3.853463, 6.339214, 15.125341}}],
    Line[{{3.853463, 6.339214, 15.125341},{4.111528, 6.789120, 14.985233}}],
    Line[{{4.111528, 6.789120, 14.985233},{4.389538, 7.274136, 14.885786}}],
    Line[{{4.389538, 7.274136, 14.885786},{4.688993, 7.795338, 14.831530}}],
    Line[{{4.688993, 7.795338, 14.831530},{5.011335, 8.353425, 14.827654}}],
    Line[{{5.011335, 8.353425, 14.827654},{5.357901, 8.948541, 14.880038}}],
    Line[{{5.357901, 8.948541, 14.880038},{5.729897, 9.580137, 14.995292}}],
    Line[{{5.729897, 9.580137, 14.995292},{6.128307, 10.246676, 15.180736}}],
    Line[{{6.128307, 10.246676, 15.180736},{6.553818, 10.945378, 15.444352}}],
    
    Line[{{6.553818, 10.945378, 15.444352},{7.006718, 11.671911, 15.794693}}],
    
    Line[{{7.006718, 11.671911, 15.794693},{7.486763, 12.420027, 16.240679}}],
    
    Line[{{7.486763, 12.420027, 16.240679},{7.993030, 13.181181, 16.791300}}],
    
    Line[{{7.993030, 13.181181, 16.791300},{8.523742, 13.944177, 17.455156}}],
    
    Line[{{8.523742, 13.944177, 17.455156},{9.076091, 14.694838, 18.239922}}],
    
    Line[{{9.076091, 14.694838, 18.239922},{9.646027, 15.415770, 19.151531}}],
    
    Line[{{9.646027, 15.415770, 19.151531},{
      10.228073, 16.086315, 20.193233}}],
    Line[{{10.228073, 16.086315, 20.193233},{
      10.815158, 16.682787, 21.364487}}],
    Line[{{10.815158, 16.682787, 21.364487},{
      11.398502, 17.179022, 22.659796}}],
    Line[{{11.398502, 17.179022, 22.659796},{
      11.967594, 17.547411, 24.067539}}],
    Line[{{11.967594, 17.547411, 24.067539},{
      12.510283, 17.760418, 25.569012}}],
    Line[{{12.510283, 17.760418, 25.569012},{
      13.013036, 17.792595, 27.137875}}],
    Line[{{13.013036, 17.792595, 27.137875},{
      13.461382, 17.622961, 28.740234}}],
    Line[{{13.461382, 17.622961, 28.740234},{
      13.840552, 17.237564, 30.335573}}],
    Line[{{13.840552, 17.237564, 30.335573},{
      14.136290, 16.631823, 31.878645}}],
    Line[{{14.136290, 16.631823, 31.878645},{
      14.335787, 15.812329, 33.322254}}],
    Line[{{14.335787, 15.812329, 33.322254},{
      14.428660, 14.797524, 34.620819}}],
    Line[{{14.428660, 14.797524, 34.620819},{
      14.407828, 13.617216, 35.734028}}],
    Line[{{14.407828, 13.617216, 35.734028},{
      14.270197, 12.310664, 36.630302}}],
    Line[{{14.270197, 12.310664, 36.630302},{
      14.017038, 10.923478, 37.289349}}],
    Line[{{14.017038, 10.923478, 37.289349},{
      13.653998, 9.503780, 37.703465}}],
    Line[{{13.653998, 9.503780, 37.703465},{13.190726, 8.098237, 37.877342}}],
    
    Line[{{13.190726, 8.098237, 37.877342},{12.640177, 6.748532, 37.826542}}],
    
    Line[{{12.640177, 6.748532, 37.826542},{12.017685, 5.488741, 37.575020}}],
    
    Line[{{12.017685, 5.488741, 37.575020},{11.339942, 4.343898, 37.152065}}],
    
    Line[{{11.339942, 4.343898, 37.152065},{10.623975, 3.329676, 36.589329}}],
    
    Line[{{10.623975, 3.329676, 36.589329},{9.886256, 2.453053, 35.918190}}],
    Line[{{9.886256, 2.453053, 35.918190},{9.141983, 1.713627, 35.167755}}],
    Line[{{9.141983, 1.713627, 35.167755},{8.404579, 1.105276, 34.363586}}],
    Line[{{8.404579, 1.105276, 34.363586},{7.685401, 0.617865, 33.527061}}],
    Line[{{7.685401, 0.617865, 33.527061},{6.993629, 0.238819, 32.675285}}],
    Line[{{6.993629, 0.238819, 32.675285},{6.336309, -0.045570, 31.821358}}],
    Line[{{6.336309, -0.045570, 31.821358},{5.718500, -0.249135, 30.974871}}],
    
    Line[{{5.718500, -0.249135, 30.974871},{5.143486, -0.385119, 30.142504}}],
    
    Line[{{5.143486, -0.385119, 30.142504},{4.613027, -0.465710, 29.328615}}],
    
    Line[{{4.613027, -0.465710, 29.328615},{4.127617, -0.501790, 28.535807}}],
    
    Line[{{4.127617, -0.501790, 28.535807},{3.686734, -0.502829, 27.765390}}],
    
    Line[{{3.686734, -0.502829, 27.765390},{3.289076, -0.476890, 27.017778}}],
    
    Line[{{3.289076, -0.476890, 27.017778},{2.932760, -0.430703, 26.292786}}],
    
    Line[{{2.932760, -0.430703, 26.292786},{2.615504, -0.369775, 25.589861}}],
    
    Line[{{2.615504, -0.369775, 25.589861},{2.334770, -0.298526, 24.908236}}],
    
    Line[{{2.334770, -0.298526, 24.908236},{2.087890, -0.220431, 24.247053}}],
    
    Line[{{2.087890, -0.220431, 24.247053},{1.872159, -0.138151, 23.605433}}],
    
    Line[{{1.872159, -0.138151, 23.605433},{1.684911, -0.053661, 22.982519}}],
    
    Line[{{1.684911, -0.053661, 22.982519},{1.523572, 0.031637, 22.377508}}],
    Line[{{1.523572, 0.031637, 22.377508},{1.385706, 0.116809, 21.789660}}],
    Line[{{1.385706, 0.116809, 21.789660},{1.269037, 0.201306, 21.218300}}],
    Line[{{1.269037, 0.201306, 21.218300},{1.171471, 0.284891, 20.662821}}],
    Line[{{1.171471, 0.284891, 20.662821},{1.091100, 0.367571, 20.122675}}],
    Line[{{1.091100, 0.367571, 20.122675},{1.026211, 0.449552, 19.597370}}],
    Line[{{1.026211, 0.449552, 19.597370},{0.975280, 0.531196, 19.086464}}],
    Line[{{0.975280, 0.531196, 19.086464},{0.936970, 0.612987, 18.589560}}],
    Line[{{0.936970, 0.612987, 18.589560},{0.910120, 0.695506, 18.106297}}],
    Line[{{0.910120, 0.695506, 18.106297},{0.893740, 0.779414, 17.636354}}],
    Line[{{0.893740, 0.779414, 17.636354},{0.887001, 0.865434, 17.179440}}],
    Line[{{0.887001, 0.865434, 17.179440},{0.889224, 0.954348, 16.735300}}],
    Line[{{0.889224, 0.954348, 16.735300},{0.899871, 1.046988, 16.303705}}],
    Line[{{0.899871, 1.046988, 16.303705},{0.918537, 1.144232, 15.884468}}],
    Line[{{0.918537, 1.144232, 15.884468},{0.944941, 1.247013, 15.477426}}],
    Line[{{0.944941, 1.247013, 15.477426},{0.978922, 1.356312, 15.082458}}],
    Line[{{0.978922, 1.356312, 15.082458},{1.020428, 1.473172, 14.699485}}],
    Line[{{1.020428, 1.473172, 14.699485},{1.069516, 1.598698, 14.328472}}],
    Line[{{1.069516, 1.598698, 14.328472},{1.126345, 1.734068, 13.969440}}],
    Line[{{1.126345, 1.734068, 13.969440},{1.191176, 1.880544, 13.622466}}],
    Line[{{1.191176, 1.880544, 13.622466},{1.264369, 2.039479, 13.287704}}],
    Line[{{1.264369, 2.039479, 13.287704},{1.346383, 2.212327, 12.965390}}],
    Line[{{1.346383, 2.212327, 12.965390},{1.437779, 2.400659, 12.655857}}],
    Line[{{1.437779, 2.400659, 12.655857},{1.539217, 2.606170, 12.359555}}],
    Line[{{1.539217, 2.606170, 12.359555},{1.651464, 2.830694, 12.077076}}],
    Line[{{1.651464, 2.830694, 12.077076},{1.775397, 3.076212, 11.809169}}],
    Line[{{1.775397, 3.076212, 11.809169},{1.912002, 3.344865, 11.556785}}],
    Line[{{1.912002, 3.344865, 11.556785},{2.062387, 3.638957, 11.321105}}],
    Line[{{2.062387, 3.638957, 11.321105},{2.227778, 3.960967, 11.103585}}],
    Line[{{2.227778, 3.960967, 11.103585},{2.409532, 4.313542, 10.906018}}],
    Line[{{2.409532, 4.313542, 10.906018},{2.609135, 4.699501, 10.730572}}],
    Line[{{2.609135, 4.699501, 10.730572},{2.828208, 5.121805, 10.579894}}],
    Line[{{2.828208, 5.121805, 10.579894},{3.068506, 5.583549, 10.457164}}],
    Line[{{3.068506, 5.583549, 10.457164},{3.331916, 6.087899, 10.366217}}],
    Line[{{3.331916, 6.087899, 10.366217},{3.620445, 6.638031, 10.311641}}],
    Line[{{3.620445, 6.638031, 10.311641},{3.936212, 7.237042, 10.298893}}],
    Line[{{3.936212, 7.237042, 10.298893},{4.281420, 7.887820, 10.334440}}],
    Line[{{4.281420, 7.887820, 10.334440},{4.658315, 8.592828, 10.425900}}],
    Line[{{4.658315, 8.592828, 10.425900},{5.069137, 9.353886, 10.582171}}],
    Line[{{5.069137, 9.353886, 10.582171},{5.516042, 10.171845, 10.813556}}],
    Line[{{5.516042, 10.171845, 10.813556},{6.000998, 11.046170, 11.131850}}],
    
    Line[{{6.000998, 11.046170, 11.131850},{6.525650, 11.974419, 11.550374}}],
    
    Line[{{6.525650, 11.974419, 11.550374},{7.091131, 12.951603, 12.083879}}],
    
    Line[{{7.091131, 12.951603, 12.083879},{7.697839, 13.969456, 12.748315}}],
    
    Line[{{7.697839, 13.969456, 12.748315},{8.345166, 15.015606, 13.560418}}],
    
    Line[{{8.345166, 15.015606, 13.560418},{9.031137, 16.072643, 14.536878}}],
    
    Line[{{9.031137, 16.072643, 14.536878},{9.752033, 17.117300, 15.693245}}],
    
    Line[{{9.752033, 17.117300, 15.693245},{
      10.501966, 18.119749, 17.042316}}],
    Line[{{10.501966, 18.119749, 17.042316},{
      11.272432, 19.043293, 18.592051}}],
    Line[{{11.272432, 19.043293, 18.592051},{
      12.051927, 19.844681, 20.343018}}],
    Line[{{12.051927, 19.844681, 20.343018},{
      12.825643, 20.475327, 22.285578}}],
    Line[{{12.825643, 20.475327, 22.285578},{
      13.575409, 20.883839, 24.397083}}],
    Line[{{13.575409, 20.883839, 24.397083},{
      14.279898, 21.019775, 26.639681}}],
    Line[{{14.279898, 21.019775, 26.639681},{
      14.915256, 20.838793, 28.959297}}],
    Line[{{14.915256, 20.838793, 28.959297},{
      15.456222, 20.308680, 31.286634}}],
    Line[{{15.456222, 20.308680, 31.286634},{
      15.877704, 19.415379, 33.540638}}],
    Line[{{15.877704, 19.415379, 33.540638},{
      16.156746, 18.167831, 35.634636}}],
    Line[{{16.156746, 18.167831, 35.634636},{
      16.274647, 16.600355, 37.484505}}],
    Line[{{16.274647, 16.600355, 37.484505},{
      16.218952, 14.771488, 39.017773}}],
    Line[{{16.218952, 14.771488, 39.017773},{
      15.984939, 12.759008, 40.181808}}],
    Line[{{15.984939, 12.759008, 40.181808},{
      15.576367, 10.651960, 40.949451}}],
    Line[{{15.576367, 10.651960, 40.949451},{
      15.005254, 8.540899, 41.320782}}],
    Line[{{15.005254, 8.540899, 41.320782},{14.290787, 6.508550, 41.320946}}],
    
    Line[{{14.290787, 6.508550, 41.320946},{13.457511, 4.622474, 40.994659}}],
    
    Line[{{13.457511, 4.622474, 40.994659},{12.533147, 2.930871, 40.398861}}],
    
    Line[{{12.533147, 2.930871, 40.398861},{11.546377, 1.461619, 39.595211}}],
    
    Line[{{11.546377, 1.461619, 39.595211},{10.524889, 0.224051, 38.643620}}],
    
    Line[{{10.524889, 0.224051, 38.643620},{9.493864, -0.787532, 37.597652}}],
    
    Line[{{9.493864, -0.787532, 37.597652},{8.474987, -1.589627, 36.501907}}],
    
    Line[{{8.474987, -1.589627, 36.501907},{7.485955, -2.205414, 35.391201}}],
    
    Line[{{7.485955, -2.205414, 35.391201},{6.540398, -2.661250, 34.290993}}],
    
    Line[{{6.540398, -2.661250, 34.290993},{5.648097, -2.984017, 33.218582}}],
    
    Line[{{5.648097, -2.984017, 33.218582},{4.815393, -3.199312, 32.184673}}],
    
    Line[{{4.815393, -3.199312, 32.184673},{4.045697, -3.330365, 31.194950}}],
    
    Line[{{4.045697, -3.330365, 31.194950},{3.340023, -3.397519, 30.251497}}],
    
    Line[{{3.340023, -3.397519, 30.251497},{2.697496, -3.418106, 29.353983}}],
    
    Line[{{2.697496, -3.418106, 29.353983},{2.115818, -3.406559, 28.500586}}],
    
    Line[{{2.115818, -3.406559, 28.500586},{1.591666, -3.374680, 27.688669}}],
    
    Line[{{1.591666, -3.374680, 27.688669},{1.121024, -3.331960, 26.915257}}],
    
    Line[{{1.121024, -3.331960, 26.915257},{0.699452, -3.285924, 26.177349}}],
    
    Line[{{0.699452, -3.285924, 26.177349},{0.322300, -3.242454, 25.472116}}],
    
    Line[{{
      0.322300, -3.242454, 25.472116},{-0.015132, -3.206089, 24.796999}}],
    Line[{{-0.015132, -3.206089, 24.796999},{-0.317477, -3.180293, 
        24.149761}}],
    Line[{{-0.317477, -3.180293, 24.149761},{-0.589212, -3.167676, 
        23.528500}}],
    Line[{{-0.589212, -3.167676, 23.528500},{-0.834604, -3.170190, 
        22.931641}}],
    Line[{{-0.834604, -3.170190, 22.931641},{-1.057673, -3.189292, 
        22.357901}}],
    Line[{{-1.057673, -3.189292, 22.357901},{-1.262179, -3.226076, 
        21.806278}}],
    Line[{{-1.262179, -3.226076, 21.806278},{-1.451612, -3.281379, 
        21.276014}}],
    Line[{{-1.451612, -3.281379, 21.276014},{-1.629203, -3.355879, 
        20.766577}}],
    Line[{{-1.629203, -3.355879, 20.766577},{-1.797936, -3.450158, 
        20.277636}}],
    Line[{{-1.797936, -3.450158, 20.277636},{-1.960562, -3.564765, 
        19.809057}}],
    Line[{{-1.960562, -3.564765, 19.809057},{-2.119623, -3.700256, 
        19.360888}}],
    Line[{{-2.119623, -3.700256, 19.360888},{-2.277476, -3.857232, 
        18.933359}}],
    Line[{{-2.277476, -3.857232, 18.933359},{-2.436311, -4.036361, 
        18.526890}}],
    Line[{{-2.436311, -4.036361, 18.526890},{-2.598180, -4.238397, 
        18.142094}}],
    Line[{{-2.598180, -4.238397, 18.142094},{-2.765013, -4.464186, 
        17.779791}}],
    Line[{{-2.765013, -4.464186, 17.779791},{-2.938645, -4.714670, 
        17.441031}}],
    Line[{{-2.938645, -4.714670, 17.441031},{-3.120826, -4.990884, 
        17.127111}}],
    Line[{{-3.120826, -4.990884, 17.127111},{-3.313246, -5.293939, 
        16.839615}}],
    Line[{{-3.313246, -5.293939, 16.839615},{-3.517541, -5.625004, 
        16.580435}}],
    Line[{{-3.517541, -5.625004, 16.580435},{-3.735305, -5.985281, 
        16.351810}}],
    Line[{{-3.735305, -5.985281, 16.351810},{-3.968092, -6.375949, 
        16.156380}}],
    Line[{{-3.968092, -6.375949, 16.156380},{-4.217421, -6.798122, 
        15.997210}}],
    Line[{{-4.217421, -6.798122, 15.997210},{-4.484766, -7.252780, 
        15.877846}}],
    Line[{{-4.484766, -7.252780, 15.877846},{-4.771537, -7.740654, 
        15.802360}}],
    Line[{{-4.771537, -7.740654, 15.802360},{-5.079073, -8.262150, 
        15.775378}}],
    Line[{{-5.079073, -8.262150, 15.775378},{-5.408599, -8.817185, 
        15.802126}}],
    Line[{{-5.408599, -8.817185, 15.802126},{-5.761178, -9.405005, 
        15.888416}}],
    Line[{{-5.761178, -9.405005, 15.888416},{-6.137674, -10.024036, 
        16.040667}}],
    Line[{{-6.137674, -10.024036, 16.040667},{-6.538661, -10.671597, 
        16.265831}}],
    Line[{{-6.538661, -10.671597, 16.265831},{-6.964331, -11.343643, 
        16.571268}}],
    Line[{{-6.964331, -11.343643, 16.571268},{-7.414417, -12.034524, 
        16.964663}}],
    Line[{{-7.414417, -12.034524, 16.964663},{-7.888031, -12.736609, 
        17.453659}}],
    Line[{{-7.888031, -12.736609, 17.453659},{-8.383542, -13.440042, 
        18.045553}}],
    Line[{{-8.383542, -13.440042, 18.045553},{-8.898418, -14.132468, 
        18.746786}}],
    Line[{{-8.898418, -14.132468, 18.746786},{-9.429064, -14.798857, 
        19.562321}}],
    Line[{{-9.429064, -14.798857, 19.562321},{-9.970662, -15.421470, 
        20.494852}}],
    Line[{{-9.970662, -15.421470, 20.494852},{-10.517043, -15.980042, 
        21.543932}}],
    Line[{{-10.517043, -15.980042, 21.543932},{-11.060593, -16.452251, 
        22.705019}}],
    Line[{{-11.060593, -16.452251, 22.705019},{-11.592218, -16.814445, 
        23.968554}}],
    Line[{{-11.592218, -16.814445, 23.968554},{-12.101435, -17.042933, 
        25.319136}}],
    Line[{{-12.101435, -17.042933, 25.319136},{-12.576556, -17.115498, 
        26.735060}}],
    Line[{{-12.576556, -17.115498, 26.735060},{-13.005042, -17.013283, 
        28.188290}}],
    Line[{{-13.005042, -17.013283, 28.188290},{-13.373994, -16.722843, 
        29.645077}}],
    Line[{{-13.373994, -16.722843, 29.645077},{-13.670803, -16.238087, 
        31.067316}}],
    Line[{{-13.670803, -16.238087, 31.067316},{-13.883904, -15.561834, 
        32.414627}}],
    Line[{{-13.883904, -15.561834, 32.414627},{-14.003566, -14.706669, 
        33.647034}}],
    Line[{{-14.003566, -14.706669, 33.647034},{-14.022659, -13.694856, 
        34.727943}}],
    Line[{{-14.022659, -13.694856, 34.727943},{-13.937277, -12.557140, 
        35.627037}}],
    Line[{{-13.937277, -12.557140, 35.627037},{-13.747132, -11.330608, 
        36.322620}}],
    Line[{{-13.747132, -11.330608, 36.322620},{-13.455691, -10.055803, 
        36.803097}}],
    Line[{{-13.455691, -10.055803, 36.803097},{-13.069983, -8.773532, 
        37.067333}}],
    Line[{{-13.069983, -8.773532, 37.067333},{-12.600144, -7.521823, 
        37.123940}}],
    Line[{{-12.600144, -7.521823, 37.123940},{-12.058723, -6.333443, 
        36.989594}}],
    Line[{{-12.058723, -6.333443, 36.989594},{-11.459869, -5.234221, 
        36.686817}}],
    Line[{{-11.459869, -5.234221, 36.686817},{-10.818474, -4.242314, 
        36.241520}}],
    Line[{{-10.818474, -4.242314, 36.241520},{-10.149367, -3.368297, 
        35.680717}}],
    Line[{{-10.149367, -3.368297, 35.680717},{-9.466640, -2.615920, 
        35.030582}}],
    Line[{{-9.466640, -2.615920, 35.030582},{-8.783110, -1.983279, 
        34.315079}}],
    Line[{{-8.783110, -1.983279, 34.315079},{-8.109978, -1.464174, 
        33.555088}}],
    Line[{{-8.109978, -1.464174, 33.555088},{-7.456637, -1.049454, 
        32.768036}}],
    Line[{{-7.456637, -1.049454, 32.768036},{-6.830619, -0.728224, 
        31.967915}}],
    Line[{{-6.830619, -0.728224, 31.967915},{-6.237661, -0.488844, 
        31.165510}}],
    Line[{{-6.237661, -0.488844, 31.165510},{-5.681841, -0.319685, 
        30.368830}}],
    Line[{{-5.681841, -0.319685, 30.368830},{-5.165767, -0.209677, 
        29.583569}}],
    Line[{{-5.165767, -0.209677, 29.583569},{-4.690785, -0.148653, 
        28.813564}}],
    Line[{{-4.690785, -0.148653, 28.813564},{-4.257198, -0.127543, 
        28.061249}}],
    Line[{{-4.257198, -0.127543, 28.061249},{-3.864474, -0.138455, 
        27.327991}}],
    Line[{{-3.864474, -0.138455, 27.327991},{-3.511438, -0.174671, 
        26.614422}}],
    Line[{{-3.511438, -0.174671, 26.614422},{-3.196441, -0.230590, 
        25.920656}}],
    Line[{{-3.196441, -0.230590, 25.920656},{-2.917510, -0.301639, 
        25.246481}}],
    Line[{{-2.917510, -0.301639, 25.246481},{-2.672467, -0.384166, 
        24.591486}}],
    Line[{{-2.672467, -0.384166, 24.591486},{-2.459037, -0.475333, 
        23.955158}}],
    Line[{{-2.459037, -0.475333, 23.955158},{-2.274925, -0.573001, 
        23.336943}}],
    Line[{{-2.274925, -0.573001, 23.336943},{-2.117881, -0.675633, 
        22.736288}}],
    Line[{{-2.117881, -0.675633, 22.736288},{-1.985746, -0.782201, 
        22.152670}}],
    Line[{{-1.985746, -0.782201, 22.152670},{-1.876494, -0.892101, 
        21.585609}}],
    Line[{{-1.876494, -0.892101, 21.585609},{-1.788249, -1.005084, 
        21.034672}}],
    Line[{{-1.788249, -1.005084, 21.034672},{-1.719306, -1.121197, 
        20.499481}}],
    Line[{{-1.719306, -1.121197, 20.499481},{-1.668137, -1.240731, 
        19.979715}}],
    Line[{{-1.668137, -1.240731, 19.979715},{-1.633399, -1.364181, 
        19.475107}}],
    Line[{{-1.633399, -1.364181, 19.475107},{-1.613932, -1.492212, 
        18.985447}}],
    Line[{{-1.613932, -1.492212, 18.985447},{-1.608756, -1.625633, 
        18.510578}}],
    Line[{{-1.608756, -1.625633, 18.510578},{-1.617069, -1.765381, 
        18.050406}}],
    Line[{{-1.617069, -1.765381, 18.050406},{-1.638239, -1.912504, 
        17.604895}}],
    Line[{{-1.638239, -1.912504, 17.604895},{-1.671799, -2.068154, 
        17.174076}}],
    Line[{{-1.671799, -2.068154, 17.174076},{-1.717441, -2.233581, 
        16.758059}}],
    Line[{{-1.717441, -2.233581, 16.758059},{-1.775010, -2.410129, 
        16.357031}}],
    Line[{{-1.775010, -2.410129, 16.357031},{-1.844499, -2.599239, 
        15.971277}}],
    Line[{{-1.844499, -2.599239, 15.971277},{-1.926042, -2.802452, 
        15.601191}}],
    Line[{{-1.926042, -2.802452, 15.601191},{-2.019912, -3.021409, 
        15.247290}}],
    Line[{{-2.019912, -3.021409, 15.247290},{-2.126520, -3.257856, 
        14.910241}}],
    Line[{{-2.126520, -3.257856, 14.910241},{-2.246405, -3.513650, 
        14.590879}}],
    Line[{{-2.246405, -3.513650, 14.590879},{-2.380239, -3.790756, 
        14.290244}}],
    Line[{{-2.380239, -3.790756, 14.290244},{-2.528824, -4.091252, 
        14.009603}}],
    Line[{{-2.528824, -4.091252, 14.009603},{-2.693086, -4.417324, 
        13.750499}}],
    Line[{{-2.693086, -4.417324, 13.750499},{-2.874077, -4.771250, 
        13.514801}}],
    Line[{{-2.874077, -4.771250, 13.514801},{-3.072969, -5.155402, 
        13.304740}}],
    Line[{{-3.072969, -5.155402, 13.304740},{-3.291052, -5.572193, 
        13.122995}}],
    Line[{{-3.291052, -5.572193, 13.122995},{-3.529724, -6.024069, 
        12.972735}}],
    Line[{{-3.529724, -6.024069, 12.972735},{-3.790483, -6.513432, 
        12.857714}}],
    Line[{{-3.790483, -6.513432, 12.857714},{-4.074902, -7.042556, 
        12.782347}}],
    Line[{{-4.074902, -7.042556, 12.782347},{-4.384622, -7.613530, 
        12.751790}}],
    Line[{{-4.384622, -7.613530, 12.751790},{-4.721300, -8.228049, 
        12.772046}}],
    Line[{{-4.721300, -8.228049, 12.772046},{-5.086577, -8.887283, 
        12.850032}}],
    Line[{{-5.086577, -8.887283, 12.850032},{-5.482013, -9.591638, 
        12.993653}}],
    Line[{{-5.482013, -9.591638, 12.993653},{-5.909012, -10.340461, 
        13.211852}}],
    Line[{{-5.909012, -10.340461, 13.211852},{-6.368714, -11.131681, 
        13.514599}}],
    Line[{{-6.368714, -11.131681, 13.514599},{-6.861865, -11.961392, 
        13.912809}}],
    Line[{{-6.861865, -11.961392, 13.912809},{-7.388669, -12.823380, 
        14.418207}}],
    Line[{{-7.388669, -12.823380, 14.418207},{-7.948583, -13.708556, 
        15.042987}}],
    Line[{{-7.948583, -13.708556, 15.042987},{-8.540082, -14.604379, 
        15.799299}}],
    Line[{{-8.540082, -14.604379, 15.799299},{-9.160408, -15.494326, 
        16.698549}}],
    Line[{{-9.160408, -15.494326, 16.698549},{-9.805281, -16.357428, 
        17.750381}}],
    Line[{{-9.805281, -16.357428, 17.750381},{-10.468606, -17.168026, 
        18.961395}}],
    Line[{{-10.468606, -17.168026, 18.961395},{-11.142202, -17.895872, 
        20.333565}}],
    Line[{{-11.142202, -17.895872, 20.333565},{-11.815590, -18.506739, 
        21.862476}}],
    Line[{{-11.815590, -18.506739, 21.862476},{-12.475876, -18.963673, 
        23.535484}}],
    Line[{{-12.475876, -18.963673, 23.535484},{-13.107841, -19.229181, 
        25.330112}}],
    Line[{{-13.107841, -19.229181, 25.330112},{-13.694229, -19.268053, 
        27.213013}}],
    Line[{{-13.694229, -19.268053, 27.213013},{-14.216326, -19.050961, 
        29.139858}}],
    Line[{{-14.216326, -19.050961, 29.139858},{-14.654851, -18.558392, 
        31.056595}}],
    Line[{{-14.654851, -18.558392, 31.056595},{-14.991128, -17.784327, 
        32.902245}}],
    Line[{{-14.991128, -17.784327, 32.902245},{-15.208455, -16.738955, 
        34.613235}}],
    Line[{{-15.208455, -16.738955, 34.613235},{-15.293526, -15.449739, 
        36.128822}}],
    Line[{{-15.293526, -15.449739, 36.128822},{-15.237709, -13.960258, 
        37.396851}}],
    Line[{{-15.237709, -13.960258, 37.396851},{-15.038004, -12.326941, 
        38.378860}}],
    Line[{{-15.038004, -12.326941, 38.378860},{-14.697478, -10.613863, 
        39.053562}}],
    Line[{{-14.697478, -10.613863, 39.053562},{-14.225128, -8.886634, 
        39.418118}}],
    Line[{{-14.225128, -8.886634, 39.418118},{-13.635172, -7.206404, 
        39.487003}}],
    Line[{{-13.635172, -7.206404, 39.487003},{-12.945868, -5.624957, 
        39.288811}}],
    Line[{{-12.945868, -5.624957, 39.288811},{-12.178079, -4.181561, 
        38.861835}}],
    Line[{{-12.178079, -4.181561, 38.861835},{-11.353758, -2.901777, 
        38.249302}}],
    Line[{{-11.353758, -2.901777, 38.249302},{-10.494556, -1.798031, 
        37.494957}}],
    Line[{{-10.494556, -1.798031, 37.494957},{-9.620682, -0.871431, 
        36.639690}}],
    Line[{{-9.620682, -0.871431, 36.639690},{-8.750076, -0.114279, 
        35.719265}}],
    Line[{{-8.750076, -0.114279, 35.719265},{-7.897924, 0.487241, 
        34.763241}}],
    Line[{{-7.897924, 0.487241, 34.763241},{-7.076457, 0.950604, 33.794739}}],
    
    Line[{{-7.076457, 0.950604, 33.794739},{-6.294985, 1.294889, 32.830921}}],
    
    Line[{{-6.294985, 1.294889, 32.830921},{-5.560104, 1.539249, 31.883772}}],
    
    Line[{{-5.560104, 1.539249, 31.883772},{-4.876001, 1.701842, 30.961094}}],
    
    Line[{{-4.876001, 1.701842, 30.961094},{-4.244811, 1.799202, 30.067436}}],
    
    Line[{{-4.244811, 1.799202, 30.067436},{-3.666984, 1.845910, 29.204983}}],
    
    Line[{{-3.666984, 1.845910, 29.204983},{-3.141639, 1.854503, 28.374250}}],
    
    Line[{{-3.141639, 1.854503, 28.374250},{-2.666885, 1.835533, 27.574682}}],
    
    Line[{{-2.666885, 1.835533, 27.574682},{-2.240093, 1.797719, 26.805063}}],
    
    Line[{{-2.240093, 1.797719, 26.805063},{-1.858137, 1.748143, 26.063835}}],
    
    Line[{{-1.858137, 1.748143, 26.063835},{-1.517586, 1.692464, 25.349312}}],
    
    Line[{{-1.517586, 1.692464, 25.349312},{-1.214856, 1.635132, 24.659813}}],
    
    Line[{{-1.214856, 1.635132, 24.659813},{-0.946331, 1.579590, 23.993748}}],
    
    Line[{{-0.946331, 1.579590, 23.993748},{-0.708452, 1.528455, 23.349659}}],
    
    Line[{{-0.708452, 1.528455, 23.349659},{-0.497786, 1.483674, 22.726240}}],
    
    Line[{{-0.497786, 1.483674, 22.726240},{-0.311064, 1.446667, 22.122341}}],
    
    Line[{{-0.311064, 1.446667, 22.122341},{-0.145216, 1.418447, 21.536951}}],
    
    Line[{{-0.145216, 1.418447, 21.536951},{0.002617, 1.399714, 20.969198}}],
    Line[{{0.002617, 1.399714, 20.969198},{0.135076, 1.390946, 20.418322}}],
    Line[{{0.135076, 1.390946, 20.418322},{0.254590, 1.392464, 19.883667}}],
    Line[{{0.254590, 1.392464, 19.883667},{0.363381, 1.404488, 19.364670}}],
    Line[{{0.363381, 1.404488, 19.364670},{0.463478, 1.427188, 18.860840}}],
    Line[{{0.463478, 1.427188, 18.860840},{0.556731, 1.460718, 18.371759}}],
    Line[{{0.556731, 1.460718, 18.371759},{0.644832, 1.505250, 17.897072}}],
    Line[{{0.644832, 1.505250, 17.897072},{0.729326, 1.560997, 17.436478}}],
    Line[{{0.729326, 1.560997, 17.436478},{0.811638, 1.628231, 16.989733}}],
    Line[{{0.811638, 1.628231, 16.989733},{0.893084, 1.707306, 16.556646}}],
    Line[{{0.893084, 1.707306, 16.556646},{0.974896, 1.798665, 16.137087}}],
    Line[{{0.974896, 1.798665, 16.137087},{1.058231, 1.902855, 15.730975}}],
    Line[{{1.058231, 1.902855, 15.730975},{1.144199, 2.020540, 15.338302}}],
    Line[{{1.144199, 2.020540, 15.338302},{1.233869, 2.152503, 14.959126}}],
    Line[{{1.233869, 2.152503, 14.959126},{1.328292, 2.299660, 14.593586}}],
    Line[{{1.328292, 2.299660, 14.593586},{1.428511, 2.463069, 14.241916}}],
    Line[{{1.428511, 2.463069, 14.241916},{1.535578, 2.643931, 13.904451}}],
    Line[{{1.535578, 2.643931, 13.904451},{1.650566, 2.843603, 13.581656}}],
    Line[{{1.650566, 2.843603, 13.581656},{1.774585, 3.063602, 13.274134}}],
    Line[{{1.774585, 3.063602, 13.274134},{1.908790, 3.305612, 12.982666}}],
    Line[{{1.908790, 3.305612, 12.982666},{2.054393, 3.571485, 12.708227}}],
    Line[{{2.054393, 3.571485, 12.708227},{2.212678, 3.863247, 12.452036}}],
    Line[{{2.212678, 3.863247, 12.452036},{2.385007, 4.183092, 12.215586}}],
    Line[{{2.385007, 4.183092, 12.215586},{2.572829, 4.533383, 12.000697}}],
    Line[{{2.572829, 4.533383, 12.000697},{2.777687, 4.916625, 11.809592}}],
    Line[{{2.777687, 4.916625, 11.809592},{3.001222, 5.335462, 11.644933}}],
    Line[{{3.001222, 5.335462, 11.644933},{3.245178, 5.792626, 11.509926}}],
    Line[{{3.245178, 5.792626, 11.509926},{3.511389, 6.290885, 11.408403}}],
    Line[{{3.511389, 6.290885, 11.408403},{3.801786, 6.832996, 11.344909}}],
    Line[{{3.801786, 6.832996, 11.344909},{4.118366, 7.421552, 11.324829}}],
    Line[{{4.118366, 7.421552, 11.324829},{4.463172, 8.058882, 11.354492}}],
    Line[{{4.463172, 8.058882, 11.354492},{4.838256, 8.746854, 11.441282}}],
    Line[{{4.838256, 8.746854, 11.441282},{5.245619, 9.486627, 11.593760}}],
    Line[{{5.245619, 9.486627, 11.593760},{5.687133, 10.278322, 11.821735}}],
    Line[{{5.687133, 10.278322, 11.821735},{6.164438, 11.120653, 12.136318}}],
    
    Line[{{6.164438, 11.120653, 12.136318},{6.678815, 12.010443, 12.549911}}],
    
    Line[{{6.678815, 12.010443, 12.549911},{7.231000, 12.942017, 13.076073}}],
    
    Line[{{7.231000, 12.942017, 13.076073},{7.820971, 13.906550, 13.729220}}],
    
    Line[{{7.820971, 13.906550, 13.729220},{8.447689, 14.891351, 14.524170}}],
    
    Line[{{8.447689, 14.891351, 14.524170},{9.108785, 15.879099, 15.475350}}],
    
    Line[{{9.108785, 15.879099, 15.475350},{9.800220, 16.847181, 16.595711}}],
    
    Line[{{9.800220, 16.847181, 16.595711},{
      10.515909, 17.767202, 17.895224}}],
    Line[{{10.515909, 17.767202, 17.895224},{
      11.247358, 18.604889, 19.378984}}],
    Line[{{11.247358, 18.604889, 19.378984},{
      11.983348, 19.320541, 21.045006}}],
    Line[{{11.983348, 19.320541, 21.045006},{
      12.709741, 19.870445, 22.881784}}],
    Line[{{12.709741, 19.870445, 22.881784},{
      13.409480, 20.209143, 24.866106}}],
    Line[{{13.409480, 20.209143, 24.866106},{
      14.062857, 20.292961, 26.961365}}],
    Line[{{14.062857, 20.292961, 26.961365},{
      14.648148, 20.084488, 29.117067}}],
    Line[{{14.648148, 20.084488, 29.117067},{
      15.142642, 19.557669, 31.270023}}],
    Line[{{15.142642, 19.557669, 31.270023},{
      15.524064, 18.702747, 33.347626}}],
    Line[{{15.524064, 18.702747, 33.347626},{
      15.772277, 17.530102, 35.273243}}],
    Line[{{15.772277, 17.530102, 35.273243},{
      15.871106, 16.071859, 36.973278}}],
    Line[{{15.871106, 16.071859, 36.973278},{
      15.809981, 14.380629, 38.384670}}],
    Line[{{15.809981, 14.380629, 38.384670},{
      15.585181, 12.525251, 39.461647}}],
    Line[{{15.585181, 12.525251, 39.461647},{
      15.200402, 10.583931, 40.180298}}],
    Line[{{15.200402, 10.583931, 40.180298},{
      14.666556, 8.636185, 40.539978}}],
    Line[{{14.666556, 8.636185, 40.539978},{14.000835, 6.755034, 40.561600}}],
    
    Line[{{14.000835, 6.755034, 40.561600},{13.225167, 5.000814, 40.283077}}],
    
    Line[{{13.225167, 5.000814, 40.283077},{12.364358, 3.417521, 39.753319}}],
    
    Line[{{12.364358, 3.417521, 39.753319},{11.444202, 2.031761, 39.025955}}],
    
    Line[{{11.444202, 2.031761, 39.025955},{10.489772, 0.854012, 38.153835}}],
    
    Line[{{10.489772, 0.854012, 38.153835},{9.524079, -0.118616, 37.184967}}],
    
    Line[{{9.524079, -0.118616, 37.184967},{8.567163, -0.898916, 36.160072}}],
    
    Line[{{8.567163, -0.898916, 36.160072},{7.635601, -1.506102, 35.111649}}],
    
    Line[{{7.635601, -1.506102, 35.111649},{6.742378, -1.962767, 34.064110}}],
    
    Line[{{6.742378, -1.962767, 34.064110},{5.897030, -2.292491, 33.034668}}],
    
    Line[{{5.897030, -2.292491, 33.034668},{5.105965, -2.518147, 32.034561}}],
    
    Line[{{5.105965, -2.518147, 32.034561},{4.372883, -2.660836, 31.070347}}],
    
    Line[{{4.372883, -2.660836, 31.070347},{3.699235, -2.739305, 30.145149}}],
    
    Line[{{3.699235, -2.739305, 30.145149},{3.084673, -2.769733, 29.259687}}],
    
    Line[{{3.084673, -2.769733, 29.259687},{2.527467, -2.765767, 28.413113}}],
    
    Line[{{2.527467, -2.765767, 28.413113},{2.024867, -2.738688, 27.603649}}],
    
    Line[{{2.024867, -2.738688, 27.603649},{1.573416, -2.697669, 26.829054}}],
    
    Line[{{1.573416, -2.697669, 26.829054},{1.169207, -2.650049, 26.086916}}],
    
    Line[{{1.169207, -2.650049, 26.086916},{0.808078, -2.601622, 25.374868}}],
    
    Line[{{0.808078, -2.601622, 25.374868},{0.485779, -2.556894, 24.690702}}],
    
    Line[{{0.485779, -2.556894, 24.690702},{0.198089, -2.519324, 24.032433}}],
    
    Line[{{
      0.198089, -2.519324, 24.032433},{-0.059101, -2.491535, 23.398325}}],
    Line[{{-0.059101, -2.491535, 23.398325},{-0.289723, -2.475489, 
        22.786888}}],
    Line[{{-0.289723, -2.475489, 22.786888},{-0.497499, -2.472646, 
        22.196869}}],
    Line[{{-0.497499, -2.472646, 22.196869},{-0.685914, -2.484088, 
        21.627232}}],
    Line[{{-0.685914, -2.484088, 21.627232},{-0.858210, -2.510627, 
        21.077133}}],
    Line[{{-0.858210, -2.510627, 21.077133},{-1.017391, -2.552896, 
        20.545908}}],
    Line[{{-1.017391, -2.552896, 20.545908},{-1.166228, -2.611416, 
        20.033049}}],
    Line[{{-1.166228, -2.611416, 20.033049},{-1.307275, -2.686661, 
        19.538189}}],
    Line[{{-1.307275, -2.686661, 19.538189},{-1.442887, -2.779098, 
        19.061104}}],
    Line[{{-1.442887, -2.779098, 19.061104},{-1.575242, -2.889232, 
        18.601690}}],
    Line[{{-1.575242, -2.889232, 18.601690},{-1.706361, -3.017632, 
        18.159979}}],
    Line[{{-1.706361, -3.017632, 18.159979},{-1.838131, -3.164955, 
        17.736132}}],
    Line[{{-1.838131, -3.164955, 17.736132},{-1.972328, -3.331965, 
        17.330446}}],
    Line[{{-1.972328, -3.331965, 17.330446},{-2.110634, -3.519544, 
        16.943373}}],
    Line[{{-2.110634, -3.519544, 16.943373},{-2.254666, -3.728702, 
        16.575529}}],
    Line[{{-2.254666, -3.728702, 16.575529},{-2.405985, -3.960583, 
        16.227715}}],
    Line[{{-2.405985, -3.960583, 16.227715},{-2.566122, -4.216465, 
        15.900941}}],
    Line[{{-2.566122, -4.216465, 15.900941},{-2.736589, -4.497750, 
        15.596460}}],
    Line[{{-2.736589, -4.497750, 15.596460},{-2.918892, -4.805961, 
        15.315800}}],
    Line[{{-2.918892, -4.805961, 15.315800},{-3.114546, -5.142725, 
        15.060798}}],
    Line[{{-3.114546, -5.142725, 15.060798},{-3.325081, -5.509748, 
        14.833653}}],
    Line[{{-3.325081, -5.509748, 14.833653},{-3.552042, -5.908772, 
        14.636980}}],
    Line[{{-3.552042, -5.908772, 14.636980},{-3.796997, -6.341545, 
        14.473856}}],
    Line[{{-3.796997, -6.341545, 14.473856},{-4.061530, -6.809744, 
        14.347887}}],
    Line[{{-4.061530, -6.809744, 14.347887},{-4.347219, -7.314884, 
        14.263280}}],
    Line[{{-4.347219, -7.314884, 14.263280},{-4.655635, -7.858237, 
        14.224892}}],
    Line[{{-4.655635, -7.858237, 14.224892},{-4.988297, -8.440672, 
        14.238303}}],
    Line[{{-4.988297, -8.440672, 14.238303},{-5.346631, -9.062464, 
        14.309860}}],
    Line[{{-5.346631, -9.062464, 14.309860},{-5.731929, -9.723135, 
        14.446716}}],
    Line[{{-5.731929, -9.723135, 14.446716},{-6.145260, -10.421142, 
        14.656829}}],
    Line[{{-6.145260, -10.421142, 14.656829},{-6.587371, -11.153557, 
        14.948885}}],
    Line[{{-6.587371, -11.153557, 14.948885},{-7.058602, -11.915786, 
        15.332254}}],
    Line[{{-7.058602, -11.915786, 15.332254},{-7.558707, -12.701080, 
        15.816715}}],
    Line[{{-7.558707, -12.701080, 15.816715},{-8.086706, -13.500157, 
        16.412130}}],
    Line[{{-8.086706, -13.500157, 16.412130},{-8.640689, -14.300777, 
        17.127981}}],
    Line[{{-8.640689, -14.300777, 17.127981},{-9.217605, -15.087366, 
        17.972687}}],
    Line[{{-9.217605, -15.087366, 17.972687},{-9.813036, -15.840757, 
        18.952717}}],
    Line[{{-9.813036, -15.840757, 18.952717},{-10.420988, -16.538147, 
        20.071508}}],
    Line[{{-10.420988, -16.538147, 20.071508},{-11.033697, -17.153364, 
        21.328207}}],
    Line[{{-11.033697, -17.153364, 21.328207},{-11.641509, -17.657537, 
        22.716322}}],
    Line[{{-11.641509, -17.657537, 22.716322},{-12.232862, -18.020321, 
        24.222412}}],
    Line[{{-12.232862, -18.020321, 24.222412},{-12.794399, -18.211683, 
        25.825022}}],
    Line[{{-12.794399, -18.211683, 25.825022},{-13.311291, -18.204268, 
        27.494137}}],
    Line[{{-13.311291, -18.204268, 27.494137},{-13.767750, -17.976152, 
        29.191395}}],
    Line[{{-13.767750, -17.976152, 29.191395},{-14.147791, -17.513758, 
        30.871323}}],
    Line[{{-14.147791, -17.513758, 30.871323},{-14.436164, -16.814444, 
        32.483688}}],
    Line[{{-14.436164, -16.814444, 32.483688},{-14.619429, -15.888336, 
        33.976883}}],
    Line[{{-14.619429, -15.888336, 33.976883},{-14.687036, -14.758860, 
        35.302036}}],
    Line[{{-14.687036, -14.758860, 35.302036},{-14.632277, -13.461754, 
        36.417213}}],
    Line[{{-14.632277, -13.461754, 36.417213},{-14.452980, -12.042516, 
        37.291153}}],
    Line[{{-14.452980, -12.042516, 37.291153},{-14.151836, -10.552591, 
        37.905830}}],
    Line[{{-14.151836, -10.552591, 37.905830},{-13.736280, -9.044847, 
        38.257427}}],
    Line[{{-13.736280, -9.044847, 38.257427},{-13.217957, -7.569127, 
        38.355606}}],
    Line[{{-13.217957, -7.569127, 38.355606},{-12.611843, -6.168532, 
        38.221329}}],
    Line[{{-12.611843, -6.168532, 38.221329},{-11.935161, -4.876863, 
        37.883732}}],
    Line[{{-11.935161, -4.876863, 37.883732},{-11.206207, -3.717500, 
        37.376587}}],
    Line[{{-11.206207, -3.717500, 37.376587},{-10.443259, -2.703499, 
        36.735008}}],
    Line[{{-10.443259, -2.703499, 36.735008},{-9.663638, -1.838718, 
        35.992699}}],
    Line[{{-9.663638, -1.838718, 35.992699},{-8.883011, -1.119537, 
        35.180054}}],
    Line[{{-8.883011, -1.119537, 35.180054},{-8.114923, -0.536817, 
        34.323013}}],
    Line[{{-8.114923, -0.536817, 34.323013},{-7.370571, -0.077803, 
        33.442669}}],
    Line[{{-7.370571, -0.077803, 33.442669},{-6.658770, 0.272219, 
        32.555408}}],
    Line[{{-6.658770, 0.272219, 32.555408},{-5.986052, 0.528595, 31.673347}}],
    
    Line[{{-5.986052, 0.528595, 31.673347},{-5.356877, 0.706341, 30.805014}}],
    
    Line[{{-5.356877, 0.706341, 30.805014},{-4.773897, 0.819486, 29.956024}}],
    
    Line[{{-4.773897, 0.819486, 29.956024},{-4.238239, 0.880696, 29.129766}}],
    
    Line[{{-4.238239, 0.880696, 29.129766},{-3.749792, 0.901086, 28.327980}}],
    
    Line[{{-3.749792, 0.901086, 28.327980},{-3.307473, 0.890189, 27.551249}}],
    
    Line[{{-3.307473, 0.890189, 27.551249},{-2.909472, 0.856019, 26.799381}}],
    
    Line[{{-2.909472, 0.856019, 26.799381},{-2.553454, 0.805178, 26.071709}}],
    
    Line[{{-2.553454, 0.805178, 26.071709},{-2.236743, 0.743016, 25.367285}}],
    
    Line[{{-2.236743, 0.743016, 25.367285},{-1.956463, 0.673779, 24.685043}}],
    
    Line[{{-1.956463, 0.673779, 24.685043},{-1.709652, 0.600774, 24.023888}}],
    
    Line[{{-1.709652, 0.600774, 24.023888},{-1.493356, 0.526512, 23.382751}}],
    
    Line[{{-1.493356, 0.526512, 23.382751},{-1.304696, 0.452845, 22.760635}}],
    
    Line[{{-1.304696, 0.452845, 22.760635},{-1.140919, 0.381083, 22.156620}}],
    
    Line[{{-1.140919, 0.381083, 22.156620},{-0.999430, 0.312100, 21.569870}}],
    
    Line[{{-0.999430, 0.312100, 21.569870},{-0.877814, 0.246423, 20.999636}}],
    
    Line[{{-0.877814, 0.246423, 20.999636},{-0.773853, 0.184304, 20.445238}}],
    
    Line[{{-0.773853, 0.184304, 20.445238},{-0.685523, 0.125784, 19.906069}}],
    
    Line[{{-0.685523, 0.125784, 19.906069},{-0.610999, 0.070743, 19.381575}}],
    
    Line[{{-0.610999, 0.070743, 19.381575},{-0.548647, 0.018946, 18.871258}}],
    
    Line[{{-0.548647, 0.018946, 18.871258},{-0.497015, -0.029934, 
        18.374653}}],
    Line[{{-0.497015, -0.029934, 18.374653},{-0.454823, -0.076280, 
        17.891338}}],
    Line[{{-0.454823, -0.076280, 17.891338},{-0.420951, -0.120517, 
        17.420919}}],
    Line[{{-0.420951, -0.120517, 17.420919},{-0.394430, -0.163097, 
        16.963026}}],
    Line[{{-0.394430, -0.163097, 16.963026},{-0.374423, -0.204487, 
        16.517309}}],
    Line[{{-0.374423, -0.204487, 16.517309},{-0.360222, -0.245163, 
        16.083439}}],
    Line[{{-0.360222, -0.245163, 16.083439},{-0.351228, -0.285605, 
        15.661104}}],
    Line[{{-0.351228, -0.285605, 15.661104},{-0.346947, -0.326295, 
        15.250006}}],
    Line[{{-0.346947, -0.326295, 15.250006},{-0.346978, -0.367721, 
        14.849861}}],
    Line[{{-0.346978, -0.367721, 14.849861},{-0.351004, -0.410369, 
        14.460398}}],
    Line[{{-0.351004, -0.410369, 14.460398},{-0.358785, -0.454738, 
        14.081360}}],
    Line[{{-0.358785, -0.454738, 14.081360},{-0.370151, -0.501330, 
        13.712501}}],
    Line[{{-0.370151, -0.501330, 13.712501},{-0.384998, -0.550667, 
        13.353590}}],
    Line[{{-0.384998, -0.550667, 13.353590},{-0.403283, -0.603287, 
        13.004409}}],
    Line[{{-0.403283, -0.603287, 13.004409},{-0.425016, -0.659754, 
        12.664753}}],
    Line[{{-0.425016, -0.659754, 12.664753},{-0.450266, -0.720662, 
        12.334436}}],
    Line[{{-0.450266, -0.720662, 12.334436},{-0.479149, -0.786645, 
        12.013288}}],
    Line[{{-0.479149, -0.786645, 12.013288},{-0.511836, -0.858378, 
        11.701156}}],
    Line[{{-0.511836, -0.858378, 11.701156},{-0.548546, -0.936592, 
        11.397912}}],
    Line[{{-0.548546, -0.936592, 11.397912},{-0.589552, -1.022077, 
        11.103453}}],
    Line[{{-0.589552, -1.022077, 11.103453},{-0.635177, -1.115695, 
        10.817701}}],
    Line[{{-0.635177, -1.115695, 10.817701},{-0.685801, -1.218387, 
        10.540618}}],
    Line[{{-0.685801, -1.218387, 10.540618},{-0.741861, -1.331182, 
        10.272199}}],
    Line[{{-0.741861, -1.331182, 10.272199},{-0.803854, -1.455213, 
        10.012489}}],
    Line[{{-0.803854, -1.455213, 10.012489},{-0.872345, -1.591726, 
        9.761587}}],
    Line[{{-0.872345, -1.591726, 9.761587},{-0.947968, -1.742091, 9.519660}}],
    
    Line[{{-0.947968, -1.742091, 9.519660},{-1.031436, -1.907819, 9.286950}}],
    
    Line[{{-1.031436, -1.907819, 9.286950},{-1.123542, -2.090578, 9.063797}}],
    
    Line[{{-1.123542, -2.090578, 9.063797},{-1.225173, -2.292200, 8.850654}}],
    
    Line[{{-1.225173, -2.292200, 8.850654},{-1.337315, -2.514707, 8.648110}}],
    
    Line[{{-1.337315, -2.514707, 8.648110},{-1.461059, -2.760319, 8.456923}}],
    
    Line[{{-1.461059, -2.760319, 8.456923},{-1.597617, -3.031472, 8.278057}}],
    
    Line[{{-1.597617, -3.031472, 8.278057},{-1.748327, -3.330837, 8.112706}}],
    
    Line[{{-1.748327, -3.330837, 8.112706},{-1.914666, -3.661318, 7.962373}}],
    
    Line[{{-1.914666, -3.661318, 7.962373},{-2.098259, -4.026078, 7.828913}}],
    
    Line[{{-2.098259, -4.026078, 7.828913},{-2.300889, -4.428535, 7.714607}}],
    
    Line[{{-2.300889, -4.428535, 7.714607},{-2.524508, -4.872341, 7.622271}}],
    
    Line[{{-2.524508, -4.872341, 7.622271},{-2.771240, -5.361382, 7.555340}}],
    
    Line[{{-2.771240, -5.361382, 7.555340},{-3.043385, -5.899740, 7.518000}}],
    
    Line[{{-3.043385, -5.899740, 7.518000},{-3.343419, -6.491599, 7.515343}}],
    
    Line[{{-3.343419, -6.491599, 7.515343},{-3.673990, -7.141204, 7.553517}}],
    
    Line[{{-3.673990, -7.141204, 7.553517},{-4.037879, -7.852636, 7.639934}}],
    
    Line[{{-4.037879, -7.852636, 7.639934},{-4.437994, -8.629700, 7.783458}}],
    
    Line[{{-4.437994, -8.629700, 7.783458},{-4.877291, -9.475538, 7.994638}}],
    
    Line[{{-4.877291, -9.475538, 7.994638},{-5.358696, -10.392297, 
        8.285902}}],
    Line[{{-5.358696, -10.392297, 8.285902},{-5.884998, -11.380597, 
        8.671762}}],
    Line[{{-5.884998, -11.380597, 8.671762},{-6.458679, -12.438841, 
        9.168928}}],
    Line[{{-6.458679, -12.438841, 9.168928},{-7.081681, -13.562346, 
        9.796274}}],
    Line[{{-7.081681, -13.562346, 9.796274},{-7.755143, -14.742350, 
        10.574730}}],
    Line[{{-7.755143, -14.742350, 10.574730},{-8.478999, -15.964724, 
        11.526675}}],
    Line[{{-8.478999, -15.964724, 11.526675},{-9.251539, -17.208662, 
        12.675097}}],
    Line[{{-9.251539, -17.208662, 12.675097},{-10.068853, -18.445286, 
        14.042049}}],
    Line[{{-10.068853, -18.445286, 14.042049},{-10.924219, -19.636477, 
        15.646443}}],
    Line[{{-10.924219, -19.636477, 15.646443},{-11.807446, -20.734179, 
        17.501041}}],
    Line[{{-11.807446, -20.734179, 17.501041},{-12.704263, -21.680601, 
        19.608654}}],
    Line[{{-12.704263, -21.680601, 19.608654},{-13.595838, -22.409897, 
        21.957747}}],
    Line[{{-13.595838, -22.409897, 21.957747},{-14.458632, -22.851896, 
        24.518131}}],
    Line[{{-14.458632, -22.851896, 24.518131},{-15.264674, -22.937876, 
        27.237423}}],
    Line[{{-15.264674, -22.937876, 27.237423},{-15.982511, -22.608728, 
        30.039635}}],
    Line[{{-15.982511, -22.608728, 30.039635},{-16.578896, -21.824371, 
        32.827072}}],
    Line[{{-16.578896, -21.824371, 32.827072},{-17.021242, -20.573050, 
        35.486481}}],
    Line[{{-17.021242, -20.573050, 35.486481},{-17.280598, -18.878040, 
        37.899529}}],
    Line[{{-17.280598, -18.878040, 37.899529},{-17.334795, -16.799891, 
        39.956264}}],
    Line[{{-17.334795, -16.799891, 39.956264},{-17.171198, -14.432349, 
        41.569157}}],
    Line[{{-17.171198, -14.432349, 41.569157},{-16.788519, -11.892235, 
        42.684418}}],
    Line[{{-16.788519, -11.892235, 42.684418},{-16.197252, -9.305206, 
        43.287918}}],
    Line[{{-16.197252, -9.305206, 43.287918},{-15.418657, -6.790416, 
        43.404327}}],
    Line[{{-15.418657, -6.790416, 43.404327},{-14.482460, -4.447672, 
        43.090065}}],
    Line[{{-14.482460, -4.447672, 43.090065},{-13.423767, -2.349265, 
        42.422337}}],
    Line[{{-13.423767, -2.349265, 42.422337},{-12.279766, -0.537399, 
        41.487057}}],
    Line[{{-12.279766, -0.537399, 41.487057},{-11.086746, 0.973555, 
        40.368317}}],
    Line[{{-11.086746, 0.973555, 40.368317},{-9.877771, 2.191663, 
        39.140762}}],
    Line[{{-9.877771, 2.191663, 39.140762},{-8.681177, 3.140743, 37.865467}}],
    
    Line[{{-8.681177, 3.140743, 37.865467},{-7.519836, 3.853877, 36.588699}}],
    
    Line[{{-7.519836, 3.853877, 36.588699},{-6.411080, 4.368026, 35.342873}}],
    
    Line[{{-6.411080, 4.368026, 35.342873},{-5.367038, 4.720122, 34.148590}}],
    
    Line[{{-5.367038, 4.720122, 34.148590},{-4.395284, 4.944539, 33.017235}}],
    
    Line[{{-4.395284, 4.944539, 33.017235},{-3.499583, 5.071741, 31.953451}}],
    
    Line[{{-3.499583, 5.071741, 31.953451},{-2.680654, 5.127764, 30.957310}}],
    
    Line[{{-2.680654, 5.127764, 30.957310},{-1.936882, 5.134253, 30.026024}}],
    
    Line[{{-1.936882, 5.134253, 30.026024},{-1.264949, 5.108797, 29.155241}}],
    
    Line[{{-1.264949, 5.108797, 29.155241},{-0.660352, 5.065437, 28.339943}}],
    
    Line[{{-0.660352, 5.065437, 28.339943},{-0.117832, 5.015194, 27.575052}}],
    
    Line[{{-0.117832, 5.015194, 27.575052},{0.368294, 4.966598, 26.855783}}],
    Line[{{0.368294, 4.966598, 26.855783},{0.803880, 4.926156, 26.177855}}],
    Line[{{0.803880, 4.926156, 26.177855},{1.194758, 4.898763, 25.537573}}],
    Line[{{1.194758, 4.898763, 25.537573},{1.546612, 4.888045, 24.931858}}],
    Line[{{1.546612, 4.888045, 24.931858},{1.864876, 4.896649, 24.358219}}],
    Line[{{1.864876, 4.896649, 24.358219},{2.154683, 4.926474, 23.814713}}],
    Line[{{2.154683, 4.926474, 23.814713},{2.420830, 4.978857, 23.299891}}],
    Line[{{2.420830, 4.978857, 23.299891},{2.667763, 5.054727, 22.812746}}],
    Line[{{2.667763, 5.054727, 22.812746},{2.899579, 5.154720, 22.352671}}],
    Line[{{2.899579, 5.154720, 22.352671},{3.120034, 5.279271, 21.919416}}],
    Line[{{3.120034, 5.279271, 21.919416},{3.332562, 5.428677, 21.513060}}],
    Line[{{3.332562, 5.428677, 21.513060},{3.540294, 5.603150, 21.133980}}],
    Line[{{3.540294, 5.603150, 21.133980},{3.746080, 5.802849, 20.782848}}],
    Line[{{3.746080, 5.802849, 20.782848},{3.952512, 6.027888, 20.460617}}],
    Line[{{3.952512, 6.027888, 20.460617},{4.161943, 6.278347, 20.168518}}],
    Line[{{4.161943, 6.278347, 20.168518},{4.376512, 6.554257, 19.908062}}],
    Line[{{4.376512, 6.554257, 19.908062},{4.598146, 6.855578, 19.681049}}],
    Line[{{4.598146, 6.855578, 19.681049},{4.828590, 7.182170, 19.489571}}],
    Line[{{4.828590, 7.182170, 19.489571},{5.069396, 7.533741, 19.336012}}],
    Line[{{5.069396, 7.533741, 19.336012},{5.321932, 7.909780, 19.223064}}],
    Line[{{5.321932, 7.909780, 19.223064},{5.587375, 8.309505, 19.153711}}],
    Line[{{5.587375, 8.309505, 19.153711},{5.866700, 8.731765, 19.131224}}],
    Line[{{5.866700, 8.731765, 19.131224},{6.160654, 9.174936, 19.159126}}],
    Line[{{6.160654, 9.174936, 19.159126},{6.469734, 9.636826, 19.241158}}],
    Line[{{6.469734, 9.636826, 19.241158},{6.794151, 10.114549, 19.381218}}],
    Line[{{6.794151, 10.114549, 19.381218},{7.133779, 10.604398, 19.583231}}],
    
    Line[{{7.133779, 10.604398, 19.583231},{7.488104, 11.101709, 19.851065}}],
    
    Line[{{7.488104, 11.101709, 19.851065},{7.856174, 11.600775, 20.188318}}],
    
    Line[{{7.856174, 11.600775, 20.188318},{8.236523, 12.094707, 20.598116}}],
    
    Line[{{8.236523, 12.094707, 20.598116},{8.627108, 12.575387, 21.082844}}],
    
    Line[{{8.627108, 12.575387, 21.082844},{9.025257, 13.033488, 21.643814}}],
    
    Line[{{9.025257, 13.033488, 21.643814},{9.427594, 13.458450, 22.280928}}],
    
    Line[{{9.427594, 13.458450, 22.280928},{9.830025, 13.838761, 22.992281}}],
    
    Line[{{9.830025, 13.838761, 22.992281},{
      10.227692, 14.162105, 23.773775}}],
    Line[{{10.227692, 14.162105, 23.773775},{
      10.615017, 14.415864, 24.618765}}],
    Line[{{10.615017, 14.415864, 24.618765},{
      10.985768, 14.587640, 25.517838}}],
    Line[{{10.985768, 14.587640, 25.517838},{
      11.333136, 14.665898, 26.458525}}],
    Line[{{11.333136, 14.665898, 26.458525},{
      11.649961, 14.640795, 27.425550}}],
    Line[{{11.649961, 14.640795, 27.425550},{
      11.928929, 14.504942, 28.400944}}],
    Line[{{11.928929, 14.504942, 28.400944},{
      12.162880, 14.254230, 29.364628}}],
    Line[{{12.162880, 14.254230, 29.364628},{
      12.345123, 13.888466, 30.295212}}],
    Line[{{12.345123, 13.888466, 30.295212},{
      12.469795, 13.411811, 31.170984}}],
    Line[{{12.469795, 13.411811, 31.170984},{
      12.532206, 12.832906, 31.971081}}],
    Line[{{12.532206, 12.832906, 31.971081},{
      12.529137, 12.164653, 32.676670}}],
    Line[{{12.529137, 12.164653, 32.676670},{
      12.459098, 11.423621, 33.272079}}],
    Line[{{12.459098, 11.423621, 33.272079},{
      12.322453, 10.629103, 33.745663}}],
    Line[{{12.322453, 10.629103, 33.745663},{
      12.121452, 9.801967, 34.090359}}],
    Line[{{12.121452, 9.801967, 34.090359},{11.860143, 8.963421, 34.303864}}],
    
    Line[{{11.860143, 8.963421, 34.303864},{11.544174, 8.133763, 34.388470}}],
    
    Line[{{11.544174, 8.133763, 34.388470},{11.180496, 7.331303, 34.350468}}],
    
    Line[{{11.180496, 7.331303, 34.350468},{10.777018, 6.571627, 34.199409}}],
    
    Line[{{10.777018, 6.571627, 34.199409},{10.342220, 5.867040, 33.947159}}],
    
    Line[{{10.342220, 5.867040, 33.947159},{9.884784, 5.226404, 33.606953}}],
    Line[{{9.884784, 5.226404, 33.606953},{9.413241, 4.655230, 33.192535}}],
    Line[{{9.413241, 4.655230, 33.192535},{8.935689, 4.155982, 32.717415}}],
    Line[{{8.935689, 4.155982, 32.717415},{8.459555, 3.728529, 32.194305}}],
    Line[{{8.459555, 3.728529, 32.194305},{7.991445, 3.370670, 31.634743}}],
    Line[{{7.991445, 3.370670, 31.634743},{7.537047, 3.078663, 31.048882}}],
    Line[{{7.537047, 3.078663, 31.048882},{7.101100, 2.847735, 30.445423}}],
    Line[{{7.101100, 2.847735, 30.445423},{6.687404, 2.672514, 29.831644}}],
    Line[{{6.687404, 2.672514, 29.831644},{6.298873, 2.547401, 29.213505}}],
    Line[{{6.298873, 2.547401, 29.213505},{5.937611, 2.466856, 28.595802}}],
    Line[{{5.937611, 2.466856, 28.595802},{5.605006, 2.425602, 27.982334}}],
    Line[{{5.605006, 2.425602, 27.982334},{5.301832, 2.418777, 27.376068}}],
    Line[{{5.301832, 2.418777, 27.376068},{5.028348, 2.442023, 26.779305}}],
    Line[{{5.028348, 2.442023, 26.779305},{4.784404, 2.491529, 26.193823}}],
    Line[{{4.784404, 2.491529, 26.193823},{4.569525, 2.564044, 25.620998}}],
    Line[{{4.569525, 2.564044, 25.620998},{4.382998, 2.656872, 25.061905}}],
    Line[{{4.382998, 2.656872, 25.061905},{4.223952, 2.767839, 24.517414}}],
    Line[{{4.223952, 2.767839, 24.517414},{4.091411, 2.895259, 23.988249}}],
    Line[{{4.091411, 2.895259, 23.988249},{3.984354, 3.037891, 23.475054}}],
    Line[{{3.984354, 3.037891, 23.475054},{3.901762, 3.194893, 22.978422}}],
    Line[{{3.901762, 3.194893, 22.978422},{3.842646, 3.365778, 22.498953}}],
    Line[{{3.842646, 3.365778, 22.498953},{3.806083, 3.550374, 22.037268}}],
    Line[{{3.806083, 3.550374, 22.037268},{3.791234, 3.748776, 21.594038}}],
    Line[{{3.791234, 3.748776, 21.594038},{3.797362, 3.961315, 21.170013}}],
    Line[{{3.797362, 3.961315, 21.170013},{3.823840, 4.188518, 20.766039}}],
    Line[{{3.823840, 4.188518, 20.766039},{3.870157, 4.431076, 20.383081}}],
    Line[{{3.870157, 4.431076, 20.383081},{3.935925, 4.689813, 20.022240}}],
    Line[{{3.935925, 4.689813, 20.022240},{4.020880, 4.965652, 19.684784}}],
    Line[{{4.020880, 4.965652, 19.684784},{4.124868, 5.259585, 19.372164}}],
    Line[{{4.124868, 5.259585, 19.372164},{4.247850, 5.572639, 19.086035}}],
    Line[{{4.247850, 5.572639, 19.086035},{4.389888, 5.905837, 18.828295}}],
    Line[{{4.389888, 5.905837, 18.828295},{4.551134, 6.260160, 18.601093}}],
    Line[{{4.551134, 6.260160, 18.601093},{4.731814, 6.636495, 18.406874}}],
    Line[{{4.731814, 6.636495, 18.406874},{4.932209, 7.035580, 18.248383}}],
    Line[{{4.932209, 7.035580, 18.248383},{5.152638, 7.457936, 18.128700}}],
    Line[{{5.152638, 7.457936, 18.128700},{5.393420, 7.903789, 18.051260}}],
    Line[{{5.393420, 7.903789, 18.051260},{5.654851, 8.372975, 18.019846}}],
    Line[{{5.654851, 8.372975, 18.019846},{5.937160, 8.864836, 18.038593}}],
    Line[{{5.937160, 8.864836, 18.038593},{6.240458, 9.378081, 18.111969}}],
    Line[{{6.240458, 9.378081, 18.111969},{6.564693, 9.910669, 18.244732}}],
    Line[{{6.564693, 9.910669, 18.244732},{6.909576, 10.459625, 18.441828}}],
    Line[{{6.909576, 10.459625, 18.441828},{7.274515, 11.020899, 18.708317}}],
    
    Line[{{7.274515, 11.020899, 18.708317},{7.658525, 11.589181, 19.049158}}],
    
    Line[{{7.658525, 11.589181, 19.049158},{8.060148, 12.157756, 19.469021}}],
    
    Line[{{8.060148, 12.157756, 19.469021},{8.477345, 12.718348, 19.971979}}],
    
    Line[{{8.477345, 12.718348, 19.971979},{8.907412, 13.261059, 20.561146}}],
    
    Line[{{8.907412, 13.261059, 20.561146},{9.346871, 13.774341, 21.238237}}],
    
    Line[{{9.346871, 13.774341, 21.238237},{9.791410, 14.245099, 22.003107}}],
    
    Line[{{9.791410, 14.245099, 22.003107},{
      10.235811, 14.658913, 22.853195}}],
    Line[{{10.235811, 14.658913, 22.853195},{
      10.673923, 15.000428, 23.783005}}],
    Line[{{10.673923, 15.000428, 23.783005},{
      11.098717, 15.254009, 24.783680}}],
    Line[{{11.098717, 15.254009, 24.783680},{
      11.502342, 15.404447, 25.842600}}],
    Line[{{11.502342, 15.404447, 25.842600},{
      11.876311, 15.438007, 26.943251}}],
    Line[{{11.876311, 15.438007, 26.943251},{
      12.211767, 15.343466, 28.065495}}],
    Line[{{12.211767, 15.343466, 28.065495},{
      12.499775, 15.113288, 29.185831}}],
    Line[{{12.499775, 15.113288, 29.185831},{
      12.731765, 14.744579, 30.278524}}],
    Line[{{12.731765, 14.744579, 30.278524},{
      12.899964, 14.239928, 31.316675}}],
    Line[{{12.899964, 14.239928, 31.316675},{
      12.997868, 13.607754, 32.273781}}],
    Line[{{12.997868, 13.607754, 32.273781},{
      13.020668, 12.862267, 33.125347}}],
    Line[{{13.020668, 12.862267, 33.125347},{
      12.965633, 12.022841, 33.850521}}],
    Line[{{12.965633, 12.022841, 33.850521},{
      12.832338, 11.112849, 34.433395}}],
    Line[{{12.832338, 11.112849, 34.433395},{
      12.622753, 10.158177, 34.863926}}],
    Line[{{12.622753, 10.158177, 34.863926},{
      12.341177, 9.185529, 35.138309}}],
    Line[{{12.341177, 9.185529, 35.138309},{11.994011, 8.220665, 35.258835}}],
    
    Line[{{11.994011, 8.220665, 35.258835},{11.589393, 7.286928, 35.233181}}],
    
    Line[{{11.589393, 7.286928, 35.233181},{11.136738, 6.404087, 35.073338}}],
    
    Line[{{11.136738, 6.404087, 35.073338},{10.646248, 5.587598, 34.794373}}],
    
    Line[{{10.646248, 5.587598, 34.794373},{10.128401, 4.848363, 34.413082}}],
    
    Line[{{10.128401, 4.848363, 34.413082},{9.593500, 4.192863, 33.946812}}],
    Line[{{9.593500, 4.192863, 33.946812},{9.051288, 3.623595, 33.412437}}],
    Line[{{9.051288, 3.623595, 33.412437},{8.510650, 3.139729, 32.825634}}],
    Line[{{8.510650, 3.139729, 32.825634},{7.979415, 2.737819, 32.200390}}],
    Line[{{7.979415, 2.737819, 32.200390},{7.464245, 2.412554, 31.548767}}],
    Line[{{7.464245, 2.412554, 31.548767},{6.970596, 2.157426, 30.880856}}],
    Line[{{6.970596, 2.157426, 30.880856},{6.502754, 1.965307, 30.204865}}],
    Line[{{6.502754, 1.965307, 30.204865},{6.063906, 1.828918, 29.527302}}],
    Line[{{6.063906, 1.828918, 29.527302},{5.656251, 1.741177, 28.853205}}],
    Line[{{5.656251, 1.741177, 28.853205},{5.281126, 1.695444, 28.186386}}],
    Line[{{5.281126, 1.695444, 28.186386},{4.939136, 1.685677, 27.529669}}],
    Line[{{4.939136, 1.685677, 27.529669},{4.630284, 1.706531, 26.885094}}],
    Line[{{4.630284, 1.706531, 26.885094},{4.354103, 1.753382, 26.254105}}],
    Line[{{4.354103, 1.753382, 26.254105},{4.109762, 1.822329, 25.637714}}],
    Line[{{4.109762, 1.822329, 25.637714},{3.896174, 1.910160, 25.036615}}],
    Line[{{3.896174, 1.910160, 25.036615},{3.712080, 2.014308, 24.451288}}],
    Line[{{3.712080, 2.014308, 24.451288},{3.556125, 2.132790, 23.882074}}],
    Line[{{3.556125, 2.132790, 23.882074},{3.426921, 2.264151, 23.329233}}],
    Line[{{3.426921, 2.264151, 23.329233},{3.323097, 2.407404, 22.792994}}],
    Line[{{3.323097, 2.407404, 22.792994},{3.243339, 2.561970, 22.273581}}],
    Line[{{3.243339, 2.561970, 22.273581},{3.186418, 2.727632, 21.771244}}],
    Line[{{3.186418, 2.727632, 21.771244},{3.151221, 2.904478, 21.286285}}],
    Line[{{3.151221, 2.904478, 21.286285},{3.136758, 3.092867, 20.819067}}],
    Line[{{3.136758, 3.092867, 20.819067},{3.142183, 3.293387, 20.370039}}],
    Line[{{3.142183, 3.293387, 20.370039},{3.166793, 3.506827, 19.939747}}],
    Line[{{3.166793, 3.506827, 19.939747},{3.210038, 3.734142, 19.528852}}],
    Line[{{3.210038, 3.734142, 19.528852},{3.271516, 3.976434, 19.138151}}],
    Line[{{3.271516, 3.976434, 19.138151},{3.350976, 4.234921, 18.768599}}],
    Line[{{3.350976, 4.234921, 18.768599},{3.448311, 4.510926, 18.421318}}],
    Line[{{3.448311, 4.510926, 18.421318},{3.563554, 4.805840, 18.097641}}],
    Line[{{3.563554, 4.805840, 18.097641},{3.696869, 5.121109, 17.799126}}],
    Line[{{3.696869, 5.121109, 17.799126},{3.848545, 5.458197, 17.527592}}],
    Line[{{3.848545, 5.458197, 17.527592},{4.018982, 5.818563, 17.285149}}],
    Line[{{4.018982, 5.818563, 17.285149},{4.208678, 6.203611, 17.074238}}],
    Line[{{4.208678, 6.203611, 17.074238},{4.418212, 6.614641, 16.897663}}],
    Line[{{4.418212, 6.614641, 16.897663},{4.648229, 7.052797, 16.758635}}],
    Line[{{4.648229, 7.052797, 16.758635},{4.899403, 7.518973, 16.660795}}],
    Line[{{4.899403, 7.518973, 16.660795},{5.172419, 8.013740, 16.608263}}],
    Line[{{5.172419, 8.013740, 16.608263},{5.467930, 8.537206, 16.605640}}],
    Line[{{5.467930, 8.537206, 16.605640},{5.786507, 9.088900, 16.658031}}],
    Line[{{5.786507, 9.088900, 16.658031},{6.128591, 9.667595, 16.771029}}],
    Line[{{6.128591, 9.667595, 16.771029},{6.494414, 10.271120, 16.950651}}],
    Line[{{6.494414, 10.271120, 16.950651},{6.883934, 10.896152, 17.203306}}],
    
    Line[{{6.883934, 10.896152, 17.203306},{7.296722, 11.537972, 17.535580}}],
    
    Line[{{7.296722, 11.537972, 17.535580},{7.731872, 12.190232, 17.954103}}],
    
    Line[{{7.731872, 12.190232, 17.954103},{8.187863, 12.844697, 18.465206}}],
    
    Line[{{8.187863, 12.844697, 18.465206},{8.662445, 13.491075, 19.074530}}],
    
    Line[{{8.662445, 13.491075, 19.074530},{9.152485, 14.116780, 19.786570}}],
    
    Line[{{9.152485, 14.116780, 19.786570},{9.653847, 14.707011, 20.604000}}],
    
    Line[{{9.653847, 14.707011, 20.604000},{
      10.161272, 15.244761, 21.527023}}],
    Line[{{10.161272, 15.244761, 21.527023},{
      10.668286, 15.711159, 22.552576}}],
    Line[{{10.668286, 15.711159, 22.552576},{
      11.167171, 16.086075, 23.673552}}],
    Line[{{11.167171, 16.086075, 23.673552},{
      11.649007, 16.348993, 24.878180}}],
    Line[{{11.649007, 16.348993, 24.878180},{
      12.103781, 16.480156, 26.149431}}],
    Line[{{12.103781, 16.480156, 26.149431},{
      12.520658, 16.462080, 27.464935}}],
    Line[{{12.520658, 16.462080, 27.464935},{
      12.888352, 16.281139, 28.797337}}],
    Line[{{12.888352, 16.281139, 28.797337},{
      13.195595, 15.929222, 30.115013}}],
    Line[{{13.195595, 15.929222, 30.115013},{
      13.431752, 15.405141, 31.383669}}],
    Line[{{13.431752, 15.405141, 31.383669},{
      13.587466, 14.715615, 32.568230}}],
    Line[{{13.587466, 14.715615, 32.568230},{
      13.655304, 13.875566, 33.635208}}],
    Line[{{13.655304, 13.875566, 33.635208},{
      13.630342, 12.907626, 34.555099}}],
    Line[{{13.630342, 12.907626, 34.555099},{
      13.510602, 11.840792, 35.304565}}],
    Line[{{13.510602, 11.840792, 35.304565},{
      13.297278, 10.708417, 35.868057}}],
    Line[{{13.297278, 10.708417, 35.868057},{
      12.994741, 9.545733, 36.238697}}],
    Line[{{12.994741, 9.545733, 36.238697},{12.610284, 8.387239, 36.418201}}],
    
    Line[{{12.610284, 8.387239, 36.418201},{12.153653, 7.264433, 36.416031}}],
    
    Line[{{12.153653, 7.264433, 36.416031},{11.636449, 6.203957, 36.247883}}],
    
    Line[{{11.636449, 6.203957, 36.247883},{11.071416, 5.226450, 35.933826}}],
    
    Line[{{11.071416, 5.226450, 35.933826},{10.471743, 4.346144, 35.496326}}],
    
    Line[{{10.471743, 4.346144, 35.496326},{9.850410, 3.571062, 34.958462}}],
    Line[{{9.850410, 3.571062, 34.958462},{9.219657, 2.903706, 34.342430}}],
    Line[{{9.219657, 2.903706, 34.342430},{8.590565, 2.342034, 33.668522}}],
    Line[{{8.590565, 2.342034, 33.668522},{7.972790, 1.880554, 32.954468}}],
    Line[{{7.972790, 1.880554, 32.954468},{7.374426, 1.511409, 32.215157}}],
    Line[{{7.374426, 1.511409, 32.215157},{6.801974, 1.225337, 31.462662}}],
    Line[{{6.801974, 1.225337, 31.462662},{6.260397, 1.012470, 30.706438}}],
    Line[{{6.260397, 1.012470, 30.706438},{5.753245, 0.862948, 29.953644}}],
    Line[{{5.753245, 0.862948, 29.953644},{5.282811, 0.767364, 29.209515}}],
    Line[{{5.282811, 0.767364, 29.209515},{4.850308, 0.717051, 28.477734}}],
    Line[{{4.850308, 0.717051, 28.477734},{4.456050, 0.704252, 27.760767}}],
    Line[{{4.456050, 0.704252, 27.760767},{4.099635, 0.722198, 27.060173}}],
    Line[{{4.099635, 0.722198, 27.060173},{3.780097, 0.765110, 26.376842}}],
    Line[{{3.780097, 0.765110, 26.376842},{3.496064, 0.828165, 25.711199}}],
    Line[{{3.496064, 0.828165, 25.711199},{3.245875, 0.907424, 25.063351}}],
    Line[{{3.245875, 0.907424, 25.063351},{3.027695, 0.999753, 24.433214}}],
    Line[{{3.027695, 0.999753, 24.433214},{2.839598, 1.102735, 23.820581}}],
    Line[{{2.839598, 1.102735, 23.820581},{2.679644, 1.214576, 23.225197}}],
    Line[{{2.679644, 1.214576, 23.225197},{2.545933, 1.334028, 22.646790}}],
    Line[{{2.545933, 1.334028, 22.646790},{2.436651, 1.460308, 22.085100}}],
    Line[{{2.436651, 1.460308, 22.085100},{2.350102, 1.593030, 21.539904}}],
    Line[{{2.350102, 1.593030, 21.539904},{2.284729, 1.732147, 21.011023}}],
    Line[{{2.284729, 1.732147, 21.011023},{2.239136, 1.877896, 20.498329}}],
    Line[{{2.239136, 1.877896, 20.498329},{2.212092, 2.030761, 20.001764}}],
    Line[{{2.212092, 2.030761, 20.001764},{2.202543, 2.191431, 19.521330}}],
    Line[{{2.202543, 2.191431, 19.521330},{2.209605, 2.360775, 19.057106}}],
    Line[{{2.209605, 2.360775, 19.057106},{2.232573, 2.539822, 18.609255}}],
    Line[{{2.232573, 2.539822, 18.609255},{2.270911, 2.729737, 18.178032}}],
    Line[{{2.270911, 2.729737, 18.178032},{2.324252, 2.931813, 17.763792}}],
    Line[{{2.324252, 2.931813, 17.763792},{2.392394, 3.147461, 17.367012}}],
    Line[{{2.392394, 3.147461, 17.367012},{2.475292, 3.378198, 16.988300}}],
    Line[{{2.475292, 3.378198, 16.988300},{2.573055, 3.625645, 16.628418}}],
    Line[{{2.573055, 3.625645, 16.628418},{2.685941, 3.891518, 16.288307}}],
    Line[{{2.685941, 3.891518, 16.288307},{2.814352, 4.177624, 15.969110}}],
    Line[{{2.814352, 4.177624, 15.969110},{2.958825, 4.485849, 15.672209}}],
    Line[{{2.958825, 4.485849, 15.672209},{3.120032, 4.818148, 15.399260}}],
    Line[{{3.120032, 4.818148, 15.399260},{3.298767, 5.176523, 15.152232}}],
    Line[{{3.298767, 5.176523, 15.152232},{3.495943, 5.563004, 14.933460}}],
    Line[{{3.495943, 5.563004, 14.933460},{3.712576, 5.979606, 14.745689}}],
    Line[{{3.712576, 5.979606, 14.745689},{3.949778, 6.428287, 14.592141}}],
    Line[{{3.949778, 6.428287, 14.592141},{4.208732, 6.910874, 14.476565}}],
    Line[{{4.208732, 6.910874, 14.476565},{4.490678, 7.428993, 14.403314}}],
    Line[{{4.490678, 7.428993, 14.403314},{4.796872, 7.983932, 14.377385}}],
    Line[{{4.796872, 7.983932, 14.377385},{5.128559, 8.576530, 14.404507}}],
    Line[{{5.128559, 8.576530, 14.404507},{5.486907, 9.206964, 14.491145}}],
    Line[{{5.486907, 9.206964, 14.491145},{5.872960, 9.874560, 14.644571}}],
    Line[{{5.872960, 9.874560, 14.644571},{6.287535, 10.577507, 14.872788}}],
    Line[{{6.287535, 10.577507, 14.872788},{6.731143, 11.312551, 15.184547}}],
    
    Line[{{6.731143, 11.312551, 15.184547},{7.203842, 12.074641, 15.589105}}],
    
    Line[{{7.203842, 12.074641, 15.589105},{7.705108, 12.856514, 16.096113}}],
    
    Line[{{7.705108, 12.856514, 16.096113},{8.233653, 13.648339, 16.715101}}],
    
    Line[{{8.233653, 13.648339, 16.715101},{8.787225, 14.437214, 17.455116}}],
    
    Line[{{8.787225, 14.437214, 17.455116},{9.362409, 15.206978, 18.323860}}],
    
    Line[{{9.362409, 15.206978, 18.323860},{9.954404, 15.937905, 19.326887}}],
    
    Line[{{9.954404, 15.937905, 19.326887},{
      10.556817, 16.606781, 20.466446}}],
    Line[{{10.556817, 16.606781, 20.466446},{
      11.161498, 17.187263, 21.740234}}],
    Line[{{11.161498, 17.187263, 21.740234},{
      11.758447, 17.650675, 23.140133}}],
    Line[{{11.758447, 17.650675, 23.140133},{
      12.335823, 17.967321, 24.650946}}],
    Line[{{12.335823, 17.967321, 24.650946},{
      12.880108, 18.108400, 26.249468}}],
    Line[{{12.880108, 18.108400, 26.249468},{
      13.376473, 18.048405, 27.904190}}],
    Line[{{13.376473, 18.048405, 27.904190},{
      13.809337, 17.767792, 29.575729}}],
    Line[{{13.809337, 17.767792, 29.575729},{
      14.163152, 17.255894, 31.218266}}],
    Line[{{14.163152, 17.255894, 31.218266},{
      14.423354, 16.513105, 32.782146}}],
    Line[{{14.423354, 16.513105, 32.782146},{
      14.577405, 15.552486, 34.217300}}],
    Line[{{14.577405, 15.552486, 34.217300},{
      14.615831, 14.399880, 35.477325}}],
    Line[{{14.615831, 14.399880, 35.477325},{
      14.533088, 13.092628, 36.523457}}],
    Line[{{14.533088, 13.092628, 36.523457},{
      14.328163, 11.676747, 37.327980}}],
    Line[{{14.328163, 11.676747, 37.327980},{
      14.004784, 10.203069, 37.876358}}],
    Line[{{14.004784, 10.203069, 37.876358},{
      13.571214, 8.722794, 38.167816}}],
    Line[{{13.571214, 8.722794, 38.167816},{13.039651, 7.283343, 38.214279}}],
    
    Line[{{13.039651, 7.283343, 38.214279},{12.425320, 5.924991, 38.038044}}],
    
    Line[{{12.425320, 5.924991, 38.038044},{11.745393, 4.678683, 37.668640}}],
    
    Line[{{11.745393, 4.678683, 37.668640},{11.017861, 3.565159, 37.139454}}],
    
    Line[{{11.017861, 3.565159, 37.139454},{10.260496, 2.595319, 36.484573}}],
    
    Line[{{10.260496, 2.595319, 36.484573},{9.489983, 1.771436, 35.736340}}],
    Line[{{9.489983, 1.771436, 35.736340},{8.721286, 1.088881, 34.923622}}],
    Line[{{8.721286, 1.088881, 34.923622},{7.967251, 0.538018, 34.070881}}],
    Line[{{7.967251, 0.538018, 34.070881},{7.238412, 0.106009, 33.197876}}],
    Line[{{7.238412, 0.106009, 33.197876},{6.542990, -0.221640, 32.319874}}],
    Line[{{6.542990, -0.221640, 32.319874},{5.887014, -0.459864, 31.448111}}],
    
    Line[{{5.887014, -0.459864, 31.448111},{5.274532, -0.623153, 30.590448}}],
    
    Line[{{5.274532, -0.623153, 30.590448},{4.707877, -0.724972, 29.752047}}],
    
    Line[{{4.707877, -0.724972, 29.752047},{4.187939, -0.777425, 28.935986}}],
    
    Line[{{4.187939, -0.777425, 28.935986},{3.714446, -0.791101, 28.143833}}],
    
    Line[{{3.714446, -0.791101, 28.143833},{3.286219, -0.775056, 27.376081}}],
    
    Line[{{3.286219, -0.775056, 27.376081},{2.901398, -0.736884, 26.632523}}],
    
    Line[{{2.901398, -0.736884, 26.632523},{2.557647, -0.682829, 25.912504}}],
    
    Line[{{2.557647, -0.682829, 25.912504},{2.252317, -0.617930, 25.215126}}],
    
    Line[{{2.252317, -0.617930, 25.215126},{1.982581, -0.546178, 24.539377}}],
    
    Line[{{1.982581, -0.546178, 24.539377},{1.745548, -0.470667, 23.884226}}],
    
    Line[{{1.745548, -0.470667, 23.884226},{1.538345, -0.393729, 23.248665}}],
    
    Line[{{1.538345, -0.393729, 23.248665},{1.358183, -0.317067, 22.631756}}],
    
    Line[{{1.358183, -0.317067, 22.631756},{1.202399, -0.241870, 22.032627}}],
    
    Line[{{1.202399, -0.241870, 22.032627},{1.068496, -0.168907, 21.450499}}],
    
    Line[{{1.068496, -0.168907, 21.450499},{0.954153, -0.098613, 20.884653}}],
    
    Line[{{0.954153, -0.098613, 20.884653},{0.857246, -0.031158, 20.334454}}],
    
    Line[{{0.857246, -0.031158, 20.334454},{0.775845, 0.033489, 19.799324}}],
    Line[{{0.775845, 0.033489, 19.799324},{0.708214, 0.095519, 19.278738}}],
    Line[{{0.708214, 0.095519, 19.278738},{0.652809, 0.155240, 18.772223}}],
    Line[{{0.652809, 0.155240, 18.772223},{0.608265, 0.213049, 18.279341}}],
    Line[{{0.608265, 0.213049, 18.279341},{0.573388, 0.269408, 17.799690}}],
    Line[{{0.573388, 0.269408, 17.799690},{0.547144, 0.324822, 17.332899}}],
    Line[{{0.547144, 0.324822, 17.332899},{0.528647, 0.379836, 16.878620}}],
    Line[{{0.528647, 0.379836, 16.878620},{0.517151, 0.435015, 16.436529}}],
    Line[{{0.517151, 0.435015, 16.436529},{0.512031, 0.490946, 16.006319}}],
    Line[{{0.512031, 0.490946, 16.006319},{0.512783, 0.548234, 15.587708}}],
    Line[{{0.512783, 0.548234, 15.587708},{0.519006, 0.607499, 15.180429}}],
    Line[{{0.519006, 0.607499, 15.180429},{0.530398, 0.669381, 14.784231}}],
    Line[{{0.530398, 0.669381, 14.784231},{0.546749, 0.734541, 14.398886}}],
    Line[{{0.546749, 0.734541, 14.398886},{0.567931, 0.803665, 14.024179}}],
    Line[{{0.567931, 0.803665, 14.024179},{0.593897, 0.877473, 13.659924}}],
    Line[{{0.593897, 0.877473, 13.659924},{0.624673, 0.956721, 13.305949}}],
    Line[{{0.624673, 0.956721, 13.305949},{0.660358, 1.042210, 12.962113}}],
    Line[{{0.660358, 1.042210, 12.962113},{0.701119, 1.134797, 12.628301}}],
    Line[{{0.701119, 1.134797, 12.628301},{0.747192, 1.235399, 12.304429}}],
    Line[{{0.747192, 1.235399, 12.304429},{0.798883, 1.345005, 11.990454}}],
    Line[{{0.798883, 1.345005, 11.990454},{0.856564, 1.464689, 11.686374}}],
    Line[{{0.856564, 1.464689, 11.686374},{0.920680, 1.595615, 11.392239}}],
    Line[{{0.920680, 1.595615, 11.392239},{0.991750, 1.739055, 11.108159}}],
    Line[{{0.991750, 1.739055, 11.108159},{1.070368, 1.896397, 10.834316}}],
    Line[{{1.070368, 1.896397, 10.834316},{1.157212, 2.069162, 10.570977}}],
    Line[{{1.157212, 2.069162, 10.570977},{1.253046, 2.259012, 10.318510}}],
    Line[{{1.253046, 2.259012, 10.318510},{1.358727, 2.467771, 10.077406}}],
    Line[{{1.358727, 2.467771, 10.077406},{1.475213, 2.697434, 9.848302}}],
    Line[{{1.475213, 2.697434, 9.848302},{1.603570, 2.950182, 9.632008}}],
    Line[{{1.603570, 2.950182, 9.632008},{1.744977, 3.228398, 9.429549}}],
    Line[{{1.744977, 3.228398, 9.429549},{1.900740, 3.534672, 9.242203}}],
    Line[{{1.900740, 3.534672, 9.242203},{2.072298, 3.871817, 9.071550}}],
    Line[{{2.072298, 3.871817, 9.071550},{2.261230, 4.242860, 8.919546}}],
    Line[{{2.261230, 4.242860, 8.919546},{2.469265, 4.651061, 8.788575}}],
    Line[{{2.469265, 4.651061, 8.788575},{2.698286, 5.099867, 8.681566}}],
    Line[{{2.698286, 5.099867, 8.681566},{2.950336, 5.592926, 8.602061}}],
    Line[{{2.950336, 5.592926, 8.602061},{3.227613, 6.133985, 8.554372}}],
    Line[{{3.227613, 6.133985, 8.554372},{3.532475, 6.726887, 8.543681}}],
    Line[{{3.532475, 6.726887, 8.543681},{3.867409, 7.375382, 8.576231}}],
    Line[{{3.867409, 7.375382, 8.576231},{4.235021, 8.083032, 8.659472}}],
    Line[{{4.235021, 8.083032, 8.659472},{4.637985, 8.852959, 8.802253}}],
    Line[{{4.637985, 8.852959, 8.802253},{5.078985, 9.687539, 9.015006}}],
    Line[{{5.078985, 9.687539, 9.015006},{5.560629, 10.588045, 9.309926}}],
    Line[{{5.560629, 10.588045, 9.309926},{6.085316, 11.554062, 9.701077}}],
    Line[{{6.085316, 11.554062, 9.701077},{6.655075, 12.582879, 10.204464}}],
    Line[{{6.655075, 12.582879, 10.204464},{7.271343, 13.668660, 10.837986}}],
    
    Line[{{7.271343, 13.668660, 10.837986},{7.934667, 14.801437, 11.621065}}],
    
    Line[{{7.934667, 14.801437, 11.621065},{8.644354, 15.966046, 12.574139}}],
    
    Line[{{8.644354, 15.966046, 12.574139},{9.398033, 17.140919, 13.717631}}],
    
    Line[{{9.398033, 17.140919, 13.717631},{
      10.191150, 18.296946, 15.070422}}],
    Line[{{10.191150, 18.296946, 15.070422},{
      11.016412, 19.396603, 16.647665}}],
    Line[{{11.016412, 19.396603, 16.647665},{
      11.863225, 20.393618, 18.457933}}],
    Line[{{11.863225, 20.393618, 18.457933},{
      12.717195, 21.233566, 20.499773}}],
    Line[{{12.717195, 21.233566, 20.499773},{
      13.559794, 21.855810, 22.757898}}],
    Line[{{13.559794, 21.855810, 22.757898},{
      14.368337, 22.197241, 25.199596}}],
    Line[{{14.368337, 22.197241, 25.199596},{
      15.116381, 22.197868, 27.772148}}],
    Line[{{15.116381, 22.197868, 27.772148},{
      15.774738, 21.808172, 30.402283}}],
    Line[{{15.774738, 21.808172, 30.402283},{
      16.313120, 20.997274, 32.998650}}],
    Line[{{16.313120, 20.997274, 32.998650},{
      16.702404, 19.760574, 35.457947}}],
    Line[{{16.702404, 19.760574, 35.457947},{
      16.917292, 18.124847, 37.674538}}],
    Line[{{16.917292, 18.124847, 37.674538},{
      16.939018, 16.149189, 39.552223}}],
    Line[{{16.939018, 16.149189, 39.552223},{
      16.757637, 13.920688, 41.016018}}],
    Line[{{16.757637, 13.920688, 41.016018},{
      16.373434, 11.545195, 42.021313}}],
    Line[{{16.373434, 11.545195, 42.021313},{
      15.797153, 9.134901, 42.558304}}],
    Line[{{15.797153, 9.134901, 42.558304},{15.048967, 6.795331, 42.650707}}],
    
    Line[{{15.048967, 6.795331, 42.650707},{14.156404, 4.614639, 42.349476}}],
    
    Line[{{14.156404, 4.614639, 42.349476},{13.151628, 2.656845, 41.723354}}],
    
    Line[{{13.151628, 2.656845, 41.723354},{12.068566, 0.959760, 40.848640}}],
    
    Line[{{12.068566, 0.959760, 40.848640},{
      10.940312, -0.463111, 39.800194}}],
    Line[{{10.940312, -0.463111, 39.800194},{
      9.797097, -1.618015, 38.644936}}],
    Line[{{9.797097, -1.618015, 38.644936},{8.664951, -2.525296, 37.438168}}],
    
    Line[{{8.664951, -2.525296, 37.438168},{7.565040, -3.213832, 36.222420}}],
    
    Line[{{7.565040, -3.213832, 36.222420},{6.513544, -3.716355, 35.028057}}],
    
    Line[{{6.513544, -3.716355, 35.028057},{5.521950, -4.065967, 33.874992}}],
    
    Line[{{5.521950, -4.065967, 33.874992},{4.597579, -4.293831, 32.774818}}],
    
    Line[{{4.597579, -4.293831, 32.774818},{3.744242, -4.427874, 31.732931}}],
    
    Line[{{3.744242, -4.427874, 31.732931},{2.962909, -4.492224, 30.750423}}],
    
    Line[{{2.962909, -4.492224, 30.750423},{2.252348, -4.507150, 29.825623}}],
    
    Line[{{2.252348, -4.507150, 29.825623},{1.609697, -4.489299, 28.955244}}],
    
    Line[{{1.609697, -4.489299, 28.955244},{1.030939, -4.452091, 28.135231}}],
    
    Line[{{1.030939, -4.452091, 28.135231},{0.511299, -4.406169, 27.361330}}],
    
    Line[{{0.511299, -4.406169, 27.361330},{0.045561, -4.359857, 26.629436}}],
    
    Line[{{
      0.045561, -4.359857, 26.629436},{-0.371692, -4.319575, 25.935806}}],
    Line[{{-0.371692, -4.319575, 25.935806},{-0.745895, -4.290210, 
        25.277161}}],
    Line[{{-0.745895, -4.290210, 25.277161},{-1.082371, -4.275436, 
        24.650721}}],
    Line[{{-1.082371, -4.275436, 24.650721},{-1.386236, -4.277978, 
        24.054203}}],
    Line[{{-1.386236, -4.277978, 24.054203},{-1.662346, -4.299841, 
        23.485786}}],
    Line[{{-1.662346, -4.299841, 23.485786},{-1.915254, -4.342484, 
        22.944077}}],
    Line[{{-1.915254, -4.342484, 22.944077},{-2.149201, -4.406971, 
        22.428061}}],
    Line[{{-2.149201, -4.406971, 22.428061},{-2.368109, -4.494090, 
        21.937075}}],
    Line[{{-2.368109, -4.494090, 21.937075},{-2.575594, -4.604440, 
        21.470770}}],
    Line[{{-2.575594, -4.604440, 21.470770},{-2.774979, -4.738508, 
        21.029085}}],
    Line[{{-2.774979, -4.738508, 21.029085},{-2.969312, -4.896718, 
        20.612232}}],
    Line[{{-2.969312, -4.896718, 20.612232},{-3.161392, -5.079472, 
        20.220684}}],
    Line[{{-3.161392, -5.079472, 20.220684},{-3.353788, -5.287173, 
        19.855171}}],
    Line[{{-3.353788, -5.287173, 19.855171},{-3.548863, -5.520234, 
        19.516687}}],
    Line[{{-3.548863, -5.520234, 19.516687},{-3.748798, -5.779083, 
        19.206493}}],
    Line[{{-3.748798, -5.779083, 19.206493},{-3.955606, -6.064149, 
        18.926138}}],
    Line[{{-3.955606, -6.064149, 18.926138},{-4.171145, -6.375842, 
        18.677462}}],
    Line[{{-4.171145, -6.375842, 18.677462},{-4.397139, -6.714515, 
        18.462627}}],
    Line[{{-4.397139, -6.714515, 18.462627},{-4.635172, -7.080426, 
        18.284132}}],
    Line[{{-4.635172, -7.080426, 18.284132},{-4.886699, -7.473674, 
        18.144833}}],
    Line[{{-4.886699, -7.473674, 18.144833},{-5.153032, -7.894126, 
        18.047955}}],
    Line[{{-5.153032, -7.894126, 18.047955},{-5.435331, -8.341326, 
        17.997099}}],
    Line[{{-5.435331, -8.341326, 17.997099},{-5.734585, -8.814393, 
        17.996246}}],
    Line[{{-5.734585, -8.814393, 17.996246},{-6.051578, -9.311898, 
        18.049744}}],
    Line[{{-6.051578, -9.311898, 18.049744},{-6.386849, -9.831715, 
        18.162243}}],
    Line[{{-6.386849, -9.831715, 18.162243},{-6.740647, -10.370868, 
        18.338659}}],
    Line[{{-6.740647, -10.370868, 18.338659},{-7.112864, -10.925364, 
        18.584044}}],
    Line[{{-7.112864, -10.925364, 18.584044},{-7.502967, -11.490019, 
        18.903435}}],
    Line[{{-7.502967, -11.490019, 18.903435},{-7.909915, -12.058280, 
        19.301655}}],
    Line[{{-7.909915, -12.058280, 19.301655},{-8.332069, -12.622079, 
        19.783020}}],
    Line[{{-8.332069, -12.622079, 19.783020},{-8.767105, -13.171741, 
        20.350998}}],
    Line[{{-8.767105, -13.171741, 20.350998},{-9.211911, -13.695894, 
        21.007788}}],
    Line[{{-9.211911, -13.695894, 21.007788},{-9.662519, -14.181589, 
        21.753834}}],
    Line[{{-9.662519, -14.181589, 21.753834},{-10.114032, -14.614448, 
        22.587297}}],
    Line[{{-10.114032, -14.614448, 22.587297},{-10.560586, -14.979000, 
        23.503498}}],
    Line[{{-10.560586, -14.979000, 23.503498},{-10.995393, -15.259319, 
        24.494459}}],
    Line[{{-10.995393, -15.259319, 24.494459},{-11.410782, -15.439659, 
        25.548456}}],
    Line[{{-11.410782, -15.439659, 25.548456},{-11.798363, -15.505491, 
        26.649803}}],
    Line[{{-11.798363, -15.505491, 26.649803},{-12.149282, -15.444539, 
        27.779058}}],
    Line[{{-12.149282, -15.444539, 27.779058},{-12.454487, -15.247977, 
        28.913153}}],
    Line[{{-12.454487, -15.247977, 28.913153},{-12.705181, -14.911457, 
        30.026474}}],
    Line[{{-12.705181, -14.911457, 30.026474},{-12.893236, -14.436038, 
        31.091848}}],
    Line[{{-12.893236, -14.436038, 31.091848},{-13.011683, -13.828663, 
        32.082077}}],
    Line[{{-13.011683, -13.828663, 32.082077},{-13.055166, -13.102283, 
        32.971573}}],
    Line[{{-13.055166, -13.102283, 32.971573},{-13.020350, -12.275314, 
        33.738049}}],
    Line[{{-13.020350, -12.275314, 33.738049},{-12.906189, -11.370600, 
        34.363964}}],
    Line[{{-12.906189, -11.370600, 34.363964},{-12.714067, -10.413973, 
        34.837543}}],
    Line[{{-12.714067, -10.413973, 34.837543},{-12.447769, -9.432554, 
        35.153358}}],
    Line[{{-12.447769, -9.432554, 35.153358},{-12.113297, -8.452885, 
        35.312309}}],
    Line[{{-12.113297, -8.452885, 35.312309},{-11.718506, -7.499437, 
        35.320957}}],
    Line[{{-11.718506, -7.499437, 35.320957},{-11.272683, -6.593245, 
        35.190582}}],
    Line[{{-11.272683, -6.593245, 35.190582},{-10.786029, -5.751088, 
        34.935905}}],
    Line[{{-10.786029, -5.751088, 34.935905},{-10.269148, -4.985115, 
        34.573723}}],
    Line[{{-10.269148, -4.985115, 34.573723},{-9.732571, -4.302898, 
        34.121643}}],
    Line[{{-9.732571, -4.302898, 34.121643},{-9.186337, -3.707827, 
        33.597015}}],
    Line[{{-9.186337, -3.707827, 33.597015},{-8.639675, -3.199728, 
        33.016094}}],
    Line[{{-8.639675, -3.199728, 33.016094},{-8.100780, -2.775596, 
        32.393490}}],
    Line[{{-8.100780, -2.775596, 32.393490},{-7.576669, -2.430364, 
        31.741892}}],
    Line[{{-7.576669, -2.430364, 31.741892},{-7.073144, -2.157601, 
        31.071959}}],
    Line[{{-7.073144, -2.157601, 31.071959},{-6.594799, -1.950134, 
        30.392399}}],
    Line[{{-6.594799, -1.950134, 30.392399},{-6.145092, -1.800541, 
        29.710146}}],
    Line[{{-6.145092, -1.800541, 29.710146},{-5.726451, -1.701544, 
        29.030569}}],
    Line[{{-5.726451, -1.701544, 29.030569},{-5.340398, -1.646265, 
        28.357752}}],
    Line[{{-5.340398, -1.646265, 28.357752},{-4.987684, -1.628418, 
        27.694708}}],
    Line[{{-4.987684, -1.628418, 27.694708},{-4.668422, -1.642408, 
        27.043617}}],
    Line[{{-4.668422, -1.642408, 27.043617},{-4.382217, -1.683376, 
        26.406027}}],
    Line[{{-4.382217, -1.683376, 26.406027},{-4.128285, -1.747202, 
        25.782999}}],
    Line[{{-4.128285, -1.747202, 25.782999},{-3.905560, -1.830473, 
        25.175264}}],
    Line[{{-3.905560, -1.830473, 25.175264},{-3.712784, -1.930445, 
        24.583313}}],
    Line[{{-3.712784, -1.930445, 24.583313},{-3.548589, -2.044977, 
        24.007479}}],
    Line[{{-3.548589, -2.044977, 24.007479},{-3.411558, -2.172480, 
        23.448008}}],
    Line[{{-3.411558, -2.172480, 23.448008},{-3.300284, -2.311848, 
        22.905102}}],
    Line[{{-3.300284, -2.311848, 22.905102},{-3.213410, -2.462403, 
        22.378958}}],
    Line[{{-3.213410, -2.462403, 22.378958},{-3.149660, -2.623840, 
        21.869785}}],
    Line[{{-3.149660, -2.623840, 21.869785},{-3.107867, -2.796176, 
        21.377848}}],
    Line[{{-3.107867, -2.796176, 21.377848},{-3.086991, -2.979709, 
        20.903458}}],
    Line[{{-3.086991, -2.979709, 20.903458},{-3.086132, -3.174975, 
        20.447016}}],
    Line[{{-3.086132, -3.174975, 20.447016},{-3.104535, -3.382719, 
        20.009010}}],
    Line[{{-3.104535, -3.382719, 20.009010},{-3.141599, -3.603864, 
        19.590038}}],
    Line[{{-3.141599, -3.603864, 19.590038},{-3.196873, -3.839483, 
        19.190828}}],
    Line[{{-3.196873, -3.839483, 19.190828},{-3.270059, -4.090778, 
        18.812254}}],
    Line[{{-3.270059, -4.090778, 18.812254},{-3.361007, -4.359060, 
        18.455353}}],
    Line[{{-3.361007, -4.359060, 18.455353},{-3.469710, -4.645720, 
        18.121361}}],
    Line[{{-3.469710, -4.645720, 18.121361},{-3.596298, -4.952218, 
        17.811726}}],
    Line[{{-3.596298, -4.952218, 17.811726},{-3.741027, -5.280041, 
        17.528147}}],
    Line[{{-3.741027, -5.280041, 17.528147},{-3.904275, -5.630690, 
        17.272602}}],
    Line[{{-3.904275, -5.630690, 17.272602},{-4.086521, -6.005634, 
        17.047390}}],
    Line[{{-4.086521, -6.005634, 17.047390},{-4.288339, -6.406262, 
        16.855154}}],
    Line[{{-4.288339, -6.406262, 16.855154},{-4.510373, -6.833840, 
        16.698940}}],
    Line[{{-4.510373, -6.833840, 16.698940},{-4.753315, -7.289423, 
        16.582211}}],
    Line[{{-4.753315, -7.289423, 16.582211},{-5.017883, -7.773789, 
        16.508904}}],
    Line[{{-5.017883, -7.773789, 16.508904},{-5.304779, -8.287314, 
        16.483444}}],
    Line[{{-5.304779, -8.287314, 16.483444},{-5.614650, -8.829852, 
        16.510761}}],
    Line[{{-5.614650, -8.829852, 16.510761},{-5.948040, -9.400585, 
        16.596308}}],
    Line[{{-5.948040, -9.400585, 16.596308},{-6.305315, -9.997827, 
        16.745996}}],
    Line[{{-6.305315, -9.997827, 16.745996},{-6.686606, -10.618834, 
        16.966181}}],
    Line[{{-6.686606, -10.618834, 16.966181},{-7.091704, -11.259563, 
        17.263515}}],
    Line[{{-7.091704, -11.259563, 17.263515},{-7.519961, -11.914432, 
        17.644770}}],
    Line[{{-7.519961, -11.914432, 17.644770},{-7.970180, -12.576044, 
        18.116627}}],
    Line[{{-7.970180, -12.576044, 18.116627},{-8.440471, -13.234998, 
        18.685253}}],
    Line[{{-8.440471, -13.234998, 18.685253},{-8.928128, -13.879645, 
        19.355927}}],
    Line[{{-8.928128, -13.879645, 19.355927},{-9.429478, -14.496000, 
        20.132399}}],
    Line[{{-9.429478, -14.496000, 20.132399},{-9.939756, -15.067803, 
        21.016245}}],
    Line[{{-9.939756, -15.067803, 21.016245},{-10.452998, -15.576670, 
        22.006102}}],
    Line[{{-10.452998, -15.576670, 22.006102},{-10.961973, -16.002579, 
        23.096851}}],
    Line[{{-10.961973, -16.002579, 23.096851},{-11.458186, -16.324642, 
        24.278873}}],
    Line[{{-11.458186, -16.324642, 24.278873},{-11.931962, -16.522146, 
        25.537447}}],
    Line[{{-11.931962, -16.522146, 25.537447},{-12.372631, -16.575914, 
        26.852348}}],
    Line[{{-12.372631, -16.575914, 26.852348},{-12.768859, -16.469969, 
        28.197973}}],
    Line[{{-12.768859, -16.469969, 28.197973},{-13.109094, -16.193174, 
        29.543976}}],
    Line[{{-13.109094, -16.193174, 29.543976},{-13.382119, -15.740877, 
        30.856388}}],
    Line[{{-13.382119, -15.740877, 30.856388},{-13.577714, -15.116134, 
        32.099499}}],
    Line[{{-13.577714, -15.116134, 32.099499},{-13.687321, -14.330380, 
        33.238079}}],
    Line[{{-13.687321, -14.330380, 33.238079},{-13.704690, -13.403301, 
        34.239883}}],
    Line[{{-13.704690, -13.403301, 34.239883},{-13.626403, -12.361835, 
        35.078033}}],
    Line[{{-13.626403, -12.361835, 35.078033},{-13.452210, -11.238378, 
        35.732998}}],
    Line[{{-13.452210, -11.238378, 35.732998},{-13.185138, -10.068407, 
        36.193848}}],
    Line[{{-13.185138, -10.068407, 36.193848},{-12.831344, -8.887821, 
        36.458603}}],
    Line[{{-12.831344, -8.887821, 36.458603},{-12.399730, -7.730392, 
        36.533722}}],
    Line[{{-12.399730, -7.730392, 36.533722},{-11.901374, -6.625629, 
        36.432781}}],
    Line[{{-11.901374, -6.625629, 36.432781},{-11.348840, -5.597299, 
        36.174675}}],
    Line[{{-11.348840, -5.597299, 36.174675},{-10.755445, -4.662675, 
        35.781609}}],
    Line[{{-10.755445, -4.662675, 35.781609},{-10.134569, -3.832503, 
        35.277115}}],
    Line[{{-10.134569, -3.832503, 35.277115},{-9.499040, -3.111519, 
        34.684410}}],
    Line[{{-9.499040, -3.111519, 34.684410},{-8.860663, -2.499365, 
        34.025127}}],
    Line[{{-8.860663, -2.499365, 34.025127},{-8.229884, -1.991684, 
        33.318466}}],
    Line[{{-8.229884, -1.991684, 33.318466},{-7.615592, -1.581260, 
        32.580784}}],
    Line[{{-7.615592, -1.581260, 32.580784},{-7.025046, -1.259063, 
        31.825512}}],
    Line[{{-7.025046, -1.259063, 31.825512},{-6.463908, -1.015143, 
        31.063278}}],
    Line[{{-6.463908, -1.015143, 31.063278},{-5.936335, -0.839340, 
        30.302219}}],
    Line[{{-5.936335, -0.839340, 30.302219},{-5.445134, -0.721800, 
        29.548347}}],
    Line[{{-5.445134, -0.721800, 29.548347},{-4.991940, -0.653339, 
        28.805937}}],
    Line[{{-4.991940, -0.653339, 28.805937},{-4.577396, -0.625652, 
        28.077887}}],
    Line[{{-4.577396, -0.625652, 28.077887},{-4.201343, -0.631426, 
        27.366056}}],
    Line[{{-4.201343, -0.631426, 27.366056},{-3.862988, -0.664367, 
        26.671539}}],
    Line[{{-3.862988, -0.664367, 26.671539},{-3.561068, -0.719179, 
        25.994877}}],
    Line[{{-3.561068, -0.719179, 25.994877},{-3.293976, -0.791499, 
        25.336243}}],
    Line[{{-3.293976, -0.791499, 25.336243},{-3.059888, -0.877816, 
        24.695572}}],
    Line[{{-3.059888, -0.877816, 24.695572},{-2.856857, -0.975388, 
        24.072655}}],
    Line[{{-2.856857, -0.975388, 24.072655},{-2.682893, -1.082139, 
        23.467205}}],
    Line[{{-2.682893, -1.082139, 23.467205},{-2.536026, -1.196579, 
        22.878912}}],
    Line[{{-2.536026, -1.196579, 22.878912},{-2.414360, -1.317721, 
        22.307472}}],
    Line[{{-2.414360, -1.317721, 22.307472},{-2.316101, -1.445004, 
        21.752611}}],
    Line[{{-2.316101, -1.445004, 21.752611},{-2.239596, -1.578228, 
        21.214090}}],
    Line[{{-2.239596, -1.578228, 21.214090},{-2.183341, -1.717503, 
        20.691727}}],
    Line[{{-2.183341, -1.717503, 20.691727},{-2.146002, -1.863197, 
        20.185394}}],
    Line[{{-2.146002, -1.863197, 20.185394},{-2.126416, -2.015902, 
        19.695032}}],
    Line[{{-2.126416, -2.015902, 19.695032},{-2.123598, -2.176396, 
        19.220644}}],
    Line[{{-2.123598, -2.176396, 19.220644},{-2.136737, -2.345623, 
        18.762314}}],
    Line[{{-2.136737, -2.345623, 18.762314},{-2.165196, -2.524674, 
        18.320208}}],
    Line[{{-2.165196, -2.524674, 18.320208},{-2.208513, -2.714767, 
        17.894581}}],
    Line[{{-2.208513, -2.714767, 17.894581},{-2.266385, -2.917242, 
        17.485798}}],
    Line[{{-2.266385, -2.917242, 17.485798},{-2.338677, -3.133550, 
        17.094339}}],
    Line[{{-2.338677, -3.133550, 17.094339},{-2.425407, -3.365247, 
        16.720821}}],
    Line[{{-2.425407, -3.365247, 16.720821},{-2.526745, -3.613994, 
        16.366016}}],
    Line[{{-2.526745, -3.613994, 16.366016},{-2.643008, -3.881541, 
        16.030882}}],
    Line[{{-2.643008, -3.881541, 16.030882},{-2.774652, -4.169736, 
        15.716577}}],
    Line[{{-2.774652, -4.169736, 15.716577},{-2.922272, -4.480505, 
        15.424507}}],
    Line[{{-2.922272, -4.480505, 15.424507},{-3.086592, -4.815846, 
        15.156358}}],
    Line[{{-3.086592, -4.815846, 15.156358},{-3.268460, -5.177810, 
        14.914136}}],
    Line[{{-3.268460, -5.177810, 14.914136},{-3.468839, -5.568470, 
        14.700221}}],
    Line[{{-3.468839, -5.568470, 14.700221},{-3.688801, -5.989899, 
        14.517419}}],
    Line[{{-3.688801, -5.989899, 14.517419},{-3.929506, -6.444104, 
        14.369020}}],
    Line[{{-3.929506, -6.444104, 14.369020},{-4.192193, -6.932968, 
        14.258865}}],
    Line[{{-4.192193, -6.932968, 14.258865},{-4.478151, -7.458165, 
        14.191410}}],
    Line[{{-4.478151, -7.458165, 14.191410},{-4.788691, -8.021029, 
        14.171787}}],
    Line[{{-4.788691, -8.021029, 14.171787},{-5.125104, -8.622429, 
        14.205872}}],
    Line[{{-5.125104, -8.622429, 14.205872},{-5.488613, -9.262566, 
        14.300323}}],
    Line[{{-5.488613, -9.262566, 14.300323},{-5.880298, -9.940746, 
        14.462605}}],
    Line[{{-5.880298, -9.940746, 14.462605},{-6.301022, -10.655122, 
        14.700994}}],
    Line[{{-6.301022, -10.655122, 14.700994},{-6.751313, -11.402334, 
        15.024471}}],
    Line[{{-6.751313, -11.402334, 15.024471},{-7.231250, -12.177174, 
        15.442634}}],
    Line[{{-7.231250, -12.177174, 15.442634},{-7.740298, -12.972137, 
        15.965405}}],
    Line[{{-7.740298, -12.972137, 15.965405},{-8.277129, -13.777035, 
        16.602640}}],
    Line[{{-8.277129, -13.777035, 16.602640},{-8.839428, -14.578516, 
        17.363667}}],
    Line[{{-8.839428, -14.578516, 17.363667},{-9.423664, -15.359830, 
        18.256378}}],
    Line[{{-9.423664, -15.359830, 18.256378},{-10.024864, -16.100475, 
        19.286474}}],
    Line[{{-10.024864, -16.100475, 19.286474},{-10.636410, -16.776407, 
        20.456120}}],
    Line[{{-10.636410, -16.776407, 20.456120},{-11.249858, -17.360304, 
        21.762758}}],
    Line[{{-11.249858, -17.360304, 21.762758},{-11.854852, -17.822514, 
        23.197689}}],
    Line[{{-11.854852, -17.822514, 23.197689},{-12.439130, -18.132376, 
        24.744833}}],
    Line[{{-12.439130, -18.132376, 24.744833},{-12.988712, -18.260296, 
        26.379759}}],
    Line[{{-12.988712, -18.260296, 26.379759},{-13.488286, -18.180277, 
        28.069384}}],
    Line[{{-13.488286, -18.180277, 28.069384},{-13.921817, -17.872778, 
        29.772551}}],
    Line[{{-13.921817, -17.872778, 29.772551},{-14.273357, -17.327595, 
        31.441576}}],
    Line[{{-14.273357, -17.327595, 31.441576},{-14.528066, -16.546276, 
        33.025043}}],
    Line[{{-14.528066, -16.546276, 33.025043},{-14.673291, -15.543555, 
        34.471500}}],
    Line[{{-14.673291, -15.543555, 34.471500},{-14.699635, -14.347435, 
        35.733700}}],
    Line[{{-14.699635, -14.347435, 35.733700},{-14.601844, -12.997608, 
        36.772762}}],
    Line[{{-14.601844, -12.997608, 36.772762},{-14.379390, -11.542391, 
        37.561615}}],
    Line[{{-14.379390, -11.542391, 37.561615},{-14.036644, -10.034559, 
        38.087032}}],
    Line[{{-14.036644, -10.034559, 38.087032},{-13.582611, -8.526717, 
        38.350044}}],
    Line[{{-13.582611, -8.526717, 38.350044},{-13.030261, -7.067053, 
        38.364628}}],
    Line[{{-13.030261, -7.067053, 38.364628},{-12.395561, -5.695903, 
        38.155151}}],
    Line[{{-12.395561, -5.695903, 38.155151},{-11.696327, -4.443670, 
        37.752972}}],
    Line[{{-11.696327, -4.443670, 37.752972},{-10.951057, -3.330161, 
        37.192909}}],
    Line[{{-10.951057, -3.330161, 37.192909},{-10.177883, -2.365086, 
        36.510082}}],
    Line[{{-10.177883, -2.365086, 36.510082},{-9.393697, -1.549448, 
        35.737408}}],
    Line[{{-9.393697, -1.549448, 35.737408},{-8.613532, -0.877402, 
        34.903969}}],
    Line[{{-8.613532, -0.877402, 34.903969},{-7.850186, -0.338242, 
        34.034149}}],
    Line[{{-7.850186, -0.338242, 34.034149},{-7.114058, 0.081750, 
        33.147442}}],
    Line[{{-7.114058, 0.081750, 33.147442},{-6.413170, 0.397747, 32.258713}}],
    
    Line[{{-6.413170, 0.397747, 32.258713},{-5.753319, 0.625172, 31.378775}}],
    
    Line[{{-5.753319, 0.625172, 31.378775},{-5.138305, 0.778839, 30.515053}}],
    
    Line[{{-5.138305, 0.778839, 30.515053},{-4.570209, 0.872404, 29.672302}}],
    
    Line[{{-4.570209, 0.872404, 29.672302},{-4.049682, 0.918063, 28.853254}}],
    
    Line[{{-4.049682, 0.918063, 28.853254},{-3.576233, 0.926426, 28.059172}}],
    
    Line[{{-3.576233, 0.926426, 28.059172},{-3.148480, 0.906520, 27.290306}}],
    
    Line[{{-3.148480, 0.906520, 27.290306},{-2.764389, 0.865876, 26.546242}}],
    
    Line[{{-2.764389, 0.865876, 26.546242},{-2.421469, 0.810664, 25.826176}}],
    
    Line[{{-2.421469, 0.810664, 25.826176},{-2.116939, 0.745844, 25.129086}}],
    
    Line[{{-2.116939, 0.745844, 25.129086},{-1.847861, 0.675328, 24.453869}}],
    
    Line[{{-1.847861, 0.675328, 24.453869},{-1.611254, 0.602140, 23.799423}}],
    
    Line[{{-1.611254, 0.602140, 23.799423},{-1.404166, 0.528553, 23.164692}}],
    
    Line[{{-1.404166, 0.528553, 23.164692},{-1.223740, 0.456224, 22.548691}}],
    
    Line[{{-1.223740, 0.456224, 22.548691},{-1.067260, 0.386305, 21.950521}}],
    
    Line[{{-1.067260, 0.386305, 21.950521},{-0.932179, 0.319547, 21.369375}}],
    
    Line[{{-0.932179, 0.319547, 21.369375},{-0.816136, 0.256380, 20.804520}}],
    
    Line[{{-0.816136, 0.256380, 20.804520},{-0.716966, 0.196983, 20.255297}}],
    
    Line[{{-0.716966, 0.196983, 20.255297},{-0.632706, 0.141345, 19.721117}}],
    
    Line[{{-0.632706, 0.141345, 19.721117},{-0.561583, 0.089312, 19.201441}}],
    
    Line[{{-0.561583, 0.089312, 19.201441},{-0.502017, 0.040626, 18.695778}}],
    
    Line[{{-0.502017, 0.040626, 18.695778},{-0.452605, -0.005048, 
        18.203680}}],
    Line[{{-0.452605, -0.005048, 18.203680},{-0.412112, -0.048094, 
        17.724730}}],
    Line[{{-0.412112, -0.048094, 17.724730},{-0.379459, -0.088929, 
        17.258537}}],
    Line[{{-0.379459, -0.088929, 17.258537},{-0.353711, -0.127990, 
        16.804739}}],
    Line[{{-0.353711, -0.127990, 16.804739},{-0.334063, -0.165724, 
        16.362989}}],
    Line[{{-0.334063, -0.165724, 16.362989},{-0.319830, -0.202583, 
        15.932961}}],
    Line[{{-0.319830, -0.202583, 15.932961},{-0.310436, -0.239018, 
        15.514340}}],
    Line[{{-0.310436, -0.239018, 15.514340},{-0.305401, -0.275480, 
        15.106833}}],
    Line[{{-0.305401, -0.275480, 15.106833},{-0.304335, -0.312417, 
        14.710153}}],
    Line[{{-0.304335, -0.312417, 14.710153},{-0.306926, -0.350280, 
        14.324026}}],
    Line[{{-0.306926, -0.350280, 14.324026},{-0.312938, -0.389521, 
        13.948194}}],
    Line[{{-0.312938, -0.389521, 13.948194},{-0.322198, -0.430599, 
        13.582405}}],
    Line[{{-0.322198, -0.430599, 13.582405},{-0.334593, -0.473982, 
        13.226423}}],
    Line[{{-0.334593, -0.473982, 13.226423},{-0.350069, -0.520155, 
        12.880024}}],
    Line[{{-0.350069, -0.520155, 12.880024},{-0.368621, -0.569621, 
        12.542994}}],
    Line[{{-0.368621, -0.569621, 12.542994},{-0.390296, -0.622910, 
        12.215134}}],
    Line[{{-0.390296, -0.622910, 12.215134},{-0.415187, -0.680582, 
        11.896259}}],
    Line[{{-0.415187, -0.680582, 11.896259},{-0.443435, -0.743239, 
        11.586202}}],
    Line[{{-0.443435, -0.743239, 11.586202},{-0.475224, -0.811523, 
        11.284812}}],
    Line[{{-0.475224, -0.811523, 11.284812},{-0.510786, -0.886134, 
        10.991960}}],
    Line[{{-0.510786, -0.886134, 10.991960},{-0.550402, -0.967829, 
        10.707538}}],
    Line[{{-0.550402, -0.967829, 10.707538},{-0.594398, -1.057439, 
        10.431467}}],
    Line[{{-0.594398, -1.057439, 10.431467},{-0.643155, -1.155870, 
        10.163698}}],
    Line[{{-0.643155, -1.155870, 10.163698},{-0.697105, -1.264121, 
        9.904221}}],
    Line[{{-0.697105, -1.264121, 9.904221},{-0.756743, -1.383288, 9.653066}}],
    
    Line[{{-0.756743, -1.383288, 9.653066},{-0.822623, -1.514581, 9.410315}}],
    
    Line[{{-0.822623, -1.514581, 9.410315},{-0.895369, -1.659337, 9.176112}}],
    
    Line[{{-0.895369, -1.659337, 9.176112},{-0.975678, -1.819027, 8.950677}}],
    
    Line[{{-0.975678, -1.819027, 8.950677},{-1.064329, -1.995279, 8.734313}}],
    
    Line[{{-1.064329, -1.995279, 8.734313},{-1.162191, -2.189887, 8.527434}}],
    
    Line[{{-1.162191, -2.189887, 8.527434},{-1.270228, -2.404831, 8.330583}}],
    
    Line[{{-1.270228, -2.404831, 8.330583},{-1.389510, -2.642290, 8.144454}}],
    
    Line[{{-1.389510, -2.642290, 8.144454},{-1.521224, -2.904660, 7.969940}}],
    
    Line[{{-1.521224, -2.904660, 7.969940},{-1.666684, -3.194572, 7.808148}}],
    
    Line[{{-1.666684, -3.194572, 7.808148},{-1.827339, -3.514897, 7.660480}}],
    
    Line[{{-1.827339, -3.514897, 7.660480},{-2.004787, -3.868769, 7.528666}}],
    
    Line[{{-2.004787, -3.868769, 7.528666},{-2.200785, -4.259583, 7.414841}}],
    
    Line[{{-2.200785, -4.259583, 7.414841},{-2.417256, -4.690982, 7.321655}}],
    
    Line[{{-2.417256, -4.690982, 7.321655},{-2.656305, -5.166886, 7.252318}}],
    
    Line[{{-2.656305, -5.166886, 7.252318},{-2.920213, -5.691393, 7.210799}}],
    
    Line[{{-2.920213, -5.691393, 7.210799},{-3.211447, -6.268787, 7.201906}}],
    
    Line[{{-3.211447, -6.268787, 7.201906},{-3.532650, -6.903428, 7.231475}}],
    
    Line[{{-3.532650, -6.903428, 7.231475},{-3.886626, -7.599611, 7.306559}}],
    
    Line[{{-3.886626, -7.599611, 7.306559},{-4.276317, -8.361423, 7.435634}}],
    
    Line[{{-4.276317, -8.361423, 7.435634},{-4.704742, -9.192409, 7.628815}}],
    
    Line[{{-4.704742, -9.192409, 7.628815},{-5.174942, -10.095274, 
        7.898095}}],
    Line[{{-5.174942, -10.095274, 7.898095},{-5.689859, -11.071378, 
        8.257549}}],
    Line[{{-5.689859, -11.071378, 8.257549},{-6.252191, -12.120058, 
        8.723480}}],
    Line[{{-6.252191, -12.120058, 8.723480},{-6.864196, -13.237879, 
        9.314507}}],
    Line[{{-6.864196, -13.237879, 9.314507},{-7.527411, -14.417570, 
        10.051449}}],
    Line[{{-7.527411, -14.417570, 10.051449},{-8.242299, -15.646820, 
        10.956907}}],
    Line[{{-8.242299, -15.646820, 10.956907},{-9.007811, -16.906921, 
        12.054534}}],
    Line[{{-9.007811, -16.906921, 12.054534},{-9.820846, -18.171310, 
        13.367676}}],
    Line[{{-9.820846, -18.171310, 13.367676},{-10.675638, -19.404230, 
        14.917384}}]},
    Boxed -> True,
    Lighting -> True,
    SphericalRegion -> False,
    BoxRatios -> {1.000000, 1.000000, 1.000000},
    ViewPoint -> {-1.839149, 1.825318, 2.212769}
  ]
], "Picture",
  ImageSize->{261.562, 261.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000560001AR000`400?l00000o`00003oRP3oool0
0`000000oooo0?ooo`2i0?ooo`00R@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0/P3oool008L0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P00002b0?oo
o`00QP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0[`3oool008D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0:h0oooo00240?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool200000:h0oooo00220?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0:/0oooo00210?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`2Z0?ooo`00P03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo0P00002Z0?ooo`00O`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0Y`3oool007d0oooo0P00000>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0YP3oool007`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`800000YP3oool007/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0:<0oooo001i0?ooo`8000004P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0:80oooo001h0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool200000:80oooo001g0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`2O0?ooo`00MP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0WP3oool007@0oooo0P00000F0?ooo`030000003oool0oooo
01L0oooo0P00002N0?ooo`00L`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0V`3oool00780oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo09X0oooo001a0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool06`3oool2000009X0oooo001_0?ooo`8000006`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo09L0oooo001^0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`2F0?ooo`00K@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01l0oooo0P00002F0?ooo`00K03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0T`3oool006X0oooo0P00000P0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0TP3oool006T0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0S0?ooo`800000TP3oool006P0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo08l0oooo001W0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2>0?ooo`00I@3oool2000002D0oooo
00<000000?ooo`3oool09`3oool2000008h0oooo001T0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`2;0?ooo`00H`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0RP3oool00640oooo0P00000Y0?oo
o`030000003oool0oooo02/0oooo0P00002:0?ooo`00H03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0Q`3oool005l0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo08H0oooo001N0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0;`3oool2000008H0oooo001L0?ooo`800000;P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo08<0oooo001K0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`220?ooo`00FP3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo03<0oooo0P0000220?ooo`00F@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0O`3oool005L0oooo0P00
000c0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0OP3oool005H0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0g0?ooo`800000OP3oool005D0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo07/0oooo001D0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1j0?ooo`00
DP3oool2000003P0oooo00<000000?ooo`3oool0>`3oool2000007X0oooo001A0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1g0?ooo`00D03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0MP3oool0
04l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0o0?ooo`800000MP3oool004d0
oooo0P00000m0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0L`3oool004`0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0780oooo
001;0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0@`3oool200000780oooo0019
0?ooo`800000@03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo06l0oooo00180?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1^0?oo
o`00A`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0K@3oool004H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`190?ooo`800000
K@3oool004@0oooo0P0000150?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0JP3o
ool004<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo06T0oooo00120?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0C@3oool20000
06T0oooo00110?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`1V0?ooo`00?`3oool2000004X0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`1U0?ooo`00?P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0540oooo0P00
001U0?ooo`00?@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool0HP3oool003`0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0640oooo000j0?ooo`800000C`3oool00`000000oooo0?ooo`1E0?ooo`80
0000H@3oool003T0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo05h0oooo000h0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`1M0?ooo`00=`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo05T0oooo0P00001M0?ooo`00=@3oool2000005@0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`1J0?ooo`00=03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0F@3oool003<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`1M0?ooo`800000F@3oool00340oooo0P00001H0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0EP3oool00300oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo05D0oooo000_0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0H@3oool2000005D0oooo000^0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`1B0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`1A0?ooo`00:`3oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo06D0oooo0P00001A0?ooo`00:P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0CP3oool002T0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo04d0oooo000W0?ooo`800000HP3oool00`000000
oooo0?ooo`1Y0?ooo`800000C@3oool002H0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo04X0oooo000U0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`190?ooo`009@3oool3000006<0oooo00<00000
0?ooo`3oool0K@3oool2000004T0oooo000U0?ooo`030000003oool0oooo00800000H@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo04H0oooo000U0?ooo`030000003oool0oooo0080
oooo0P00001O0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0A@3oool002@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0780oooo
0P0000150?ooo`00903oool00`000000oooo0?ooo`060?ooo`800000F`3oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0480oooo000T0?ooo`030000003oool0oooo00P0oooo0P00001I
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0@@3oool002@0oooo00<000000?oo
o`3oool02P3oool2000005L0oooo00<000000?ooo`3oool0MP3oool200000440oooo000T0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo03h0oooo000T0?ooo`030000003oool0oooo00d0oooo0P00001D0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0?@3oool002@0oooo00<000000?ooo`3oool03`3o
ool2000003X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1j0?ooo`800000?@3o
ool002<0oooo00<000000?ooo`3oool04P3oool2000003H0oooo0P00000H0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0>P3oool002<0oooo00<000000?ooo`3oool0503oool20000
0380oooo0P00000J0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0>@3oool002<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`800000703oool00`000000
oooo0?ooo`1n0?ooo`800000>@3oool002<0oooo00<000000?ooo`3oool05`3oool2000002X0oooo
0`00000N0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0=P3oool002<0oooo00<0
00000?ooo`3oool06@3oool2000002H0oooo0P00000Q0?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool0=@3oool002<0oooo00<000000?ooo`3oool06`3oool200000280oooo0P00000S
0?ooo`030000003oool0oooo0880oooo0P00000e0?ooo`008P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01d0oooo0P00000U0?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool0<P3oool00280oooo00<000000?ooo`3oool07`3oool2000001/0oooo0P00000C0?ooo`T0
00002`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0340oooo000R0?ooo`030000
003oool0oooo0240oooo0P00000G0?ooo`8000002@3ooolN00000080oooo00<000000?ooo`3oool0
QP3oool200000340oooo000R0?ooo`030000003oool0oooo02<0oooo0P00000C0?ooo`8000001`3o
ool>000000h0oooo2@00002:0?ooo`030000003oool0oooo02h0oooo000R0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool03P3oool2000000H0oooo1`00000N0?ooo`L000005`3oool:
000006H0oooo00<000000?ooo`3oool0;@3oool00280oooo00<000000?ooo`3oool09P3oool20000
00d0oooo00<000000?ooo`3oool00`3oool6000000d0oooo2`00000<0?ooo`030000003oool00000
00@00000503oool2000000T0oooo1P00001Q0?ooo`800000;@3oool00280oooo00<000000?ooo`3o
ool0:03oool2000000T0oooo0P0000030?ooo`H000002@3ooolJ000000@0oooo00<000000?ooo`3o
ool00`3oool300000100oooo0P00000A0?ooo`<00000H03oool00`000000oooo0?ooo`0Z0?ooo`00
8@3oool00`000000oooo0?ooo`0[0?ooo`8000001@3oool200000080oooo1P0000070?oooa`00000
0P3oool6000000H0oooo1000000=0?ooo`8000000`3oool=000000D0oooo0P00001O0?ooo`030000
003oool0oooo02T0oooo000Q0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00P00
00020?ooo`H000001@3oool=000000030?ooo`000000000000`000000`3oool;000000L0oooo0P00
000<0?ooo`030000003oool0oooo00<00000303oool500000080oooo0`00001J0?ooo`<00000:`3o
ool00240oooo00<000000?ooo`3oool0;P3oool200000080oooo1@0000050?ooobD000000P3oool8
000000H0oooo0P00000:0?ooo`80000000<0oooo0000000000001@3oool7000000H0oooo0`000003
0?ooo`@00000E03oool200000080oooo00<000000?ooo`3oool0:@3oool00240oooo00<000000?oo
o`3oool0;03oool200000080oooo0`0000060?oooa8000004@3ooolA000000D0oooo0P0000090?oo
o`040000003oool00000000000<0oooo0`0000070?ooo`H000000`3oool3000000@0oooo0P00001@
0?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`008@3oool00`000000oooo0?ooo`0Z0?oo
o`8000000P3oool3000000030?ooo`000000000000<0oooo4000000K0?ooo`D000000P3oool60000
00@0oooo0P0000080?ooo`030000003oool000000080oooo0P00000@0?ooo`<000000`3oool30000
00<0oooo0P00001<0?ooo`8000001`3oool00`000000oooo0?ooo`0X0?ooo`008@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00<000001@3oool8000000030?ooo`000000000000<0
00002@3ooolA000000X0oooo2P0000040?ooo`8000001`3oool3000000030?ooo`000000000001@0
oooo0`0000030?ooo`<000000P3oool2000004P0oooo0P0000090?ooo`030000003oool0oooo02P0
oooo000Q0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00`0000050?ooo`H00000
00<0oooo000000000000100000070?ooo`@000000`3oool=000000030?ooo`000000000000@00000
103oool01P000000oooo000000000000oooo00000080oooo0`0000040?ooo`8000001P3oool20000
00030?ooo`000000000000H0oooo2@0000090?ooo`<000000`3oool200000080oooo0P0000140?oo
o`8000002`3oool00`000000oooo0?ooo`0X0?ooo`00803oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool00000008000001@3oool<000000D0oooo7`0000000`3oool00000000000020?ooo`04
0000003oool0oooo0?ooo`<000000P3oool010000000oooo0000000000030?ooo`030000003oool0
oooo00@0oooo100000040?ooo`<0000000<0oooo0000000000002`0000070?ooo`<000000P3oool0
10000000oooo0?ooo`3oool200000440oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0X0?ooo`00803oool00`000000oooo0?ooo`0V0?ooo`80000000@0oooo0000000000000000103o
ool6000000030?ooo`000000000000<000000`3ooolQ000000050?ooo`00000000000000003oool0
100000050?ooo`80000000@0oooo0000003oool000000`3oool2000000@0oooo0P0000000`3oool0
00000?ooo`030?ooo`D000002@3oool7000000L0oooo1@0000030?ooo`030000003oool0oooo03`0
oooo0P00000>0?ooo`030000003oool0oooo02P0oooo000P0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool00P0000050?ooo`D0000000@0oooo0000000000000000103oool300000080
oooo9`0000000`3oool000000?ooo`040?ooo`@0000000<0oooo0000003oool00P3oool00`000000
oooo0?ooo`020?ooo`80000000@0oooo0000003oool0oooo100000040?ooo`X000000`3oool70000
00D0oooo1@0000000`3oool000000000000j0?ooo`800000403oool00`000000oooo0?ooo`0X0?oo
o`00803oool00`000000oooo0?ooo`0T0?ooo`040000003oool00000000000D0oooo1@000000103o
ool000000000000000040?ooo`T0000000<0oooo000000000000800000000`3oool0000000000003
000000@0oooo00<000000?ooo`0000000`0000020?ooo`8000000`3oool300000080oooo0`000003
0?ooo`<000002P3oool5000000050?ooo`00000000000000003oool00P0000050?ooo`80000000@0
oooo000000000000oooo0P00000f0?ooo`8000004P3oool00`000000oooo0?ooo`0X0?ooo`00803o
ool00`000000oooo0?ooo`0S0?ooo`040000003oool00000000000D0oooo100000000`3oool00000
00000002000000<0oooo0P0000000`3oool000000000000E000000<0oooo4`0000001@3oool00000
0000003oool0000000@0oooo00<000000?ooo`0000000`0000000`3oool00000000000030?ooo`<0
00000P3oool200000080oooo0P00000B0?ooo`<0000000<0oooo0000000000000`0000050?ooo`80
000000@0oooo000000000000oooo0P00000b0?ooo`8000005@3oool00`000000oooo0?ooo`0W0?oo
o`00803oool00`000000oooo0?ooo`0R0?ooo`040000003oool00000000000@0oooo100000000`3o
ool0000000000002000000<0oooo0P0000000`3oool000000000000?000001@0oooo3P0000000`3o
ool000000?ooo`030?ooo`D000000P3oool010000000oooo0?ooo`3oool3000000060?ooo`000000
00000000003oool000005`3oool3000000030?ooo`000000000000<00000103oool2000000040?oo
o`000000oooo0?ooo`800000;P3oool2000001L0oooo00<000000?ooo`3oool09`3oool00200oooo
00<000000?ooo`3oool0803oool2000000030?ooo`000000oooo00@0oooo10000000103oool00000
0000000000030?ooo`80000000@0oooo000000000000oooo3000000L0?ooo`d00000103oool50000
00030?ooo`00000000000080oooo0P0000020?ooo`80000000<0oooo0000003oool06P3oool50000
00030?ooo`000000000000@0oooo00@000000?ooo`00000000000P3oool2000002X0oooo0P00000I
0?ooo`030000003oool0oooo02L0oooo000O0?ooo`030000003oool0oooo0200oooo00@000000?oo
o`0000000000103oool4000000040?ooo`0000000000000000@0oooo00D000000?ooo`0000000000
0?ooo`0:000000<0oooo00<000000?ooo`3oool07@3oool4000000030?ooo`000000000000@00000
0`3oool5000000030?ooo`00000000000080oooo0P0000001@3oool000000000003oool0000000`0
oooo1@00000>0?ooo`L000000`3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02L0oooo000O0?ooo`030000
003oool0oooo01l0oooo00@000000?ooo`0000000000103oool4000000040?ooo`00000000000000
00<0oooo100000020?ooo`L00000203oool2000000/0oooo0`00000@0?ooo`L0000000@0oooo0000
0000000000000`3oool400000080oooo00<000000?ooo`3oool00P000000103oool0000000000000
00090?ooo`@000001@3oool7000000X0oooo1P0000030?ooo`040000003oool0000000000080oooo
0P00000T0?ooo`800000703oool00`000000oooo0?ooo`0W0?ooo`007`3oool00`000000oooo0?oo
o`0N0?ooo`040000003oool00000000000@0oooo1`0000040?ooo`@0000000<0oooo000000000000
1@00000<0?oooaH00000203oool00`000000oooo0?ooo`05000000040?ooo`0000000000000000<0
oooo10000000103oool000000?ooo`3oool2000000040?ooo`000000oooo000000H0oooo0`00000@
0?ooo`<000002@3oool2000000040?ooo`000000000000000080oooo0P0000000`3oool000000000
00020?ooo`030000003oool0oooo01l0oooo0P00000N0?ooo`030000003oool0oooo02L0oooo000O
0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`0000000000103oool00`000000oooo0000
0004000000<0oooo100000000`3oool0000000000005000000/0oooo100000000`3oool000000000
000A000000030?ooo`000000000000H0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`00
0000oooo00<000000P3oool4000000040?ooo`000000oooo0?ooo`80000000<0oooo000000000000
1P3oool00`000000oooo0?ooo`0D0?ooo`<00000203oool5000000<0oooo0P0000001@3oool00000
0000003oool0000001h0oooo0P00000P0?ooo`030000003oool0oooo02L0oooo000O0?ooo`030000
003oool0oooo01`0oooo00@000000?ooo`0000000000103oool00`000000oooo00000003000000<0
oooo0P0000000`3oool000000?ooo`07000000X0oooo0`0000020?oooad000000P3oool00`000000
oooo0?ooo`030?ooo`80000000<0oooo0000000000000`0000020?ooo`H0000000<0oooo00000000
00000`0000050?ooo`030000003oool0oooo00D0oooo3@0000060?ooo`<000001`3oool5000000<0
oooo00D000000?ooo`00000000000?ooo`02000001X0oooo0P00000S0?ooo`030000003oool0oooo
02H0oooo000O0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`0000000000103oool01P00
0000oooo000000000000oooo000000<0oooo00<000000?ooo`0000002000000:0?ooo`80000000<0
oooo0000000000007P000000103oool000000000000000050?ooo`040000003oool000000?ooo`<0
000000<0oooo0000003oool01P0000000`3oool0000000000003000000<0oooo0P0000040?oooa@0
00001P3oool3000000H0oooo00@000000?ooo`00000000000`3oool2000000050?ooo`0000000000
0?ooo`0000005`3oool2000002D0oooo00<000000?ooo`3oool09P3oool001l0oooo00<000000?oo
o`3oool06`3oool3000000@0oooo1P0000030?ooo`030000003oool000000080000000<0oooo0000
000000000`0000080?ooobP0000000<0oooo0000003oool01@3oool00`000000oooo000000050000
00030?ooo`00000000000080000000<0oooo0000003oool0100000040?ooo`030000003oool0oooo
0080oooo6@0000050?ooo`8000001@3oool2000000030?ooo`000000000000<0oooo0P000000103o
ool0000000000000000D0?ooo`8000009`3oool00`000000oooo0?ooo`0V0?ooo`007P3oool00`00
0000oooo0?ooo`0K0?ooo`80000000<0oooo0000003oool00P3oool6000000<0oooo00D000000?oo
o`00000000000?ooo`06000000L0oooo0P0000000`3oool000000000000Y000000D0oooo1`000002
0?ooo`<0000000<0oooo0000003oool0100000030?ooo`040000003oool0oooo0?ooo`T000002P3o
ool:000000D0oooo0P0000050?ooo`030000003oool0oooo008000000`3oool00`000000oooo0000
000300000140oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`007P3oool0
0`000000oooo0?ooo`0J0?ooo`80000000<0oooo0000003oool00P3oool6000000<0oooo00D00000
0?ooo`00000000000?ooo`03000000030?ooo`000000oooo00H0oooo0P0000000`3oool000000000
000?000000H0oooo00<000000?ooo`3oool00P3oool:000000030?ooo`000000000000<0000000<0
oooo0000003oool0103oool7000000070?ooo`00000000000000003oool000000?ooo`04000000<0
oooo00<000000?ooo`3oool01`00000B0?ooo`P00000103oool2000000@0oooo0P0000020?ooo`80
00000P3oool4000000030?ooo`000000oooo00d0oooo0P00000Z0?ooo`030000003oool0oooo02H0
oooo000N0?ooo`030000003oool0oooo01T0oooo100000030?ooo`H000000`3oool01@000000oooo
000000000000oooo00<0000000<0oooo0000003oool01P3oool00`000000oooo0000000>000000/0
oooo0P0000070?ooo``0000000<0oooo0000003oool0103oool600000080oooo100000000`3oool0
00000000000200000080oooo00@000000?ooo`3oool0oooo1@0000040?ooo`h000001@3oool80000
00<0oooo0P0000040?ooo`80000000<0oooo0000000000000`3oool00`000000oooo000000030000
00X0oooo0P00000/0?ooo`030000003oool0oooo02H0oooo000N0?ooo`030000003oool0oooo01P0
oooo100000030?ooo`H000000`3oool4000000030?ooo`000000000000<000001P3oool@00000100
oooo0P0000070?ooo`H0000000<0oooo0000000000000`0000060?ooo`H0000000<0oooo00000000
00000P000000103oool000000000000000030?ooo`030000003oool0oooo00D000000`3oool20000
00030?ooo`0000000000010000000`3oool7000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0200000080oooo100000000`3oool000000?ooo`060?ooo`800000;P3oool00`00
0000oooo0?ooo`0V0?ooo`007P3oool00`000000oooo0?ooo`0H0?ooo`<000000`3oool6000000<0
oooo1`0000000`3oool000000?ooo`060?ooo`030000003oool0000000X000002P3oool>000000L0
oooo0`0000000`3oool0000000000005000000D0oooo1P0000000`3oool000000000000200000004
0?ooo`000000000000000080oooo00<000000?ooo`3oool0100000040?ooo`P000001@3oool<0000
0080oooo1`0000020?ooo`800000103oool2000000040?ooo`000000000000000080oooo00D00000
0?ooo`000000oooo000000040?ooo`800000<03oool00`000000oooo0?ooo`0V0?ooo`007P3oool0
0`000000oooo0?ooo`0G0?ooo`<000000`3oool4000000030?ooo`000000oooo0080oooo1`000000
0`3oool000000?ooo`060?ooo``000001P3ooolF000000L0oooo0P0000000`3oool0000000000005
000000D0oooo1@0000000`3oool0000000000002000000040?ooo`000000000000000080oooo00<0
00000?ooo`3oool0100000020?ooo`D000000`3oool<000000<0oooo1`0000000`3oool000000000
0004000000<0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`00000000000080oooo00H0
00000?ooo`000000oooo0000003oool2000003<0oooo00<000000?ooo`3oool09@3oool001d0oooo
00<000000?ooo`3oool05`3oool400000080oooo1P0000030?ooo`L0000000<0oooo0000003oool0
1@3oool<000000H0oooo0P000000103oool000000000000000030?ooo`P000001@3oool5000000D0
oooo2P0000040?ooo`X0000000@0oooo00000000000000000P3oool00`000000oooo000000030000
0080oooo100000020?oooa/0000000<0oooo000000000000100000020?ooo`8000001@3oool00`00
0000oooo00000002000000030?ooo`000000oooo00@00000=03oool00`000000oooo0?ooo`0U0?oo
o`007@3oool00`000000oooo0?ooo`0G0?ooo`<000000P3oool6000000<0oooo1`0000000`3oool0
00000?ooo`050?ooo`030000003oool0000000P000001P3oool>00000080oooo200000030?ooo`@0
0000103oool7000000030?ooo`000000000000@0oooo1@0000000`3oool000000000000500000080
oooo00<000000?ooo`0000000P0000020?ooo`@000000P3ooolH000000030?ooo`00000000000080
00000P3oool00`000000oooo00000002000000<0oooo0P0000040?ooo`030000003oool000000080
000000<0oooo0000000000000P0000000`3oool000000?ooo`0b0?ooo`030000003oool0oooo02D0
oooo000M0?ooo`030000003oool0oooo01H0oooo0`0000030?ooo`D000000`3oool7000000030?oo
o`000000oooo00D0oooo2P0000060?ooo`<0000000<0oooo0000000000001000000?0?ooo`D00000
00<0oooo0000000000000P0000030?ooo`T000001@3oool4000000030?ooo`000000000000D00000
00<0oooo0000003oool0100000000`3oool000000?ooo`02000000030?ooo`000000000000P00000
1P3oool<000000030?ooo`00000000000080000000@0oooo000000000000oooo0`0000030?ooo`03
0000003oool0oooo0080oooo0P0000002P3oool00000000000000000oooo0000003oool000000?oo
o`00000b0?ooo`030000003oool0oooo02D0oooo000M0?ooo`030000003oool0oooo01D0oooo0`00
00030?ooo`H000000P3oool00`000000oooo00000004000000030?ooo`000000oooo00D0oooo2P00
00050?ooo`<0000000<0oooo0000000000000`0000070?ooo`L00000203oool200000080oooo0`00
00020?ooo`030000003oool0000000L00000103oool4000000030?ooo`000000000000D0000000<0
oooo0000003oool00`0000020?ooo`<0000000<0oooo0000000000001@0000000`3oool000000000
000E000000040?ooo`000000000000000080oooo1P0000020?ooo`800000103oool400000080oooo
00D000000?ooo`000000oooo0000000a0?ooo`030000003oool0oooo02D0oooo000M0?ooo`030000
003oool0oooo01D0oooo0`0000020?ooo`H000000P3oool01@000000oooo000000000000oooo0080
000000<0oooo0000003oool01@3oool9000000H0oooo0P000000103oool000000000000000050?oo
o`P000000`3oool6000000H0oooo0P0000020?ooo`80000000<0oooo0000003oool00P0000000`3o
ool0000000000004000000<0oooo100000000`3oool0000000000005000000030?ooo`000000oooo
00<0000000D0oooo00000000000000000?ooo`06000000030?ooo`000000000001T0000000@0oooo
00000000000000000P3oool5000000<0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`08
0000003oool0oooo0000003oool000000?ooo`00000`0?ooo`030000003oool0oooo02D0oooo000M
0?ooo`030000003oool0oooo01@0oooo0`0000030?ooo`D000000`3oool3000000030?ooo`000000
0000008000001P3oool8000000H0oooo0`0000000`3oool00000000000040?ooo`<000000`3oool@
000000D0oooo0P0000020?ooo`<000000P3oool8000000@0oooo0`0000000`3oool0000000000004
00000080oooo00<000000?ooo`000000100000000`3oool000000000000400000080oooo8P000002
0?ooo`D0000000<0oooo000000000000103oool00`000000oooo0?ooo`02000000060?ooo`000000
oooo0000003oool00000;`3oool00`000000oooo0?ooo`0U0?ooo`007@3oool00`000000oooo0?oo
o`0C0?ooo`<000000`3oool5000000<0oooo1@0000000`3oool00000000000060?ooo`P000001@3o
ool3000000030?ooo`000000000000@0oooo0P0000000`3oool0000000000003000000`0oooo1`00
00040?ooo`H000000P3oool7000000@0oooo2P0000020?ooo`@0000000<0oooo0000000000001P00
00000`3oool000000000000T00000080oooo100000020?ooo`8000000`3oool2000000040?ooo`00
000000000?ooo`D00000;`3oool00`000000oooo0?ooo`0T0?ooo`00703oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0000000<0oooo1@0000030?ooo`H0000000<0oooo0000003oool0103o
ool8000000D0oooo0P0000020?ooo`8000000`3oool2000000030?ooo`000000000000800000103o
ool9000000D0oooo1P0000030?ooo`L0000000<0oooo0000003oool01@0000030?ooo`X0000000<0
oooo0000003oool00`000000103oool000000000003oool4000000030?ooo`000000000000P00000
0P3oool600000080oooo6`0000020?ooo`8000000`3oool010000000oooo0000000000020?ooo`04
0000003oool00000000002h0oooo00<000000?ooo`3oool0903oool001`0oooo00<000000?ooo`3o
ool04`3oool3000000<0oooo1@0000030?ooo`H0000000<0oooo0000003oool01@3oool8000000@0
oooo00<000000?ooo`3oool00P0000030?ooo`80000000@0oooo00000000000000000P3oool50000
00030?ooo`000000000000D0000000<0oooo0000000000000P0000030?ooo`<0000000@0oooo0000
003oool0oooo0P0000001@3oool000000?ooo`000000oooo00<0000000<0oooo0000000000000`00
00020?ooo`X0000000<0oooo0000003oool01P0000001@3oool00000000000000000oooo00D00000
00@0oooo000000000000oooo3`0000020?ooo`d0000000@0oooo00000000000000000P3oool40000
00<0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo00@000000?ooo`0000000000
;@3oool00`000000oooo0?ooo`0T0?ooo`00703oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool000000080oooo100000000`3oool000000?ooo`020?ooo`@0000000<0oooo0000000000001P3o
ool5000000030?ooo`000000000000@0oooo00<000000?ooo`3oool00P0000020?ooo`80000000@0
oooo00000000000000000P3oool200000080oooo1@0000060?ooo`@0000000@0oooo000000000000
00000P3oool400000080oooo100000000`3oool000000?ooo`02000000030?ooo`000000000000<0
00000P3oool:000000030?ooo`000000oooo0080000000<0oooo0000000000004@0000030?ooo`H0
00000P3oool9000000030?ooo`000000000000/0000000<0oooo0000000000000P0000030?ooo`06
0000003oool0oooo0?ooo`000000oooo0P0000020?ooo`040000003oool00000000002`0oooo00<0
00000?ooo`3oool0903oool001`0oooo00<000000?ooo`3oool04P3oool3000000<0oooo1@000003
0?ooo`80000000<0oooo0000003oool00P0000060?ooo`D0000000<0oooo000000000000103oool0
10000000oooo0?ooo`0000020?ooo`80000000@0oooo00000000000000000P3oool2000000040?oo
o`0000000000000000<0oooo200000040?ooo`H0000000@0oooo00000000000000000`3oool30000
0080oooo00<000000?ooo`0000001P0000030?ooo`T0000000<0oooo0000003oool00P0000000`3o
ool0000000000004000000030?ooo`000000000000L000000P3oool>00000080oooo500000020?oo
o`<000000`3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool010000000oooo0000
0000000[0?ooo`030000003oool0oooo02@0oooo000L0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`0000000P3oool600000080oooo200000050?ooo`P00000103oool010000000oooo0000
000000020?ooo`D000000P3oool2000000040?ooo`00000000000?oooa4000000`3oool400000004
0?ooo`0000000000000000<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0
00000000003oool00P0000020?ooo`030000003oool0000000H0000000<0oooo0000003oool0>`00
0000103oool000000000000000030?ooo`040000003oool0oooo0?ooo`@000000P3oool010000000
oooo00000000000Z0?ooo`030000003oool0oooo02@0oooo000L0?ooo`030000003oool0oooo0140
oooo0`0000030?ooo`D000000`3oool4000000030?ooo`000000000000D0oooo1`0000050?ooo`04
0000003oool0000000000080oooo1@0000020?ooo`@0000000<0oooo0000000000001@0000000`3o
ool0000000000004000000030?ooo`000000000000D0000000<0oooo0000000000000P000000103o
ool000000000000000020?ooo`80000000D0oooo0000003oool000000?ooo`0700000080oooo00<0
00000?ooo`0000001P0000000`3oool000000?ooo`08000000030?ooo`000000000000D0000000<0
oooo0000000000005`0000000`3oool000000000000D00000080oooo00<000000?ooo`3oool00P3o
ool2000000<0oooo00<000000?ooo`0000000P00000X0?ooo`030000003oool0oooo02@0oooo000L
0?ooo`030000003oool0oooo0140oooo0`0000020?ooo`H000000P3oool2000000030?ooo`000000
000000<000001@3oool7000000@0oooo00@000000?ooo`00000000000`3oool300000080oooo1000
00000`3oool000000000000200000080oooo4`0000000`3oool0000000000006000000030?ooo`00
000000000080000000<0oooo0000003oool00P0000000`3oool000000000000200000080oooo2@00
00000`3oool000000000000=000000030?ooo`000000oooo01`0000000<0oooo0000000000001P00
00000`3oool000000000000:00000080oooo00<000000?ooo`3oool00P3oool2000000<0oooo00D0
00000?ooo`000000oooo0000000X0?ooo`030000003oool0oooo02<0oooo000K0?ooo`030000003o
ool0oooo0140oooo0`0000030?ooo`D000000`3oool4000000030?ooo`000000000000D0oooo1`00
00040?ooo`@000000`3oool300000080oooo0`0000000`3oool000000000000200000080oooo0P00
00000`3oool0000000000002000000<0oooo20000000103oool000000?ooo`0000020?ooo`800000
00D0oooo00000000000000000?ooo`03000000070?ooo`000000oooo0000003oool000000?ooo`0?
000000030?ooo`000000000000`0000000@0oooo0000003oool0oooo2@0000020?ooob00000000D0
oooo00000000000000000?ooo`0300000080oooo00<000000?ooo`3oool00P3oool2000000<0oooo
00D000000?ooo`000000oooo0000000W0?ooo`030000003oool0oooo02<0oooo000K0?ooo`030000
003oool0oooo0140oooo0`0000020?ooo`H000000P3oool2000000060?ooo`00000000000000003o
ool00000103oool8000000<0oooo0P0000000`3oool000000?ooo`020?ooo`<000000P3oool30000
00040?ooo`000000000000000080oooo400000000`3oool000000000000600000080oooo0P000000
0`3oool0000000000002000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`@0
000000<0oooo0000000000001`0000000`3oool000000000000>000000030?ooo`000000000000<0
000000@0oooo000000000000oooo:0000000103oool000000000000000020?ooo`030000003oool0
oooo0080oooo0P0000030?ooo`050000003oool000000?ooo`0000009P3oool00`000000oooo0?oo
o`0S0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`8000000`3oool5000000<0oooo10000000
0`3oool00000000000040?ooo`P000000`3oool2000000030?ooo`000000oooo0080oooo0`000002
0?ooo`L0000000<0oooo0000000000000P0000000`3oool0000000000003000000L0oooo10000000
0`3oool0000000000004000000050?ooo`000000oooo0000003oool00`0000020?ooo`<0000000D0
oooo00000000000000000?ooo`04000000030?ooo`000000000000L0000000<0oooo000000000000
3@0000000`3oool0000000000005000000030?ooo`000000000002T0000000<0oooo000000000000
0P0000000`3oool000000?ooo`030?ooo`8000000`3oool01@000000oooo0000003oool0000002D0
oooo00<000000?ooo`3oool08`3oool001/0oooo00<000000?ooo`3oool0403oool300000080oooo
0`0000000`3oool00000000000020?ooo`80000000H0oooo00000000000000000?ooo`0000040?oo
o`030000003oool0000000@000000`3oool2000000030?ooo`000000oooo0080oooo00@000000?oo
o`000000oooo400000000`3oool0000000000009000000070?ooo`00000000000000003oool00000
0?ooo`0300000080oooo0P0000000`3oool0000000000002000000040?ooo`000000oooo00000080
oooo0P0000000`3oool000000000000<000000050?ooo`00000000000000003oool0100000000`3o
ool000000000000B000000P0oooo400000000`3oool000000000000<00000080oooo0`0000000`3o
ool000000?ooo`030?ooo`8000000`3oool01@000000oooo0000003oool0000002@0oooo00<00000
0?ooo`3oool08`3oool001/0oooo00<000000?ooo`3oool0403oool300000080oooo1P0000020?oo
o`@0000000<0oooo000000000000103oool4000000040?ooo`0000000000000000<0oooo10000002
0?ooo`040000003oool000000?ooo`<0000000D0oooo00000000000000000?ooo`04000000030?oo
o`000000000000<0000000<0oooo0000000000001`0000000`3oool000000?ooo`020?ooo`<00000
00@0oooo00000000000000000P3oool2000000050?ooo`00000000000000003oool00`0000020?oo
o`80000000<0oooo000000000000300000001@3oool00000000000000000oooo00P0000000<0oooo
0000003oool02@0000000`3oool00000000000040?ooo`T0000000<0oooo0000000000006P000000
0`3oool0000000000002000000030?ooo`000000oooo00<0oooo0P0000020?ooo`060000003oool0
oooo0000003oool000008`3oool00`000000oooo0?ooo`0S0?ooo`006`3oool00`000000oooo0?oo
o`0@0?ooo`8000000P3oool600000080oooo1P0000000`3oool000000?ooo`030?ooo`L000000`3o
ool2000000040?ooo`000000oooo0?ooo`<0000000D0oooo00000000000000000?ooo`0300000004
0?ooo`00000000000?ooo`@000000`3oool2000000T0oooo1@0000000`3oool00000000000050000
00030?ooo`000000oooo00L0000000<0oooo0000003oool00P0000000`3oool000000000000@0000
00030?ooo`00000000000080000000D0oooo00000000000000000?ooo`07000000030?ooo`000000
0000008000000`3oool@000000030?ooo`000000000001@0000000@0oooo000000000000oooo1000
00000`3oool000000?ooo`030?ooo`8000000P3oool00`000000oooo000000020?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool08`3oool001/0oooo00<000000?ooo`3oool0403oool2
00000080oooo0`0000000`3oool00000000000020?ooo`@0000000<0oooo000000000000103oool8
000000<0oooo00<000000?ooo`0000000P3oool4000000030?ooo`00000000000080oooo00D00000
0?ooo`3oool000000?ooo`05000000040?ooo`0000000000000000h0oooo0`0000000`3oool00000
0?ooo`0;000000050?ooo`00000000000?ooo`0000000P3oool00`000000oooo0000000?00000003
0?ooo`000000000000@0000000<0oooo0000000000002`0000000`3oool000000?ooo`020?ooo`L0
00000`3oool9000000030?ooo`000000000001<0000000@0oooo000000000000oooo100000000`3o
ool000000?ooo`030?ooo`8000000P3oool01@000000oooo0000003oool0000002<0oooo00<00000
0?ooo`3oool08P3oool001X0oooo00<000000?ooo`3oool0403oool2000000<0oooo1@0000030?oo
o`D0000000<0oooo0000003oool00`3oool7000000<0oooo00<000000?ooo`0000000P3oool40000
00030?ooo`00000000000080oooo0P0000000`3oool000000?ooo`02000000030?ooo`000000oooo
008000004`3oool2000000050?ooo`00000000000000003oool00P0000000`3oool0000000000003
000000050?ooo`00000000000?ooo`0000000P3oool00`000000oooo0000000>000000030?ooo`00
0000000001@000000`3oool5000000`0oooo1@0000000`3oool000000000000>000000050?ooo`00
000000000000003oool00P0000000`3oool0000000000002000000030?ooo`000000oooo00<0oooo
0P0000020?ooo`050000003oool000000?ooo`0000008P3oool00`000000oooo0?ooo`0R0?ooo`00
6P3oool00`000000oooo0?ooo`0@0?ooo`8000000P3oool3000000030?ooo`00000000000080oooo
1`0000040?ooo`030000003oool0000000@00000103oool00`000000oooo000000020?ooo`<00000
00D0oooo0000003oool000000?ooo`02000000040?ooo`000000oooo0?ooo`<0000000<0oooo0000
003oool05@3oool2000000030?ooo`000000000000X0000000@0oooo00000000000000000P3oool4
000000030?ooo`000000000000X0000000<0oooo0000000000004`0000030?ooo`040000003oool0
000000000100oooo5@0000000`3oool0000000000004000000040?ooo`000000000000000080oooo
00<000000?ooo`3oool00P3oool200000080oooo00D000000?ooo`000000oooo0000000Q0?ooo`03
0000003oool0oooo0280oooo000J0?ooo`030000003oool0oooo0100oooo0P0000020?ooo`<00000
00<0oooo0000003oool00P3oool5000000030?ooo`000000oooo00<0oooo1`0000030?ooo`030000
003oool000000080oooo0`0000020?ooo`80000000@0oooo000000000000oooo0P0000001P3oool0
0000000000000000oooo000001P0oooo0`0000000`3oool0000000000002000000040?ooo`000000
00000?ooo`80000000@0oooo00000000000000000P3oool2000000030?ooo`000000oooo00`00000
00<0oooo0000000000004`0000020?ooo`@000004`3ooolD000000030?ooo`000000000000D00000
00<0oooo0000000000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@00
0000oooo0000003oool000000200oooo00<000000?ooo`3oool08P3oool001X0oooo00<000000?oo
o`3oool03`3oool2000000<0oooo1@0000030?ooo`D0000000<0oooo0000003oool00P3oool00`00
0000oooo00000004000000@0oooo0`0000020?ooo`8000000P3oool2000000040?ooo`0000000000
0?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0
00000?ooo`L0000000<0oooo000000000000100000020?ooo`80000000<0oooo0000003oool02000
00000`3oool000000000000F00000080oooo0`00000G0?oooa/0000000<0oooo0000000000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
01l0oooo00<000000?ooo`3oool08P3oool001X0oooo00<000000?ooo`3oool03`3oool2000000<0
oooo1@0000020?ooo`<0000000@0oooo0000000000000000103oool00`000000oooo000000040000
00<0oooo100000001@3oool000000?ooo`000000oooo00<0000000<0oooo00000000000010000000
103oool000000?ooo`00000K0?ooo`030000003oool0000000L0000000D0oooo0000000000000000
0?ooo`0200000080oooo100000000`3oool000000000000O000000040?ooo`0000000000000001/0
oooo6@0000000`3oool00000000000020?ooo`040000003oool0oooo0?ooo`8000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08P3oool001X0
oooo00<000000?ooo`3oool03`3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`@0
000000<0oooo0000000000000`3oool00`000000oooo00000005000000<0oooo0`0000020?ooo`<0
000000@0oooo000000000000oooo0P0000000`3oool0000000000003000000030?ooo`000000oooo
01`0oooo00<000000?ooo`000000100000000`3oool0000000000006000000<0oooo0`0000020?oo
o``0000000<0oooo0000000000005000000M0?ooo`<0000000<0oooo0000000000005P0000020?oo
o`040000003oool0oooo0?ooo`8000000P3oool01@000000oooo0000003oool0000001h0oooo00<0
00000?ooo`3oool08P3oool001X0oooo00<000000?ooo`3oool03`3oool200000080oooo1@000003
0?ooo`H00000103oool00`000000oooo00000004000000<0oooo100000001@3oool000000?ooo`00
0000oooo00<0000000<0oooo0000000000001@0000000`3oool000000?ooo`0M0?ooo`030000003o
ool0000000@0000000<0oooo0000000000000`000000103oool000000000000000020?ooo`030000
003oool0000000<0oooo1`0000001@3oool00000000000000000oooo01D00000803oool200000003
0?ooo`000000000001H0000000<0oooo0000003oool00P3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000007P3oool00`000000oooo0?ooo`0Q0?ooo`006@3oool00`000000
oooo0?ooo`0?0?ooo`8000000`3oool5000000<0oooo1P0000040?ooo`030000003oool0000000@0
00000`3oool00`000000oooo000000020?ooo`040000003oool000000?ooo`80000000H0oooo0000
00000000oooo0000003oool2000000030?ooo`000000oooo01h0oooo00<000000?ooo`0000001000
00000`3oool0000000000003000000050?ooo`00000000000000003oool00P0000000`3oool00000
0?ooo`020?ooo`L0000000<0oooo0000000000005`00000Q0?oooaL0000000H0oooo000000000000
00000?ooo`0000030?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000M
0?ooo`030000003oool0oooo0240oooo000I0?ooo`030000003oool0oooo00l0oooo0P0000030?oo
o`D000000P3oool3000000040?ooo`0000000000000000@0oooo1`0000030?ooo`030000003oool0
00000080oooo1P0000000`3oool0000000000005000000030?ooo`000000oooo01l0oooo0P000000
0`3oool0000000000007000000030?ooo`000000000000@0000000<0oooo0000000000000P3oool8
000000030?ooo`000000000000H0000000<0oooo0000003oool03000000S0?oooa/0000000<0oooo
0000003oool00P3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool08@3oool001T0oooo00<000000?ooo`3oool03`3oool200000080oooo1@0000030?oo
o`H000001@3oool7000000<0oooo0`0000001@3oool000000?ooo`000000oooo00D0000000<0oooo
0000003oool00P0000000`3oool000000?ooo`0P0?ooo`80000000D0oooo00000000000000000?oo
o`02000000040?ooo`00000000000?ooo`P0000000<0oooo0000003oool0200000000`3oool00000
0000000E000002@0oooo6P0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool200000003
0?ooo`000000oooo01/0oooo00<000000?ooo`3oool08@3oool001T0oooo00<000000?ooo`3oool0
3`3oool200000080oooo1@0000030?ooo`H00000103oool00`000000oooo00000004000000<0oooo
00D000000?ooo`00000000000?ooo`03000000040?ooo`00000000000?ooo`L0000000<0oooo0000
003oool0803oool01`000000oooo000000000000oooo0000003oool00P000000103oool000000000
003oool3000000030?ooo`00000000000080000000<0oooo0000003oool01@0000001@3oool00000
000000000000oooo01D000009P3ooolD000000030?ooo`000000000000<000000P3oool01P000000
oooo0?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo0000000K0?ooo`030000003o
ool0oooo0240oooo000I0?ooo`030000003oool0oooo00l0oooo0P0000020?ooo`D000000`3oool6
000000@0oooo1`0000030?ooo`030000003oool000000080oooo0P0000020?ooo`@0000000<0oooo
0000000000000`0000000`3oool000000?ooo`0P0?ooo`030000003oool0000000T0000000@0oooo
000000000000oooo1@0000020?ooo`L0000000<0oooo0000000000005`00000V0?oooaH0000000@0
oooo00000000000000000P3oool00`000000oooo0?ooo`02000000<0oooo00D000000?ooo`000000
oooo0000000J0?ooo`030000003oool0oooo0240oooo000I0?ooo`030000003oool0oooo00l0oooo
0P0000020?ooo`030000003oool00000008000000P3oool3000000040?ooo`0000000000000000@0
oooo1`0000020?ooo`80000000@0oooo0000003oool0oooo0P000000103oool000000000003oool4
000000050?ooo`00000000000?ooo`0000008P3oool00`000000oooo00000006000000030?ooo`00
0000000000<0000000<0oooo0000000000000`0000020?ooo`L000000P3ooolH000002L0oooo1000
00000`3oool000000000000B00000080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`800000
00<0oooo0000003oool06@3oool00`000000oooo0?ooo`0Q0?ooo`00603oool00`000000oooo0?oo
o`0?0?ooo`8000000`3oool00`000000oooo0000000200000080oooo0`000000103oool000000000
000000040?ooo`L000000P3oool2000000040?ooo`000000oooo0?ooo`80000000@0oooo00000000
0000oooo100000001@3oool000000000003oool000000280oooo00<000000?ooo`0000000`000000
103oool000000000003oool2000000030?ooo`00000000000080oooo100000020?ooo`P0000000<0
oooo0000000000005P00000X0?ooo`@0000000<0oooo0000000000003P000000103oool000000000
000000020?ooo`030000003oool0oooo00800000103oool2000000030?ooo`000000oooo01P0oooo
00<000000?ooo`3oool08@3oool001P0oooo00<000000?ooo`3oool03`3oool2000000<0oooo1@00
00020?ooo`H000001@3oool700000080oooo100000001@3oool00000000000000000oooo00800000
00<0oooo0000003oool01P00000S0?ooo`030000003oool0000000<0000000D0oooo000000000000
00000?ooo`0400000080oooo00H000000?ooo`000000oooo0000003oool9000000030?ooo`000000
000001H00000:03oool2000000030?ooo`000000000000d0000000@0oooo000000000000oooo0`00
00020?ooo`030000003oool0oooo008000000`3oool01@000000oooo0000003oool0000001T0oooo
00<000000?ooo`3oool0803oool001P0oooo00<000000?ooo`3oool03`3oool200000080oooo1@00
00030?ooo`H000001@3oool700000080oooo00D000000?ooo`00000000000?ooo`03000000060?oo
o`00000000000?ooo`000000oooo1P00000S0?ooo`070000003oool000000000003oool000000?oo
o`04000000030?ooo`00000000000080000000<0oooo0000003oool00P0000000`3oool000000000
000Q000002T0oooo5@0000000`3oool00000000000030?ooo`030000003oool0oooo008000000`3o
ool010000000oooo00000000000I0?ooo`030000003oool0oooo0200oooo000H0?ooo`030000003o
ool0oooo00l0oooo0P0000020?ooo`D000000`3oool6000000D0oooo1P0000030?ooo`030000003o
ool000000080oooo1P0000000`3oool000000?ooo`03000000030?ooo`000000000002<0oooo00<0
00000?ooo`0000002P0000000`3oool000000?ooo`04000000030?ooo`000000oooo00H0000000<0
oooo0000000000005`0000000`3oool000000000000Y0?ooo`<0000000D0oooo0000000000000000
0?ooo`0<000000040?ooo`000000000000000080oooo00D000000?ooo`3oool0oooo000000040?oo
o`80000000<0oooo0000003oool05`3oool00`000000oooo0?ooo`0P0?ooo`00603oool00`000000
oooo0?ooo`0?0?ooo`8000000P3oool5000000<0oooo1P0000050?ooo`H000000`3oool00`000000
oooo000000020?ooo`P0000000<0oooo0000000000000P0000000`3oool000000?ooo`0R0?ooo`P0
000000<0oooo0000000000002@0000020?ooo`L000000P3ooolL000002T0oooo4@000000103oool0
00000000003oool300000080oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool00000
0?ooo`0000005`3oool00`000000oooo0?ooo`0P0?ooo`00603oool00`000000oooo0?ooo`0?0?oo
o`8000000P3oool5000000<0oooo1P0000040?ooo`L000000`3oool00`000000oooo000000020?oo
o`80000000@0oooo000000000000oooo100000001@3oool000000000003oool0000002<0oooo2000
0000103oool000000000003oool3000000040?ooo`000000oooo000000<0oooo200000020?oooaH0
000000<0oooo0000000000000P00000Y0?ooo`T0000000@0oooo000000000000oooo2`0000020?oo
o`040000003oool0oooo0?ooo`8000000`3oool4000001L0oooo00<000000?ooo`3oool0803oool0
01P0oooo00<000000?ooo`3oool03`3oool200000080oooo1@0000020?ooo`030000003oool00000
00@00000103oool7000000<0oooo00<000000?ooo`0000000P3oool2000000040?ooo`0000000000
0?ooo`@0000000D0oooo000000000000oooo0000000R0?ooo`H0000000@0oooo000000000000oooo
0P0000000`3oool000000000000600000080oooo1@0000001@3oool000000?ooo`000000oooo00/0
000000<0oooo0000000000003P00000X0?oooa80000000@0oooo000000000000oooo0`0000020?oo
o`040000003oool0oooo0?ooo`8000000P3oool01@000000oooo0000003oool0000001H0oooo00<0
00000?ooo`3oool0803oool001L0oooo00<000000?ooo`3oool0403oool200000080oooo1@000002
0?ooo`030000003oool0000000@00000103oool7000000<0oooo00<000000?ooo`0000000P3oool2
000000040?ooo`00000000000?ooo`L0000000<0oooo0000003oool0803oool2000000030?ooo`00
000000000080000000H0oooo000000000000oooo0000003oool300000080oooo1@0000000`3oool0
000000000004000000<0oooo7P00000X0?ooo`T0000000<0oooo000000000000300000020?ooo`04
0000003oool0oooo0?ooo`8000000`3oool4000001H0oooo00<000000?ooo`3oool0803oool001L0
oooo00<000000?ooo`3oool0403oool200000080oooo1@0000020?ooo`L00000103oool7000000<0
oooo00<000000?ooo`0000000P3oool2000000040?ooo`00000000000?ooo`80000000<0oooo0000
000000000P0000000`3oool000000?ooo`0N0?ooo`80000000<0oooo0000003oool00P0000000`3o
ool000000?ooo`04000000040?ooo`000000oooo00000080oooo3@0000030?oooah000009`3ooolB
000000040?ooo`00000000000?ooo`<000000P3oool010000000oooo0?ooo`3oool200000080oooo
00D000000?ooo`000000oooo0000000F0?ooo`030000003oool0oooo01l0oooo000G0?ooo`030000
003oool0oooo0100oooo0P0000020?ooo`D000000P3oool7000000@0oooo1`0000030?ooo`030000
003oool000000080oooo0P0000000`3oool0000000000003000000030?ooo`000000000000800000
00<0oooo0000003oool0703oool2000000<0oooo200000002P3oool000000000003oool000000?oo
o`000000oooo0000003oool9000000040?ooo`000000000000000080oooo0`0000001@3oool00000
000000000000oooo01L000009`3oool9000000030?ooo`000000000000`000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool4000001H0oooo00<000000?ooo`3oool07`3oool0
01L0oooo00<000000?ooo`3oool0403oool200000080oooo1@0000020?ooo`L00000103oool70000
00<0oooo00<000000?ooo`0000000P3oool2000000030?ooo`000000000000<0000000<0oooo0000
003oool00P0000000`3oool000000?ooo`0J0?ooo`800000103oool00`000000oooo0000000:0000
00070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`L000000P3oool4000000030?ooo`00
0000oooo01`000009P3oool2000000030?ooo`000000000000d0000000@0oooo000000000000oooo
0`0000020?ooo`040000003oool0oooo0?ooo`8000000P3oool01@000000oooo0000003oool00000
01D0oooo00<000000?ooo`3oool07`3oool001L0oooo00<000000?ooo`3oool0403oool200000080
oooo1@0000020?ooo`L00000103oool7000000<0oooo00<000000?ooo`0000000P3oool200000080
oooo0P0000000`3oool0000000000004000000030?ooo`000000oooo01T0oooo00<000000?ooo`3o
ool0103oool2000000030?ooo`000000000000<0000000<0oooo0000000000000P0000000`3oool0
00000?ooo`0400000080oooo1`0000030?ooob@000009@3ooolD000000040?ooo`00000000000000
0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo1000000E0?ooo`030000003o
ool0oooo01l0oooo000G0?ooo`030000003oool0oooo0100oooo0P0000020?ooo`D000000P3oool7
000000@0oooo1`0000030?ooo`030000003oool000000080oooo0P0000020?ooo`80000000<0oooo
0000000000001P00000H0?ooo`8000001`3oool8000000030?ooo`00000000000080000000D0oooo
0000003oool000000?ooo`0200000080oooo200000020?ooo`L000000P3oool7000000030?ooo`00
0000000000D0000000<0oooo0000003oool02P00000T0?oooa80000000@0oooo000000000000oooo
0`0000020?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo00000000000E0?oo
o`030000003oool0oooo01l0oooo000G0?ooo`030000003oool0oooo0100oooo0P0000020?ooo`D0
00000P3oool7000000@0oooo1`0000030?ooo`@0000000<0oooo0000000000000P3oool200000003
0?ooo`000000000000D0000000<0oooo0000003oool0503oool2000000P0oooo0P0000000`3oool0
000000000005000000050?ooo`00000000000?ooo`0000000P3oool00`000000oooo000000030?oo
oaP0000000<0oooo0000000000005@00000S0?oooaD0000000@0oooo00000000000000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool4000001@0oooo00<000000?ooo`3oool0
7`3oool001H0oooo00<000000?ooo`3oool04@3oool200000080oooo1@0000020?ooo`L00000103o
ool7000000<0oooo100000001@3oool00000000000000000oooo0080000000<0oooo000000000000
0`000000103oool0000000000000000C0?ooo`8000002P3oool8000000040?ooo`00000000000?oo
o`<0000000<0oooo0000000000000P0000020?ooo`T0000000<0oooo0000000000001@0000030?oo
o`H0000000<0oooo0000000000005P00000Q0?oooa<0000000<0oooo0000003oool0100000020?oo
o`060000003oool0oooo0000003oool000000P3oool4000001@0oooo00<000000?ooo`3oool07`3o
ool001H0oooo00<000000?ooo`3oool04@3oool200000080oooo0`000000103oool000000?ooo`3o
ool7000000@0oooo00<000000?ooo`000000100000040?ooo`<000000P3oool200000080oooo00<0
00000?ooo`3oool01`0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo00P0oooo0`00
00000`3oool0000000000005000000030?ooo`0000000000008000000P3oool00`000000oooo0000
00030?ooo`D0000000<0oooo0000003oool00`0000000`3oool0000000000004000000030?ooo`00
0000000000h0000000<0oooo0000000000003`00000O0?oooa<0000000@0oooo000000000000oooo
0`0000020?ooo`0:0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`<00000503o
ool00`000000oooo0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool5
000000<0oooo0P000000103oool000000000000000040?ooo`030000003oool0000000D000000`3o
ool300000080oooo0P0000020?ooo`80000000<0oooo0000000000000`000000103oool000000?oo
o`00000?0?ooo`8000002P3oool00`000000oooo0?ooo`07000000040?ooo`00000000000?ooo`<0
000000<0oooo0000000000000P0000030?ooo`H000000`3oool7000000030?ooo`000000000000D0
000000<0oooo0000000000006`00000N0?ooo`X0000000<0oooo0000000000002@0000000`3oool0
000000000002000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P3oool4000001@0
oooo00<000000?ooo`3oool07P3oool001H0oooo00<000000?ooo`3oool04@3oool200000080oooo
1P0000020?ooo`80000000@0oooo0000000000000000103oool00`000000oooo00000005000000<0
oooo00<000000?ooo`0000000P3oool3000000040?ooo`00000000000?ooo`P0000000<0oooo0000
003oool02`3oool2000000`0oooo00D000000?ooo`00000000000?ooo`02000000050?ooo`000000
00000?ooo`0000000P3oool200000080oooo00<000000?ooo`0000000`3oool7000000@0oooo3@00
00000`3oool000000?ooo`0N000001`0oooo2P0000000`3oool000000000000>00000080oooo00@0
00000?ooo`3oool0oooo0P0000020?ooo`040000003oool00000000001@0oooo00<000000?ooo`3o
ool07P3oool001H0oooo00<000000?ooo`3oool04@3oool200000080oooo1P0000020?ooo`800000
00@0oooo00000000000000001@3oool7000000<0oooo00T000000?ooo`00000000000?ooo`000000
oooo0000003oool00`0000000`3oool0000000000005000000030?ooo`000000oooo00T0oooo0P00
000=0?ooo`030000003oool0000000@0000000@0oooo000000000000oooo0P0000001@3oool00000
000000000000oooo00@000000`3oool6000000@0oooo200000000`3oool000000000000300000080
oooo1P0000000`3oool000000000000H000001T0oooo4P0000000`3oool000000000000300000003
0?ooo`00000000000080000000<0oooo0000003oool00P3oool01P000000oooo0000003oool00000
0?ooo`<000004`3oool00`000000oooo0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`0A0?oo
o`<000000P3oool500000080oooo0P0000000`3oool0000000000002000000@0oooo1`0000030?oo
o`@0000000<0oooo0000000000000P000000103oool000000000003oool3000000030?ooo`000000
00000080000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
000000@0000000@0oooo000000000000oooo0P000000103oool000000000000000020?ooo`030000
003oool0000000<0oooo1`0000040?ooo`X0000000<0oooo0000000000000P0000001@3oool00000
000000000000oooo00@0000000<0oooo0000000000006000000F0?ooo`050000003oool000000000
003oool00`0000000`3oool0000000000008000000030?ooo`000000000000<0000000<0oooo0000
000000000P0000000`3oool000000?ooo`020?ooo`030000003oool000000080oooo00@000000?oo
o`00000000004`3oool00`000000oooo0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`0A0?oo
o`<000000P3oool500000080oooo1`0000040?ooo`030000003oool0000000@00000103oool30000
0080oooo0`0000000`3oool0000000000006000000060?ooo`000000oooo0000003oool000001@3o
ool2000000h0oooo1@0000001@3oool00000000000000000oooo00@0000000<0oooo000000000000
0P3oool4000000<0oooo1P0000050?oooa80000000<0oooo000000000000100000000`3oool00000
0000000I000001@0oooo6@0000000`3oool0000000000002000000030?ooo`000000oooo00<0oooo
0P0000020?ooo`050000003oool000000?ooo`0000004P3oool00`000000oooo0?ooo`0N0?ooo`00
5@3oool00`000000oooo0?ooo`0C0?ooo`8000000P3oool500000080oooo00<000000?ooo`000000
100000040?ooo`030000003oool0000000D000000`3oool00`000000oooo000000020?ooo`030000
003oool000000080000000<0oooo0000003oool00P0000000`3oool0000000000002000000040?oo
o`000000oooo00000080oooo0P00000>0?ooo`<0000000@0oooo000000000000oooo0P0000000`3o
ool0000000000003000000040?ooo`000000000000000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo00000004000000@0oooo1P0000000`3oool000000000000500000080oooo0`000003
0?ooo`030000003oool0000000<0000000<0oooo0000000000002`0000000`3oool000000000000<
00000100oooo100000001@3oool00000000000000000oooo0180000000@0oooo0000000000000000
0P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`0000000P00000B0?ooo`03
0000003oool0oooo01h0oooo000E0?ooo`030000003oool0oooo01<0oooo0P0000020?ooo`D00000
0P3oool00`000000oooo00000004000000D0oooo1`0000030?ooo`050000003oool000000000003o
ool010000000103oool000000000003oool3000000030?ooo`000000oooo0080000000<0oooo0000
003oool00P00000>0?ooo`8000000P3oool3000000040?ooo`00000000000?ooo`80000000@0oooo
000000000000oooo0`0000020?ooo`80000000<0oooo0000003oool00P3oool7000000@0oooo1P00
00020?ooo`H000000P3oool400000080oooo:@0000080?ooo`l0000000<0oooo0000000000002`00
00000`3oool0000000000002000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P3o
ool01@000000oooo0000003oool000000180oooo00<000000?ooo`3oool07@3oool001D0oooo00<0
00000?ooo`3oool04`3oool200000080oooo0`0000000`3oool00000000000020?ooo`80000000@0
oooo00000000000000001@3oool7000000<0oooo0P0000001P3oool000000?ooo`3oool000000?oo
o`<0000000<0oooo0000003oool01@0000000`3oool000000000000200000080oooo0P0000080?oo
o`@000000P3oool4000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000P3oool3
00000080oooo00<000000?ooo`0000000`3oool7000000@0oooo1`0000020?ooo`X0000000<0oooo
0000000000000P0000020?ooo`030000003oool0000000<0000000<0oooo000000000000;P000000
0`3oool0000000000003000000030?ooo`000000oooo00P0000000@0oooo000000000000oooo1000
00000`3oool000000?ooo`020?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo
0000000B0?ooo`030000003oool0oooo01d0oooo000E0?ooo`030000003oool0oooo01<0oooo0P00
00020?ooo`H000000P3oool2000000040?ooo`0000000000000000D0oooo00<000000?ooo`000000
1@0000030?ooo`050000003oool000000000003oool0100000000`3oool00000000000020?ooo`80
000000@0oooo000000000000oooo1@0000020?ooo`P00000103oool5000000040?ooo`0000000000
0?ooo`80000000P0oooo00000000000000000?ooo`000000oooo00000080oooo0P0000000`3oool0
00000?ooo`020?ooo`L00000103oool600000080oooo2P0000030?ooo`<000000`3oool200000004
0?ooo`000000000000000080oooo<`0000020?ooo`030000003oool0000000L0000000<0oooo0000
000000000P3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000`3oool20000
0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`005@3oool00`000000
oooo0?ooo`0C0?ooo`<000000P3oool500000080oooo1`0000050?ooo`L000000`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000000@000000P3oool2000000040?ooo`0000000000
0?ooo`<0000000@0oooo00000000000000001P3oool8000000030?ooo`000000000000@0000000L0
oooo00000000000000000?ooo`000000oooo0080000000D0oooo000000000000oooo000000030?oo
o`L00000103oool700000080oooo1@0000000`3oool0000000000003000000<0oooo100000030?oo
o`030000003oool0000000<000000P3ooolX000000040?ooo`00000000000?ooo`D0000000@0oooo
000000000000oooo200000000`3oool00000000000020?ooo`<000000P3oool010000000oooo0?oo
o`3oool2000000<0oooo0`0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo01d0oooo
000E0?ooo`030000003oool0oooo01<0oooo0`0000020?ooo`D000000`3oool6000000D0oooo2000
00030?ooo`050000003oool000000000003oool00P0000000`3oool000000?ooo`0300000080oooo
0P0000000`3oool0000000000006000000030?ooo`000000000000@000000P3oool300000080oooo
0`0000002@3oool00000000000000000oooo0000003oool000000?ooo`0400000080oooo00<00000
0?ooo`0000000`3oool8000000@0oooo1P0000020?ooo`D000000`3oool2000000030?ooo`000000
000000<0oooo0P0000000`3oool00000000000020?ooo`80000000<0oooo0000000000000P000000
0`3oool000000000000W000000030?ooo`000000000000<000000P3oool00`000000oooo00000008
000000030?ooo`00000000000080oooo0`0000020?ooo`040000003oool0oooo0?ooo`8000000`3o
ool01@000000oooo0000003oool000000140oooo00<000000?ooo`3oool07@3oool001@0oooo00<0
00000?ooo`3oool05@3oool200000080oooo1P0000020?ooo`L000001@3oool5000000030?ooo`00
0000oooo0080oooo00@000000?ooo`3oool000000P3oool4000000030?ooo`000000000000<00000
00<0oooo0000003oool0100000000`3oool000000000000:000000030?ooo`000000000000<00000
00D0oooo00000000000000000?ooo`03000000040?ooo`0000000000000000<0oooo00@000000?oo
o`00000000000`3oool7000000@0oooo1`0000020?ooo`D000000P3oool4000000090?ooo`000000
00000000003oool000000?ooo`000000oooo00<000000P3oool00`000000oooo0000000b00000004
0?ooo`00000000000?ooo`D0000000D0oooo00000000000000000?ooo`0200000080oooo0`000002
0?ooo`040000003oool0oooo0?ooo`800000103oool2000000030?ooo`000000oooo0100oooo00<0
00000?ooo`3oool07@3oool001@0oooo00<000000?ooo`3oool05@3oool200000080oooo1P000002
0?ooo`L000001@3oool8000000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo0000
00020?ooo`<0000000<0oooo0000000000000P0000000`3oool000000000000400000080oooo1@00
0000103oool000000000003oool2000000030?ooo`00000000000080000000@0oooo000000000000
00000P3oool2000000<0oooo00@000000?ooo`00000000000`3oool6000000030?ooo`000000oooo
0080oooo1`0000020?ooo`D000000`3oool200000080oooo00<000000?ooo`3oool00`0000020?oo
o`80000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000002h0000000@0oooo
000000000000oooo1P0000000`3oool0000000000004000000030?ooo`0000000000008000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool200000080oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0M0?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`800000
0P3oool600000080oooo00<000000?ooo`000000100000050?ooo`030000003oool0000000<00000
00<0oooo0000003oool00`3oool00`000000oooo000000030?ooo`050000003oool000000000003o
ool0200000020?ooo`l0000000<0oooo0000000000000P0000000`3oool000000000000200000080
oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`P00000103oool60000
00<0oooo1@0000020?ooo`<000000`3oool200000080oooo0P0000030?ooo`040000003oool00000
0?ooo`80000000<0oooo0000003oool0:P0000001@3oool00000000000000000oooo0080000000@0
oooo000000000000oooo0`0000000`3oool0000000000005000000030?ooo`000000000000800000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool3000000030?ooo`000000oooo
0100oooo00<000000?ooo`3oool0703oool001@0oooo00<000000?ooo`3oool05@3oool300000080
oooo1@0000030?ooo`L000001@3oool8000000<0oooo00@000000?ooo`3oool000000P3oool20000
00040?ooo`000000oooo0?ooo`@0000000<0oooo0000000000000`0000030?ooo`H000000`3oool5
00000080oooo100000001@3oool000000000003oool000000080oooo0P0000000`3oool000000?oo
o`030?ooo`L00000103oool4000000030?ooo`00000000000080oooo1@0000030?ooo`8000001P3o
ool00`000000oooo0?ooo`0300000080oooo100000000`3oool0000000000002000000030?ooo`00
0000000002L000000P3oool300000080oooo00<000000?ooo`0000000P0000020?ooo`<0000000D0
oooo00000000000000000?ooo`0400000080oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00D000000?ooo`000000oooo0000000A0?ooo`030000003oool0oooo01`0oooo000D0?oo
o`030000003oool0oooo01D0oooo0`0000020?ooo`H000000P3oool00`000000oooo000000040000
00D0oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo
008000000P3oool00`000000oooo000000020?ooo`D0000000<0oooo000000000000400000020?oo
o`80000000@0oooo0000003oool0oooo100000020?ooo`80000000<0oooo0000003oool00`3oool7
000000@0oooo00<000000?ooo`000000100000030?ooo`030000003oool00000008000000P3oool3
000000L0oooo0`0000000`3oool00000000000030?ooo`<000000P3oool00`000000oooo00000006
000000030?ooo`000000000001d000000`3oool4000000040?ooo`00000000000?ooo`@0000000<0
oooo0000000000000P0000000`3oool00000000000020?ooo`@000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool01@000000oooo0000003oool000000140oooo00<000000?oo
o`3oool0703oool001@0oooo00<000000?ooo`3oool05P3oool2000000<0oooo1@0000020?ooo`03
0000003oool0000000D000001@3oool8000000<0oooo1@0000020?ooo`040000003oool0oooo0000
00<0oooo1@0000020?ooo``000000P3oool3000000040?ooo`00000000000?ooo`@000000`3oool2
000000030?ooo`000000oooo00<0oooo1`0000050?ooo`@0000000<0oooo0000000000000P3oool5
000000<0oooo0P00000:0?ooo`80000000@0oooo00000000000000000`3oool3000000040?ooo`00
000000000?ooo`L0000000<0oooo0000000000008`0000000`3oool0000000000003000000030?oo
o`000000000000H000000P3oool400000080oooo00<000000?ooo`3oool00P3oool2000000<0oooo
00D000000?ooo`000000oooo0000000A0?ooo`030000003oool0oooo01`0oooo000D0?ooo`030000
003oool0oooo01H0oooo0`0000020?ooo`D000000`3oool7000000D0oooo00<000000?ooo`000000
0`0000000`3oool000000?ooo`020?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo
0?ooo`0200000080oooo1`00000:0?ooo`@0000000<0oooo0000000000000P3oool4000000<0oooo
0P0000000`3oool000000?ooo`030?ooo`L000001@3oool4000000030?ooo`00000000000080oooo
0P0000000`3oool00000000000030?ooo`<000002P3oool01@000000oooo000000000000oooo0080
00000`3oool4000000040?ooo`00000000000?ooo`L000000P3ooolW000000030?ooo`0000000000
00<0000000D0oooo00000000000000000?ooo`0500000080oooo00<000000?ooo`3oool00P3oool2
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01`0oooo000C0?ooo`030000003oool0oooo01P0oooo0P0000020?ooo`D000000`3oool00`00
0000oooo00000005000000D0oooo2P0000020?ooo`80000000<0oooo0000003oool00P3oool20000
00030?ooo`000000000000<0oooo0`0000000`3oool000000000000>00000080oooo100000040?oo
o`80000000<0oooo0000003oool00`3oool6000000030?ooo`000000oooo00@0oooo1`0000020?oo
o`@000000`3oool3000000/0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`030000003oool0
00000080oooo0P0000000`3oool000000000000500000080oooo8`0000020?ooo`D000000P3oool2
00000080oooo100000030?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0L0?ooo`004`3oool00`00
0000oooo0?ooo`0H0?ooo`8000000`3oool5000000<0oooo0P0000000`3oool00000000000020000
00H0oooo1`0000050?ooo`80000000<0oooo0000000000000`3oool5000000@0oooo3P0000020?oo
o`H000000`3oool5000000@0oooo1P0000000`3oool000000?ooo`040?ooo`@0000000<0oooo0000
000000000P3oool500000080oooo0`00000<0?ooo`030000003oool0oooo00<0oooo1@0000020?oo
o`@000000P3oool2000000030?ooo`000000000000D000000P3ooolP000000030?ooo`0000000000
00@000000P3oool00`000000oooo000000020?ooo`@000000`3oool00`000000oooo0?ooo`020?oo
o`8000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0703oool001<0oooo00<000000?ooo`3oool0603oool2000000<0oooo1@0000030?ooo`03
0000003oool0000000D000001@3oool6000000030?ooo`000000oooo00<0oooo0`0000000`3oool0
0000000000040?ooo`D000003`3oool4000000030?ooo`000000000000<0oooo0`0000000`3oool0
0000000000040?ooo`P000001@3oool6000000040?ooo`000000oooo0?ooo`@000000`3oool30000
00`0oooo00<000000?ooo`3oool0103oool600000080oooo100000020?ooo`80000000<0oooo0000
000000001P0000000`3oool000000000000R00000080oooo0`0000020?ooo`D000000P3oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool01P000000oooo000000000000oooo00000100oooo00<0
00000?ooo`3oool0703oool001<0oooo00<000000?ooo`3oool06@3oool2000000<0oooo1@000002
0?ooo`040000003oool000000?ooo`@000001P3oool8000000@0oooo0`0000000`3oool000000000
00050?ooo`L000001`3oool6000000030?ooo`000000000000@0oooo0`0000000`3oool000000000
00040?ooo`P000001P3oool5000000040?ooo`000000oooo0?ooo`D000000P3oool3000000d0oooo
00<000000?ooo`3oool01P3oool600000080oooo100000020?ooo`80000000<0oooo000000000000
6@0000030?ooo``000000P3oool2000000030?ooo`000000oooo00D000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00H000000?ooo`00000000000?ooo`00000A0?oo
o`030000003oool0oooo01/0oooo000C0?ooo`030000003oool0oooo01T0oooo0P0000030?ooo`80
000000<0oooo0000000000000`3oool00`000000oooo00000005000000@0oooo2P0000040?ooo`<0
000000@0oooo00000000000000001@3ooolC000000@0oooo0`000000103oool00000000000000004
0?ooo`L0000000<0oooo0000003oool0103oool3000000040?ooo`000000000000000080oooo1@00
00030?ooo`<000003@3oool00`000000oooo0?ooo`080?ooo`H000000P3oool400000080oooo0P00
0000103oool000000000003ooolO000000040?ooo`000000000000000080oooo0`000000103oool0
00000?ooo`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`060000003oool000000000003oool000004@3oool00`000000oooo0?ooo`0K0?ooo`004`3oool0
0`000000oooo0?ooo`0I0?ooo`800000103oool500000080oooo00@000000?ooo`000000oooo1000
00020?ooo`8000000P3oool9000000D0oooo0P0000020?ooo`<000001@3oool?000000@0oooo0`00
00020?ooo`<00000103oool3000000060?ooo`00000000000000003oool000001@3oool700000080
oooo1P0000020?ooo`<000003P3oool00`000000oooo0?ooo`090?ooo`L000000P3oool400000080
oooo0P000000103oool000000000003ooolT000000030?ooo`00000000000080oooo1@0000030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020000
0180oooo00<000000?ooo`3oool06`3oool001<0oooo00<000000?ooo`3oool06P3oool2000000<0
oooo0P0000000`3oool00000000000030?ooo`030000003oool0000000H000001@3oool9000000H0
oooo00@000000?ooo`3oool0oooo0`00000D0?ooo`<000000P3oool3000000D0oooo0`0000000`3o
ool0000000000003000000D0oooo00<000000?ooo`000000100000030?ooo`D000000P3oool30000
00l0oooo00<000000?ooo`3oool02`3oool700000080oooo100000020?ooo`80000000<0oooo0000
000000000P3oool7000000030?ooo`000000000000L000001P3oool;000000<0oooo1@0000040?oo
o`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool00000008000004P3oool00`00
0000oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`0K0?ooo`800000103oool500000080
oooo00@000000?ooo`000000oooo100000070?ooo`T000001P3oool2000000<0oooo1@00000<0?oo
o`D000000P3oool3000000H0oooo2@0000050?ooo`030000003oool0000000D000000P3oool50000
00<0oooo0P00000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000100000020?oo
o`@000000P3oool00`000000oooo0?ooo`0200000080oooo1`0000040?oooa8000001@3oool50000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0oooo
00<000004P3oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`0L0?ooo`80
00000`3oool2000000030?ooo`000000000000<0oooo00<000000?ooo`0000001@0000060?ooo`03
0000003oool0000000D0000000<0oooo0000000000001P3oool3000000<0oooo4@0000020?ooo`<0
00001P3oool3000000030?ooo`000000000000@000001@3oool00`000000oooo0000000500000080
oooo0P000000103oool000000000000000020?ooo`<00000403oool00`000000oooo0?ooo`0>0?oo
o`80000000@0oooo000000000000oooo0P0000020?ooo`@0000000<0oooo0000000000000P3oool2
000000<0oooo2@0000060?ooo`H000001`3oool7000000@0oooo00<000000?ooo`3oool0103oool2
000000@0oooo00H000000?ooo`3oool000000?ooo`00000B0?ooo`030000003oool0oooo01/0oooo
000B0?ooo`030000003oool0oooo01`0oooo0P0000040?ooo`D000000`3oool8000000H0oooo00<0
00000?ooo`0000001@000000103oool000000000000000070?ooo`D000000`3oool4000000H0oooo
1@0000060?ooo`@0000000<0oooo000000000000100000050?ooo`030000003oool0000000800000
00<0oooo0000000000000P3oool4000000030?ooo`000000oooo0080oooo0P00000A0?ooo`030000
003oool0oooo0100oooo1@0000000`3oool00000000000020?ooo`@0000000<0oooo000000000000
0P3oool2000000@0oooo3@0000060?ooo`/000001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000@0oooo00H000000?ooo`3oool000000?ooo`00000B0?ooo`030000003oool0oooo
01/0oooo000B0?ooo`030000003oool0oooo01d0oooo0P0000030?ooo`80000000@0oooo00000000
0000oooo0`0000000`3oool000000?ooo`05000000H0oooo00<000000?ooo`0000000`0000000`3o
ool000000?ooo`03000000P0oooo4P0000070?ooo`X0000000<0oooo0000003oool0103oool00`00
0000oooo00000002000000030?ooo`00000000000080oooo1P0000030?ooo`8000004P3oool00`00
0000oooo0?ooo`0B0?ooo`D0000000<0oooo0000000000000`3oool3000000030?ooo`0000000000
0080oooo0P0000070?oooaL000001P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool01P00
0000oooo000000000000oooo000001<0oooo00<000000?ooo`3oool06P3oool00180oooo00<00000
0?ooo`3oool07@3oool2000000@0oooo0`0000000`3oool000000?ooo`020?ooo`050000003oool0
00000000003oool00`0000070?ooo`030000003oool0000000H0000000@0oooo0000000000000000
2P3oool9000000X0oooo1@0000000`3oool0000000000005000000D0oooo00<000000?ooo`000000
1@0000030?ooo`80000000@0oooo00000000000000000P3oool2000001<0oooo00<000000?ooo`3o
ool0503oool5000000030?ooo`000000000000<0oooo0`0000000`3oool00000000000020?ooo`@0
00001`3oool@000000L0oooo0P0000070?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00`00000D0?ooo`030000003oool0oooo01X0oooo000B0?ooo`030000003oool0oooo01h0oooo
0P0000030?ooo`H000000`3oool01@000000oooo000000000000oooo00<000001`3oool:00000004
0?ooo`0000000000000001T0oooo0P0000000`3oool0000000000008000000H0oooo00@000000?oo
o`000000oooo100000030?ooo`80000000@0oooo00000000000000000P3oool3000001<0oooo00<0
00000?ooo`3oool05P3oool5000000030?ooo`000000000000<0oooo1P0000040?ooo`@00000203o
ool7000000T0oooo0P0000090?ooo`8000001@3oool01P000000oooo0?ooo`000000oooo000001@0
oooo00<000000?ooo`3oool06P3oool00180oooo00<000000?ooo`3oool07P3oool2000000<0oooo
100000000`3oool000000?ooo`030?ooo`@0000000<0oooo0000000000000P0000070?ooo`030000
003oool0000000<0000000<0oooo0000000000001P00000D0?ooo``0000000<0oooo0000003oool0
1@3oool010000000oooo0000003oool4000000<0oooo0P000000103oool000000000000000030?oo
o`800000503oool00`000000oooo0?ooo`0H0?ooo`D0000000<0oooo0000000000000`3oool20000
00040?ooo`0000000000000000H0oooo1`00000>0?ooo`<000002P3oool2000000D0oooo00L00000
0?ooo`3oool0oooo0000003oool0000001@0oooo00<000000?ooo`3oool06P3oool00140oooo00<0
00000?ooo`3oool0803oool4000000030?ooo`00000000000080000000<0oooo0000003oool00P3o
ool020000000oooo0000003oool000000?ooo`000000oooo0P0000070?ooo`030000003oool00000
00@0000000<0oooo0000000000002@00000:0?ooo`l0000000<0oooo0000000000001P3oool00`00
0000oooo00000005000000<0oooo100000000`3oool000000?ooo`020?ooo`8000005@3oool00`00
0000oooo0?ooo`0J0?ooo`D0000000<0oooo0000000000000`3oool200000080oooo0`00000:0?oo
o`h000002`3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P0000000`3o
ool000000?ooo`0C0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo0200
oooo0P0000040?ooo`80000000@0oooo00000000000000000`3oool020000000oooo0000003oool0
00000?ooo`000000oooo0P0000070?ooob`000001P3oool5000000040?ooo`0000000000000000<0
oooo100000000`3oool000000?ooo`020?ooo`<000005@3oool00`000000oooo0?ooo`0L0?ooo`D0
000000<0oooo0000000000000`3oool8000001h0oooo0P0000020?ooo`030000003oool0oooo00<0
oooo00L000000?ooo`3oool0oooo0000003oool0000001D0oooo00<000000?ooo`3oool06P3oool0
0140oooo00<000000?ooo`3oool07`3oool4000000<0oooo100000000`3oool00000000000030?oo
o`040000003oool000000?ooo`L000001`3ooolX000000L0oooo00<000000?ooo`0000000P000000
1@3oool000000000003oool0000000<0oooo1@0000030?ooo`<000005P3oool00`000000oooo0?oo
o`0N0?ooo`D0000000<0oooo0000000000001@3oool7000001P0oooo0`0000030?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo01d0oooo0P0000020?ooo`<000000`3o
ool4000000030?ooo`000000oooo00<0oooo00@000000?ooo`000000oooo1@0000000`3oool00000
0?ooo`070?ooob@00000203oool00`000000oooo00000002000000050?ooo`00000000000?ooo`00
00000`3oool600000080oooo0`00000G0?ooo`030000003oool0oooo0200oooo0P000000103oool0
00000000003oool2000000H0oooo2P00000?0?ooo`<00000103oool2000000D0oooo0P0000020?oo
o`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`0I0?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`8000001@3oool2000000@0oooo0`0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000200000090?ooo`80000000<0oooo0000000000006`0000080?oo
o`80000000<0oooo000000000000100000000`3oool000000?ooo`020?ooo`H000000`3oool20000
01P0oooo00<000000?ooo`3oool08P3oool2000000040?ooo`00000000000?ooo`8000001P3oool7
000000030?ooo`000000000000d000001@3oool2000000H0oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool00140oooo00<00000
0?ooo`3oool06@3oool2000000L0oooo00<000000?ooo`000000103oool300000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo00000003000000030?ooo`0000000000008000002P3oool2
00000080oooo5`00000:0?ooo`030000003oool000000080000000@0oooo000000000000oooo0P00
00020?ooo`<0000000@0oooo00000000000000000`3oool3000001P0oooo00<000000?ooo`3oool0
903oool2000000030?ooo`000000000000@000001@3oool2000000<0oooo1`0000090?ooo`D00000
1P3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
6@3oool00140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`<00000103o
ool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09000000X0oooo1@00
00020?ooo`l000002`3oool9000000030?ooo`000000oooo0080oooo0`000000103oool000000000
000000030?ooo`<000006@3oool00`000000oooo0?ooo`0V0?ooo`<0000000<0oooo000000000000
1@0000030?ooo`800000203oool9000000T0oooo0P0000030?ooo`<000000P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01T0oooo000@0?ooo`030000003oool0oooo01L0oooo0P00
000<0?ooo`<000000`3oool4000000030?ooo`000000000000@0oooo00D000000?ooo`3oool00000
0?ooo`07000000h0oooo3000000>0?ooo``000000P3oool4000000040?ooo`0000000000000000<0
oooo0`00000J0?ooo`030000003oool0oooo02T0oooo0`0000001@3oool00000000000000000oooo
00@0000000<0oooo0000000000005P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool06@3oool00100oooo00<000000?ooo`3oool05@3oool2000000l0
oooo0`0000030?ooo`@0000000<0oooo000000000000103oool00`000000oooo0?ooo`0:000002@0
oooo2P0000000`3oool000000?ooo`020?ooo`L00000103oool3000001/0oooo00<000000?ooo`3o
ool0;03oool700000080oooo1`00000@0?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0I0?ooo`00403oool00`000000oooo0?ooo`0C0?ooo`800000
4P3oool2000000@0oooo200000030?ooo`80000000<0oooo0000000000002@00000O0?ooo`T00000
00D0oooo000000000000oooo000000030?ooo`<0000000@0oooo0000000000000000103oool30000
01`0oooo00<000000?ooo`3oool0;`3oool8000000<0oooo4P0000030?ooo`<00000103oool20000
01`0oooo00<000000?ooo`3oool06@3oool00100oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0C0?ooo`800000103oool8000000@0oooo00D000000?ooo`3oool000000?ooo`0:0000
01P0oooo100000000`3oool0000000000004000000040?ooo`00000000000?ooo`8000000`3oool7
000000@0oooo0P00000N0?ooo`030000003oool0oooo03<0oooo2`00000=0?ooo`D00000103oool2
000001l0oooo00<000000?ooo`3oool0603oool00100oooo00<000000?ooo`3oool0403oool20000
01L0oooo0P0000040?ooo`P00000103oool2000000030?ooo`000000000000h000003P3oool50000
00<0oooo1P0000000`3oool00000000000020?ooo`030000003oool0oooo0080oooo0P0000000`3o
ool0000000000002000000@0oooo0P00000O0?ooo`030000003oool0oooo03L0oooo100000000`3o
ool000000000000>000000H0oooo0P00000Q0?ooo`030000003oool0oooo01P0oooo000@0?ooo`03
0000003oool0oooo00h0oooo0P00000J0?ooo`800000103oool5000000030?ooo`000000000000D0
oooo0P0000000`3oool000000000000J000000<0oooo2@0000001@3oool00000000000000000oooo
008000000`3oool3000000030?ooo`000000000000800000103oool200000200oooo00<000000?oo
o`3oool0>`3oool7000000/0oooo1@00000S0?ooo`030000003oool0oooo01P0oooo000?0?ooo`03
0000003oool0oooo00d0oooo0P00000M0?ooo`8000001@3oool8000000D0oooo0P0000000`3oool0
000000000002000000030?ooo`00000000000240000000<0oooo000000000000103oool200000003
0?ooo`000000000000800000103oool300000240oooo00<000000?ooo`3oool0@P3oool;000002P0
oooo00<000000?ooo`3oool0603oool000l0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0N0?ooo`8000001@3oool5000000030?ooo`000000000000H0oooo0P0000000`3oool00000
0000000R000000030?ooo`000000000000@0oooo0`0000000`3oool0000000000002000000@0oooo
0`00000R0?ooo`030000003oool0oooo04<0oooo0P00000`0?ooo`030000003oool0oooo01P0oooo
000?0?ooo`030000003oool0oooo00X0oooo0P00000R0?ooo`<00000103oool9000000H0oooo8@00
00020?ooo`<00000103oool3000000030?ooo`000000000000<00000103oool3000002<0oooo00<0
00000?ooo`3oool0A@3oool2000002h0oooo00<000000?ooo`3oool0603oool000l0oooo00<00000
0?ooo`3oool0203oool2000002D0oooo0`0000040?ooo`@0000000<0oooo0000003oool00`000007
0?ooo`T00000103oool700000080oooo2P0000040?ooo`/000000`3oool4000002@0oooo00<00000
0?ooo`3oool0A`3oool2000002`0oooo00<000000?ooo`3oool0603oool000l0oooo00<000000?oo
o`3oool01P3oool2000002P0oooo0`0000050?ooo`H0000000@0oooo0000000000000000203oool4
000000030?ooo`0000000000018000001@3oool<000000@0oooo0P0000000`3oool000000?ooo`0T
0?ooo`030000003oool0oooo04T0oooo0P00000[0?ooo`030000003oool0oooo01L0oooo000?0?oo
o`030000003oool0oooo00@0oooo0P00000[0?ooo`<000001P3oool6000000030?ooo`0000000000
008000002@3oool?000000T0oooo300000040?ooo`<0000000<0oooo0000003oool09@3oool00`00
0000oooo0?ooo`1;0?ooo`800000:@3oool00`000000oooo0?ooo`0G0?ooo`003`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo100000060?ooo`H0000000<0oooo00000000
00000`00000J0?ooo`h000001@3oool5000002L0oooo00<000000?ooo`3oool0C@3oool2000002L0
oooo00<000000?ooo`3oool05`3oool000h0oooo00<000000?ooo`3oool00P3oool200000340oooo
0`0000070?ooo`H0000000<0oooo0000000000001@00000B0?oooa0000001P3oool4000002T0oooo
00<000000?ooo`3oool0C`3oool2000002D0oooo00<000000?ooo`3oool05`3oool000h0oooo00<0
00000?ooo`3oool00P00000d0?ooo`<00000203oool6000000<0oooo1`0000080?ooo`/0000000<0
oooo0000000000001P0000060?ooo`@00000:`3oool00`000000oooo0?ooo`1A0?ooo`8000008`3o
ool00`000000oooo0?ooo`0G0?ooo`003P3oool3000003L0oooo100000080?ooo`<0000000<0oooo
0000000000000P0000030?oooa80000000<0oooo000000000000200000060?ooo`@00000;@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05`3oool0
00h0oooo0P00000i0?ooo`D00000203oool:000000H0oooo4`0000060?ooo`D00000;`3oool00`00
0000oooo0?ooo`1D0?ooo`800000803oool00`000000oooo0?ooo`0G0?ooo`00403oool3000003P0
oooo1@0000090?oooaD000000P3oool6000000L0oooo1@00000a0?ooo`030000003oool0oooo05H0
oooo0P00000N0?ooo`030000003oool0oooo01L0oooo000C0?ooo`800000>03oool5000000/0oooo
5P0000070?ooo`H00000<`3oool00`000000oooo0?ooo`1H0?ooo`8000007@3oool00`000000oooo
0?ooo`0F0?ooo`005@3oool3000003L0oooo1P00000>0?ooo`X000002P3oool7000003D0oooo00<0
00000?ooo`3oool0FP3oool2000001/0oooo00<000000?ooo`3oool05P3oool001P0oooo0`00000f
0?ooo`P000006`3oool7000003P0oooo00<000000?ooo`3oool0G03oool2000001T0oooo00<00000
0?ooo`3oool05P3oool001/0oooo0P00000f0?ooo`X00000403oool;000003/0oooo00<000000?oo
o`3oool0GP3oool2000001L0oooo00<000000?ooo`3oool05P3oool001d0oooo0`00000g0?oooah0
0000?P3oool00`000000oooo0?ooo`1P0?ooo`8000005@3oool00`000000oooo0?ooo`0F0?ooo`00
803oool3000003X0oooo500000120?ooo`030000003oool0oooo0680oooo0P00000C0?ooo`030000
003oool0oooo01H0oooo000S0?ooo`800000?`3oool8000004L0oooo00<000000?ooo`3oool0I03o
ool200000140oooo00<000000?ooo`3oool05P3oool002D0oooo0`00002;0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool30000
08P0oooo00<000000?ooo`3oool0I`3oool2000000l0oooo00<000000?ooo`3oool05@3oool002/0
oooo0P0000260?ooo`030000003oool0oooo06T0oooo0P00000=0?ooo`030000003oool0oooo01D0
oooo000]0?ooo`<00000P`3oool00`000000oooo0?ooo`1[0?ooo`8000002`3oool00`000000oooo
0?ooo`0E0?ooo`00<03oool300000800oooo00<000000?ooo`3oool0K@3oool2000000T0oooo00<0
00000?ooo`3oool05@3oool003<0oooo0P00001n0?ooo`030000003oool0oooo06l0oooo0P000007
0?ooo`030000003oool0oooo01D0oooo000e0?ooo`<00000N`3oool00`000000oooo0?ooo`1a0?oo
o`8000001@3oool00`000000oooo0?ooo`0E0?ooo`00>03oool3000007P0oooo00<000000?ooo`3o
ool0L`3oool2000000@0oooo00<000000?ooo`3oool0503oool003/0oooo0P00001f0?ooo`030000
003oool0oooo07D0oooo0P0000020?ooo`030000003oool0oooo01@0oooo000m0?ooo`<00000L`3o
ool00`000000oooo0?ooo`1g0?ooo`<000005P3oool00400oooo0`00001`0?ooo`030000003oool0
oooo07P0oooo0P00000F0?ooo`00@`3oool2000006h0oooo00<000000?ooo`3oool0M@3oool30000
01P0oooo00150?ooo`<00000J`3oool00`000000oooo0?ooo`1b0?ooo`<000006`3oool004P0oooo
0`00001X0?ooo`030000003oool0oooo06l0oooo0`00000N0?ooo`00B`3oool2000006H0oooo00<0
00000?ooo`3oool0K@3oool200000240oooo001=0?ooo`<00000H`3oool00`000000oooo0?ooo`1Z
0?ooo`<000008`3oool00500oooo0`00001P0?ooo`030000003oool0oooo06L0oooo0`00000V0?oo
o`00D`3oool2000005h0oooo00<000000?ooo`3oool0I03oool3000002T0oooo001E0?ooo`<00000
F`3oool00`000000oooo0?ooo`1Q0?ooo`<00000;03oool005P0oooo0`00001I0?ooo`030000003o
ool0oooo05d0oooo0`00000_0?ooo`00F`3oool2000005L0oooo00<000000?ooo`3oool0FP3oool3
00000380oooo001M0?ooo`<00000E03oool00`000000oooo0?ooo`1H0?ooo`800000=@3oool00600
oooo0`00001A0?ooo`030000003oool0oooo05D0oooo0`00000g0?ooo`00H`3oool3000004h0oooo
00<000000?ooo`3oool0DP3oool3000003X0oooo001V0?ooo`800000C03oool00`000000oooo0?oo
o`1?0?ooo`<00000?@3oool006P0oooo0`0000190?ooo`030000003oool0oooo04`0oooo0`000010
0?ooo`00J`3oool3000004H0oooo00<000000?ooo`3oool0B@3oool3000004<0oooo001^0?ooo`80
0000A03oool00`000000oooo0?ooo`160?ooo`<00000AP3oool00700oooo0`0000110?ooo`030000
003oool0oooo04@0oooo0P0000190?ooo`00L`3oool3000003h0oooo00<000000?ooo`3oool0@@3o
ool3000004/0oooo001f0?ooo`800000?03oool00`000000oooo0?ooo`0n0?ooo`<00000CP3oool0
07P0oooo0`00000i0?ooo`030000003oool0oooo03/0oooo0`00001A0?ooo`00N`3oool3000003H0
oooo00<000000?ooo`3oool0>03oool3000005@0oooo001n0?ooo`800000=03oool00`000000oooo
0?ooo`0e0?ooo`<00000E`3oool00800oooo0`00000a0?ooo`030000003oool0oooo0380oooo0`00
001J0?ooo`00P`3oool3000002h0oooo00<000000?ooo`3oool0<03oool2000005d0oooo00260?oo
o`800000;03oool00`000000oooo0?ooo`0]0?ooo`<00000G`3oool008P0oooo0`00000Y0?ooo`03
0000003oool0oooo02X0oooo0`00001R0?ooo`00R`3oool3000002H0oooo00<000000?ooo`3oool0
9`3oool3000006D0oooo002>0?ooo`800000903oool00`000000oooo0?ooo`0T0?ooo`<00000J03o
ool00900oooo0`00000Q0?ooo`030000003oool0oooo0240oooo0`00001[0?ooo`00T`3oool30000
01h0oooo00<000000?ooo`3oool07P3oool3000006h0oooo002F0?ooo`800000703oool00`000000
oooo0?ooo`0L0?ooo`800000L@3oool009P0oooo0`00000I0?ooo`030000003oool0oooo01T0oooo
0`00001c0?ooo`00V`3oool3000001H0oooo00<000000?ooo`3oool05P3oool3000007H0oooo002N
0?ooo`800000503oool00`000000oooo0?ooo`0C0?ooo`<00000N@3oool00:00oooo0`00000A0?oo
o`030000003oool0oooo0100oooo0`00001l0?ooo`00X`3oool3000000h0oooo00<000000?ooo`3o
ool03@3oool3000007l0oooo002V0?ooo`800000303oool00`000000oooo0?ooo`0:0?ooo`<00000
PP3oool00:P0oooo0`0000090?ooo`030000003oool0oooo00P0oooo0P0000250?ooo`00Z`3oool3
000000H0oooo00<000000?ooo`3oool01@3oool3000008L0oooo002^0?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`<00000RP3oool00;00oooo0`0000000`3oool000000?ooo`03000008d0
oooo002c0?ooo`<00000T03oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0
ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0
ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0
ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0
ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0
ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00?l0ooooA`3oool00001\
\>"]],

Cell["Fig. 1.13 Strange attractor for the Lorenz system.", "Caption",
  CellTags->{"Fig. 1.13", "i:129"}],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " Magnetic and electric field lines can also display chaotic behavior.  For \
example, consider the following simple field:"
}], "Text"],

Cell[TextData[{
  " \t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["B",
                  FontSlant->"Plain"], 
                StyleBox["o",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "(", 
            StyleBox[\(r, \[Theta], z\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{"2", " ", "r", 
              StyleBox[
                OverscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[\(Sin(2  \[Theta])\),
                FontWeight->"Plain"]}], 
            StyleBox["  ",
              FontWeight->"Plain"], 
            StyleBox["+",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["\[Theta]",
                    FontWeight->"Bold"], "^"],
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{"(", " ", 
                RowBox[{\(r\^3/4\), 
                  StyleBox["+",
                    FontWeight->"Plain"], 
                  StyleBox[\(2\ r\ \(Cos(2  \[Theta])\)\),
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["+",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  " [One can easily show that this field satisfies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              StyleBox["B",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". It consists of a uniform field superimposed on a quadrupole field \
created by external currents,  and the field from a current density ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["j",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "r", ")"}], "\[Proportional]", 
          RowBox[{\(r\^2\), " ", 
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"]}]}], TraditionalForm]]],
  ".]\nFor this field is it useful to consider field line ODEs of the form "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]r/\[DifferentialD]z = \(\(\
\[DifferentialD]r/\[DifferentialD]s\)\/\(\(\ \)\(\[DifferentialD]z/\
\[DifferentialD]s\)\) = \(\(B\_r\)(r, \[Theta], z)\)/\(\(B\_z\)(r, \[Theta], 
              z)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r \[DifferentialD]\[Theta]/\[DifferentialD]z = \(\(r \
\[DifferentialD]\[Theta]/\[DifferentialD]s\)\/\(\[DifferentialD]z/\
\[DifferentialD]s\) = \(\(B\_\[Theta]\)(r, \[Theta], z)\)/\(\(B\_z\)(
              r, \[Theta], z)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "[see Eqs. ",
  ButtonBox["(1.3.6)",
    ButtonData:>"(1.3.6)",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Solve these coupled ODEs for ",
  Cell[BoxData[
      \(TraditionalForm\`r(z)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](z)\)]],
  " using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and  plot the resulting field line in ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\)\)]],
  " via ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < z < 20\)]],
  " and for initial conditions  ",
  Cell[BoxData[
      FormBox[Cell[TextData[{
          Cell[BoxData[
              FormBox[
                RowBox[{\(\[Theta]\_o\), "=", Cell["\[Pi] / 2"]}], 
                TraditionalForm]]],
          ","
        }]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\_o = \ \(-5\)\  + \ 2\ n\)]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3, 4\)]],
  ". [Hint:  Along the field line ",
  Cell[BoxData[
      \(TraditionalForm\`x(z) = \(r(z)\)\ \(cos\[Theta](z)\), \ 
      y(z) = \(r(z)\)\ \(sin\[Theta](z)\)\)]],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Although the result from part (a) appears to be very complicated, these \
field lines are not chaotic. One way to see this is to project the field \
lines into the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane, since the field is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ". Do so, and show that the field lines created in part (a) fall on nested \
closed curves.   (The solution is shown in Fig. ",
  ButtonBox["1.14",
    ButtonData:>"Fig. 1.14",
    ButtonStyle->"Hyperlink"],
  ". Note the appearance of two ",
  StyleBox["magnetic islands, ",
    FontSlant->"Italic"],
  "around which the field lines spiral. )"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0961538 0.5 0.0961538 [
[.11538 .4875 -6 -9 ]
[.11538 .4875 6 0 ]
[.30769 .4875 -6 -9 ]
[.30769 .4875 6 0 ]
[.69231 .4875 -3 -9 ]
[.69231 .4875 3 0 ]
[.88462 .4875 -3 -9 ]
[.88462 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 .11538 -12 -4.5 ]
[.4875 .11538 0 4.5 ]
[.4875 .30769 -12 -4.5 ]
[.4875 .30769 0 4.5 ]
[.4875 .69231 -6 -4.5 ]
[.4875 .69231 0 4.5 ]
[.4875 .88462 -6 -4.5 ]
[.4875 .88462 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 .5 m
.11538 .50625 L
s
[(-4)] .11538 .4875 0 1 Mshowa
.30769 .5 m
.30769 .50625 L
s
[(-2)] .30769 .4875 0 1 Mshowa
.69231 .5 m
.69231 .50625 L
s
[(2)] .69231 .4875 0 1 Mshowa
.88462 .5 m
.88462 .50625 L
s
[(4)] .88462 .4875 0 1 Mshowa
.125 Mabswid
.16346 .5 m
.16346 .50375 L
s
.21154 .5 m
.21154 .50375 L
s
.25962 .5 m
.25962 .50375 L
s
.35577 .5 m
.35577 .50375 L
s
.40385 .5 m
.40385 .50375 L
s
.45192 .5 m
.45192 .50375 L
s
.54808 .5 m
.54808 .50375 L
s
.59615 .5 m
.59615 .50375 L
s
.64423 .5 m
.64423 .50375 L
s
.74038 .5 m
.74038 .50375 L
s
.78846 .5 m
.78846 .50375 L
s
.83654 .5 m
.83654 .50375 L
s
.06731 .5 m
.06731 .50375 L
s
.01923 .5 m
.01923 .50375 L
s
.93269 .5 m
.93269 .50375 L
s
.98077 .5 m
.98077 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .11538 m
.50625 .11538 L
s
[(-4)] .4875 .11538 1 0 Mshowa
.5 .30769 m
.50625 .30769 L
s
[(-2)] .4875 .30769 1 0 Mshowa
.5 .69231 m
.50625 .69231 L
s
[(2)] .4875 .69231 1 0 Mshowa
.5 .88462 m
.50625 .88462 L
s
[(4)] .4875 .88462 1 0 Mshowa
.125 Mabswid
.5 .16346 m
.50375 .16346 L
s
.5 .21154 m
.50375 .21154 L
s
.5 .25962 m
.50375 .25962 L
s
.5 .35577 m
.50375 .35577 L
s
.5 .40385 m
.50375 .40385 L
s
.5 .45192 m
.50375 .45192 L
s
.5 .54808 m
.50375 .54808 L
s
.5 .59615 m
.50375 .59615 L
s
.5 .64423 m
.50375 .64423 L
s
.5 .74038 m
.50375 .74038 L
s
.5 .78846 m
.50375 .78846 L
s
.5 .83654 m
.50375 .83654 L
s
.5 .06731 m
.50375 .06731 L
s
.5 .01923 m
.50375 .01923 L
s
.5 .93269 m
.50375 .93269 L
s
.5 .98077 m
.50375 .98077 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.5 .01923 m
.50243 .01924 L
.50463 .01927 L
.50718 .01934 L
.50959 .01942 L
.51387 .01962 L
.5185 .01992 L
.5236 .02036 L
.52899 .02093 L
.53862 .02226 L
.54847 .02402 L
.55762 .02602 L
.57805 .03181 L
.59818 .0394 L
.61583 .04774 L
.6524 .07073 L
.68019 .09458 L
.70602 .12354 L
.72626 .15283 L
.74357 .18503 L
.75721 .21815 L
.76689 .24903 L
.77401 .27914 L
.77878 .30613 L
.78226 .33287 L
.78374 .3477 L
.78485 .36134 L
.78579 .3754 L
.78648 .38854 L
.78698 .4001 L
.78741 .41272 L
.78774 .4251 L
.788 .43812 L
.78817 .45009 L
.78829 .46125 L
.78834 .46711 L
.78838 .4735 L
.78842 .48016 L
.78843 .48334 L
.78844 .48635 L
.78845 .48914 L
.78845 .4906 L
.78845 .49216 L
.78845 .49346 L
.78846 .4949 L
.78846 .49621 L
.78846 .49743 L
.78846 .49896 L
.78846 .50041 L
.78846 .50172 L
Mistroke
.78846 .50314 L
.78846 .50468 L
.78845 .50632 L
.78845 .50787 L
.78845 .50927 L
.78844 .51216 L
.78843 .51533 L
.78841 .52173 L
.78838 .52767 L
.78834 .53321 L
.78822 .54578 L
.78814 .55286 L
.78804 .55932 L
.7878 .57192 L
.78751 .58367 L
.7871 .59669 L
.78652 .61068 L
.78587 .62313 L
.78499 .63672 L
.78283 .66182 L
.78132 .67527 L
.77933 .6902 L
.77399 .72099 L
.76703 .75045 L
.75695 .78255 L
.74325 .81563 L
.72661 .8466 L
.70602 .87647 L
.68324 .90239 L
.65619 .92638 L
.63895 .93871 L
.62221 .94884 L
.60553 .95732 L
.58657 .96522 L
.56575 .97191 L
.55533 .97452 L
.54542 .97657 L
.53549 .97822 L
.52631 .97937 L
.52133 .97985 L
.51607 .98025 L
.51351 .9804 L
.51078 .98053 L
.50921 .9806 L
.50778 .98065 L
.50645 .98069 L
.50498 .98072 L
.50228 .98076 L
.50081 .98077 L
.49942 .98077 L
Mistroke
.49695 .98075 L
.49429 .9807 L
.49281 .98066 L
.49119 .98061 L
.48824 .98049 L
.48272 .98017 L
.47745 .97974 L
.47185 .97916 L
.46183 .97781 L
.45098 .97588 L
.44111 .97368 L
.41929 .9673 L
.40073 .96013 L
.38195 .9511 L
.34906 .93036 L
.32197 .90751 L
.29619 .87926 L
.27661 .85178 L
.26012 .82257 L
.24598 .79044 L
.23568 .76001 L
.22756 .7283 L
.22212 .69964 L
.21846 .6735 L
.21696 .65973 L
.21567 .64547 L
.21398 .62052 L
.21335 .60789 L
.21283 .59458 L
.21244 .58216 L
.21217 .57099 L
.21194 .55833 L
.21179 .54675 L
.21167 .53412 L
.21162 .52778 L
.21158 .52082 L
.21157 .51772 L
.21156 .51435 L
.21155 .51116 L
.21155 .50964 L
.21155 .50821 L
.21154 .5068 L
.21154 .50528 L
.21154 .5039 L
.21154 .50264 L
.21154 .50126 L
.21154 .49975 L
.21154 .49817 L
.21154 .49671 L
.21154 .49509 L
Mistroke
.21154 .49334 L
.21155 .49169 L
.21155 .49016 L
.21156 .48727 L
.21157 .4842 L
.21159 .47782 L
.21163 .47078 L
.21168 .46432 L
.21173 .45815 L
.21187 .44653 L
.21208 .43393 L
.21239 .42004 L
.21278 .40676 L
.21324 .39458 L
.21393 .38033 L
.21477 .36671 L
.21576 .35346 L
.21707 .33924 L
.22018 .3132 L
.22489 .28471 L
.23093 .25738 L
.23995 .22638 L
.25076 .19772 L
.26488 .16826 L
.2842 .13679 L
.30679 .1082 L
.33548 .08034 L
.36629 .05793 L
.39858 .04081 L
.41708 .03346 L
.43727 .02729 L
.45496 .02335 L
.46512 .02169 L
.47465 .02053 L
.48004 .02003 L
.48502 .01968 L
.48763 .01954 L
.49049 .01941 L
.49194 .01936 L
.49349 .01931 L
.49496 .01928 L
.4963 .01926 L
.49891 .01923 L
.50133 .01923 L
.50398 .01926 L
.50547 .01929 L
.50681 .01932 L
.50928 .0194 L
.51195 .01952 L
.51678 .0198 L
Mistroke
.5214 .02015 L
.52646 .02064 L
.53661 .02195 L
.54595 .02352 L
.55459 .02531 L
.57526 .0309 L
.5942 .03774 L
.62761 .05424 L
.65986 .07651 L
.68593 .10035 L
.70856 .12682 L
.72918 .15769 L
.74473 .18751 L
.75779 .21978 L
.76728 .25048 L
.77461 .28208 L
.77949 .31086 L
.78269 .33684 L
.78407 .35141 L
.78512 .36495 L
.78655 .38974 L
.78707 .40249 L
.78751 .41581 L
.78779 .42707 L
.78802 .43933 L
.78821 .45214 L
.78832 .46377 L
.78837 .47017 L
.78841 .47712 L
.78842 .4803 L
.78844 .48367 L
.78845 .48663 L
.78845 .48974 L
.78846 .49262 L
.78846 .49425 L
.78846 .49578 L
.78846 .49718 L
.78846 .49845 L
.78847 .49992 L
.78846 .50132 L
.78846 .50283 L
.78846 .50443 L
.78846 .5058 L
.78846 .50731 L
.78845 .51067 L
.78845 .51381 L
.78843 .51952 L
.7884 .52474 L
.78836 .53077 L
.78832 .53652 L
Mistroke
.7882 .54852 L
.78801 .56139 L
.78777 .57363 L
.78749 .58482 L
.78706 .59779 L
.78656 .60986 L
.78582 .62414 L
.78493 .63766 L
.78265 .66353 L
.78105 .67755 L
.77895 .69281 L
.77339 .72388 L
.76602 .75413 L
.75619 .78467 L
.74441 .81317 L
.72942 .8419 L
.70886 .87277 L
.68542 .90017 L
.65556 .92688 L
.62256 .94865 L
.60453 .95779 L
.58386 .96621 L
.56384 .97243 L
.54516 .97663 L
.53466 .97834 L
.5291 .97906 L
.52319 .97969 L
.51801 .98012 L
.51526 .9803 L
.5123 .98047 L
.50958 .98059 L
.5071 .98067 L
.5046 .98073 L
.50223 .98076 L
.49965 .98077 L
.4982 .98077 L
.49687 .98076 L
.49441 .98071 L
.49182 .98064 L
.48949 .98055 L
.48733 .98045 L
.48241 .98015 L
.47709 .97971 L
.47226 .97922 L
.46146 .97776 L
.45228 .97614 L
.44241 .974 L
.42479 .96912 L
.40675 .96264 L
.38764 .95404 L
Mistroke
.35195 .93247 L
.32303 .90853 L
.29649 .87965 L
.27444 .84833 L
.25763 .81751 L
.24463 .7869 L
.23527 .75866 L
.22743 .72773 L
.22223 .70038 L
.21838 .67288 L
.21676 .65774 L
.21555 .64403 L
.21387 .61872 L
.2132 .60464 L
.21272 .59166 L
.21233 .57823 L
.21206 .56563 L
.21188 .55441 L
.21179 .54815 L
.21173 .54228 L
.21163 .53057 L
.21159 .52437 L
.21158 .52118 L
.21156 .51769 L
.21155 .51449 L
.21154 .51108 L
.21154 .50919 L
.21154 .50747 L
.21153 .50575 L
.21153 .50412 L
.21153 .50261 L
.21153 .50101 L
.21153 .49965 L
.21153 .49815 L
.21153 .49654 L
.21153 .49563 L
.21153 .4948 L
.21154 .49319 L
.21154 .49167 L
.21154 .48857 L
.21155 .48576 L
.21158 .47945 L
.2116 .47399 L
.21164 .46808 L
.21169 .46153 L
.21176 .45459 L
.21193 .44211 L
.21214 .43009 L
.21245 .4171 L
.21284 .40472 L
Mistroke
.21329 .39331 L
.21468 .36792 L
.21577 .35327 L
.21703 .33951 L
.22018 .31317 L
.22517 .28323 L
.23171 .2543 L
.24128 .22244 L
.25349 .19142 L
.2701 .15891 L
.28962 .12924 L
.3115 .10305 L
.34025 .07641 L
.37022 .05552 L
.40462 .03822 L
.4253 .03072 L
.43474 .02796 L
.445 .0254 L
.45521 .0233 L
.46461 .02176 L
.46916 .02115 L
.47413 .02058 L
.4788 .02013 L
.48321 .01979 L
.48591 .01963 L
.48882 .01948 L
.49147 .01937 L
.49391 .0193 L
.49656 .01925 L
.49806 .01923 L
.49946 .01923 L
.50094 .01923 L
.50229 .01924 L
.50384 .01925 L
.50531 .01928 L
.50779 .01935 L
.51042 .01944 L
.51513 .01969 L
.52019 .02005 L
.52575 .02057 L
.53636 .02191 L
.54637 .0236 L
.5649 .02786 L
.58432 .03396 L
.60473 .0423 L
.63903 .06134 L
.67137 .08629 L
.69946 .11541 L
.72137 .14505 L
.73902 .1757 L
Mistroke
.75195 .20427 L
.76229 .23328 L
.77084 .26462 L
.77673 .29349 L
.78119 .32355 L
.7828 .33782 L
.78422 .3531 L
.7852 .36609 L
.78607 .38023 L
.78669 .3928 L
.78721 .40617 L
.78763 .42013 L
.78792 .4331 L
.78812 .44519 L
.78828 .45832 L
.78834 .46492 L
.78839 .47195 L
.78842 .47857 L
.78845 .48458 L
.78845 .48744 L
.78846 .49059 L
.78846 .49217 L
.78847 .49387 L
.78847 .49548 L
.78847 .49694 L
.78847 .49839 L
.78847 .49974 L
.78847 .50122 L
.78847 .50279 L
.78847 .50429 L
.78847 .5057 L
.78846 .50834 L
.78846 .51148 L
.78845 .5148 L
.78843 .52073 L
.78839 .52713 L
.78834 .53417 L
.78822 .54695 L
.78806 .55866 L
.78781 .57229 L
.78748 .58532 L
.78707 .59784 L
.7865 .61128 L
.78506 .63588 L
.78407 .64867 L
.78275 .66265 L
.77958 .68849 L
.77465 .7177 L
.76735 .7493 L
.75803 .77955 L
Mistroke
.74678 .80796 L
.73078 .83955 L
.71272 .86756 L
.6902 .89512 L
.66125 .92237 L
.62923 .94481 L
.61163 .95441 L
.59129 .96342 L
.57171 .9702 L
.5533 .97498 L
.54295 .97703 L
.53744 .97793 L
.53157 .97876 L
.52643 .97936 L
.52074 .97991 L
.51555 .98029 L
.51067 .98055 L
.50825 .98064 L
.50567 .98071 L
.50323 .98076 L
.50101 .98077 L
.4984 .98077 L
.49692 .98076 L
.49556 .98074 L
.49307 .98068 L
.49042 .98059 L
.4879 .98048 L
.48519 .98033 L
.48029 .97999 L
.47448 .97946 L
.46918 .97885 L
.45994 .97752 L
.44994 .97567 L
.43201 .97129 L
.41203 .9647 L
.39458 .95738 L
.3582 .93682 L
.32867 .91375 L
.30127 .88546 L
.27945 .85621 L
.26086 .82406 L
.24722 .79366 L
.2373 .76541 L
.22896 .73454 L
.22337 .70707 L
.2192 .67957 L
.21757 .66567 L
.21609 .65057 L
.21415 .62378 L
.21341 .60942 L
Mistroke
.21287 .59612 L
.21246 .58341 L
.21214 .57018 L
.21194 .55898 L
.21177 .54682 L
.2117 .5402 L
.21165 .53397 L
.21161 .52832 L
.21158 .52235 L
.21157 .51926 L
.21155 .51586 L
.21154 .51273 L
.21154 .50988 L
.21153 .50827 L
.21153 .50651 L
.21153 .50555 L
.21153 .50466 L
.21153 .50376 L
.21153 .5029 L
.21153 .50211 L
.21153 .50124 L
.21153 .49974 L
.21153 .49889 L
.21153 .49799 L
.21153 .49638 L
.21153 .49486 L
.21153 .49321 L
.21154 .49021 L
.21154 .48729 L
.21155 .4846 L
.21157 .47847 L
.21161 .47196 L
.21169 .46108 L
.21175 .45487 L
.21182 .44903 L
.21203 .43595 L
.21229 .42341 L
.2126 .41205 L
.21303 .39951 L
.21363 .38597 L
.21431 .37354 L
.21532 .35881 L
.21649 .34503 L
.21951 .31807 L
.22426 .28798 L
.23026 .26 L
.23922 .22857 L
.25043 .19847 L
.266 .16618 L
.2861 .13408 L
Mistroke
.30953 .10517 L
.33707 .07901 L
.36633 .0579 L
.39932 .04048 L
.41938 .03266 L
.43891 .02686 L
.44907 .02451 L
.45863 .0227 L
.46869 .02121 L
.47438 .02055 L
.47977 .02005 L
.48439 .01971 L
.48683 .01957 L
.48942 .01945 L
.49159 .01937 L
.49398 .0193 L
.49616 .01925 L
.4982 .01923 L
.50075 .01922 L
.50317 .01924 L
.50534 .01928 L
.50771 .01934 L
.51027 .01944 L
.513 .01956 L
.51791 .01987 L
.52327 .02032 L
.52892 .02092 L
.53899 .02231 L
.54973 .02426 L
.56137 .02693 L
.58178 .03306 L
.60016 .04025 L
.63609 .05943 L
.6653 .08099 L
.6915 .10629 L
.71543 .13625 L
.73403 .16623 L
.74966 .19869 L
.76085 .22879 L
.7689 .25664 L
.77551 .28676 L
.77988 .3136 L
.78305 .3403 L
.78438 .35508 L
.78537 .3686 L
.7862 .38268 L
.78682 .39578 L
.78725 .40731 L
.78762 .41985 L
.7879 .43227 L
Mistroke
.78812 .44529 L
.78827 .45727 L
.78837 .4684 L
.7884 .4746 L
.78842 .47788 L
.78844 .48135 L
.78845 .48438 L
.78846 .48772 L
.78846 .49076 L
.78847 .49212 L
.78847 .49361 L
.78847 .49506 L
.78847 .49642 L
.78847 .49784 L
.78847 .49937 L
.78847 .50079 L
.78847 .50214 L
.78847 .50335 L
.78847 .50466 L
.78847 .50609 L
.78847 .50767 L
.78846 .51086 L
.78845 .51382 L
.78844 .51659 L
.78842 .52275 L
.78838 .52948 L
.78833 .53586 L
.78828 .54179 L
.78815 .55304 L
.78795 .5651 L
.78767 .5782 L
.78726 .59252 L
.78673 .60621 L
.78612 .61896 L
.78443 .64431 L
.78312 .65901 L
.78161 .67296 L
.77749 .70209 L
.7722 .72943 L
.76485 .75823 L
.75415 .79014 L
.7408 .82074 L
.7227 .85288 L
.70192 .88162 L
.67866 .90692 L
.64874 .93198 L
.61761 .95134 L
.59984 .95989 L
.58263 .96664 L
.5631 .97262 L
Mistroke
.55201 .97526 L
.54166 .97725 L
.53154 .97876 L
.52634 .97937 L
.52074 .97991 L
.5178 .98014 L
.51512 .98032 L
.51239 .98047 L
.50985 .98058 L
.50691 .98068 L
.50535 .98072 L
.5037 .98075 L
.50212 .98077 L
.50063 .98078 L
.4993 .98078 L
.49785 .98077 L
.49525 .98073 L
.49282 .98067 L
.49016 .98058 L
.48731 .98045 L
.4815 .98009 L
.47622 .97963 L
.46608 .97844 L
.45654 .97694 L
.43715 .97269 L
.41711 .96655 L
.40056 .96006 L
.38302 .95167 L
.35043 .93137 L
.31969 .90532 L
.2946 .87728 L
.27291 .84584 L
.25664 .81544 L
.24466 .787 L
.23437 .75554 L
.22737 .72751 L
.22205 .69926 L
.21992 .68499 L
.21799 .66957 L
.21539 .64204 L
.21437 .62734 L
.21362 .6138 L
.21301 .60011 L
.21258 .58728 L
.21227 .57589 L
.21202 .5636 L
.21183 .55176 L
.21169 .53878 L
.21164 .53228 L
.21159 .52529 L
Mistroke
.21158 .52208 L
.21156 .5187 L
.21155 .51581 L
.21154 .51267 L
.21153 .50949 L
.21153 .50803 L
.21153 .50648 L
.21153 .50509 L
.21153 .50356 L
.21153 .50216 L
.21153 .50086 L
.21153 .49923 L
.21153 .49768 L
.21153 .49629 L
.21153 .49478 L
.21153 .49314 L
.21153 .49139 L
.21154 .48824 L
.21155 .48528 L
.21156 .48209 L
.21158 .47629 L
.21162 .47064 L
.21165 .46543 L
.21177 .45325 L
.21193 .44181 L
.21216 .42917 L
.21249 .4155 L
.21292 .40233 L
.21354 .38783 L
.21429 .37393 L
.21516 .36091 L
.21747 .3352 L
.21923 .32023 L
.22123 .30596 L
.22654 .2764 L
.23322 .2486 L
.24226 .21961 L
.25523 .18758 L
.27099 .15738 L
.29204 .12602 L
.31835 .096 L
.34775 .0706 L
.36349 .05969 L
.38115 .04932 L
.41513 .03415 L
.43348 .0283 L
.44381 .02567 L
.45373 .02358 L
.46302 .02199 L
.46795 .0213 L
Mistroke
.47322 .02067 L
.4781 .02019 L
.48254 .01984 L
.487 .01956 L
.4892 .01946 L
.4912 .01938 L
.49361 .0193 L
.4962 .01925 L
.49859 .01922 L
.50085 .01922 L
.50349 .01925 L
.50592 .01929 L
.50859 .01937 L
.51142 .01948 L
.51665 .01978 L
.52154 .02016 L
.52689 .02069 L
.53264 .02138 L
.5427 .02293 L
.55219 .02477 L
.56973 .02921 L
.58823 .0354 L
.60724 .04347 L
.63918 .06143 L
.67212 .08696 L
.69861 .11439 L
.72057 .14382 L
.7371 .17197 L
.75065 .20106 L
.76218 .23292 L
.77035 .26253 L
.77674 .29352 L
.77912 .30825 L
.78125 .32403 L
.78277 .33745 L
.78413 .35203 L
.78599 .37873 L
.78671 .39304 L
.78722 .40631 L
.7876 .41898 L
.78791 .43218 L
.7881 .44336 L
.78826 .4555 L
.78832 .4621 L
.78837 .46832 L
.78841 .47396 L
.78843 .47992 L
.78845 .48301 L
.78846 .48641 L
.78847 .4895 L
Mistroke
.78847 .49238 L
.78847 .49413 L
.78847 .49499 L
.78847 .49578 L
.78848 .49727 L
.78848 .49889 L
.78848 .49981 L
.78848 .50067 L
.78848 .50228 L
.78848 .50318 L
.78848 .50401 L
.78847 .50588 L
.78847 .50745 L
.78847 .50894 L
.78846 .51172 L
.78845 .51472 L
.78844 .51797 L
.78842 .52384 L
.78839 .52928 L
.78828 .54179 L
.78821 .54813 L
.78812 .55514 L
.7879 .56793 L
.78764 .57974 L
.78725 .59284 L
.78671 .60678 L
.7861 .61941 L
.78526 .63308 L
.7832 .65819 L
.78167 .67253 L
.77962 .68832 L
.77467 .71765 L
.76785 .74742 L
.75802 .77961 L
.74591 .80993 L
.73158 .83817 L
.71185 .86877 L
.69002 .89533 L
.66365 .9204 L
.63054 .94403 L
.5952 .96186 L
.57617 .96882 L
.56567 .97194 L
.55443 .97474 L
.54475 .97671 L
.53406 .97843 L
.52934 .97904 L
.52427 .97959 L
.51951 .98001 L
.51511 .98032 L
Mistroke
.51247 .98047 L
.50956 .9806 L
.50663 .98069 L
.50503 .98073 L
.50353 .98076 L
.50212 .98077 L
.50078 .98078 L
.49826 .98078 L
.49555 .98074 L
.49401 .98071 L
.49259 .98067 L
.48991 .98058 L
.48739 .98046 L
.48268 .98018 L
.47762 .97977 L
.47217 .97921 L
.46213 .97787 L
.45283 .97625 L
.43203 .9713 L
.41235 .96482 L
.39207 .95621 L
.35552 .935 L
.32511 .9105 L
.29935 .88318 L
.27937 .85609 L
.26269 .82763 L
.24806 .79577 L
.23746 .76594 L
.2289 .73432 L
.22294 .70468 L
.22061 .68992 L
.21855 .67441 L
.21696 .65992 L
.21578 .64696 L
.21405 .62215 L
.21338 .60893 L
.21289 .5969 L
.21247 .58384 L
.21214 .57017 L
.21192 .55821 L
.21183 .55166 L
.21175 .54546 L
.21169 .53973 L
.21164 .53351 L
.2116 .52827 L
.21157 .52263 L
.21156 .51918 L
.21155 .51601 L
.21154 .51304 L
.21153 .50979 L
Mistroke
.21153 .50838 L
.21152 .50687 L
.21152 .50556 L
.21152 .50414 L
.21152 .50254 L
.21152 .50102 L
.21152 .49955 L
.21152 .49819 L
.21152 .49669 L
.21152 .49509 L
.21152 .49357 L
.21153 .49218 L
.21153 .48879 L
.21154 .48557 L
.21156 .47916 L
.2116 .47215 L
.21165 .46554 L
.2117 .4593 L
.21184 .44758 L
.21204 .43488 L
.21234 .421 L
.21269 .40878 L
.2132 .39521 L
.21388 .38085 L
.21471 .36724 L
.21577 .35307 L
.21703 .33942 L
.22015 .31327 L
.22493 .28438 L
.23102 .25691 L
.23923 .2285 L
.25118 .1967 L
.26563 .16684 L
.28524 .13528 L
.30837 .10642 L
.3375 .07864 L
.36903 .05623 L
.40175 .03942 L
.4217 .03187 L
.4412 .02628 L
.45913 .02261 L
.46937 .02112 L
.47888 .02012 L
.4839 .01974 L
.48849 .01948 L
.49103 .01938 L
.49237 .01933 L
.4938 .01929 L
.49641 .01924 L
.49884 .01922 L
Mistroke
.50127 .01922 L
.50389 .01925 L
.50637 .0193 L
.50865 .01937 L
.51071 .01945 L
.51297 .01956 L
.51753 .01984 L
.52307 .02029 L
.52811 .02082 L
.53937 .02236 L
.54972 .02425 L
.55941 .02643 L
.57839 .0319 L
.59788 .03926 L
.63073 .05609 L
.66195 .07819 L
.68756 .10204 L
.71158 .13086 L
.72977 .15868 L
.7449 .18785 L
.75784 .21988 L
.76715 .24992 L
.77447 .28132 L
.77973 .31241 L
.78154 .32633 L
.78312 .34082 L
.7843 .35397 L
.78536 .36821 L
.7867 .39274 L
.78722 .40602 L
.78759 .41801 L
.78791 .4317 L
.78813 .44456 L
.78828 .45665 L
.78834 .46337 L
.78839 .46943 L
.78842 .47511 L
.78845 .48122 L
.78846 .48403 L
.78847 .48699 L
.78847 .48953 L
.78848 .49228 L
.78848 .49393 L
.78848 .49546 L
.78848 .49691 L
.78849 .49846 L
.78849 .49984 L
.78849 .50113 L
.78848 .50255 L
.78848 .50407 L
Mistroke
.78848 .50569 L
.78848 .50745 L
.78847 .51066 L
.78847 .51379 L
.78846 .51669 L
.78843 .52247 L
.7884 .52772 L
.78831 .53953 L
.78825 .54562 L
.78817 .55209 L
.78799 .56372 L
.78773 .57634 L
.78734 .59034 L
.78686 .60361 L
.78629 .61585 L
.78545 .63034 L
.78447 .64395 L
.78192 .67037 L
.78014 .68463 L
.77784 .70001 L
.77238 .72866 L
.76544 .75622 L
.75527 .7872 L
.74318 .81584 L
.72765 .84492 L
.70656 .8758 L
.68233 .90332 L
.6518 .92974 L
.63518 .94116 L
.61601 .95219 L
.59855 .96045 L
.57853 .96805 L
.56888 .97104 L
.55836 .97382 L
.54915 .97587 L
.53902 .97769 L
.53306 .97857 L
.52751 .97925 L
.52174 .97983 L
.51651 .98023 L
.51403 .98039 L
.51135 .98052 L
.50881 .98063 L
.50648 .9807 L
.504 .98075 L
.50128 .98078 L
.49991 .98078 L
.49844 .98078 L
.49579 .98075 L
.49327 .98069 L
Mistroke
.49183 .98065 L
.49048 .9806 L
.48755 .98047 L
.48486 .98032 L
.48001 .97998 L
.47479 .9795 L
.46375 .97812 L
.45224 .97614 L
.43306 .97159 L
.41269 .96496 L
.39349 .95689 L
.37683 .94832 L
.34248 .92537 L
.31505 .90067 L
.28993 .87118 L
.27021 .84129 L
.25361 .80886 L
.24161 .77853 L
.23297 .7505 L
.2258 .72003 L
.22106 .69295 L
.21758 .66591 L
.21612 .65097 L
.21503 .63735 L
.21354 .61244 L
.21295 .59853 L
.21252 .58561 L
.2122 .57304 L
.21195 .55993 L
.21179 .54881 L
.21166 .53672 L
.21161 .53014 L
.21158 .52395 L
.21155 .51839 L
.21154 .51528 L
.21153 .51237 L
.21153 .50925 L
.21152 .5076 L
.21152 .50582 L
.21152 .50493 L
.21152 .50396 L
.21152 .50305 L
.21152 .5022 L
.21152 .50059 L
.21152 .49969 L
.21152 .49888 L
.21152 .49728 L
.21152 .4958 L
.21152 .49418 L
.21152 .49247 L
Mistroke
.21153 .48959 L
.21154 .48643 L
.21155 .48331 L
.21156 .47992 L
.21159 .47375 L
.21163 .46773 L
.21167 .46215 L
.21181 .44945 L
.2119 .44301 L
.21202 .43587 L
.21229 .42302 L
.21262 .41113 L
.21308 .39793 L
.21373 .38386 L
.21446 .37112 L
.21543 .35733 L
.21782 .33195 L
.21958 .31747 L
.22192 .30151 L
.2275 .27189 L
.2351 .24189 L
.24597 .20954 L
.25921 .17923 L
.27474 .15116 L
.29593 .12103 L
.31918 .09518 L
.34696 .07119 L
.36457 .059 L
.38152 .04912 L
.39865 .04077 L
.41796 .03315 L
.42889 .02961 L
.43911 .0268 L
.44892 .02453 L
.45954 .02254 L
.46997 .02104 L
.47951 .02007 L
.48413 .01973 L
.48656 .01958 L
.48915 .01946 L
.4914 .01937 L
.49389 .01929 L
.49615 .01925 L
.49828 .01922 L
.50091 .01922 L
.5024 .01923 L
.50378 .01925 L
.50631 .0193 L
.50901 .01938 L
.51166 .01949 L
Mistroke
.51415 .01962 L
.51881 .01993 L
.52432 .02041 L
.52938 .02096 L
.54073 .02259 L
.55022 .02435 L
.56028 .02665 L
.57811 .03181 L
.59861 .03957 L
.61653 .04808 L
.64867 .06797 L
.67939 .09377 L
.70426 .12127 L
.72607 .15248 L
.74231 .18234 L
.75445 .21063 L
.76482 .24163 L
.77199 .26957 L
.77742 .29745 L
.77982 .31309 L
.78162 .32708 L
.78432 .35428 L
.7854 .36889 L
.7862 .38248 L
.78681 .39528 L
.7873 .40867 L
.78763 .41998 L
.78791 .4323 L
.78813 .44514 L
.78827 .45679 L
.78833 .46319 L
.78839 .47016 L
.78843 .47672 L
.78845 .4828 L
.78846 .48609 L
.78847 .48911 L
.78848 .49242 L
.78848 .49409 L
.78848 .49503 L
.78848 .49592 L
.78848 .49753 L
.78848 .499 L
.78848 .50058 L
.78848 .50148 L
.78848 .5023 L
.78848 .50368 L
.78848 .50519 L
.78848 .50678 L
.78847 .50826 L
.78847 .51108 L
Mistroke
.78846 .51406 L
.78844 .51937 L
.78842 .5251 L
.78838 .53137 L
.78832 .53798 L
.78826 .54422 L
.78812 .55596 L
.78789 .56868 L
.78757 .5826 L
.78719 .59484 L
.78664 .60845 L
.78591 .62285 L
.78503 .63652 L
.7839 .65074 L
.78257 .66443 L
.77928 .6907 L
.77427 .71967 L
.76791 .74723 L
.75937 .77568 L
.747 .8075 L
.73208 .83729 L
.71191 .86869 L
.68821 .89727 L
.65848 .92461 L
.62644 .94645 L
.59332 .96263 L
.5732 .96975 L
.56305 .97264 L
.55357 .97493 L
.54503 .97666 L
.53556 .97822 L
.52596 .97942 L
.52069 .97992 L
.51574 .98028 L
.51317 .98043 L
.51044 .98056 L
.50785 .98066 L
.50551 .98072 L
.50407 .98075 L
.50274 .98077 L
.50129 .98078 L
.49975 .98078 L
.49716 .98077 L
.49569 .98075 L
.49432 .98072 L
.49168 .98064 L
.48919 .98055 L
.48451 .9803 L
.47947 .97993 L
.47401 .97942 L
Mistroke
.46448 .97822 L
.45442 .97656 L
.43661 .97255 L
.41831 .96697 L
.39925 .9595 L
.36689 .94245 L
.33513 .91938 L
.30637 .89135 L
.28386 .86275 L
.26661 .83494 L
.25235 .80602 L
.24027 .77463 L
.23077 .74209 L
.22426 .71209 L
.21969 .68332 L
.21792 .66898 L
.21638 .65382 L
.21521 .63982 L
.21435 .62721 L
.21312 .60297 L
.21265 .59014 L
.21232 .57837 L
.21204 .56558 L
.21192 .55853 L
.21183 .55208 L
.21168 .53916 L
.21163 .53239 L
.21158 .52528 L
.21155 .51909 L
.21153 .51333 L
.21153 .51002 L
.21152 .50701 L
.21152 .50534 L
.21152 .50447 L
.21152 .50354 L
.21152 .50272 L
.21152 .50183 L
.21152 .50025 L
.21152 .49874 L
.21152 .49733 L
.21152 .49579 L
.21152 .49492 L
.21152 .49414 L
.21152 .49255 L
.21152 .49083 L
.21153 .48771 L
.21154 .4848 L
.21155 .48173 L
.21157 .47621 L
.21161 .46982 L
Mistroke
.21166 .46383 L
.21172 .4573 L
.2118 .45016 L
.212 .43701 L
.21225 .42443 L
.21259 .41207 L
.21298 .40051 L
.21416 .37592 L
.2151 .36163 L
.21621 .348 L
.21927 .31981 L
.22331 .29317 L
.22901 .26518 L
.23754 .2338 L
.24831 .2036 L
.26328 .17122 L
.28278 .13882 L
.30555 .10957 L
.33254 .08283 L
.36127 .06112 L
.39392 .04291 L
.41382 .03462 L
.43316 .02838 L
.44302 .02584 L
.45391 .02354 L
.4643 .0218 L
.46929 .02112 L
.47401 .02058 L
.47865 .02014 L
.48368 .01975 L
.48591 .01961 L
.48826 .01949 L
.49046 .0194 L
.49247 .01933 L
.49482 .01927 L
.49734 .01923 L
.49967 .01921 L
.50188 .01922 L
.50445 .01925 L
.50682 .01931 L
.50943 .01939 L
.51219 .01951 L
.51711 .0198 L
.52227 .02022 L
.53146 .02122 L
.54129 .02268 L
.55195 .02471 L
.57075 .0295 L
.58776 .03521 L
.62502 .05273 L
Mistroke
.65552 .07307 L
.68319 .09754 L
.70861 .12687 L
.72858 .15665 L
.74545 .18904 L
.75766 .21935 L
.76646 .24741 L
.77378 .2779 L
.77864 .30503 L
.7822 .33211 L
.78371 .34707 L
.78483 .36071 L
.78579 .375 L
.7865 .38824 L
.787 .3999 L
.78743 .41252 L
.78777 .42509 L
.78803 .43822 L
.78821 .45028 L
.78833 .46145 L
.78838 .46772 L
.78842 .47452 L
.78845 .48092 L
.78846 .48397 L
.78847 .48683 L
.78848 .4896 L
.78848 .49214 L
.78848 .49359 L
.78849 .49496 L
.78849 .49642 L
.78849 .498 L
.78849 .49956 L
.78849 .50097 L
.78849 .5026 L
.78849 .50414 L
.78848 .50556 L
.78848 .50688 L
.78848 .50984 L
.78847 .51288 L
.78846 .51566 L
.78844 .52191 L
.78841 .52771 L
.78837 .53321 L
.78825 .54558 L
.78817 .55259 L
.78807 .55911 L
.78785 .57131 L
.78756 .58286 L
.78716 .59566 L
.7866 .60963 L
Mistroke
.78595 .6223 L
.78505 .63636 L
.78384 .65144 L
.78248 .66536 L
.77891 .69318 L
.77342 .72382 L
.76645 .75264 L
.75626 .78452 L
.74345 .81527 L
.72604 .84758 L
.70586 .8767 L
.68325 .90241 L
.6539 .92816 L
.62332 .94824 L
.58866 .96445 L
.56786 .97134 L
.54798 .9761 L
.53767 .97791 L
.53221 .97869 L
.52644 .97937 L
.52135 .97987 L
.51577 .98029 L
.51331 .98043 L
.51068 .98056 L
.50819 .98065 L
.50593 .98072 L
.50354 .98076 L
.50101 .98079 L
.49885 .98079 L
.49646 .98076 L
.49391 .98071 L
.49247 .98067 L
.49116 .98063 L
.48619 .9804 L
.48185 .98012 L
.47712 .97973 L
.46762 .97866 L
.45684 .977 L
.44677 .97501 L
.42825 .9702 L
.4089 .96351 L
.38878 .95462 L
.35474 .93446 L
.32313 .90865 L
.29804 .8816 L
.27837 .85458 L
.26193 .82618 L
.24768 .79484 L
.2363 .76218 L
.2283 .73176 L
Mistroke
.22259 .70263 L
.22033 .68805 L
.21833 .67257 L
.2168 .6584 L
.21566 .64559 L
.21398 .62095 L
.21333 .60802 L
.21285 .59611 L
.21244 .5832 L
.21211 .56954 L
.21189 .5566 L
.21179 .54982 L
.21171 .54267 L
.21165 .53644 L
.2116 .5296 L
.21157 .52339 L
.21154 .51759 L
.21153 .51439 L
.21152 .51143 L
.21152 .50818 L
.21151 .50636 L
.21151 .50471 L
.21151 .50314 L
.21151 .50169 L
.21151 .5001 L
.21151 .4993 L
.21151 .49842 L
.21151 .49694 L
.21151 .49535 L
.21151 .49385 L
.21152 .49249 L
.21152 .48955 L
.21153 .48684 L
.21155 .48069 L
.21157 .47526 L
.21161 .46949 L
.21171 .45779 L
.21178 .45119 L
.21186 .44511 L
.21205 .43386 L
.21231 .42192 L
.21266 .40964 L
.21314 .39637 L
.21439 .37205 L
.21536 .3582 L
.21667 .34295 L
.21996 .31461 L
.22466 .28578 L
.23167 .25437 L
.24057 .22448 L
Mistroke
.2514 .19618 L
.26672 .16484 L
.28418 .13678 L
.30587 .10921 L
.33401 .08156 L
.36506 .05868 L
.40226 .03919 L
.42186 .03182 L
.43245 .02858 L
.44379 .02566 L
.45387 .02354 L
.46504 .02169 L
.46997 .02104 L
.47527 .02045 L
.47982 .02003 L
.48485 .01967 L
.48741 .01953 L
.49016 .01941 L
.49168 .01935 L
.49306 .01931 L
.49579 .01925 L
.49827 .01922 L
.50098 .01921 L
.50353 .01924 L
.50591 .01928 L
.50734 .01932 L
.50889 .01937 L
.51171 .01949 L
.51696 .01979 L
.52308 .02029 L
.5287 .02088 L
.53822 .02218 L
.5486 .02402 L
.56919 .02904 L
.58888 .03563 L
.60619 .04296 L
.64238 .06356 L
.67158 .08646 L
.69886 .11467 L
.72047 .14365 L
.73904 .1757 L
.75258 .2058 L
.76252 .23396 L
.77084 .26455 L
.77648 .29196 L
.78066 .31923 L
.78247 .33451 L
.78381 .34817 L
.78578 .37475 L
.78654 .38905 L
Mistroke
.78709 .40237 L
.78751 .41493 L
.78784 .4281 L
.78805 .43924 L
.78822 .45141 L
.7883 .45793 L
.78835 .46411 L
.78839 .46971 L
.78843 .47566 L
.78845 .47904 L
.78846 .4821 L
.78847 .48521 L
.78848 .48806 L
.78848 .4914 L
.78849 .49316 L
.78849 .49502 L
.78849 .49663 L
.78849 .49814 L
.78849 .499 L
.78849 .49979 L
.78849 .5007 L
.78849 .50156 L
.78849 .50297 L
.78849 .5045 L
.78849 .50594 L
.78849 .50726 L
.78848 .51032 L
.78847 .51354 L
.78845 .51962 L
.78842 .52628 L
.78838 .53203 L
.78833 .53818 L
.78821 .54929 L
.78802 .56222 L
.78773 .57634 L
.78736 .58982 L
.78691 .60238 L
.78566 .62723 L
.78466 .64164 L
.78349 .65532 L
.78025 .68383 L
.77601 .71065 L
.77001 .73895 L
.7611 .7705 L
.74982 .80096 L
.73425 .83339 L
.71608 .86284 L
.6954 .88936 L
.66836 .91639 L
.63967 .93826 L
Mistroke
.60686 .95672 L
.5869 .96512 L
.56757 .97142 L
.5576 .97401 L
.54664 .97636 L
.53617 .97814 L
.53116 .97882 L
.52644 .97937 L
.52184 .97982 L
.51763 .98016 L
.51294 .98045 L
.51035 .98057 L
.50789 .98066 L
.50552 .98073 L
.503 .98077 L
.50062 .98079 L
.49846 .98078 L
.49591 .98076 L
.49448 .98073 L
.49316 .98069 L
.49073 .98062 L
.48817 .98051 L
.48292 .9802 L
.47797 .97981 L
.4687 .9788 L
.45879 .97734 L
.44811 .9753 L
.42921 .97049 L
.41221 .96478 L
.37809 .94903 L
.36005 .93808 L
.34415 .92667 L
.31749 .90315 L
.29261 .87474 L
.27228 .8448 L
.25519 .81236 L
.24283 .78202 L
.23281 .74994 L
.22539 .71798 L
.22042 .68865 L
.2186 .67482 L
.21701 .66041 L
.21487 .63512 L
.21406 .62246 L
.21338 .60903 L
.21287 .59661 L
.2125 .58522 L
.21218 .57225 L
.21191 .55825 L
.21175 .54601 L
Mistroke
.21168 .53921 L
.21163 .53306 L
.21159 .52697 L
.21156 .52056 L
.21154 .51509 L
.21153 .512 L
.21152 .50911 L
.21152 .5075 L
.21152 .50575 L
.21152 .50496 L
.21151 .50411 L
.21151 .50258 L
.21151 .50113 L
.21151 .49976 L
.21151 .49826 L
.21151 .49665 L
.21152 .49502 L
.21152 .49325 L
.21152 .4914 L
.21152 .48968 L
.21153 .48659 L
.21154 .48329 L
.21157 .47666 L
.21161 .47053 L
.21166 .4638 L
.21172 .45666 L
.21187 .4446 L
.2121 .43125 L
.21241 .41824 L
.21277 .40625 L
.21332 .39224 L
.214 .37879 L
.2148 .36587 L
.21587 .35193 L
.21846 .32634 L
.2224 .2985 L
.22756 .2716 L
.23531 .24118 L
.24474 .21276 L
.25713 .18351 L
.27437 .15176 L
.29466 .12263 L
.32093 .09346 L
.35261 .06705 L
.36873 .05641 L
.38681 .04636 L
.40424 .03837 L
.42422 .03105 L
.44299 .02585 L
.45227 .02385 L
Mistroke
.46096 .02231 L
.4711 .0209 L
.47648 .02033 L
.48223 .01985 L
.48486 .01968 L
.48772 .01952 L
.49024 .01941 L
.4929 .01932 L
.4953 .01926 L
.49794 .01922 L
.50034 .01921 L
.50258 .01923 L
.50496 .01926 L
.50754 .01933 L
.50998 .01942 L
.51224 .01952 L
.5165 .01976 L
.52102 .02011 L
.53036 .02108 L
.5406 .02256 L
.55055 .02442 L
.5609 .0268 L
.57904 .03212 L
.59796 .03929 L
.61774 .04872 L
.65063 .06939 L
.68134 .09569 L
.7077 .12568 L
.72808 .1558 L
.74433 .18661 L
.75615 .21517 L
.7655 .24398 L
.77319 .27506 L
.77842 .3036 L
.78234 .33332 L
.78374 .3474 L
.78496 .36249 L
.78589 .37668 L
.78655 .38934 L
.78707 .40176 L
.78751 .41502 L
.78785 .42886 L
.78809 .44175 L
.78825 .45374 L
.78832 .46051 L
.78837 .4668 L
.78841 .47344 L
.78845 .47947 L
.78846 .4828 L
.78847 .48642 L
Mistroke
.78848 .48983 L
.78848 .49145 L
.78848 .49298 L
.78849 .49442 L
.78849 .49599 L
.78849 .49742 L
.78849 .49875 L
.78849 .50032 L
.78849 .50175 L
.78849 .50254 L
.78849 .5034 L
.78849 .50495 L
.78849 .5063 L
.78848 .50779 L
.78848 .51079 L
.78847 .51357 L
.78846 .51617 L
.78844 .52263 L
.7884 .52853 L
.78835 .53536 L
.7883 .54184 L
.78815 .55394 L
.78794 .5669 L
.78769 .57805 L
.78734 .59047 L
.78686 .60359 L
.7863 .61576 L
.78547 .63017 L
.78449 .64378 L
.78197 .66996 L
.78021 .68412 L
.77793 .6995 L
.77189 .73091 L
.76394 .76138 L
.75338 .79216 L
.74083 .82071 L
.72488 .84945 L
.70322 .88004 L
.6786 .907 L
.64754 .93285 L
.63084 .94385 L
.61151 .95448 L
.59207 .96313 L
.57375 .96959 L
.56417 .97235 L
.55368 .97491 L
.5445 .97676 L
.53436 .9784 L
.52347 .97967 L
.5175 .98017 L
Mistroke
.51463 .98036 L
.51192 .9805 L
.50941 .98061 L
.50668 .9807 L
.5042 .98075 L
.50191 .98078 L
.49944 .98079 L
.49671 .98077 L
.49533 .98074 L
.49386 .98071 L
.49119 .98063 L
.48859 .98053 L
.48623 .98041 L
.48095 .98005 L
.47606 .97963 L
.47147 .97914 L
.4612 .97773 L
.45018 .97573 L
.42837 .97023 L
.4089 .96351 L
.37484 .9472 L
.34121 .92436 L
.31361 .89919 L
.28863 .86944 L
.26804 .83751 L
.25255 .80649 L
.24065 .77577 L
.2322 .74765 L
.22574 .71975 L
.22057 .68974 L
.21721 .66244 L
.21581 .64743 L
.21478 .63387 L
.21336 .60871 L
.2128 .59472 L
.2124 .58185 L
.21209 .56844 L
.21187 .55589 L
.21173 .5447 L
.21167 .53846 L
.21162 .53262 L
.21158 .52649 L
.21155 .52088 L
.21153 .51466 L
.21152 .51124 L
.21152 .50953 L
.21151 .50798 L
.21151 .50648 L
.21151 .50486 L
.21151 .50396 L
Mistroke
.21151 .50314 L
.21151 .50152 L
.21151 .50013 L
.21151 .49861 L
.21151 .49701 L
.21151 .49553 L
.21151 .49468 L
.21151 .49376 L
.21151 .49209 L
.21152 .48896 L
.21153 .48531 L
.21154 .48192 L
.21157 .47617 L
.2116 .46995 L
.2117 .45868 L
.21177 .45212 L
.21186 .44519 L
.21207 .43274 L
.21234 .42056 L
.21273 .40742 L
.2132 .39489 L
.21374 .38336 L
.2154 .35758 L
.21669 .34272 L
.21817 .3288 L
.22183 .30202 L
.22754 .27168 L
.23496 .24234 L
.24569 .21023 L
.26008 .17746 L
.27753 .14672 L
.29882 .11745 L
.32238 .09206 L
.35309 .0667 L
.38462 .04748 L
.40296 .0389 L
.4205 .03227 L
.44038 .02648 L
.4506 .02418 L
.46191 .02215 L
.46705 .02141 L
.47265 .02072 L
.47761 .02023 L
.48287 .0198 L
.48762 .01952 L
.49032 .0194 L
.49285 .01931 L
.49517 .01926 L
.4973 .01923 L
.49975 .01921 L
Mistroke
.50209 .01922 L
.5048 .01926 L
.50727 .01932 L
.50863 .01936 L
.51011 .01942 L
.51279 .01954 L
.51795 .01986 L
.5227 .02025 L
.53357 .0215 L
.54498 .02332 L
.56392 .02758 L
.5837 .03372 L
.61754 .04861 L
.63505 .05875 L
.65296 .07112 L
.68221 .09655 L
.70663 .12427 L
.72798 .15562 L
.74383 .18553 L
.75565 .21381 L
.76573 .24476 L
.77267 .27263 L
.77792 .30042 L
.78023 .31601 L
.78197 .32996 L
.78456 .35706 L
.78559 .37163 L
.78635 .38518 L
.78693 .39794 L
.7874 .4113 L
.78771 .42258 L
.78797 .43488 L
.78818 .44769 L
.78831 .45932 L
.78837 .46572 L
.78842 .47268 L
.78845 .47923 L
.78847 .48531 L
.78848 .48859 L
.78849 .49161 L
.78849 .49319 L
.78849 .49493 L
.78849 .4958 L
.78849 .49673 L
.78849 .49762 L
.78849 .49842 L
.78849 .5 L
.78849 .50146 L
.78849 .50306 L
.78849 .50387 L
Mistroke
.78849 .50476 L
.78849 .50625 L
.78849 .50786 L
.78848 .51076 L
.78848 .51357 L
.78847 .51663 L
.78844 .52281 L
.78841 .52855 L
.78837 .53389 L
.78832 .5402 L
.78824 .54706 L
.78807 .55957 L
.78784 .57184 L
.78756 .58324 L
.78716 .59578 L
.78669 .60763 L
.78599 .62165 L
.78514 .63513 L
.78412 .64836 L
.78274 .663 L
.7795 .68922 L
.77463 .71794 L
.76735 .74937 L
.7571 .78224 L
.7443 .81347 L
.72794 .84444 L
.70938 .87212 L
.68664 .89893 L
.65725 .92559 L
.62529 .94713 L
.60578 .95723 L
.58717 .96502 L
.5679 .97133 L
.5496 .97578 L
.5399 .97756 L
.52912 .97907 L
.52367 .97966 L
.51778 .98015 L
.51493 .98034 L
.51222 .98049 L
.50957 .9806 L
.50712 .98069 L
.50456 .98075 L
.50321 .98077 L
.50178 .98078 L
.49938 .98079 L
.49675 .98077 L
.4944 .98073 L
.49189 .98066 L
.48951 .98057 L
Mistroke
.48735 .98047 L
.48217 .98015 L
.47656 .97968 L
.46638 .9785 L
.45697 .97703 L
.44705 .97507 L
.42953 .97058 L
.41145 .96449 L
.39266 .9565 L
.3609 .93864 L
.32991 .91487 L
.30198 .88631 L
.28024 .85742 L
.26364 .82946 L
.24889 .79784 L
.23847 .76917 L
.23025 .74 L
.22371 .70911 L
.2193 .68044 L
.21762 .66632 L
.21612 .65103 L
.21419 .62468 L
.21343 .6102 L
.21289 .59715 L
.21247 .58439 L
.21218 .57267 L
.21194 .55993 L
.21183 .55291 L
.21175 .54648 L
.21163 .5336 L
.21158 .52685 L
.21156 .52342 L
.21155 .51975 L
.21154 .51651 L
.21153 .51357 L
.21152 .51061 L
.21151 .50781 L
.21151 .50623 L
.21151 .50455 L
.21151 .50312 L
.21151 .50154 L
.21151 .50066 L
.21151 .49985 L
.21151 .49896 L
.21151 .49803 L
.21151 .49645 L
.21151 .49556 L
.21151 .49473 L
.21151 .49315 L
.21151 .49147 L
Mistroke
.21152 .48846 L
.21153 .48522 L
.21154 .48166 L
.21157 .47527 L
.21161 .4693 L
.2117 .4581 L
.21177 .4518 L
.21185 .44603 L
.21205 .43353 L
.21231 .42185 L
.21268 .40892 L
.21319 .395 L
.21378 .38267 L
.21457 .3692 L
.21654 .34429 L
.21791 .33099 L
.21974 .31619 L
.22468 .28563 L
.23114 .25643 L
.24056 .22449 L
.25342 .19153 L
.26917 .16049 L
.28873 .13042 L
.31054 .10406 L
.33652 .07945 L
.36946 .05596 L
.4042 .03838 L
.42502 .03079 L
.43448 .02801 L
.44471 .02545 L
.4551 .02331 L
.46461 .02175 L
.46923 .02113 L
.47424 .02055 L
.47895 .0201 L
.48335 .01977 L
.48851 .01947 L
.49124 .01936 L
.49277 .01931 L
.49417 .01928 L
.49565 .01925 L
.49725 .01922 L
.49866 .01921 L
.50016 .01921 L
.50276 .01922 L
.50423 .01924 L
.50562 .01927 L
.50813 .01934 L
.51076 .01944 L
.51547 .01969 L
Mistroke
.52054 .02006 L
.52606 .02058 L
.53687 .02197 L
.54699 .0237 L
.56563 .02804 L
.58518 .03425 L
.60556 .04266 L
.64014 .06205 L
.67245 .08724 L
.69819 .11387 L
.71847 .14064 L
.73549 .16889 L
.75031 .20019 L
.76218 .23287 L
.77058 .26339 L
.7766 .29262 L
.78112 .32282 L
.78277 .33732 L
.78421 .35271 L
.78521 .36581 L
.78608 .37995 L
.78671 .39271 L
.78724 .40619 L
.78766 .42025 L
.78795 .43321 L
.78816 .44611 L
.78825 .45335 L
.78832 .46001 L
.78838 .46631 L
.78842 .47219 L
.78845 .47832 L
.78847 .48182 L
.78848 .48506 L
.78849 .48829 L
.78849 .49121 L
.78849 .49288 L
.7885 .49446 L
.7885 .49612 L
.7885 .49705 L
.7885 .49792 L
.7885 .49938 L
.7885 .50075 L
.7885 .50225 L
.7885 .50386 L
.7885 .50466 L
.7885 .50554 L
.78849 .50714 L
.78849 .51014 L
.78848 .51288 L
.78847 .51592 L
Mistroke
.78845 .52207 L
.78842 .52777 L
.78838 .53314 L
.78827 .54541 L
.78819 .55161 L
.7881 .55842 L
.78787 .57056 L
.7876 .58196 L
.78718 .59553 L
.78666 .6085 L
.78527 .63324 L
.78428 .64643 L
.78298 .66062 L
.77987 .68663 L
.7752 .71503 L
.76918 .74232 L
.76021 .77322 L
.74945 .80184 L
.73543 .83122 L
.71621 .86267 L
.69377 .89121 L
.6652 .91911 L
.64942 .9315 L
.63113 .94368 L
.61436 .95305 L
.59504 .96194 L
.57531 .96911 L
.55631 .97432 L
.54561 .97656 L
.53577 .9782 L
.53029 .97894 L
.52432 .9796 L
.51866 .98009 L
.51611 .98027 L
.51342 .98043 L
.51103 .98055 L
.50842 .98065 L
.50605 .98072 L
.50384 .98076 L
.50123 .98079 L
.49885 .98079 L
.49753 .98078 L
.49611 .98076 L
.49352 .98071 L
.49127 .98064 L
.4888 .98054 L
.48382 .98026 L
.4792 .97992 L
.4749 .97952 L
.46428 .97821 L
Mistroke
.45465 .97661 L
.43334 .97168 L
.41415 .96551 L
.39698 .9585 L
.36072 .93852 L
.33178 .91652 L
.30417 .88887 L
.28248 .86077 L
.26343 .82909 L
.24901 .79816 L
.23735 .76565 L
.22922 .73576 L
.2236 .70856 L
.21912 .67913 L
.2163 .65315 L
.21517 .63953 L
.21433 .62713 L
.21354 .61286 L
.21297 .59967 L
.21257 .58797 L
.21223 .57552 L
.21196 .56183 L
.21178 .54941 L
.21171 .54344 L
.21165 .53709 L
.2116 .53161 L
.21157 .5257 L
.21155 .52208 L
.21153 .51875 L
.21152 .51563 L
.21151 .51221 L
.21151 .50914 L
.2115 .50627 L
.2115 .50469 L
.2115 .50325 L
.2115 .50245 L
.2115 .50158 L
.2115 .5 L
.2115 .49849 L
.2115 .49711 L
.2115 .49559 L
.2115 .49399 L
.2115 .4913 L
.21151 .48835 L
.21152 .48513 L
.21153 .48169 L
.21156 .47548 L
.2116 .46843 L
.21166 .46177 L
.21179 .44924 L
Mistroke
.21198 .43698 L
.21225 .4239 L
.21255 .41262 L
.21298 .40009 L
.21356 .38675 L
.21423 .37441 L
.21522 .35979 L
.21637 .34603 L
.21931 .31939 L
.22396 .28945 L
.23052 .25887 L
.23856 .23053 L
.24945 .20077 L
.26468 .16857 L
.28315 .13825 L
.30718 .10772 L
.334 .08156 L
.36276 .06014 L
.38071 .04953 L
.3986 .04077 L
.41521 .0341 L
.43413 .0281 L
.45347 .02361 L
.46422 .0218 L
.46916 .02113 L
.47438 .02053 L
.47892 .0201 L
.4839 .01972 L
.48609 .01959 L
.48843 .01947 L
.49063 .01938 L
.49265 .01931 L
.4952 .01925 L
.49655 .01923 L
.49797 .01921 L
.50036 .0192 L
.50299 .01922 L
.50533 .01926 L
.50784 .01933 L
.51021 .01941 L
.51237 .01951 L
.51706 .01979 L
.52224 .0202 L
.53269 .02137 L
.5423 .02284 L
.55126 .02456 L
.57107 .02959 L
.59178 .03675 L
.62791 .05438 L
.64469 .06513 L
Mistroke
.66187 .07811 L
.69127 .10601 L
.71371 .13378 L
.73287 .16408 L
.74738 .19333 L
.75936 .22423 L
.76783 .25241 L
.77432 .28047 L
.77948 .31053 L
.78285 .33799 L
.78425 .35305 L
.78527 .36661 L
.78669 .3919 L
.78724 .40594 L
.78763 .4188 L
.78794 .4323 L
.78816 .4449 L
.7883 .45613 L
.78836 .46238 L
.7884 .4682 L
.78844 .4744 L
.78847 .48004 L
.78848 .48303 L
.78849 .48629 L
.7885 .48973 L
.7885 .49141 L
.7885 .49298 L
.78851 .49449 L
.78851 .49611 L
.78851 .49699 L
.78851 .49791 L
.78851 .4987 L
.78851 .49956 L
.78851 .50048 L
.78851 .50131 L
.78851 .50227 L
.78851 .50318 L
.78851 .50479 L
.78851 .5057 L
.78851 .50654 L
.7885 .50945 L
.78849 .51264 L
.78848 .51598 L
.78847 .5191 L
.78844 .52529 L
.7884 .53205 L
.78835 .53802 L
.78829 .5444 L
.78813 .55649 L
.78794 .56777 L
Mistroke
.78764 .58094 L
.7872 .59533 L
.78664 .60908 L
.78599 .62187 L
.78421 .64738 L
.78283 .66216 L
.78126 .67616 L
.77694 .70548 L
.77144 .73294 L
.7638 .76191 L
.75271 .7939 L
.73891 .82458 L
.72028 .85666 L
.6989 .8853 L
.6751 .91033 L
.64452 .93499 L
.61289 .9538 L
.59483 .96203 L
.57741 .96844 L
.55768 .974 L
.54643 .97641 L
.53611 .97815 L
.52616 .97941 L
.52112 .9799 L
.51558 .98031 L
.51084 .98056 L
.50818 .98066 L
.50575 .98073 L
.50349 .98077 L
.50103 .9808 L
.49871 .98079 L
.49656 .98077 L
.4941 .98073 L
.49145 .98065 L
.48895 .98055 L
.48666 .98044 L
.48135 .9801 L
.47577 .97961 L
.46529 .97836 L
.45392 .97648 L
.43342 .9717 L
.41528 .96592 L
.39511 .95765 L
.37692 .94839 L
.34403 .92659 L
.31742 .90309 L
.29419 .87679 L
.27301 .84604 L
.25697 .81618 L
.24348 .78385 L
Mistroke
.2332 .75141 L
.22603 .72125 L
.22094 .69228 L
.21759 .66618 L
.21615 .65149 L
.21505 .63788 L
.21355 .61298 L
.21299 .60014 L
.21253 .58675 L
.21223 .57544 L
.21198 .56315 L
.21186 .55598 L
Mfstroke
.5 .21154 m
.50009 .21154 L
.50016 .21154 L
.50025 .21154 L
.50034 .21154 L
.50049 .21155 L
.50065 .21155 L
.50083 .21156 L
.50103 .21157 L
.50137 .21159 L
.50172 .21163 L
.50205 .21166 L
.5028 .21177 L
.50356 .21192 L
.50424 .21208 L
.50576 .21255 L
.50703 .21307 L
.50837 .21375 L
.51078 .2154 L
.51279 .21736 L
.51369 .21847 L
.51454 .21974 L
.51579 .22227 L
.51626 .22359 L
.51645 .22427 L
.51662 .22501 L
.51676 .22571 L
.51685 .22636 L
.51689 .22667 L
.51693 .227 L
.51695 .2273 L
.51697 .22762 L
.51698 .22779 L
.51699 .22795 L
.51699 .2281 L
.51699 .22819 L
.51699 .22826 L
.517 .22835 L
.517 .22839 L
.517 .22844 L
.517 .22852 L
.517 .2286 L
.517 .22865 L
.517 .2287 L
.517 .22875 L
.517 .2288 L
.51699 .22888 L
.51699 .22897 L
.51699 .22916 L
.51698 .22936 L
Mistroke
.51696 .22973 L
.51693 .23008 L
.5169 .23041 L
.5168 .23112 L
.51669 .23179 L
.51641 .23302 L
.516 .23431 L
.51554 .23546 L
.5143 .23778 L
.51279 .23979 L
.5109 .24164 L
.50884 .24312 L
.50771 .24374 L
.50645 .24433 L
.5053 .24475 L
.504 .24512 L
.50276 .24537 L
.50207 .24547 L
.50176 .24551 L
.50142 .24554 L
.50109 .24556 L
.50078 .24558 L
.50062 .24559 L
.50046 .24559 L
.50038 .2456 L
.50029 .2456 L
.50024 .2456 L
.5002 .2456 L
.50012 .2456 L
.50004 .2456 L
.49998 .2456 L
.4999 .2456 L
.49983 .2456 L
.49976 .2456 L
.49969 .2456 L
.49955 .24559 L
.49941 .24559 L
.49925 .24558 L
.49893 .24557 L
.49862 .24554 L
.49828 .24551 L
.49769 .24544 L
.49706 .24534 L
.49637 .24521 L
.49515 .24489 L
.49388 .24446 L
.4927 .24395 L
.49146 .24329 L
.48933 .24182 L
.48738 .23998 L
Mistroke
.4858 .23793 L
.48458 .23572 L
.48408 .23452 L
.48364 .23319 L
.48347 .23253 L
.48331 .2318 L
.48319 .2311 L
.48311 .23044 L
.48307 .2301 L
.48304 .22972 L
.48303 .22955 L
.48302 .22937 L
.48302 .22921 L
.48301 .22913 L
.48301 .22904 L
.48301 .22896 L
.48301 .22888 L
.48301 .2288 L
.483 .22873 L
.483 .22866 L
.483 .22859 L
.483 .22851 L
.483 .22843 L
.48301 .22835 L
.48301 .22827 L
.48301 .22819 L
.48301 .22811 L
.48302 .22793 L
.48302 .22777 L
.48304 .22742 L
.48307 .22704 L
.48315 .22636 L
.48325 .22569 L
.48336 .22509 L
.48368 .22382 L
.48414 .22245 L
.48468 .22119 L
.48538 .21989 L
.48708 .2175 L
.48911 .2155 L
.49136 .21391 L
.49261 .21323 L
.49401 .21263 L
.49549 .21215 L
.49619 .21197 L
.49692 .21182 L
.49761 .21171 L
.49798 .21166 L
.49837 .21162 L
.49874 .21159 L
Mistroke
.49907 .21157 L
.49923 .21156 L
.4994 .21155 L
.49948 .21155 L
.49957 .21155 L
.49965 .21154 L
.49972 .21154 L
.49981 .21154 L
.4999 .21154 L
.49999 .21154 L
.50008 .21154 L
.50016 .21154 L
.50025 .21154 L
.50032 .21154 L
.5004 .21155 L
.50059 .21155 L
.50079 .21156 L
.50114 .21158 L
.50147 .2116 L
.50177 .21163 L
.50246 .21172 L
.50321 .21185 L
.50392 .212 L
.50522 .21236 L
.50657 .21286 L
.50778 .21343 L
.51018 .21493 L
.51221 .21672 L
.5132 .21784 L
.51402 .21894 L
.51537 .22131 L
.51589 .22254 L
.51635 .22391 L
.51667 .22524 L
.5168 .22599 L
.51689 .22667 L
.51692 .22701 L
.51695 .22736 L
.51697 .22766 L
.51698 .22783 L
.51698 .22799 L
.51699 .22808 L
.51699 .22818 L
.51699 .22827 L
.51699 .22835 L
.51699 .22844 L
.51699 .22851 L
.51699 .2286 L
.51699 .22868 L
.51699 .22877 L
Mistroke
.51699 .22882 L
.51699 .22887 L
.51699 .22904 L
.51699 .22913 L
.51698 .22923 L
.51697 .22942 L
.51695 .22978 L
.51692 .23011 L
.51684 .23086 L
.51674 .23152 L
.5166 .23221 L
.51627 .23349 L
.51587 .23465 L
.51477 .23699 L
.51407 .23812 L
.51324 .23924 L
.51154 .24107 L
.50946 .24271 L
.50726 .24396 L
.50599 .2445 L
.50476 .24492 L
.50415 .24508 L
.50351 .24523 L
.5029 .24535 L
.50234 .24544 L
.50174 .24551 L
.5014 .24554 L
.50109 .24556 L
.50094 .24557 L
.50079 .24558 L
.50066 .24558 L
.50052 .24559 L
.50044 .24559 L
.50037 .24559 L
.5003 .24559 L
.50023 .2456 L
.50016 .2456 L
.50008 .2456 L
.5 .2456 L
.49995 .2456 L
.49991 .2456 L
.49983 .2456 L
.49976 .2456 L
.49968 .24559 L
.4996 .24559 L
.49943 .24559 L
.49927 .24558 L
.49897 .24557 L
.49868 .24555 L
.49805 .24548 L
Mistroke
.49735 .24539 L
.4967 .24527 L
.49611 .24515 L
.49481 .24478 L
.49364 .24436 L
.49242 .24381 L
.49014 .24244 L
.48816 .24079 L
.48651 .23892 L
.4857 .23778 L
.48505 .23667 L
.484 .2343 L
.48361 .23307 L
.48345 .23242 L
.4833 .2317 L
.48318 .23102 L
.4831 .23037 L
.48307 .23001 L
.48304 .22968 L
.48302 .22932 L
.48301 .22914 L
.48301 .22903 L
.48301 .22894 L
.48301 .22885 L
.48301 .22876 L
.48301 .22867 L
.483 .22862 L
.483 .22857 L
.48301 .22849 L
.48301 .22841 L
.48301 .22836 L
.48301 .22832 L
.48301 .22823 L
.48301 .22814 L
.48301 .22807 L
.48302 .2279 L
.48303 .22759 L
.48306 .22723 L
.48309 .22684 L
.48318 .22615 L
.48328 .22549 L
.48343 .22478 L
.48382 .22336 L
.48429 .22208 L
.48491 .22074 L
.4856 .21952 L
.48647 .21826 L
.48838 .21614 L
.48944 .21523 L
.49069 .21432 L
Mistroke
.49318 .21297 L
.49449 .21246 L
.49595 .21203 L
.49667 .21187 L
.49746 .21173 L
.49782 .21168 L
.49821 .21164 L
.49855 .2116 L
.49891 .21158 L
.49909 .21156 L
.4993 .21155 L
.49948 .21155 L
.49957 .21155 L
.49966 .21154 L
.49971 .21154 L
.49976 .21154 L
.49981 .21154 L
.49986 .21154 L
.49995 .21154 L
.50005 .21154 L
.5001 .21154 L
.50015 .21154 L
.50021 .21154 L
.50026 .21154 L
.50036 .21154 L
.50047 .21155 L
.50066 .21155 L
.50083 .21156 L
.50123 .21158 L
.50159 .21161 L
.50193 .21165 L
.50263 .21175 L
.50337 .21188 L
.50467 .2122 L
.50602 .21264 L
.50724 .21316 L
.50967 .21456 L
.51088 .21548 L
.51194 .21645 L
.51372 .21852 L
.51456 .21978 L
.51522 .22098 L
.5158 .22229 L
.51624 .22353 L
.51658 .22483 L
.51672 .22552 L
.51684 .22625 L
.51691 .2269 L
.51695 .22727 L
.51697 .2276 L
Mistroke
.51698 .22775 L
.51698 .22791 L
.51699 .228 L
.51699 .22809 L
.51699 .22817 L
.51699 .22825 L
.51699 .22833 L
.51699 .2284 L
.517 .22848 L
.517 .22857 L
.517 .22864 L
.51699 .22872 L
.51699 .2288 L
.51699 .22886 L
.51699 .22895 L
.51699 .22902 L
.51698 .2292 L
.51698 .22937 L
.51697 .22955 L
.51694 .22988 L
.51692 .23018 L
.51684 .2309 L
.51673 .23158 L
.51644 .23289 L
.51608 .23408 L
.51558 .23537 L
.51504 .23649 L
.51363 .23874 L
.51197 .24066 L
.50992 .24239 L
.50881 .24313 L
.50773 .24373 L
.50659 .24427 L
.50547 .24469 L
.50421 .24507 L
.50304 .24532 L
.50243 .24542 L
.50177 .2455 L
.5015 .24553 L
.50121 .24555 L
.50089 .24557 L
.50074 .24558 L
.50059 .24559 L
.50043 .24559 L
.50034 .24559 L
.50026 .2456 L
.50018 .2456 L
.50011 .2456 L
.50003 .2456 L
.49994 .2456 L
Mistroke
.49986 .2456 L
.49981 .2456 L
.49977 .2456 L
.49969 .2456 L
.49961 .24559 L
.49943 .24559 L
.49924 .24558 L
.49891 .24556 L
.49857 .24554 L
.49795 .24547 L
.49735 .24539 L
.49671 .24528 L
.49557 .24501 L
.49434 .24462 L
.49307 .24412 L
.4909 .24295 L
.48879 .24137 L
.487 .23954 L
.4862 .2385 L
.48541 .2373 L
.48423 .23492 L
.48378 .23366 L
.48359 .233 L
.48341 .23229 L
.48328 .23161 L
.48318 .23098 L
.48314 .23068 L
.4831 .23034 L
.48307 .23005 L
.48304 .22974 L
.48303 .22955 L
.48302 .22937 L
.48302 .22921 L
.48301 .22912 L
.48301 .22903 L
.48301 .22894 L
.48301 .22887 L
.48301 .22879 L
.483 .22872 L
.483 .22863 L
.483 .22856 L
.483 .22847 L
.48301 .22839 L
.48301 .2283 L
.48301 .22822 L
.48301 .22813 L
.48301 .22803 L
.48302 .22787 L
.48303 .2277 L
.48305 .22731 L
Mistroke
.48308 .22694 L
.48317 .22622 L
.48328 .22554 L
.48355 .22427 L
.48396 .22293 L
.48444 .22173 L
.48507 .22043 L
.48576 .21928 L
.4874 .21714 L
.48943 .21523 L
.49059 .21439 L
.49192 .21359 L
.49315 .21298 L
.49456 .21244 L
.49594 .21203 L
.49671 .21186 L
.49744 .21173 L
.49814 .21164 L
.4985 .21161 L
.49889 .21158 L
.49923 .21156 L
.49942 .21155 L
.49951 .21155 L
.49959 .21154 L
.49967 .21154 L
.49975 .21154 L
.49984 .21154 L
.49992 .21154 L
.5 .21154 L
.50009 .21154 L
.50017 .21154 L
.50024 .21154 L
.50033 .21154 L
.50042 .21154 L
.50059 .21155 L
.50077 .21156 L
.50096 .21157 L
.5013 .21159 L
.50162 .21162 L
.50235 .2117 L
.50312 .21183 L
.50451 .21215 L
.50578 .21255 L
.50714 .21312 L
.50834 .21373 L
.51071 .21535 L
.51269 .21724 L
.51357 .21831 L
.51443 .21957 L
.51569 .22203 L
Mistroke
.51616 .22331 L
.51637 .22397 L
.51655 .22471 L
.51669 .22537 L
.51681 .22608 L
.51687 .22647 L
.51691 .22683 L
.51694 .22717 L
.51696 .22753 L
.51698 .22785 L
.51699 .22804 L
.51699 .22813 L
.51699 .22821 L
.51699 .22829 L
.51699 .22837 L
.517 .22845 L
.517 .22852 L
.517 .2286 L
.517 .22868 L
.51699 .22876 L
.51699 .22885 L
.51699 .22893 L
.51699 .22902 L
.51698 .2292 L
.51698 .22937 L
.51697 .22953 L
.51694 .22989 L
.51691 .23027 L
.51683 .23096 L
.51671 .2317 L
.5164 .23303 L
.516 .2343 L
.51547 .23561 L
.51427 .23782 L
.51266 .23993 L
.51083 .24169 L
.50982 .24247 L
.50864 .24323 L
.50634 .24437 L
.50515 .2448 L
.50385 .24516 L
.5032 .24529 L
.5025 .24541 L
.50217 .24546 L
.50183 .2455 L
.50151 .24553 L
.50121 .24556 L
.5009 .24557 L
.50076 .24558 L
.5006 .24559 L
Mistroke
.50053 .24559 L
.50044 .24559 L
.50036 .24559 L
.50029 .2456 L
.50021 .2456 L
.50016 .2456 L
.50012 .2456 L
.50004 .2456 L
.49999 .2456 L
.49995 .2456 L
.49988 .2456 L
.4998 .2456 L
.49972 .2456 L
.49965 .2456 L
.49952 .24559 L
.49938 .24559 L
.49909 .24557 L
.49877 .24555 L
.49844 .24553 L
.49812 .24549 L
.49753 .24542 L
.4969 .24531 L
.49621 .24517 L
.49499 .24484 L
.49371 .24439 L
.49253 .24387 L
.4913 .2432 L
.48917 .24169 L
.48724 .23982 L
.48568 .23774 L
.48448 .23551 L
.48399 .2343 L
.48358 .23295 L
.48341 .23228 L
.48327 .23154 L
.48316 .23084 L
.48312 .23053 L
.48308 .23019 L
.48305 .22984 L
.48303 .22953 L
.48302 .22923 L
.48301 .22907 L
.48301 .229 L
.48301 .22891 L
.48301 .22886 L
.48301 .22881 L
.483 .22872 L
.483 .22864 L
.483 .22855 L
.483 .22851 L
Mistroke
.483 .22846 L
.483 .22837 L
.48301 .22832 L
.48301 .22827 L
.48301 .22818 L
.48301 .22801 L
.48302 .22785 L
.48304 .22749 L
.48306 .22717 L
.48309 .22683 L
.48317 .22621 L
.48329 .22548 L
.48342 .22481 L
.48376 .22353 L
.48425 .22217 L
.48487 .22081 L
.48554 .21962 L
.48718 .21739 L
.48923 .21539 L
.49151 .21382 L
.49278 .21315 L
.49419 .21257 L
.49554 .21214 L
.49684 .21184 L
.49758 .21171 L
.49795 .21166 L
.49829 .21163 L
.49863 .21159 L
.49894 .21157 L
.49928 .21155 L
.49946 .21155 L
.49955 .21155 L
.49964 .21154 L
.49973 .21154 L
.49982 .21154 L
.4999 .21154 L
.49998 .21154 L
.50007 .21154 L
.50016 .21154 L
.50025 .21154 L
.5003 .21154 L
.50035 .21154 L
.50054 .21155 L
.50064 .21155 L
.50074 .21156 L
.5011 .21157 L
.50141 .2116 L
.50175 .21163 L
.50244 .21172 L
.50318 .21184 L
Mistroke
.50384 .21198 L
.50531 .21239 L
.50661 .21288 L
.50797 .21353 L
.50919 .21424 L
.51044 .21513 L
.51252 .21705 L
.51349 .2182 L
.51427 .21932 L
.51557 .22174 L
.51606 .22298 L
.51647 .22437 L
.51663 .22506 L
.51676 .22571 L
.51687 .22646 L
.5169 .22679 L
.51694 .22715 L
.51696 .2275 L
.51698 .22782 L
.51699 .228 L
.51699 .22817 L
.51699 .22826 L
.51699 .22831 L
.517 .22836 L
.517 .2284 L
.517 .22845 L
.517 .22853 L
.517 .22861 L
.517 .2287 L
.517 .22877 L
.51699 .22885 L
.51699 .22893 L
.51699 .22903 L
.51699 .22919 L
.51698 .22935 L
.51697 .22951 L
.51695 .2298 L
.51693 .23012 L
.51689 .23046 L
.5168 .23116 L
.51669 .2318 L
.51656 .23239 L
.5162 .23371 L
.51578 .23489 L
.51461 .23727 L
.51316 .23934 L
.51132 .24128 L
.50929 .24283 L
.50715 .24402 L
.506 .2445 L
Mistroke
.50473 .24493 L
.50348 .24524 L
.50284 .24536 L
.50214 .24546 L
.5018 .2455 L
.50149 .24553 L
.5012 .24556 L
.50089 .24558 L
.50073 .24558 L
.50055 .24559 L
.50048 .24559 L
.50039 .24559 L
.50032 .2456 L
.50024 .2456 L
.5002 .2456 L
.50015 .2456 L
.50011 .2456 L
.50006 .2456 L
.50001 .2456 L
.49996 .2456 L
.49992 .2456 L
.49988 .2456 L
.4998 .2456 L
.49976 .2456 L
.49971 .2456 L
.49963 .2456 L
.49954 .24559 L
.49938 .24559 L
.49922 .24558 L
.49887 .24556 L
.49857 .24554 L
.49824 .24551 L
.49763 .24543 L
.49706 .24534 L
.49579 .24507 L
.49464 .24473 L
.4935 .2443 L
.49228 .24374 L
.49004 .24237 L
.48809 .24072 L
.48631 .23866 L
.48554 .23751 L
.48491 .2364 L
.48434 .2352 L
.4839 .23403 L
.48354 .23282 L
.48338 .23212 L
.48325 .23145 L
.48315 .2308 L
.48311 .23045 L
Mistroke
.48307 .23008 L
.48304 .22974 L
.48302 .22942 L
.48302 .22927 L
.48301 .22911 L
.48301 .22903 L
.48301 .22895 L
.48301 .22888 L
.483 .22881 L
.483 .22873 L
.483 .22868 L
.483 .22864 L
.483 .22856 L
.483 .22847 L
.483 .22839 L
.483 .22831 L
.48301 .22823 L
.48301 .22816 L
.48301 .22799 L
.48302 .2278 L
.48304 .22746 L
.48306 .22714 L
.48309 .2268 L
.48317 .2262 L
.48328 .22549 L
.48344 .22474 L
.48381 .22338 L
.48429 .22207 L
.48492 .22072 L
.48634 .21844 L
.48824 .21627 L
.49041 .21451 L
.49171 .2137 L
.49301 .21304 L
.49424 .21255 L
.49563 .21211 L
.4963 .21195 L
.49703 .2118 L
.49744 .21173 L
.49781 .21168 L
.49817 .21164 L
.49855 .2116 L
.49892 .21157 L
.49926 .21155 L
.49943 .21155 L
.49951 .21155 L
.4996 .21154 L
.49968 .21154 L
.49977 .21154 L
.49985 .21154 L
Mistroke
.49993 .21154 L
.50002 .21154 L
.50007 .21154 L
.50012 .21154 L
.50021 .21154 L
.5003 .21154 L
.5004 .21154 L
.50049 .21155 L
.50065 .21155 L
.50085 .21156 L
.50103 .21157 L
.50143 .2116 L
.50177 .21163 L
.50214 .21167 L
.50279 .21177 L
.50357 .21192 L
.50426 .21208 L
.50559 .21249 L
.50699 .21305 L
.50825 .21368 L
.50956 .21449 L
.51176 .21627 L
.51365 .21842 L
.5151 .22075 L
.5157 .22204 L
.5162 .22343 L
.51639 .22407 L
.51657 .22476 L
.5167 .22541 L
.5168 .22601 L
.5169 .22672 L
.51693 .22709 L
.51696 .22748 L
.51697 .22764 L
.51698 .22782 L
.51699 .22799 L
.51699 .22814 L
.51699 .22823 L
.517 .22832 L
.517 .22836 L
.517 .22841 L
.517 .22846 L
.517 .22851 L
.517 .2286 L
.517 .22868 L
.517 .22877 L
.517 .22882 L
.51699 .22887 L
.51699 .22904 L
.51699 .22914 L
Mistroke
.51698 .22923 L
.51697 .22957 L
.51695 .22988 L
.51692 .2302 L
.51684 .23088 L
.51672 .23161 L
.51644 .2329 L
.51603 .23424 L
.5155 .23556 L
.5149 .23676 L
.51353 .23888 L
.51175 .24088 L
.50978 .2425 L
.50869 .24321 L
.50746 .24387 L
.50633 .24437 L
.50506 .24483 L
.50382 .24516 L
.50313 .24531 L
.50249 .24542 L
.50217 .24546 L
.50182 .2455 L
.50151 .24553 L
.50119 .24556 L
.50089 .24558 L
.50073 .24558 L
.50057 .24559 L
.50042 .24559 L
.50029 .2456 L
.50022 .2456 L
.50015 .2456 L
.50007 .2456 L
.5 .2456 L
.49991 .2456 L
.49987 .2456 L
.49983 .2456 L
.49975 .2456 L
.49967 .2456 L
.4995 .24559 L
.49941 .24559 L
.49932 .24559 L
.49899 .24557 L
.49868 .24555 L
.49811 .24549 L
.4975 .24541 L
.49684 .2453 L
.49625 .24518 L
.49494 .24483 L
.49377 .24441 L
.49254 .24387 L
Mistroke
.49025 .24252 L
.48826 .24088 L
.48658 .23902 L
.48577 .23788 L
.48511 .23678 L
.48404 .23441 L
.48364 .23319 L
.48347 .23254 L
.48332 .23182 L
.4832 .23118 L
.48311 .23049 L
.48307 .2301 L
.48304 .22975 L
.48303 .22958 L
.48302 .22939 L
.48301 .22922 L
.48301 .22905 L
.48301 .22897 L
.48301 .22888 L
.483 .22879 L
.483 .22874 L
.483 .22869 L
.483 .2286 L
.483 .22852 L
.483 .22848 L
.483 .22843 L
.483 .22835 L
.483 .22827 L
.48301 .22818 L
.48301 .22801 L
.48302 .22785 L
.48302 .2277 L
.48305 .22734 L
.48307 .22701 L
.48316 .22626 L
.48326 .22559 L
.48339 .22497 L
.48375 .22357 L
.48423 .22222 L
.48476 .22103 L
.48622 .2186 L
.48799 .21651 L
.48902 .21557 L
.49024 .21463 L
.49269 .21319 L
.49399 .21264 L
.49543 .21216 L
.49614 .21198 L
.49693 .21182 L
.49768 .2117 L
Mistroke
.49838 .21162 L
.49875 .21158 L
.49894 .21157 L
.49915 .21156 L
.49933 .21155 L
.49942 .21155 L
.49953 .21154 L
.49962 .21154 L
.49971 .21154 L
.49979 .21154 L
.49987 .21154 L
.49995 .21154 L
.50004 .21154 L
.50013 .21154 L
.50021 .21154 L
.50029 .21154 L
.50036 .21154 L
.50052 .21155 L
.50069 .21155 L
.50087 .21156 L
.50123 .21158 L
.50161 .21161 L
.50197 .21165 L
.50265 .21175 L
.50337 .21188 L
.50414 .21205 L
.50553 .21246 L
.50695 .21302 L
.50935 .21434 L
.51049 .21516 L
.51162 .21614 L
.51262 .21715 L
.51359 .21834 L
.51509 .22073 L
.51568 .22199 L
.51619 .22337 L
.51639 .22406 L
.51658 .22481 L
.51671 .22547 L
.51683 .22619 L
.51688 .22654 L
.51692 .2269 L
.51694 .22722 L
.51697 .22757 L
.51698 .22777 L
.51699 .22796 L
.51699 .22814 L
.51699 .22823 L
.517 .22828 L
.517 .22833 L
Mistroke
.517 .22842 L
.517 .2285 L
.517 .22859 L
.517 .22864 L
.517 .22868 L
.517 .22877 L
.517 .22884 L
.51699 .22893 L
.51699 .22902 L
.51699 .22918 L
.51698 .22934 L
.51696 .22968 L
.51694 .23002 L
.5169 .23039 L
.51682 .23104 L
.51672 .23163 L
.51644 .23289 L
.51603 .23423 L
.51554 .23546 L
.51492 .23672 L
.51357 .23882 L
.51182 .2408 L
.50989 .24242 L
.50882 .24313 L
.5076 .2438 L
.50638 .24435 L
.50524 .24477 L
.50402 .24512 L
.50334 .24527 L
.5027 .24538 L
.50211 .24547 L
.50148 .24554 L
.50115 .24556 L
.50085 .24558 L
.50067 .24559 L
.50051 .24559 L
.50042 .2456 L
.50032 .2456 L
.50028 .2456 L
.50023 .2456 L
.50015 .2456 L
.50007 .2456 L
.50002 .2456 L
.49998 .2456 L
.49993 .2456 L
.49989 .2456 L
.49985 .2456 L
.4998 .2456 L
.49972 .2456 L
.49965 .2456 L
Mistroke
.49948 .24559 L
.49932 .24559 L
.49914 .24558 L
.49877 .24556 L
.49845 .24553 L
.4981 .24549 L
.49748 .24541 L
.49687 .24531 L
.49621 .24517 L
.4949 .24482 L
.49371 .24439 L
.49247 .24384 L
.49016 .24246 L
.48815 .24078 L
.48648 .23889 L
.48573 .23783 L
.48501 .2366 L
.48441 .23536 L
.48395 .23419 L
.48357 .23293 L
.4834 .23222 L
.48326 .23155 L
.48317 .23093 L
.48309 .23026 L
.48306 .22992 L
.48303 .22959 L
.48302 .22942 L
.48301 .22923 L
.48301 .22914 L
.48301 .22903 L
.48301 .22893 L
.483 .22884 L
.483 .22876 L
.483 .22867 L
.483 .22858 L
.483 .22853 L
.483 .22848 L
.483 .2284 L
.483 .22832 L
.48301 .22823 L
.48301 .22814 L
.48301 .22798 L
.48302 .22783 L
.48304 .2275 L
.48306 .22713 L
.48309 .2268 L
.48319 .22606 L
.4833 .22537 L
.48344 .22474 L
.48382 .22334 L
Mistroke
.48427 .2221 L
.48488 .22078 L
.4864 .21835 L
.48824 .21627 L
.48931 .21533 L
.49056 .21441 L
.49308 .21301 L
.49441 .21248 L
.49511 .21226 L
.49588 .21205 L
.4966 .21188 L
.49726 .21176 L
.49791 .21167 L
.49826 .21163 L
.49859 .2116 L
.49895 .21157 L
.49928 .21155 L
.49947 .21155 L
.49964 .21154 L
.49973 .21154 L
.49978 .21154 L
.49982 .21154 L
.49987 .21154 L
.49993 .21154 L
.50002 .21154 L
.50011 .21154 L
.50019 .21154 L
.50028 .21154 L
.50035 .21154 L
.50054 .21155 L
.50071 .21155 L
.50102 .21157 L
.50136 .21159 L
.50172 .21162 L
.50205 .21166 L
.5028 .21177 L
.50353 .21191 L
.5043 .21209 L
.50578 .21255 L
.50713 .21311 L
.50954 .21447 L
.51069 .21533 L
.51182 .21633 L
.5136 .21835 L
.51444 .21959 L
.51511 .22077 L
.51571 .22206 L
.51616 .22329 L
.51652 .22456 L
.51667 .22524 L
Mistroke
.5168 .22597 L
.51689 .22668 L
.51693 .22708 L
.51696 .22744 L
.51698 .22777 L
.51699 .22795 L
.51699 .22812 L
.51699 .22821 L
.517 .2283 L
.517 .22838 L
.517 .22846 L
.517 .22851 L
.517 .22855 L
.517 .22861 L
.517 .22865 L
.517 .22874 L
.517 .22879 L
.517 .22883 L
.51699 .22892 L
.51699 .229 L
.51699 .22915 L
.51698 .22932 L
.51697 .2295 L
.51695 .22982 L
.51693 .23012 L
.51685 .2308 L
.51674 .23152 L
.51646 .23281 L
.51611 .234 L
.51563 .23527 L
.5151 .23639 L
.51371 .23863 L
.51208 .24055 L
.51008 .24229 L
.50792 .24364 L
.50667 .24423 L
.50546 .2447 L
.50422 .24507 L
.50305 .24532 L
.50243 .24543 L
.50185 .2455 L
.50153 .24553 L
.50122 .24556 L
.50104 .24557 L
.50086 .24558 L
.5007 .24559 L
.50053 .24559 L
.50045 .2456 L
.50037 .2456 L
.50029 .2456 L
Mistroke
.50022 .2456 L
.50015 .2456 L
.50008 .2456 L
.5 .2456 L
.49993 .2456 L
.49988 .2456 L
.49984 .2456 L
.49976 .2456 L
.49968 .2456 L
.49958 .2456 L
.49941 .24559 L
.49926 .24559 L
.49892 .24557 L
.49861 .24554 L
.49791 .24547 L
.49728 .24538 L
.4967 .24528 L
.4954 .24497 L
.49426 .2446 L
.49303 .2441 L
.49075 .24286 L
.48875 .24133 L
.48688 .23939 L
.48538 .23725 L
.48425 .23497 L
.4838 .23374 L
.48343 .23237 L
.48329 .23169 L
.48317 .23095 L
.48312 .23061 L
.48308 .23024 L
.48305 .2299 L
.48303 .22958 L
.48302 .22943 L
.48302 .22925 L
.48301 .22909 L
.48301 .22894 L
.483 .22885 L
.483 .22876 L
.483 .22869 L
.483 .2286 L
.483 .22856 L
.483 .22851 L
.483 .22846 L
.483 .22842 L
.483 .22833 L
.483 .22824 L
.48301 .22816 L
.48301 .22808 L
.48301 .22791 L
Mistroke
.48302 .22775 L
.48303 .22759 L
.48305 .2273 L
.48307 .22698 L
.48315 .22629 L
.48325 .22566 L
.48356 .22424 L
.48394 .22297 L
.48448 .22162 L
.48515 .22028 L
.48586 .21911 L
.48759 .21693 L
.48972 .21501 L
.49205 .21351 L
.49335 .21289 L
.49478 .21236 L
.49544 .21216 L
.49615 .21198 L
.49683 .21184 L
.49746 .21173 L
.4982 .21163 L
.49858 .2116 L
.49878 .21158 L
.499 .21157 L
.4992 .21156 L
.49939 .21155 L
.49957 .21154 L
.49966 .21154 L
.49972 .21154 L
.49976 .21154 L
.49986 .21154 L
.49994 .21154 L
.50003 .21154 L
.50008 .21154 L
.50012 .21154 L
.5002 .21154 L
.50029 .21154 L
.50038 .21154 L
.50046 .21154 L
.50064 .21155 L
.5008 .21156 L
.50118 .21158 L
.50154 .21161 L
.50193 .21165 L
.50263 .21174 L
.50326 .21185 L
.50462 .21218 L
.50606 .21265 L
.50738 .21323 L
.50872 .21395 L
Mistroke
.51095 .21554 L
.51299 .21758 L
.51459 .21983 L
.5153 .22115 L
.51586 .22245 L
.51631 .22377 L
.51662 .22501 L
.51675 .22567 L
.51685 .22629 L
.51692 .22697 L
.51696 .22735 L
.51697 .22754 L
.51698 .22771 L
.51698 .22786 L
.51699 .22803 L
.51699 .22812 L
.517 .22821 L
.517 .22829 L
.517 .22838 L
.517 .22845 L
.517 .22853 L
.517 .22861 L
.517 .22868 L
.517 .22876 L
.517 .22884 L
.517 .22893 L
.51699 .229 L
.51699 .22919 L
.51698 .22936 L
.51696 .22969 L
.51694 .23004 L
.5169 .23042 L
.51682 .23106 L
.5167 .23176 L
.51637 .23315 L
.51597 .2344 L
.51544 .2357 L
.51409 .23809 L
.51246 .24015 L
.51063 .24186 L
.50961 .24262 L
.50843 .24336 L
.50614 .24445 L
.50496 .24486 L
.50435 .24504 L
.50366 .2452 L
.50305 .24533 L
.50239 .24543 L
.50203 .24548 L
.5017 .24552 L
Mistroke
.50138 .24555 L
.50105 .24557 L
.50074 .24559 L
.50057 .24559 L
.50048 .2456 L
.5004 .2456 L
.50033 .2456 L
.50026 .2456 L
.50018 .2456 L
.50012 .2456 L
.50004 .2456 L
.49997 .2456 L
.49989 .2456 L
.49981 .2456 L
.49973 .2456 L
.49965 .2456 L
.49948 .24559 L
.49932 .24559 L
.49917 .24558 L
.49884 .24556 L
.49848 .24553 L
.49783 .24546 L
.49712 .24536 L
.49585 .24509 L
.49463 .24473 L
.49336 .24425 L
.49118 .24313 L
.48905 .2416 L
.48724 .23982 L
.48642 .23882 L
.48561 .23764 L
.48439 .2353 L
.48391 .23407 L
.48351 .23271 L
.48336 .23204 L
.48322 .23129 L
.48312 .23059 L
.48306 .22993 L
.48303 .22961 L
.48302 .22943 L
.48301 .22926 L
.48301 .22911 L
.48301 .22903 L
.483 .22894 L
.483 .22886 L
.483 .22878 L
.483 .22871 L
.483 .22864 L
.483 .22856 L
.483 .22847 L
Mistroke
.483 .22842 L
.483 .22837 L
.483 .22828 L
.483 .2282 L
.48301 .22811 L
.48301 .22796 L
.48302 .22777 L
.48303 .2276 L
.48305 .22722 L
.48308 .2269 L
.48312 .22655 L
.48321 .22593 L
.48334 .22519 L
.48349 .22452 L
.48385 .22325 L
.48436 .22189 L
.48501 .22053 L
.48571 .21935 L
.4874 .21713 L
.4895 .21517 L
.49182 .21364 L
.49312 .21299 L
.49454 .21244 L
.49591 .21204 L
.49654 .21189 L
.49722 .21177 L
.49761 .2117 L
.49798 .21166 L
.49832 .21162 L
.4987 .21159 L
.49903 .21156 L
.49919 .21156 L
.49935 .21155 L
.49943 .21155 L
.49953 .21154 L
.49961 .21154 L
.49969 .21154 L
.49978 .21154 L
.49983 .21154 L
.49987 .21154 L
.49996 .21154 L
.50005 .21154 L
.50014 .21154 L
.50022 .21154 L
.50031 .21154 L
.5004 .21154 L
.50056 .21155 L
.50074 .21155 L
.50093 .21156 L
.50113 .21157 L
Mistroke
.50149 .2116 L
.50222 .21168 L
.50301 .21181 L
.50373 .21195 L
.50438 .21211 L
.50583 .21257 L
.5071 .21309 L
.50843 .21378 L
.51083 .21544 L
.51283 .21739 L
.51371 .2185 L
.51456 .21977 L
.51581 .2223 L
.51626 .22361 L
.51645 .22429 L
.51663 .22503 L
.51676 .22573 L
.51686 .22637 L
.51689 .22667 L
.51693 .22701 L
.51695 .22731 L
.51697 .22762 L
.51698 .22781 L
.51699 .22799 L
.51699 .22816 L
.517 .22824 L
.517 .22829 L
.517 .22833 L
.517 .22842 L
.517 .2285 L
.517 .22858 L
.517 .22867 L
.517 .22875 L
.517 .22883 L
.517 .2289 L
.51699 .22898 L
.51699 .22916 L
.51698 .22933 L
.51696 .22972 L
.51693 .23005 L
.5169 .23041 L
.51682 .23105 L
.5167 .23174 L
.51643 .23295 L
.516 .23432 L
.51549 .23558 L
.51427 .23783 L
.51263 .23997 L
.51077 .24175 L
.50875 .24317 L
Mistroke
.50755 .24383 L
.50642 .24434 L
.5052 .24479 L
.50404 .24511 L
.50284 .24536 L
.5022 .24546 L
.50185 .2455 L
.50152 .24553 L
.5012 .24556 L
.50086 .24558 L
.50068 .24559 L
.50051 .24559 L
.50042 .2456 L
.50033 .2456 L
.50028 .2456 L
.50023 .2456 L
.50019 .2456 L
.50014 .2456 L
.50006 .2456 L
.49999 .2456 L
.49994 .2456 L
.4999 .2456 L
.49981 .2456 L
.49977 .2456 L
.49973 .2456 L
.49965 .2456 L
.49947 .24559 L
.4993 .24559 L
.49914 .24558 L
.49885 .24556 L
.49855 .24554 L
.49822 .24551 L
.49756 .24543 L
.49696 .24533 L
.49639 .24522 L
.49513 .24489 L
.49399 .2445 L
.49276 .24398 L
.49166 .24341 L
.48959 .24204 L
.48769 .24031 L
.48611 .23839 L
.48536 .23723 L
.48475 .2361 L
.48421 .23487 L
.48379 .23369 L
.48345 .23246 L
.48331 .2318 L
.48319 .23108 L
.4831 .23039 L
Mistroke
.48306 .23 L
.48303 .22964 L
.48302 .22932 L
.48301 .22914 L
.483 .22897 L
.483 .22888 L
.483 .22879 L
.483 .22871 L
.483 .22862 L
.483 .22858 L
.483 .22853 L
.483 .22848 L
.483 .22843 L
.483 .22835 L
.483 .2283 L
.483 .22826 L
.48301 .22809 L
.48301 .22793 L
.48302 .22775 L
.48303 .22758 L
.48305 .22728 L
.48308 .22696 L
.48316 .22622 L
.48327 .22554 L
.48355 .22427 L
.48397 .22289 L
.48447 .22163 L
.48513 .22031 L
.48676 .21788 L
.48871 .21583 L
.4909 .21418 L
.49213 .21347 L
.49351 .21283 L
.49497 .2123 L
.49565 .2121 L
.49639 .21192 L
.49707 .21179 L
.49782 .21168 L
.49816 .21164 L
.49851 .2116 L
.49885 .21157 L
.49916 .21156 L
.49933 .21155 L
.49951 .21154 L
.4996 .21154 L
.4997 .21154 L
.4998 .21154 L
.49988 .21154 L
.49996 .21154 L
.50004 .21154 L
Mistroke
.50012 .21154 L
.50021 .21154 L
.5003 .21154 L
.50039 .21154 L
.50055 .21154 L
.50073 .21155 L
.50093 .21156 L
.50127 .21158 L
.50165 .21162 L
.50206 .21166 L
.50279 .21177 L
.50345 .21189 L
.50492 .21226 L
.50622 .21272 L
.50759 .21333 L
.50894 .21408 L
.51009 .21486 L
.51221 .21671 L
.5132 .21783 L
.51401 .21892 L
.51537 .22129 L
.51589 .22251 L
.51634 .22388 L
.51666 .2252 L
.5168 .22595 L
.51685 .22628 L
.51689 .22663 L
.51692 .22696 L
.51695 .22731 L
.51697 .22764 L
.51698 .22779 L
.51699 .22795 L
.51699 .22812 L
.517 .22822 L
.517 .2283 L
.517 .22839 L
.517 .22846 L
.517 .22855 L
.517 .22863 L
.517 .22872 L
.517 .22877 L
.517 .22882 L
.517 .2289 L
.51699 .22899 L
.51699 .22917 L
.51698 .22937 L
.51696 .22973 L
.51693 .23006 L
.51685 .23081 L
.51675 .23147 L
Mistroke
.51662 .23216 L
.51625 .23356 L
.51581 .23484 L
.51468 .23716 L
.51397 .23827 L
.51313 .23939 L
.51141 .24119 L
.50933 .24281 L
.50712 .24403 L
.50585 .24456 L
.50462 .24496 L
.50402 .24512 L
.50337 .24526 L
.50276 .24538 L
.5022 .24546 L
.5016 .24553 L
.50129 .24555 L
.50096 .24558 L
.50081 .24558 L
.50066 .24559 L
.50053 .24559 L
.50039 .2456 L
.50031 .2456 L
.50023 .2456 L
.50015 .2456 L
.50007 .2456 L
.5 .2456 L
.49993 .2456 L
.49986 .2456 L
.49978 .2456 L
.4997 .2456 L
.49962 .2456 L
.49944 .24559 L
.49928 .24559 L
.49913 .24558 L
.49879 .24556 L
.49842 .24553 L
.49775 .24545 L
.49714 .24536 L
.49595 .24511 L
.49467 .24474 L
.49348 .2443 L
.49225 .24373 L
.48997 .24232 L
.48799 .24062 L
.48634 .2387 L
.48561 .23764 L
.4849 .2364 L
.48432 .23516 L
.48388 .23398 L
Mistroke
.48351 .23272 L
.48335 .232 L
.48322 .23133 L
.48313 .23071 L
.48306 .23005 L
.48303 .22967 L
.48302 .22948 L
.48302 .2293 L
.48301 .22915 L
.483 .22898 L
.483 .22889 L
.483 .22881 L
.483 .22872 L
.483 .22867 L
.483 .22863 L
.483 .22855 L
.483 .22847 L
.483 .22839 L
.483 .2283 L
.483 .22821 L
.48301 .22811 L
.48301 .22795 L
.48302 .22779 L
.48302 .22765 L
.48305 .22732 L
.48308 .22695 L
.48311 .22662 L
.48321 .22589 L
.48333 .22521 L
.48347 .22458 L
.48387 .22318 L
.48433 .22195 L
.48496 .22063 L
.48649 .21822 L
.48835 .21616 L
.48943 .21523 L
.49068 .21432 L
.49321 .21295 L
.49455 .21244 L
.49601 .21201 L
.49674 .21185 L
.49754 .21171 L
.49791 .21166 L
.4983 .21162 L
.49867 .21159 L
.49901 .21156 L
.49918 .21156 L
.49936 .21155 L
.49945 .21154 L
.49954 .21154 L
Mistroke
.49962 .21154 L
.4997 .21154 L
.49979 .21154 L
.49988 .21154 L
.49997 .21154 L
.50005 .21154 L
.50015 .21154 L
.50024 .21154 L
.50029 .21154 L
.50034 .21154 L
.50044 .21154 L
.50061 .21155 L
.50077 .21155 L
.50113 .21157 L
.50144 .2116 L
.50177 .21163 L
.50246 .21171 L
.50319 .21184 L
.50449 .21214 L
.50595 .21261 L
.5073 .21318 L
.50969 .21457 L
.51082 .21543 L
.51194 .21644 L
.5137 .21848 L
.51453 .21972 L
.51519 .22091 L
.51577 .2222 L
.51621 .22343 L
.51656 .2247 L
.5167 .22538 L
.51682 .22611 L
.51691 .22682 L
.51695 .22721 L
.51697 .22758 L
.51698 .22773 L
.51699 .2279 L
.51699 .228 L
.51699 .22808 L
.517 .22816 L
.517 .22825 L
.517 .22834 L
.517 .22843 L
.517 .22848 L
.517 .22853 L
.517 .22862 L
.517 .2287 L
.517 .22878 L
.517 .22887 L
.517 .22896 L
Mistroke
.51699 .22914 L
.51698 .2293 L
.51697 .22961 L
.51694 .22995 L
.51691 .23031 L
.51683 .23095 L
.51674 .23154 L
.51647 .23278 L
.51607 .23411 L
.51561 .23533 L
.515 .23658 L
.51353 .23888 L
.5118 .24083 L
.50989 .24242 L
.50873 .24318 L
.50764 .24379 L
.50644 .24433 L
.50531 .24475 L
.50412 .2451 L
.50344 .24525 L
.50281 .24537 L
.50223 .24546 L
.50161 .24553 L
.50126 .24556 L
.50092 .24558 L
.50077 .24559 L
.50062 .24559 L
.50053 .2456 L
.50044 .2456 L
.50036 .2456 L
.50029 .2456 L
.50021 .2456 L
.50013 .2456 L
.50009 .2456 L
.50005 .2456 L
.49997 .2456 L
.49989 .2456 L
.49981 .2456 L
.49973 .2456 L
.49964 .2456 L
.49949 .2456 L
.49936 .24559 L
.49904 .24558 L
.49871 .24555 L
.4984 .24553 L
.49771 .24545 L
.49709 .24535 L
.49651 .24524 L
.49521 .24491 L
.49396 .24449 L
Mistroke
.49285 .24402 L
.49059 .24275 L
.48861 .24121 L
.48676 .23925 L
.48528 .2371 L
.48418 .23481 L
.48375 .23358 L
.48339 .23221 L
.48326 .23153 L
.48314 .23079 L
.4831 .23044 L
.48307 .23008 L
.48304 .22977 L
.48303 .2296 L
.48302 .22942 L
.48301 .22926 L
.48301 .22908 L
.483 .22899 L
.483 .2289 L
.483 .22881 L
.483 .22873 L
.483 .22865 L
.483 .22857 L
.483 .2285 L
.483 .22842 L
.483 .22834 L
.483 .22825 L
.483 .22817 L
.48301 .22809 L
.48301 .22791 L
.48302 .22774 L
.48304 .22735 L
.48307 .22702 L
.48311 .22666 L
.4832 .22595 L
.48334 .22519 L
.48367 .22382 L
.48412 .22249 L
.4847 .22113 L
.48607 .21881 L
.48791 .21659 L
.49003 .21477 L
.49132 .21392 L
.4926 .21323 L
.49381 .2127 L
.4952 .21223 L
.49659 .21188 L
.49737 .21174 L
.49811 .21164 L
.49846 .2116 L
Mistroke
.49886 .21157 L
.49904 .21156 L
.49923 .21155 L
.49941 .21154 L
.49958 .21154 L
.49966 .21154 L
.49975 .21154 L
.49983 .21154 L
.49991 .21153 L
.5 .21153 L
.50005 .21153 L
.5001 .21153 L
.50019 .21154 L
.50027 .21154 L
.50035 .21154 L
.50043 .21154 L
.50058 .21154 L
.50075 .21155 L
.50092 .21156 L
.50128 .21158 L
.50166 .21162 L
.50233 .21169 L
.50304 .21181 L
.50382 .21197 L
.50519 .21235 L
.50662 .21288 L
.50801 .21354 L
.50926 .21428 L
.51145 .21598 L
.51343 .21812 L
.51427 .2193 L
.51495 .22046 L
.51556 .22169 L
.51603 .2229 L
.51645 .22425 L
.51673 .22551 L
.51683 .22617 L
.51688 .22653 L
.51692 .22687 L
.51695 .22719 L
.51697 .22754 L
.51698 .22769 L
.51699 .22785 L
.51699 .22799 L
.517 .22814 L
.517 .22823 L
.517 .22831 L
.517 .22839 L
.517 .22848 L
.517 .22856 L
Mistroke
.517 .22863 L
.517 .22871 L
.517 .22879 L
.517 .22888 L
.517 .22897 L
.51699 .22915 L
.51698 .22933 L
.51698 .22949 L
.51696 .2298 L
.51693 .23009 L
.51686 .23073 L
.51676 .23141 L
.51665 .23202 L
.51631 .23339 L
.51591 .23459 L
.51537 .23586 L
.51403 .23819 L
.51243 .24019 L
.51044 .24201 L
.50935 .24279 L
.50829 .24344 L
.50605 .24449 L
.50479 .24491 L
.50363 .24521 L
.50304 .24533 L
.50241 .24543 L
.50208 .24548 L
.50172 .24552 L
.50141 .24555 L
.50108 .24557 L
.5009 .24558 L
.50074 .24559 L
.50059 .24559 L
.50051 .2456 L
.50042 .2456 L
.50034 .2456 L
.50027 .2456 L
.5002 .2456 L
.50013 .2456 L
.50005 .2456 L
.49998 .2456 L
.4999 .2456 L
.49982 .2456 L
.49978 .2456 L
.49973 .2456 L
.49965 .2456 L
.49956 .2456 L
.49946 .2456 L
.49928 .24559 L
.49912 .24558 L
Mistroke
.49881 .24556 L
.49848 .24554 L
.49783 .24546 L
.49712 .24536 L
.49586 .24509 L
.49464 .24473 L
.49337 .24425 L
.49119 .24314 L
.48907 .24162 L
.48726 .23985 L
.48563 .23767 L
.48491 .23641 L
Mfstroke
.5 .40385 m
.4998 .40385 L
.49962 .40384 L
.49941 .40384 L
.49921 .40384 L
.49886 .40384 L
.49847 .40383 L
.49805 .40382 L
.49761 .40381 L
.4968 .40378 L
.49597 .40374 L
.4952 .40369 L
.49343 .40356 L
.49163 .40338 L
.48997 .40317 L
.48624 .40258 L
.48299 .40191 L
.47943 .40102 L
.47239 .39876 L
.46554 .39592 L
.45817 .39217 L
.45097 .38779 L
.44397 .38282 L
.43644 .37666 L
.42915 .3698 L
.42214 .36229 L
.41475 .35321 L
.40781 .34332 L
.40077 .33147 L
.39452 .31864 L
.38924 .30493 L
.38694 .29746 L
.38474 .2888 L
.38307 .2802 L
.38247 .27622 L
.38191 .27178 L
.38149 .2673 L
.38131 .26482 L
.38118 .26249 L
.38113 .26136 L
.38109 .26028 L
.38107 .2593 L
.38104 .25826 L
.38103 .25772 L
.38103 .25712 L
.38102 .25658 L
.38102 .25607 L
.38102 .25547 L
.38102 .25492 L
.38102 .25428 L
Mistroke
.38103 .25368 L
.38103 .25307 L
.38105 .25242 L
.38108 .25123 L
.38111 .25007 L
.38116 .249 L
.38129 .24655 L
.38147 .24394 L
.38189 .23955 L
.38251 .2347 L
.38337 .22948 L
.38435 .22469 L
.38722 .21386 L
.39074 .20394 L
.39559 .19324 L
.40114 .18345 L
.40842 .17305 L
.42498 .15566 L
.4346 .14821 L
.44593 .14126 L
.45765 .13578 L
.46388 .1335 L
.47068 .13145 L
.47729 .12989 L
.48337 .12882 L
.48633 .12842 L
.48954 .12808 L
.49102 .12795 L
.49259 .12784 L
.49393 .12776 L
.4954 .12769 L
.49626 .12766 L
.49707 .12763 L
.49784 .12762 L
.49865 .1276 L
.49938 .1276 L
.50006 .1276 L
.50081 .1276 L
.50162 .12761 L
.50243 .12762 L
.50332 .12765 L
.50424 .12768 L
.50511 .12771 L
.50665 .12779 L
.5083 .1279 L
.51153 .12818 L
.51457 .12854 L
.52024 .12942 L
.52646 .13073 L
.53294 .13248 L
Mistroke
.54421 .13655 L
.55552 .14206 L
.5654 .14822 L
.58371 .16392 L
.59204 .17365 L
.59884 .18342 L
.60883 .20287 L
.61253 .21309 L
.61549 .22395 L
.61658 .22924 L
.61752 .23492 L
.61818 .24022 L
.61861 .24504 L
.61876 .24737 L
.61883 .24864 L
.61888 .24984 L
.61891 .25095 L
.61893 .25154 L
.61895 .25216 L
.61896 .25268 L
.61897 .25325 L
.61897 .25377 L
.61898 .25426 L
.61898 .25484 L
.61898 .25548 L
.61898 .2558 L
.61898 .25614 L
.61898 .25675 L
.61897 .25737 L
.61896 .25794 L
.61894 .25902 L
.6189 .26029 L
.61886 .26145 L
.61873 .26407 L
.61859 .26624 L
.6184 .26855 L
.61799 .27267 L
.61735 .27747 L
.61666 .28176 L
.61503 .28979 L
.61287 .29814 L
.60768 .31335 L
.6018 .32652 L
.5949 .33901 L
.58784 .34969 L
.58083 .35879 L
.57327 .36732 L
.56596 .3745 L
.55896 .38053 L
.55156 .38607 L
Mistroke
.54453 .39061 L
.53715 .39464 L
.53013 .39779 L
.52346 .40017 L
.5201 .40115 L
.51642 .40204 L
.51291 .40273 L
.5097 .40322 L
.50812 .4034 L
.50639 .40357 L
.50545 .40365 L
.50457 .4037 L
.50367 .40375 L
.50284 .40379 L
.50198 .40382 L
.50153 .40383 L
.5013 .40383 L
.50105 .40384 L
.50083 .40384 L
.50063 .40384 L
.50043 .40384 L
.50024 .40384 L
.50002 .40384 L
.49982 .40384 L
.49959 .40384 L
.49948 .40384 L
.49936 .40384 L
.49916 .40384 L
.49895 .40384 L
.49857 .40383 L
.49817 .40382 L
.49772 .40381 L
.49693 .40378 L
.49619 .40375 L
.4944 .40363 L
.49271 .40349 L
.48955 .40311 L
.48613 .40256 L
.48297 .40191 L
.47618 .40006 L
.46959 .39768 L
.4625 .39446 L
.45559 .39068 L
.44814 .38586 L
.44088 .3804 L
.43384 .37432 L
.42633 .36689 L
.41911 .35873 L
.41157 .34886 L
.40455 .33809 L
Mistroke
.39817 .32646 L
.39203 .31263 L
.38931 .30515 L
.38704 .29781 L
.385 .28994 L
.38341 .28216 L
.38271 .27791 L
.38208 .2732 L
.38162 .26883 L
.38131 .26472 L
.38119 .26255 L
.38114 .26141 L
.38109 .2602 L
.38106 .25913 L
.38105 .25856 L
.38104 .25795 L
.38103 .25739 L
.38102 .25688 L
.38102 .25637 L
.38102 .25589 L
.38102 .25531 L
.38102 .25468 L
.38102 .25436 L
.38102 .25402 L
.38103 .2534 L
.38104 .25279 L
.38105 .2522 L
.38108 .2511 L
.38113 .2498 L
.38118 .24859 L
.38133 .24584 L
.3815 .24354 L
.38173 .24105 L
.38226 .23651 L
.38309 .23106 L
.38406 .226 L
.38651 .21624 L
.39013 .2055 L
.39452 .1954 L
.40031 .1848 L
.40688 .17507 L
.41522 .16506 L
.43387 .14873 L
.44455 .14202 L
.45675 .13615 L
.46246 .13398 L
.46875 .13199 L
.47476 .13044 L
.48042 .1293 L
.48386 .12875 L
Mistroke
.48699 .12835 L
.49048 .128 L
.49241 .12785 L
.49422 .12775 L
.49583 .12768 L
.49664 .12765 L
.49753 .12763 L
.49829 .12761 L
.4991 .1276 L
.49987 .1276 L
.50057 .1276 L
.501 .1276 L
.50145 .12761 L
.50226 .12762 L
.50271 .12763 L
.50314 .12764 L
.5041 .12767 L
.50571 .12774 L
.50744 .12784 L
.51069 .1281 L
.5137 .12843 L
.5205 .12947 L
.52703 .13087 L
.53389 .13278 L
.54683 .1377 L
.55831 .14366 L
.56885 .15071 L
.57773 .15806 L
.5865 .16696 L
.59372 .17588 L
.60517 .19477 L
.60977 .20523 L
.61308 .21485 L
.61565 .2247 L
.61676 .23022 L
.61758 .2353 L
.61792 .23788 L
.61823 .24065 L
.61846 .24307 L
.61865 .24561 L
.61879 .2479 L
.61884 .2491 L
.6189 .25039 L
.61893 .25156 L
.61896 .25263 L
.61896 .25315 L
.61897 .2537 L
.61898 .25423 L
.61898 .25471 L
.61898 .25531 L
Mistroke
.61898 .25588 L
.61898 .25639 L
.61897 .25694 L
.61897 .25754 L
.61896 .25818 L
.61893 .25933 L
.6189 .26048 L
.61886 .26157 L
.61876 .26359 L
.61861 .26598 L
.61844 .26817 L
.61794 .27303 L
.61737 .27736 L
.61674 .28132 L
.61497 .29003 L
.61062 .30534 L
.60487 .32003 L
.59855 .33269 L
.59201 .34359 L
.58473 .35389 L
.57755 .36264 L
.57059 .37007 L
.56317 .377 L
.55607 .38279 L
.5486 .38807 L
.54149 .39236 L
.53474 .39579 L
.52765 .39874 L
.52089 .40093 L
.51746 .40181 L
.51377 .40258 L
.51022 .40314 L
.50853 .40336 L
.50695 .40352 L
.50541 .40365 L
.50376 .40375 L
.50282 .40379 L
.50236 .40381 L
.50193 .40382 L
.50151 .40383 L
.50113 .40383 L
.50091 .40384 L
.5007 .40384 L
.50049 .40384 L
.50037 .40384 L
.50025 .40384 L
.50004 .40384 L
.49983 .40384 L
.49965 .40384 L
.49945 .40384 L
Mistroke
.49924 .40384 L
.49901 .40384 L
.4986 .40383 L
.49822 .40382 L
.49786 .40381 L
.49705 .40378 L
.49617 .40374 L
.49536 .4037 L
.49353 .40356 L
.49186 .4034 L
.49031 .40321 L
.48677 .40267 L
.48327 .40197 L
.48007 .40119 L
.47315 .39903 L
.46642 .39632 L
.45917 .39272 L
.45211 .38852 L
.44523 .38376 L
.43783 .37786 L
.43066 .3713 L
.42303 .3633 L
.41574 .3545 L
.40889 .34495 L
.40189 .3335 L
.39563 .32113 L
.38976 .30644 L
.38722 .29845 L
.38519 .29073 L
.38354 .28285 L
.38283 .2787 L
.3822 .27417 L
.38168 .26951 L
.38134 .2652 L
.38121 .26309 L
.38116 .26197 L
.38111 .26078 L
.38108 .25974 L
.38105 .25859 L
.38104 .25808 L
.38103 .25753 L
.38103 .25702 L
.38102 .25654 L
.38102 .25593 L
.38102 .25534 L
.38102 .25482 L
.38102 .25425 L
.38103 .25363 L
.38103 .25332 L
.38104 .25297 L
Mistroke
.38106 .25179 L
.38109 .25068 L
.38114 .24949 L
.38124 .24732 L
.38142 .24457 L
.38164 .24194 L
.3822 .23697 L
.38292 .23207 L
.38389 .22682 L
.38621 .21731 L
.38949 .2072 L
.3934 .19775 L
.40454 .17831 L
.41188 .16881 L
.42077 .15945 L
.43968 .14488 L
.45069 .13884 L
.46325 .13371 L
.46962 .13174 L
.47668 .13002 L
.47996 .12938 L
.48345 .12881 L
.48674 .12838 L
.48976 .12806 L
.49127 .12794 L
.49293 .12782 L
.4945 .12773 L
.49595 .12767 L
.49682 .12764 L
.49764 .12762 L
.49838 .12761 L
.49918 .1276 L
.4996 .1276 L
.50005 .1276 L
.50053 .1276 L
.50097 .1276 L
.50177 .12761 L
.50262 .12763 L
.50343 .12765 L
.50417 .12768 L
.50586 .12775 L
.50734 .12784 L
.50892 .12795 L
.51164 .1282 L
.51462 .12855 L
.52118 .1296 L
.52711 .13089 L
.53351 .13266 L
.5401 .13491 L
.55178 .14007 L
Mistroke
.56196 .14592 L
.58102 .16119 L
.5898 .17082 L
.59694 .18049 L
.60759 .19996 L
.61161 .21028 L
.61483 .2212 L
.61595 .22608 L
.61694 .23128 L
.61769 .23612 L
.61822 .24055 L
.61845 .24297 L
.61865 .24561 L
.6188 .24826 L
.61887 .2497 L
.61891 .25104 L
.61895 .25224 L
.61896 .25284 L
.61897 .25349 L
.61897 .25405 L
.61898 .25465 L
.61898 .25521 L
.61898 .25573 L
.61898 .25604 L
.61898 .25637 L
.61897 .25696 L
.61897 .25729 L
.61897 .25759 L
.61895 .25829 L
.61893 .25945 L
.61889 .2607 L
.61878 .26316 L
.61864 .26543 L
.61822 .27049 L
.61771 .27486 L
.61705 .27943 L
.61531 .28855 L
.61326 .29674 L
.60847 .31131 L
.60241 .32527 L
.59592 .33729 L
.5893 .34761 L
.582 .35736 L
.57484 .36564 L
.56719 .37335 L
.55985 .3798 L
.55284 .38516 L
.54547 .39004 L
.53846 .39397 L
.5318 .39709 L
Mistroke
.52479 .39974 L
.51811 .40165 L
.51467 .4024 L
.51107 .40302 L
.50944 .40324 L
.5077 .40344 L
.50607 .40359 L
.50457 .4037 L
.50372 .40374 L
.50283 .40378 L
.50239 .4038 L
.50193 .40381 L
.50142 .40382 L
.50117 .40383 L
.50094 .40383 L
.50073 .40383 L
.5005 .40384 L
.50037 .40384 L
.50025 .40384 L
.50014 .40384 L
.50002 .40384 L
.4998 .40384 L
.49969 .40384 L
.49957 .40384 L
.49935 .40383 L
.49915 .40383 L
.49874 .40383 L
.49836 .40382 L
.49751 .4038 L
.49669 .40376 L
.49582 .40372 L
.49426 .40362 L
.49258 .40347 L
.49072 .40326 L
.48741 .40278 L
.48384 .40209 L
.47674 .40023 L
.46984 .39777 L
.46313 .39477 L
.4559 .39086 L
.44885 .38635 L
.44127 .3807 L
.4339 .37436 L
.42677 .36736 L
.41923 .35886 L
.41207 .34955 L
.40539 .33947 L
.39867 .32743 L
.39277 .31447 L
.39007 .30734 L
Mistroke
.38743 .29915 L
.3854 .29159 L
.38354 .28284 L
.3822 .2742 L
.38167 .26931 L
.38148 .26708 L
.3813 .26462 L
.38118 .26224 L
.38113 .2611 L
.38109 .26001 L
.38107 .25942 L
.38106 .25877 L
.38105 .25823 L
.38104 .25763 L
.38103 .25699 L
.38102 .25664 L
.38102 .2563 L
.38102 .25571 L
.38102 .25538 L
.38102 .25507 L
.38102 .25452 L
.38103 .25394 L
.38103 .25338 L
.38104 .25288 L
.38107 .25164 L
.3811 .25047 L
.38119 .24835 L
.38132 .24604 L
.3815 .2436 L
.38171 .24131 L
.38232 .23605 L
.38312 .23088 L
.38422 .22528 L
.3871 .21428 L
.39078 .20383 L
.39543 .19357 L
.40063 .18427 L
.40741 .17437 L
.41477 .16555 L
.4322 .14992 L
.44295 .14293 L
.45354 .13753 L
.46502 .13312 L
.47174 .13117 L
.47811 .12973 L
.48138 .12914 L
.48494 .1286 L
.48832 .1282 L
.49144 .12792 L
.4928 .12783 L
Mistroke
.49427 .12775 L
.49511 .12771 L
.49587 .12768 L
.4966 .12765 L
.49738 .12763 L
.49818 .12761 L
.49892 .12761 L
.49972 .1276 L
.50018 .1276 L
.50061 .1276 L
.50137 .12761 L
.50208 .12762 L
.50285 .12764 L
.50367 .12766 L
.50535 .12773 L
.50695 .12781 L
.50992 .12804 L
.51311 .12836 L
.51657 .12882 L
.52273 .1299 L
.52835 .1312 L
.53998 .13487 L
.55216 .14026 L
.56286 .14651 L
.57343 .15432 L
.58241 .16258 L
.59105 .17238 L
.60374 .19195 L
.60848 .20205 L
.61248 .21293 L
.61406 .21826 L
.6155 .22402 L
.61653 .22896 L
.61743 .23435 L
.61811 .23956 L
.61856 .24437 L
.61874 .247 L
.61885 .24938 L
.6189 .25069 L
.61892 .25138 L
.61894 .25211 L
.61896 .25275 L
.61897 .25345 L
.61897 .25408 L
.61898 .25468 L
.61898 .25524 L
.61898 .25585 L
.61898 .25642 L
.61897 .25693 L
.61897 .25754 L
Mistroke
.61895 .25819 L
.61893 .25938 L
.61889 .26062 L
.61884 .26192 L
.61872 .26424 L
.61842 .26831 L
.61798 .27271 L
.61739 .27724 L
.61674 .28129 L
.61495 .2901 L
.61048 .30573 L
.60517 .31934 L
.59874 .33234 L
.59205 .34351 L
.58462 .35403 L
.57728 .36295 L
.57015 .3705 L
.56257 .37751 L
.55531 .38335 L
.54841 .38818 L
.54115 .39254 L
.53425 .39601 L
.527 .39897 L
.5201 .40114 L
.51351 .40262 L
.51013 .40315 L
.5084 .40336 L
.50655 .40355 L
.50481 .40368 L
.50405 .40373 L
.50323 .40377 L
.50244 .4038 L
.50171 .40382 L
.50131 .40382 L
.50094 .40383 L
.50074 .40383 L
.50052 .40383 L
.50031 .40383 L
.50012 .40383 L
.4999 .40383 L
.4997 .40383 L
.49952 .40383 L
.49932 .40383 L
.4991 .40383 L
.49888 .40383 L
.49846 .40382 L
.49809 .40381 L
.49773 .4038 L
.49692 .40377 L
.49604 .40373 L
Mistroke
.49523 .40368 L
.49341 .40354 L
.49174 .40338 L
.49019 .40319 L
.48665 .40264 L
.48315 .40194 L
.47996 .40115 L
.47305 .39899 L
.46633 .39627 L
.45909 .39267 L
.45203 .38847 L
.44516 .38371 L
.43777 .3778 L
.43061 .37125 L
.423 .36325 L
.41572 .35447 L
.40887 .34492 L
.40189 .33348 L
.39564 .32113 L
.38977 .30647 L
.38723 .29849 L
.38521 .29079 L
.38355 .28292 L
.38285 .27878 L
.38221 .27425 L
.3817 .26961 L
.38135 .2653 L
.38122 .2632 L
.38117 .26209 L
.38112 .2609 L
.38109 .25986 L
.38106 .2587 L
.38105 .2582 L
.38104 .25765 L
.38103 .25713 L
.38102 .25666 L
.38102 .25605 L
.38102 .25547 L
.38102 .25494 L
.38102 .25438 L
.38103 .25376 L
.38103 .25345 L
.38104 .2531 L
.38106 .25192 L
.38109 .25082 L
.38114 .24962 L
.38124 .24746 L
.38141 .24471 L
.38163 .24209 L
.38218 .23712 L
Mistroke
.38289 .23224 L
.38386 .227 L
.38615 .2175 L
.38981 .20635 L
.39426 .19593 L
.40574 .17662 L
.41326 .16723 L
.42233 .15801 L
.44153 .14376 L
.45265 .13793 L
.4653 .13303 L
.4717 .13118 L
.47879 .1296 L
.48207 .12903 L
.48557 .12852 L
.48858 .12818 L
.4919 .12789 L
.49353 .12778 L
.49439 .12774 L
.49531 .1277 L
.49619 .12766 L
.49699 .12764 L
.4978 .12762 L
.49856 .12761 L
.4993 .1276 L
.50009 .1276 L
.50075 .1276 L
.50149 .12761 L
.50228 .12762 L
.50313 .12764 L
.50393 .12767 L
.50466 .1277 L
.50641 .12778 L
.50803 .12788 L
.51169 .1282 L
.51491 .12858 L
.5183 .12909 L
.52434 .13024 L
.53074 .13184 L
.542 .13565 L
.55372 .14108 L
.56519 .14807 L
.58324 .16343 L
.59106 .1724 L
.59828 .18253 L
.60405 .19254 L
.60914 .20364 L
.61295 .21443 L
.61557 .22436 L
.61653 .22901 L
Mistroke
.61738 .23396 L
.61809 .23935 L
.61856 .24434 L
.61873 .24694 L
.61885 .24933 L
.6189 .2507 L
.61894 .25194 L
.61895 .25263 L
.61896 .25336 L
.61897 .2537 L
.61897 .25406 L
.61898 .2547 L
.61898 .2553 L
.61898 .25585 L
.61898 .25648 L
.61897 .25708 L
.61896 .25763 L
.61896 .25814 L
.61893 .25928 L
.6189 .26043 L
.61885 .26169 L
.61872 .26422 L
.61857 .26651 L
.61837 .26889 L
.61793 .27309 L
.61734 .27752 L
.61657 .28226 L
.61486 .29051 L
.61264 .29892 L
.60728 .31434 L
.60121 .32766 L
.59481 .33914 L
.5876 .35001 L
.58044 .35926 L
.57345 .36712 L
.56599 .37446 L
.55883 .38062 L
.5513 .38625 L
.54412 .39084 L
.5373 .39455 L
.53014 .39777 L
.52332 .4002 L
.51682 .40194 L
.51351 .40261 L
.51181 .4029 L
.50995 .40317 L
.5083 .40337 L
.50654 .40355 L
.50557 .40363 L
.50469 .40369 L
Mistroke
.50385 .40373 L
.50296 .40378 L
.50215 .4038 L
.50169 .40381 L
.50126 .40382 L
.50106 .40383 L
.50087 .40383 L
.5007 .40383 L
.50051 .40383 L
.50031 .40383 L
.50012 .40383 L
.4999 .40383 L
.4997 .40383 L
.49948 .40383 L
.49937 .40383 L
.49924 .40383 L
.49883 .40382 L
.49859 .40382 L
.49834 .40382 L
.49788 .4038 L
.49698 .40377 L
.49617 .40374 L
.49448 .40363 L
.49292 .4035 L
.48938 .40308 L
.48619 .40256 L
.48266 .40182 L
.47573 .3999 L
.46899 .39742 L
.46174 .39407 L
.45467 .39012 L
.44778 .3856 L
.44037 .37997 L
.43318 .37369 L
.42551 .36601 L
.41815 .35754 L
.41119 .34831 L
.40405 .33724 L
.39758 .32524 L
.39195 .31239 L
.38916 .30466 L
.38688 .29723 L
.38481 .28908 L
.38324 .28117 L
.38255 .27681 L
.38203 .27278 L
.38157 .26822 L
.38137 .26568 L
.38123 .26327 L
.38113 .26107 L
Mistroke
.38109 .25982 L
.38105 .25865 L
.38104 .25801 L
.38103 .25741 L
.38103 .25686 L
.38102 .25627 L
.38102 .25596 L
.38102 .25562 L
.38102 .25527 L
.38102 .25493 L
.38102 .25434 L
.38103 .254 L
.38103 .2537 L
.38104 .25315 L
.38105 .25256 L
.38107 .2515 L
.38111 .25023 L
.38116 .24908 L
.38128 .2468 L
.38142 .24464 L
.38187 .23977 L
.38253 .23456 L
.38327 .23008 L
.38426 .22511 L
.38687 .21503 L
.39065 .20418 L
.39559 .19325 L
.40135 .18312 L
.41532 .16496 L
.42405 .15647 L
.43441 .14835 L
.44505 .14175 L
.4555 .13668 L
.46731 .13241 L
.47371 .13069 L
.48058 .12928 L
.48376 .12877 L
.48677 .12838 L
.49026 .12802 L
.49181 .1279 L
.49345 .12779 L
.49488 .12772 L
.49564 .12769 L
.49646 .12766 L
.49721 .12764 L
.4979 .12762 L
.49859 .12761 L
.49924 .1276 L
.5 .1276 L
.5008 .1276 L
Mistroke
.50156 .12761 L
.50225 .12762 L
.50306 .12764 L
.50394 .12767 L
.50553 .12774 L
.50709 .12782 L
.50876 .12794 L
.51177 .12821 L
.51533 .12864 L
.51857 .12913 L
.52553 .13051 L
.532 .13221 L
.5442 .13655 L
.55488 .14171 L
.56501 .14795 L
.57524 .15586 L
.58457 .16484 L
.59209 .17372 L
.60422 .19288 L
.60872 .20262 L
.61261 .21336 L
.61538 .22353 L
.61656 .22918 L
.61742 .23426 L
.61808 .23931 L
.61852 .24392 L
.61869 .24631 L
.61883 .24891 L
.61888 .25022 L
.61891 .25093 L
.61893 .25161 L
.61894 .25224 L
.61896 .25292 L
.61897 .25354 L
.61897 .25412 L
.61898 .25474 L
.61898 .25506 L
.61898 .2554 L
.61898 .25601 L
.61897 .25657 L
.61897 .25691 L
.61897 .25724 L
.61896 .25784 L
.61895 .25849 L
.61893 .2592 L
.6189 .26039 L
.61885 .26165 L
.61874 .26389 L
.6186 .26601 L
.61845 .26799 L
Mistroke
.61801 .27243 L
.61741 .27705 L
.61673 .28135 L
.61516 .28919 L
.61096 .30431 L
.60537 .31887 L
.59923 .33145 L
.59215 .34336 L
.585 .35352 L
.57796 .36217 L
.57039 .37026 L
.56309 .37705 L
.55613 .38273 L
.54878 .38794 L
.54179 .39218 L
.53446 .39591 L
.52749 .39879 L
.52085 .40093 L
.51752 .40178 L
.51385 .40255 L
.51039 .40311 L
.50715 .40349 L
.50548 .40363 L
.50456 .40369 L
.50371 .40374 L
.50293 .40377 L
.50221 .4038 L
.50183 .40381 L
.50142 .40382 L
.50119 .40382 L
.50098 .40382 L
.50078 .40383 L
.50057 .40383 L
.50036 .40383 L
.50015 .40383 L
.49996 .40383 L
.49977 .40383 L
.49956 .40383 L
.49936 .40383 L
.49913 .40382 L
.49892 .40382 L
.49853 .40382 L
.49818 .40381 L
.49738 .40378 L
.49656 .40375 L
.49567 .4037 L
.49387 .40358 L
.49213 .40342 L
.49054 .40323 L
.48697 .40269 L
Mistroke
.48369 .40205 L
.48012 .40119 L
.47306 .39899 L
.46618 .3962 L
.4595 .39288 L
.45228 .38862 L
.44526 .38377 L
.43771 .37774 L
.43038 .37102 L
.42333 .36363 L
.41589 .35469 L
.40889 .34493 L
.40175 .33324 L
.39538 .32056 L
.38995 .30699 L
.38755 .29957 L
.38526 .291 L
.38347 .28244 L
.38219 .27409 L
.38168 .26938 L
.38147 .26702 L
.38132 .26482 L
.38121 .26281 L
.38111 .26066 L
.38108 .25954 L
.38105 .25849 L
.38104 .25788 L
.38103 .25732 L
.38103 .25671 L
.38102 .2564 L
.38102 .25606 L
.38102 .25543 L
.38102 .25485 L
.38102 .25454 L
.38103 .2542 L
.38103 .25385 L
.38103 .25352 L
.38104 .25291 L
.38105 .25236 L
.38109 .2511 L
.38112 .24999 L
.38117 .24876 L
.38129 .24653 L
.38148 .24392 L
.38173 .24112 L
.38232 .23605 L
.38314 .23081 L
.38426 .2251 L
.38698 .21467 L
.3906 .20431 L
Mistroke
.39548 .19346 L
.40723 .17461 L
.41477 .16555 L
.42398 .15654 L
.43372 .14884 L
.44535 .14158 L
.45741 .13589 L
.46343 .13365 L
.4692 .13186 L
.47538 .13031 L
.48113 .12918 L
.4842 .12871 L
.48758 .12828 L
.49099 .12796 L
.49285 .12783 L
.49459 .12773 L
.49543 .12769 L
.49632 .12766 L
.49708 .12764 L
.49791 .12762 L
.49838 .12761 L
.49881 .12761 L
.4993 .1276 L
.49977 .1276 L
.50061 .1276 L
.50108 .12761 L
.50152 .12761 L
.50237 .12763 L
.50318 .12765 L
.50468 .1277 L
.5063 .12778 L
.50805 .12789 L
.51114 .12815 L
.51439 .12852 L
.52016 .12941 L
.52626 .13069 L
.53269 .13241 L
.54391 .13643 L
.55621 .14245 L
.56699 .14934 L
.58483 .16511 L
.59253 .17429 L
.59954 .18456 L
.60922 .20385 L
.61279 .21392 L
.61565 .22473 L
.6167 .22991 L
.6176 .23553 L
.61793 .23807 L
.61824 .24077 L
Mistroke
.61846 .24312 L
.61865 .24559 L
.61873 .24685 L
.6188 .24823 L
.61886 .24949 L
.6189 .25064 L
.61894 .25199 L
.61895 .25274 L
.61896 .25344 L
.61897 .25375 L
.61897 .25408 L
.61898 .25468 L
.61898 .25501 L
.61898 .25532 L
.61898 .25566 L
.61898 .25602 L
.61897 .25663 L
.61897 .2572 L
.61896 .25781 L
.61895 .25847 L
.61891 .25981 L
.61887 .26103 L
.61877 .26336 L
.61863 .26554 L
.61826 .27 L
.61774 .27463 L
.61649 .2827 L
.61476 .2909 L
.61283 .29825 L
.6079 .31277 L
.60172 .32665 L
.59514 .33859 L
.58844 .34883 L
.58107 .35849 L
.57386 .36669 L
.56616 .3743 L
.55878 .38065 L
.55174 .38593 L
.54433 .39071 L
.53729 .39455 L
.53061 .39758 L
.52357 .40012 L
.51686 .40193 L
.51322 .40266 L
.51155 .40294 L
.50978 .40319 L
.50816 .40338 L
.50638 .40356 L
.50476 .40368 L
.50325 .40376 L
Mistroke
.50245 .40379 L
.50199 .4038 L
.50157 .40381 L
.50113 .40382 L
.50089 .40382 L
.50066 .40382 L
.50045 .40383 L
.50025 .40383 L
.50004 .40383 L
.49993 .40383 L
.49981 .40383 L
.4996 .40383 L
.4994 .40382 L
.49922 .40382 L
.49903 .40382 L
.49859 .40381 L
.49818 .40381 L
.49745 .40378 L
.49666 .40375 L
.49507 .40367 L
.49336 .40353 L
.49024 .40319 L
.48683 .40267 L
.48322 .40195 L
.47666 .40019 L
.46962 .39767 L
.46276 .39457 L
.45537 .39053 L
.44816 .38586 L
.44115 .3806 L
.43363 .3741 L
.42635 .36691 L
.41938 .35904 L
.41207 .34955 L
.40525 .33924 L
.39841 .32691 L
.39243 .31361 L
.38751 .29942 L
.3854 .29156 L
.38353 .28278 L
.38278 .27833 L
.38211 .27339 L
.38161 .26863 L
.38142 .26631 L
.38128 .26417 L
.38117 .26197 L
.38112 .26076 L
.38108 .2596 L
.38105 .25852 L
.38104 .25753 L
Mistroke
.38103 .257 L
.38103 .25643 L
.38102 .25582 L
.38102 .25526 L
.38102 .25467 L
.38103 .25404 L
.38103 .25372 L
.38104 .25337 L
.38105 .25275 L
.38107 .25154 L
.38111 .25044 L
.38116 .24914 L
.38123 .24773 L
.38138 .24516 L
.3818 .24044 L
.38244 .23519 L
.38335 .22965 L
.38441 .22443 L
.38721 .21392 L
.3906 .2043 L
.39497 .1945 L
.40079 .18402 L
.40799 .17362 L
.41556 .1647 L
.4339 .14871 L
.44428 .14218 L
.45634 .13633 L
.4686 .13203 L
.47496 .1304 L
.4786 .12964 L
.48206 .12903 L
.48525 .12857 L
.48873 .12816 L
.49026 .12802 L
.4919 .12789 L
.49343 .12779 L
.49484 .12772 L
.49647 .12766 L
.49732 .12763 L
.49775 .12763 L
.49822 .12762 L
.499 .12761 L
.49973 .1276 L
.5006 .1276 L
.50139 .12761 L
.50184 .12762 L
.50232 .12763 L
.50317 .12765 L
.50409 .12768 L
.50511 .12772 L
Mistroke
.50691 .12781 L
.5086 .12793 L
.51187 .12823 L
.51542 .12866 L
.52183 .12972 L
.52798 .13111 L
.53358 .13269 L
.54494 .13687 L
.55679 .14278 L
.5671 .14943 L
.57724 .15762 L
.58577 .16615 L
.59394 .17619 L
.60575 .19597 L
.61009 .20608 L
.61369 .21696 L
.61508 .22225 L
.61633 .22796 L
.6172 .23287 L
.61795 .23821 L
.61823 .2407 L
.61847 .24335 L
.61865 .24563 L
.61879 .2481 L
.61886 .24954 L
.61891 .25086 L
.61894 .25212 L
.61895 .25283 L
.61896 .25346 L
.61897 .25409 L
.61898 .25466 L
.61898 .25529 L
.61898 .25561 L
.61898 .25596 L
.61897 .25654 L
.61897 .25716 L
.61896 .25775 L
.61895 .25828 L
.61892 .25937 L
.61889 .26057 L
.61879 .26297 L
.61866 .26518 L
.61851 .26723 L
.61808 .27179 L
.61747 .2766 L
.61599 .28527 L
.614 .29399 L
.60945 .30865 L
.60361 .32275 L
.5973 .33491 L
Mistroke
.59012 .34641 L
.58292 .3562 L
.57585 .36453 L
.56829 .3723 L
.56101 .37882 L
.55407 .38426 L
.54676 .38923 L
.53981 .39325 L
.53252 .39677 L
.52557 .39946 L
.51896 .40142 L
.51558 .40221 L
.51198 .40287 L
.51022 .40313 L
.50832 .40336 L
.50668 .40353 L
.50581 .4036 L
.50488 .40367 L
.50396 .40372 L
.50312 .40376 L
.50272 .40378 L
.50228 .40379 L
.50187 .4038 L
.50148 .40381 L
.50105 .40382 L
.50083 .40382 L
.50058 .40382 L
.50046 .40382 L
.50032 .40382 L
.5002 .40383 L
.50008 .40383 L
.49986 .40383 L
.49973 .40383 L
.49962 .40382 L
.4994 .40382 L
.49919 .40382 L
.49897 .40382 L
.49873 .40381 L
.49834 .40381 L
.4979 .4038 L
.49701 .40377 L
.49617 .40373 L
.49458 .40363 L
.49288 .40349 L
.49102 .40329 L
.48765 .40281 L
.48405 .40213 L
.47756 .40046 L
.47058 .39805 L
.46379 .39508 L
Mistroke
.45647 .39118 L
.44934 .38667 L
.44239 .38158 L
.43494 .3753 L
.42772 .36834 L
.42007 .35986 L
.41281 .35056 L
.40601 .34047 L
.39917 .3284 L
.39315 .31537 L
.38814 .30149 L
.38579 .29317 L
.38399 .2852 L
.38324 .28112 L
.38252 .27659 L
.38197 .27224 L
.38156 .26807 L
.38138 .26578 L
.38123 .26329 L
.38118 .26217 L
.38113 .26099 L
.38109 .25989 L
.38106 .25887 L
.38105 .2583 L
.38104 .25768 L
.38104 .25734 L
.38103 .25702 L
.38103 .2564 L
.38102 .25587 L
.38102 .25528 L
.38102 .25466 L
.38103 .25408 L
.38103 .25377 L
.38104 .25343 L
.38105 .25274 L
.38108 .25151 L
.38112 .25008 L
.38118 .24873 L
.38131 .24624 L
.38151 .24352 L
.38201 .23854 L
.38267 .23364 L
.38345 .22909 L
.38564 .2194 L
.38895 .20869 L
.39302 .19861 L
.39845 .18795 L
.40466 .17814 L
.41262 .16796 L
.43054 .15117 L
Mistroke
.44088 .14415 L
.45279 .13787 L
.45836 .13551 L
.46453 .13328 L
.47045 .13152 L
.47605 .13016 L
.4822 .12901 L
.48549 .12853 L
.48902 .12814 L
.4908 .12798 L
.49274 .12783 L
.49457 .12773 L
.49545 .12769 L
.49627 .12766 L
.49707 .12764 L
.49779 .12762 L
.49861 .12761 L
.49905 .12761 L
.49948 .1276 L
.50032 .1276 L
.5011 .12761 L
.50196 .12762 L
.50244 .12763 L
.50288 .12764 L
.50441 .12769 L
.50528 .12772 L
.50609 .12777 L
.50947 .128 L
.51238 .12828 L
.51549 .12867 L
.52254 .12987 L
.52887 .13134 L
.5407 .13515 L
.55291 .14066 L
.56376 .1471 L
.5743 .15506 L
.59044 .17161 L
.59723 .18093 L
.60343 .19137 L
.60823 .20146 L
.61237 .2126 L
.61532 .22324 L
.61723 .23304 L
.61797 .23837 L
.61826 .24097 L
.61847 .24335 L
.61864 .24546 L
.61878 .24776 L
.61888 .25007 L
.61892 .25132 L
Mistroke
.61895 .25249 L
.61896 .2531 L
.61896 .25343 L
.61897 .25374 L
.61897 .25435 L
.61898 .2549 L
.61898 .25522 L
.61898 .25555 L
.61898 .25615 L
.61897 .25649 L
.61897 .2568 L
.61897 .25714 L
.61896 .2575 L
.61895 .25811 L
.61894 .25877 L
.61891 .25996 L
.61887 .26112 L
.61882 .26218 L
.61857 .26637 L
.61841 .26846 L
.61819 .27074 L
.61706 .27936 L
.61623 .28406 L
.61537 .28826 L
.61105 .30402 L
.60585 .31777 L
.59951 .33092 L
.59288 .34222 L
.58549 .35287 L
.57817 .36192 L
.57106 .36958 L
.56349 .3767 L
.55624 .38264 L
.54934 .38756 L
.54208 .39201 L
.53518 .39557 L
.52794 .39862 L
.52104 .40087 L
.51446 .40243 L
.51108 .40301 L
.50936 .40324 L
.5075 .40345 L
.50577 .4036 L
.50502 .40366 L
.50419 .40371 L
.50346 .40375 L
.50267 .40378 L
.50224 .40379 L
.50185 .4038 L
.50145 .40381 L
Mistroke
.50108 .40382 L
.50089 .40382 L
.50069 .40382 L
.50057 .40382 L
.50046 .40383 L
.50026 .40383 L
.50004 .40383 L
.49984 .40383 L
.49962 .40383 L
.4995 .40383 L
.49939 .40382 L
.49918 .40382 L
.499 .40382 L
.49858 .40381 L
.49821 .40381 L
.49782 .4038 L
.49695 .40376 L
.49614 .40373 L
.49429 .40361 L
.4925 .40345 L
.49082 .40326 L
.48765 .40281 L
.48424 .40217 L
.48107 .40143 L
.47428 .39941 L
.46769 .39686 L
.46059 .39347 L
.45367 .38949 L
.44621 .38447 L
.44254 .3817 L
Mfstroke
.5 .59615 m
.5002 .59615 L
.50038 .59616 L
.50059 .59616 L
.50079 .59616 L
.50114 .59616 L
.50153 .59617 L
.50195 .59618 L
.50239 .59619 L
.5032 .59622 L
.50403 .59626 L
.5048 .59631 L
.50657 .59644 L
.50837 .59662 L
.51003 .59683 L
.51376 .59742 L
.51701 .59809 L
.52057 .59898 L
.52761 .60124 L
.53446 .60408 L
.54183 .60783 L
.54903 .61221 L
.55603 .61718 L
.56356 .62334 L
.57085 .6302 L
.57786 .63771 L
.58525 .64679 L
.59219 .65668 L
.59923 .66853 L
.60548 .68136 L
.61076 .69507 L
.61306 .70254 L
.61526 .7112 L
.61693 .7198 L
.61753 .72378 L
.61809 .72822 L
.61851 .7327 L
.61869 .73518 L
.61882 .73751 L
.61887 .73864 L
.61891 .73972 L
.61893 .7407 L
.61896 .74174 L
.61897 .74228 L
.61897 .74288 L
.61898 .74342 L
.61898 .74393 L
.61898 .74453 L
.61898 .74508 L
.61898 .74572 L
Mistroke
.61897 .74632 L
.61897 .74693 L
.61895 .74758 L
.61892 .74877 L
.61889 .74993 L
.61884 .751 L
.61871 .75345 L
.61853 .75606 L
.61811 .76045 L
.61749 .7653 L
.61663 .77052 L
.61565 .77531 L
.61278 .78614 L
.60926 .79606 L
.60441 .80676 L
.59886 .81655 L
.59158 .82695 L
.57502 .84434 L
.5654 .85179 L
.55407 .85874 L
.54235 .86422 L
.53612 .8665 L
.52932 .86855 L
.52271 .87011 L
.51663 .87118 L
.51367 .87158 L
.51046 .87192 L
.50898 .87205 L
.50741 .87216 L
.50607 .87224 L
.5046 .87231 L
.50374 .87234 L
.50293 .87237 L
.50216 .87238 L
.50135 .8724 L
.50062 .8724 L
.49994 .8724 L
.49919 .8724 L
.49838 .87239 L
.49757 .87238 L
.49668 .87235 L
.49576 .87232 L
.49489 .87229 L
.49335 .87221 L
.4917 .8721 L
.48847 .87182 L
.48543 .87146 L
.47976 .87058 L
.47354 .86927 L
.46706 .86752 L
Mistroke
.45579 .86345 L
.44448 .85794 L
.4346 .85178 L
.41629 .83608 L
.40796 .82635 L
.40116 .81658 L
.39117 .79713 L
.38747 .78691 L
.38451 .77605 L
.38342 .77076 L
.38248 .76508 L
.38182 .75978 L
.38139 .75496 L
.38124 .75263 L
.38117 .75136 L
.38112 .75016 L
.38109 .74905 L
.38107 .74846 L
.38105 .74784 L
.38104 .74732 L
.38103 .74675 L
.38103 .74623 L
.38102 .74574 L
.38102 .74516 L
.38102 .74452 L
.38102 .7442 L
.38102 .74386 L
.38102 .74325 L
.38103 .74263 L
.38104 .74206 L
.38106 .74098 L
.3811 .73971 L
.38114 .73855 L
.38127 .73593 L
.38141 .73376 L
.3816 .73145 L
.38201 .72733 L
.38265 .72253 L
.38334 .71824 L
.38497 .71021 L
.38713 .70186 L
.39232 .68665 L
.3982 .67348 L
.4051 .66099 L
.41216 .65031 L
.41917 .64121 L
.42673 .63268 L
.43404 .6255 L
.44104 .61947 L
.44844 .61393 L
Mistroke
.45547 .60939 L
.46285 .60536 L
.46987 .60221 L
.47654 .59983 L
.4799 .59885 L
.48358 .59796 L
.48709 .59727 L
.4903 .59678 L
.49188 .5966 L
.49361 .59643 L
.49455 .59635 L
.49543 .5963 L
.49633 .59625 L
.49716 .59621 L
.49802 .59618 L
.49847 .59617 L
.4987 .59617 L
.49895 .59616 L
.49917 .59616 L
.49937 .59616 L
.49957 .59616 L
.49976 .59616 L
.49998 .59616 L
.50018 .59616 L
.50041 .59616 L
.50052 .59616 L
.50064 .59616 L
.50084 .59616 L
.50105 .59616 L
.50143 .59617 L
.50183 .59618 L
.50228 .59619 L
.50307 .59622 L
.50381 .59625 L
.5056 .59637 L
.50729 .59651 L
.51045 .59689 L
.51387 .59744 L
.51703 .59809 L
.52382 .59994 L
.53041 .60232 L
.5375 .60554 L
.54441 .60932 L
.55186 .61414 L
.55912 .6196 L
.56616 .62568 L
.57367 .63311 L
.58089 .64127 L
.58843 .65114 L
.59545 .66191 L
Mistroke
.60183 .67354 L
.60797 .68737 L
.61069 .69485 L
.61296 .70219 L
.615 .71006 L
.61659 .71784 L
.61729 .72209 L
.61792 .7268 L
.61838 .73117 L
.61869 .73528 L
.61881 .73745 L
.61886 .73859 L
.61891 .7398 L
.61894 .74087 L
.61895 .74144 L
.61896 .74205 L
.61897 .74261 L
.61898 .74312 L
.61898 .74363 L
.61898 .74411 L
.61898 .74469 L
.61898 .74532 L
.61898 .74564 L
.61898 .74598 L
.61897 .7466 L
.61896 .74721 L
.61895 .7478 L
.61892 .7489 L
.61887 .7502 L
.61882 .75141 L
.61867 .75416 L
.6185 .75646 L
.61827 .75895 L
.61774 .76349 L
.61691 .76894 L
.61594 .774 L
.61349 .78376 L
.60987 .7945 L
.60548 .8046 L
.59969 .8152 L
.59312 .82493 L
.58478 .83494 L
.56613 .85127 L
.55545 .85798 L
.54325 .86385 L
.53754 .86602 L
.53125 .86801 L
.52524 .86956 L
.51958 .8707 L
.51614 .87125 L
Mistroke
.51301 .87165 L
.50952 .872 L
.50759 .87215 L
.50578 .87225 L
.50417 .87232 L
.50336 .87235 L
.50247 .87237 L
.50171 .87239 L
.5009 .8724 L
.50013 .8724 L
.49943 .8724 L
.499 .8724 L
.49855 .87239 L
.49774 .87238 L
.49729 .87237 L
.49686 .87236 L
.4959 .87233 L
.49429 .87226 L
.49256 .87216 L
.48931 .8719 L
.4863 .87157 L
.4795 .87053 L
.47297 .86913 L
.46611 .86722 L
.45317 .8623 L
.44169 .85634 L
.43115 .84929 L
.42227 .84194 L
.4135 .83304 L
.40628 .82412 L
.39483 .80523 L
.39023 .79477 L
.38692 .78515 L
.38435 .7753 L
.38324 .76978 L
.38242 .7647 L
.38208 .76212 L
.38177 .75935 L
.38154 .75693 L
.38135 .75439 L
.38121 .7521 L
.38116 .7509 L
.3811 .74961 L
.38107 .74844 L
.38104 .74737 L
.38104 .74685 L
.38103 .7463 L
.38102 .74577 L
.38102 .74529 L
.38102 .74469 L
Mistroke
.38102 .74412 L
.38102 .74361 L
.38103 .74306 L
.38103 .74246 L
.38104 .74182 L
.38107 .74067 L
.3811 .73952 L
.38114 .73843 L
.38124 .73641 L
.38139 .73402 L
.38156 .73183 L
.38206 .72697 L
.38263 .72264 L
.38326 .71868 L
.38503 .70997 L
.38938 .69466 L
.39513 .67997 L
.40145 .66731 L
.40799 .65641 L
.41527 .64611 L
.42245 .63736 L
.42941 .62993 L
.43683 .623 L
.44393 .61721 L
.4514 .61193 L
.45851 .60764 L
.46526 .60421 L
.47235 .60126 L
.47911 .59907 L
.48254 .59819 L
.48623 .59742 L
.48978 .59686 L
.49147 .59664 L
.49305 .59648 L
.49459 .59635 L
.49624 .59625 L
.49718 .59621 L
.49764 .59619 L
.49807 .59618 L
.49849 .59617 L
.49887 .59617 L
.49909 .59616 L
.4993 .59616 L
.49951 .59616 L
.49963 .59616 L
.49975 .59616 L
.49996 .59616 L
.50017 .59616 L
.50035 .59616 L
.50055 .59616 L
Mistroke
.50076 .59616 L
.50099 .59616 L
.5014 .59617 L
.50178 .59618 L
.50214 .59619 L
.50295 .59622 L
.50383 .59626 L
.50464 .5963 L
.50647 .59644 L
.50814 .5966 L
.50969 .59679 L
.51323 .59733 L
.51673 .59803 L
.51993 .59881 L
.52685 .60097 L
.53358 .60368 L
.54083 .60728 L
.54789 .61148 L
.55477 .61624 L
.56217 .62214 L
.56934 .6287 L
.57697 .6367 L
.58426 .6455 L
.59111 .65505 L
.59811 .6665 L
.60437 .67887 L
.61024 .69356 L
.61278 .70155 L
.61481 .70927 L
.61646 .71715 L
.61717 .7213 L
.6178 .72583 L
.61832 .73049 L
.61866 .7348 L
.61879 .73691 L
.61884 .73803 L
.61889 .73922 L
.61892 .74026 L
.61895 .74141 L
.61896 .74192 L
.61897 .74247 L
.61897 .74298 L
.61898 .74346 L
.61898 .74407 L
.61898 .74466 L
.61898 .74518 L
.61898 .74575 L
.61897 .74637 L
.61897 .74668 L
.61896 .74703 L
Mistroke
.61894 .74821 L
.61891 .74932 L
.61886 .75051 L
.61876 .75268 L
.61858 .75543 L
.61836 .75806 L
.6178 .76303 L
.61708 .76793 L
.61611 .77318 L
.61379 .78269 L
.61051 .7928 L
.6066 .80225 L
.59546 .82169 L
.58812 .83119 L
.57923 .84055 L
.56032 .85512 L
.54931 .86116 L
.53675 .86629 L
.53038 .86826 L
.52332 .86998 L
.52004 .87062 L
.51655 .87119 L
.51326 .87162 L
.51024 .87194 L
.50873 .87206 L
.50707 .87218 L
.5055 .87227 L
.50405 .87233 L
.50318 .87236 L
.50236 .87238 L
.50162 .87239 L
.50082 .8724 L
.5004 .8724 L
.49995 .8724 L
.49947 .8724 L
.49903 .8724 L
.49823 .87239 L
.49738 .87237 L
.49657 .87235 L
.49583 .87232 L
.49414 .87225 L
.49266 .87216 L
.49108 .87205 L
.48836 .8718 L
.48538 .87145 L
.47882 .8704 L
.47289 .86911 L
.46649 .86734 L
.4599 .86509 L
.44822 .85993 L
Mistroke
.43804 .85408 L
.41898 .83881 L
.4102 .82918 L
.40306 .81951 L
.39241 .80004 L
.38839 .78972 L
.38517 .7788 L
.38405 .77392 L
.38306 .76872 L
.38231 .76388 L
.38178 .75945 L
.38155 .75703 L
.38135 .75439 L
.3812 .75174 L
.38113 .7503 L
.38109 .74896 L
.38105 .74776 L
.38104 .74716 L
.38103 .74651 L
.38103 .74595 L
.38102 .74535 L
.38102 .74479 L
.38102 .74427 L
.38102 .74396 L
.38102 .74363 L
.38103 .74304 L
.38103 .74271 L
.38103 .74241 L
.38105 .74171 L
.38107 .74055 L
.38111 .7393 L
.38122 .73684 L
.38136 .73457 L
.38178 .72951 L
.38229 .72514 L
.38295 .72057 L
.38469 .71145 L
.38674 .70326 L
.39153 .68869 L
.39759 .67473 L
.40408 .66271 L
.4107 .65239 L
.418 .64264 L
.42516 .63436 L
.43281 .62665 L
.44015 .6202 L
.44716 .61484 L
.45453 .60996 L
.46154 .60603 L
.4682 .60291 L
Mistroke
.47521 .60026 L
.48189 .59835 L
.48533 .5976 L
.48893 .59698 L
.49056 .59676 L
.4923 .59656 L
.49393 .59641 L
.49543 .5963 L
.49628 .59626 L
.49717 .59622 L
.49761 .5962 L
.49807 .59619 L
.49858 .59618 L
.49883 .59617 L
.49906 .59617 L
.49927 .59617 L
.4995 .59616 L
.49963 .59616 L
.49975 .59616 L
.49986 .59616 L
.49998 .59616 L
.5002 .59616 L
.50031 .59616 L
.50043 .59616 L
.50065 .59617 L
.50085 .59617 L
.50126 .59617 L
.50164 .59618 L
.50249 .5962 L
.50331 .59624 L
.50418 .59628 L
.50574 .59638 L
.50742 .59653 L
.50928 .59674 L
.51259 .59722 L
.51616 .59791 L
.52326 .59977 L
.53016 .60223 L
.53687 .60523 L
.5441 .60914 L
.55115 .61365 L
.55873 .6193 L
.5661 .62564 L
.57323 .63264 L
.58077 .64114 L
.58793 .65045 L
.59461 .66053 L
.60133 .67257 L
.60723 .68553 L
.60993 .69266 L
Mistroke
.61257 .70085 L
.6146 .70841 L
.61646 .71716 L
.6178 .7258 L
.61833 .73069 L
.61852 .73292 L
.6187 .73538 L
.61882 .73776 L
.61887 .7389 L
.61891 .73999 L
.61893 .74058 L
.61894 .74123 L
.61895 .74177 L
.61896 .74237 L
.61897 .74301 L
.61898 .74336 L
.61898 .7437 L
.61898 .74429 L
.61898 .74462 L
.61898 .74493 L
.61898 .74548 L
.61897 .74606 L
.61897 .74662 L
.61896 .74712 L
.61893 .74836 L
.6189 .74953 L
.61881 .75165 L
.61868 .75396 L
.6185 .7564 L
.61829 .75869 L
.61768 .76395 L
.61688 .76912 L
.61578 .77472 L
.6129 .78572 L
.60922 .79617 L
.60457 .80643 L
.59937 .81573 L
.59259 .82563 L
.58523 .83445 L
.5678 .85008 L
.55705 .85707 L
.54646 .86247 L
.53498 .86688 L
.52826 .86883 L
.52189 .87027 L
.51862 .87086 L
.51506 .8714 L
.51168 .8718 L
.50856 .87208 L
.5072 .87217 L
Mistroke
.50573 .87225 L
.50489 .87229 L
.50413 .87232 L
.5034 .87235 L
.50262 .87237 L
.50182 .87239 L
.50108 .87239 L
.50028 .8724 L
.49982 .8724 L
.49939 .8724 L
.49863 .87239 L
.49792 .87238 L
.49715 .87236 L
.49633 .87234 L
.49465 .87227 L
.49305 .87219 L
.49008 .87196 L
.48689 .87164 L
.48343 .87118 L
.47727 .8701 L
.47165 .8688 L
.46002 .86513 L
.44784 .85974 L
.43714 .85349 L
.42657 .84568 L
.41759 .83742 L
.40895 .82762 L
.39626 .80805 L
.39152 .79795 L
.38752 .78707 L
.38594 .78174 L
.3845 .77598 L
.38347 .77104 L
.38257 .76565 L
.38189 .76044 L
.38144 .75563 L
.38126 .753 L
.38115 .75062 L
.3811 .74931 L
.38108 .74862 L
.38106 .74789 L
.38104 .74725 L
.38103 .74655 L
.38103 .74592 L
.38102 .74532 L
.38102 .74476 L
.38102 .74415 L
.38102 .74358 L
.38103 .74307 L
.38103 .74246 L
Mistroke
.38105 .74181 L
.38107 .74062 L
.38111 .73938 L
.38116 .73808 L
.38128 .73576 L
.38158 .73169 L
.38202 .72729 L
.38261 .72276 L
.38326 .71871 L
.38505 .7099 L
.38952 .69427 L
.39483 .68066 L
.40126 .66766 L
.40795 .65649 L
.41538 .64597 L
.42272 .63705 L
.42985 .6295 L
.43743 .62249 L
.44469 .61665 L
.45159 .61182 L
.45885 .60746 L
.46575 .60399 L
.473 .60103 L
.4799 .59886 L
.48649 .59738 L
.48987 .59685 L
.4916 .59664 L
.49345 .59645 L
.49519 .59632 L
.49595 .59627 L
.49677 .59623 L
.49756 .5962 L
.49829 .59618 L
.49869 .59618 L
.49906 .59617 L
.49926 .59617 L
.49948 .59617 L
.49969 .59617 L
.49988 .59617 L
.5001 .59617 L
.5003 .59617 L
.50048 .59617 L
.50068 .59617 L
.5009 .59617 L
.50112 .59617 L
.50154 .59618 L
.50191 .59619 L
.50227 .5962 L
.50308 .59623 L
.50396 .59627 L
Mistroke
.50477 .59632 L
.50659 .59646 L
.50826 .59662 L
.50981 .59681 L
.51335 .59736 L
.51685 .59806 L
.52004 .59885 L
.52695 .60101 L
.53367 .60373 L
.54091 .60733 L
.54797 .61153 L
.55484 .61629 L
.56223 .6222 L
.56939 .62875 L
.577 .63675 L
.58428 .64553 L
.59113 .65508 L
.59811 .66652 L
.60436 .67887 L
.61023 .69353 L
.61277 .70151 L
.61479 .70921 L
.61645 .71708 L
.61715 .72122 L
.61779 .72575 L
.6183 .73039 L
.61865 .7347 L
.61878 .7368 L
.61883 .73791 L
.61888 .7391 L
.61891 .74014 L
.61894 .7413 L
.61895 .7418 L
.61896 .74235 L
.61897 .74287 L
.61898 .74334 L
.61898 .74395 L
.61898 .74453 L
.61898 .74506 L
.61898 .74562 L
.61897 .74624 L
.61897 .74655 L
.61896 .7469 L
.61894 .74808 L
.61891 .74918 L
.61886 .75038 L
.61876 .75254 L
.61859 .75529 L
.61837 .75791 L
.61782 .76288 L
Mistroke
.61711 .76776 L
.61614 .773 L
.61385 .7825 L
.61019 .79365 L
.60574 .80407 L
.59426 .82338 L
.58674 .83277 L
.57767 .84199 L
.55847 .85624 L
.54735 .86207 L
.5347 .86697 L
.5283 .86882 L
.52121 .8704 L
.51793 .87097 L
.51443 .87148 L
.51142 .87182 L
.5081 .87211 L
.50647 .87222 L
.50561 .87226 L
.50469 .8723 L
.50381 .87234 L
.50301 .87236 L
.5022 .87238 L
.50144 .87239 L
.5007 .8724 L
.49991 .8724 L
.49925 .8724 L
.49851 .87239 L
.49772 .87238 L
.49687 .87236 L
.49607 .87233 L
.49534 .8723 L
.49359 .87222 L
.49197 .87212 L
.48831 .8718 L
.48509 .87142 L
.4817 .87091 L
.47566 .86976 L
.46926 .86816 L
.458 .86435 L
.44628 .85892 L
.43481 .85193 L
.41676 .83657 L
.40894 .8276 L
.40172 .81747 L
.39595 .80746 L
.39086 .79636 L
.38705 .78557 L
.38443 .77564 L
.38347 .77099 L
Mistroke
.38262 .76604 L
.38191 .76065 L
.38144 .75566 L
.38127 .75306 L
.38115 .75067 L
.3811 .7493 L
.38106 .74806 L
.38105 .74737 L
.38104 .74664 L
.38103 .7463 L
.38103 .74594 L
.38102 .7453 L
.38102 .7447 L
.38102 .74415 L
.38102 .74352 L
.38103 .74292 L
.38104 .74237 L
.38104 .74186 L
.38107 .74072 L
.3811 .73957 L
.38115 .73831 L
.38128 .73578 L
.38143 .73349 L
.38163 .73111 L
.38207 .72691 L
.38266 .72248 L
.38343 .71774 L
.38514 .70949 L
.38736 .70108 L
.39272 .68566 L
.39879 .67234 L
.40519 .66086 L
.4124 .64999 L
.41956 .64074 L
.42655 .63288 L
.43401 .62554 L
.44117 .61938 L
.4487 .61375 L
.45588 .60916 L
.4627 .60545 L
.46986 .60223 L
.47668 .5998 L
.48318 .59806 L
.48649 .59739 L
.48819 .5971 L
.49005 .59683 L
.4917 .59663 L
.49346 .59645 L
.49443 .59637 L
.49531 .59631 L
Mistroke
.49615 .59627 L
.49704 .59622 L
.49785 .5962 L
.49831 .59619 L
.49874 .59618 L
.49894 .59617 L
.49913 .59617 L
.4993 .59617 L
.49949 .59617 L
.49969 .59617 L
.49988 .59617 L
.5001 .59617 L
.5003 .59617 L
.50052 .59617 L
.50063 .59617 L
.50076 .59617 L
.50117 .59618 L
.50141 .59618 L
.50166 .59618 L
.50212 .5962 L
.50302 .59623 L
.50383 .59626 L
.50552 .59637 L
.50708 .5965 L
.51062 .59692 L
.51381 .59744 L
.51734 .59818 L
.52427 .6001 L
.53101 .60258 L
.53826 .60593 L
.54533 .60988 L
.55222 .6144 L
.55963 .62003 L
.56682 .62631 L
.57449 .63399 L
.58185 .64246 L
.58881 .65169 L
.59595 .66276 L
.60242 .67476 L
.60805 .68761 L
.61084 .69534 L
.61312 .70277 L
.61519 .71092 L
.61676 .71883 L
.61745 .72319 L
.61797 .72722 L
.61843 .73178 L
.61863 .73432 L
.61877 .73673 L
.61887 .73893 L
Mistroke
.61891 .74018 L
.61895 .74135 L
.61896 .74199 L
.61897 .74259 L
.61897 .74314 L
.61898 .74373 L
.61898 .74404 L
.61898 .74438 L
.61898 .74473 L
.61898 .74507 L
.61898 .74566 L
.61897 .746 L
.61897 .7463 L
.61896 .74685 L
.61895 .74744 L
.61893 .7485 L
.61889 .74977 L
.61884 .75092 L
.61872 .7532 L
.61858 .75536 L
.61813 .76023 L
.61747 .76544 L
.61673 .76992 L
.61574 .77489 L
.61313 .78497 L
.60935 .79582 L
.60441 .80675 L
.59865 .81688 L
.58468 .83504 L
.57595 .84353 L
.56559 .85165 L
.55495 .85825 L
.5445 .86332 L
.53269 .86759 L
.52629 .86931 L
.51942 .87072 L
.51624 .87123 L
.51323 .87162 L
.50974 .87198 L
.50819 .8721 L
.50655 .87221 L
.50512 .87228 L
.50436 .87231 L
.50354 .87234 L
.50279 .87236 L
.5021 .87238 L
.50141 .87239 L
.50076 .8724 L
.5 .8724 L
.4992 .8724 L
Mistroke
.49844 .87239 L
.49775 .87238 L
.49694 .87236 L
.49606 .87233 L
.49447 .87226 L
.49291 .87218 L
.49124 .87206 L
.48823 .87179 L
.48467 .87136 L
.48143 .87087 L
.47447 .86949 L
.468 .86779 L
.4558 .86345 L
.44512 .85829 L
.43499 .85205 L
.42476 .84414 L
.41543 .83516 L
.40791 .82628 L
.39578 .80712 L
.39128 .79738 L
.38739 .78664 L
.38462 .77647 L
.38344 .77082 L
.38258 .76574 L
.38192 .76069 L
.38148 .75608 L
.38131 .75369 L
.38117 .75109 L
.38112 .74978 L
.38109 .74907 L
.38107 .74839 L
.38106 .74776 L
.38104 .74708 L
.38103 .74646 L
.38103 .74588 L
.38102 .74526 L
.38102 .74494 L
.38102 .7446 L
.38102 .74399 L
.38103 .74343 L
.38103 .74309 L
.38103 .74276 L
.38104 .74216 L
.38105 .74151 L
.38107 .7408 L
.3811 .73961 L
.38115 .73835 L
.38126 .73611 L
.3814 .73399 L
.38155 .73201 L
Mistroke
.38199 .72757 L
.38259 .72295 L
.38327 .71865 L
.38484 .71081 L
.38904 .69569 L
.39463 .68113 L
.40077 .66855 L
.40785 .65664 L
.415 .64648 L
.42204 .63783 L
.42961 .62974 L
.43691 .62295 L
.44387 .61727 L
.45122 .61206 L
.45821 .60782 L
.46554 .60409 L
.47251 .60121 L
.47915 .59907 L
.48248 .59822 L
.48615 .59745 L
.48961 .59689 L
.49285 .59651 L
.49452 .59637 L
.49544 .59631 L
.49629 .59626 L
.49707 .59623 L
.49779 .5962 L
.49817 .59619 L
.49858 .59618 L
.49881 .59618 L
.49902 .59618 L
.49922 .59617 L
.49943 .59617 L
.49964 .59617 L
.49985 .59617 L
.50004 .59617 L
.50023 .59617 L
.50044 .59617 L
.50064 .59617 L
.50087 .59618 L
.50108 .59618 L
.50147 .59618 L
.50182 .59619 L
.50262 .59622 L
.50344 .59625 L
.50433 .5963 L
.50613 .59642 L
.50787 .59658 L
.50946 .59677 L
.51303 .59731 L
Mistroke
.51631 .59795 L
.51988 .59881 L
.52694 .60101 L
.53382 .6038 L
.5405 .60712 L
.54772 .61138 L
.55474 .61623 L
.56229 .62226 L
.56962 .62898 L
.57667 .63637 L
.58411 .64531 L
.59111 .65507 L
.59825 .66676 L
.60462 .67944 L
.61005 .69301 L
.61245 .70043 L
.61474 .709 L
.61653 .71756 L
.61781 .72591 L
.61832 .73062 L
.61853 .73298 L
.61868 .73518 L
.61879 .73719 L
.61889 .73934 L
.61892 .74046 L
.61895 .74151 L
.61896 .74212 L
.61897 .74268 L
.61897 .74329 L
.61898 .7436 L
.61898 .74394 L
.61898 .74457 L
.61898 .74515 L
.61898 .74546 L
.61897 .7458 L
.61897 .74615 L
.61897 .74648 L
.61896 .74709 L
.61895 .74764 L
.61891 .7489 L
.61888 .75001 L
.61883 .75124 L
.61871 .75347 L
.61852 .75608 L
.61827 .75888 L
.61768 .76395 L
.61686 .76919 L
.61574 .7749 L
.61302 .78533 L
.6094 .79569 L
Mistroke
.60452 .80654 L
.59277 .82539 L
.58523 .83445 L
.57602 .84346 L
.56628 .85116 L
.55465 .85842 L
.54259 .86411 L
.53657 .86635 L
.5308 .86814 L
.52462 .86969 L
.51887 .87082 L
.5158 .87129 L
.51242 .87172 L
.50901 .87204 L
.50715 .87217 L
.50541 .87227 L
.50457 .87231 L
.50368 .87234 L
.50292 .87236 L
.50209 .87238 L
.50162 .87239 L
.50119 .87239 L
.5007 .8724 L
.50023 .8724 L
.49939 .8724 L
.49892 .87239 L
.49848 .87239 L
.49763 .87237 L
.49682 .87235 L
.49532 .8723 L
.4937 .87222 L
.49195 .87211 L
.48886 .87185 L
.48561 .87148 L
.47984 .87059 L
.47374 .86931 L
.46731 .86759 L
.45609 .86357 L
.44379 .85755 L
.43301 .85066 L
.41517 .83489 L
.40747 .82571 L
.40046 .81544 L
.39078 .79615 L
.38721 .78608 L
.38435 .77527 L
.3833 .77009 L
.3824 .76447 L
.38207 .76193 L
.38176 .75923 L
Mistroke
.38154 .75688 L
.38135 .75441 L
.38127 .75315 L
.3812 .75177 L
.38114 .75051 L
.3811 .74936 L
.38106 .74801 L
.38105 .74726 L
.38104 .74656 L
.38103 .74625 L
.38103 .74592 L
.38102 .74532 L
.38102 .74499 L
.38102 .74468 L
.38102 .74434 L
.38102 .74398 L
.38103 .74337 L
.38103 .7428 L
.38104 .74219 L
.38105 .74153 L
.38109 .74019 L
.38113 .73897 L
.38123 .73664 L
.38137 .73446 L
.38174 .73 L
.38226 .72537 L
.38351 .7173 L
.38524 .7091 L
.38717 .70175 L
.3921 .68723 L
.39828 .67335 L
.40486 .66141 L
.41156 .65117 L
.41893 .64151 L
.42614 .63331 L
.43384 .6257 L
.44122 .61935 L
.44826 .61407 L
.45567 .60929 L
.46271 .60545 L
.46939 .60242 L
.47643 .59988 L
.48314 .59807 L
.48678 .59734 L
.48845 .59706 L
.49022 .59681 L
.49184 .59662 L
.49362 .59644 L
.49524 .59632 L
.49675 .59624 L
Mistroke
.49755 .59621 L
.49801 .5962 L
.49843 .59619 L
.49887 .59618 L
.49911 .59618 L
.49934 .59618 L
.49955 .59617 L
.49975 .59617 L
.49996 .59617 L
.50007 .59617 L
.50019 .59617 L
.5004 .59617 L
.5006 .59618 L
.50078 .59618 L
.50097 .59618 L
.50141 .59619 L
.50182 .59619 L
.50255 .59622 L
.50334 .59625 L
.50493 .59633 L
.50664 .59647 L
.50976 .59681 L
.51317 .59733 L
.51678 .59805 L
.52334 .59981 L
.53038 .60233 L
.53724 .60543 L
.54463 .60947 L
.55184 .61414 L
.55885 .6194 L
.56637 .6259 L
.57365 .63309 L
.58062 .64096 L
.58793 .65045 L
.59475 .66076 L
.60159 .67309 L
.60757 .68639 L
.61249 .70058 L
.6146 .70844 L
.61647 .71722 L
.61722 .72167 L
.61789 .72661 L
.61839 .73137 L
.61858 .73369 L
.61872 .73583 L
.61883 .73803 L
.61888 .73924 L
.61892 .7404 L
.61895 .74148 L
.61896 .74247 L
Mistroke
.61897 .743 L
.61897 .74357 L
.61898 .74418 L
.61898 .74474 L
.61898 .74533 L
.61897 .74596 L
.61897 .74628 L
.61896 .74663 L
.61895 .74725 L
.61893 .74846 L
.61889 .74956 L
.61884 .75086 L
.61877 .75227 L
.61862 .75484 L
.6182 .75956 L
.61756 .76481 L
.61665 .77035 L
.61559 .77557 L
.61279 .78608 L
.6094 .7957 L
.60503 .8055 L
.59921 .81598 L
.59201 .82638 L
.58444 .8353 L
.5661 .85129 L
.55572 .85782 L
.54366 .86367 L
.5314 .86797 L
.52504 .8696 L
.5214 .87036 L
.51794 .87097 L
.51475 .87143 L
.51127 .87184 L
.50974 .87198 L
.5081 .87211 L
.50657 .87221 L
.50516 .87228 L
.50353 .87234 L
.50268 .87237 L
.50225 .87237 L
.50178 .87238 L
.501 .87239 L
.50027 .8724 L
.4994 .8724 L
.49861 .87239 L
.49816 .87238 L
.49768 .87237 L
.49683 .87235 L
.49591 .87232 L
.49489 .87228 L
Mistroke
.49309 .87219 L
.4914 .87207 L
.48813 .87177 L
.48458 .87134 L
.47817 .87028 L
.47202 .86889 L
.46642 .86731 L
.45506 .86313 L
.44321 .85722 L
.4329 .85057 L
.42276 .84238 L
.41423 .83385 L
.40606 .82381 L
.39425 .80403 L
.38991 .79392 L
.38631 .78304 L
.38492 .77775 L
.38367 .77204 L
.3828 .76713 L
.38205 .76179 L
.38177 .7593 L
.38153 .75665 L
.38135 .75437 L
.38121 .7519 L
.38114 .75046 L
.38109 .74914 L
.38106 .74788 L
.38105 .74717 L
.38104 .74654 L
.38103 .74591 L
.38102 .74534 L
.38102 .74471 L
.38102 .74439 L
.38102 .74404 L
.38103 .74346 L
.38103 .74284 L
.38104 .74225 L
.38105 .74172 L
.38108 .74063 L
.38111 .73943 L
.38121 .73703 L
.38134 .73482 L
.38149 .73277 L
.38192 .72821 L
.38253 .7234 L
.38401 .71473 L
.386 .70601 L
.39055 .69135 L
.39639 .67725 L
.4027 .66509 L
Mistroke
.40988 .65359 L
.41708 .6438 L
.42415 .63547 L
.43171 .6277 L
.43899 .62118 L
.44593 .61574 L
.45324 .61077 L
.46019 .60675 L
.46748 .60323 L
.47443 .60054 L
.48104 .59858 L
.48442 .59779 L
.48802 .59713 L
.48978 .59687 L
.49168 .59664 L
.49332 .59647 L
.49419 .5964 L
.49512 .59633 L
.49604 .59628 L
.49688 .59624 L
.49728 .59622 L
.49772 .59621 L
.49813 .5962 L
.49852 .59619 L
.49895 .59618 L
.49917 .59618 L
.49942 .59618 L
.49954 .59618 L
.49968 .59618 L
.4998 .59617 L
.49992 .59617 L
.50014 .59617 L
.50027 .59617 L
.50038 .59618 L
.5006 .59618 L
.50081 .59618 L
.50103 .59618 L
.50127 .59619 L
.50166 .59619 L
.5021 .5962 L
.50299 .59623 L
.50383 .59627 L
.50542 .59637 L
.50712 .59651 L
.50898 .59671 L
.51235 .59719 L
.51595 .59787 L
.52244 .59954 L
.52942 .60195 L
.53621 .60492 L
Mistroke
.54353 .60882 L
.55066 .61333 L
.55761 .61842 L
.56506 .6247 L
.57228 .63166 L
.57993 .64014 L
.58719 .64944 L
.59399 .65953 L
.60083 .6716 L
.60685 .68463 L
.61186 .69851 L
.61421 .70683 L
.61601 .7148 L
.61676 .71888 L
.61748 .72341 L
.61803 .72776 L
.61844 .73193 L
.61862 .73422 L
.61877 .73671 L
.61882 .73783 L
.61887 .73901 L
.61891 .74011 L
.61894 .74113 L
.61895 .7417 L
.61896 .74232 L
.61896 .74266 L
.61897 .74298 L
.61897 .7436 L
.61898 .74413 L
.61898 .74472 L
.61898 .74534 L
.61897 .74592 L
.61897 .74623 L
.61896 .74657 L
.61895 .74726 L
.61892 .74849 L
.61888 .74992 L
.61882 .75127 L
.61869 .75376 L
.61849 .75648 L
.61799 .76146 L
.61733 .76636 L
.61655 .77091 L
.61436 .7806 L
.61105 .79131 L
.60698 .80139 L
.60155 .81205 L
.59534 .82186 L
.58738 .83204 L
.56946 .84883 L
Mistroke
.55912 .85585 L
.54721 .86213 L
.54164 .86449 L
.53547 .86672 L
.52955 .86848 L
.52395 .86984 L
.5178 .87099 L
.51451 .87147 L
.51098 .87186 L
.5092 .87202 L
.50726 .87217 L
.50543 .87227 L
.50455 .87231 L
.50373 .87234 L
.50293 .87236 L
.50221 .87238 L
.50139 .87239 L
.50095 .87239 L
.50052 .8724 L
.49968 .8724 L
.4989 .87239 L
.49804 .87238 L
.49756 .87237 L
.49712 .87236 L
.49559 .87231 L
.49472 .87228 L
.49391 .87223 L
.49053 .872 L
.48762 .87172 L
.48451 .87133 L
.47746 .87013 L
.47113 .86866 L
.4593 .86485 L
.44709 .85934 L
.43624 .8529 L
.4257 .84494 L
.40956 .82839 L
.40277 .81907 L
.39657 .80863 L
.39177 .79854 L
.38763 .7874 L
.38468 .77676 L
.38277 .76696 L
.38203 .76163 L
.38174 .75903 L
.38153 .75665 L
.38136 .75454 L
.38122 .75224 L
.38112 .74993 L
.38108 .74868 L
Mistroke
.38105 .74751 L
.38104 .7469 L
.38104 .74657 L
.38103 .74626 L
.38103 .74565 L
.38102 .7451 L
.38102 .74478 L
.38102 .74445 L
.38102 .74385 L
.38103 .74351 L
.38103 .7432 L
.38103 .74286 L
.38104 .7425 L
.38105 .74189 L
.38106 .74123 L
.38109 .74004 L
.38113 .73888 L
.38118 .73782 L
.38143 .73363 L
.38159 .73154 L
.38181 .72926 L
.38294 .72064 L
.38377 .71594 L
.38463 .71174 L
.38895 .69598 L
.39415 .68223 L
.40049 .66908 L
.40712 .65778 L
.41451 .64713 L
.42183 .63808 L
.42894 .63042 L
.43651 .6233 L
.44376 .61736 L
.45066 .61244 L
.45792 .60799 L
.46482 .60443 L
.47206 .60138 L
.47896 .59913 L
.48554 .59757 L
.48892 .59699 L
.49064 .59676 L
.4925 .59655 L
.49423 .5964 L
.49498 .59634 L
.49581 .59629 L
.49654 .59625 L
.49733 .59622 L
.49776 .59621 L
.49815 .5962 L
.49855 .59619 L
Mistroke
.49892 .59618 L
.49911 .59618 L
.49931 .59618 L
.49943 .59618 L
.49954 .59617 L
.49974 .59617 L
.49996 .59617 L
.50016 .59617 L
.50038 .59617 L
.5005 .59617 L
.50061 .59618 L
.50082 .59618 L
.501 .59618 L
.50142 .59619 L
.50179 .59619 L
.50218 .5962 L
.50305 .59624 L
.50386 .59627 L
.50571 .59639 L
.5075 .59655 L
.50918 .59674 L
.51235 .59719 L
.51576 .59783 L
.51893 .59857 L
.52572 .60059 L
.53231 .60314 L
.53941 .60653 L
.54633 .61051 L
.55379 .61553 L
.55746 .6183 L
Mfstroke
.5 .78846 m
.49991 .78846 L
.49984 .78846 L
.49975 .78846 L
.49966 .78846 L
.49951 .78845 L
.49935 .78845 L
.49917 .78844 L
.49897 .78843 L
.49863 .78841 L
.49828 .78837 L
.49795 .78834 L
.4972 .78823 L
.49644 .78808 L
.49576 .78792 L
.49424 .78745 L
.49297 .78693 L
.49163 .78625 L
.48922 .7846 L
.48721 .78264 L
.48631 .78153 L
.48546 .78026 L
.48421 .77773 L
.48374 .77641 L
.48355 .77573 L
.48338 .77499 L
.48324 .77429 L
.48315 .77364 L
.48311 .77333 L
.48307 .773 L
.48305 .7727 L
.48303 .77238 L
.48302 .77221 L
.48301 .77205 L
.48301 .7719 L
.48301 .77181 L
.48301 .77174 L
.483 .77165 L
.483 .77161 L
.483 .77156 L
.483 .77148 L
.483 .7714 L
.483 .77135 L
.483 .7713 L
.483 .77125 L
.483 .7712 L
.48301 .77112 L
.48301 .77103 L
.48301 .77084 L
.48302 .77064 L
Mistroke
.48304 .77027 L
.48307 .76992 L
.4831 .76959 L
.4832 .76888 L
.48331 .76821 L
.48359 .76698 L
.484 .76569 L
.48446 .76454 L
.4857 .76222 L
.48721 .76021 L
.4891 .75836 L
.49116 .75688 L
.49229 .75626 L
.49355 .75567 L
.4947 .75525 L
.496 .75488 L
.49724 .75463 L
.49793 .75453 L
.49824 .75449 L
.49858 .75446 L
.49891 .75444 L
.49922 .75442 L
.49938 .75441 L
.49954 .75441 L
.49962 .7544 L
.49971 .7544 L
.49976 .7544 L
.4998 .7544 L
.49988 .7544 L
.49996 .7544 L
.50002 .7544 L
.5001 .7544 L
.50017 .7544 L
.50024 .7544 L
.50031 .7544 L
.50045 .75441 L
.50059 .75441 L
.50075 .75442 L
.50107 .75443 L
.50138 .75446 L
.50172 .75449 L
.50231 .75456 L
.50294 .75466 L
.50363 .75479 L
.50485 .75511 L
.50612 .75554 L
.5073 .75605 L
.50854 .75671 L
.51067 .75818 L
.51262 .76002 L
Mistroke
.5142 .76207 L
.51542 .76428 L
.51592 .76548 L
.51636 .76681 L
.51653 .76747 L
.51669 .7682 L
.51681 .7689 L
.51689 .76956 L
.51693 .7699 L
.51696 .77028 L
.51697 .77045 L
.51698 .77063 L
.51698 .77079 L
.51699 .77087 L
.51699 .77096 L
.51699 .77104 L
.51699 .77112 L
.51699 .7712 L
.517 .77127 L
.517 .77134 L
.517 .77141 L
.517 .77149 L
.517 .77157 L
.51699 .77165 L
.51699 .77173 L
.51699 .77181 L
.51699 .77189 L
.51698 .77207 L
.51698 .77223 L
.51696 .77258 L
.51693 .77296 L
.51685 .77364 L
.51675 .77431 L
.51664 .77491 L
.51632 .77618 L
.51586 .77755 L
.51532 .77881 L
.51462 .78011 L
.51292 .7825 L
.51089 .7845 L
.50864 .78609 L
.50739 .78677 L
.50599 .78737 L
.50451 .78785 L
.50381 .78803 L
.50308 .78818 L
.50239 .78829 L
.50202 .78834 L
.50163 .78838 L
.50126 .78841 L
Mistroke
.50093 .78843 L
.50077 .78844 L
.5006 .78845 L
.50052 .78845 L
.50043 .78845 L
.50035 .78846 L
.50028 .78846 L
.50019 .78846 L
.5001 .78846 L
.50001 .78846 L
.49992 .78846 L
.49984 .78846 L
.49975 .78846 L
.49968 .78846 L
.4996 .78845 L
.49941 .78845 L
.49921 .78844 L
.49886 .78842 L
.49853 .7884 L
.49823 .78837 L
.49754 .78828 L
.49679 .78815 L
.49608 .788 L
.49478 .78764 L
.49343 .78714 L
.49222 .78657 L
.48982 .78507 L
.48779 .78328 L
.4868 .78216 L
.48598 .78106 L
.48463 .77869 L
.48411 .77746 L
.48365 .77609 L
.48333 .77476 L
.4832 .77401 L
.48311 .77333 L
.48308 .77299 L
.48305 .77264 L
.48303 .77234 L
.48302 .77217 L
.48302 .77201 L
.48301 .77192 L
.48301 .77182 L
.48301 .77173 L
.48301 .77165 L
.48301 .77156 L
.48301 .77149 L
.48301 .7714 L
.48301 .77132 L
.48301 .77123 L
Mistroke
.48301 .77118 L
.48301 .77113 L
.48301 .77096 L
.48301 .77087 L
.48302 .77077 L
.48303 .77058 L
.48305 .77022 L
.48308 .76989 L
.48316 .76914 L
.48326 .76848 L
.4834 .76779 L
.48373 .76651 L
.48413 .76535 L
.48523 .76301 L
.48593 .76188 L
.48676 .76076 L
.48846 .75893 L
.49054 .75729 L
.49274 .75604 L
.49401 .7555 L
.49524 .75508 L
.49585 .75492 L
.49649 .75477 L
.4971 .75465 L
.49766 .75456 L
.49826 .75449 L
.4986 .75446 L
.49891 .75444 L
.49906 .75443 L
.49921 .75442 L
.49934 .75442 L
.49948 .75441 L
.49956 .75441 L
.49963 .75441 L
.4997 .75441 L
.49977 .7544 L
.49984 .7544 L
.49992 .7544 L
.5 .7544 L
.50005 .7544 L
.50009 .7544 L
.50017 .7544 L
.50024 .7544 L
.50032 .75441 L
.5004 .75441 L
.50057 .75441 L
.50073 .75442 L
.50103 .75443 L
.50132 .75445 L
.50195 .75452 L
Mistroke
.50265 .75461 L
.5033 .75473 L
.50389 .75485 L
.50519 .75522 L
.50636 .75564 L
.50758 .75619 L
.50986 .75756 L
.51184 .75921 L
.51349 .76108 L
.5143 .76222 L
.51495 .76333 L
.516 .7657 L
.51639 .76693 L
.51655 .76758 L
.5167 .7683 L
.51682 .76898 L
.5169 .76963 L
.51693 .76999 L
.51696 .77032 L
.51698 .77068 L
.51699 .77086 L
.51699 .77097 L
.51699 .77106 L
.51699 .77115 L
.51699 .77124 L
.51699 .77133 L
.517 .77138 L
.517 .77143 L
.51699 .77151 L
.51699 .77159 L
.51699 .77164 L
.51699 .77168 L
.51699 .77177 L
.51699 .77186 L
.51699 .77193 L
.51698 .7721 L
.51697 .77241 L
.51694 .77277 L
.51691 .77316 L
.51682 .77385 L
.51672 .77451 L
.51657 .77522 L
.51618 .77664 L
.51571 .77792 L
.51509 .77926 L
.5144 .78048 L
.51353 .78174 L
.51162 .78386 L
.51056 .78477 L
.50931 .78568 L
Mistroke
.50682 .78703 L
.50551 .78754 L
.50405 .78797 L
.50333 .78813 L
.50254 .78827 L
.50218 .78832 L
.50179 .78836 L
.50145 .7884 L
.50109 .78842 L
.50091 .78844 L
.5007 .78845 L
.50052 .78845 L
.50043 .78845 L
.50034 .78846 L
.50029 .78846 L
.50024 .78846 L
.50019 .78846 L
.50014 .78846 L
.50005 .78846 L
.49995 .78846 L
.4999 .78846 L
.49985 .78846 L
.49979 .78846 L
.49974 .78846 L
.49964 .78846 L
.49953 .78845 L
.49934 .78845 L
.49917 .78844 L
.49877 .78842 L
.49841 .78839 L
.49807 .78835 L
.49737 .78825 L
.49663 .78812 L
.49533 .7878 L
.49398 .78736 L
.49276 .78684 L
.49033 .78544 L
.48912 .78452 L
.48806 .78355 L
.48628 .78148 L
.48544 .78022 L
.48478 .77902 L
.4842 .77771 L
.48376 .77647 L
.48342 .77517 L
.48328 .77448 L
.48316 .77375 L
.48309 .7731 L
.48305 .77273 L
.48303 .7724 L
Mistroke
.48302 .77225 L
.48302 .77209 L
.48301 .772 L
.48301 .77191 L
.48301 .77183 L
.48301 .77175 L
.48301 .77167 L
.48301 .7716 L
.483 .77152 L
.483 .77143 L
.483 .77136 L
.48301 .77128 L
.48301 .7712 L
.48301 .77114 L
.48301 .77105 L
.48301 .77098 L
.48302 .7708 L
.48302 .77063 L
.48303 .77045 L
.48306 .77012 L
.48308 .76982 L
.48316 .7691 L
.48327 .76842 L
.48356 .76711 L
.48392 .76592 L
.48442 .76463 L
.48496 .76351 L
.48637 .76126 L
.48803 .75934 L
.49008 .75761 L
.49119 .75687 L
.49227 .75627 L
.49341 .75573 L
.49453 .75531 L
.49579 .75493 L
.49696 .75468 L
.49757 .75458 L
.49823 .7545 L
.4985 .75447 L
.49879 .75445 L
.49911 .75443 L
.49926 .75442 L
.49941 .75441 L
.49957 .75441 L
.49966 .75441 L
.49974 .7544 L
.49982 .7544 L
.49989 .7544 L
.49997 .7544 L
.50006 .7544 L
Mistroke
.50014 .7544 L
.50019 .7544 L
.50023 .7544 L
.50031 .7544 L
.50039 .75441 L
.50057 .75441 L
.50076 .75442 L
.50109 .75444 L
.50143 .75446 L
.50205 .75453 L
.50265 .75461 L
.50329 .75472 L
.50443 .75499 L
.50566 .75538 L
.50693 .75588 L
.5091 .75705 L
.51121 .75863 L
.513 .76046 L
.5138 .7615 L
.51459 .7627 L
.51577 .76508 L
.51622 .76634 L
.51641 .767 L
.51659 .76771 L
.51672 .76839 L
.51682 .76902 L
.51686 .76932 L
.5169 .76966 L
.51693 .76995 L
.51696 .77026 L
.51697 .77045 L
.51698 .77063 L
.51698 .77079 L
.51699 .77088 L
.51699 .77097 L
.51699 .77106 L
.51699 .77113 L
.51699 .77121 L
.517 .77128 L
.517 .77137 L
.517 .77144 L
.517 .77153 L
.51699 .77161 L
.51699 .7717 L
.51699 .77178 L
.51699 .77187 L
.51699 .77197 L
.51698 .77213 L
.51697 .7723 L
.51695 .77269 L
Mistroke
.51692 .77306 L
.51683 .77378 L
.51672 .77446 L
.51645 .77573 L
.51604 .77707 L
.51556 .77827 L
.51493 .77957 L
.51424 .78072 L
.5126 .78286 L
.51057 .78477 L
.50941 .78561 L
.50808 .78641 L
.50685 .78702 L
.50544 .78756 L
.50406 .78797 L
.50329 .78814 L
.50256 .78827 L
.50186 .78836 L
.5015 .78839 L
.50111 .78842 L
.50077 .78844 L
.50058 .78845 L
.50049 .78845 L
.50041 .78846 L
.50033 .78846 L
.50025 .78846 L
.50016 .78846 L
.50008 .78846 L
.5 .78846 L
.49991 .78846 L
.49983 .78846 L
.49976 .78846 L
.49967 .78846 L
.49958 .78846 L
.49941 .78845 L
.49923 .78844 L
.49904 .78843 L
.4987 .78841 L
.49838 .78838 L
.49765 .7883 L
.49688 .78817 L
.49549 .78785 L
.49422 .78745 L
.49286 .78688 L
.49166 .78627 L
.48929 .78465 L
.48731 .78276 L
.48643 .78169 L
.48557 .78043 L
.48431 .77797 L
Mistroke
.48384 .77669 L
.48363 .77603 L
.48345 .77529 L
.48331 .77463 L
.48319 .77392 L
.48313 .77353 L
.48309 .77317 L
.48306 .77283 L
.48304 .77247 L
.48302 .77215 L
.48301 .77196 L
.48301 .77187 L
.48301 .77179 L
.48301 .77171 L
.48301 .77163 L
.483 .77155 L
.483 .77148 L
.483 .7714 L
.483 .77132 L
.48301 .77124 L
.48301 .77115 L
.48301 .77107 L
.48301 .77098 L
.48302 .7708 L
.48302 .77063 L
.48303 .77047 L
.48306 .77011 L
.48309 .76973 L
.48317 .76904 L
.48329 .7683 L
.4836 .76697 L
.484 .7657 L
.48453 .76439 L
.48573 .76218 L
.48734 .76007 L
.48917 .75831 L
.49018 .75753 L
.49136 .75677 L
.49366 .75563 L
.49485 .7552 L
.49615 .75484 L
.4968 .75471 L
.4975 .75459 L
.49783 .75454 L
.49817 .7545 L
.49849 .75447 L
.49879 .75444 L
.4991 .75443 L
.49924 .75442 L
.4994 .75441 L
Mistroke
.49947 .75441 L
.49956 .75441 L
.49964 .75441 L
.49971 .7544 L
.49979 .7544 L
.49984 .7544 L
.49988 .7544 L
.49996 .7544 L
.50001 .7544 L
.50005 .7544 L
.50012 .7544 L
.5002 .7544 L
.50028 .7544 L
.50035 .7544 L
.50048 .75441 L
.50062 .75441 L
.50091 .75443 L
.50123 .75445 L
.50156 .75447 L
.50188 .75451 L
.50247 .75458 L
.5031 .75469 L
.50379 .75483 L
.50501 .75516 L
.50629 .75561 L
.50747 .75613 L
.5087 .7568 L
.51083 .75831 L
.51276 .76018 L
.51432 .76226 L
.51552 .76449 L
.51601 .7657 L
.51642 .76705 L
.51659 .76772 L
.51673 .76846 L
.51684 .76916 L
.51688 .76947 L
.51692 .76981 L
.51695 .77016 L
.51697 .77047 L
.51698 .77077 L
.51699 .77093 L
.51699 .771 L
.51699 .77109 L
.51699 .77114 L
.51699 .77119 L
.517 .77128 L
.517 .77136 L
.517 .77145 L
.517 .77149 L
Mistroke
.517 .77154 L
.517 .77163 L
.51699 .77168 L
.51699 .77173 L
.51699 .77182 L
.51699 .77199 L
.51698 .77215 L
.51696 .77251 L
.51694 .77283 L
.51691 .77317 L
.51683 .77379 L
.51671 .77452 L
.51658 .77519 L
.51624 .77647 L
.51575 .77783 L
.51513 .77919 L
.51446 .78038 L
.51282 .78261 L
.51077 .78461 L
.50849 .78618 L
.50722 .78685 L
.50581 .78743 L
.50446 .78786 L
.50316 .78816 L
.50242 .78829 L
.50205 .78834 L
.50171 .78837 L
.50137 .78841 L
.50106 .78843 L
.50072 .78845 L
.50054 .78845 L
.50045 .78845 L
.50036 .78846 L
.50027 .78846 L
.50018 .78846 L
.5001 .78846 L
.50002 .78846 L
.49993 .78846 L
.49984 .78846 L
.49975 .78846 L
.4997 .78846 L
.49965 .78846 L
.49946 .78845 L
.49936 .78845 L
.49926 .78844 L
.4989 .78843 L
.49859 .7884 L
.49825 .78837 L
.49756 .78828 L
.49682 .78816 L
Mistroke
.49616 .78802 L
.49469 .78761 L
.49339 .78712 L
.49203 .78647 L
.49081 .78576 L
.48956 .78487 L
.48748 .78295 L
.48651 .7818 L
.48573 .78068 L
.48443 .77826 L
.48394 .77702 L
.48353 .77563 L
.48337 .77494 L
.48324 .77429 L
.48313 .77354 L
.4831 .77321 L
.48306 .77285 L
.48304 .7725 L
.48302 .77218 L
.48301 .772 L
.48301 .77183 L
.48301 .77174 L
.48301 .77169 L
.483 .77164 L
.483 .7716 L
.483 .77155 L
.483 .77147 L
.483 .77139 L
.483 .7713 L
.483 .77123 L
.48301 .77115 L
.48301 .77107 L
.48301 .77097 L
.48301 .77081 L
.48302 .77065 L
.48303 .77049 L
.48305 .7702 L
.48307 .76988 L
.48311 .76954 L
.4832 .76884 L
.48331 .7682 L
.48344 .76761 L
.4838 .76629 L
.48422 .76511 L
.48539 .76273 L
.48684 .76066 L
.48868 .75872 L
.49071 .75717 L
.49285 .75598 L
.494 .7555 L
Mistroke
.49527 .75507 L
.49652 .75476 L
.49716 .75464 L
.49786 .75454 L
.4982 .7545 L
.49851 .75447 L
.4988 .75444 L
.49911 .75442 L
.49927 .75442 L
.49945 .75441 L
.49952 .75441 L
.49961 .75441 L
.49968 .7544 L
.49976 .7544 L
.4998 .7544 L
.49985 .7544 L
.49989 .7544 L
.49994 .7544 L
.49999 .7544 L
.50004 .7544 L
.50008 .7544 L
.50012 .7544 L
.5002 .7544 L
.50024 .7544 L
.50029 .7544 L
.50037 .7544 L
.50046 .75441 L
.50062 .75441 L
.50078 .75442 L
.50113 .75444 L
.50143 .75446 L
.50176 .75449 L
.50237 .75457 L
.50294 .75466 L
.50421 .75493 L
.50536 .75527 L
.5065 .7557 L
.50772 .75626 L
.50996 .75763 L
.51191 .75928 L
.51369 .76134 L
.51446 .76249 L
.51509 .7636 L
.51566 .7648 L
.5161 .76597 L
.51646 .76718 L
.51662 .76788 L
.51675 .76855 L
.51685 .7692 L
.51689 .76955 L
Mistroke
.51693 .76992 L
.51696 .77026 L
.51698 .77058 L
.51698 .77073 L
.51699 .77089 L
.51699 .77097 L
.51699 .77105 L
.51699 .77112 L
.517 .77119 L
.517 .77127 L
.517 .77132 L
.517 .77136 L
.517 .77144 L
.517 .77153 L
.517 .77161 L
.517 .77169 L
.51699 .77177 L
.51699 .77184 L
.51699 .77201 L
.51698 .7722 L
.51696 .77254 L
.51694 .77286 L
.51691 .7732 L
.51683 .7738 L
.51672 .77451 L
.51656 .77526 L
.51619 .77662 L
.51571 .77793 L
.51508 .77928 L
.51366 .78156 L
.51176 .78373 L
.50959 .78549 L
.50829 .7863 L
.50699 .78696 L
.50576 .78745 L
.50437 .78789 L
.5037 .78805 L
.50297 .7882 L
.50256 .78827 L
.50219 .78832 L
.50183 .78836 L
.50145 .7884 L
.50108 .78843 L
.50074 .78845 L
.50057 .78845 L
.50049 .78845 L
.5004 .78846 L
.50032 .78846 L
.50023 .78846 L
.50015 .78846 L
Mistroke
.50007 .78846 L
.49998 .78846 L
.49993 .78846 L
.49988 .78846 L
.49979 .78846 L
.4997 .78846 L
.4996 .78846 L
.49951 .78845 L
.49935 .78845 L
.49915 .78844 L
.49897 .78843 L
.49857 .7884 L
.49823 .78837 L
.49786 .78833 L
.49721 .78823 L
.49643 .78808 L
.49574 .78792 L
.49441 .78751 L
.49301 .78695 L
.49175 .78632 L
.49044 .78551 L
.48824 .78373 L
.48635 .78158 L
.4849 .77925 L
.4843 .77796 L
.4838 .77657 L
.48361 .77593 L
.48343 .77524 L
.4833 .77459 L
.4832 .77399 L
.4831 .77328 L
.48307 .77291 L
.48304 .77252 L
.48303 .77236 L
.48302 .77218 L
.48301 .77201 L
.48301 .77186 L
.48301 .77177 L
.483 .77168 L
.483 .77164 L
.483 .77159 L
.483 .77154 L
.483 .77149 L
.483 .7714 L
.483 .77132 L
.483 .77123 L
.483 .77118 L
.48301 .77113 L
.48301 .77096 L
.48301 .77086 L
Mistroke
.48302 .77077 L
.48303 .77043 L
.48305 .77012 L
.48308 .7698 L
.48316 .76912 L
.48328 .76839 L
.48356 .7671 L
.48397 .76576 L
.4845 .76444 L
.4851 .76324 L
.48647 .76112 L
.48825 .75912 L
.49022 .7575 L
.49131 .75679 L
.49254 .75613 L
.49367 .75563 L
.49494 .75517 L
.49618 .75484 L
.49687 .75469 L
.49751 .75458 L
.49783 .75454 L
.49818 .7545 L
.49849 .75447 L
.49881 .75444 L
.49911 .75442 L
.49927 .75442 L
.49943 .75441 L
.49958 .75441 L
.49971 .7544 L
.49978 .7544 L
.49985 .7544 L
.49993 .7544 L
.5 .7544 L
.50009 .7544 L
.50013 .7544 L
.50017 .7544 L
.50025 .7544 L
.50033 .7544 L
.5005 .75441 L
.50059 .75441 L
.50068 .75441 L
.50101 .75443 L
.50132 .75445 L
.50189 .75451 L
.5025 .75459 L
.50316 .7547 L
.50375 .75482 L
.50506 .75517 L
.50623 .75559 L
.50746 .75613 L
Mistroke
.50975 .75748 L
.51174 .75912 L
.51342 .76098 L
.51423 .76212 L
.51489 .76322 L
.51596 .76559 L
.51636 .76681 L
.51653 .76746 L
.51668 .76818 L
.5168 .76882 L
.51689 .76951 L
.51693 .7699 L
.51696 .77025 L
.51697 .77042 L
.51698 .77061 L
.51699 .77078 L
.51699 .77095 L
.51699 .77103 L
.51699 .77112 L
.517 .77121 L
.517 .77126 L
.517 .77131 L
.517 .7714 L
.517 .77148 L
.517 .77152 L
.517 .77157 L
.517 .77165 L
.517 .77173 L
.51699 .77182 L
.51699 .77199 L
.51698 .77215 L
.51698 .7723 L
.51695 .77266 L
.51693 .77299 L
.51684 .77374 L
.51674 .77441 L
.51661 .77503 L
.51625 .77643 L
.51577 .77778 L
.51524 .77897 L
.51378 .7814 L
.51201 .78349 L
.51098 .78443 L
.50976 .78537 L
.50731 .78681 L
.50601 .78736 L
.50457 .78784 L
.50386 .78802 L
.50307 .78818 L
.50232 .7883 L
Mistroke
.50162 .78838 L
.50125 .78842 L
.50106 .78843 L
.50085 .78844 L
.50067 .78845 L
.50058 .78845 L
.50047 .78846 L
.50038 .78846 L
.50029 .78846 L
.50021 .78846 L
.50013 .78846 L
.50005 .78846 L
.49996 .78846 L
.49987 .78846 L
.49979 .78846 L
.49971 .78846 L
.49964 .78846 L
.49948 .78845 L
.49931 .78845 L
.49913 .78844 L
.49877 .78842 L
.49839 .78839 L
.49803 .78835 L
.49735 .78825 L
.49663 .78812 L
.49586 .78795 L
.49447 .78754 L
.49305 .78698 L
.49065 .78566 L
.48951 .78484 L
.48838 .78386 L
.48738 .78285 L
.48641 .78166 L
.48491 .77927 L
.48432 .77801 L
.48381 .77663 L
.48361 .77594 L
.48342 .77519 L
.48329 .77453 L
.48317 .77381 L
.48312 .77346 L
.48308 .7731 L
.48306 .77278 L
.48303 .77243 L
.48302 .77223 L
.48301 .77204 L
.48301 .77186 L
.48301 .77177 L
.483 .77172 L
.483 .77167 L
Mistroke
.483 .77158 L
.483 .7715 L
.483 .77141 L
.483 .77136 L
.483 .77132 L
.483 .77123 L
.483 .77116 L
.48301 .77107 L
.48301 .77098 L
.48301 .77082 L
.48302 .77066 L
.48304 .77032 L
.48306 .76998 L
.4831 .76961 L
.48318 .76896 L
.48328 .76837 L
.48356 .76711 L
.48397 .76577 L
.48446 .76454 L
.48508 .76328 L
.48643 .76118 L
.48818 .7592 L
.49011 .75758 L
.49118 .75687 L
.4924 .7562 L
.49362 .75565 L
.49476 .75523 L
.49598 .75488 L
.49666 .75473 L
.4973 .75462 L
.49789 .75453 L
.49852 .75446 L
.49885 .75444 L
.49915 .75442 L
.49933 .75441 L
.49949 .75441 L
.49958 .7544 L
.49968 .7544 L
.49972 .7544 L
.49977 .7544 L
.49985 .7544 L
.49993 .7544 L
.49998 .7544 L
.50002 .7544 L
.50007 .7544 L
.50011 .7544 L
.50015 .7544 L
.5002 .7544 L
.50028 .7544 L
.50035 .7544 L
Mistroke
.50052 .75441 L
.50068 .75441 L
.50086 .75442 L
.50123 .75444 L
.50155 .75447 L
.5019 .75451 L
.50252 .75459 L
.50313 .75469 L
.50379 .75483 L
.5051 .75518 L
.50629 .75561 L
.50753 .75616 L
.50984 .75754 L
.51185 .75922 L
.51352 .76111 L
.51427 .76217 L
.51499 .7634 L
.51559 .76464 L
.51605 .76581 L
.51643 .76707 L
.5166 .76778 L
.51674 .76845 L
.51683 .76907 L
.51691 .76974 L
.51694 .77008 L
.51697 .77041 L
.51698 .77058 L
.51699 .77077 L
.51699 .77086 L
.51699 .77097 L
.51699 .77107 L
.517 .77116 L
.517 .77124 L
.517 .77133 L
.517 .77142 L
.517 .77147 L
.517 .77152 L
.517 .7716 L
.517 .77168 L
.51699 .77177 L
.51699 .77186 L
.51699 .77202 L
.51698 .77217 L
.51696 .7725 L
.51694 .77287 L
.51691 .7732 L
.51681 .77394 L
.5167 .77463 L
.51656 .77526 L
.51618 .77666 L
Mistroke
.51573 .7779 L
.51512 .77922 L
.5136 .78165 L
.51176 .78373 L
.51069 .78467 L
.50944 .78559 L
.50692 .78699 L
.50559 .78752 L
.50489 .78774 L
.50412 .78795 L
.5034 .78812 L
.50274 .78824 L
.50209 .78833 L
.50174 .78837 L
.50141 .7884 L
.50105 .78843 L
.50072 .78845 L
.50053 .78845 L
.50036 .78846 L
.50027 .78846 L
.50022 .78846 L
.50018 .78846 L
.50013 .78846 L
.50007 .78846 L
.49998 .78846 L
.49989 .78846 L
.49981 .78846 L
.49972 .78846 L
.49965 .78846 L
.49946 .78845 L
.49929 .78845 L
.49898 .78843 L
.49864 .78841 L
.49828 .78838 L
.49795 .78834 L
.4972 .78823 L
.49647 .78809 L
.4957 .78791 L
.49422 .78745 L
.49287 .78689 L
.49046 .78553 L
.48931 .78467 L
.48818 .78367 L
.4864 .78165 L
.48556 .78041 L
.48489 .77923 L
.48429 .77794 L
.48384 .77671 L
.48348 .77544 L
.48333 .77476 L
Mistroke
.4832 .77403 L
.48311 .77332 L
.48307 .77292 L
.48304 .77256 L
.48302 .77223 L
.48301 .77205 L
.48301 .77188 L
.48301 .77179 L
.483 .7717 L
.483 .77162 L
.483 .77154 L
.483 .77149 L
.483 .77145 L
.483 .77139 L
.483 .77135 L
.483 .77126 L
.483 .77121 L
.483 .77117 L
.48301 .77108 L
.48301 .771 L
.48301 .77085 L
.48302 .77068 L
.48303 .7705 L
.48305 .77018 L
.48307 .76988 L
.48315 .7692 L
.48326 .76848 L
.48354 .76719 L
.48389 .766 L
.48437 .76473 L
.4849 .76361 L
.48629 .76137 L
.48792 .75945 L
.48992 .75771 L
.49208 .75636 L
.49333 .75577 L
.49454 .7553 L
.49578 .75493 L
.49695 .75468 L
.49757 .75457 L
.49815 .7545 L
.49847 .75447 L
.49878 .75444 L
.49896 .75443 L
.49914 .75442 L
.4993 .75441 L
.49947 .75441 L
.49955 .7544 L
.49963 .7544 L
.49971 .7544 L
Mistroke
.49978 .7544 L
.49985 .7544 L
.49992 .7544 L
.5 .7544 L
.50007 .7544 L
.50012 .7544 L
.50016 .7544 L
.50024 .7544 L
.50032 .7544 L
.50042 .7544 L
.50059 .75441 L
.50074 .75441 L
.50108 .75443 L
.50139 .75446 L
.50209 .75453 L
.50272 .75462 L
.5033 .75472 L
.5046 .75503 L
.50574 .7554 L
.50697 .7559 L
.50925 .75714 L
.51125 .75867 L
.51312 .76061 L
.51462 .76275 L
.51575 .76503 L
.5162 .76626 L
.51657 .76763 L
.51671 .76831 L
.51683 .76905 L
.51688 .76939 L
.51692 .76976 L
.51695 .7701 L
.51697 .77042 L
.51698 .77057 L
.51698 .77075 L
.51699 .77091 L
.51699 .77106 L
.517 .77115 L
.517 .77124 L
.517 .77131 L
.517 .7714 L
.517 .77144 L
.517 .77149 L
.517 .77154 L
.517 .77158 L
.517 .77167 L
.517 .77176 L
.51699 .77184 L
.51699 .77192 L
.51699 .77209 L
Mistroke
.51698 .77225 L
.51697 .77241 L
.51695 .7727 L
.51693 .77302 L
.51685 .77371 L
.51675 .77434 L
.51644 .77576 L
.51606 .77703 L
.51552 .77838 L
.51485 .77972 L
.51414 .78089 L
.51241 .78307 L
.51028 .78499 L
.50795 .78649 L
.50665 .78711 L
.50522 .78764 L
.50456 .78784 L
.50385 .78802 L
.50317 .78816 L
.50254 .78827 L
.5018 .78837 L
.50142 .7884 L
.50122 .78842 L
.501 .78843 L
.5008 .78844 L
.50061 .78845 L
.50043 .78846 L
.50034 .78846 L
.50028 .78846 L
.50024 .78846 L
.50014 .78846 L
.50006 .78846 L
.49997 .78846 L
.49992 .78846 L
.49988 .78846 L
.4998 .78846 L
.49971 .78846 L
.49962 .78846 L
.49954 .78846 L
.49936 .78845 L
.4992 .78844 L
.49882 .78842 L
.49846 .78839 L
.49807 .78835 L
.49737 .78826 L
.49674 .78815 L
.49538 .78782 L
.49394 .78735 L
.49262 .78677 L
.49128 .78605 L
Mistroke
.48905 .78446 L
.48701 .78242 L
.48541 .78017 L
.4847 .77885 L
.48414 .77755 L
.48369 .77623 L
.48338 .77499 L
.48325 .77433 L
.48315 .77371 L
.48308 .77303 L
.48304 .77265 L
.48303 .77246 L
.48302 .77229 L
.48302 .77214 L
.48301 .77197 L
.48301 .77188 L
.483 .77179 L
.483 .77171 L
.483 .77162 L
.483 .77155 L
.483 .77147 L
.483 .77139 L
.483 .77132 L
.483 .77124 L
.483 .77116 L
.483 .77107 L
.48301 .771 L
.48301 .77081 L
.48302 .77064 L
.48304 .77031 L
.48306 .76996 L
.4831 .76958 L
.48318 .76894 L
.4833 .76824 L
.48363 .76685 L
.48403 .7656 L
.48456 .7643 L
.48591 .76191 L
.48754 .75985 L
.48937 .75814 L
.49039 .75738 L
.49157 .75664 L
.49386 .75555 L
.49504 .75514 L
.49565 .75496 L
.49634 .7548 L
.49695 .75467 L
.49761 .75457 L
.49797 .75452 L
.4983 .75448 L
Mistroke
.49862 .75445 L
.49895 .75443 L
.49926 .75441 L
.49943 .75441 L
.49952 .7544 L
.4996 .7544 L
.49967 .7544 L
.49974 .7544 L
.49982 .7544 L
.49988 .7544 L
.49996 .7544 L
.50003 .7544 L
.50011 .7544 L
.50019 .7544 L
.50027 .7544 L
.50035 .7544 L
.50052 .75441 L
.50068 .75441 L
.50083 .75442 L
.50116 .75444 L
.50152 .75447 L
.50217 .75454 L
.50288 .75464 L
.50415 .75491 L
.50537 .75527 L
.50664 .75575 L
.50882 .75687 L
.51095 .7584 L
.51276 .76018 L
.51358 .76118 L
.51439 .76236 L
.51561 .7647 L
.51609 .76593 L
.51649 .76729 L
.51664 .76796 L
.51678 .76871 L
.51688 .76941 L
.51694 .77007 L
.51697 .77039 L
.51698 .77057 L
.51699 .77074 L
.51699 .77089 L
.51699 .77097 L
.517 .77106 L
.517 .77114 L
.517 .77122 L
.517 .77129 L
.517 .77136 L
.517 .77144 L
.517 .77153 L
Mistroke
.517 .77158 L
.517 .77163 L
.517 .77172 L
.517 .7718 L
.51699 .77189 L
.51699 .77204 L
.51698 .77223 L
.51697 .7724 L
.51695 .77278 L
.51692 .7731 L
.51688 .77345 L
.51679 .77407 L
.51666 .77481 L
.51651 .77548 L
.51615 .77675 L
.51564 .77811 L
.51499 .77947 L
.51429 .78065 L
.5126 .78287 L
.5105 .78483 L
.50818 .78636 L
.50688 .78701 L
.50546 .78756 L
.50409 .78796 L
.50346 .78811 L
.50278 .78823 L
.50239 .7883 L
.50202 .78834 L
.50168 .78838 L
.5013 .78841 L
.50097 .78844 L
.50081 .78844 L
.50065 .78845 L
.50057 .78845 L
.50047 .78846 L
.50039 .78846 L
.50031 .78846 L
.50022 .78846 L
.50017 .78846 L
.50013 .78846 L
.50004 .78846 L
.49995 .78846 L
.49986 .78846 L
.49978 .78846 L
.49969 .78846 L
.4996 .78846 L
.49944 .78845 L
.49926 .78845 L
.49907 .78844 L
.49887 .78843 L
Mistroke
.49851 .7884 L
.49778 .78832 L
.49699 .78819 L
.49627 .78805 L
.49562 .78789 L
.49417 .78743 L
.4929 .78691 L
.49157 .78622 L
.48917 .78456 L
.48717 .78261 L
.48629 .7815 L
.48544 .78023 L
.48419 .7777 L
.48374 .77639 L
.48355 .77571 L
.48337 .77497 L
.48324 .77427 L
.48314 .77363 L
.48311 .77333 L
.48307 .77299 L
.48305 .77269 L
.48303 .77238 L
.48302 .77219 L
.48301 .77201 L
.48301 .77184 L
.483 .77176 L
.483 .77171 L
.483 .77167 L
.483 .77158 L
.483 .7715 L
.483 .77142 L
.483 .77133 L
.483 .77125 L
.483 .77117 L
.483 .7711 L
.48301 .77102 L
.48301 .77084 L
.48302 .77067 L
.48304 .77028 L
.48307 .76995 L
.4831 .76959 L
.48318 .76895 L
.4833 .76826 L
.48357 .76705 L
.484 .76568 L
.48451 .76442 L
.48573 .76217 L
.48737 .76003 L
.48923 .75825 L
.49125 .75683 L
Mistroke
.49245 .75617 L
.49358 .75566 L
.4948 .75521 L
.49596 .75489 L
.49716 .75464 L
.4978 .75454 L
.49815 .7545 L
.49848 .75447 L
.4988 .75444 L
.49914 .75442 L
.49932 .75441 L
.49949 .75441 L
.49958 .7544 L
.49967 .7544 L
.49972 .7544 L
.49977 .7544 L
.49981 .7544 L
.49986 .7544 L
.49994 .7544 L
.50001 .7544 L
.50006 .7544 L
.5001 .7544 L
.50019 .7544 L
.50023 .7544 L
.50027 .7544 L
.50035 .7544 L
.50053 .75441 L
.5007 .75441 L
.50086 .75442 L
.50115 .75444 L
.50145 .75446 L
.50178 .75449 L
.50244 .75457 L
.50304 .75467 L
.50361 .75478 L
.50487 .75511 L
.50601 .7555 L
.50724 .75602 L
.50834 .75659 L
.51041 .75796 L
.51231 .75969 L
.51389 .76161 L
.51464 .76277 L
.51525 .7639 L
.51579 .76513 L
.51621 .76631 L
.51655 .76754 L
.51669 .7682 L
.51681 .76892 L
.5169 .76961 L
Mistroke
.51694 .77 L
.51697 .77036 L
.51698 .77068 L
.51699 .77086 L
.517 .77103 L
.517 .77112 L
.517 .77121 L
.517 .77129 L
.517 .77138 L
.517 .77142 L
.517 .77147 L
.517 .77152 L
.517 .77157 L
.517 .77165 L
.517 .7717 L
.517 .77174 L
.51699 .77191 L
.51699 .77207 L
.51698 .77225 L
.51697 .77242 L
.51695 .77272 L
.51692 .77304 L
.51684 .77378 L
.51673 .77446 L
.51645 .77573 L
.51603 .77711 L
.51553 .77837 L
.51487 .77969 L
.51324 .78212 L
.51129 .78417 L
.5091 .78582 L
.50787 .78653 L
.50649 .78717 L
.50503 .7877 L
.50435 .7879 L
.50361 .78808 L
.50293 .78821 L
.50218 .78832 L
.50184 .78836 L
.50149 .7884 L
.50115 .78843 L
.50084 .78844 L
.50067 .78845 L
.50049 .78846 L
.5004 .78846 L
.5003 .78846 L
.5002 .78846 L
.50012 .78846 L
.50004 .78846 L
.49996 .78846 L
Mistroke
.49988 .78846 L
.49979 .78846 L
.4997 .78846 L
.49961 .78846 L
.49945 .78846 L
.49927 .78845 L
.49907 .78844 L
.49873 .78842 L
.49835 .78838 L
.49794 .78834 L
.49721 .78823 L
.49655 .78811 L
.49508 .78774 L
.49378 .78728 L
.49241 .78667 L
.49106 .78592 L
.48991 .78514 L
.48779 .78329 L
.4868 .78217 L
.48599 .78108 L
.48463 .77871 L
.48411 .77749 L
.48366 .77612 L
.48334 .7748 L
.4832 .77405 L
.48315 .77372 L
.48311 .77337 L
.48308 .77304 L
.48305 .77269 L
.48303 .77236 L
.48302 .77221 L
.48301 .77205 L
.48301 .77188 L
.483 .77178 L
.483 .7717 L
.483 .77161 L
.483 .77154 L
.483 .77145 L
.483 .77137 L
.483 .77128 L
.483 .77123 L
.483 .77118 L
.483 .7711 L
.48301 .77101 L
.48301 .77083 L
.48302 .77063 L
.48304 .77027 L
.48307 .76994 L
.48315 .76919 L
.48325 .76853 L
Mistroke
.48338 .76784 L
.48375 .76644 L
.48419 .76516 L
.48532 .76284 L
.48603 .76173 L
.48687 .76061 L
.48859 .75881 L
.49067 .75719 L
.49288 .75597 L
.49415 .75544 L
.49538 .75504 L
.49598 .75488 L
.49663 .75474 L
.49724 .75462 L
.4978 .75454 L
.4984 .75447 L
.49871 .75445 L
.49904 .75442 L
.49919 .75442 L
.49934 .75441 L
.49947 .75441 L
.49961 .7544 L
.49969 .7544 L
.49977 .7544 L
.49985 .7544 L
.49993 .7544 L
.5 .7544 L
.50007 .7544 L
.50014 .7544 L
.50022 .7544 L
.5003 .7544 L
.50038 .7544 L
.50056 .75441 L
.50072 .75441 L
.50087 .75442 L
.50121 .75444 L
.50158 .75447 L
.50225 .75455 L
.50286 .75464 L
.50405 .75489 L
.50533 .75526 L
.50652 .7557 L
.50775 .75627 L
.51003 .75768 L
.51201 .75938 L
.51366 .7613 L
.51439 .76236 L
.5151 .7636 L
.51568 .76484 L
.51612 .76602 L
Mistroke
.51649 .76728 L
.51665 .768 L
.51678 .76867 L
.51687 .76929 L
.51694 .76995 L
.51697 .77033 L
.51698 .77052 L
.51698 .7707 L
.51699 .77085 L
.517 .77102 L
.517 .77111 L
.517 .77119 L
.517 .77128 L
.517 .77133 L
.517 .77137 L
.517 .77145 L
.517 .77153 L
.517 .77161 L
.517 .7717 L
.517 .77179 L
.51699 .77189 L
.51699 .77205 L
.51698 .77221 L
.51698 .77235 L
.51695 .77268 L
.51692 .77305 L
.51689 .77338 L
.51679 .77411 L
.51667 .77479 L
.51653 .77542 L
.51613 .77682 L
.51567 .77805 L
.51504 .77937 L
.51351 .78178 L
.51165 .78384 L
.51057 .78477 L
.50932 .78568 L
.50679 .78705 L
.50545 .78756 L
.50399 .78799 L
.50326 .78815 L
.50246 .78829 L
.50209 .78834 L
.5017 .78838 L
.50133 .78841 L
.50099 .78844 L
.50082 .78844 L
.50064 .78845 L
.50055 .78846 L
.50046 .78846 L
Mistroke
.50038 .78846 L
.5003 .78846 L
.50021 .78846 L
.50012 .78846 L
.50003 .78846 L
.49995 .78846 L
.49985 .78846 L
.49976 .78846 L
.49971 .78846 L
.49966 .78846 L
.49956 .78846 L
.49939 .78845 L
.49923 .78845 L
.49887 .78843 L
.49856 .7884 L
.49823 .78837 L
.49754 .78829 L
.49681 .78816 L
.49551 .78786 L
.49405 .78739 L
.4927 .78682 L
.49031 .78543 L
.48918 .78457 L
.48806 .78356 L
.4863 .78152 L
.48547 .78028 L
.48481 .77909 L
.48423 .7778 L
.48379 .77657 L
.48344 .7753 L
.4833 .77462 L
.48318 .77389 L
.48309 .77318 L
.48305 .77279 L
.48303 .77242 L
.48302 .77227 L
.48301 .7721 L
.48301 .772 L
.48301 .77192 L
.483 .77184 L
.483 .77175 L
.483 .77166 L
.483 .77157 L
.483 .77152 L
.483 .77147 L
.483 .77138 L
.483 .7713 L
.483 .77122 L
.483 .77113 L
.483 .77104 L
Mistroke
.48301 .77086 L
.48302 .7707 L
.48303 .77039 L
.48306 .77005 L
.48309 .76969 L
.48317 .76905 L
.48326 .76846 L
.48353 .76722 L
.48393 .76589 L
.48439 .76467 L
.485 .76342 L
.48647 .76112 L
.4882 .75917 L
.49011 .75758 L
.49127 .75682 L
.49236 .75621 L
.49356 .75567 L
.49469 .75525 L
.49588 .7549 L
.49656 .75475 L
.49719 .75463 L
.49777 .75454 L
.49839 .75447 L
.49874 .75444 L
.49908 .75442 L
.49923 .75441 L
.49938 .75441 L
.49947 .7544 L
.49956 .7544 L
.49964 .7544 L
.49971 .7544 L
.49979 .7544 L
.49987 .7544 L
.49991 .7544 L
.49995 .7544 L
.50003 .7544 L
.50011 .7544 L
.50019 .7544 L
.50027 .7544 L
.50036 .7544 L
.50051 .7544 L
.50064 .75441 L
.50096 .75442 L
.50129 .75445 L
.5016 .75447 L
.50229 .75455 L
.50291 .75465 L
.50349 .75476 L
.50479 .75509 L
.50604 .75551 L
Mistroke
.50715 .75598 L
.50941 .75725 L
.51139 .75879 L
.51324 .76075 L
.51472 .7629 L
.51582 .76519 L
.51625 .76642 L
.51661 .76779 L
.51674 .76847 L
.51686 .76921 L
.5169 .76956 L
.51693 .76992 L
.51696 .77023 L
.51697 .7704 L
.51698 .77058 L
.51699 .77074 L
.51699 .77092 L
.517 .77101 L
.517 .7711 L
.517 .77119 L
.517 .77127 L
.517 .77135 L
.517 .77143 L
.517 .7715 L
.517 .77158 L
.517 .77166 L
.517 .77175 L
.517 .77183 L
.51699 .77191 L
.51699 .77209 L
.51698 .77226 L
.51696 .77265 L
.51693 .77298 L
.51689 .77334 L
.5168 .77405 L
.51666 .77481 L
.51633 .77618 L
.51588 .77751 L
.5153 .77887 L
.51393 .78119 L
.51209 .78341 L
.50997 .78523 L
.50868 .78608 L
.5074 .78677 L
.50619 .7873 L
.5048 .78777 L
.50341 .78812 L
.50263 .78826 L
.50189 .78836 L
.50154 .7884 L
Mistroke
.50114 .78843 L
.50096 .78844 L
.50077 .78845 L
.50059 .78846 L
.50042 .78846 L
.50034 .78846 L
.50025 .78846 L
.50017 .78846 L
.50009 .78847 L
.5 .78847 L
.49995 .78847 L
.4999 .78847 L
.49981 .78846 L
.49973 .78846 L
.49965 .78846 L
.49957 .78846 L
.49942 .78846 L
.49925 .78845 L
.49908 .78844 L
.49872 .78842 L
.49834 .78838 L
.49767 .78831 L
.49696 .78819 L
.49618 .78803 L
.49481 .78765 L
.49338 .78712 L
.49199 .78646 L
.49074 .78572 L
.48855 .78402 L
.48657 .78188 L
.48573 .7807 L
.48505 .77954 L
.48444 .77831 L
.48397 .7771 L
.48355 .77575 L
.48327 .77449 L
.48317 .77383 L
.48312 .77347 L
.48308 .77313 L
.48305 .77281 L
.48303 .77246 L
.48302 .77231 L
.48301 .77215 L
.48301 .77201 L
.483 .77186 L
.483 .77177 L
.483 .77169 L
.483 .77161 L
.483 .77152 L
.483 .77144 L
Mistroke
.483 .77137 L
.483 .77129 L
.483 .77121 L
.483 .77112 L
.483 .77103 L
.48301 .77085 L
.48302 .77067 L
.48302 .77051 L
.48304 .7702 L
.48307 .76991 L
.48314 .76927 L
.48324 .76859 L
.48335 .76798 L
.48369 .76661 L
.48409 .76541 L
.48463 .76414 L
.48597 .76181 L
.48757 .75981 L
.48956 .75799 L
.49065 .75721 L
.49171 .75656 L
.49395 .75551 L
.49521 .75509 L
.49637 .75479 L
.49696 .75467 L
.49759 .75457 L
.49792 .75452 L
.49828 .75448 L
.49859 .75445 L
.49892 .75443 L
.4991 .75442 L
.49926 .75441 L
.49941 .75441 L
.49949 .7544 L
.49958 .7544 L
.49966 .7544 L
.49973 .7544 L
.4998 .7544 L
.49987 .7544 L
.49995 .7544 L
.50002 .7544 L
.5001 .7544 L
.50018 .7544 L
.50022 .7544 L
.50027 .7544 L
.50035 .7544 L
.50044 .7544 L
.50054 .7544 L
.50072 .75441 L
.50088 .75442 L
Mistroke
.50119 .75444 L
.50152 .75446 L
.50217 .75454 L
.50288 .75464 L
.50414 .75491 L
.50536 .75527 L
.50663 .75575 L
.50881 .75686 L
.51093 .75838 L
.51274 .76015 L
.51437 .76233 L
.51509 .76359 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00W_oooolGo`000;?ooooo002Gooooo`Wo00002Oooool00ol0003oooooooooo`06ooooo`Wo0000
[Oooool009?ooooo1ol0000?ooooo`03o`000?oooooooooo00cooooo2?l0002Xooooo`00T?ooool6
o`0001?ooooo00?o0000ooooooooool04?ooool7o`000:Gooooo002=ooooo`Go00005oooool00ol0
003oooooooooo`0Dooooo`Ko0000X_ooool008[ooooo1Ol0000Jooooo`03o`000?oooooooooo01Oo
oooo1Ol0002Pooooo`00Qoooool5o`0001gooooo00?o0000ooooooooool06oooool4o`0009gooooo
0025ooooo`Co00008?ooool00ol0003oooooooooo`0Mooooo`Co0000Voooool008?ooooo1?l0000R
ooooo`03o`000?oooooooooo01oooooo1?l0002Iooooo`00POooool4o`0002Cooooo00?o0000oooo
ooooool08Oooool4o`0009Oooooo0020ooooo`?o00009_ooool00ol0003oooooooooo`0Sooooo`Co
0000UOooool007kooooo0ol0000Xooooo`03o`000?oooooooooo02Gooooo1?l0002Cooooo`00O?oo
ool3o`0002[ooooo00?o0000ooooooooool09oooool3o`0009;ooooo001jooooo`?o0000;?ooool0
0ol0003oooooooooo`0Yooooo`?o0000T?ooool007Wooooo0ol0000]ooooo`03o`000?oooooooooo
02[ooooo1?l0002>ooooo`00Moooool3o`0002oooooo00?o0000ooooooooool0;?ooool3o`0008go
oooo001fooooo`;o0000<Oooool2o`0002oooooo0_l0002<ooooo`00M?ooool3o`0003;ooooo00?o
0000ooooooooool0;oooool3o`0008[ooooo001cooooo`?o0000<oooool00ol0003oooooooooo`0`
ooooo`?o0000ROooool007;ooooo0_l0000eooooo`03o`000?oooooooooo037ooooo0ol00028oooo
o`00LOooool2o`0003Kooooo00?o0000ooooooooool0<oooool2o`0008Oooooo001`ooooo`;o0000
=oooool00ol0003oooooooooo`0dooooo`;o0000Q_ooool006oooooo0_l0000hooooo`03o`000?oo
oooooooo03Gooooo0_l00025ooooo`00K_ooool2o`0003Wooooo00?o0000ooooooooool0=_ooool2
o`0008Cooooo001]ooooo`;o0000>_ooool00ol0003oooooooooo`0gooooo`;o0000Poooool006co
oooo0_l0000kooooo`03o`000?oooooooooo03Sooooo0_l00022ooooo`00Joooool2o`0003cooooo
00?o0000ooooooooool0>Oooool2o`00087ooooo001Zooooo`?o0000??ooool00ol0003ooooooooo
o`0iooooo`?o0000P?ooool006Wooooo0ol0000mooooo`03o`000?oooooooooo03[ooooo0ol0001o
ooooo`00J?ooool3o`0003kooooo00?o0000ooooooooool0>oooool3o`0007kooooo001Wooooo`?o
0000=Oooool2o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0??ooool2o`0007ko
oooo001Wooooo`;o0000=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo
0_l0001mooooo`00I_ooool2o`0002gooooo1_l00002ooooo`Go00001oooool3o`0003kooooo0_l0
001looooo`00IOooool2o`0003Kooooo00CoA4A4omgMgOoooooo00002?ooool00ol0003ooooooooo
o`0oooooo`;o0000Noooool006Cooooo0_l0000gooooo`04omgMgOmEEEGoooooo`0000Sooooo00?o
0000ooooooooool0@?ooool2o`0007[ooooo001Sooooo`;o0000>Oooool00omgMgOoc<c<o`000008
ooooo`03o`000?oooooooooo047ooooo0_l0001iooooo`00Hoooool2o`0003Wooooo00?ok^k^odA4
A?l000001?ooool8o`00047ooooo0_l0001hooooo`00H_ooool2o`0003_ooooo1ol00003ooooo`03
o`000?oooooooooo00So0000>_ooool3o`0007Oooooo001Qooooo`;o0000>?ooool5o`0000Wooooo
00?o0000ooooooooool01_ooool5o`0003Sooooo0_l0001gooooo`00H?ooool2o`0003Oooooo0ol0
000=ooooo`03o`000?oooooooooo00Wooooo1Ol0000fooooo`;o0000M_ooool0063ooooo0_l0000e
ooooo`?o00003oooool00ol0003oooooooooo`0<ooooo`Co0000=?ooool3o`0007Gooooo001Ooooo
o`;o0000=?ooool3o`00017ooooo00?o0000ooooooooool03_ooool3o`0003Cooooo0_l0001eoooo
o`00G_ooool2o`0003?ooooo0ol0000Cooooo`03o`000?oooooooooo013ooooo0ol0000cooooo`;o
0000M?ooool005kooooo00?o0000ooooooooool0<Oooool2o`0001Gooooo00?o0000ooooooooool0
4_ooool2o`0003;ooooo0_l0001dooooo`00GOooool2o`0003;ooooo0_l0000Fooooo`03o`000?oo
oooooooo01?ooooo0_l0000booooo`;o0000Loooool005gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Cooooo0_l0000booooo`;o0000L_ooool0
05cooooo0_l0000aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05Oooool2o`00
037ooooo0_l0001booooo`00Foooool2o`00037ooooo0_l0000Iooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0;oooool2o`00077ooooo001Kooooo`03o`000?oooooooooo02oooooo
0_l0000Jooooo`;o00006Oooool00ol0003oooooooooo`0^ooooo`;o0000LOooool005[ooooo0_l0
000`ooooo`;o00006oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02kooooo0_l0
001`ooooo`00F_ooool00ol0003oooooooooo`0^ooooo`;o00007?ooool00ol0003oooooooooo`0I
ooooo`;o0000;oooool3o`0006oooooo001Iooooo`;o0000;oooool2o`0001gooooo00?o0000oooo
ooooool06_ooool2o`0002oooooo0_l0001_ooooo`00FOooool00ol0003oooooooooo`0]ooooo`;o
00007_ooool00ol0003oooooooooo`0Kooooo`;o0000;oooool2o`0006kooooo001Hooooo`;o0000
;oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01_ooooo0_l0000_ooooo`;o0000
K_ooool005Oooooo0_l0000_ooooo`;o00007oooool00ol0003oooooooooo`0Looooo`;o0000;ooo
ool2o`0006gooooo001Gooooo`;o0000;_ooool2o`00023ooooo00?o0000ooooooooool07Oooool2
o`0002kooooo0_l0001]ooooo`00E_ooool2o`0002oooooo0_l0000Pooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0;Oooool2o`0006cooooo001Fooooo`;o0000;_ooool2o`00027o
oooo00?o0000ooooooooool07_ooool2o`0002kooooo0_l0001/ooooo`00EOooool2o`0002kooooo
0_l0000Rooooo`03o`000?oooooooooo01oooooo0_l0000^ooooo`;o0000Joooool005Gooooo0_l0
000^ooooo`;o00008_ooool00ol0003oooooooooo`0Oooooo`;o0000;_ooool2o`0006_ooooo001E
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02gooooo0_l0001Zooooo`00E?ooool2o`0002kooooo0_l0000Soooo
o`03o`000?oooooooooo023ooooo0_l0000^ooooo`;o0000J_ooool005Cooooo0_l0000^ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0/ooooo`;o
0000J_ooool005Cooooo00?o0000ooooooooool0;?ooool2o`0002Cooooo00?o0000ooooooooool0
8Oooool2o`0002kooooo0_l0001Yooooo`00Doooool2o`0002kooooo0_l0000Sooooo`?o00008ooo
ool00ol0003oooooooooo`0/ooooo`;o0000JOooool005?ooooo00?o0000ooooooooool0;?ooool2
o`00027ooooo2?l0000Qooooo`;o0000;_ooool00ol0003oooooooooo`1Wooooo`00D_ooool2o`00
02kooooo0_l0000Pooooo`;o00000oooool00ol0003oooooooooo`02o`00023ooooo0_l0000^oooo
o`;o0000J?ooool005;ooooo0_l0000^ooooo`;o00008?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooooooo`;o00007oooool2o`0002oooooo00?o0000ooooooooool0I_ooool005;o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;Oooool2o`0006Oo
oooo001Aooooo`;o0000;_ooool2o`00023ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;Oooool2o`0006Oooooo
001Aooooo`;o0000;_ooool2o`00023ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01kooooo0_l0000_ooooo`03o`000?oooooooooo06Gooooo001A
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0]
ooooo`;o0000I_ooool0053ooooo0_l0000_ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0;Oooool2o`0006Kooooo001@ooooo`;o0000;oooool00ol0003oooooooooo`0Oooooo`;o
00001?ooool01?l0003oooooooooooooool2o`00027ooooo00?o0000ooooooooool0;Oooool2o`00
06Kooooo001@ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool08?ooool2o`0000?o
oooo00?o0000ooooooooool00_l0000Rooooo`03o`000?oooooooooo02kooooo0_l0001Uooooo`00
Coooool2o`00033ooooo00?o0000ooooooooool08Oooool2o`0000;ooooo00Co0000ooooool0003o
00008oooool00ol0003oooooooooo`0^ooooo`;o0000IOooool004oooooo0_l0000`ooooo`03o`00
0?oooooooooo02;ooooo1_l0000Tooooo`03o`000?oooooooooo02kooooo0_l0001Uooooo`00Cooo
ool2o`00033ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0Hoooool004oooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`1Sooooo`00C_ooool2o`00037ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02oooooo0_l0001Tooooo`00C_ooool2o`00037o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02oo
oooo0_l0001Tooooo`00C_ooool2o`00037ooooo00?o0000ooooooooool09Oooool2o`0002Gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Rooooo`00C_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo06;ooooo001=ooooo`;o0000<_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0<?ooool2o`0006?ooooo001=oooo
o`;o0000<_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0<?ooool2o`0006?ooooo001=ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0HOooool004gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0<Oooool2o`0006;ooooo001=ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo037ooooo0_l0001Rooooo`00C?ooool2o`0003?ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Sooooo`;o0000<oooool2o`0006;ooooo001<ooooo`;o0000<oooool2o`00
02Kooooo00?o0000ooooooooool08oooool2o`0003?ooooo0_l0001Rooooo`00C?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo063ooooo001<ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0H?ooool004cooooo00?o0000ooooooooool0<oooool2o`0002Gooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0cooooo`;o0000HOooool004_ooooo0_l0000e
ooooo`;o00009Oooool00ol0003oooooooooo`0Rooooo`;o0000=Oooool2o`00067ooooo001;oooo
o`;o0000=_ooool00ol0003oooooooooo`0Gooooo`Go00001oooool00ol0003oooooooooo`0Roooo
o`;o0000=Oooool2o`00067ooooo001;ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool05oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo05oooooo001;ooooo`03o`000?oooooooooo03Go
oooo0_l0000@ooooo`Ko00000oooool00onHV9So8B4Qonk^kP08ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Oooooo`00Boooool00ol0003ooooo
ooooo`0eooooo`;o00006_ooool00onHV9So8B4Qonk^kP07ooooo`?o00008Oooool2o`0003Oooooo
00?o0000ooooooooool0Goooool004[ooooo0_l0000hooooo`;o00006_ooool00omgMgOoIVIVoooo
o`06ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=_ooool2o`00063ooooo001:
ooooo`;o0000>?ooool2o`0001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0P
ooooo`;o0000>?ooool2o`00063ooooo001:ooooo`;o0000>?ooool2o`0001Oooooo00Go0000okZj
^_ooooooV9RHoa0@4007ooooo`03o`000?oooooooooo023ooooo0_l0000hooooo`;o0000H?ooool0
04[ooooo0_l0000iooooo`;o00005_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0gooooo`;o0000H?ooool004[ooooo0_l0000ioooo
o`;o00008_ooool00ol0003oooooooooo`0Oooooo`;o0000>Oooool2o`00063ooooo001:ooooo`;o
0000>_ooool2o`00027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo05kooooo001:ooooo`03o`000?oooooooooo03Wooooo0_l0000Qooooo`03o`00
0?oooooooooo01kooooo0_l0000kooooo`03o`000?oooooooooo05kooooo0019ooooo`;o0000??oo
ool2o`00023ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo05kooooo0019ooooo`;o0000??ooool2o`00023ooooo00?o0000ooooooooool07Oooool2
o`0003cooooo0_l0001Oooooo`00BOooool2o`0003gooooo0_l0000Oooooo`03o`000?oooooooooo
01cooooo0_l0000mooooo`;o0000Goooool004Wooooo0_l0000nooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool07?ooool2o`0003gooooo0_l0001Oooooo`00BOooool2o`0003kooooo
0_l0000Nooooo`03o`000?oooooooooo01_ooooo0_l0000nooooo`;o0000Goooool004Wooooo0_l0
000oooooo`;o00007Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0GOooool004Wooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1M
ooooo`00BOooool00ol0003oooooooooo`0oooooo`;o00007?ooool00ol0003oooooooooo`0Ioooo
o`;o0000@Oooool00ol0003oooooooooo`1Mooooo`00BOooool00ol0003oooooooooo`10ooooo`;o
00006oooool2o`0001Wooooo0_l00012ooooo`03o`000?oooooooooo05gooooo0019ooooo`03o`00
0?oooooooooo047ooooo0_l0000Jooooo`03o`000?oooooooooo01Oooooo0_l00013ooooo`03o`00
0?oooooooooo05gooooo0019ooooo`03o`000?oooooooooo04;ooooo0_l0000Iooooo`03o`000?oo
oooooooo01Kooooo0_l00014ooooo`03o`000?oooooooooo05gooooo0019ooooo`03o`000?oooooo
oooo04?ooooo0_l0000Hooooo`03o`000?oooooooooo01Gooooo0_l00015ooooo`03o`000?oooooo
oooo05gooooo0019ooooo`03o`000?oooooooooo04Cooooo0_l0000Gooooo`03o`000?oooooooooo
01Cooooo0_l00016ooooo`;o0000G_ooool004Wooooo00?o0000ooooooooool0AOooool2o`0001Ko
oooo00?o0000ooooooooool04oooool2o`0004Oooooo0_l0001Nooooo`00B?ooool2o`0004Sooooo
0_l0000Eooooo`03o`000?oooooooooo01;ooooo0_l00018ooooo`;o0000G_ooool004Sooooo0_l0
0019ooooo`;o00005?ooool00ol0003oooooooooo`0Aooooo`;o0000BOooool2o`0005kooooo0018
ooooo`;o0000B_ooool2o`0001?ooooo00?o0000ooooooooool04?ooool2o`0004[ooooo0_l0001N
ooooo`00B?ooool2o`0004_ooooo0ol0000Aooooo`03o`000?oooooooooo00kooooo0_l0001=oooo
o`03o`000?oooooooooo05cooooo0018ooooo`;o0000COooool2o`00013ooooo00?o0000oooooooo
ool03Oooool2o`0004kooooo00?o0000ooooooooool0G?ooool004Sooooo0_l0001>ooooo`?o0000
3_ooool00ol0003oooooooooo`0;ooooo`?o0000Coooool00ol0003oooooooooo`1Looooo`00B?oo
ool00ol0003oooooooooo`1?ooooo`?o00003?ooool00ol0003oooooooooo`09ooooo`Co0000D?oo
ool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1@ooooo`Go00002Oooool0
0ol0003oooooooooo`07ooooo`Co0000D_ooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0
003oooooooooo`1Booooo`Go00001oooool00ol0003oooooooooo`05ooooo`?o0000EOooool00ol0
003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1Eooooo`Co00001Oooool00ol0003o
ooooooooo`02ooooo`Co0000Eoooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003ooooo
ooooo`1Iooooo`_o0000F_ooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo0018oooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Loooo
o`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo0018
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1L
ooooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000oooo
ooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`;o0000G_oo
ool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo000Zooooo`;o000000?o410@oooooooo
ool06Oooool00ol0003oooooooooo`0Nooooo`Go0000>oooool00ol0003oooooooooo`0jooooo`Go
00007_ooool00ol0003oooooooooo`0Mooooo`;o000000?o410@ooooooooool0>_ooool002_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0>oooool00ol0003oooooooooo`0jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03_ooooo000Pooooo`Ko00000_ooool5o`0001_o
oooo00?o0000ooooooooool05_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0??ooool00ol0003o
ooooooooo`0kooooo`03oiRHV?lQ8B7ok^k^01oooooo00?o0000ooooooooool06oooool5o`0003co
oooo000Xooooo`04odA4A?oMgMgoooooo`0001cooooo00?o0000ooooooooool08?ooool00onHV9So
8B4Qonk^kP0kooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07_ooool00ol0003o
ooooooooo`0Kooooo`04odA4A?oMgMgoooooo`0003gooooo000Xooooo`04omgMgOmEEEGoooooo`00
01cooooo00?o0000ooooooooool08Oooool00omgMgOoIVIVooooo`0jooooo`03o`000?oooooooooo
03gooooo00?oMgMgofIVI_ooool07Oooool00ol0003oooooooooo`0Kooooo`04omgMgOmEEEGooooo
o`0003gooooo000Yooooo`03ogMgMoo<c<co000001cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03ogMgMoo<c<co000003gooooo000Yooooo`03onk^k_m4A4Co000001co
oooo00?o0000ooooooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@03_ooooo00?o0000oooo
ooooool0>_ooool01Ol0003o^[ZjoooooonHV9So410@01kooooo00?o0000ooooooooool07?ooool0
0oo^k^koA4A4o`00000mooooo`00:_ooool00omgMgOo0000ooooo`0Kooooo`03o`000?oooooooooo
01kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00kooooo`03o`000?oooooooooo03[ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00Nooooo`03o`000?oooooooooo01gooooo00?oMgMgo`000?ooool0??oo
ool004Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo05cooooo0018ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05go
oooo00?o0000ooooooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o00001_ooool004Sooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo053ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd6ooooo`0000?oooooo`000?l00000ool0001?o`0000cooooo
00CogMgMo`000?l@413oc<c<1oooool000Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo013ooooo00Cok^k^ob4Q8Ol@413ok^k^1oooool000Oooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo
00Co8B4QogMgMomgMgOo<S8b1oooool004Sooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o00001_ooool004Sooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo0018
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1L
ooooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000oooo
ooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo
0018ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0GOooool00ol0003ooooooooo
o`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool2o`0005kooooo00?o0000oooo
ooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo
0018ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0GOooool00ol0003ooooooooo
o`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0G?ooool004Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo05gooooo00?o0000ooooooooool0G?ooool004Sooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Looooo`00B?ooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0G?ooool004So
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05co
oooo0018ooooo`03o`000?oooooooooo05Kooooo4Ol0001Gooooo`03o`000?oooooooooo05cooooo
0018ooooo`03o`000?oooooooooo05?ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo1Ol0
001Eooooo`03o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo057ooooo1?l00009
ooooo`03o`000?oooooooooo00Kooooo1Ol0001Booooo`03o`000?oooooooooo05cooooo0018oooo
o`03o`000?oooooooooo04oooooo0ol0000<ooooo`03o`000?oooooooooo00Wooooo0ol0001Aoooo
o`03o`000?oooooooooo05cooooo0018ooooo`03o`000?oooooooooo04gooooo0ol0000>ooooo`03
o`000?oooooooooo00_ooooo0ol0001?ooooo`03o`000?oooooooooo05cooooo0018ooooo`;o0000
COooool2o`00013ooooo00?o0000ooooooooool03Oooool2o`0004kooooo00?o0000ooooooooool0
G?ooool004Sooooo0_l0001<ooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`;o0000COoo
ool00ol0003oooooooooo`1Looooo`00B?ooool2o`0004[ooooo0ol0000Booooo`03o`000?oooooo
oooo00oooooo0ol0001:ooooo`;o0000G_ooool004Sooooo0_l00019ooooo`;o00005?ooool00ol0
003oooooooooo`0Aooooo`;o0000BOooool2o`0005kooooo0018ooooo`;o0000B?ooool2o`0001Go
oooo00?o0000ooooooooool04_ooool2o`0004Sooooo0_l0001Nooooo`00BOooool00ol0003ooooo
ooooo`15ooooo`;o00005_ooool00ol0003oooooooooo`0Cooooo`;o0000Aoooool2o`0005kooooo
0019ooooo`03o`000?oooooooooo04Cooooo0_l0000Gooooo`03o`000?oooooooooo01Cooooo0_l0
0016ooooo`;o0000G_ooool004Wooooo00?o0000ooooooooool0@oooool2o`0001Sooooo00?o0000
ooooooooool05Oooool2o`0004Gooooo0_l0001Nooooo`00BOooool00ol0003oooooooooo`13oooo
o`;o00006?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0GOooool004Wooooo00?o0000ooooooooool0@_ooool2o`0001Wooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05gooooo0019ooooo`03o`00
0?oooooooooo047ooooo0_l0000Jooooo`03o`000?oooooooooo01Oooooo0_l00013ooooo`03o`00
0?oooooooooo05gooooo0019ooooo`03o`000?oooooooooo043ooooo0_l0000Kooooo`;o00006Ooo
ool2o`0004;ooooo00?o0000ooooooooool0GOooool004Wooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo0_l00011ooooo`03o`000?oooooo
oooo05gooooo0019ooooo`;o0000@?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Wooooo0_l00010ooooo`;o0000Goooool004Wooooo0_l0000oooooo`;o00007Oooool00ol0003o
ooooooooo`0Jooooo`;o0000?oooool2o`0005oooooo0019ooooo`;o0000?_ooool2o`0001kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0mooooo`;o0000Goooool004Wooooo0_l0
000nooooo`;o00007_ooool00ol0003oooooooooo`0Kooooo`;o0000?_ooool2o`0005oooooo0019
ooooo`;o0000?Oooool2o`0001oooooo00?o0000ooooooooool07?ooool2o`0003gooooo0_l0001O
ooooo`00BOooool2o`0003cooooo0_l0000Pooooo`03o`000?oooooooooo01gooooo0_l0000loooo
o`;o0000Goooool004[ooooo00?o0000ooooooooool0>_ooool2o`00023ooooo00?o0000oooooooo
ool07Oooool2o`0003cooooo0_l0001Oooooo`00B_ooool00ol0003oooooooooo`0iooooo`;o0000
8Oooool00ol0003oooooooooo`0Nooooo`;o0000>oooool00ol0003oooooooooo`1Nooooo`00B_oo
ool00ol0003oooooooooo`0iooooo`;o00008Oooool00ol0003oooooooooo`0Nooooo`;o0000>ooo
ool00ol0003oooooooooo`1Nooooo`00B_ooool2o`0003Wooooo0_l0000Rooooo`03o`000?oooooo
oooo01oooooo0_l0000iooooo`;o0000H?ooool004[ooooo0_l0000iooooo`;o00008_ooool00ol0
003oooooooooo`0Oooooo`;o0000>Oooool2o`00063ooooo001:ooooo`;o0000>Oooool2o`0001Ko
oooo1Ol00007ooooo`03o`000?oooooooooo023ooooo0_l0000hooooo`;o0000H?ooool004[ooooo
0_l0000hooooo`;o00005oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o0000oooooooo
ool08?ooool2o`0003Sooooo0_l0001Pooooo`00B_ooool2o`0003Sooooo0_l0000Hooooo`03oiRH
V?lQ8B7ok^k^00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0fooooo`;o0000
H?ooool004_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Hooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0ol0000Qooooo`;o0000=oooool00ol0003oooooooooo`1Oooooo`00Boooool0
0ol0003oooooooooo`0eooooo`;o00006oooool00omgMgOoIVIVooooo`06ooooo`03o`000?oooooo
oooo027ooooo0_l0000gooooo`03o`000?oooooooooo05oooooo001;ooooo`;o0000=_ooool2o`00
01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
03Cooooo0_l0001Qooooo`00Boooool2o`0003Kooooo00?o0000ooooooooool05oooool01Ol0003o
^[ZjoooooonHV9So410@00Oooooo00?o0000ooooooooool08_ooool2o`0003Gooooo0_l0001Qoooo
o`00Boooool2o`0003Gooooo0_l0000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01oooool00ol0
003oooooooooo`0Rooooo`;o0000=Oooool2o`00067ooooo001;ooooo`;o0000=Oooool2o`0002Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0cooooo`;o0000HOooool004cooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Pooooo`00C?ooool2o`0003?ooooo0_l0
000Vooooo`03o`000?oooooooooo02?ooooo0_l0000dooooo`03o`000?oooooooooo063ooooo001<
ooooo`;o0000<oooool2o`0002Kooooo00?o0000ooooooooool08oooool2o`0003?ooooo0_l0001R
ooooo`00C?ooool2o`0003?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo037ooooo0_l0001Rooooo`00C?ooool2o`0003?ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo037ooooo0_l0001Rooooo`00
COooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0aooooo`;o0000H_ooool004gooooo0_l0000booooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo067ooooo001=ooooo`;o0000<_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0<?ooool2o`0006?ooooo001=ooooo`;o0000<_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0<?ooool2o`00
06?ooooo001=ooooo`;o0000<_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0<?ooool2o`0006?ooooo001>ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool09Oooool2o`0002Gooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`1Rooooo`00C_ooool2o`00037ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02oooooo0_l0001Tooooo`00C_ooool2o`00037ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02oooooo0_l0001T
ooooo`00C_ooool2o`00037ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo02oooooo0_l0001Tooooo`00Coooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo06?ooooo001?ooooo`;o0000<?ooool00ol0003oooooooooo`0Rooooo`Ko0000
9?ooool00ol0003oooooooooo`0^ooooo`;o0000IOooool004oooooo0_l0000`ooooo`03o`000?oo
oooooooo023ooooo0ol00002ooooo`03o`000?oooooooooo00;o00008_ooool00ol0003ooooooooo
o`0^ooooo`;o0000IOooool0053ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oo
oooooooo02kooooo0_l0001Uooooo`00D?ooool2o`0002oooooo00?o0000ooooooooool07oooool2
o`0000Cooooo00Co0000oooooooooooooooo0_l0000Qooooo`03o`000?oooooooooo02gooooo0_l0
001Vooooo`00D?ooool2o`0002oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0]
ooooo`;o0000I_ooool0053ooooo0_l0000_ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0;Oooool2o`0006Kooooo001Aooooo`;o0000;_ooool2o`00023ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo0_l0000_ooooo`03
o`000?oooooooooo06Gooooo001Aooooo`;o0000;oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`;o0000
;_ooool2o`0006Oooooo001Aooooo`;o0000;oooool00ol0003oooooooooo`0Nooooo`;o00001?oo
ool01?l0003oooooooooooooool2o`00023ooooo00?o0000ooooooooool0;Oooool2o`0006Oooooo
001Booooo`;o0000;_ooool2o`00023ooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
8?ooool2o`0002oooooo00?o0000ooooooooool0I_ooool005;ooooo0_l0000^ooooo`;o00008Ooo
ool2o`0000;ooooo00?o0000ooooool000000_l0000Pooooo`;o0000;_ooool2o`0006Sooooo001B
ooooo`;o0000;oooool00ol0003oooooooooo`0Pooooo`Ko00008_ooool2o`0002kooooo0_l0001X
ooooo`00Doooool2o`0002kooooo0_l0000Tooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0;?ooool2o`0006Wooooo001Cooooo`;o0000;_ooool2o`0002Cooooo00?o0000oooooooo
ool08Oooool2o`0002kooooo0_l0001Yooooo`00E?ooool2o`0002kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Qooooo`;o0000;_ooool00ol0003oooooooooo`1Xooooo`00E?oo
ool2o`0002kooooo0_l0000Sooooo`03o`000?oooooooooo023ooooo0_l0000^ooooo`;o0000J_oo
ool005Cooooo0_l0000^ooooo`;o00008oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02gooooo0_l0001Zooooo`00EOooool2o`0002kooooo0_l0000Rooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0;?ooool2o`0006_ooooo001Eooooo`;o0000;_ooool2o`0002;o
oooo00?o0000ooooooooool07oooool2o`0002kooooo0_l0001[ooooo`00E_ooool2o`0002kooooo
0_l0000Qooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0;?ooool3o`0006_ooooo
001Fooooo`;o0000;_ooool2o`00027ooooo00?o0000ooooooooool07_ooool2o`0002kooooo0_l0
001/ooooo`00Eoooool2o`0002kooooo0_l0000Pooooo`03o`000?oooooooooo01gooooo0_l0000^
ooooo`?o0000K?ooool005Oooooo0_l0000_ooooo`;o00007oooool00ol0003oooooooooo`0Moooo
o`;o0000;_ooool2o`0006gooooo001Hooooo`;o0000;_ooool2o`0001oooooo00?o0000oooooooo
ool07?ooool2o`0002kooooo0_l0001^ooooo`00F?ooool2o`0002oooooo0_l0000Nooooo`03o`00
0?oooooooooo01_ooooo0_l0000_ooooo`;o0000K_ooool005Wooooo00?o0000ooooooooool0;_oo
ool2o`0001gooooo00?o0000ooooooooool06_ooool2o`0002oooooo0_l0001_ooooo`00FOooool2
o`00033ooooo0_l0000Looooo`03o`000?oooooooooo01Wooooo0_l0000`ooooo`;o0000Koooool0
05[ooooo0_l0000`ooooo`?o00006_ooool2o`0001Wooooo0_l0000`ooooo`;o0000L?ooool005[o
oooo0_l0000aooooo`?o00006Oooool00ol0003oooooooooo`0Gooooo`;o0000<Oooool2o`00073o
oooo001Kooooo`;o0000<Oooool3o`0001Sooooo00?o0000ooooooooool05_ooool2o`00037ooooo
0_l0001aooooo`00Foooool2o`0003;ooooo0ol0000Gooooo`03o`000?oooooooooo01Gooooo0_l0
000booooo`;o0000LOooool005cooooo0_l0000booooo`?o00005_ooool00ol0003oooooooooo`0C
ooooo`;o0000<oooool2o`0007;ooooo001Mooooo`;o0000<_ooool4o`0001Cooooo00?o0000oooo
ooooool04_ooool2o`0003Cooooo0_l0001booooo`00GOooool2o`0003Cooooo0ol0000Cooooo`03
o`000?oooooooooo013ooooo0_l0000eooooo`;o0000Loooool005kooooo0_l0000eooooo`?o0000
4Oooool00ol0003oooooooooo`0>ooooo`?o0000=Oooool2o`0007Cooooo001Oooooo`;o0000=Ooo
ool4o`0000oooooo00?o0000ooooooooool03?ooool4o`0003Kooooo0_l0001dooooo`00H?ooool0
0ol0003oooooooooo`0fooooo`?o00003Oooool00ol0003oooooooooo`0:ooooo`Co0000=oooool2
o`0007Gooooo001Pooooo`;o0000>?ooool4o`0000_ooooo00?o0000ooooooooool01oooool5o`00
03Sooooo0_l0001fooooo`00HOooool2o`0003[ooooo1Ol00007ooooo`03o`000?oooooooooo00Co
oooo1Ol0000jooooo`;o0000Moooool0067ooooo0_l0000noooooa3o0000?_ooool2o`0007Oooooo
001Rooooo`;o0000AOooool00ol0003oooooooooo`12ooooo`;o0000N?ooool006?ooooo0_l0000j
ooooo`;o000000?o410@ooooooooool01Oooool00ol0003oooooooooo`11ooooo`;o0000NOooool0
06?ooooo0ol0000jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@?ooool2o`00
07[ooooo001Tooooo`?o0000=_ooool5o`0000Oooooo0ol00010ooooo`03o`000?oooooooooo07Wo
oooo001Uooooo`;o0000=_ooool01?m4A4CogMgMooooool00008ooooo`03o`000?oooooooooo03oo
oooo0_l0001kooooo`00I_ooool2o`0003Gooooo00CogMgMoeEEEOoooooo00002?ooool00ol0003o
ooooooooo`0nooooo`;o0000O?ooool006Oooooo0_l0000eooooo`03ogMgMoo<c<co000000Sooooo
00?o0000ooooooooool0?Oooool2o`0007gooooo001Xooooo`;o0000=?ooool00oo^k^koA4A4o`00
0008ooooo`03o`000?oooooooooo03_ooooo0ol0001nooooo`00JOooool2o`0003Cooooo00?oMgMg
o`000?ooool01oooool00ol0003oooooooooo`0jooooo`?o0000Ooooool006[ooooo0_l0000moooo
o`03o`000?oooooooooo03Wooooo0ol00020ooooo`00Joooool3o`0003_ooooo00?o0000oooooooo
ool0>?ooool3o`00087ooooo001/ooooo`?o0000>_ooool00ol0003oooooooooo`0gooooo`?o0000
P_ooool006gooooo0ol0000iooooo`03o`000?oooooooooo03Kooooo0_l00024ooooo`00K_ooool3
o`0003Sooooo00?o0000ooooooooool0=Oooool2o`0008Gooooo001_ooooo`?o0000=oooool00ol0
003oooooooooo`0dooooo`;o0000Q_ooool0077ooooo0ol0000eooooo`03o`000?oooooooooo03;o
oooo0ol00027ooooo`00L_ooool3o`0003Cooooo00?o0000ooooooooool0<Oooool3o`0008Sooooo
001cooooo`?o0000<oooool00ol0003oooooooooo`0`ooooo`?o0000ROooool007Gooooo0_l0000b
ooooo`03o`000?oooooooooo02kooooo1?l0002:ooooo`00M_ooool3o`00033ooooo00?o0000oooo
ooooool0;Oooool4o`0008_ooooo001hooooo`;o0000;oooool2o`0002cooooo1?l0002=ooooo`00
NOooool3o`0002gooooo00?o0000ooooooooool0:_ooool3o`0008oooooo001jooooo`Co0000:ooo
ool00ol0003oooooooooo`0Yooooo`?o0000T?ooool007cooooo0ol0000Zooooo`03o`000?oooooo
oooo02Oooooo0ol0002Booooo`00O_ooool3o`0002Sooooo00?o0000ooooooooool09Oooool4o`00
09?ooooo001oooooo`Co00009_ooool00ol0003oooooooooo`0Sooooo`Co0000UOooool0087ooooo
1?l0000Tooooo`03o`000?oooooooooo02;ooooo0ol0002Gooooo`00Poooool4o`0002;ooooo00?o
0000ooooooooool07oooool4o`0009Wooooo0025ooooo`Co00008?ooool00ol0003oooooooooo`0M
ooooo`Co0000Voooool008Oooooo1?l0000Nooooo`03o`000?oooooooooo01_ooooo1?l0002Moooo
o`00ROooool5o`0001_ooooo00?o0000ooooooooool06?ooool5o`0009oooooo002<ooooo`Go0000
6?ooool00ol0003oooooooooo`0Eooooo`Go0000X_ooool008oooooo1_l0000Dooooo`03o`000?oo
oooooooo01;ooooo1_l0002Tooooo`00T_ooool6o`00017ooooo00?o0000ooooooooool03_ooool7
o`000:Oooooo002Fooooo`Oo00003?ooool00ol0003oooooooooo`09ooooo`So0000Zoooool009[o
oooo2ol00004ooooo`04o`000?ooooooooooooooo`_o0000/?ooool00:?ooooo3?l0002iooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00YOooool3o`000003oa0@4?oooooooooo0;gooooo
002Wooooo`03oa0@4?nj^[[ooooo0;kooooo002Wooooo`03oiRHV?lb<S;ooooo0;kooooo002Woooo
o`03omgMgOl0003o^[Zj0;kooooo002Wooooo`03oeEEEOmgMgOoA4A40;kooooo002Vooooo`05omgM
gOl@413oooooob4Q8OoMgMd0_Oooool00:Kooooo00GoIVIVohN7QoooooooV9RHoeEEE@2mooooo`00
YOooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0;_ooooo002Uooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool0^_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-5.23879, -5.20006, 0.0387359, \
0.0387359}}],

Cell[TextData[{
  "Fig. 1.14 Solution to Exercise (8)(b): Field lines for the magnetic field \
",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["B",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ", projected into the (",
  StyleBox["x",
    FontSlant->"Italic"],
  ",",
  StyleBox["y",
    FontSlant->"Italic"],
  ") plane. "
}], "Caption",
  CellTags->"Fig. 1.14"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " A chaotic magnetic field can be created by adding another magnetic field \
to ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["B",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ", writing ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["B",
                  FontSlant->"Plain"], 
                StyleBox["s",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "(", 
            StyleBox[\(r, \[Theta], z\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox["B",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], "(", 
              StyleBox[\(r, \[Theta], z\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Bold"], "+", 
            RowBox[{"\[Epsilon]", " ", 
              RowBox[{"(", " ", 
                StyleBox[
                  RowBox[{
                    RowBox[{
                      OverscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "^"], "  ", "r", 
                      " ", \(sin(\[Theta] - z)\)}], " ", "+", " ", 
                    RowBox[{
                      OverscriptBox[
                        StyleBox["\[Theta]",
                          FontWeight->"Bold"], "^"], " ", "2", "r", 
                      " ", \(cos(\[Theta] - z)\)}]}],
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ". (This field also satisfies ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{
              RowBox[{"\[Del]", 
                RowBox[{"\[CenterDot]", 
                  StyleBox["B",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}], 
              StyleBox["=",
                FontWeight->"Plain"], 
              StyleBox["0",
                FontWeight->"Plain"]}],
            "TraditionalForm"]}], TraditionalForm]]],
  ".)  For ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 1/3\)]],
  " replot the field lines for this field in ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\)\)]],
  ", using the same initial conditions as in  part ",
  Cell[BoxData[
      \(TraditionalForm\`\((a)\)\)]],
  ".The  field lines now become a \"tangle of spaghetti\".   Project them \
into the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane. You will see that some of the field lines wrap around one magnetic \
island for a time, then get captured by the adjoining island. This complex \
competition between the islands is responsible for the chaotic trajectory \
followed by the lines. "
}], "Text",
  CellTags->"i:63"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " One way to test visually whether some of the field lines are chaotic is \
to note that the magnetic field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["B",
                FontSlant->"Plain"], 
              StyleBox["s",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], "(", 
          StyleBox[\(r, \[Theta], z\),
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is periodic in ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " with period ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\)]],
  ".  If ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["B",
            FontWeight->"Bold",
            FontSlant->"Plain"], "s"], TraditionalForm]]],
  " were  not chaotic, it would create field lines that fell on closed \
surfaces,  and the  surfaces would also have to be periodic in ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ". Therefore, if you plot  values of ",
  Cell[BoxData[
      \(TraditionalForm\`\((r(z\_n), \[Theta](z\_n))\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n = 2\ \[Pi]\ n\)]],
  " in either the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r\ , \[Theta])\)\)]],
  " plane or the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, \ y)\)\)]],
  " plane, the resulting points must form closed curves  for a nonchaotic \
field.  This is called a ",
  StyleBox[ButtonBox["Poincar\[EAcute]",
    ButtonData:>{
      URL[ 
      "http://turnbull.dcs.st-and.ac.uk/~history/Mathematicians/Poincare.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" plot",
    FontSlant->"Italic"],
  ". However, for  a chaotic field the field lines are",
  StyleBox[" not",
    FontSlant->"Italic"],
  " on closed surfaces; rather,  they fill space.  A Poincar\[EAcute]  plot \
will now show a chaotic collection of points filling a region in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r\ , \[Theta])\)\)]],
  " plane [or the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\ , \ y)\)\)]],
  " plane]."
}], "Text",
  CellTags->"i:107"],

Cell[TextData[{
  "\tFor the same initial conditions as in part (a), use ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to evaluate the field lines for the field ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["B",
              FontSlant->"Plain"], 
            StyleBox["s",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 1/3\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ z \[LessEqual] \ 400\ \[Pi]\)]],
  ". (Increase MaxSteps to about 200000) . Make a table of values of ",
  Cell[BoxData[
      \(TraditionalForm\`\((r(z\_n), \[Theta](z\_n))\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n = 2\ \[Pi]\ n\)]],
  ". Use ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to plot these values in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane.  (The solution is shown in Fig. ",
  ButtonBox["1.15",
    ButtonData:>"Fig. 1.15",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 1/4\)]],
  ")"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0961538 0.5 0.0961538 [
[.11538 .4875 -6 -9 ]
[.11538 .4875 6 0 ]
[.30769 .4875 -6 -9 ]
[.30769 .4875 6 0 ]
[.69231 .4875 -3 -9 ]
[.69231 .4875 3 0 ]
[.88462 .4875 -3 -9 ]
[.88462 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 .11538 -12 -4.5 ]
[.4875 .11538 0 4.5 ]
[.4875 .30769 -12 -4.5 ]
[.4875 .30769 0 4.5 ]
[.4875 .69231 -6 -4.5 ]
[.4875 .69231 0 4.5 ]
[.4875 .88462 -6 -4.5 ]
[.4875 .88462 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 .5 m
.11538 .50625 L
s
[(-4)] .11538 .4875 0 1 Mshowa
.30769 .5 m
.30769 .50625 L
s
[(-2)] .30769 .4875 0 1 Mshowa
.69231 .5 m
.69231 .50625 L
s
[(2)] .69231 .4875 0 1 Mshowa
.88462 .5 m
.88462 .50625 L
s
[(4)] .88462 .4875 0 1 Mshowa
.125 Mabswid
.16346 .5 m
.16346 .50375 L
s
.21154 .5 m
.21154 .50375 L
s
.25962 .5 m
.25962 .50375 L
s
.35577 .5 m
.35577 .50375 L
s
.40385 .5 m
.40385 .50375 L
s
.45192 .5 m
.45192 .50375 L
s
.54808 .5 m
.54808 .50375 L
s
.59615 .5 m
.59615 .50375 L
s
.64423 .5 m
.64423 .50375 L
s
.74038 .5 m
.74038 .50375 L
s
.78846 .5 m
.78846 .50375 L
s
.83654 .5 m
.83654 .50375 L
s
.06731 .5 m
.06731 .50375 L
s
.01923 .5 m
.01923 .50375 L
s
.93269 .5 m
.93269 .50375 L
s
.98077 .5 m
.98077 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .11538 m
.50625 .11538 L
s
[(-4)] .4875 .11538 1 0 Mshowa
.5 .30769 m
.50625 .30769 L
s
[(-2)] .4875 .30769 1 0 Mshowa
.5 .69231 m
.50625 .69231 L
s
[(2)] .4875 .69231 1 0 Mshowa
.5 .88462 m
.50625 .88462 L
s
[(4)] .4875 .88462 1 0 Mshowa
.125 Mabswid
.5 .16346 m
.50375 .16346 L
s
.5 .21154 m
.50375 .21154 L
s
.5 .25962 m
.50375 .25962 L
s
.5 .35577 m
.50375 .35577 L
s
.5 .40385 m
.50375 .40385 L
s
.5 .45192 m
.50375 .45192 L
s
.5 .54808 m
.50375 .54808 L
s
.5 .59615 m
.50375 .59615 L
s
.5 .64423 m
.50375 .64423 L
s
.5 .74038 m
.50375 .74038 L
s
.5 .78846 m
.50375 .78846 L
s
.5 .83654 m
.50375 .83654 L
s
.5 .06731 m
.50375 .06731 L
s
.5 .01923 m
.50375 .01923 L
s
.5 .93269 m
.50375 .93269 L
s
.5 .98077 m
.50375 .98077 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.017 w
.5 .01923 Mdot
.52067 .01852 Mdot
.54188 .0196 Mdot
.56367 .0226 Mdot
.58556 .02761 Mdot
.60715 .03461 Mdot
.62939 .04409 Mdot
.65145 .05605 Mdot
.67247 .07012 Mdot
.6924 .08625 Mdot
.71129 .10459 Mdot
.72832 .1243 Mdot
.74396 .14579 Mdot
.75762 .16811 Mdot
.76959 .19139 Mdot
.77996 .21562 Mdot
.78885 .24081 Mdot
.79618 .26641 Mdot
.80201 .29188 Mdot
.80658 .31725 Mdot
.81013 .34295 Mdot
.81276 .36818 Mdot
.81459 .39305 Mdot
.81588 .41721 Mdot
.81674 .44154 Mdot
.81725 .46565 Mdot
.81749 .49008 Mdot
.81748 .51466 Mdot
.81719 .53987 Mdot
.81656 .56558 Mdot
.8155 .59201 Mdot
.81382 .61951 Mdot
.81122 .64825 Mdot
.80732 .67869 Mdot
.80165 .71047 Mdot
.79362 .7437 Mdot
.78257 .77796 Mdot
.76784 .81268 Mdot
.74815 .84814 Mdot
.72281 .88279 Mdot
.69134 .91501 Mdot
.65336 .94309 Mdot
.60944 .96485 Mdot
.55964 .97844 Mdot
.50731 .98156 Mdot
.45668 .97397 Mdot
.40911 .95639 Mdot
.36763 .93101 Mdot
.33238 .89937 Mdot
.30355 .86308 Mdot
.28141 .82448 Mdot
.26501 .78457 Mdot
.25356 .74456 Mdot
.24605 .70481 Mdot
.24162 .66701 Mdot
.23921 .63074 Mdot
.23804 .59517 Mdot
.23762 .5603 Mdot
.23749 .5266 Mdot
.23747 .49298 Mdot
.23751 .45908 Mdot
.23772 .42427 Mdot
.23843 .38833 Mdot
.24019 .35051 Mdot
.24389 .3105 Mdot
.25072 .26803 Mdot
.26226 .22339 Mdot
.28008 .178 Mdot
.30577 .13345 Mdot
.34138 .09125 Mdot
.3877 .05518 Mdot
.44464 .02929 Mdot
.5098 .01816 Mdot
.57778 .02508 Mdot
.64141 .04972 Mdot
.69602 .08887 Mdot
.73852 .13708 Mdot
.76938 .18982 Mdot
.79027 .24371 Mdot
.8034 .29631 Mdot
.8112 .3476 Mdot
.81539 .39698 Mdot
.81736 .44422 Mdot
.81805 .49092 Mdot
.81778 .53811 Mdot
.8163 .58657 Mdot
.81283 .63713 Mdot
.80593 .69016 Mdot
.79329 .74639 Mdot
.77192 .80491 Mdot
.7382 .86354 Mdot
.6898 .91678 Mdot
.62645 .95794 Mdot
.55217 .97984 Mdot
.47466 .9782 Mdot
.4027 .9535 Mdot
.3437 .91121 Mdot
.30043 .85895 Mdot
.27128 .80243 Mdot
.25358 .74613 Mdot
.24384 .69158 Mdot
.23933 .64047 Mdot
.23762 .5931 Mdot
.23716 .54759 Mdot
.23709 .5031 Mdot
.23712 .45853 Mdot
.2375 .41277 Mdot
.23903 .36461 Mdot
.24324 .31317 Mdot
.25271 .25733 Mdot
.27122 .19748 Mdot
.30384 .13568 Mdot
.35508 .07843 Mdot
.42595 .03565 Mdot
.5116 .01786 Mdot
.6007 .0315 Mdot
.67987 .07481 Mdot
.73891 .13717 Mdot
.77764 .20771 Mdot
.80037 .28023 Mdot
.81184 .34992 Mdot
.81682 .41665 Mdot
.81842 .48121 Mdot
.81804 .54513 Mdot
.81533 .61065 Mdot
.80793 .68004 Mdot
.79121 .75458 Mdot
.75831 .83241 Mdot
.70262 .9054 Mdot
.62184 .96032 Mdot
.52377 .98232 Mdot
.42559 .96436 Mdot
.34523 .91307 Mdot
.29052 .84327 Mdot
.25942 .7694 Mdot
.2444 .69861 Mdot
.23855 .6336 Mdot
.23686 .57311 Mdot
.23661 .51498 Mdot
.23663 .45723 Mdot
.23733 .39667 Mdot
.24093 .33084 Mdot
.25214 .25797 Mdot
.27855 .1797 Mdot
.32909 .10313 Mdot
.41025 .04227 Mdot
.51647 .01752 Mdot
.62571 .04128 Mdot
.71368 .10571 Mdot
.77044 .19073 Mdot
.80056 .27978 Mdot
.8136 .36412 Mdot
.81811 .44384 Mdot
.81874 .52123 Mdot
.81631 .60012 Mdot
.80754 .68442 Mdot
.78443 .77575 Mdot
.73497 .86885 Mdot
.65007 .94601 Mdot
.53501 .98206 Mdot
.41721 .96107 Mdot
.32684 .89461 Mdot
.27286 .80796 Mdot
.24751 .72042 Mdot
.23849 .64009 Mdot
.23638 .56661 Mdot
.23618 .49682 Mdot
.23644 .42705 Mdot
.23889 .3537 Mdot
.24866 .27346 Mdot
.27531 .18637 Mdot
.3321 .09961 Mdot
.42739 .03463 Mdot
.55019 .01936 Mdot
.66739 .06505 Mdot
.75035 .15343 Mdot
.79481 .25606 Mdot
.813 .35534 Mdot
.81845 .44693 Mdot
.81884 .53531 Mdot
.81467 .62732 Mdot
.79926 .72699 Mdot
.75869 .83266 Mdot
.67647 .92844 Mdot
.55256 .98045 Mdot
.41937 .96221 Mdot
.31921 .88597 Mdot
.26486 .78782 Mdot
.24296 .69231 Mdot
.23683 .60632 Mdot
.23594 .52759 Mdot
.23598 .45057 Mdot
.23772 .36982 Mdot
.2471 .28039 Mdot
.27735 .18126 Mdot
.34681 .08482 Mdot
.46486 .02303 Mdot
.60552 .03261 Mdot
.71902 .1111 Mdot
.78334 .22037 Mdot
.81008 .32994 Mdot
.5 .21154 Mdot
.498 .22783 Mdot
.50382 .24194 Mdot
.51464 .25197 Mdot
.52844 .25694 Mdot
.54332 .25564 Mdot
.55634 .24665 Mdot
.56268 .22988 Mdot
.55696 .20964 Mdot
.53885 .19567 Mdot
.51703 .19569 Mdot
.50207 .20763 Mdot
.49766 .22386 Mdot
.50182 .23876 Mdot
.5116 .24989 Mdot
.52481 .2562 Mdot
.53961 .25661 Mdot
.55345 .24967 Mdot
.56201 .23472 Mdot
.55971 .21464 Mdot
.5443 .19809 Mdot
.52231 .19431 Mdot
.50494 .20385 Mdot
.49788 .21964 Mdot
.50012 .23519 Mdot
.50868 .2474 Mdot
.52114 .25504 Mdot
.5357 .25712 Mdot
.5501 .25226 Mdot
.56056 .23936 Mdot
.56161 .22005 Mdot
.54944 .20153 Mdot
.52813 .19387 Mdot
.50867 .20038 Mdot
.49878 .21523 Mdot
.4988 .23122 Mdot
.5059 .24446 Mdot
.51746 .25342 Mdot
.53159 .25714 Mdot
.5463 .25434 Mdot
.55832 .24371 Mdot
.56255 .22578 Mdot
.55412 .20604 Mdot
.53446 .19455 Mdot
.51342 .19735 Mdot
.50053 .21062 Mdot
.49797 .2268 Mdot
.50333 .24103 Mdot
.5138 .25129 Mdot
.52733 .25662 Mdot
.54209 .25588 Mdot
.55531 .24767 Mdot
.56243 .23162 Mdot
.55802 .21152 Mdot
.54101 .19658 Mdot
.51919 .1951 Mdot
.5033 .20601 Mdot
.49779 .22198 Mdot
.50108 .23708 Mdot
.51023 .24864 Mdot
.523 .25557 Mdot
.5376 .25683 Mdot
.55168 .25101 Mdot
.56124 .23722 Mdot
.5608 .2176 Mdot
.54722 .19996 Mdot
.52564 .194 Mdot
.50711 .20179 Mdot
.49842 .21697 Mdot
.49933 .23273 Mdot
.50695 .24551 Mdot
.51879 .25395 Mdot
.53299 .25709 Mdot
.54754 .25364 Mdot
.55904 .24233 Mdot
.5623 .22402 Mdot
.55278 .20466 Mdot
.53265 .19429 Mdot
.51208 .19816 Mdot
.50005 .21184 Mdot
.4982 .22792 Mdot
.50398 .24183 Mdot
.51465 .25175 Mdot
.52827 .25671 Mdot
.54298 .25554 Mdot
.55594 .24685 Mdot
.56248 .23046 Mdot
.55731 .21044 Mdot
.53981 .19616 Mdot
.51815 .19547 Mdot
.50284 .20679 Mdot
.49785 .22273 Mdot
.50145 .23762 Mdot
.51074 .24894 Mdot
.52354 .25563 Mdot
.53808 .25666 Mdot
.55201 .25064 Mdot
.56131 .2367 Mdot
.56056 .21713 Mdot
.54679 .19976 Mdot
.52529 .1941 Mdot
.507 .20201 Mdot
.49849 .21712 Mdot
.49945 .23275 Mdot
.50704 .24544 Mdot
.51878 .25382 Mdot
.53287 .25698 Mdot
.54734 .25363 Mdot
.55884 .2425 Mdot
.56227 .22439 Mdot
.55308 .20507 Mdot
.53323 .19446 Mdot
.51267 .19792 Mdot
.5004 .21131 Mdot
.49822 .22728 Mdot
.50371 .24123 Mdot
.51413 .25127 Mdot
.52752 .25646 Mdot
.54212 .25568 Mdot
.5552 .24753 Mdot
.56227 .23169 Mdot
.55804 .2118 Mdot
.54135 .19687 Mdot
.51975 .19509 Mdot
.5038 .20562 Mdot
.498 .22133 Mdot
.50094 .23633 Mdot
.50974 .24795 Mdot
.52218 .25508 Mdot
.53652 .25675 Mdot
.55058 .25159 Mdot
.5606 .23858 Mdot
.56124 .21947 Mdot
.54898 .2014 Mdot
.52797 .19407 Mdot
.50888 .20051 Mdot
.4991 .21505 Mdot
.49898 .23077 Mdot
.50578 .24386 Mdot
.51698 .25284 Mdot
.53075 .25679 Mdot
.54525 .2545 Mdot
.55742 .24463 Mdot
.56242 .22747 Mdot
.55535 .20784 Mdot
.53677 .19529 Mdot
.51567 .19653 Mdot
.50179 .20874 Mdot
.49805 .2246 Mdot
.5024 .23898 Mdot
.51205 .24971 Mdot
.52495 .25581 Mdot
.53939 .25624 Mdot
.55295 .24962 Mdot
.56155 .23524 Mdot
.55987 .2157 Mdot
.54544 .19904 Mdot
.52404 .19435 Mdot
.50639 .20278 Mdot
.49851 .21788 Mdot
.49981 .23326 Mdot
.50748 .24566 Mdot
.51918 .25381 Mdot
.53316 .25681 Mdot
.54747 .25337 Mdot
.5588 .24227 Mdot
.56213 .2243 Mdot
.55302 .20518 Mdot
.5334 .1946 Mdot
.513 .19789 Mdot
.50069 .21103 Mdot
.49833 .22683 Mdot
.50357 .2407 Mdot
.51372 .25078 Mdot
.52686 .25616 Mdot
.54129 .25574 Mdot
.55443 .24813 Mdot
.56197 .23288 Mdot
.55868 .21323 Mdot
.54292 .19771 Mdot
.52148 .19481 Mdot
.50493 .20444 Mdot
.49829 .2198 Mdot
.50048 .23486 Mdot
.50869 .24677 Mdot
.52069 .25436 Mdot
.53476 .25671 Mdot
.54888 .2525 Mdot
.55959 .24062 Mdot
.56176 .22222 Mdot
.55136 .20357 Mdot
.5312 .19434 Mdot
.51136 .1989 Mdot
.50009 .21255 Mdot
.49859 .22825 Mdot
.50437 .24177 Mdot
.51482 .25143 Mdot
.52812 .25633 Mdot
.54252 .25533 Mdot
.55534 .24708 Mdot
.56214 .2313 Mdot
.5 .40385 Mdot
.3772 .80482 Mdot
.65488 .27066 Mdot
.68347 .28122 Mdot
.47461 .40374 Mdot
.39803 .6432 Mdot
.49821 .87388 Mdot
.67875 .50304 Mdot
.50794 .12487 Mdot
.41112 .38184 Mdot
.46807 .58394 Mdot
.69952 .67323 Mdot
.62514 .19219 Mdot
.38799 .77398 Mdot
.6302 .55317 Mdot
.60154 .85648 Mdot
.43805 .11628 Mdot
.50472 .60237 Mdot
.65322 .53195 Mdot
.69904 .5238 Mdot
.62854 .52489 Mdot
.49342 .89006 Mdot
.39249 .3233 Mdot
.45793 .64071 Mdot
.65722 .51766 Mdot
.56268 .41225 Mdot
.57777 .37794 Mdot
.5549 .38357 Mdot
.62675 .36699 Mdot
.39949 .35725 Mdot
.47314 .59919 Mdot
.68312 .71031 Mdot
.65366 .70726 Mdot
.39003 .36443 Mdot
.47333 .55352 Mdot
.38628 .28839 Mdot
.43145 .69476 Mdot
.6436 .72853 Mdot
.61958 .12584 Mdot
.6494 .46741 Mdot
.56091 .41456 Mdot
.57968 .37763 Mdot
.55159 .38192 Mdot
.6368 .35577 Mdot
.67494 .33931 Mdot
.4806 .39811 Mdot
.38507 .66954 Mdot
.60048 .40005 Mdot
.39339 .78738 Mdot
.50276 .53312 Mdot
.45469 .47383 Mdot
.40364 .59808 Mdot
.52941 .59757 Mdot
.65848 .17372 Mdot
.55914 .48521 Mdot
.60277 .54561 Mdot
.65496 .78318 Mdot
.52387 .55459 Mdot
.66674 .78753 Mdot
.46594 .44916 Mdot
.40379 .6097 Mdot
.64565 .31562 Mdot
.54759 .53666 Mdot
.64325 .83164 Mdot
.43282 .40666 Mdot
.45234 .58231 Mdot
.64141 .52196 Mdot
.54163 .90194 Mdot
.45374 .16136 Mdot
.3858 .75122 Mdot
.66786 .43197 Mdot
.40964 .27335 Mdot
.40846 .72422 Mdot
.67188 .58559 Mdot
.43632 .11458 Mdot
.48517 .53827 Mdot
.55397 .11198 Mdot
.60485 .48074 Mdot
.70397 .71593 Mdot
.61508 .16093 Mdot
.66746 .37891 Mdot
.47352 .38619 Mdot
.39038 .66572 Mdot
.53869 .52631 Mdot
.6784 .79077 Mdot
.43048 .18926 Mdot
.3933 .73814 Mdot
.689 .509 Mdot
.39794 .21771 Mdot
.64725 .73203 Mdot
.62262 .12728 Mdot
.66779 .41956 Mdot
.41777 .30419 Mdot
.41166 .69323 Mdot
.68386 .63541 Mdot
.69541 .7687 Mdot
.5285 .11678 Mdot
.65407 .41885 Mdot
.51704 .4085 Mdot
.70735 .73421 Mdot
.64824 .4855 Mdot
.62957 .38134 Mdot
.6332 .41281 Mdot
.6203 .40005 Mdot
.62947 .41061 Mdot
.62147 .40132 Mdot
.62496 .41208 Mdot
.625 .39957 Mdot
.61947 .41431 Mdot
.62838 .3986 Mdot
.61449 .41547 Mdot
.63009 .40072 Mdot
.61253 .41391 Mdot
.63172 .40308 Mdot
.6118 .41193 Mdot
.63442 .40342 Mdot
.60852 .41257 Mdot
.64295 .39665 Mdot
.58697 .42182 Mdot
.64402 .7775 Mdot
.69873 .25882 Mdot
.58644 .50976 Mdot
.58941 .88163 Mdot
.62178 .62098 Mdot
.49725 .65273 Mdot
.61077 .67138 Mdot
.42912 .42145 Mdot
.45209 .55978 Mdot
.61227 .83463 Mdot
.69462 .39345 Mdot
.42178 .35339 Mdot
.44033 .64034 Mdot
.68283 .66415 Mdot
.48364 .87615 Mdot
.69802 .40706 Mdot
.49847 .45232 Mdot
.70828 .73394 Mdot
.52307 .61055 Mdot
.5079 .65408 Mdot
.62097 .68452 Mdot
.37984 .32596 Mdot
.48535 .5872 Mdot
.68153 .7262 Mdot
.61211 .60273 Mdot
.651 .50364 Mdot
.65975 .32373 Mdot
.58747 .44136 Mdot
.64915 .37756 Mdot
.57394 .42864 Mdot
.50208 .38711 Mdot
.46584 .8981 Mdot
.61595 .15694 Mdot
.63167 .44275 Mdot
.58948 .1283 Mdot
.59799 .47382 Mdot
.69751 .48646 Mdot
.61389 .5299 Mdot
.56231 .88195 Mdot
.51158 .63876 Mdot
.59974 .65081 Mdot
.46528 .47053 Mdot
.38031 .64833 Mdot
.59744 .53365 Mdot
.62043 .84527 Mdot
.53216 .62572 Mdot
.5885 .63365 Mdot
.5249 .53944 Mdot
.67246 .79778 Mdot
.51937 .90499 Mdot
.63708 .26332 Mdot
.57491 .33179 Mdot
.43901 .28472 Mdot
.65249 .33619 Mdot
.61008 .43484 Mdot
.66796 .3023 Mdot
.55992 .44234 Mdot
.43302 .18988 Mdot
.38207 .75803 Mdot
.42066 .15163 Mdot
.68582 .33821 Mdot
.42711 .34223 Mdot
.42538 .65809 Mdot
.68795 .66646 Mdot
.46015 .88746 Mdot
.6839 .79888 Mdot
.55768 .1221 Mdot
.6476 .42763 Mdot
.5642 .41823 Mdot
.56666 .36976 Mdot
.55968 .39045 Mdot
.61435 .37534 Mdot
.5528 .11472 Mdot
.61443 .47203 Mdot
.69977 .56154 Mdot
.51461 .47097 Mdot
.59205 .36443 Mdot
.52918 .37107 Mdot
.65024 .19877 Mdot
.58902 .46003 Mdot
.40552 .34595 Mdot
.45627 .63094 Mdot
.5 .59615 Mdot
.6228 .19518 Mdot
.34512 .72934 Mdot
.31653 .71878 Mdot
.52539 .59626 Mdot
.60197 .3568 Mdot
.50253 .12626 Mdot
.32125 .49649 Mdot
.49113 .8752 Mdot
.5867 .61442 Mdot
.53329 .41768 Mdot
.30122 .375 Mdot
.38575 .83517 Mdot
.41531 .88514 Mdot
.40727 .50544 Mdot
.35114 .15724 Mdot
.40885 .84031 Mdot
.53919 .64962 Mdot
.62369 .27709 Mdot
.35234 .23098 Mdot
.31911 .80026 Mdot
.37096 .49149 Mdot
.46767 .09936 Mdot
.59626 .17243 Mdot
.5788 .85038 Mdot
.31407 .6613 Mdot
.57359 .65887 Mdot
.57465 .34087 Mdot
.31279 .33576 Mdot
.56414 .1304 Mdot
.35117 .23368 Mdot
.33325 .82611 Mdot
.35326 .52365 Mdot
.37272 .61564 Mdot
.36355 .59062 Mdot
.39011 .5914 Mdot
.35162 .60849 Mdot
.43113 .57519 Mdot
.41147 .66245 Mdot
.52734 .66252 Mdot
.63679 .71171 Mdot
.53261 .47713 Mdot
.38756 .64514 Mdot
.45321 .64723 Mdot
.50226 .6296 Mdot
.32676 .17731 Mdot
.56973 .61995 Mdot
.552 .38735 Mdot
.3042 .3101 Mdot
.55109 .83632 Mdot
.60532 .25332 Mdot
.31201 .45159 Mdot
.4636 .87797 Mdot
.31807 .75563 Mdot
.51316 .57782 Mdot
.62445 .3188 Mdot
.37317 .66854 Mdot
.42257 .66413 Mdot
.54887 .68823 Mdot
.55459 .53611 Mdot
.57436 .43684 Mdot
.47129 .41067 Mdot
.34879 .44 Mdot
.54404 .12607 Mdot
.47549 .50536 Mdot
.32534 .69066 Mdot
.48754 .57653 Mdot
.30856 .20952 Mdot
.33958 .55036 Mdot
.56716 .67097 Mdot
.59269 .32394 Mdot
.3086 .43002 Mdot
.44218 .87341 Mdot
.31452 .72405 Mdot
.53142 .59919 Mdot
.59291 .36738 Mdot
.5092 .89295 Mdot
.36828 .52077 Mdot
.30095 .52196 Mdot
.34305 .54254 Mdot
.54073 .63715 Mdot
.60601 .32748 Mdot
.50635 .89007 Mdot
.37147 .525 Mdot
.30073 .52749 Mdot
.34038 .55038 Mdot
.56078 .66106 Mdot
.59453 .32839 Mdot
.30082 .57577 Mdot
.43125 .49396 Mdot
.32972 .18907 Mdot
.4162 .84619 Mdot
.39712 .60284 Mdot
.60226 .21021 Mdot
.29301 .65117 Mdot
.38035 .47695 Mdot
.4806 .10863 Mdot
.48626 .51286 Mdot
.42996 .5926 Mdot
.43565 .62598 Mdot
.42486 .60915 Mdot
.43673 .61903 Mdot
.40784 .61301 Mdot
.44778 .64064 Mdot
.46683 .61184 Mdot
.41195 .46871 Mdot
.37899 .15299 Mdot
.35354 .4897 Mdot
.28958 .63687 Mdot
.4912 .3778 Mdot
.45476 .35438 Mdot
.39044 .35929 Mdot
.51224 .49741 Mdot
.40603 .64764 Mdot
.488 .63507 Mdot
.51103 .54378 Mdot
.55306 .10826 Mdot
.36592 .4756 Mdot
.51552 .10908 Mdot
.61587 .69368 Mdot
.53863 .35793 Mdot
.31775 .60748 Mdot
.598 .7419 Mdot
.5842 .22041 Mdot
.32845 .54761 Mdot
.57987 .81019 Mdot
.52282 .1402 Mdot
.32497 .54611 Mdot
.56649 .83355 Mdot
.36861 .19897 Mdot
.29967 .66461 Mdot
.52387 .57405 Mdot
.60393 .36592 Mdot
.38115 .68398 Mdot
.49877 .65581 Mdot
.45898 .60354 Mdot
.60491 .79498 Mdot
.47959 .48397 Mdot
.53992 .32117 Mdot
.41042 .33159 Mdot
.39816 .38313 Mdot
.43827 .38447 Mdot
.42455 .38227 Mdot
.43061 .39693 Mdot
.46343 .3609 Mdot
.39796 .36568 Mdot
.485 .46803 Mdot
.30393 .44122 Mdot
.60695 .72169 Mdot
.5832 .2447 Mdot
.50547 .89998 Mdot
.32952 .59289 Mdot
.58205 .69237 Mdot
.5868 .30931 Mdot
.31724 .36594 Mdot
.44491 .09777 Mdot
.36133 .72762 Mdot
.40576 .68113 Mdot
.55489 .70997 Mdot
.48765 .61173 Mdot
.29944 .2383 Mdot
.41987 .48007 Mdot
.40308 .1269 Mdot
.60355 .66107 Mdot
.53431 .37685 Mdot
.3349 .39478 Mdot
.48191 .11749 Mdot
.29382 .6656 Mdot
.4044 .48182 Mdot
.42914 .1161 Mdot
.57297 .60763 Mdot
.54394 .40692 Mdot
.30443 .41437 Mdot
.46933 .88033 Mdot
.3206 .6529 Mdot
.55503 .63717 Mdot
.58221 .35292 Mdot
.30807 .50494 Mdot
.57123 .62804 Mdot
.55485 .37831 Mdot
.30832 .29971 Mdot
.29699 .26007 Mdot
.57243 .84298 Mdot
.32554 .78794 Mdot
.48949 .55329 Mdot
.62636 .66351 Mdot
.53919 .4818 Mdot
.51219 .54709 Mdot
.61677 .17444 Mdot
.44842 .49749 Mdot
.30256 .53109 Mdot
.39883 .47387 Mdot
.41702 .12506 Mdot
.36187 .45728 Mdot
.51392 .1153 Mdot
.35732 .47668 Mdot
.44911 .09893 Mdot
.42977 .85284 Mdot
.50567 .61953 Mdot
.59557 .14875 Mdot
.3503 .71128 Mdot
.5 .78846 Mdot
.502 .77217 Mdot
.49618 .75806 Mdot
.48536 .74803 Mdot
.47156 .74306 Mdot
.45668 .74436 Mdot
.44366 .75335 Mdot
.43732 .77012 Mdot
.44304 .79036 Mdot
.46115 .80433 Mdot
.48297 .80431 Mdot
.49793 .79237 Mdot
.50234 .77614 Mdot
.49818 .76124 Mdot
.4884 .75011 Mdot
.47519 .7438 Mdot
.46039 .74339 Mdot
.44655 .75033 Mdot
.43799 .76528 Mdot
.44029 .78536 Mdot
.4557 .80191 Mdot
.47769 .80569 Mdot
.49506 .79615 Mdot
.50212 .78036 Mdot
.49988 .76481 Mdot
.49132 .7526 Mdot
.47886 .74496 Mdot
.4643 .74288 Mdot
.4499 .74774 Mdot
.43944 .76064 Mdot
.43839 .77995 Mdot
.45056 .79847 Mdot
.47187 .80613 Mdot
.49133 .79962 Mdot
.50122 .78477 Mdot
.5012 .76878 Mdot
.4941 .75554 Mdot
.48254 .74658 Mdot
.46841 .74286 Mdot
.4537 .74566 Mdot
.44168 .75629 Mdot
.43745 .77422 Mdot
.44588 .79396 Mdot
.46554 .80545 Mdot
.48658 .80265 Mdot
.49947 .78938 Mdot
.50203 .7732 Mdot
.49667 .75897 Mdot
.4862 .74871 Mdot
.47267 .74338 Mdot
.45791 .74412 Mdot
.44469 .75233 Mdot
.43757 .76838 Mdot
.44198 .78848 Mdot
.45899 .80342 Mdot
.48081 .8049 Mdot
.4967 .79399 Mdot
.50221 .77802 Mdot
.49892 .76292 Mdot
.48977 .75136 Mdot
.477 .74443 Mdot
.4624 .74317 Mdot
.44832 .74899 Mdot
.43876 .76278 Mdot
.4392 .7824 Mdot
.45278 .80004 Mdot
.47436 .806 Mdot
.49289 .79821 Mdot
.50158 .78303 Mdot
.50067 .76727 Mdot
.49305 .75449 Mdot
.48121 .74605 Mdot
.46701 .74291 Mdot
.45246 .74636 Mdot
.44096 .75767 Mdot
.4377 .77598 Mdot
.44722 .79534 Mdot
.46735 .80571 Mdot
.48792 .80184 Mdot
.49995 .78816 Mdot
.5018 .77208 Mdot
.49602 .75817 Mdot
.48535 .74825 Mdot
.47173 .74329 Mdot
.45702 .74446 Mdot
.44406 .75315 Mdot
.43752 .76954 Mdot
.44269 .78956 Mdot
.46019 .80384 Mdot
.48185 .80453 Mdot
.49716 .79321 Mdot
.50215 .77727 Mdot
.49855 .76238 Mdot
.48926 .75106 Mdot
.47646 .74437 Mdot
.46192 .74334 Mdot
.44799 .74936 Mdot
.43869 .7633 Mdot
.43944 .78287 Mdot
.45321 .80024 Mdot
.47471 .8059 Mdot
.493 .79799 Mdot
.50151 .78288 Mdot
.50055 .76725 Mdot
.49296 .75456 Mdot
.48122 .74618 Mdot
.46713 .74302 Mdot
.45266 .74637 Mdot
.44116 .7575 Mdot
.43773 .77561 Mdot
.44692 .79493 Mdot
.46677 .80554 Mdot
.48733 .80208 Mdot
.4996 .78869 Mdot
.50178 .77272 Mdot
.49629 .75877 Mdot
.48587 .74873 Mdot
.47248 .74354 Mdot
.45788 .74432 Mdot
.4448 .75247 Mdot
.43773 .76831 Mdot
.44196 .7882 Mdot
.45865 .80313 Mdot
.48025 .80491 Mdot
.4962 .79438 Mdot
.502 .77867 Mdot
.49906 .76367 Mdot
.49026 .75205 Mdot
.47782 .74492 Mdot
.46348 .74325 Mdot
.44942 .74841 Mdot
.4394 .76142 Mdot
.43876 .78053 Mdot
.45102 .7986 Mdot
.47203 .80593 Mdot
.49112 .79949 Mdot
.5009 .78495 Mdot
.50102 .76923 Mdot
.49422 .75614 Mdot
.48302 .74716 Mdot
.46925 .74321 Mdot
.45475 .7455 Mdot
.44258 .75537 Mdot
.43758 .77253 Mdot
.44465 .79216 Mdot
.46323 .80471 Mdot
.48433 .80347 Mdot
.49821 .79126 Mdot
.50195 .7754 Mdot
.4976 .76102 Mdot
.48795 .75029 Mdot
.47505 .74419 Mdot
.46061 .74376 Mdot
.44705 .75038 Mdot
.43845 .76476 Mdot
.44013 .7843 Mdot
.45456 .80096 Mdot
.47596 .80565 Mdot
.49361 .79722 Mdot
.50149 .78212 Mdot
.50019 .76674 Mdot
.49252 .75434 Mdot
.48082 .74619 Mdot
.46684 .74319 Mdot
.45253 .74663 Mdot
.4412 .75773 Mdot
.43787 .7757 Mdot
.44698 .79482 Mdot
.4666 .8054 Mdot
.487 .80211 Mdot
.49931 .78897 Mdot
.50167 .77317 Mdot
.49643 .7593 Mdot
.48628 .74922 Mdot
.47314 .74384 Mdot
.45871 .74426 Mdot
.44557 .75187 Mdot
.43803 .76712 Mdot
.44132 .78677 Mdot
.45708 .80229 Mdot
.47852 .80519 Mdot
.49507 .79556 Mdot
.50171 .7802 Mdot
.49952 .76514 Mdot
.49131 .75323 Mdot
.47931 .74564 Mdot
.46524 .74329 Mdot
.45112 .7475 Mdot
.44041 .75938 Mdot
.43824 .77778 Mdot
.44864 .79643 Mdot
.4688 .80566 Mdot
.48864 .8011 Mdot
.49991 .78745 Mdot
.50141 .77175 Mdot
.49563 .75823 Mdot
.48518 .74857 Mdot
.47188 .74367 Mdot
.45748 .74467 Mdot
.44466 .75292 Mdot
.43786 .7687 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00Yoooool3o`000003ooooool0003o000000Co00001?ooool6o`000:gooooo002Voooo
o`co00000_ooool8o`000004ooooool0003o0000o`000:Sooooo002Kooooo`?o00002?ooool<o`00
00;ooooo4?l0002Tooooo`00V_ooool5o`0000Oooooo3?l00002oooooa?o0000XOooool009Gooooo
0ol00002ooooo`Go00002?ooool3o`000003ooooool0003o000000Co00001?ooool6o`000003oooo
ool0003o000000[o000000Coooooo`000?l0003o0000W?ooool008oooooo0ol00002ooooo`Go0000
00?oooooo`000?l000000ol0000:ooooo`03o`000?oooooooooo017ooooo4Ol0002Jooooo`00S_oo
ool5o`000003ooooool0003o000000?o00000_ooool3o`0000_ooooo00?o0000ooooooooool05Ooo
ool>o`0009Wooooo002=ooooo`Ko000000?oooooo`000?l000000ol0000@ooooo`03o`000?oooooo
oooo01Sooooo0ol000000ooooooo0000o`000005o`0009Wooooo0029ooooo`?o000000?oooooo`00
0?l000001?l00002ooooo`?o00004Oooool00ol0003oooooooooo`0Mooooo`Ko00000_ooool3o`00
09Cooooo0028ooooo`[o00005oooool00ol0003oooooooooo`0Oooooo`?o00000_ooool6o`0009;o
oooo0028ooooo`Go000000Coooooo`000?l0003o00006?ooool00ol0003oooooooooo`0Tooooo`[o
0000S_ooool008Sooooo1Ol0000Looooo`03o`000?oooooooooo02Cooooo2ol0002=ooooo`00P_oo
ool3o`0000Cooooo0ol0000Mooooo`03o`000?oooooooooo02Gooooo2_l0002=ooooo`00POooool5
o`0002?ooooo00?o0000ooooooooool09oooool:o`0008_ooooo0021ooooo`Go00008oooool00ol0
003oooooooooo`0[ooooo`Oo0000R_ooool0087ooooo1Ol0000Sooooo`03o`000?oooooooooo02go
oooo1Ol0002:ooooo`00P_ooool3o`0002Cooooo00?o0000ooooooooool0;Oooool5o`000004oooo
ool0003o0000o`0008Kooooo002Yooooo`03o`000?oooooooooo02kooooo0ol000000ooooooo0000
o`000004o`0008Cooooo002Yooooo`;o0000<oooool7o`0008?ooooo002Yooooo`03o`000?oooooo
oooo03;ooooo2Ol00021ooooo`00Moooool3o`0002oooooo00?o0000ooooooooool0<oooool9o`00
083ooooo001fooooo`Go0000;_ooool00ol0003oooooooooo`0eooooo`Oo0000P?ooool007Cooooo
1ol0000^ooooo`03o`000?oooooooooo03Oooooo1Ol00020ooooo`00Loooool8o`0002kooooo00?o
0000ooooooooool0>?ooool3o`000004ooooool0003o0000o`0007gooooo001booooo`So0000;ooo
ool00ol0003oooooooooo`0kooooo`Go0000O?ooool0077ooooo1ol0000aooooo`03o`000?oooooo
oooo03_ooooo1_l0001kooooo`00LOooool6o`0003;ooooo00?o0000ooooooooool0>oooool6o`00
07_ooooo001_ooooo`Oo00007oooool4o`0000?ooooo0ol0000:ooooo`03o`000?oooooooooo03co
oooo1Ol0001kooooo`00K_ooool7o`0001oooooo1_l000000ooooooo0000o`000003o`0000Wooooo
00?o0000ooooooooool0?Oooool3o`0007cooooo001]ooooo`Ko00008Oooool6o`000003ooooool0
003o000000?o00002Oooool00ol0003oooooooooo`12ooooo`Co0000M_ooool006gooooo1_l0000Q
ooooo`Ko000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00005ooooo`03o`000?oo
oooooooo00?o00002_ooool3o`00037ooooo1_l0001eooooo`00KOooool5o`0002?ooooo1?l00003
ooooo`?o000000?oooooo`000?l000000ol00004ooooo`03o`000?oooooo000000Co00002?ooool5
o`00033ooooo1ol0001dooooo`00K_ooool3o`00027ooooo0ol0000:ooooo`Ko00001?ooool00ol0
003oooooo`000004o`0000Sooooo1Ol0000`ooooo`So0000Loooool008oooooo1ol0000:ooooo`Go
00001?ooool00ol0003oooooo`000004o`000004ooooool0003o0000o`0000Cooooo1Ol0000aoooo
o`Oo0000Loooool008kooooo3Ol00002ooooo`So00001?ooool<o`0000?ooooo1Ol0000cooooo`Go
0000Loooool008kooooo2?l00007ooooo`03odA4A?oMgMgooooo00Go00001?ooool00ol0003ooooo
o`000009o`0000?ooooo1_l0000cooooo`?o0000M?ooool008Oooooo0ol000000ooooooo0000o`00
0009o`0000Oooooo00?ogMgMoeEEEOooool01Ol00003ooooo`go000000?oooooo`000?l000001ol0
000@ooooo`?o00008_ooool3o`00077ooooo0026ooooo`oo00002Oooool00omgMgOoc<c<o`000003
o`0000?ooooo2?l00002ooooo`?o000000?oooooo`000?l000002?l00006ooooo`?o00001_ooool5
o`00023ooooo1Ol0001`ooooo`00Q_ooool9o`0000oooooo00?ok^k^odA4A?l000001_ooool7o`00
00Oooooo2ol00004ooooo`Go00001Oooool6o`0001oooooo1Ol0001`ooooo`00IOooool4o`0001go
oooo2Ol0000@ooooo`03ogMgMol0003ooooo00Gooooo1ol00007ooooo`Go000000?oooooo`000?l0
00001?l00003ooooo`Go00001Oooool6o`0001oooooo1Ol0001`ooooo`00I?ooool6o`0001gooooo
0ol000001?oooooo0000o`000?l0000Jooooo`Go00002Oooool3o`0000?ooooo1Ol00003ooooo`Go
00001_ooool5o`00023ooooo1_l0001^ooooo`00I?ooool6o`0003oooooo00?o0000ooooooooool0
0oooool3o`0000[ooooo1Ol00004ooooo`?o00002?ooool3o`0002?ooooo1Ol0001]ooooo`00I?oo
ool6o`0003oooooo00?o0000ooooooooool00_ooool5o`0000[ooooo0ol0000fooooo`Go0000KOoo
ool006Gooooo1?l00010ooooo`03o`000?oooooooooo00;ooooo1Ol00013ooooo`Ko0000K?ooool0
0:Wooooo00?o0000ooooooooool00_ooool5o`0001Cooooo0ol0000]ooooo`Ko0000Joooool007oo
oooo0ol0000;ooooo`?o00006Oooool00ol0003oooooooooo`03ooooo`?o00005?ooool5o`0002go
oooo1_l0001Zooooo`00O_ooool5o`0000Wooooo1Ol0000Hooooo`03o`000?oooooooooo01[ooooo
1Ol00003ooooo`?o00009oooool7o`0006Wooooo001eooooo`?o00001_ooool5o`0000Wooooo1Ol0
000Hooooo`03o`000?oooooooooo01[ooooo1Ol00002ooooo`Go00009oooool6o`0006Wooooo001d
ooooo`Go00001Oooool5o`0000Wooooo1Ol00007ooooo`?o00003_ooool00ol0003oooooooooo`0K
ooooo`?o00000oooool5o`0002Sooooo1Ol0001Yooooo`00M?ooool5o`0000Kooooo0ol0000;oooo
o`?o00001oooool5o`0000gooooo00?o0000ooooooooool08Oooool5o`0002Wooooo0ol0001Zoooo
o`00M?ooool5o`0001kooooo1Ol0000=ooooo`;o00008_ooool5o`0002cooooo0ol0001Wooooo`00
MOooool3o`0001oooooo1Ol0000=ooooo`03o`000?oooooooooo027ooooo1Ol0000[ooooo`Go0000
I_ooool009Sooooo0ol0000>ooooo`03o`000?oooooooooo01cooooo0ol00003ooooo`?o00002ooo
ool3o`0001kooooo1Ol0001Vooooo`00KOooool3o`0003Wooooo00?o0000ooooooooool06oooool5
o`000003ooooool0003o000000?o00002Oooool5o`0001gooooo1Ol0001Vooooo`00GOooool3o`00
00cooooo1Ol0000hooooo`03o`000?oooooooooo01_ooooo1Ol000000ooooooo0000o`000003o`00
00Wooooo1Ol0000Nooooo`?o0000Ioooool005cooooo1Ol0000;ooooo`Go0000>?ooool00ol0003o
ooooooooo`0Kooooo`Go000000?oooooo`000?l000000ol00009ooooo`Go0000R?ooool005cooooo
1Ol0000;ooooo`Go0000>?ooool00ol0003oooooooooo`0Looooo`?o00000oooool3o`0000_ooooo
0ol00029ooooo`00Foooool6o`0000cooooo1?l0000Oooooo`?o00005_ooool00ol0003ooooooooo
o`2looooo`00Foooool6o`0000cooooo1Ol0000Mooooo`Go00005Oooool00ol0003oooooooooo`0U
ooooo`?o0000;_ooool3o`0006?ooooo001Kooooo`Go00003Oooool5o`0001gooooo1_l0000Doooo
o`04o`000?ooooooooooooooo`[o00006Oooool5o`0002cooooo1Ol0001Rooooo`00F_ooool5o`00
00kooooo1Ol0000Mooooo`Ko00005?ooool00ol0003oooooo`00000=o`0001Kooooo1_l0000/oooo
o`Go0000H_ooool005Wooooo1Ol0000@ooooo`?o00002_ooool3o`0001;ooooo1Ol0000Doooooa;o
00005?ooool6o`0000Gooooo0ol0000Tooooo`Go0000H_ooool005Wooooo1Ol0000Looooo`Go0000
4_ooool3o`0001Gooooo4ol0000Cooooo`Go00001Oooool5o`0002Cooooo0ol0001Sooooo`00FOoo
ool5o`0001cooooo1Ol0000YoooooaGo00004oooool3o`0000Kooooo1Ol0002:ooooo`00F_ooool3
o`0000[ooooo0ol0000@ooooo`Go0000:?ooool9o`0000Gooooo2?l0000=ooooo`?o00003?ooool5
o`0002Kooooo0ol0001Qooooo`00I_ooool5o`00013ooooo0ol0000Xooooo`So00002?ooool8o`00
00_ooooo1Ol0000<ooooo`?o00009_ooool5o`00063ooooo001Vooooo`Go0000>oooool7o`0000_o
oooo1ol0000:ooooo`Go0000=Oooool5o`00063ooooo001Vooooo`Go00006_ooool3o`0001kooooo
1_l0000=ooooo`Ko00002_ooool5o`0003Gooooo1_l0001Oooooo`00Ioooool3o`0001[ooooo1Ol0
000Mooooo`Go00003oooool6o`0000Cooooo0ol00003ooooo`?o0000=oooool5o`0005oooooo001G
ooooo`?o0000:_ooool5o`0001gooooo1Ol0000?ooooo`Ko00000oooool5o`0003cooooo1_l0001N
ooooo`00E_ooool5o`0002Wooooo1Ol0000Looooo`Ko00004?ooool5o`0000?ooooo1Ol0000moooo
o`Go0000G_ooool005Kooooo1Ol0000Kooooo`?o00003?ooool3o`0001gooooo1_l0000@ooooo`Go
00000oooool5o`0003gooooo1Ol0001Nooooo`00E_ooool5o`0001[ooooo1Ol0000[ooooo`Ko0000
4?ooool5o`0000Cooooo0ol0000oooooo`?o0000Goooool005Oooooo0ol0000Jooooo`Ko0000;?oo
ool5o`00013ooooo1Ol0002Xooooo`00I?ooool3o`0000gooooo1_l0000/ooooo`Ko00003oooool5
o`000:Sooooo001Sooooo`Go00003?ooool5o`0002gooooo1_l0000?ooooo`Go0000B?ooool3o`00
05gooooo001Sooooo`Go00003Oooool3o`0002kooooo1ol0000=ooooo`Ko00000oooool3o`00047o
oooo1Ol0001Looooo`00Hoooool5o`0003oooooo1ol0000<ooooo`Ko00000_ooool5o`00043ooooo
1_l0001Kooooo`00I?ooool3o`00043ooooo2?l00009ooooo`Oo00000oooool5o`00043ooooo1_l0
001Kooooo`00Z?ooool:o`0000Cooooo2Ol00003ooooo`Go00001?ooool3o`0003[ooooo1Ol0001K
ooooo`00E?ooool3o`0005;ooooo5Ol00005ooooo`?o00001?ooool5o`0003[ooooo1?l0001Koooo
o`00Doooool5o`0000_ooooo0ol00013oooooaCo00003Oooool5o`0001_ooooo0ol0000Looooo`Go
0000F_ooool005?ooooo1Ol0000:ooooo`Go0000@_ooool00ol0003oooooo`00000@o`0000kooooo
1Ol00006ooooo`?o00004Oooool5o`0001_ooooo1Ol0001Jooooo`00Doooool5o`0000[ooooo1Ol0
0012ooooo`;o00000_ooool>o`00013ooooo0ol00006ooooo`Go00004?ooool5o`0001_ooooo1Ol0
001Jooooo`00E?ooool3o`0000_ooooo1Ol00012ooooo`03o`000?oooooooooo00?ooooo2_l0000K
ooooo`Go00004?ooool5o`0001cooooo1Ol0001Iooooo`00Doooool5o`0000_ooooo0ol00013oooo
o`03o`000?oooooooooo02Sooooo1Ol00002ooooo`?o00003?ooool3o`0001gooooo1Ol0001Ioooo
o`00Doooool5o`00037ooooo0ol0000Mooooo`03o`000?oooooooooo02Wooooo0ol00002ooooo`Go
0000:oooool5o`0005Wooooo001Booooo`Ko0000<?ooool5o`0001cooooo00?o0000ooooooooool0
9Oooool3o`0000Kooooo1Ol0000/ooooo`?o0000F_ooool005;ooooo1Ol0000aooooo`Go00007?oo
ool00ol0003oooooooooo`0Tooooo`Go00001Oooool5o`0000Kooooo0ol0000Tooooo`?o0000FOoo
ool0057ooooo1_l0000aooooo`Go00001_ooool3o`0001?ooooo00?o0000ooooooooool09?ooool5
o`0000Kooooo0ol00006ooooo`Go00008_ooool5o`0005Sooooo001Aooooo`Go0000<oooool3o`00
00Kooooo1Ol0000Booooo`03o`000?oooooooooo02Cooooo1Ol0000?ooooo`Go00008_ooool5o`00
05Sooooo001Aooooo`Go0000:oooool3o`0000kooooo1Ol0000Booooo`03o`000?oooooooooo02Go
oooo0ol0000@ooooo`Go00008_ooool5o`0005Sooooo001Booooo`?o0000:oooool5o`0000gooooo
1Ol0000Booooo`03o`000?oooooooooo03Wooooo0ol0000Tooooo`Co0000F?ooool0083ooooo1Ol0
000>ooooo`?o00004oooool00ol0003oooooooooo`1Pooooo`Go0000Eoooool006Oooooo0ol0000F
ooooo`Go00009?ooool00ol0003oooooooooo`1Pooooo`Go0000Eoooool006Kooooo1Ol0000Foooo
o`?o00009Oooool00ol0003oooooooooo`0dooooo`?o0000:Oooool5o`0005Oooooo001Vooooo`Go
00008Oooool3o`0000kooooo1Ol00007ooooo`03o`000?oooooooooo03?ooooo1Ol0000Xooooo`Go
0000Eoooool006Kooooo1Ol0000Pooooo`Go00003Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?o0000ooooooooool0<oooool5o`0002Wooooo0ol0001Hooooo`00DOooool3o`0001;ooooo
1?l0000Qooooo`Go00001Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h02?ooool00ol0003ooooo
ooooo`0Hooooo`?o00006?ooool5o`0008Cooooo001@ooooo`Go00004?ooool5o`00027ooooo1Ol0
000?ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Gooooo`Go00006?ooool3o`0008Gooooo001@
ooooo`Go00004?ooool5o`0002;ooooo0ol0000Aooooo`03ogMgMomVIVKooooo00Kooooo00?o0000
ooooooooool05oooool5o`00013ooooo0ol0000cooooo`?o0000Eoooool0053ooooo1Ol0000@oooo
o`Go0000=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo1Ol00009oooo
o`?o00000oooool5o`00037ooooo1Ol0001Fooooo`00D?ooool5o`00017ooooo0ol0000Jooooo`?o
00005oooool01Ol0003o^[ZjoooooonHV9So410@00Oooooo00?o0000ooooooooool02Oooool3o`00
00cooooo0ol00009ooooo`Go00000_ooool5o`000004ooooool0003o0000o`0002gooooo1Ol0001F
ooooo`00DOooool3o`0002_ooooo2?l0000Fooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01oooool0
0ol0003oooooooooo`08ooooo`Go00003Oooool3o`0000Oooooo1Ol00002ooooo`[o0000;?ooool5
o`0005Kooooo001nooooo`Wo00008_ooool00ol0003oooooooooo`08ooooo`Go00003?ooool5o`00
0004ooooool0003o0000o`0000;ooooo1Ol00003ooooo`?o000000?oooooo`000?l000000ol0000]
ooooo`?o0000Eoooool0053ooooo0ol0000[ooooo`Wo00000_ooool3o`0001gooooo00?o0000oooo
ooooool02?ooool5o`0000Oooooo0ol00002ooooo`[o00000_ooool3o`0000Sooooo1Ol0000^oooo
o`?o0000E_ooool004oooooo1Ol0000Dooooo`?o00004oooool8o`0000;ooooo1Ol0000Looooo`03
o`000?oooooooooo00Wooooo0ol00007ooooo`Go000000?oooooo`000?l000002?l0000>ooooo`?o
0000;_ooool5o`0005Gooooo001?ooooo`Go00004oooool5o`0001?ooooo0ol00006ooooo`Go0000
7?ooool00ol0003oooooooooo`0Cooooo`Go00000_ooool9o`0000_ooooo0ol00009ooooo`?o0000
9Oooool5o`0005Gooooo001?ooooo`Go00004oooool5o`0001cooooo1Ol0000Looooo`03o`000?oo
oooooooo01?ooooo1Ol00003ooooo`?o000000Coooooo`000?l0003o00002oooool5o`0000Cooooo
2?l0000Tooooo`Go0000EOooool0053ooooo0ol0000Dooooo`Go00007Oooool3o`0000?ooooo0ol0
000Gooooo`03o`000?oooooooooo01?ooooo1Ol0000Eooooo`Go00000oooool9o`0002Gooooo0ol0
001Fooooo`00J?ooool3o`0001gooooo0ol00003ooooo`Go00005_ooool00ol0003oooooooooo`0C
ooooo`Go00005Oooool5o`0000?ooooo2Ol0000Tooooo`Go0000EOooool0053ooooo0ol0000doooo
o`Go00000_ooool5o`0001Kooooo00?o0000ooooooooool04oooool5o`0001Kooooo0ol00004oooo
o`So00009Oooool6o`0005Cooooo001?ooooo`Go0000<oooool5o`000003ooooool0003o000000Co
00005_ooool00ol0003oooooooooo`0Dooooo`Ko00007?ooool3o`0002Wooooo1_l0001Dooooo`00
Coooool5o`0003?ooooo2ol00006ooooo`?o00003_ooool00ol0003oooooooooo`0Fooooo`Go0000
3_ooool3o`0003Oooooo1Ol0001Dooooo`00Coooool5o`0002kooooo0ol000000ooooooo0000o`00
0003o`000003ooooool0003o000000?o00001_ooool5o`0000gooooo00?o0000ooooooooool02?oo
ool3o`0000_ooooo1Ol00002ooooo`?o00002?ooool5o`0003Kooooo1Ol0001Dooooo`00Coooool5
o`0002gooooo2Ol00002ooooo`Go00001_ooool7o`0000_ooooo0_l00008ooooo`Go00002_ooool5
o`000003ooooool0003o000000?o00001oooool5o`0003Kooooo1Ol0001Dooooo`00Coooool5o`00
02gooooo2Ol00003ooooo`?o00001oooool8o`0000[ooooo00?o0000ooooooooool01oooool5o`00
00_ooooo2_l00007ooooo`Go0000=_ooool5o`0005Cooooo001?ooooo`Go00005_ooool3o`0001Co
oooo2Ol0000>ooooo`Oo00002_ooool00ol0003oooooooooo`07ooooo`Go00003Oooool8o`0000Go
oooo1_l0000gooooo`Go0000E?ooool004oooooo1Ol0000Eooooo`Go00004oooool8o`00017ooooo
1Ol0000:ooooo`03o`000?oooooooooo00Gooooo1_l00007ooooo`?o00001?ooool9o`0000?ooooo
1Ol0000iooooo`Go0000E?ooool004kooooo1_l0000Eooooo`Go00004oooool8o`0001;ooooo0ol0
000;ooooo`03o`000?oooooooooo00Cooooo1Ol00008ooooo`Go00000oooool9o`0000?ooooo1Ol0
000iooooo`Go0000E?ooool004kooooo1Ol0000Booooo`?o000000?oooooo`000?l000000ol0000D
ooooo`Oo00008?ooool00ol0003oooooooooo`04ooooo`Ko00001oooool5o`0000?ooooo4Ol0000i
ooooo`Go0000E?ooool004kooooo1Ol0000Aooooo`Go000000Coooooo`000?l0003o00006?ooool3
o`0001cooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo1ol00003ooooo`_o000000Gooooo
o`000?l0003o0000ooooo`0;o`0000Cooooo0ol00003ooooo`?o0000;_ooool3o`0005Gooooo001?
ooooo`?o00004_ooool5o`0001cooooo0ol000001?oooooo0000o`000?l00002ooooo`?o00004_oo
ool5o`000003ooooool0003ooooo00Kooooo1_l00002ooooo`go00001oooool5o`000004ooooool0
003o0000o`0000;ooooo1Ol000000ooooooo0000o`000003o`0008Gooooo001Tooooo`Go00006ooo
ool>o`000004ooooool0003o0000o`0000Sooooo0ol00002ooooo`Go000000?oooooo`000?ooool0
1oooool5o`000003ooooool0003o000000Co00000_ooool6o`0000Oooooo2_l000000ooooooo0000
o`000003o`000003ooooool0003o000000?o0000QOooool004oooooo0ol0000Cooooo`?o00007?oo
oolCo`0000Kooooo1Ol000000ooooooo0000o`000006o`0000Sooooo0ol00002ooooo`Ko00000_oo
ool6o`0000Sooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000ol00025ooooo`00C_ooool5o`00037ooooo4ol00006ooooo`Go00000_ooool8
o`0000cooooo1_l00003ooooo`Co00003Oooool5o`0000;ooooo0ol00003ooooo`?o0000Q_ooool0
04kooooo1Ol0000Mooooo`?o00004_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol00000
0ooooooo0000o`000003o`0000Kooooo1Ol00005ooooo`Go00003?ooool7o`0001Cooooo0ol0000C
ooooo`?o00009Oooool3o`0005Cooooo001>ooooo`Go00007?ooool5o`0001cooooo1_l00008oooo
o`Ko00000oooool5o`0000cooooo1ol0000Hooooo`?o00003_ooool5o`0002?ooooo1Ol0001Coooo
o`00C_ooool5o`0001cooooo1Ol0000Kooooo`Go00003?ooool5o`0000?ooooo0ol0000>ooooo`Ko
00002_ooool3o`0000Cooooo2ol0000=ooooo`Go00008oooool5o`0005?ooooo001>ooooo`Go0000
7?ooool5o`0001_ooooo1Ol0000;ooooo`Ko00000_ooool3o`00017ooooo0ol0000:ooooo`Go0000
0_ooool<o`0000gooooo1Ol0000Sooooo`Go0000Doooool004kooooo1Ol0000Mooooo`?o00007?oo
ool5o`0000[ooooo1ol000000ooooooo0000o`000003o`0000_ooooo0ol0000?ooooo`Go00000_oo
ool<o`0000kooooo1?l0000Sooooo`Go0000Doooool004oooooo0ol0000nooooo`Go00002Oooool6
o`0000;ooooo1Ol00002ooooo`?o00001Oooool5o`0000kooooo1Ol00002ooooo`_o00003oooool5
o`0002?ooooo0ol0001Dooooo`00Coooool3o`0003kooooo1Ol00009ooooo`Go00000oooool5o`00
0003ooooool0003o000000?o00001?ooool5o`0000;ooooo0ol0000:ooooo`oo00004Oooool5o`00
07[ooooo001>ooooo`Go00004oooool3o`0002Oooooo1Ol00008ooooo`Go00001Oooool3o`0000;o
oooo1Ol00004ooooo`Go000000?oooooo`000?l000000ol0000;ooooo`go00004Oooool5o`0007[o
oooo001>ooooo`Go00004_ooool5o`0002Oooooo0ol00009ooooo`Go00001oooool00ol0003ooooo
ooooo`05o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`Go00002oooool=o`0000?o
oooo0ol0000<ooooo`?o00009?ooool4o`0005?ooooo001>ooooo`Go00004_ooool5o`0002Gooooo
0ol0000;ooooo`Go00001oooool01?l0003oooooooooooooool3o`000003ooooool0003o000000?o
00001Oooool6o`0000?ooooo0ol00004ooooo`go00000_ooool5o`000004ooooool0003o0000o`00
02gooooo1_l0001Booooo`00Coooool3o`0001?ooooo1Ol0000Tooooo`Go00002oooool3o`0000So
oooo00?o0000ooooooooool01Oooool5o`0000Gooooo1_l00002ooooo`Go00001?ooool;o`0000?o
oooo2_l0000/ooooo`Ko0000D_ooool004kooooo1Ol0000Cooooo`?o00009Oooool5o`0001Kooooo
00?o0000ooooooooool01Oooool5o`0000Kooooo1Ol00002ooooo`Go00001Oooool5o`0000Oooooo
2ol0000/ooooo`Ko0000D_ooool004kooooo1Ol0000Dooooo`?o00009?ooool5o`0001Kooooo00?o
0000ooooooooool01_ooool3o`0000Sooooo2ol0000@ooooo`Ko000000?oooooo`000?l000000ol0
000]ooooo`Co0000Doooool004kooooo1Ol0000Cooooo`Go00009?ooool3o`0001Oooooo00?o0000
ooooooooool04oooool8o`00017ooooo1Ol00003ooooo`?o0000QOooool004kooooo1Ol0000Coooo
o`Go0000?_ooool00ol0003oooooooooo`0Cooooo`Go00002?ooool3o`0000Wooooo1Ol00002oooo
o`Go0000Q?ooool004oooooo0ol0000Dooooo`Go00002Oooool3o`0003;ooooo00?o0000oooooooo
ool04oooool5o`0000Oooooo1Ol00009ooooo`?o00000oooool5o`0008Cooooo001Uooooo`Go0000
2Oooool5o`00037ooooo00?o0000ooooooooool03oooool3o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003o00000oooool5o`0000?ooooo0ol00009ooooo`Go0000;_ooool3o`0005?o
oooo001Tooooo`Go00002_ooool5o`00037ooooo00?o0000ooooooooool03_ooool?o`0000;ooooo
1Ol00002ooooo`Go00002Oooool3o`0002kooooo1Ol0001Booooo`00I?ooool5o`0000[ooooo1Ol0
000aooooo`03o`000?oooooooooo00kooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Go0000
0oooool3o`0000?ooooo1Ol0000jooooo`Go0000D_ooool004oooooo0ol0000Booooo`Oo00002Ooo
ool3o`0002Gooooo0ol0000:ooooo`03o`000?oooooooooo00kooooo1Ol00005ooooo`Go00002Ooo
ool5o`0003[ooooo1Ol0001Booooo`00C_ooool5o`0001;ooooo1ol0000_ooooo`Go00001oooool3
o`00017ooooo0ol00007ooooo`?o00002oooool3o`0003_ooooo1Ol0001Booooo`00C_ooool5o`00
01Cooooo1Ol0000=ooooo`?o00007oooool5o`0000Kooooo1Ol0001Vooooo`Go0000D_ooool004ko
oooo1Ol0000Dooooo`Go00003?ooool5o`0001kooooo1Ol00006ooooo`Go00006_ooool3o`0004[o
oooo0ol0001Cooooo`00C_ooool5o`0001Gooooo0ol0000=ooooo`Go00007oooool3o`0000Oooooo
1Ol0000Iooooo`Go0000Woooool002[ooooo0_l000000ol@413oooooooooo`0Oooooo`Go00005_oo
ool5o`0000[ooooo1Ol0000Zooooo`?o00006_ooool5o`0001gooooo1Ol0000Wooooo`?o00005?oo
ool2o`000003oa0@4?oooooooooo03[ooooo000[ooooo`03o`000?oooooooooo023ooooo1Ol0000F
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02oooool3o`0000kooooo0ol0000Eooooo`?o00001?oo
ool00ol0003oooooooooo`0Hooooo`Go00004?ooool3o`0000[ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Vooooo`Go00005?ooool00ol0003oooooooooo`0kooooo`008?ooool6o`0000;ooooo1Ol0
000Rooooo`?o00003oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07?ooool5o`0000kooooo0ol0
0002ooooo`Go00000oooool00ol0003oooooooooo`03o`0001Kooooo0ol00006ooooo`?o00001ooo
ool5o`0000[ooooo00?oV9RHob4Q8Oo^k^h09oooool5o`00017ooooo1Ol0000looooo`00:?ooool0
1?m4A4CogMgMooooool0000oooooo`03oiRHV?lQ8B7ok^k^00cooooo0ol00008ooooo`?o000000?o
ooooo`000?l000000ol0000:ooooo`So000000?oooooo`000?l000000ol00003ooooo`03o`000?oo
oooo000000Co00006?ooool3o`0000;ooooo1Ol00006ooooo`Go00002oooool00onHV9So8B4Qonk^
kP0Vooooo`Go00004Oooool01?m4A4CogMgMooooool0000mooooo`00:?ooool01?oMgMgoEEEEoooo
ool00010ooooo`03ogMgMomVIVKooooo00Sooooo1ol000001?oooooo0000o`000?l00002ooooo`[o
00002Oooool9o`000003ooooool0003o000000?o00000oooool00ol0003oooooo`000004o`0000;o
oooo0ol0000Booooo`Go000000?oooooo`000?l000000ol00006ooooo`Go00003?ooool00omgMgOo
IVIVooooo`0Vooooo`?o00004_ooool01?oMgMgoEEEEooooool0000mooooo`00:Oooool00omgMgOo
c<c<o`000011ooooo`03o`000?oooooooooo00Kooooo3Ol000000ooooooo0000o`000003o`000003
ooooool0003o000000?o00002?ooool9o`0000;ooooo0ol00004ooooo`03o`000?oooooo000000Co
000000?oooooo`000?l000000ol0000Aooooo`_o00001oooool3o`0000kooooo00?o0000oooooooo
ool09Oooool3o`0001?ooooo00?oMgMgolc<c?l00000?Oooool002Wooooo00?ok^k^odA4A?l00000
?Oooool01Ol0003o^[ZjoooooonHV9So410@00Sooooo3Ol000000ooooooo0000o`000004o`000003
ooooool0003o000000?o00001oooool8o`000004ooooool0003o0000o`0000Kooooo00?o0000oooo
ooooool00ol00002ooooo`Ko00004?ooool:o`0001Gooooo00Go0000okZj^_ooooooV9RHoa0@400V
ooooo`Go00004_ooool00oo^k^koA4A4o`00000mooooo`00:_ooool00omgMgOo0000ooooo`0loooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`02?ooool7o`000003ooooool0003o000000?o00000_ooool;
o`0000Sooooo0ol00004ooooo`Go00001Oooool00ol0003oooooooooo`05ooooo`Oo00000oooool3
o`0000[ooooo1_l0000;ooooo`?o00002_ooool01?nHV9So410@o`000?lQ8B43o`0002Cooooo1Ol0
000Cooooo`03ogMgMol0003ooooo03cooooo001fooooo`Co00001Oooool3o`0000Cooooo2_l0000?
ooooo`Go00001Oooool00ol0003oooooooooo`06ooooo`Ko00000_ooool5o`0000[ooooo1Ol0000:
ooooo`Go00003?ooool5o`0002?ooooo1Ol0001Booooo`00Coooool3o`0002?ooooo1Ol00002oooo
o`?o00001oooool5o`000004ooooool0003o0000o`00013ooooo1Ol00005ooooo`03o`000?oooooo
oooo00Oooooo1Ol00002ooooo`Go00002oooool3o`0000_ooooo1Ol0000<ooooo`Go00008oooool5
o`0005;ooooo001>ooooo`Go00006?ooool3o`0000Oooooo1Ol000000ooooooo0000o`000003o`00
00Oooooo0ol00006ooooo`?o00003Oooool3o`0000Kooooo00?o0000ooooooooool02?ooool3o`00
00?ooooo1Ol0000Iooooo`Go00003?ooool5o`0002?ooooo1Ol0001Booooo`00C_ooool5o`0001Oo
oooo1Ol00006ooooo`Go000000?oooooo`000?l000000ol0000?ooooo`Go00000_ooool3o`00013o
oooo00?o0000ooooool000000_l0000=ooooo`?o00006oooool3o`0000kooooo0ol0000Tooooo`Go
0000A_ooool2o`0000;ooooo0_l00006ooooo`00C_ooool5o`0001Oooooo1Ol00007ooooo`?o0000
0_ooool5o`0000oooooo1Ol000000ooooooo0000o`000003o`0000oooooo1_l0001Rooooo`Go0000
A_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Kooooo00000ooooooo0000o`00003oo`0004oo
00003?ooool01?oMgMgo0000oa0@4?o<c<`7ooooo`001oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo2?l0000:ooooo`03
o`000?oooooooooo00cooooo1Ol00004ooooo`?o00000_ooool5o`0000Cooooo1Ol00006ooooo`Ko
00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo1Ol00004ooooo`Go
00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0@ooooo`04onk^k_lQ8B7o410@onk^kPOooooo0007ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool5o`0000Gooooo00?o0000oooooooo
ool02oooool5o`0000gooooo00?o0000ooooooooool03?ooool5o`0000[ooooo0ol00005ooooo`Go
00001_ooool00ol0003oooooo`000002o`0000_ooooo00?o0000ooooooooool02?ooool3o`0000;o
oooo00?o0000ooooooooool03Oooool5o`0000Cooooo2?l0000?ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`04ob4Q8OmgMgOoMgMgoc8b
<POooooo001>ooooo`Go00004oooool5o`0001cooooo1Ol0000Booooo`So00000oooool00ol0003o
ooooooooo`0Gooooo`Go00004Oooool5o`0000Cooooo2Ol0001aooooo`;o00000_ooool2o`0000Ko
oooo001?ooooo`?o00005Oooool3o`0001kooooo0ol0000Dooooo`So00000_ooool00ol0003ooooo
ooooo`0Gooooo`Go00004_ooool3o`0000Kooooo2?l0000Wooooo`?o0000Doooool004kooooo1Ol0
001?ooooo`Go00000_ooool00ol0003oooooooooo`0Gooooo`Go00005?ooool3o`0000Oooooo1Ol0
000Vooooo`Go0000D_ooool004kooooo1Ol0000Aooooo`?o00005?ooool3o`0002Cooooo1Ol00002
ooooo`03o`000?oooooooooo01Sooooo0ol0000@ooooo`?o000000?oooooo`000?l000000ol00007
ooooo`?o00009oooool5o`0005;ooooo001>ooooo`Go00004?ooool5o`0000kooooo0ol000000ooo
oooo0000o`000003o`0002Cooooo0ol00003ooooo`03o`000?oooooooooo00Sooooo0ol0000Koooo
o`?o000000?oooooo`000?l000002?l0000:ooooo`?o00009?ooool5o`0005;ooooo001?ooooo`?o
00004Oooool5o`0000gooooo2ol0000Yooooo`03o`000?oooooooooo00Oooooo1Ol0000Iooooo`oo
00002Oooool5o`0002?ooooo1Ol0001Booooo`00C_ooool5o`00013ooooo1Ol0000=ooooo`_o0000
:Oooool00ol0003oooooooooo`07ooooo`Go00005Oooool3o`000003ooooool0003o000000co0000
2_ooool5o`0002?ooooo1Ol0001Booooo`00C_ooool5o`00013ooooo1_l0000<ooooo`Go000000?o
ooooo`000?l000000ol0000Xooooo`?o00002?ooool5o`00013ooooo0ol000000ooooooo0000o`00
0008o`000003ooooool0003o000000Ko00002_ooool5o`0002Cooooo0ol0001Cooooo`00C_ooool5
o`00013ooooo1_l0000=ooooo`?o00000oooool3o`0002?ooooo0ol00002ooooo`Go00002?ooool9
o`0000[ooooo2_l000001?oooooo0000o`000?l00005ooooo`Go00002oooool3o`0002Cooooo1Ol0
001Booooo`00Coooool3o`0001;ooooo1Ol0000hooooo`Go000000?oooooo`000?l000000ol00004
ooooo`?o00000oooool8o`0000Wooooo2_l00009ooooo`Go0000<_ooool5o`0005;ooooo001Uoooo
o`?o00002oooool3o`0002_ooooo1Ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00?o00000_ooool8o`0000Wooooo1Ol000001?oooooo0000o`000?l0000;ooooo`?o0000<oooool5
o`0005;ooooo001]ooooo`?o00000_ooool5o`0002[ooooo1Ol00002ooooo`co00000_ooool8o`00
00[ooooo1Ol00014ooooo`Go0000D_ooool004oooooo0ol0000Jooooo`Go000000?oooooo`000?l0
00000ol0000[ooooo`?o00001?ooool;o`0000?ooooo1_l0000<ooooo`Go0000@oooool5o`0005;o
oooo001>ooooo`Go00006Oooool;o`0002gooooo0ol00002ooooo`Ko000000Coooooo`000?l0003o
00005_ooool5o`0000Gooooo0ol0000kooooo`Go0000D_ooool004kooooo1Ol0000Iooooo`[o0000
:?ooool3o`0000;ooooo1Ol000000ooooooo0000o`000007o`0001Oooooo1Ol00004ooooo`Go0000
>_ooool5o`0005;ooooo001>ooooo`Go00006_ooool9o`0002Oooooo1Ol000000ooooooo0000o`00
0003o`000003ooooool0003ooooo00So00005oooool3o`0000Gooooo1Ol0000kooooo`?o0000Dooo
ool004oooooo0ol0000Looooo`So00008Oooool3o`0000?ooooo1Ol000000ooooooo0000o`000003
o`000003ooooool0003ooooo00?ooooo1Ol0000Oooooo`Go00004oooool3o`0007_ooooo001>oooo
o`Go00007_ooool4o`00027ooooo1Ol00002ooooo`Go00000_ooool3o`0000;ooooo00?o0000oooo
ooooool00_ooool5o`00023ooooo0ol0000Cooooo`Go0000N_ooool004kooooo1Ol00013ooooo`Go
00000oooool3o`0000Sooooo00?o0000ooooooooool00oooool3o`0003Oooooo1Ol0000Sooooo`?o
0000E?ooool004kooooo1Ol00013ooooo`Go00003_ooool00ol0003oooooooooo`0mooooo`Go0000
8_ooool5o`0005?ooooo001>ooooo`Go0000A?ooool3o`0000oooooo00?o0000ooooooooool00ooo
ool3o`0003Sooooo0ol0000Sooooo`Go0000Doooool004kooooo1Ol0000Aooooo`?o0000:Oooool3
o`00013ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo1Ol0001Mooooo`Go0000Doooool0
04kooooo1Ol0000@ooooo`Go00009oooool5o`0000kooooo1Ol00002ooooo`03o`000?oooooooooo
00Oo0000G_ooool3o`0005Cooooo001>ooooo`Go00004?ooool5o`0002Oooooo1Ol00003ooooo`?o
00002?ooool5o`0000;ooooo00?o0000ooooool000001ol0002eooooo`00Coooool3o`00017ooooo
1Ol0000Wooooo`Go00000_ooool5o`0000;ooooo0ol00002ooooo`Go00000_ooool00ol0003ooooo
o`000006o`0002oooooo0ol00024ooooo`00I?ooool3o`0002Wooooo0ol00003ooooo`Go000000?o
ooooo`000?l000000ol000000ooooooo0000o`000002o`0000?ooooo00?o0000ooooool000001?l0
000`ooooo`Go0000;?ooool3o`0005Cooooo001iooooo`?o00001_ooool3o`00017ooooo1Ol00000
0ooooooo0000o`000008o`0000?ooooo00?o0000ooooooooool00ol0000aooooo`Go0000:oooool5
o`0005?ooooo001?ooooo`?o00007?ooool3o`0000Oooooo1Ol00004ooooo`Go00002_ooool3o`00
00Cooooo0ol00002ooooo`[o00000oooool00ol0003oooooooooo`0dooooo`Go0000:oooool5o`00
05?ooooo001>ooooo`Go00006_ooool5o`0000Kooooo1Ol00004ooooo`Go00002Oooool5o`0000Wo
oooo0ol000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000Kooooo1?l0000]oooo
o`?o0000;?ooool5o`0005?ooooo001>ooooo`Go00006_ooool5o`0000Kooooo1Ol00004ooooo`Go
000000Coooooo`000?l0003o00001Oooool5o`0000[ooooo0ol000001Ooooooo0000o`000?l0003o
oooo00Go00001?ooool6o`0005_ooooo1Ol0001Cooooo`00C_ooool5o`0001[ooooo1Ol00007oooo
o`?o00001_ooool9o`0000Cooooo1Ol00005ooooo`?o000000?oooooo`000?l000000ol00004oooo
o`Ko00000oooool7o`0001Oooooo0ol00010ooooo`Go0000Doooool004kooooo1Ol0000Kooooo`?o
00004oooool7o`0000Gooooo0ol00005ooooo`[o00001?ooool7o`0000;ooooo1ol0000Fooooo`Go
0000?oooool5o`0005?ooooo001>ooooo`Go00005oooool3o`0000Sooooo0ol0000<ooooo`Oo0000
0oooool3o`0000Oooooo2_l00005ooooo`Ko00000oooool6o`0000[ooooo0ol00009ooooo`Go0000
?oooool5o`0005?ooooo001>ooooo`Go00005_ooool5o`0000Kooooo1Ol0000;ooooo`Oo00000_oo
ool5o`0000Kooooo2Ol00002ooooo`?o00000_ooool5o`0000;ooooo1_l0000:ooooo`Go00002?oo
ool5o`00043ooooo0ol0001Dooooo`00C_ooool5o`0001Kooooo1Ol00006ooooo`Go00001?ooool3
o`0000Gooooo1_l00002ooooo`Go00001oooool7o`0000;ooooo1Ol00002ooooo`?o00000_ooool5
o`0000cooooo2?l00006ooooo`?o0000@?ooool5o`0005?ooooo001?ooooo`?o00005oooool5o`00
00Kooooo1Ol00003ooooo`Go00001Oooool6o`000003ooooool0003o000000?o00002Oooool5o`00
00;ooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo1Ol0000<ooooo`Wo0000B?ooool5o`00
05?ooooo001Zooooo`?o00002?ooool3o`0000Cooooo1Ol00006ooooo`Go00000_ooool3o`000004
ooooool0003o0000o`0000Kooooo1Ol00002ooooo`Go00000_ooool3o`0000;ooooo1Ol0000<oooo
o`Wo00002?ooool3o`0003gooooo1Ol0001Cooooo`00O?ooool5o`0000Kooooo1Ol00005ooooo`Go
00001_ooool3o`0000Cooooo0ol00002ooooo`Go00000_ooool3o`0000cooooo2_l00007ooooo`Go
0000??ooool5o`0005?ooooo001mooooo`?o00002?ooool3o`0000Kooooo1Ol0000Booooo`Go0000
1Oooool3o`0000Wooooo1Ol000001?oooooo0000o`000?l00008ooooo`Go0000??ooool5o`0005?o
oooo001@ooooo`?o0000?_ooool5o`0001;ooooo1Ol00004ooooo`Go00002?ooool5o`0000cooooo
1Ol0000looooo`Go0000Doooool004oooooo1Ol0000mooooo`Go00000oooool3o`0000_ooooo1Ol0
0005ooooo`Go00002?ooool5o`0000;ooooo0ol00008ooooo`?o0000?Oooool5o`0005?ooooo001?
ooooo`Go0000?Oooool5o`0000;ooooo1Ol00006ooooo`?o000000?oooooo`000?l000000ol00005
ooooo`Go00002?ooool5o`000003ooooool0003o000000?o00007?ooool3o`0002Sooooo1Ol0001C
ooooo`00Coooool5o`0000gooooo0ol0000^ooooo`?o00000oooool5o`0000Gooooo3?l00004oooo
o`Ko00000_ooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol0000Koooo
o`Go00009oooool4o`0005Cooooo001?ooooo`Go00003?ooool5o`0002kooooo2_l00005ooooo`Go
000000?oooooo`000?l000001Ol00005ooooo`[o000000Coooooo`000?l0003o00000_ooool5o`00
01_ooooo1Ol0000Vooooo`Go0000E?ooool004kooooo1_l0000<ooooo`Go00007Oooool6o`0000[o
oooo2ol00005ooooo`Go00000_ooool6o`0000Gooooo2_l00007ooooo`?o00007?ooool5o`0002Ko
oooo1Ol0001Dooooo`00C_ooool6o`0000cooooo1Ol0000Jooooo`co00001oooool;o`0000Kooooo
0ol00003ooooo`Ko00001Oooool:o`0002Oooooo0ol0000Wooooo`Go0000E?ooool004kooooo1_l0
000=ooooo`Co00006Oooool>o`0000Kooooo2ol0000<ooooo`Go00001_ooool4o`0000;ooooo0ol0
000<ooooo`?o0000@oooool5o`0005Cooooo001?ooooo`Co00003_ooool5o`0000Gooooo0ol0000@
ooooo`ko00001oooool9o`0000[ooooo1ol00006ooooo`Go00004?ooool5o`0004;ooooo1Ol0001D
ooooo`00HOooool5o`0000Cooooo1Ol0000?ooooo`ko00002oooool5o`0000Wooooo2Ol00005oooo
o`Go00004?ooool5o`0004;ooooo1Ol0001Dooooo`00HOooool5o`0000Cooooo1Ol0000@ooooo`?o
00001_ooool3o`0000?ooooo0ol00007ooooo`?o00002_ooool9o`0000Gooooo1Ol00008ooooo`?o
00001Oooool5o`0004?ooooo0ol0001Eooooo`00H_ooool3o`0000Cooooo1_l0000Kooooo`So0000
4oooool9o`0000;ooooo0ol000001?oooooo0000o`000?l00005ooooo`So00001Oooool4o`0000Go
oooo0ol0002Cooooo`00H_ooool5o`000003ooooool0003o000000Co00005?ooool3o`0000Cooooo
2Ol0000Dooooo`Oo00000_ooool5o`0000Oooooo2Ol00005ooooo`Go00000oooool5o`0000oooooo
1?l0001oooooo`00DOooool3o`0000gooooo3?l0000@ooooo`?o000000?oooooo`000?l000000ol0
0003ooooo`Wo00005Oooool3o`0000Gooooo1Ol00007ooooo`Wo00001Oooool5o`0000?ooooo1Ol0
000>ooooo`Ko0000O_ooool0053ooooo1Ol0000<ooooo`co00003oooool:o`0000?ooooo2?l0000H
ooooo`03o`000?oooooooooo00?ooooo1Ol00007ooooo`So00001_ooool6o`0000;ooooo1Ol0000>
ooooo`Ko0000O_ooool0053ooooo1Ol0000<ooooo`Oo000000Coooooo`000?l0003o00004?ooool:
o`0000Cooooo1ol0000Hooooo`03o`000?oooooooooo00Cooooo0ol00009ooooo`Ko00002?ooool6
o`0000;ooooo0ol0000?ooooo`Wo0000Noooool0053ooooo1Ol0000=ooooo`Go00005Oooool9o`00
00Sooooo0ol0000Iooooo`03o`000?oooooooooo017ooooo1Ol00009ooooo`Go00005Oooool9o`00
07[ooooo001Aooooo`?o0000:Oooool8o`0000?ooooo0ol0000Nooooo`03o`000?oooooooooo017o
oooo1Ol00009ooooo`Go00006Oooool5o`00023ooooo1?l0001Fooooo`00Ooooool5o`0000?ooooo
1Ol0000Mooooo`03o`000?oooooooooo01;ooooo0ol0000;ooooo`?o00006_ooool5o`0001oooooo
1_l0001Eooooo`00O_ooool5o`0000Cooooo1Ol0000Mooooo`03o`000?oooooooooo02Cooooo0ol0
000Gooooo`?o00008?ooool6o`0005Gooooo001nooooo`Go00001?ooool5o`00017ooooo1Ol00007
ooooo`03o`000?oooooooooo00cooooo0ol0000Dooooo`Go0000>Oooool6o`0005Gooooo001Aoooo
o`?o00006Oooool3o`0000kooooo1Ol00005ooooo`Go00004?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?o0000ooooooooool02oooool5o`0000Oooooo0ol00009ooooo`Go0000>Oooool5
o`0005Kooooo001@ooooo`Go00005oooool5o`0000kooooo0ol00007ooooo`Go00000_ooool3o`00
00_ooooo00?oV9RHob4Q8Oo^k^h02?ooool00ol0003oooooooooo`0;ooooo`Go00001_ooool5o`00
00Oooooo1_l0000iooooo`Go0000E_ooool0053ooooo1Ol0000Gooooo`Go00006?ooool5o`000003
ooooool0003o000000?o00002oooool00onHV9So8B4Qonk^kP07ooooo`?o00002oooool5o`0000Ko
oooo1Ol00006ooooo`Ko0000>_ooool5o`0005Kooooo001@ooooo`Go00005oooool5o`0001Sooooo
1Ol000000ooooooo0000o`000003o`0000cooooo00?oMgMgofIVI_ooool01_ooool00ol0003ooooo
ooooo`0<ooooo`?o00001oooool5o`0000Kooooo1Ol0000looooo`?o0000Eoooool0053ooooo1Ol0
000Hooooo`?o00006_ooool3o`0000;ooooo1Ol0000=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05oooool3o`0000Oooooo1Ol0002Fooooo`00D?ooool6o`0003[ooooo0ol0000:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001oooool00ol0003oooooooooo`0Rooooo`?o00002_oo
ool3o`0008[ooooo001Aooooo`Go0000Aoooool01OnHV9So410@o`000?lQ8B7oc<c<00Oooooo00?o
0000ooooooooool03_ooool3o`0001gooooo1Ol00006ooooo`?o00009?ooool3o`0005Wooooo001A
ooooo`Go00007oooool3o`00037ooooo00?o0000ooooooooool03Oooool5o`0001Oooooo0ol00002
ooooo`Go00001Oooool5o`0002;ooooo1Ol0001Hooooo`00D_ooool3o`0001oooooo1Ol0000`oooo
o`03o`000?oooooooooo00gooooo1Ol0000Fooooo`Go000000?oooooo`000?l000000ol00005oooo
o`Go00000oooool3o`0001cooooo1Ol0001Hooooo`00J_ooool3o`0000Oooooo1Ol0000`ooooo`03
o`000?oooooooooo00gooooo1Ol0000Fooooo`Go00000_ooool3o`0000Kooooo1Ol00002ooooo`Go
00006oooool5o`0005Sooooo001Cooooo`?o00004oooool5o`0000Kooooo1Ol0000`ooooo`03o`00
0?oooooooooo00kooooo0ol0000>ooooo`?o00001_ooool5o`0000cooooo0ol00003ooooo`Go0000
7?ooool3o`0005Wooooo001Booooo`Go00004_ooool5o`0000Oooooo0ol0000Aooooo`?o00007Ooo
ool00ol0003oooooooooo`0Nooooo`Go00001_ooool3o`0001?ooooo1Ol0001hooooo`00D_ooool5
o`00017ooooo1_l0000;ooooo`?o00003?ooool5o`0001cooooo00?o0000ooooooooool07_ooool5
o`0000Sooooo0ol0000:ooooo`?o00001Oooool3o`0001gooooo0ol0001Iooooo`00D_ooool5o`00
017ooooo1Ol00006ooooo`?o00000_ooool5o`0000_ooooo1Ol0000Looooo`03o`000?oooooooooo
01kooooo1Ol00007ooooo`Ko00001oooool5o`0002?ooooo1Ol0001Hooooo`00Doooool3o`0001;o
oooo1Ol00005ooooo`Go000000?oooooo`000?l000000ol0000;ooooo`Go00007?ooool00ol0003o
ooooooooo`0Oooooo`?o00002?ooool7o`0000Kooooo1Ol00005ooooo`?o00006oooool5o`0005So
oooo001Yooooo`?o00001_ooool5o`000003ooooool0003o000000?o00003?ooool3o`0001gooooo
00?o0000ooooooooool0:_ooool7o`0000Kooooo1Ol00004ooooo`Go00006_ooool5o`0005Sooooo
001booooo`Go00000_ooool3o`0000Oooooo0ol0000Sooooo`03o`000?oooooooooo02_ooooo1_l0
0007ooooo`?o00001Oooool5o`0001_ooooo0ol0001Iooooo`00Loooool3o`0000cooooo1Ol0000C
ooooo`So00001oooool00ol0003oooooooooo`0Looooo`?o00003_ooool3o`00013ooooo1Ol0000I
ooooo`?o0000Foooool005Gooooo0ol0000Zooooo`Go00004?ooool=o`0000Gooooo0_l0000Loooo
o`Go00008Oooool3o`0001Wooooo1Ol0001Jooooo`00E?ooool5o`0002Wooooo1Ol0000?oooooa3o
00000oooool00ol0003oooooooooo`0Kooooo`Go0000?Oooool5o`0005[ooooo001Dooooo`Go0000
:?ooool5o`0000oooooo4_l00002ooooo`03o`000?oooooooooo01_ooooo1Ol0000mooooo`Go0000
F_ooool005Cooooo1Ol0000Aooooo`?o00004oooool5o`0000oooooo5?l000000ooooooo0000oooo
o`0Mooooo`?o0000?_ooool5o`0005[ooooo001Eooooo`?o00004Oooool5o`0001;ooooo1Ol0000>
ooooo`Wo00000oooool;o`0005kooooo1Ol0001Kooooo`00JOooool5o`00017ooooo1_l0000=oooo
o`So00002?ooool8o`0005kooooo1Ol0001Kooooo`00JOooool5o`00017ooooo1Ol0000>ooooo`Ko
00002oooool8o`0005gooooo1Ol0001Kooooo`00J_ooool3o`0001;ooooo1Ol0000>ooooo`Ko0000
3?ooool7o`0005kooooo0ol0001Looooo`00Eoooool3o`0002Kooooo0ol0000>ooooo`Ko00003_oo
ool6o`0003kooooo0ol0001looooo`00E_ooool5o`0003Kooooo1_l0000?ooooo`Ko0000??ooool5
o`0007_ooooo001Fooooo`Go00009oooool3o`0000cooooo1Ol0000@ooooo`Ko0000??ooool5o`00
01[ooooo0ol0001Nooooo`00E_ooool5o`0002Kooooo1Ol0000;ooooo`Go00004Oooool5o`0002co
oooo0ol0000=ooooo`Go00006Oooool5o`0005gooooo001Gooooo`?o00009oooool5o`0000_ooooo
1_l0000@ooooo`Go0000:oooool5o`0000gooooo0ol0000Iooooo`Ko0000GOooool005Sooooo0ol0
000Vooooo`Go00002oooool6o`00013ooooo1Ol0000[ooooo`Oo00009oooool6o`0005gooooo001G
ooooo`Go00004Oooool3o`0001;ooooo1?l0000<ooooo`Go00004?ooool5o`0002_ooooo2ol0000S
ooooo`Go0000G_ooool005Oooooo1Ol0000@ooooo`Go00004Oooool5o`0000_ooooo1_l0000>oooo
o`Ko0000;?ooool>o`00023ooooo0ol0001Oooooo`00Eoooool5o`00013ooooo1Ol0000Aooooo`Go
00002oooool6o`0000kooooo1_l0000^ooooo`go0000POooool005Oooooo1Ol0000@ooooo`Go0000
4Oooool5o`0000cooooo1_l0000<ooooo`Ko00007oooool3o`0000kooooo3?l00021ooooo`00F?oo
ool3o`00013ooooo1Ol0000Cooooo`?o00003Oooool8o`0000Wooooo1ol0000Nooooo`Go00004Ooo
ool9o`00083ooooo001Jooooo`?o00003Oooool5o`0002Gooooo2?l00006ooooo`Wo00007_ooool5
o`0001;ooooo2Ol0001oooooo`00FOooool5o`0000cooooo1Ol0000?ooooo`?o00004ooooolFo`00
01oooooo1Ol0000Booooo`Wo00006_ooool3o`0006;ooooo001Iooooo`Go00003?ooool5o`0000ko
oooo1Ol0000CoooooaGo00008?ooool3o`0001?ooooo2Ol0000Iooooo`Go0000HOooool005Wooooo
1_l0000<ooooo`?o00003oooool5o`0001Gooooo4Ol000000ooooooo0000ooooo`0Gooooo`?o0000
7?ooool3o`000004ooooool0003o0000o`0001[ooooo1Ol0001Qooooo`00F_ooool5o`0001kooooo
1Ol0000Fooooo`ko00000oooool00ol0003oooooooooo`0Eooooo`Go0000>oooool6o`00067ooooo
001Jooooo`Go00007oooool3o`0001Wooooo2ol00004ooooo`03o`000?oooooooooo01Gooooo1Ol0
000jooooo`Ko0000H_ooool005_ooooo0ol0001;ooooo`03o`000?oooooooooo01Gooooo1Ol0000j
ooooo`Go0000Hoooool00:Wooooo00?o0000ooooooooool05_ooool3o`0003_ooooo1Ol0001Soooo
o`00G_ooool3o`0000kooooo0ol0000gooooo`03o`000?oooooooooo05Gooooo0ol0001Tooooo`00
GOooool5o`0000cooooo1Ol0000fooooo`03o`000?oooooooooo0;cooooo001Mooooo`Go00003?oo
ool5o`0003Kooooo00?o0000ooooooooool0:oooool3o`0002Cooooo0ol0001Wooooo`00GOooool5
o`0000cooooo1Ol0000>ooooo`?o00009Oooool00ol0003oooooooooo`0<ooooo`?o00000oooool3
o`0000cooooo0ol00006ooooo`Go00008_ooool5o`0006Kooooo001Nooooo`?o00003_ooool3o`00
00kooooo1Ol0000Tooooo`03o`000?oooooooooo00_ooooo1Ol000000ooooooo0000o`000003o`00
00[ooooo1Ol00005ooooo`Go00008_ooool5o`0006Kooooo0020ooooo`Go00001?ooool3o`0001go
oooo0_l0000<ooooo`Go000000?oooooo`000?l000000ol0000:ooooo`Go00001Oooool5o`0002;o
oooo1Ol0001Vooooo`00HOooool3o`0001cooooo1Ol00003ooooo`Go00007?ooool00ol0003ooooo
ooooo`0;ooooo`Go000000?oooooo`000?l000001?l00009ooooo`Oo00001?ooool3o`0002Cooooo
0ol0001Wooooo`00H?ooool5o`0001cooooo0ol00004ooooo`Ko00006oooool00ol0003ooooooooo
o`0<ooooo`?o00000oooool6o`0000Wooooo1ol0000Wooooo`?o0000J_ooool0063ooooo1Ol0000S
ooooo`Oo00006_ooool00ol0003oooooooooo`0Cooooo`Ko00002_ooool5o`0002Kooooo1Ol0001Y
ooooo`00H?ooool5o`0002Cooooo1_l000001?oooooo0000o`000?l0000Fooooo`03o`000?oooooo
oooo01?ooooo1ol00009ooooo`Go00009_ooool5o`0006Wooooo001Qooooo`?o00009_ooool:o`00
01Gooooo00?o0000ooooooooool05?ooool6o`0000?ooooo0ol00004ooooo`?o00009oooool5o`00
06Wooooo001Tooooo`?o00009?ooool3o`000003ooooool0003o000000?o00005Oooool00ol0003o
ooooooooo`0Eooooo`Go00000_ooool5o`0002kooooo0ol0001Zooooo`00Hoooool5o`0002Oooooo
1Ol0000Eooooo`03o`000?oooooooooo01Kooooo0ol00003ooooo`Go0000Voooool006?ooooo1_l0
000Wooooo`?o00005_ooool00ol0003oooooooooo`0Looooo`Go0000:_ooool3o`0006kooooo001S
ooooo`Ko0000@?ooool00ol0003oooooooooo`0Mooooo`?o0000:_ooool5o`0006gooooo001Toooo
o`Go0000@?ooool00ol0003oooooooooo`19ooooo`Ko0000KOooool006Gooooo0ol0000/ooooo`?o
00004?ooool3o`0004_ooooo1_l0001]ooooo`00Toooool5o`0000?ooooo0ol00004ooooo`Wo0000
B_ooool5o`0006kooooo002Cooooo`Go00000_ooool6o`000003ooooool0003o000000So0000Booo
ool3o`0006oooooo002Cooooo`Go00000_oooolAo`00017ooooo0ol00006ooooo`?o0000:_ooool3
o`0007?ooooo001[ooooo`?o00007Oooool3o`0000Kooooo0ol00003oooooa3o00004Oooool5o`00
00Cooooo1Ol0000Xooooo`Go0000L_ooool006[ooooo1Ol0000Kooooo`Go00002oooool=o`0000;o
oooo0ol0000?ooooo`Go00001?ooool5o`0002Sooooo1Ol0001booooo`00J_ooool5o`0001_ooooo
1Ol0000:ooooo`So00001?ooool3o`000003ooooool0003o000000;o00003_ooool5o`0000Cooooo
1Ol0000Xooooo`Go0000L_ooool006[ooooo1_l0000Jooooo`Go00002_ooool5o`000003oeEEEOoo
oooo000000?ooooo2_l0000>ooooo`?o00001_ooool3o`0002[ooooo0ol0001cooooo`00Joooool6
o`0001[ooooo0ol0000;ooooo`Ko000000?oc<c<o`000?ooool00_ooool:o`000;[ooooo001/oooo
o`Ko0000:?ooool7o`0000?ooooo2_l0002jooooo`00K?ooool7o`0002Sooooo1_l00004ooooo`So
00002?ooool3o`000;3ooooo001]ooooo`Ko0000:?ooool5o`0000Sooooo1Ol000001?oooooo0000
o`000?l00003ooooo`Go0000<_ooool3o`0007[ooooo001^ooooo`Go0000:Oooool3o`0000Wooooo
2_l00002ooooo`Go0000<Oooool5o`0007Wooooo001_ooooo`?o000000Coooooo`000?l0003o0000
<oooool3o`000003ooooool0003o000000?o00000_ooool5o`00037ooooo1Ol0001iooooo`00L_oo
ool5o`0003;ooooo00Co0000oooooooooooooooo1Ol00003ooooo`?o0000;oooool8o`0007Wooooo
001booooo`Go0000<_ooool00ol0003oooooooooo`02ooooo`?o0000=Oooool8o`0007[ooooo001b
ooooo`Go0000<_ooool00ol0003oooooooooo`0jooooo`Go0000OOooool007?ooooo0ol0000coooo
o`03o`000?oooooooooo03[ooooo1Ol0001mooooo`00ZOooool00ol0003oooooooooo`0fooooo`?o
00000_ooool3o`0007kooooo001kooooo`?o0000:oooool00ol0003oooooooooo`0eooooo`Go0000
P_ooool007[ooooo1Ol0000Zooooo`03o`000?oooooooooo03Gooooo1Ol00022ooooo`00N_ooool5
o`0002[ooooo00?o0000ooooooooool0=Oooool5o`0008;ooooo001jooooo`Go0000:_ooool2o`00
03Oooooo0ol00023ooooo`00Noooool3o`0002_ooooo00?o0000ooooooooool0;oooool3o`0008[o
oooo002Yooooo`03o`000?oooooooooo02kooooo1Ol00029ooooo`00ZOooool00ol0003ooooooooo
o`0]ooooo`Ko0000ROooool00:Wooooo00?o0000ooooooooool0;Oooool6o`0008Wooooo0027oooo
o`?o00007oooool00ol0003oooooooooo`0]ooooo`Go0000R_ooool008Kooooo1_l0000Mooooo`03
o`000?oooooooooo02Kooooo0ol00005ooooo`?o0000Roooool008Kooooo2?l0000Kooooo`03o`00
0?oooooooooo02Cooooo1_l0002Booooo`00Q_ooool;o`0001Sooooo00?o0000ooooooooool08ooo
ool7o`0009;ooooo0027ooooo`_o00005oooool00ol0003oooooooooo`0Pooooo`[o0000T_ooool0
08Wooooo2Ol0000Gooooo`03o`000?oooooooooo01oooooo2_l0002Cooooo`00Roooool7o`0001Oo
oooo00?o0000ooooooooool07oooool8o`0009Gooooo002<ooooo`Go00002?ooool3o`0000gooooo
00?o0000ooooooooool07oooool5o`0009Sooooo002Hooooo`Go00000_ooool3o`0000Oooooo00?o
0000ooooooooool03oooool3o`0000kooooo0ol0002Iooooo`00V?ooool5o`000003ooooool0003o
000000?o00001_ooool4o`0000;ooooo0ol000001?oooooo0000o`000?l00003ooooo`Ko0000ZOoo
ool009Sooooo1Ol000000ooooooo0000o`000003o`0000Kooooo3_l000000ooooooo0000o`000005
o`000:Wooooo002Iooooo`?o00000_ooool5o`0000Kooooo3_l000000ooooooo0000o`000005o`00
0:Wooooo002Oooooo`?o00001oooool>o`000003ooooool0003o000000Co0000Z_ooool00:Wooooo
1?l00002ooooo`?o000000Coooooo`000?l0003o00000oooool3o`000:cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Uooooo`?o000000?o410@ooooooooool0_Oooool00:Oo
oooo00?o410@okZj^_ooool0__ooool00:Oooooo00?oV9RHoc8b<_ooool0__ooool00:Oooooo00?o
gMgMo`000?nj^[X0__ooool00:Oooooo00?oEEEEogMgMom4A4@0__ooool00:Kooooo00GogMgMoa0@
4?oooooo8B4QomgMg@2mooooo`00Y_ooool01OmVIVKoQhN7oooooonHV9SoEEEE0;gooooo002Uoooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0^oooool00:Gooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`2jooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-5.23879, -5.20006, 0.0387359, \
0.0387359}}],

Cell[TextData[{
  "Fig. 1.15 Solution to Exercise(8)(d): Poincar\[EAcute] plot in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane for the magnetic field ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["B",
              FontSlant->"Plain"], 
            StyleBox["s",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 1/4\)]],
  " ."
}], "Caption",
  CellTags->"Fig. 1.15"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Use Euler's method to "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " solve the following ODEs with initial conditions over the given range of \
time, and for the given step size. Then,  "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " plot the solution; "
}], "Text"],

Cell[TextData[{
  StyleBox["(c) ",
    FontWeight->"Bold"],
  "solve the ODE analytically, and plot the error in ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(t). "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " In each case, using the results of (c) ",
  StyleBox["predict",
    FontSlant->"Italic"],
  " how small a step size is necessary for the error to be smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-4\)\)]],
  " over the course of the run."
}], "Text"],

Cell[TextData[{
  "\t(i)\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
            MultilineFunction->None], "=", \(sin(t) - x\)}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = x\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 5\)]],
  ",   \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  "=0.1."
}], "Text"],

Cell[TextData[{
  "\t(ii)\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(4\ x\), "+", 
            FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
              MultilineFunction->None], "+", 
            FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
              MultilineFunction->None]}], "==", "0"}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x(0) = 2\), ",", \(\(x\^\[Prime]\)(0) = 1\), ",", 
          " ", \(0 < t < 10\), ",", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "=", "0.01"}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(iii)\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\^\[Prime]\)\^\[Prime]\)\^\[Prime] + 
          2  x\^\[DoublePrime] + x\^\[Prime] + 
          2  x = \(cos\ t\ \ \(x(0)\) = \(\(x\^\[Prime]\)(
              0) = \(\(x\^\[DoublePrime]\)(0) = 0\)\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.02"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " Use Euler's method to solve the following nonlinear ODE initial-value \
problems, and answer the questions concerning the solutions. By looking at \
solutions as you vary the step size , ensure that each answer is accurate to \
at least ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-4\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[Prime]\)(t) = t/\((x + t)\)\^2, x(0) = 3\)]],
  StyleBox[" . ",
    FontSlant->"Italic"],
  " What is ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(10)?"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b) ",
    FontWeight->"Bold"],
  "   ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[DoublePrime]\)(
          t) = \(cos(t)\) \(cos(x)\), \ \ x(0) = \(-1\), \ \ \(x\^\[Prime]\)(
          0) = 0\)]],
  ". What is ",
  StyleBox["x(",
    FontSlant->"Italic"],
  "20)?"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Eqs. ",
  ButtonBox["(1.4.25)",
    ButtonData:>"(1.4.25)",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["\[Sigma]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox["=10, ",
    FontFamily->"Symbol"],
  StyleBox["b",
    FontSlant->"Italic"],
  "=8/3,  and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 28; ",
  StyleBox["x",
    FontSlant->"Italic"],
  "=1, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "=1, ",
  StyleBox["z",
    FontSlant->"Italic"],
  "=1. What is ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(40)?"
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  "  Prove that the error in the integral of ",
  ButtonBox["Eq. (1.4.6)",
    ButtonData:>"(1.4.6)",
    ButtonStyle->"Hyperlink"],
  " is of 0(\[CapitalDelta]",
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)]],
  "). ",
  StyleBox["(Hint: Taylor-expand ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["f",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" about the initial time.)",
    FontColor->RGBColor[0, 0, 0.00389105]]
}], "Text"],

Cell[TextData[{
  StyleBox["(13) ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  "Prove that the error in the integral of Eq. ",
  ButtonBox["(1.4.10)",
    ButtonData:>"(1.4.10)",
    ButtonStyle->"Hyperlink"],
  " is of 0(\[CapitalDelta]",
  Cell[BoxData[
      \(TraditionalForm\`t\^3\)]],
  "). "
}], "Text",
  CellTags->"ex 13"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " Modify our second-order predictor-corrector algorithm so that it can \
handle differential equations of order higher than one, or systems of coupled \
equations. Use the modified method to repeat"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Exercise (10)(ii),"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Exercise (10)(iii),"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Exercise (11)(b),"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Exercise (11)(c)."
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Centered-difference method",
    FontSlant->"Italic"],
  ". The following discretization method can be used to solve a second-order \
differential equation of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", \(f(x, t)\)}], TraditionalForm]]],
  " , with initial condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(x(0)\), "=", 
            FormBox[\(x\_o\),
              "TraditionalForm"]}], ",", " ", 
          RowBox[{
            RowBox[{
              FormBox[\(x\^\[Prime]\),
                "TraditionalForm"], "(", "0", ")"}], "=", 
            FormBox[\(v\_o\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". The method requires only one force evaluation per timestep. First, \
discretize time in the usual way, with ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  ". ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "Approximate the second derivative as "
}], "Text",
  CellTags->"i:64"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
              MultilineFunction->None], \((t\_n)\)}], "=", 
          
          FractionBox[\(x(t\_\(n + 1\)) - 2\ \(x(t\_n)\) + x(t\_\(n - 1\))\), 
            
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "2"]]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(1.4.26)"],

Cell[TextData[{
  "This approximation is referred to as a ",
  StyleBox["centered-difference",
    FontSlant->"Italic"],
  " form for the derivative, since the expression is symmetric about timestep \
",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  " . (See the ",
  ButtonBox["Appendix",
    ButtonData:>{"Appendix.nb", None},
    ButtonStyle->"Hyperlink"],
  " and Sec. ",
  ButtonBox["2.4.5",
    ButtonData:>{"Chapter2.nb", "c:48"},
    ButtonStyle->"Hyperlink"],
  ").  The differential equation then becomes the recursion relation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["x",
                  FontSize->11], \(n + 1\)], "-", \(2  x\_n\), 
              "+", \(x\_\(n - 1\)\)}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "2"], 
              " ", \(f(x\_n, t\_n)\)}]}], ",", " ", \(n > 1\)}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(1.4.27)"],

Cell[TextData[{
  "Note that in order to determine the first step,  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " , given the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ", Eq. ",
  ButtonBox["(1.4.27)",
    ButtonData:>"(1.4.27)",
    ButtonStyle->"Hyperlink"],
  " requires ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(-1\)\)]],
  ", which is not defined. Therefore, we need a different equation to obtain \
",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  StyleBox[". ",
    FontSlant->"Italic"],
  "Use"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_1\), "=", 
          RowBox[{\(x\_o\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(v\_o\)}], "+", 
            RowBox[{
              FractionBox[
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "2"], "2"], \(f(x\_o, 
                t\_o)\)}]}]}], TraditionalForm]]],
  " ,"
}], "NE4",
  CellTags->"(1.4.28)"],

Cell["\<\
which is the formula for position change due to a constant \
acceleration.\
\>", "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Write a module that implements this scheme."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use this module to solve the problem of a harmonic oscillator, with ",
  Cell[BoxData[
      \(TraditionalForm\`f = \(-x\)\)]],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  StyleBox[" = ",
    FontSlant->"Italic"],
  "1, and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  StyleBox[" = ",
    FontSlant->"Italic"],
  " 0 on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  ", and taking ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0.1. Plot the error in your solution, compared to the analytic solution \
",
  Cell[BoxData[
      \(TraditionalForm\`cos\ t\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Repeat (b) with ",
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0.02. By what factor has the error been reduced? What is the order of \
this method?"
}], "Text"],

Cell[TextData[{
  StyleBox["(16)", "Text",
    FontWeight->"Bold"],
  StyleBox[" ", "Text"],
  StyleBox["The leapfrog method . ", "Text",
    FontSlant->"Italic"],
  StyleBox["The following discretization method can also be used to solve a \
second-order  differential equation of the form ", "Text"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", \(f(x)\)}], TraditionalForm]]],
  ", with initial conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontSlant->"Italic"], "(", "0", ")"}], "=", 
            FormBox[\(x\_o\),
              "TraditionalForm"]}], ",", 
          RowBox[{
            RowBox[{
              StyleBox[\(x'\),
                FontSlant->"Italic"], \((0)\)}], "=", 
            FormBox[\(v\_o\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". This method requires only one force evaluation per timestep. We first \
write this equation in terms of two first-order equations for position and \
velocity:"
}], "Text",
  CellTags->"i:65"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ 
        v(t), \ \[DifferentialD]v/\[DifferentialD]t\  = \ f(x)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We then discretize ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " on a grid ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". But we discretize the velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v(t)\)]],
  " on the grid ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_\(n + 1/2\)\), "=", 
          RowBox[{\((n + 1/2)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". \nIn each case  we use ",
  "centered-difference",
  "  forms for the discretized first derivative:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(v\_\(n + \(\(1/2\)\(\ \)\)\) - v\_\(n - 1/2\)\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]], "=", \(f(x\_n)\)}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
            FractionBox[\(x\_\(\(n\)\(+\)\(1\)\(\ \)\) - \ x\_n\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]], 
            "=", \(\(v\_\(n + 1/2\)\)\(.\)\)}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "In the first equation, the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " is evaluated at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " using a centered-difference form for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DifferentialD]v\/\[DifferentialD]t\) \
\((t\_n)\)\)]],
  ".  (See the ",
  ButtonBox["Appendix",
    ButtonData:>{"Appendix.nb", None},
    ButtonStyle->"Hyperlink"],
  " and Sec. ",
  ButtonBox["2.4.5",
    ButtonData:>{"Chapter2.nb", "c:48"},
    ButtonStyle->"Hyperlink"],
  "). In the second equation, the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is evaluated at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1/2\)]],
  ", using the same centered-difference form.  The method is started using a \
predictor-corrector step in order to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(1/2\)\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      FormBox[
        RowBox[{
          RowBox[{\(x\_\(\(1/2\)\(\ \)\)\), " ", "=", " ", 
            RowBox[{\(x\_o\), " ", "+", " ", 
              RowBox[{\(v\_o\), " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "/", "2"}]}]}]}], " ", ";"}],
         TraditionalForm], "\[IndentingNewLine]", 
      FormBox[
        RowBox[{\(v\_\(\(1/2\)\(\ \)\)\), "=", " ", 
          RowBox[{\(v\_o\), " ", "+", " ", 
            RowBox[{\(1\/2\), \((f(x\_o)\  + \ f(x\_\(1/2\)))\), " ", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "/", "2."}]}]}]}], 
        TraditionalForm]}]]
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Write a module that implements this scheme."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the module to solve  the same problem as in Exercise (15)(b) and (c). \
What is the order of this method?"
}], "Text"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " ",
  StyleBox["The Adams-Bashforth method",
    FontSlant->"Italic"],
  ". Consider the following general first-order ODE (or system of ODEs): ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]v/\[DifferentialD]t = f(v, t)\)]],
  ", with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`v(0) = v\_o\)]],
  ". We wish to obtain a second-order (or even higher-order) method for \
solving this problem, using only one force evaluation per step.  First, we \
replace Eq. ",
  ButtonBox["(1.4.11)",
    ButtonData:>"(1.4.11)",
    ButtonStyle->"Hyperlink"],
  " by"
}], "Text",
  CellTags->"i:66"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(v(t\_n)\), "=", 
          RowBox[{\(v(t\_\(n - 1\))\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \(f(t\_\(n - 1/2\), v(t\_\(n - 1/2\)))\)}], "+", 
            RowBox[{
              StyleBox["0",
                FontSlant->"Italic"], 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "3"], ")"}]}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "This formula is exact if ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is a linear function of time, as is clear from Fig. ",
  ButtonBox["1.11",
    ButtonData:>"Fig. 1.11",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that the error in one step is in fact of order ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "3"], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " To obtain the force at the intermediate time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(n - 1/2\)\)]],
  ", we ",
  StyleBox["extrapolate",
    FontSlant->"Italic"],
  " from previous force evaluations. If at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  " we call the force  ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  ", then by using a linear fit through ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(n - 1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(n - 2\)\)]],
  " show that"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(n - 1/2\) = \((\ 
            3\ f\_\(n - 1\)\  - \ f\_\(n - 2\))\)/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " The code arising from this approach is called the second-order \
Adams-Bashforth method.   It is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(v(t\_n)\), "=", 
          RowBox[{\(v(t\_\(n - 1\))\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \(\(\((\ 3\ f\_\(n - 1\)\  - \ f\_\(n - 2\))\)/
                2\)\(\ \)\)}]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(1.4.29)"],

Cell[TextData[{
  "This algorithm is an example of a ",
  StyleBox["multistep method",
    FontSlant->"Italic"],
  ", where force evaluations from previous steps are kept in memory and used \
to make the next step. One way to save previous force evaluations is to use \
the double-equal sign trick : define a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(force[n_]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[":=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox[\(force[n]\),
              FontFamily->"Courier",
              FontWeight->"Bold"], " ", "=", " ", 
            RowBox[{\(f(t\_n, v(t\_n))\), Cell[""]}]}]}], TraditionalForm]]],
  ", and use this function in Eq. ",
  ButtonBox["(1.4.29)",
    ButtonData:>"(1.4.29)",
    ButtonStyle->"Hyperlink"],
  ".  Write a module for this algorithm. To take the first step, use the \
second-order predictor-corrector method.  Use your module to solve the ",
  StyleBox["coupled system",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ \(-\ 
            y\)\  - \ x\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y/\[DifferentialD]t\  = \ 
        2\ x - 3\ y\  + \ sin\ t\)]],
  " "
}], "Text"],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0 < t < 10\)\(,\)\)\)]],
  " taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.1"}], 
        TraditionalForm]]],
  ", with initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 0, y(0) = 1\)]],
  " . Compare ",
  Cell[BoxData[
      \(TraditionalForm\`y(t)\)]],
  " with the exact solution found using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and verify that the method is second-order accurate by evaluating the \
error taking half the step size, then reducing by half again.   "
}], "Text"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " For force laws",
  StyleBox[" ",
    FontWeight->"Bold"],
  "that are derivable from a potential, such as the gravitational force, the \
equations ",
  ButtonBox["(1.4.21)",
    ButtonData:>"(1.4.21)",
    ButtonStyle->"Hyperlink"],
  "  are Hamiltonian in form, with conserved energy"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`H = \[Sum]\+\(i = 1\)\%N\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\(m\_i\) v\_i\^2\)\/2\), "+", 
          RowBox[{\(\[Sum]\+\(i = 1\)\%N\), 
            RowBox[{\(\[Sum]\+\(j = i + 1\)\%N\), 
              RowBox[{\(V\_\(i\ j\)\), "(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "i"], "-", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "j"]}], ")"}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NE4",
  CellTags->{"(1.4.30)", "i:78"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(i\ j\)\)]],
  " is the potential energy of interaction between particles ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  ". Evaluating the energy in molecular dynamics calculations provides a \
useful check of the accuracy of the numerics.  This Hamiltonian also \
conserves total linear momentum,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["P",
          FontWeight->"Bold",
          FontSlant->"Plain"], "=", 
        RowBox[{\(\[Sum]\+\(i = 1\)\%N\), 
          RowBox[{\(m\_i\), 
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "i"], " "}]}]}], 
      TraditionalForm]]]], "NE4",
  CellTags->{"(1.4.31)", "i:67"}],

Cell[TextData[{
  "\tFor central-force problems where the potential energy depends only on \
the distance between bodies (again, gravity is an example), the total angular \
momentum ",
  StyleBox["L",
    FontWeight->"Bold"],
  " = (",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`L\_z\)]],
  ")",
  StyleBox["  ",
    FontSlant->"Italic"],
  "is also conserved, and provides three more useful checks on the numerical \
accuracy of a code:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["L",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{\(\[Sum]\+\(i = 1\)\%N\), 
            RowBox[{\(m\_i\), 
              RowBox[{
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"], "\[Cross]", 
                SubscriptBox[
                  StyleBox["v",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}]}]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->{"(1.4.32)", "i:68"}],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "Run the example problem on two gravitating bodies (see ",
  ButtonBox["Cell 1.56",
    ButtonData:>"Cell 1.56",
    ButtonStyle->"Hyperlink"],
  "). Use the results to calculate and plot the energy, the total momentum, \
and the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\)\(-\)\)\)]],
  "component of angular momentum as a function of time."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Repeat (a), setting  ",
  StyleBox["AccuracyGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PrecisionGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to their highest possible values for your computer system."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " The center-of-mass velocity is defined as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold",
              FontSlant->"Plain"], "cm"], "=", 
          RowBox[{
            StyleBox["P",
              FontWeight->"Bold",
              FontSlant->"Plain"], "/", \(\[Sum]\+\(i = 1\)\%N m\_i\)}]}], 
        TraditionalForm]]],
  ".",
  StyleBox[" ",
    FontWeight->"Bold"],
  "Plot the orbits of the two planets as seen in a frame moving at the \
constant speed ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold",
            FontSlant->"Plain"], "cm"], TraditionalForm]]],
  ". What do they look like in this frame of reference?"
}], "Text",
  CellTags->"i:69"],

Cell[TextData[{
  StyleBox["(19) ",
    FontWeight->"Bold"],
  "A classical model of a helium atom consists of a massive nucleus with mass \
roughly 4 ",
  Cell[BoxData[
      \(TraditionalForm\`m\_p\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`m\_p\)]],
  " being the proton mass) and charge 2",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  ", and two electrons with mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\_e\)]],
  " and charges -",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  ".  In this model the electrons are equidistant from the nucleus, on \
opposite sides, and the electrons move in circular orbits. The charges \
interact via Coulomb's law, written below for charges ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(q\_i\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`q\_j\)]],
  " separated by displacement ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ":"
}], "Text",
  CellTags->"i:75"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["F",
                  FontSlant->"Plain"], 
                StyleBox[\(i\ j\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(q\_i\),
              FontWeight->"Plain"], 
            StyleBox[\(q\_j\),
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["/",
                FontWeight->"Plain"], 
              StyleBox[\((4  \[Pi]\ \[Epsilon]\_o\ r\^3)\),
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(1.4.33)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Analytically solve for an equilibrium distance ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["v",
    FontSlant->"Italic"],
  ") of each electron from the nucleus, as a function of the orbital speed ",
  StyleBox["v",
    FontSlant->"Italic"],
  ". The orbital period of this motion is ",
  Cell[BoxData[
      \(TraditionalForm\`T\  = \ 2  \[Pi]\ d/v\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " We will numerically examine the stability of this equilibrium. Choose any \
value of the orbital speed ",
  StyleBox["v ",
    FontSlant->"Italic"],
  "that you wish. Move the electrons a small distance, 0.05 ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["v",
    FontSlant->"Italic"],
  "), in a random direction from the equilibrium determined in part (a). \
Numerically evaluate the resulting motion for a time 5T and make a movie of \
the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " motion, plotting every ",
  Cell[BoxData[
      \(TraditionalForm\`0.1  T\)]],
  ". Is this motion stable (i.e., do the electrons remain near the \
equilibrium orbit)?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Repeat for a displacement from equilibrium of 0.3 ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["v",
    FontSlant->"Italic"],
  "). "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Repeat (a), (b), and (c) for lithium",
  StyleBox[", ",
    FontSlant->"Italic"],
  "nuclear charge 3",
  StyleBox["e",
    FontSlant->"Italic"],
  ", nuclear mass 7",
  Cell[BoxData[
      \(TraditionalForm\`m\_p\)]],
  ". The equilibrium now consists of three electrons arranged in an \
equilateral triangle around the nucleus. "
}], "Text"],

Cell[TextData[{
  StyleBox["(20)",
    FontWeight->"Bold"],
  " The great mass of the sun compared to that of the planets is essential to \
the long-term stability of the solar system.  By integrating the solar system \
equations four times for 1000 years, keeping the initial positions of the \
outer planets the same in each case, but taking larger masses for the planets \
by factors of 10 in each consecutive run, determine roughly how massive the \
sun must be, as a muliple of that of Jupiter,  in order to provide a stable \
equilibrium for outer-planet orbits over ",
  Cell[BoxData[
      \(TraditionalForm\`10\^3\)]],
  " years.  Perform the integration only for the outer planets, from Jupiter \
on out.  (Take care to check whether ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is giving accurate results over this long time period.)   "
}], "Text",
  CellTags->"i:76"],

Cell[TextData[{
  StyleBox["(21)",
    FontWeight->"Bold"],
  " An astronomer discovers that a minor  asteroid has been kicked through a \
collision into an unusual orbit. The asteroid is initially located somewhere \
between Mars and Jupiter, and  is heading at rather high speed into the inner \
solar system. As of January 1 , 2001 at 12 noon, the asteroid has velocity \
(11060, -9817, -744) ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["m",
            FontSlant->"Plain"], "/", 
          StyleBox["s",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " and  position (",
  Cell[BoxData[
      \(TraditionalForm\`\(-5.206\[Cross]\ 10\^11\)\)]],
  " , 3.124 \[Cross]",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  ", 6.142 \[Cross]",
  Cell[BoxData[
      \(TraditionalForm\`10\^10\)]],
  ") ",
  Cell[BoxData[
      FormBox[
        StyleBox["m",
          FontSlant->"Plain"], TraditionalForm]]],
  " (with respect to the solar system center of mass). Using the data of ",
  ButtonBox["Table 1.2",
    ButtonData:>"Table 1.2",
    ButtonStyle->"Hyperlink"],
  " and the molecular dynamics code, determine which planet this asteroid is \
going to strike by making a movie of the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-",
  StyleBox["y",
    FontSlant->"Italic"],
  " positions of all solar system bodies in ",
  ButtonBox["Table 1.2",
    ButtonData:>"Table 1.2",
    ButtonStyle->"Hyperlink"],
  "  over a 2-year period, including the asteroid. "
}], "Text",
  CellTags->"i:77"],

Cell[TextData[{
  StyleBox["(22)(a) ",
    FontWeight->"Bold"],
  "Modify the molecular dynamics code to allow for a drag force, so that \
equations of motion are of the form"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(m\_i\), " ", 
            FractionBox[
              RowBox[{\(\[DifferentialD]\^2\), 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}], \(\[DifferentialD]t\^2\),
              MultilineFunction->None]}], "=", 
          RowBox[{
            RowBox[{\(\[Sum]\+\(j = 1\[IndentingNewLine]
                  j \[NotEqual] i\)\%N\), 
              RowBox[{
                SubscriptBox[
                  StyleBox["F",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], \(i\ j\)], "(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "i"], "-", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "j"]}], ")"}]}], "-", 
            RowBox[{\(m\_i\), " ", "\[Gamma]", " ", 
              FractionBox[
                RowBox[{"\[DifferentialD]", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "i"]}], \(\[DifferentialD]t\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:74"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The Lennard-Jones potential is often used to model interatomic \
interactions classically. The form of the potential energy is ",
  Cell[BoxData[
      \(TraditionalForm\`V(r) = \[Epsilon](
          1\/\((r/a)\)\^12 - 2\/\((r/a)\)\^6)\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["a ",
    FontSlant->"Italic"],
  " is a distance scale and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is an energy scale. We are going to use molecular dynamics to determine \
the form of molecules that interact via the Lennard-Jones potential. To do \
so, start with ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " atoms distributed randomly in a cube with sides of length ",
  Cell[BoxData[
      \(TraditionalForm\`N\^\(1/3\)\)]],
  ".   Take ",
  Cell[BoxData[
      \(TraditionalForm\`a\  = \ \(m = \(\[Epsilon]\  = \ 1\)\)\)]],
  ".   Initially the atoms have zero velocities. Add some (small) damping to \
the motion of the atoms, and follow their motion until they fall into a \
minimum energy state."
}], "Text",
  CellTags->"i:71"],

Cell[TextData[{
  "(i) Construct the energy function. Then, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 0.05\)]],
  StyleBox[",  ",
    FontFamily->"Symbol"],
  " and  for ",
  Cell[BoxData[
      \(TraditionalForm\`N\  = \ 3, 4, 5, 6\)]],
  ","
}], "Text"],

Cell[TextData[{
  "(ii) follow the motion for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 100\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "(iii) Evaluate and plot  the energy vs. time.  Does it appear that an \
energy minimum has been achieved? For each ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-value, what is the minimum energy in units of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  StyleBox["? ",
    FontFamily->"Symbol"]
}], "Text"],

Cell[TextData[{
  "(iv) Use ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to plot the positions of the atoms. Can you describe the structure in \
words? "
}], "Text"],

Cell["\<\
(v) If a minimum has not yet been achieved, repeat the process \
using the final state of the previous simulation as the new initial \
condition.\
\>", "Text"],

Cell[TextData[{
  "(vi) The larger the molecule, the more local minimum-energy states there \
are. For ",
  Cell[BoxData[
      \(TraditionalForm\`N\  = \ 5\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`6\)]],
  ", repeat your simulations for ",
  Cell[BoxData[
      \(TraditionalForm\`five\)]],
  " different random initial conditions to see if you can find any other \
minimum energy states. How many did you find?"
}], "Text"],

Cell[TextData[{
  StyleBox["(23)",
    FontWeight->"Bold"],
  " Modify the molecular dynamics code to be able to handle applied magnetic \
and electric fields ",
  StyleBox["B",
    FontWeight->"Bold"],
  "(",
  StyleBox["r",
    FontWeight->"Bold"],
  ",t) and ",
  StyleBox["E",
    FontWeight->"Bold"],
  "(",
  StyleBox["r,",
    FontWeight->"Bold"],
  "t), and a damping force: The equations of motion are now\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{\(\[DifferentialD]\^2\), 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "i"]}], \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{
            RowBox[{\(\[Sum]\+\(j = 1\[IndentingNewLine]
                  j \[NotEqual] i\)\%N\), 
              RowBox[{
                SubscriptBox[
                  StyleBox["F",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "ij"], "(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "i"], "-", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "j"]}], ")"}]}], "+", 
            RowBox[{\(q\_i\), "(", 
              RowBox[{
                RowBox[{
                  StyleBox["E",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "i"], ",", "t"}], ")"}], "+", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["v",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "i"], "\[Cross]", 
                  RowBox[{
                    StyleBox["B",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "i"], ",", "t"}], ")"}]}]}], 
              ")"}], "+", " ", 
            RowBox[{\(m\_i\), " ", "\[Gamma]", " ", 
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"], " ", 
              FractionBox[\(\[DifferentialD]z\_i\), \(\[DifferentialD]t\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  "\n(The damping is allowed to work only on the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-motion.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Check that your new molecular dynamics code works by solving numerically \
for the motion of a single particle in a uniform electric and magnetic field \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((1, 0, 0)\)}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["B",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((0, 0, 1)\)}], TraditionalForm]]],
  ", taking ",
  StyleBox["m=q=",
    FontSlant->"Italic"],
  "1, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 0\)]],
  ", and ",
  StyleBox["r",
    FontWeight->"Bold"],
  " = ",
  StyleBox["v",
    FontWeight->"Bold"],
  " = 0 at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". Compare the numerical result from ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 10\)]],
  " with the analytic result of  ",
  ButtonBox["Sec. 1.3",
    ButtonData:>"Ex. 1.3",
    ButtonStyle->"Hyperlink"],
  ", Exercise (6)."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " A ",
  StyleBox["Penning trap",
    FontSlant->"Italic"],
  " is a trap for charged particles, which can hold the particles in vacuum, \
away from solid walls, using only static electric and magnetic fields. The \
trap works for particles that all have the same sign of charge. We will take \
all the charges to have charge 1 and mass 1, so that their potential \
interaction is ",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`V(r)\  = \ 1/r\)]],
  ".  The trap has the following applied electric and magnetic fields:"
}], "Text",
  CellTags->"i:72"],

Cell[TextData[{
  "\t\t",
  StyleBox["B",
    FontWeight->"Bold"],
  "=(0,0,5), ",
  StyleBox["E ",
    FontWeight->"Bold"],
  "=",
  StyleBox[" ",
    FontWeight->"Bold"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  "/2, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "/2, -",
  StyleBox["z",
    FontSlant->"Italic"],
  ").\nConsider four ions  given random initial ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["z",
    FontSlant->"Italic"],
  " velocities in the ranges -0.1 to 0.1, and positions ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 0, 1/4)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((1, 0, 0)\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\), 0, 0)\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 1, 0)\)\)]],
  ". Their ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\)\(-\)\)\)]],
  "motion is damped (using lasers) with rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 0.1\)]],
  ". (Only the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\)\(-\)\)\)]],
  "motion is damped; otherwise the ions would be lost from the trap because \
of the applied torque from the damping). Numerically integrate the motion of \
these ions until they settle into an equilibrium configuration. What is this \
configuration?  ",
  StyleBox["(Hint: make ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  Cell[BoxData[
      \(TraditionalForm\`x\  - y\)]],
  StyleBox[" images of the ion positions. The equilibrium will actually \
rotate at a constant rate around the origin due to the ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["E",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["\[Times]",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["B",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" drift [",
    FontColor->RGBColor[0, 0, 0.00389105]],
  ButtonBox["Sec. 1.3",
    ButtonData:>"Ex. 1.3",
    ButtonStyle->"Hyperlink"],
  StyleBox[", Exercise (6)].",
    FontColor->RGBColor[0, 0, 0.00389105]]
}], "Text"],

Cell[TextData[{
  StyleBox["(24)",
    FontWeight->"Bold"],
  " Consider a model of an elastic rod as a system of masses and springs.  \
The equilibrium of such a system is considered in ",
  ButtonBox["Sec. 9.10",
    ButtonData:>{"Chapter9.nb", "Ex. 9.10"},
    ButtonStyle->"Hyperlink"],
  ", Exercises (5) and (6), and is examined using an analytic model in  ",
  ButtonBox["Sec. 1.5",
    ButtonData:>"Ex. 1.5",
    ButtonStyle->"Hyperlink"],
  ", Exercise (1). Here we will examine the dynamics of this elastic rod, \
using the molecular dynamics method.  We will consider a system of ",
  Cell[BoxData[
      \(TraditionalForm\`M = 41\)]],
  " masses. In the absence of gravity, the  masses are arranged in \
equilibrium positions ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "i"], TraditionalForm]]],
  " , which are the same as in the statics problem of Sec. 9.10, Exercise ",
  ButtonBox["(5)",
    ButtonData:>{"Chapter9.nb", "i:89"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:73"],

Cell[BoxData[{
    \(p = a {1/2, 0}; \ q = a {0, Sqrt[3]/2};\), "\n", 
    \(\(R[i_]\  = \ \((i - 1)\)\ p\  + \ Mod[i, 2]\ q;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.66"],

Cell[TextData[{
  "As before, nearest neighbor masses ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " interact via the isotropic  force "
}], "Text"],

Cell[BoxData[
    \(F[i_, j_, \ 
        r_]\  := \ \(-k[i, j]\)\ \((r\  - a\ \ r/Sqrt[\ r . r])\)\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 1.67"],

Cell[TextData[{
  "The total force on mass ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is given by interactions with its four nearest neighbors, assuming that \
the mass is not at the ends of the rod:"
}], "Text"],

Cell[BoxData[
    \(Ftot[
        i_]\  := \ {0, \(-m\)\ g}\  + \ \ \ F[i, i - 2, 
          r[i, t] - r[i - 2, t]] + F[i, i - 1, r[i, t] - r[i - 1, t]]\  + 
        F[i, i + 1, r[i, t] - r[i + 1, t]]\  + \ 
        F[i, i + 2, r[i, t] - r[i + 2, t]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.68"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "i"], "(", "t", ")"}], TraditionalForm]]],
  " is the position of the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            StyleBox["i",
              FontSlant->"Italic"], "th"}]], TraditionalForm]]],
  " mass. The end masses are fixed to the walls:"
}], "Text"],

Cell[BoxData[{
    \(\(r[1, t_]\  = \ R[1];\)\), "\n", 
    \(\(r[2, t_]\  = \ R[2];\)\), "\n", 
    \(\(r[M, t_]\  = \ R[M];\)\), "\n", 
    \(\(r[M - 1, t_]\  = \ R[M - 1];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.69"],

Cell[TextData[{
  "\tModify the molecular dynamics code to handle this type of nearest \
neighbor force, and solve the following problem: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "i"], "(", \(t = 0\), ")"}], "=", 
          SubscriptBox[
            StyleBox["R",
              FontWeight->"Bold",
              FontSlant->"Plain"], "i"]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "i"], "(", \(t = 0\), ")"}], "=", "0"}], 
        TraditionalForm]]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, g = 0.5, \ k\_\(i\ j\) = 160\)]],
  ", over the time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 24\)]],
  ". [An analytic approach to  a similar problem can be found in  ",
  ButtonBox["Sec. 4.2",
    ButtonData:>{"Chapter4.nb", "Ex. 4.2"},
    ButtonStyle->"Hyperlink"],
  ", Exercise (7).]"
}], "Text"],

Cell[TextData[{
  StyleBox["(25)",
    FontWeight->"Bold"],
  " Use the molecular dynamics code and the data in Table ",
  ButtonBox["1.2",
    ButtonData:>"Table 1.2",
    ButtonStyle->"Hyperlink"],
  " to plot the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " velocities of the sun, ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(v\_x\)(t), \ \(v\_y\)(t))\)\)]],
  ",  as a parametric plot over the time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < \ 30\ years\)]],
  ". What is the magnitude of the maximum speed attained by the sun? This \
oscillatory motion has been discerned in distant stars through tiny \
oscillatory Doppler shifts in the starlight, providing indirect evidence for \
the existence of planetary systems beyond our own solar system [",
  ButtonBox["Marcy and Butler, (1998)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text",
  CellTags->"i:144"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["1.5 ",
    FontFamily->"Helvetica",
    FontSlant->"Plain"],
  StyleBox["Boundary-Value",
    FontSlant->"Plain"],
  StyleBox[" Problems",
    FontFamily->"Helvetica",
    FontSlant->"Plain"]
}], "Subtitle",
  FontSlant->"Italic",
  CellTags->{"Sec. 1.5", "i:79", "c:29"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.5.1 Introduction",
  FontFamily->"Helvetica"]], "Subsubtitle",
  CellTags->"c:30"],

Cell[TextData[{
  "In order to determine a unique solution to an initial-value problem for an \
",
  StyleBox["N",
    FontSlant->"Italic"],
  "th",
  "-order",
  " ODE, we have seen that ",
  StyleBox["N",
    FontSlant->"Italic"],
  " initial conditions must be specified. The ",
  StyleBox["N",
    FontSlant->"Italic"],
  " initial conditions are all given at the same point in time. "
}], "Text"],

Cell[TextData[{
  "\tBoundary-value problems differ from initial-value problems in that the \
",
  StyleBox["N",
    FontSlant->"Italic"],
  " conditions on the problem are provided at ",
  StyleBox["more than one point. ",
    FontSlant->"Italic"],
  " Typically they are given at starting and finishing points at, say, ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = T\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tAs a simple example of a boundary-value problem,  consider trying to hit \
a moving object with an arrow.  To further simplify the problem, let's assume \
that the arrow moves in a single dimension, vertically, under the influence \
only of gravity- no air drag or other forces will be kept. Then the position \
of the arrow, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  "), satisfies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 y\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", \(-g\)}], TraditionalForm]]],
  ","
}], "NE5",
  CellTags->"(1.5.1)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", " ", "=", " ", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  " is the acceleration of gravity. The arrow starts at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", and must be at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y\)\(=\)\(H\)\(\ \)\)\)]],
  "at ",
  Cell[BoxData[
      \(TraditionalForm\`t = T\)]],
  " in order to hit an object that passes overhead at that instant.  \
Therefore, the ",
  StyleBox["boundary",
    FontSlant->"Italic"],
  " ",
  StyleBox["conditions  ",
    FontSlant->"Italic"],
  "on the problem are",
  StyleBox[" ",
    FontSlant->"Italic"],
  " "
}], "Text",
  CellTags->"i:120"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`y(0)\  = \ 0, \ y(T)\  = \ H\)]]], "NE5",
  CellTags->"(1.5.2)"],

Cell[TextData[{
  "\tIn order to solve this problem, consider the general solution of ",
  ButtonBox["Eq. (1.5.1)",
    ButtonData:>"(1.5.1)",
    ButtonStyle->"Hyperlink"],
  ", determined by integrating the ODE twice :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(t) = C\_1 + C\_2\ t - \(g\ t\^2\)\/2\)]],
  "."
}], "NE5",
  CellTags->"(1.5.3)"],

Cell[TextData[{
  "We determine the constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " using the boundary conditions ",
  ButtonBox["(1.5.2)",
    ButtonData:>"(1.5.2)",
    ButtonStyle->"Hyperlink"],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`y(0)\  = \ 0\)]],
  ", ",
  ButtonBox["Eq. (1.5.3)",
    ButtonData:>"(1.5.3)",
    ButtonStyle->"Hyperlink"],
  " evaluated at",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t = 0\)\)\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " = 0. Since ",
  Cell[BoxData[
      \(TraditionalForm\`y(T)\  = \ H\)]],
  ", we find that  ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2 = \ H/T\  - \ g\ T\ /\ 2\)]],
  ",  yielding the following solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(
          t) = \((H\/T - \(g\ T\)\/2)\) t - \(g\ t\^2\)\/2\)]],
  "."
}], "NE5",
  CellTags->"(1.5.4)"],

Cell["\<\
\tFinding the solution of this boundary-value problem seems to be \
no different than finding the solution of an initial-value problem. However, \
there is a fundamental difference between these two types of problems: unlike \
solutions to initial-value problems that satisfy the conditions of Theorem \
1.1,\
\>", "Text"],

Cell["\<\
The solutions to boundary-value problems need not exist, and if \
they exist they need not be unique.\
\>", "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:17"],

Cell["\<\
\tIt is easy to find examples of boundary-value problems for which \
there is no solution. Consider the motion of a harmonic oscillator, whose \
position satisfies\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", \(\(-\[Omega]\_o\%2\)\ x\)}], 
        TraditionalForm]]],
  "."
}], "NE5",
  CellTags->"(1.5.5)"],

Cell[TextData[{
  "Let's again try to hit a passing object with this oscillator (an arrow \
attached to a spring?). The object is assumed to pass through the point ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " at a time ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ \[Pi]/\[Omega]\_o\)]],
  ". Starting the oscillator from the origin at ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "=0, the boundary conditions are"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 0, \ x(\[Pi]/\[Omega]\_o) = x\_o\)]],
  "."
}], "NE5",
  CellTags->"(1.5.6)"],

Cell[TextData[{
  "Using the first boundary condition in the general solution, given by ",
  ButtonBox["Eq. (1.1.7)",
    ButtonData:>"(1.1.7)",
    ButtonStyle->"Hyperlink"],
  ", implies that ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " = 0 and  ",
  Cell[BoxData[
      \(TraditionalForm\`x(t) = C\_2\ \(sin(\[Omega]\_o\ t)\)\)]],
  ". Now it seems like a simple task to find the value of ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " using the second boundary condition, as we did in the previous example. \
Unfortunately, however, we are faced with a dilemma: at the requested time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/\[Omega]\_o\)]],
  " ,  "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`x(\[Pi]/\[Omega]\_o) = \(\(C\_2\) sin\ \[Pi] = 
        0\)\)]]], "NE5",
  CellTags->"(1.5.7)"],

Cell[TextData[{
  "for ",
  StyleBox["all",
    FontSlant->"Italic"],
  " values of ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  ", so it is impossible to satisfy the second boundary condition.  \
Therefore, there is ",
  StyleBox["no",
    FontSlant->"Italic"],
  " solution to this ",
  "boundary-value",
  " problem."
}], "Text"],

Cell["\<\
\tIt is also easy to find boundary-value problems for which the \
solution is not unique. Consider again the previous harmonic oscillator \
problem, but this time take boundary conditions\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 0, \ x(T) = 0\)]],
  ","
}], "NE5",
  CellTags->"(1.5.8)"],

Cell[TextData[{
  "for some given time ",
  StyleBox["T",
    FontSlant->"Italic"],
  " : that is, we want the oscillator to pass back through the origin at time \
",
  StyleBox["T",
    FontSlant->"Italic"],
  ". Now, for most values of ",
  StyleBox["T",
    FontSlant->"Italic"],
  ", there is only one solution to this problem: the trivial solution ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\  = \ 0\)]],
  ", where the oscillator is stationary at the origin for all time. However, \
for special values of ",
  StyleBox["T",
    FontSlant->"Italic"],
  " there are other solutions. If ",
  Cell[BoxData[
      \(TraditionalForm\`T\  = \ n\ \[Pi]\ /\ \[Omega]\_o\)]],
  StyleBox[", ",
    FontFamily->"Symbol"],
  " for some integer ",
  StyleBox["n",
    FontSlant->"Italic"],
  ", the solution"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`x(t) = C\_2\ \(sin(\[Omega]\_o\ t)\)\)]]], "NE5",
  CellTags->"(1.5.9)"],

Cell[TextData[{
  "matches the boundary conditions  ",
  StyleBox["for any value of ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  ". Therefore, for these special values of ",
  StyleBox["T",
    FontSlant->"Italic"],
  ", the solution is not unique - in fact, there are an infinite number of \
solutions, corresponding to sine oscillations with arbitrary amplitude given \
by ",
  ButtonBox["Eq. (1.5.9)",
    ButtonData:>"(1.5.9)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tAnother way to do this problem is to hold the time ",
  StyleBox["T",
    FontSlant->"Italic"],
  " fixed and instead allow the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "to vary. For most values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  StyleBox[", ",
    FontFamily->"Symbol"],
  " the boundary conditions ",
  ButtonBox["(1.5.8)",
    ButtonData:>"(1.5.8)",
    ButtonStyle->"Hyperlink"],
  " are satisfied only for the trivial solution ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\  = \ 0\)]],
  ". But at values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  StyleBox["  ",
    FontFamily->"Symbol"],
  "given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = n\ \[Pi]/T\)]],
  ","
}], "NE5",
  CellTags->"(1.5.10)"],

Cell[TextData[{
  "the solution again is of the form of ",
  ButtonBox["Eq. (1.5.9)",
    ButtonData:>"(1.5.9)",
    ButtonStyle->"Hyperlink"],
  " with arbitrary amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe problem of determining the values of a parameter (such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  StyleBox[")",
    FontFamily->"Symbol"],
  " for which nontrivial (i.e. nonzero) solutions of a ",
  "boundary-value",
  " problem exist is referred to as an ",
  StyleBox["eigenvalue problem.",
    FontSlant->"Italic"],
  " "
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:80"],

Cell[TextData[{
  "\tThese problems are called eigenvalue problems because, as we will see, \
they are often equivalent to finding the eigenvalues of a matrix. (See Sec. \
",
  ButtonBox["6.3",
    ButtonData:>{"Chapter6.nb", "c:28"},
    ButtonStyle->"Hyperlink"],
  "). Eigenvalue problems turn out to be very important in the solution of \
linear PDEs, so we will return to a discussion of their solution in later \
chapters."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
1.5.2 Numerical Solution of Boundary-Value Problems: The Shooting \
Method\
\>", "Subsubtitle",
  CellTags->{"i:43", "c:31"}],

Cell[TextData[{
  StyleBox[" ",
    FontSlant->"Italic"],
  "For the simple cases discussed above, general analytic solutions to the \
ODEs could be found, and the boundary-value problem could be solved \
analytically (when the solution existed). However, we have already seen that \
there are many ODEs for which no general analytic solution can be found. In \
these cases numerical methods must be employed. This section will consider \
one method that can be used to find a numerical solution to a boundary-value \
problem: the ",
  StyleBox["shooting method",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell["\<\
\tAs an example of the shooting method, consider a general \
second-order ODE of the form\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[\(\[DifferentialD]\^2 y\), \(\[DifferentialD]t\^2\),
          MultilineFunction->None], "=", 
        RowBox[{"f", "(", 
          RowBox[{"t", ",", "y", ",", 
            FractionBox[\(\[DifferentialD]y\), \(\[DifferentialD]t\),
              MultilineFunction->None]}], ")"}]}], TraditionalForm]]]], "NE5",\

  CellTags->"(1.5.11)"],

Cell["and with boundary conditions", "Text",
  CellTags->"i:122"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(t\_o) = y\_o, y(t\_1) = y\_1\)]],
  "."
}], "NE5",
  CellTags->"(1.5.12)"],

Cell[TextData[{
  "We require the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(t)\)]],
  " between the initial time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " and the final time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  ". An example of such a problem would be our previous archery problem, but \
with an acceleration determined by the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIn attempting to solve this problem numerically, we run into an \
immediate difficulty. All of the numerical methods that have been described \
so far in this book have dealt with initial-value problems, where for ",
  StyleBox["given",
    FontSlant->"Italic"],
  " initial conditions, we take steps forward in time until the final time is \
reached. Here we don't know all of the required initial conditions, so we \
can't step forward in time. Although we are given ",
  Cell[BoxData[
      \(TraditionalForm\`y(t\_o)\)]],
  ", we don't know ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^\[Prime]\)(t\_o)\)]],
  ". ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", Euler's method, and the predictor corrector method all require the \
initial position ",
  StyleBox["and",
    FontSlant->"Italic"],
  " velocity in order to integrate this problem forward in time."
}], "Text"],

Cell["\<\
\tThe shooting method proposes the following solution to this \
difficulty: if you don't know all of the initial conditions, have a guess! \
Using the guess, integrate the solution forward, and see if it matches the \
second boundary condition. If it misses, adjust the guess and try again, \
iterating until the guess gives a solution that does match the second \
boundary condition. \
\>", "Text"],

Cell["\<\
\tYou can see immediately why this is called the shooting method: \
we are shooting an arrow, refining our guesses for the initial velocity until \
we make a hit at the required instant. \
\>", "Text"],

Cell[TextData[{
  "\tTo do this problem in ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " we will first define a function ",
  StyleBox["Sol[v0]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which solves the ",
  "initial-value",
  " problem taking ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^\[Prime]\)(t\_o) = v\_o\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(Sol[v0_] := 
      NDSolve[{\(y''\)[t] \[Equal] f[t, y[t], \(y'\)[t]], 
          y[t0] \[Equal] y0, \(y'\)[t0] \[Equal] v0}, 
        y, {t, t0, t1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.70"],

Cell[TextData[{
  "The result of evaluating this cell is an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that gives a solution for the chosen initial velocity ",
  StyleBox["v0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In the second argument of ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", we have specified that the unknown function is ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`y(t)\)]],
  ", so that the output will be in terms of a pure function. We will see that \
this slightly simplifies the code for the shooting method."
}], "Text"],

Cell[TextData[{
  "\t To see an example, we must first define the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  " and chose an initial time and position. Let us take for our example the \
problem of an arrow shot in the vertical direction, adding  a drag force due \
to air on the motion of the arrow. The acceleration of the arrow is taken as"
}], "Text"],

Cell[BoxData[{
    \(\(f[t_, y_, v_] := \(-g\) - \[Gamma]\ v;\)\), "\n", 
    \(g = 9.8; \ \[Gamma] = 0.1;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.71"],

Cell[TextData[{
  "We are working in units of meters and seconds. The added acceleration due \
to air drag is assumed to be a linear function of the velocity, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Gamma]\)\ \(v(t)\)\)]],
  ", and we have taken the drag coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " to equal ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0.1", " ", 
          FormBox[
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], \(-1\)],
            "TraditionalForm"]}], TraditionalForm]]],
  ". Also, to complete the problem we must choose initial and final times, \
and initial and final positions:"
}], "Text"],

Cell[BoxData[{
    \(t0 = 0; y0 = 0;\), "\n", 
    \(t1 = 1; y1 = 20;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.72"],

Cell[TextData[{
  "Then for a given initial velocity of, say , ",
  Cell[BoxData[
      FormBox[
        RowBox[{"30", " ", 
          RowBox[{
            StyleBox["m",
              FontSlant->"Plain"], "/", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ", the arrow's position ",
  "vs.",
  " time is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sol[30]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.73"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"y", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 1.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In Cell ",
  ButtonBox["1.74",
    ButtonData:>"Cell 1.74",
    ButtonStyle->"Hyperlink"],
  " we plot this ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to see how  close it comes to the required solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[y[t] /. %[\([1]\)], {t, 0, t1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.74"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.0247228 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13833 -6 -4.5 ]
[.01131 .13833 0 4.5 ]
[.01131 .26194 -12 -4.5 ]
[.01131 .26194 0 4.5 ]
[.01131 .38556 -12 -4.5 ]
[.01131 .38556 0 4.5 ]
[.01131 .50917 -12 -4.5 ]
[.01131 .50917 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13833 m
.03006 .13833 L
s
[(5)] .01131 .13833 1 0 Mshowa
.02381 .26194 m
.03006 .26194 L
s
[(10)] .01131 .26194 1 0 Mshowa
.02381 .38556 m
.03006 .38556 L
s
[(15)] .01131 .38556 1 0 Mshowa
.02381 .50917 m
.03006 .50917 L
s
[(20)] .01131 .50917 1 0 Mshowa
.125 Mabswid
.02381 .03944 m
.02756 .03944 L
s
.02381 .06416 m
.02756 .06416 L
s
.02381 .08888 m
.02756 .08888 L
s
.02381 .11361 m
.02756 .11361 L
s
.02381 .16305 m
.02756 .16305 L
s
.02381 .18777 m
.02756 .18777 L
s
.02381 .2125 m
.02756 .2125 L
s
.02381 .23722 m
.02756 .23722 L
s
.02381 .28667 m
.02756 .28667 L
s
.02381 .31139 m
.02756 .31139 L
s
.02381 .33611 m
.02756 .33611 L
s
.02381 .36083 m
.02756 .36083 L
s
.02381 .41028 m
.02756 .41028 L
s
.02381 .435 m
.02756 .435 L
s
.02381 .45973 m
.02756 .45973 L
s
.02381 .48445 m
.02756 .48445 L
s
.02381 .53389 m
.02756 .53389 L
s
.02381 .55862 m
.02756 .55862 L
s
.02381 .58334 m
.02756 .58334 L
s
.02381 .60806 m
.02756 .60806 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .04454 L
.10458 .07648 L
.14415 .10592 L
.18221 .13372 L
.22272 .16276 L
.26171 .19019 L
.30316 .21878 L
.34309 .24577 L
.3815 .27123 L
.42237 .29777 L
.46172 .3228 L
.49955 .34638 L
.53984 .37096 L
.57861 .39411 L
.61984 .41818 L
.65954 .44085 L
.69774 .46216 L
.73838 .48432 L
.77751 .50514 L
.81909 .52673 L
.85916 .54701 L
.89771 .56604 L
.93871 .58576 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00C03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D00000;03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool0:P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`0;03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0=@3oool400000003014A4@3oool0oooo00P0oooo001<0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00/
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool0:`3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R80;03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80=`3oool00`000000oooo0?ooo`0:0?ooo`00C03oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h0;@3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000/0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002`0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000=`3oool0
0`000000oooo0?ooo`0:0?ooo`00C03oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h0;03oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
;@3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0/0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c03L0oooo00<0
00000?ooo`3oool02P3oool004`0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002d0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`0;03oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00g0?ooo`030000
003oool0oooo00X0oooo001<0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0Z0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000]0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0^0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A03L0oooo00<000000?ooo`3oool02P3o
ool004`0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
;03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000;@3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0;P3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000g0?ooo`030000003oool0oooo00X0oooo001<
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02`0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02`0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4B`0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0=@3oool205EEE@030000003oool0oooo00X0oooo
003o0?ooofT0oooo000F0?ooo`030000003oool0oooo0?l0ooooD03oool001H0oooo00<000000?oo
o`3oool0o`3ooom@0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooe00oooo000F0?ooo`030000
003oool0oooo0?l0ooooD03oool001H0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`003P3ooooo
000005L00000103oool001H0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00X0oooo000F0?ooo`040000003oool0oooo000003d0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`005P3oool010000000oooo0?ooo`3oool20000
0?l0ooooC@3oool001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooodX0
oooo000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom90?ooo`005P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooB03oool001H0oooo00<00000
0?ooo`3oool01P3oool200000?l0ooooB03oool001H0oooo0P0000090?ooo`030000003oool0oooo
0?l0ooooA@3oool001H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oood@0
oooo000F0?ooo`030000003oool0oooo00X0oooo0P00003o0?oood@0oooo000F0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0o`3ooom10?ooo`005P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0oooo@03oool001H0oooo00<000000?ooo`3oool03P3oool20000
0?l0oooo@03oool001H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooocd0
oooo000F0?ooo`030000003oool0oooo0140oooo0P00003o0?ooocd0oooo000F0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`005P3oool2000001D0oooo00<00000
0?ooo`3oool0o`3oooli0?ooo`005P3oool00`000000oooo0?ooo`0E0?ooo`800000o`3oooli0?oo
o`005P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0oooo=P3oool001H0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooocD0oooo000F0?ooo`030000003o
ool0oooo01T0oooo0P00003o0?ooocD0oooo000F0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0o`3ooolb0?ooo`005P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0?l0oooo<@3oool001H0oooo00<000000?ooo`3oool07@3oool200000?l0oooo<@3oool001H0oooo
0P00000P0?ooo`030000003oool0oooo0?l0oooo;P3oool001H0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`3o0?ooobd0oooo000F0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0o`3oool/0?ooo`005P3oool00`000000oooo0?ooo`0R0?ooo`800000o`3oool/0?oo
o`005P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0oooo:@3oool001H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooobP0oooo000F0?ooo`030000003o
ool0oooo02H0oooo0P00003o0?ooobP0oooo000F0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0o`3ooolU0?ooo`005P3oool2000002X0oooo0P00003o0?ooobD0oooo000F0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`005P3oool00`000000oooo
0?ooo`0/0?ooo`800000o`3ooolR0?ooo`005P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0?l0oooo7`3oool001H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o
0?oooah0oooo000F0?ooo`030000003oool0oooo0300oooo0P00003o0?oooah0oooo000<0?ooo`05
04A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0?l0oooo6`3oool000l0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`0c0?ooo`80
0000o`3ooolK0?ooo`00403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0o`3ooolH0?ooo`003`3oool00`1gMgL0<c<c0?ooo`040?ooo`<00000=P3o
ool200000?l0oooo603oool000`0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00303oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00303oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo0P00003o0?oooa@0oooo000<0?ooo`@0
00001P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0oooo4@3oool001H0oooo
00<000000?ooo`3oool0?@3oool200000?l0oooo4@3oool001H0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`3o0?ooo`h0oooo000F0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0o`3oool=0?ooo`005P3oool200000480oooo0P00003o0?ooo`d0oooo000F0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`005P3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0?l0oooo2@3oool001H0oooo00<000000?ooo`3oool0A@3o
ool200000?l0oooo2@3oool001H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o
0?ooo`H0oooo000F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3oool50?oo
o`005P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo103oool001H0oooo
00<000000?ooo`3oool0BP3oool200000?l0oooo103oool001H0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`3o0?ooo`40oooo000F0?ooo`800000CP3oool00`000000oooo0?ooo`3o
0?ooo`005P3oool00`000000oooo0?ooo`1>0?ooo`800000o`3oool001H0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`3l0?ooo`005P3oool00`000000oooo0?ooo`1A0?ooo`800000
o03oool001H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3i0?ooo`005P3oool0
0`000000oooo0?ooo`1D0?ooo`800000n@3oool001H0oooo00<000000?ooo`3oool0EP3oool20000
0?L0oooo000F0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0m03oool001H0oooo
0P00001J0?ooo`800000m03oool001H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`3a0?ooo`005P3oool00`000000oooo0?ooo`1L0?ooo`800000l@3oool001H0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`3^0?ooo`005P3oool00`000000oooo0?ooo`1O0?ooo`80
0000kP3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3[0?ooo`005P3o
ool00`000000oooo0?ooo`1R0?ooo`800000j`3oool001H0oooo00<000000?ooo`3oool0I03oool2
00000>T0oooo000F0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0iP3oool001H0
oooo0P00001X0?ooo`800000iP3oool001H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`3S0?ooo`005P3oool00`000000oooo0?ooo`1Z0?ooo`800000h`3oool001H0oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`3P0?ooo`005P3oool00`000000oooo0?ooo`1]0?oo
o`800000h03oool000@0oooo10000000200A4A40oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^1P3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0=d0oooo00060?ooo`030000003oool0
oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`060?ooo`030000003oool0oooo0700oooo0P00
003M0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0=X0oooo00060?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000L`3oool00`000000oooo0?oo
o`3I0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`1d0?ooo`800000f@3oool000H0oooo00<000000?ooo`3oool00P3oool0
1@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`3F0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3o
ool00`000000oooo0?ooo`1g0?ooo`800000eP3oool000@0oooo0P1EEED00`000000oooo0?ooo`02
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo0=<0oooo000F0?ooo`030000003oool0oooo07X0oooo0P00003C0?ooo`005P3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0=00oooo000F0?ooo`030000003oool0oooo07d0
oooo0P00003@0?ooo`005P3oool200000800oooo0P00003>0?ooo`005P3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0</0oooo000F0?ooo`030000003oool0oooo0880oooo0P00003;
0?ooo`005P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0<P0oooo000F0?ooo`03
0000003oool0oooo08D0oooo0P0000380?ooo`005P3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo0<D0oooo000F0?ooo`030000003oool0oooo08P0oooo0P0000350?ooo`005P3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0<80oooo000F0?ooo`030000003oool0oooo
08/0oooo0P0000320?ooo`005P3oool2000008h0oooo0P0000300?ooo`005P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo0;d0oooo000F0?ooo`030000003oool0oooo0900oooo0P00
002m0?ooo`005P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;X0oooo000F0?oo
o`030000003oool0oooo09<0oooo0P00002j0?ooo`005P3oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo0;L0oooo000F0?ooo`030000003oool0oooo09H0oooo0P00002g0?ooo`005P3o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0;@0oooo000F0?ooo`800000VP3oool2
00000;@0oooo000F0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0/@3oool001H0
oooo00<000000?ooo`3oool0W03oool200000;40oooo000F0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0[P3oool001H0oooo00<000000?ooo`3oool0W`3oool200000:h0oooo000F
0?ooo`030000003oool0oooo0:40oooo0P00002/0?ooo`005P3oool00`000000oooo0?ooo`2S0?oo
o`030000003oool0oooo0:T0oooo000F0?ooo`030000003oool0oooo0:@0oooo0P00002Y0?ooo`00
5P3oool00`000000oooo0?ooo`2V0?ooo`800000Y`3oool001H0oooo0P00002Y0?ooo`800000Y@3o
ool001H0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2R0?ooo`005P3oool00`00
0000oooo0?ooo`2[0?ooo`800000XP3oool001H0oooo00<000000?ooo`3oool0[@3oool200000:00
oooo000F0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0W@3oool001H0oooo00<0
00000?ooo`3oool0/03oool2000009d0oooo00040?ooo`@0000000D04A4A0?ooo`3oool0oooo04A4
A0020000000303<c<`3MgMd0oooo00@0oooo00<000000?ooo`3oool0/P3oool2000009/0oooo0006
0?ooo`030000003oool0oooo00H0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo09P0oooo00060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool300000;D0oooo0P00002H0?ooo`001P3oool00`000000oooo0?ooo`060?ooo`03
07MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0]`3oool2000009H0oooo00060?ooo`030000
003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0T`3oool000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0;X0oooo0P00002C0?ooo`001P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0_03oool200000940oooo0004
0?ooo`80EEEE00<000000?ooo`3oool00`3oool4000000H0oooo00<000000?ooo`3oool0_P3oool0
0`000000oooo0?ooo`2>0?ooo`005P3oool00`000000oooo0?ooo`2o0?ooo`800000SP3oool001H0
oooo00<000000?ooo`3oool0`@3oool2000008`0oooo000F0?ooo`030000003oool0oooo0<<0oooo
0P00002:0?ooo`005P3oool200000<H0oooo00<000000?ooo`3oool0Q`3oool001H0oooo00<00000
0?ooo`3oool0aP3oool2000008L0oooo000F0?ooo`030000003oool0oooo0<P0oooo0P0000250?oo
o`005P3oool00`000000oooo0?ooo`3:0?ooo`800000P`3oool001H0oooo00<000000?ooo`3oool0
c03oool00`000000oooo0?ooo`200?ooo`005P3oool00`000000oooo0?ooo`3=0?ooo`800000P03o
ool001H0oooo00<000000?ooo`3oool0c`3oool2000007h0oooo000F0?ooo`030000003oool0oooo
0=40oooo0P00001l0?ooo`005P3oool200000=@0oooo00<000000?ooo`3oool0N@3oool001H0oooo
00<000000?ooo`3oool0e03oool2000007T0oooo000F0?ooo`030000003oool0oooo0=H0oooo0P00
001g0?ooo`005P3oool00`000000oooo0?ooo`3H0?ooo`800000M@3oool001H0oooo00<000000?oo
o`3oool0fP3oool2000007<0oooo000F0?ooo`030000003oool0oooo0=`0oooo0P00001a0?ooo`00
5P3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo06h0oooo000F0?ooo`030000003o
ool0oooo0=l0oooo0P00001^0?ooo`005P3oool200000>80oooo0P00001/0?ooo`005P3oool00`00
0000oooo0?ooo`3S0?ooo`800000JP3oool001H0oooo00<000000?ooo`3oool0i@3oool2000006P0
oooo000F0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0I@3oool001H0oooo00<0
00000?ooo`3oool0j03oool2000006D0oooo000F0?ooo`030000003oool0oooo0>X0oooo0P00001S
0?ooo`005P3oool00`000000oooo0?ooo`3/0?ooo`800000H@3oool001H0oooo00<000000?ooo`3o
ool0kP3oool00`000000oooo0?ooo`1N0?ooo`005P3oool00`000000oooo0?ooo`3_0?ooo`800000
GP3oool001H0oooo0P00003b0?ooo`800000G03oool001H0oooo00<000000?ooo`3oool0l`3oool2
000005X0oooo000F0?ooo`030000003oool0oooo0?D0oooo0P00001H0?ooo`005P3oool00`000000
oooo0?ooo`3g0?ooo`800000EP3oool001H0oooo00<000000?ooo`3oool0n@3oool00`000000oooo
0?ooo`1C0?ooo`005P3oool00`000000oooo0?ooo`3j0?ooo`800000D`3oool000<0oooo1@000003
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`3l0?ooo`800000D@3o
ool000<0oooo00D0VIVI028R8P3^k^h0oooo04A4A0030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0
1P3oool00`000000oooo0?ooo`3n0?ooo`800000C`3oool000@0oooo00<0VIVI028R8P3^k^h0103o
ool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo0`00003o0?ooo`40oooo0P00001=0?ooo`001@3o
ool00`2IVIT08R8R0>k^kP030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo0P00001;0?ooo`001P3oool00`1gMgL0IVIV0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo0P0000190?ooo`001`3o
ool01@000000oooo0?ooo`3oool04A4A00<0oooo00<04A4A0?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?ooo`L0oooo0P0000170?ooo`000`3oool01@000000^k^k0?ooo`2IVIT04A4A00<0oooo
00D0MgMg09VIV@3oool0VIVI07MgM`060?ooo`030000003oool0oooo0?l0oooo2@3oool2000004D0
oooo00030?ooo`0509VIV@0A4A400000028R8P3<c<`00`3oool01@3^k^h0<c<c0000000c<c<0k^k^
00H0oooo00<000000?ooo`3oool0o`3oool;0?ooo`800000@`3oool001H0oooo00<000000?ooo`3o
ool0o`3oool=0?ooo`800000@@3oool001H0oooo00<000000?ooo`3oool0o`3oool?0?ooo`800000
?`3oool001H0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`800000?@3oool001H0oooo0P00003o
0?oooa@0oooo0P00000k0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooaD0oooo0P00000i0?oo
o`005P3oool00`000000oooo0?ooo`3o0?oooaL0oooo0P00000g0?ooo`005P3oool00`000000oooo
0?ooo`3o0?oooaT0oooo0P00000e0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooa/0oooo0P00
000c0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooad0oooo0P00000a0?ooo`005P3oool00`00
0000oooo0?ooo`3o0?oooal0oooo0P00000_0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooob40
oooo0P00000]0?ooo`005P3oool200000?l0oooo903oool00`000000oooo0?ooo`0Z0?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooob@0oooo0P00000Z0?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooobH0oooo0P00000X0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooobP0oooo0P00000V0?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooobX0oooo0`00000S0?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooobd0oooo0P00000Q0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooobl0oooo0P00
000O0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooc40oooo0`00000L0?ooo`005P3oool00`00
0000oooo0?ooo`3o0?oooc@0oooo0P00000J0?ooo`005P3oool200000?l0oooo=`3oool2000001P0
oooo000F0?ooo`030000003oool0oooo0?l0oooo>03oool2000001H0oooo000F0?ooo`030000003o
ool0oooo0?l0oooo>P3oool2000001@0oooo000F0?ooo`030000003oool0oooo0?l0oooo?03oool3
00000140oooo000F0?ooo`030000003oool0oooo0?l0oooo?`3oool2000000l0oooo000F0?ooo`03
0000003oool0oooo0?l0oooo@@3oool2000000d0oooo000F0?ooo`030000003oool0oooo0?l0oooo
@`3oool00`000000oooo0?ooo`0:0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooe00oooo000F
0?ooo`800000o`3ooomA0?ooo`005P3oool00`000000oooo0?ooo`3o0?oooe00oooo000F0?ooo`03
0000003oool0oooo0?l0ooooD03oool001H0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The plot shows that we have overshot the mark,  reaching somewhat higher \
than 20m at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  " s. We need to lower the initial velocity a bit. Of course, we could do \
this by hand, and by making several attempts eventually we would obtain the \
required boundary conditions. However, it is easier to automate this process. \
"
}], "Text"],

Cell[TextData[{
  "\tLet us define a function ",
  StyleBox["yend[v0]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the solution at the final time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(yend[v0_] := \ y[t1] /. \(Sol[v0]\)[\([1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.75"],

Cell[TextData[{
  "We can test whether this function is working by trying it out for the case \
of ",
  StyleBox["v0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "=30m/s:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yend[30]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.76"],

Cell[BoxData[
    \(23.808101944374013`\)], "Output"]
}, Open  ]],

Cell["\<\
This value appears to agree with the  trajectory  plotted  above.\
\
\>", "Text"],

Cell[TextData[{
  "\tNow we can apply the ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to solve the equation ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(yend[v0] == \ y1\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ". To do so, we will need to provide ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with ",
  StyleBox["two ",
    FontSlant->"Italic"],
  " initial guesses for ",
  StyleBox["v0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", since the function ",
  StyleBox["ysol[v0]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not analytically  differentiable (see ",
  ButtonBox["Sec. 9.11",
    ButtonData:>{"Chapter9.nb", "Sec. 9.11"},
    ButtonStyle->"Hyperlink"],
  "). Since ",
  StyleBox["v0=30",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " almost worked, we'll try two guesses near that:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[yend[v0] \[Equal] y1, {v0, 30, 29}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.77"],

Cell[BoxData[
    \({v0 \[Rule] 25.998319849538465`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus,  a throw of about 26 m/s will hit the mark at 20 m height after one \
second.  The trajectory is displayed in Cell ",
  ButtonBox["1.78",
    ButtonData:>"Cell 1.78",
    ButtonStyle->"Hyperlink"],
  " by evaluating ",
  StyleBox["Sol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at this velocity and plotting the resulting function:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ysol = y /. \(Sol[v0 /. %\ ]\)[\([1]\)];\)\), "\n", 
    \(\(Plot[ysol[t], {t, 0, t1}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.78"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.0294302 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16187 -6 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -12 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(5)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(10)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(15)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(20)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .04545 L
.10458 .0783 L
.14415 .1085 L
.18221 .13695 L
.22272 .16661 L
.26171 .19455 L
.30316 .22359 L
.34309 .25094 L
.3815 .27666 L
.42237 .3034 L
.46172 .32853 L
.49955 .35214 L
.53984 .37668 L
.57861 .3997 L
.61984 .42356 L
.65954 .44594 L
.69774 .46689 L
.73838 .4886 L
.77751 .50891 L
.81909 .52988 L
.85916 .54947 L
.89771 .56776 L
.93871 .58662 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00C03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D00000;03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A
0?ooo`3oool0:P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c
<c<00000014A4@3<c<`0;03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`05
0<c<c00R8R800000028R8P3<c<`0=@3oool400000003014A4@3oool0oooo00P0oooo001<0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A00/
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool0:`3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R
8R80;03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo
09VIV@0R8R80=`3oool00`000000oooo0?ooo`0:0?ooo`00C03oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<0VIVI028R8P3^k^h0;@3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@00
000/0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000002`0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`000000=`3oool0
0`000000oooo0?ooo`0:0?ooo`00C03oool01@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI
028R8P3^k^h0;03oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
;@3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P0/0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c03L0oooo00<0
00000?ooo`3oool02P3oool004`0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1V
IVH0oooo02/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000002d0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<c<`0;03oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c00g0?ooo`030000
003oool0oooo00X0oooo001<0?ooo`05014A4@3oool0oooo0?ooo`0A4A403`3oool00`000000oooo
0?ooo`0Z0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000000]0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`0^0?ooo`05014A4@3oool0oooo
0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A03L0oooo00<000000?ooo`3oool02P3o
ool004`0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A40
;03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000;@3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0;P3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00/0oooo00D000000;^k^`3oool0^k^k0000000g0?ooo`030000003oool0oooo00X0oooo001<
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<02`0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0=0?ooo`0307MgM`000000oooo02`0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4B`0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0=@3oool205EEE@030000003oool0oooo00X0oooo
003o0?ooofT0oooo000G0?ooo`030000003oool0oooo0?l0ooooC`3oool001L0oooo00<000000?oo
o`3oool0o`3ooom?0?ooo`005`3oool00`000000oooo0?ooo`3o0?ooodl0oooo000G0?ooo`030000
003oool0oooo0?l0ooooC`3oool001L0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`003P3ooooo
000005L00000103oool001L0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00X0oooo000G0?ooo`040000003oool0oooo000003`0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`005`3oool010000000oooo0?ooo`3oool20000
0?l0ooooC03oool001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooodT0
oooo000G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom80?ooo`005`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooA`3oool001L0oooo00<00000
0?ooo`3oool01P3oool200000?l0ooooA`3oool001L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3o0?oood@0oooo000G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0o`3ooom30?ooo`005`3oool2000000/0oooo0P00003o0?oood<0oooo000G0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0o`3ooom00?ooo`005`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0oooo?`3oool001L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`3o0?oooch0oooo000G0?ooo`030000003oool0oooo00l0oooo0P00003o0?oooch0
oooo000G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooolk0?ooo`005`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo>P3oool001L0oooo00<00000
0?ooo`3oool04`3oool200000?l0oooo>P3oool001L0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`3o0?ooocL0oooo000G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0o`3ooolf0?ooo`005`3oool2000001P0oooo00<000000?ooo`3oool0o`3ooole0?ooo`005`3o
ool00`000000oooo0?ooo`0H0?ooo`800000o`3ooole0?ooo`005`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0?l0oooo<P3oool001L0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`3o0?oooc40oooo000G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0o`3oool`0?ooo`005`3oool00`000000oooo0?ooo`0M0?ooo`800000o`3oool`0?ooo`005`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo;@3oool001L0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooob`0oooo000G0?ooo`030000003oool0oooo
0240oooo0P00003o0?ooob`0oooo000G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0o`3ooolY0?ooo`005`3oool2000002D0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`005`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo9`3oool001L0oooo00<00000
0?ooo`3oool09P3oool200000?l0oooo9`3oool001L0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`3o0?ooob@0oooo000G0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0o`3ooolS0?ooo`005`3oool00`000000oooo0?ooo`0Z0?ooo`800000o`3ooolS0?ooo`005`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo803oool001L0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oooal0oooo000G0?ooo`030000003oool0oooo
02h0oooo0P00003o0?oooal0oooo000G0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`005`3oool200000380oooo00<000000?ooo`3oool0o`3ooolK0?ooo`005`3o
ool00`000000oooo0?ooo`0b0?ooo`800000o`3ooolK0?ooo`005`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0?l0oooo603oool001L0oooo00<000000?ooo`3oool0=@3oool20000
0?l0oooo603oool001L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?oooaD0
oooo000G0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`005`3o
ool00`000000oooo0?ooo`0i0?ooo`800000o`3ooolD0?ooo`00303oool01@14A4@000000000000c
<c<0gMgM00H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?oooa40oooo000?
0?ooo`0307MgM`0c<c<0oooo00D0oooo00<000000?ooo`3oool0?03oool200000?l0oooo4@3oool0
0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
0?l0oooo3P3oool000l0oooo00<0MgMg03<c<`3oool01@3oool3000003l0oooo00<000000?ooo`3o
ool0o`3oool=0?ooo`00303oool01@0000008R8R0000000c<c<0c<c<00H0oooo00<000000?ooo`3o
ool0@03oool200000?l0oooo3@3oool000`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo0?l0oooo2P3oool000`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`130?ooo`800000o`3oool:0?ooo`00303oool4000000L0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000G0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0o`3oool60?ooo`005`3oool00`000000oooo0?ooo`170?ooo`80
0000o`3oool60?ooo`005`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo
0`3oool001L0oooo00<000000?ooo`3oool0BP3oool200000?l0oooo0`3oool001L0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooo`005`3oool2000004h0oooo00<000000?oo
o`3oool0oP3oool001L0oooo00<000000?ooo`3oool0CP3oool200000?h0oooo000G0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool0n`3oool001L0oooo00<000000?ooo`3oool0D@3o
ool200000?/0oooo000G0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0n03oool0
01L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3g0?ooo`005`3oool00`000000
oooo0?ooo`1E0?ooo`800000m`3oool001L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3d0?ooo`005`3oool00`000000oooo0?ooo`1H0?ooo`800000m03oool001L0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`3a0?ooo`005`3oool2000005`0oooo00<000000?oo
o`3oool0l03oool001L0oooo00<000000?ooo`3oool0G03oool200000?00oooo000G0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0k@3oool001L0oooo00<000000?ooo`3oool0G`3o
ool200000>d0oooo000G0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0jP3oool0
01L0oooo00<000000?ooo`3oool0HP3oool200000>X0oooo000G0?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0i`3oool001L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`3V0?ooo`005`3oool00`000000oooo0?ooo`1V0?ooo`800000iP3oool001L0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`3S0?ooo`005`3oool2000006X0oooo0P00003S0?oo
o`005`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0>00oooo000G0?ooo`030000
003oool0oooo06`0oooo0P00003P0?ooo`005`3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo0=d0oooo000G0?ooo`030000003oool0oooo06l0oooo0P00003M0?ooo`005`3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0=X0oooo000G0?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0f@3oool001L0oooo00<000000?ooo`3oool0L`3oool200000=T0oooo
000G0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0eP3oool001L0oooo00<00000
0?ooo`3oool0MP3oool200000=H0oooo000G0?ooo`800000N@3oool00`000000oooo0?ooo`3C0?oo
o`005`3oool00`000000oooo0?ooo`1i0?ooo`800000d`3oool001L0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`3@0?ooo`005`3oool00`000000oooo0?ooo`1l0?ooo`800000d03o
ool001L0oooo00<000000?ooo`3oool0OP3oool200000<h0oooo000G0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0b`3oool001L0oooo00<000000?ooo`3oool0P@3oool200000</0
oooo00040?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kPL0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`380?ooo`001P3oool00`000000oooo0?ooo`020?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL01`3oool00`000000oooo0?ooo`240?ooo`800000b03oool0
00H0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A00L0oooo00<00000
0?ooo`3oool0QP3oool200000<H0oooo00060?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000070?ooo`<00000R03oool00`000000oooo0?ooo`330?ooo`001P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`29
0?ooo`800000``3oool000H0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool0
4A4A00L0oooo00<000000?ooo`3oool0R`3oool200000<40oooo00060?ooo`030000003oool0oooo
0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`070?ooo`030000003oool0oooo08d0oooo0P00002o
0?ooo`00103oool205EEE@030000003oool0oooo0080oooo00D0k^k^03<c<`000000<c<c0>k^kP07
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0_03oool001L0oooo00<000000?oo
o`3oool0T03oool200000;`0oooo000G0?ooo`030000003oool0oooo0980oooo0P00002j0?ooo`00
5`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0;L0oooo000G0?ooo`030000003o
ool0oooo09D0oooo0P00002g0?ooo`005`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo0;@0oooo000G0?ooo`800000V@3oool200000;@0oooo000G0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0/@3oool001L0oooo00<000000?ooo`3oool0V`3oool200000;40oooo
000G0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0[P3oool001L0oooo00<00000
0?ooo`3oool0WP3oool200000:h0oooo000G0?ooo`030000003oool0oooo0:00oooo00<000000?oo
o`3oool0Z`3oool001L0oooo00<000000?ooo`3oool0X@3oool200000:/0oooo000G0?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`3oool0Z03oool001L0oooo00<000000?ooo`3oool0Y03o
ool200000:P0oooo000G0?ooo`030000003oool0oooo0:H0oooo0P00002V0?ooo`005`3oool20000
0:T0oooo00<000000?ooo`3oool0X`3oool001L0oooo00<000000?ooo`3oool0Z@3oool200000:<0
oooo000G0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0X03oool001L0oooo00<0
00000?ooo`3oool0[03oool200000:00oooo000G0?ooo`030000003oool0oooo0:h0oooo00<00000
0?ooo`3oool0W@3oool001L0oooo00<000000?ooo`3oool0[`3oool2000009d0oooo000G0?ooo`03
0000003oool0oooo0;40oooo0P00002K0?ooo`005`3oool00`000000oooo0?ooo`2c0?ooo`030000
003oool0oooo09P0oooo000G0?ooo`030000003oool0oooo0;@0oooo0P00002H0?ooo`005`3oool0
0`000000oooo0?ooo`2f0?ooo`800000UP3oool001L0oooo0P00002i0?ooo`030000003oool0oooo
09<0oooo000G0?ooo`030000003oool0oooo0;T0oooo0P00002C0?ooo`005`3oool00`000000oooo
0?ooo`2k0?ooo`800000T@3oool001L0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`2>0?ooo`005`3oool00`000000oooo0?ooo`2n0?ooo`800000SP3oool001L0oooo00<000000?oo
o`3oool0`03oool2000008`0oooo000G0?ooo`030000003oool0oooo0<80oooo0P00002:0?ooo`00
5`3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo08L0oooo000G0?ooo`030000003o
ool0oooo0<D0oooo0P0000270?ooo`005`3oool00`000000oooo0?ooo`370?ooo`800000Q@3oool0
01L0oooo0P00003:0?ooo`800000P`3oool001L0oooo00<000000?ooo`3oool0b`3oool200000840
oooo000G0?ooo`030000003oool0oooo0<d0oooo0P00001o0?ooo`005`3oool00`000000oooo0?oo
o`3?0?ooo`800000O@3oool001L0oooo00<000000?ooo`3oool0d@3oool2000007/0oooo000G0?oo
o`030000003oool0oooo0=<0oooo0P00001i0?ooo`005`3oool00`000000oooo0?ooo`3E0?ooo`80
0000M`3oool000@0oooo100000001@0A4A40oooo0?ooo`3oool0A4A40080000000<0<c<c0=gMg@3o
ool01@3oool00`000000oooo0?ooo`3G0?ooo`800000M@3oool000H0oooo00<000000?ooo`3oool0
1P3oool00`1gMgL0<c<c0?ooo`050?ooo`030000003oool0oooo0=T0oooo0P00001c0?ooo`001P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0f`3o
ool200000740oooo00060?ooo`030000003oool0oooo00H0oooo00<0MgMg03<c<`3oool01@3oool3
00000=d0oooo00<000000?ooo`3oool0KP3oool000H0oooo00<000000?ooo`3oool00`3oool01@00
00008R8R0000000c<c<0c<c<00H0oooo00<000000?ooo`3oool0gP3oool2000006h0oooo00060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3P0?oo
o`800000K03oool000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0>80oooo0P00001Z0?ooo`00103oool205EEE@030000003oool0oooo00<0oooo
100000070?ooo`030000003oool0oooo0>@0oooo0P00001X0?ooo`005`3oool00`000000oooo0?oo
o`3V0?ooo`030000003oool0oooo06D0oooo000G0?ooo`030000003oool0oooo0>L0oooo0P00001U
0?ooo`005`3oool00`000000oooo0?ooo`3Y0?ooo`800000H`3oool001L0oooo00<000000?ooo`3o
ool0j`3oool200000640oooo000G0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool0
GP3oool001L0oooo0P00003_0?ooo`800000GP3oool001L0oooo00<000000?ooo`3oool0l03oool2
000005`0oooo000G0?ooo`030000003oool0oooo0?80oooo0P00001J0?ooo`005`3oool00`000000
oooo0?ooo`3d0?ooo`800000F03oool001L0oooo00<000000?ooo`3oool0mP3oool2000005H0oooo
000G0?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3oool0D`3oool001L0oooo00<00000
0?ooo`3oool0n@3oool2000005<0oooo000G0?ooo`030000003oool0oooo0?/0oooo0P00001A0?oo
o`005`3oool00`000000oooo0?ooo`3m0?ooo`800000C`3oool001L0oooo00<000000?ooo`3oool0
o`3oool2000004d0oooo000G0?ooo`800000o`3oool30?ooo`800000B`3oool001L0oooo00<00000
0?ooo`3oool0o`3oool40?ooo`800000B@3oool001L0oooo00<000000?ooo`3oool0o`3oool60?oo
o`800000A`3oool001L0oooo00<000000?ooo`3oool0o`3oool80?ooo`800000A@3oool001L0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`800000@`3oool001L0oooo00<000000?ooo`3oool0o`3o
ool<0?ooo`800000@@3oool001L0oooo00<000000?ooo`3oool0o`3oool>0?ooo`800000?`3oool0
01L0oooo00<000000?ooo`3oool0o`3oool@0?ooo`800000?@3oool001L0oooo00<000000?ooo`3o
ool0o`3ooolB0?ooo`800000>`3oool001L0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`800000
>@3oool001L0oooo0P00003o0?oooaL0oooo0P00000g0?ooo`005`3oool00`000000oooo0?ooo`3o
0?oooaP0oooo0P00000e0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooaX0oooo0P00000c0?oo
o`005`3oool00`000000oooo0?ooo`3o0?oooa`0oooo0P00000a0?ooo`005`3oool00`000000oooo
0?ooo`3o0?oooah0oooo0P00000_0?ooo`005`3oool00`000000oooo0?ooo`3o0?ooob00oooo0`00
000/0?ooo`005`3oool00`000000oooo0?ooo`3o0?ooob<0oooo0P00000Z0?ooo`005`3oool00`00
0000oooo0?ooo`3o0?ooobD0oooo0P00000X0?ooo`005`3oool00`000000oooo0?ooo`3o0?ooobL0
oooo0P00000V0?ooo`005`3oool00`000000oooo0?ooo`3o0?ooobT0oooo0`00000S0?ooo`005`3o
ool200000?l0oooo;@3oool200000240oooo000G0?ooo`030000003oool0oooo0?l0oooo;P3oool2
000001l0oooo000G0?ooo`030000003oool0oooo0?l0oooo<03oool3000001`0oooo000G0?ooo`03
0000003oool0oooo0?l0oooo<`3oool2000001X0oooo000G0?ooo`030000003oool0oooo0?l0oooo
=@3oool2000001P0oooo000G0?ooo`030000003oool0oooo0?l0oooo=`3oool2000001H0oooo000G
0?ooo`030000003oool0oooo0?l0oooo>@3oool2000001@0oooo00030?ooo`D000000`3oool01@3^
k^h0<c<c0000000c<c<0k^k^00L0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`<000004@3oool0
00<0oooo00D0VIVI028R8P3^k^h0oooo04A4A0030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01`3o
ool00`000000oooo0?ooo`3o0?oooch0oooo0P00000?0?ooo`00103oool00`2IVIT08R8R0>k^kP04
0?ooo`05014A4@3oool0oooo0?ooo`0A4A401`3oool00`000000oooo0?ooo`3o0?oood00oooo0P00
000=0?ooo`001@3oool00`2IVIT08R8R0>k^kP030?ooo`050000003oool0oooo0?ooo`0000001`3o
ool300000?l0oooo@P3oool00`000000oooo0?ooo`0:0?ooo`001P3oool00`1gMgL0IVIV0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3o0?ooodl0oooo0007
0?ooo`050000003oool0oooo0?ooo`0A4A400`3oool00`0A4A40oooo0?ooo`050?ooo`030000003o
ool0oooo0?l0ooooC`3oool000<0oooo00D000000;^k^`3oool0VIVI014A4@030?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL01`3oool00`000000oooo0?ooo`3o0?ooodl0oooo00030?ooo`0509VIV@0A
4A400000028R8P3<c<`00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00L0oooo00<000000?ooo`3o
ool0o`3ooom?0?ooo`005`3oool00`000000oooo0?ooo`3o0?ooodl0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}]
}, Open  ]],

Cell["\<\
\tIn this example of the shooting method, we found one solution to \
the boundary-value problem. How do we know that there are no other solutions? \
We don't . There could be other solutions that would be found if we made \
different choices for the initial velocity. (Actually, in this particular \
problem, one can show analytically that the above solution is unique, but for \
other problems this is not the case; see the exercises.)\
\>", "Text"],

Cell["\tThis points out a major weakness in the shooting method: ", "Text"],

Cell["\<\
The shooting method only finds one solution at a time. To find a \
solution, reasonably accurate initial guesses must be made. Thus, it is \
possible to miss valid solutions to a boundary-value problem when using the \
shooting method.\
\>", "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercises for Sec. 1.5",
  FontFamily->"Helvetica"]], "Subsubtitle",
  CellTags->{"Ex. 1.5", "c:32"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " A thin rod of length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  "  and mass ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " per unit length  is clamped between two vertical walls at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ". In the absence of gravity, the rod would be horizontal, but in gravity \
the rod sags with a vertical displacement given by the function ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ". According to the theory of elasticity, the shape of the rod satisfies \
the following boundary-value problem, assuming that the sag is small: ",
  Cell[BoxData[
      \(TraditionalForm\`D\ \(\[PartialD]\^4\/\[PartialD]x\^4\) \(y(
            x)\) = \(-\[Rho]\)\ g\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is the acceleration of gravity and ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " depends on Young's modulus ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " and the cross-sectional area ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " of the rod according to ",
  Cell[BoxData[
      \(TraditionalForm\`D\  = \ \[Alpha]\ E\ a\^2\)]],
  ", and where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is a dimensionless constant that depends on the shape of the cross \
section of the rod. The boundary conditions for a rod clamped at both ends \
are ",
  Cell[BoxData[
      \(TraditionalForm\`y(
          0) = \(\(y\^\[Prime]\)(
            0) = \(y(L) = \(\(y\^\[Prime]\)(L) = 0\)\)\)\)]],
  ". Solve this problem analytically, and determine the shape ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " of the rod.  How does the maximum sag scale with the length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of the rod, holding everything else fixed?\n[You may wish to compare your \
results to those obtained in ",
  ButtonBox["Sec. 9.10",
    ButtonData:>{"Chapter9.nb", "Ex. 9.10"},
    ButtonStyle->"Hyperlink"],
  ", Exercise (5).]"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A neutral plasma is a gas of freely moving charged particles, with equal \
amounts of positive and negative charge. If the plasma encounters a conductor \
to which a positive voltage is applied, negative plasma charges will be \
attracted to the conductor and positive charges will be repelled. As a \
result, an excess negative charge will surround a positively charged \
conductor. If the applied voltage is not too large, the plasma's net charge \
density ",
  StyleBox["\[Rho]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox["(",
    FontFamily->"Symbol"],
  StyleBox["r",
    FontWeight->"Bold"],
  StyleBox[") ",
    FontFamily->"Symbol"],
  "will satisfy a linear law:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Rho]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], " ", "=", " ", 
        RowBox[{\(-A\), " ", 
          RowBox[{"\[Phi]", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}]}]}], TraditionalForm]]]], "NE5",
  CellTags->"(1.5.13)"],

Cell[TextData[{
  "where ",
  StyleBox["\[Phi]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  " is the electrostatic potential in the plasma at position ",
  StyleBox["r",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["A",
    FontSlant->"Italic"],
  " is a positive constant that depends on the plasma density and \
temperature.  The potential satisfies Poisson's equation ",
  ButtonBox["(1.1.10)",
    ButtonData:>"(1.1.10)",
    ButtonStyle->"Hyperlink"],
  ",  so ",
  ButtonBox["Eq. (1.5.13)",
    ButtonData:>"(1.5.13)",
    ButtonStyle->"Hyperlink"],
  " implies a linear PDE for the potential must be solved:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = \(A\/\[Epsilon]\_o\) \[Phi]\)]],
  " ."
}], "NE5",
  CellTags->"(1.5.14)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Consider a plasma confined by conducting plates at ",
  StyleBox["x",
    FontSlant->"Italic"],
  "=0 and ",
  StyleBox["x",
    FontSlant->"Italic"],
  "=",
  StyleBox["L",
    FontSlant->"Italic"],
  ". The plate at ",
  StyleBox["x=",
    FontSlant->"Italic"],
  "0",
  StyleBox[" ",
    FontSlant->"Italic"],
  " is biased to potential ",
  StyleBox["V",
    FontSlant->"Italic"],
  " and the plate at ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = ",
  StyleBox["L",
    FontSlant->"Italic"],
  " is grounded. Solve analytically the 1-D version of ",
  ButtonBox["Eq. (1.5.14)",
    ButtonData:>"(1.5.14)",
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]x\^2\) \[Phi] = \(A\/\
\[Epsilon]\_o\) \[Phi]\)]],
  ", to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  " between the plates."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Repeat this solution numerically using the shooting method. Take ",
  StyleBox["L=",
    FontSlant->"Italic"],
  "2 and ",
  Cell[BoxData[
      \(TraditionalForm\`A/\[Epsilon]\_o\ \  = \ 1\)]],
  ". Plot the analytic and numerical results for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " An artillery sergeant is asked to hit a fixed object at position ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) = \((d, 0)\)\)]],
  " with respect to his cannon. The muzzle velocity of the field piece is \
fixed at ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ", but the angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " of the muzzle with respect to the horizontal can be varied."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Solve this boundary-value problem analytically for ",
  StyleBox["\[Theta]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  ". Show that there are two solutions for ",
  StyleBox["\[Theta]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  "  if the distance to the object is not too great, but that there is no \
solution if ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " exceeds a distance ",
  Cell[BoxData[
      \(TraditionalForm\`d\_max\)]],
  ", and find ",
  Cell[BoxData[
      \(TraditionalForm\`d\_max\)]],
  ". (Note that the time of impact is unimportant in this problem.)"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Create a module that will perform this solution using the shooting \
method, for given ",
  StyleBox["d",
    FontSlant->"Italic"],
  ". Use it to solve the problem where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(v\_o\), "  ", "=", " ", 
          RowBox[{"1000", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`d\  = \ 1\ km\)]],
  ", and there is linear damping of the shell's velocity, with rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 0.3\)]],
  ". Plot the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " trajectory of the shell. By choosing a different initial guess, have the \
method converge to other solutions, if any; and plot all on the same graph of \
",
  StyleBox["y",
    FontSlant->"Italic"],
  " vs. ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)(a)",
    FontWeight->"Bold"],
  " A jet aircraft follows a straight trajectory given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["R",
                FontWeight->"Bold",
                FontSlant->"Plain"], "jet"], "(", "t", ")"}], 
          "=", \((v\_jet\ t\  + \ x\_o, \ y\_o, \ z\_o)\)}], 
        TraditionalForm]]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(v\_jet\), "=", 
          RowBox[{"250", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_o\), "=", 
          RowBox[{\(-500\), " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(y\_o\), "=", 
            RowBox[{"800", " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]}], 
          StyleBox[",",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z\_o\), "=", 
          RowBox[{"5000", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". An antiaircraft gun at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", "0"}], TraditionalForm]]],
  " is trying to shoot the plane down. The muzzle velocity of the gun is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(v\_o\), "=", 
          RowBox[{"600", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ".  If the gun fires a shell at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", where should it aim (i.e.what is the direction of the initial shell \
velocity)? Solve the problem ",
  StyleBox["analytically ",
    FontSlant->"Italic"],
  "(using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to help with the algebra; the final equation needs to be solved \
numerically using ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "), keeping only the force of gravity on the shell. Plot the trajectory of \
the shell and the plane using a three-dimensional parametric plot (",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") up to the instant of impact. Is there more than one solution? [Hint: It \
is useful to introduce spherical polar angles ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Theta], \[Phi])\)\)]],
  " to describe the direction of the initial shell velocity: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["v",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain",
                FontSlant->"Italic"]],
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(v\_o\),
              FontWeight->"Plain"], "(", \(sin\ \[Theta]\ cos\[Phi], \ 
            sin\[Theta]\ sin\[Phi], \ cos\[Theta]\), ")"}]}], 
        TraditionalForm]]],
  ". See Fig. ",
  ButtonBox["1.16",
    ButtonData:>"Fig. 1.16",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Repeat the procedure using the shooting method, but now add a frictional \
deceleration of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Gamma]\)\ v\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Gamma]", "=", 
          RowBox[{"0.075", " ", 
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005U0001HR000`400?l00000o`00003ooooooomV
ooooo`00oooooomVooooo`00oooooomVooooo`00oooooomVooooo`00oooooomVooooo`00oooooomV
ooooo`00oooooomVooooo`00oooooomVooooo`00oooooomVooooo`002?oooooo0?oooe@0oooo2_oo
ool000Soooooo`3ooomD0?ooo`[ooooo0008ooooool0ooooE03oool:ooooo`002?oooooo0?oooe@0
oooo2_ooool000Soooooo`3ooomD0?ooo`[ooooo0008ooooool0ooooE03oool:ooooo`002?oooooo
0?oooe@0oooo2_ooool000Soooooo`3ooomD0?ooo`[ooooo0008ooooool0ooooE03oool:ooooo`00
2?oooooo0?oooe@0oooo2_ooool000Soooooo`3ooomD0?ooo`[ooooo0008ooooo`80000000<0`<30
0?ooo`3oool01P3oool01030`<00000000000020P83o0?ooodD0oooo2_ooool000Sooooo0`000000
0`10@400oooo0?ooo`050?ooo`@0000000<0@4100?ooo`3oool0o`3ooom20?ooo`[ooooo0008oooo
o`@0000000<0P8200?ooo`3oool00`3oool00`20P800000000000003000000030410@03oool0oooo
0?l0oooo@@3oool:ooooo`002?ooool01P000000@4100?ooo`10@40000000<30`0@0oooo00@0@410
00000000000000000P3oool00`10@400P8200?ooo`3o0?oood40oooo2_ooool000Sooooo00H0P820
0?ooo`3oool0oooo0410@00000040?ooo`<0000000H0@4100?ooo`3oool0oooo0410@030`<070?oo
o`0300000030`<00oooo0?l0oooo=`3oool:ooooo`002?ooool50?ooo`80@4100P3oool01@30`<00
0000000000000000P82000<0oooo00<0`<300410@03oool01P3oool00`20P80000000410@03o0?oo
ocL0oooo2_ooool000Sooooo1@3oool01@30`<0000000<30`03oool0P82000<000003P3oool30000
00030<30`03oool0oooo0?l0oooo<`3oool:ooooo`002?ooool60?ooo`030820P010@400oooo00@0
00003P3oool01@10@4000000000000000000@4100?l0oooo=03oool:ooooo`002?ooool70?ooo`03
0410@020P80000000080000000<0P8200?ooo`3oool0303oool00`20P80000000000000300000003
0<30`03oool0oooo0?l0oooo<03oool:ooooo`002?ooool70?ooo`030<30`0000000000000800000
00<0`<300?ooo`3oool03@3oool6000000030410@03oool0oooo0?l0oooo;`3oool:ooooo`002?oo
ool80?ooo`040410@0000000000000000100oooo00<0@4100000000000001@0000000`30`<00oooo
0?ooo`3o0?ooobd0oooo2_ooool000Sooooo203oool3000000030410@03oool0oooo00h0oooo00<0
P8200000000000001P0000000`10@400oooo0?ooo`3M0?ooo`800000C03oool:ooooo`002?ooool7
0?ooo`050<30`0000000000000000020P800403oool00`30`<00000000000008000000030<30`03o
ool0oooo0=@0oooo00<0ZZZZ0?ooo`3oool0103oool2000004`0oooo2_ooool000Sooooo1`3oool0
1@20P8000000000000000000@4100140oooo2`0000000`10@400oooo0?ooo`3B0?ooo`030410@000
0000P82000D0oooo0P00001<0?ooo`[ooooo0008ooooo`L0oooo100000000`10@400`<300?ooo`0?
0?ooo`030410@0000000000000X0000000<0`<300?ooo`3oool0cP3oool01@30`<00000000000000
0000@41000D0oooo0P00001<0?ooo`[ooooo0008ooooo`H0oooo00P0`<3000000000000000000820
P030`<0000000<30`0l0oooo00<0P8200000000000002`0000000`10@400oooo0?ooo`3<0?ooo`05
0820P000000000000000002ZZZX01P3oool2000004`0oooo2_ooool000Sooooo1P3oool01P20P800
0000000000000000`<300?ooo`80@4103`3oool00`30`<0000000000000=000000030<30`03oool0
oooo0<X0oooo00@0P82000000010@400`<30E@3oool:ooooo`002?ooool60?ooo`@000000`3oool0
1`000000@4100<30`03oool0P82000000010@4002P3oool@000000030<30`03oool0oooo0<X0oooo
00<0P8200?ooo`3oool0E@3oool:ooooo`002?ooool40?ooo`030<30`010@40000000080000000D0
@4100?ooo`3oool0oooo0<30`006000000030820P03oool0oooo00L0oooo00<0@410000000000000
300000000`10@400oooo0?ooo`3o0?ooob@0oooo2_ooool000Sooooo00<0oooo0820P00000001P00
00000`30`<00oooo0?ooo`020?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool01`3o
ool00`30`<0000000000000<000000030<30`03oool0oooo0?l0oooo903oool:ooooo`002?ooool2
0?ooo`030<30`020P800@41000<0000000<0@4100?ooo`3oool0103oool00`30`<00000000000002
000000030<30`03oool0oooo00P0oooo3@0000000`30`<00oooo0?ooo`3o0?ooobD0oooo2_ooool0
00Sooooo1P3oool00`30`<00P8200?ooo`080?ooo`80P82000<0`<300?ooo`3oool02@3oool00`20
P800000000000009000000030<30`03oool0oooo0?l0oooo9P3oool:ooooo`002?oooolO0?ooo`03
0<30`0000000000000P0000000<0`<300?ooo`3oool0``3oool00`20P80000000?ooo`1P0?ooo`[o
oooo0008ooooob00oooo2P0000340?ooo`050<30`0000000000000000030`<00H03oool:ooooo`00
2?oooolP0?ooo`030820P0000000000000@0000000@0P8200410@0000000@410`P3oool01010@400
000000000010@41R0?ooo`[ooooo0008ooooob00oooo00<0`<300000000000000P0000001010@400
`<300?ooo`30`<02000000030820P03oool0oooo0;h0oooo00@0@410000000000000`<30H`3oool:
ooooo`002?oooolQ0?ooo`040410@0000000P8200<30`0@0oooo00@0`<30000000000000`<30`03o
ool00`20P800`<300?ooo`0E0?ooo`80P820C03oool:ooooo`002?oooolZ0?ooo`030410@0000000
00000=P0oooo0P00001<0?ooo`[ooooo0008ooooob/0oooo00<0@41000000010@400e`3oool20000
04`0oooo2_ooool000Sooooo:`3oool01030`<00000000000010@43F0?ooo`800000C03oool:oooo
o`002?ooool/0?ooo`040<30`000000000000<30`=D0oooo0P00001<0?ooo`[ooooo0008ooooobd0
oooo00@0@410000000000000`<30/@3oool00`20P80000000?ooo`0P0?ooo`800000C03oool:oooo
o`002?ooool^0?ooo`030410@0000000@4100:l0oooo00D0`<300410@000000000000820P00P0?oo
o`80P820C03oool:ooooo`002?ooool_0?ooo`80000000<0@4100?ooo`3oool0Z`3oool01@30`<00
0000000000000000P82006l0oooo2_ooool000Sooooo;`3oool01030`<00000000000030`<2[0?oo
o`050<30`000000000000410@030`<00L03oool:ooooo`002?ooool`0?ooo`040820P00000000000
0<30`:/0oooo0P10@41b0?ooo`[ooooo0008oooooc40oooo00<0@41000000010@400o`3ooolP0?oo
o`[ooooo0008oooooc80oooo0P0000000`10@400oooo0?ooo`3o0?oooad0oooo2_ooool000Sooooo
<P3oool01030`<00000000000030`<3o0?oooah0oooo2_ooool000Sooooo<`3oool01020P8000000
00000030`<0f0?ooo`040820P0000000000000000>80oooo2_ooool000Sooooo=03oool00`10@400
00000410@00f0?ooo`050<30`0000000000000000020P800H`3oool00`20P800oooo0?ooo`1k0?oo
o`[ooooo0008ooooocD0oooo0P0000000`10@400oooo0?ooo`0d0?ooo`<0000000<0P8200?ooo`3o
ool0G`3oool01030`<00000000000010@41l0?ooo`[ooooo0008ooooocD0oooo00@0`<3000000000
0000`<30=@3oool3000000030410@03oool0oooo05h0oooo00D0@410000000000000@4100<30`01l
0?ooo`[ooooo0008ooooocH0oooo00@0`<30000000000000`<30=03oool01020P800000000000000
001N0?ooo`050<30`010@400000000000030`<00<03oool2000004`0oooo2_ooool000Sooooo=`3o
ool00`10@40000000410@00d0?ooo`040820P00000000000000005l0oooo00<000000410@03oool0
<@3oool2000004`0oooo2_ooool000Sooooo>03oool00`10@40000000410@00c0?ooo`050<30`000
0000000000000020P800TP3oool2000004`0oooo2_ooool000Sooooo>03oool01030`<0000000000
0030`<0c0?ooo`<0000000<0P8200?ooo`3oool0T03oool2000004`0oooo2_ooool000Sooooo>@3o
ool01030`<00000000000030`<0b0?ooo`<0000000<0@4100?ooo`3oool0T03oool2000004`0oooo
2_ooool000Sooooo>P3oool00`10@40000000410@00b0?ooo`040820P0000000000000000980oooo
0P00001<0?ooo`[ooooo0008oooooc/0oooo00<0@41000000010@400;P3oool00`30`<00P8200000
0005000000030410@020P800`<300500oooo0P30`<0l0?ooo`80P820C03oool:ooooo`002?oooolk
0?ooo`040<30`000000000000820P2/0oooo00<0`<300410@00000000P0000001@20P80000000000
00000000@41000<0000000<0@4100<30`03oool0B`3oool01030`<00@41000000010@42:0?ooo`[o
oooo0008oooooc`0oooo00@0`<30000000000000`<30:@3oool01@30`<000000000000000000@410
0080oooo0`0000000`20P800oooo0<30`003000000030820P03oool0oooo04P0oooo00D0P8200000
0000000000000410@02:0?ooo`[ooooo0008ooooocd0oooo00<0@410000000000000:@3oool01010
@40000000000000000030?ooo`040410@000000000000820P080oooo00D0`<300000000000000000
0410@0170?ooo`060<30`010@400000000000010@400`<30R`3oool:ooooo`002?ooooln0?ooo`03
0410@0000000@41002L0oooo00D0`<3000000000000000000820P0030?ooo`040820P00000000000
000000<0oooo00D0`<3000000000000000000410@0170?ooo`80000000<0P8200?ooo`3oool0R`3o
ool:ooooo`002?ooooln0?ooo`040<30`000000000000820P2H0oooo00@0@4100000000000000000
103oool01030`<0000000000000000040?ooo`050820P0000000000000000020P800AP3oool20<30
`8h0oooo2_ooool000Sooooo?`3oool01030`<00000000000030`<0U0?ooo`@000001@3oool30000
00D0oooo00@0@4100000000000000000eP3oool:ooooo`002?oooom00?ooo`030820P00000000000
02D0oooo100000050?ooo`<0000000<0P8200?ooo`3oool00P3oool01@20P8000000000000000000
P8200=D0oooo2_ooool000Sooooo@@3oool00`10@40000000410@00T0?ooo`@000001@3oool01020
P800000000000020P8050?ooo`@00000e@3oool:ooooo`002?oooom20?ooo`80000000<0P8200?oo
o`3oool08@3oool4000000D0oooo00@0P820000000000000P8201@3oool01@20P800000000000000
0000`<300=@0oooo2_ooool000Sooooo@P3oool01030`<00000000000030`<0R0?ooo`@000001P3o
ool3000000D0oooo00D0P82000000000000000000820P00i0?ooo`030<30`010@400P82004X0oooo
0P20P81<0?ooo`[ooooo0008oooood<0oooo00<0P8200000000000008P3oool01@20P80000000000
00000000P82000D0oooo0`0000050?ooo`050<30`0000000000000000010@400>03oool01010@400
000000000010@41:0?ooo`800000C03oool:ooooo`002?oooom40?ooo`030410@0000000@4100240
oooo00D0P82000000000000000000820P0050?ooo`030410@0000000000000H0oooo1000000f0?oo
o`050<30`0000000000000000030`<00B`3oool2000004`0oooo2_ooool000SoooooA@3oool20000
00030820P03oool0oooo01l0oooo100000050?ooo`040820P000000000000820P0D0oooo1000000e
0?ooo`040<30`000000000000410@4d0oooo0P00001<0?ooo`[ooooo0008ooooodD0oooo00@0`<30
000000000000`<30803oool01@10@4000000000000000000`<3000@0oooo00@0`<30000000000000
P8201@3oool4000003H0oooo00<0`<300820P03oool0C@3oool2000004`0oooo2_ooool000Sooooo
AP3oool00`20P80000000000000P0?ooo`050<30`0000000000000000010@4001@3oool200000003
0410@03oool0oooo00<0oooo100000260?ooo`800000C03oool:ooooo`002?oooom70?ooo`030410
@0000000@4100200oooo00D0P82000000000000000000<30`0040?ooo`<00000103oool01@30`<00
0000000000000000P82008H0oooo0P00001<0?ooo`[ooooo0008ooooodP0oooo0P0000000`20P800
oooo0?ooo`0N0?ooo`050410@0000000000000000030`<000`3oool00`20P8000000000000040?oo
o`050820P0000000000000000030`<00e03oool:ooooo`002?oooom80?ooo`040<30`00000000000
0<30`200oooo00D0@410000000000000@4100<30`0020?ooo`040820P000000000000<30`080oooo
00D0`<3000000000000000000410@03E0?ooo`[ooooo0008ooooodT0oooo00<0`<30000000000000
8@3oool01@10@4000000000000000000`<300080oooo0P0000001020P800oooo0<30`010@4020000
00030410@03oool0oooo02/0oooo00<0`<300410@020P800YP3oool:ooooo`002?oooom:0?ooo`03
0410@0000000@4100240oooo00<0`<300410@00000000P0000000`20P8000000000000020410@0<0
000000<0@4100?ooo`3oool0:`3oool01020P800000000000000002V0?ooo`[ooooo0008oooood/0
oooo00<0@41000000020P8008P3oool00`30`<00P82000000006000000030820P030`<00oooo02`0
oooo00D0@410000000000000@4100<30`02V0?ooo`[ooooo0008oooood/0oooo00@0`<3000000000
0000`<309@3oool00`20P80000000000000`0?ooo`040410@000000000000820P:P0oooo2_ooool0
00SoooooC03oool01030`<00000000000030`<0T0?ooo`030<30`000000000000300oooo00<0`<30
00000030`<00Z@3oool:ooooo`002?oooom=0?ooo`030410@0000000@41002D0oooo0P0000000`30
`<00oooo0?ooo`3I0?ooo`[ooooo0008ooooodh0oooo00<0@41000000010@400903oool00`10@400
00000820P03K0?ooo`[ooooo0008ooooodh0oooo00@0`<30000000000000`<308`3oool00`20P800
00000820P03K0?ooo`[ooooo0008ooooodl0oooo00@0`<30000000000000`<308P3oool00`20P800
00000000002=0?ooo`80P820C03oool:ooooo`002?oooom@0?ooo`030410@0000000@41002<0oooo
0P00000U0?ooo`80`<30IP3oool2000004`0oooo2_ooool000SoooooD@3oool00`10@40000000410
@00R0?ooo`800000903oool01010@400000000000030`<1U0?ooo`800000C03oool:ooooo`002?oo
oomA0?ooo`040<30`000000000000=GEeB40oooo00<0P82000000020P8008@3oool01@30`<000000
000000000000P82006H0oooo0P00001<0?ooo`[ooooo0008oooooe80oooo00<0`<300000000[:b/0
0`20P8000`10@40000000000000?000000030410@020P800P82002`0oooo00@0P820000000000000
@410J03oool2000004`0oooo2_ooool000SoooooD`3oool00`20P80000000000000I00000080P820
00<0`<300?ooo`3oool09@3oool00`20P80000000<30`01Y0?ooo`800000C03oool:ooooo`002?oo
oomD0?ooo`0302/[:`000000@41000D0P82000<0`<300?ooo`3oool02`3oool20820P0030410@000
0000000000@0000000<0@4100820P020P800S`3oool20820P4`0oooo2_ooool000SoooooE03oool0
0`2ZZZX000000410@00G0?ooo`030<30`020P800P82000L0000000<0P8200?ooo`3oool0f03oool:
ooooo`002?oooomE0?ooo`030410@0000000@41001/0oooo0P20P8000`10@4000000000000020000
00030410@030`<00oooo0=H0oooo2_ooool000SoooooEP3oool2000000030<30`03oool0oooo01`0
oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`3C0?ooo`[ooooo0008oooooeH0oooo
00@0`<30000000000000`<307`3oool00`30`<00@41000000003000000030820P03oool0oooo00h0
oooo00<0P8200?ooo`3oool0`03oool:ooooo`002?oooomG0?ooo`030820P0000000@4100280oooo
00<0P8200000000000000P0000000`30`<00oooo0?ooo`0:0?ooo`040820P000000000000<30`<40
oooo2_ooool000SoooooF03oool00`10@40000000410@00S0?ooo`060820P0000000000000000010
@400`<30203oool00`30`<00@41000000002000000030<30`03oool0oooo0;l0oooo2_ooool000So
ooooF@3oool2000000030<30`03oool0oooo0280oooo00@0@410000000000000@4101`3oool01@20
P8000000000000000000P8200<<0oooo2_ooool000SoooooF@3oool01030`<00000000000030`<0T
0?ooo`050<30`0000000000000000030`<001@3oool01020P80000000410@030`<340?ooo`[ooooo
0008oooooeX0oooo00<0`<3000000010@4009@3oool01@30`<00@410000000000000`<3000D0oooo
00<0P8200?ooo`3oool0a03oool:ooooo`002?oooomK0?ooo`030410@0000000@41002H0oooo00@0
P820000000000000@410b`3oool:ooooo`002?oooomL0?ooo`030410@0000000P82002H0oooo00<0
`<300410@010@400O@3oool2000004`0oooo2_ooool000SoooooG03oool01030`<00000000000030
`<2U0?ooo`800000C03oool:ooooo`002?oooomM0?ooo`030<30`000000000000:D0oooo0P00001<
0?ooo`[ooooo0008oooooeh0oooo00<0@41000000010@400803oool00`20P80000000?ooo`210?oo
o`800000C03oool:ooooo`002?oooomO0?ooo`030410@0000000P82001d0oooo00D0`<3000000000
000000000<30`0210?ooo`800000C03oool:ooooo`002?oooomO0?ooo`040<30`000000000000<30
`1/0oooo00@0@410000000000000@410P`3oool2000004`0oooo2_ooool000SoooooH03oool00`30
`<0000000000000J0?ooo`040410@000000000000<30`8@0oooo0P20P81<0?ooo`[ooooo0008oooo
of40oooo00<0@41000000010@4006P3oool00`20P800`<300?ooo`3B0?ooo`[ooooo0008ooooof80
oooo00<0@41000000020P800kP3oool:ooooo`002?oooomR0?ooo`040<30`000000000000<30`>d0
oooo2_ooool000SoooooH`3oool00`30`<0000000000003]0?ooo`[ooooo0008ooooof@0oooo00<0
P82000000010@400k03oool:ooooo`002?oooomU0?ooo`030410@0000000P82000/0oooo00<0P820
0000003oool0g@3oool:ooooo`002?oooomV0?ooo`80000000<0`<300?ooo`3oool01P3oool01@30
`<00@410000000000000P8200=d0oooo2_ooool000SoooooIP3oool00`30`<000000000000070?oo
o`050<30`0000000000000000020P800[03oool20820P0030<30`03oool0oooo02d0oooo2_ooool0
00SoooooI`3oool00`20P80000000410@0050?ooo`050<30`000000000000410@030`<00[03oool0
1P20P8000000000000000000@4100<30`2d0oooo2_ooool000SoooooJ03oool00`10@40000000820
P0050?ooo`80@410T`3oool20820P1T0oooo00<0@4100000000000000`0000000`10@400P8200<30
`00C0?ooo`030<30`03oool0oooo01@0oooo2_ooool000SoooooJ@3oool2000000030<30`03oool0
oooo09L0oooo0P00000I0?ooo`X0000000<0@4100820P03oool03`3oool00`000000@4100?ooo`0D
0?ooo`[ooooo0008ooooofT0oooo00<0`<30000000000000V@3oool2000001T0oooo3@0000000`20
P800`<300?ooo`0<0?ooo`<0000000<0`<300?ooo`3oool04@3oool:ooooo`002?oooomZ0?ooo`03
0820P0000000@41009P0oooo0P00000H0?ooo`030820P0000000000000d0000000<0@4100820P03o
ool02P3oool20<30`080000000<0`<300?ooo`3oool0403oool:ooooo`002?oooom[0?ooo`040410
@0000000P8200?ooo`80@41000<0`<300?ooo`3oool0T@3oool2000001P0oooo00<0P82000000000
0000400000000`20P800`<300?ooo`0:0?ooo`030410@0000000`<300140oooo2_ooool000Sooooo
K03oool2000000040820P00000000000000009<0P8200P00000H0820P0030410@0000000000001<0
000000<0P8200<30`03oool0203oool00`10@40000000<30`00@0?ooo`[ooooo0008ooooof`0oooo
00<0`<30000000000000a`0000000`10@400`<300?ooo`080?ooo`80@410403oool:ooooo`002?oo
oom]0?ooo`P0000000<0@4100820P020P800Y`20P80D000000030410@020P800oooo00`0oooo0P10
@40?0?ooo`[ooooo0008ooooof`0oooo00<0@4100000000000001`0000000`20P800oooo0?ooo`2V
0?ooo`030820P0000000000000l0000000<0P8200<30`03oool03`3oool20410@0h0oooo2_ooool0
00SoooooK03oool00`30`<00000000000008000000030410@03oool0oooo0:D0oooo00<0P8200000
00000000300000000`20P800`<300?ooo`0B0?ooo`030820P0000000@41000d0oooo2_ooool000So
ooooK@3oool<000000030<30`03oool0oooo0:@0oooo2`0000000`20P800`<300?ooo`0E0?ooo`04
0820P000000000000410@0`0oooo2_ooool000SoooooK@3oool2000000030<30`0000000000000P0
000000<0@4100?ooo`3oool0X`3oool8000000030820P030`<00oooo01P0oooo00D0@41000000000
000000000410@00;0?ooo`[ooooo0008ooooofd0oooo0P0000020?ooo`030410@0000000000000L0
000000<0@4100<30`03oool0XP3oool00`20P800000000000002000000030410@020P800oooo01/0
oooo1@0000000`30`<00oooo0?ooo`080?ooo`[ooooo0008ooooofd0oooo0P0000030?ooo`030820
P0000000000000P0000000<0`<300?ooo`3oool0X03oool01020P80000000410@020P80O0?ooo`@0
000000<0`<3000000030`<002@3oool:ooooo`002?oooom]0?ooo`800000103oool00`30`<000000
00000008000000030410@03oool0oooo09l0oooo00<0`<300?ooo`3oool0803oool4000000030?oo
o`20P800000000T0oooo2_ooool000SoooooK@3oool2000000H0oooo00<0@4100000000000001`00
00000`10@400`<300?ooo`310?ooo`<0000000<0@4100?ooo`3oool00P10@4080?ooo`[ooooo0008
ooooofd0oooo0P0000070?ooo`030<30`0000000000000P0000000<0P8200?ooo`3oool0_`3oool3
000000060820P03oool0oooo0?ooo`000000P8201`3oool:ooooo`002?oooom]0?ooo`800000203o
ool00`30`<00@41000000008000000030410@03oool0oooo0800oooo0P20P80k0?ooo`050<30`000
0000000000000020P8000`3oool00`30`<0000000<30`0060?ooo`[ooooo0008ooooofd0oooo0P00
000:0?ooo`030410@0000000000000P0000000<0`<300?ooo`3oool0OP3oool2000003/0oooo00D0
P82000000000000000000820P0040?ooo`030820P0000000oooo00D0oooo2_ooool000SoooooK@3o
ool2000000/0oooo00<0`<30000000000000200000000`20P800oooo0?ooo`1m0?ooo`800000>`3o
ool01@20P8000000000000000000P82000D0oooo0P10@4050?ooo`[ooooo0008ooooofd0oooo0P00
000=0?ooo`030410@0000000000000L0000000<0@4100<30`03oool0O03oool2000003/0oooo00D0
P82000000000000000000820P0050?ooo`030<30`0000000`<3000@0oooo2_ooool000SoooooK@3o
ool2000000h0oooo00<0P820000000000000200000000`30`<00oooo0?ooo`1j0?ooo`800000>`3o
ool01020P80000000000000000070?ooo`030820P0000000oooo00<0oooo2_ooool000SoooooK@3o
ool2000000l0oooo00<0`<30000000000000200000000`10@400oooo0?ooo`1i0?ooo`800000>`3o
ool01020P80000000000000000080?ooo`80@4100`3oool:ooooo`002?oooom]0?ooo`8000004@3o
ool00`10@400000000000007000000030410@030`<00oooo07P0oooo0P20P80k0?ooo`@00000203o
ool00`30`<0000000<30`0020?ooo`[ooooo0008ooooofd0oooo0P00000B0?ooo`030<30`0000000
000000P0000000<0`<300?ooo`3oool0/`3oool4000000T0oooo0P10@4020?ooo`[ooooo0008oooo
ofd0oooo0P00000C0?ooo`030<30`010@400000000P0000000<0@4100?ooo`3oool0/P3oool40000
00T0oooo00@0P8200000003oool0oooo2_ooool000SoooooK@3oool2000001D0oooo00<0@4100000
00000000200000000`30`<00oooo0?ooo`2_0?ooo`050<30`0000000000000000020P8002@3oool0
1010@40000000820P03oool:ooooo`002?oooom]0?ooo`8000005P3oool00`30`<00000000000008
000000030820P03oool0oooo0:h0oooo00D0P82000000000000000000820P0080?ooo`<0000000<0
P8200?ooooooool02Oooool000SoooooK@3oool2000001P0oooo00<0@4100000000000001`000000
0`10@400oooo0?ooo`2Y0?ooo`040<30`020P800P8200410@0@0000000<0P8200?ooo`3oool01@3o
ool01P20P8000000000000000000P8200?ooo`[ooooo0008ooooofd0oooo0P00000I0?ooo`030820
P0000000000000P0000000<0`<300?ooo`3oool0Y`3oool00`30`<00@41000000005000000P0oooo
00H0P82000000000000000000<30`03oool:ooooo`002?oooom]0?ooo`8000006P3oool00`30`<00
000000000008000000030410@03oool0oooo0:X0oooo0P20P8000`000000P8200?ooo`080?ooo`03
0410@0000000P8200080oooo2_ooool000SoooooK@3oool2000001`0oooo00<0@410000000000000
1`0000000`10@400`<300?ooo`2k0?ooo`[ooooo0008ooooofd0oooo0P00000M0?ooo`030<30`000
0000000000P0000000<0`<300?ooo`3oool0^@3oool:ooooo`002?oooom]0?ooo`8000007P3oool0
0`30`<00@41000000008000000030410@03oool0oooo0;P0oooo2_ooool000SoooooK@3oool20000
0200oooo00<0@4100000000000001`0000000`10@400`<300?ooo`1Y0?ooo`800000C03oool:oooo
o`002?oooom]0?ooo`800000803oool00`30`<00000000000009000000030820P03oool0oooo06L0
oooo0P00001<0?ooo`[ooooo0008ooooofd0oooo0P00000P0?ooo`040410@0000000@4100410@0T0
000000<0@4100?ooo`3oool0IP3oool2000004`0oooo2_ooool000SoooooK@3oool2000001l0oooo
00H0`<30000000000000`<300?ooo`20P80:000000030<30`03oool0oooo06@0oooo0P00001<0?oo
o`[ooooo0008ooooofd0oooo0P00000O0?ooo`80000000D0@4100?ooo`3oool0oooo0<30`00:0000
00030820P03oool0oooo06<0oooo0P00001<0?ooo`[ooooo0008ooooofd0oooo0P00000N0?ooo`03
0410@0000000P82000H0oooo00<0@4100000000000001`0000000`10@400`<300?ooo`1R0?ooo`80
0000C03oool:ooooo`002?oooom]0?ooo`8000007@3oool00`10@40000000410@0080?ooo`030<30
`0000000000000P0000000<0`<300?ooo`3oool0H03oool20820P4`0oooo2_ooool000SoooooK@3o
ool2000001`0oooo00@0`<30000000000000`<302@3oool00`30`<00@41000000008000000030410
@03oool0oooo0:d0oooo2_ooool000SoooooK@3oool2000001/0oooo00@0`<30000000000000`<30
303oool00`10@400000000000007000000030410@030`<00oooo0:`0oooo2_ooool000SoooooK@3o
ool2000001X0oooo00@0`<30000000000000@4103P3oool00`30`<00000000000008000000030<30
`03oool0oooo0:X0oooo2_ooool000SoooooK@3oool2000001X0oooo00<0@41000000010@4004@3o
ool00`10@400000000000007000000030410@03oool0oooo0:T0oooo2_ooool000SoooooK@3oool2
000001T0oooo00<0@4100000000000004`3oool00`20P800000000000008000000030<30`03oool0
oooo0:L0oooo2_ooool000SoooooK@3oool2000001P0oooo00@0@410000000000000`<30503oool0
0`30`<00000000000008000000030820P03oool0oooo0:H0oooo2_ooool000SoooooK@3oool20000
01H0oooo00D0`<300410@000000000000<30`00G0?ooo`030410@0000000000000L0000000<0@410
0?ooo`3oool0Y@3oool:ooooo`002?oooom]0?ooo`800000503oool01@3EeMD0P820000000000000
P82001X0oooo00<0ZZZZ02/[:`000000200000000`20P800eMGE0?ooo`2S0?ooo`[ooooo0008oooo
ofd0oooo0P00000C0?ooo`050410@000000000000410@030`<007@3oool00`30`<00000000000008
000000030<30`03oool0oooo0:40oooo2_ooool000SoooooK@3oool200000140oooo00D0P8200000
0000000000000410@00P0?ooo`030<30`010@400000000P0000000<0@4100?ooo`3oool0DP3oool2
000004`0oooo2_ooool000SoooooK@3oool2000000l0oooo00H0`<300410@000000000000410@030
`<0S0?ooo`030410@0000000000000L0000000<0@4100<30`03oool0D@3oool2000004`0oooo2_oo
ool000SoooooK@3oool2000000d0oooo00H0P8200410@000000000000410@030`<0V0?ooo`030<30
`0000000000000P0000000<0`<300?ooo`3oool0C`3oool2000004`0oooo2_ooool000SoooooK@3o
ool2000000T0oooo00<0`<300820P00000000`0000000`10@400`<300?ooo`0Y0?ooo`030410@000
0000000000L0000000<0@4100?ooo`3oool0CP3oool2000004`0oooo2_ooool000SoooooK@3oool2
000000H0oooo0P20P805000000030820P03oool0oooo02`0oooo00<0P82000000000000020000000
0`30`<00oooo0?ooo`1<0?ooo`800000C03oool:ooooo`002?oooom]0?ooo`80000000<0oooo0000
000000001`0000000`20P800`<300?ooo`0`0?ooo`030<30`0000000000000P0000000<0P8200?oo
o`3oool0B`3oool2000004`0oooo2_ooool000SoooooK@3oool2000000030?ooo`000000000000<0
000000<0@4100820P030`<00=P3oool00`10@400000000000007000000030410@03oool0oooo04X0
oooo0P20P81<0?ooo`[ooooo0008ooooofd0oooo0P00000E0?ooo`030<30`020P800000000<00000
00<0@4100820P03oool08P3oool00`30`<00000000000008000000030<30`03oool0oooo09H0oooo
2_ooool000SoooooK@3oool2000001@0oooo00@0@410000000000000P8200`3oool01020P8000000
00000020P80R0?ooo`030<30`010@400000000P0000000<0@4100?ooo`3oool0U@3oool:ooooo`00
2?oooom]0?ooo`8000004`3oool01010@400000000000030`<060?ooo`030410@0000000@41002<0
oooo00<0@4100000000000001`0000000`10@400`<300?ooo`2D0?ooo`[ooooo0008ooooofd0oooo
0P00000B0?ooo`040<30`000000000000410@0P0oooo00<0@41000000010@4008`3oool00`30`<00
000000000008000000030<30`03oool0oooo0980oooo2_ooool000SoooooK@3oool200000180oooo
00@0@410000000000000P820203oool01030`<00000000000010@40T0?ooo`030410@00000000000
00L0000000<0@4100?ooo`3oool0T@3oool:ooooo`002?oooom]0?ooo`8000004P3oool300000003
0820P03oool0oooo00L0oooo00@0@410000000000000P820903oool00`20P8000000000000080000
00030<30`03oool0oooo08l0oooo2_ooool000SoooooK@3oool200000140oooo00D0P82000000000
000000000820P0090?ooo`040820P00000000000000002D0oooo00<0`<3000000000000020000000
0`20P800oooo0?ooo`2>0?ooo`[ooooo0008ooooofd0oooo0P00000A0?ooo`050820P00000000000
00000020P8002P3oool3000000030410@03oool0oooo02@0oooo00<0@4100000000000001`000000
0`10@400oooo0?ooo`2=0?ooo`[ooooo0008ooooofd0oooo0P00000A0?ooo`050820P00000000000
00000020P8002P3oool01010@400000000000000000W0?ooo`030<30`0000000000000P0000000<0
`<300?ooo`3oool0R`3oool:ooooo`002?oooom]0?ooo`8000004@3oool01@20P800000000000000
0000P82000X0oooo00D0P82000000000000000000820P00W0?ooo`030<30`010@400000000P00000
00<0P8200?ooo`3oool0RP3oool:ooooo`002?oooom]0?ooo`8000004@3oool01@20P80000000000
00000000P82000/0oooo1000000Y0?ooo`030410@0000000000000L0000000<0@4100<30`03oool0
>`3oool2000004`0oooo2_ooool000SoooooK@3oool200000140oooo00D0P8200000000000000000
0410@00;0?ooo`@0000000<0P8200?ooo`3oool09`3oool00`30`<00000000000008000000030<30
`03oool0oooo03T0oooo0P00001<0?ooo`[ooooo0008ooooofd0oooo0P00000A0?ooo`030820P000
00000000008000002`3oool01@20P8000000000000000000P82002/0oooo00<0@410000000000000
1`0000000`10@400oooo0?ooo`0h0?ooo`800000C03oool:ooooo`002?oooom]0?ooo`8000004@3o
ool00`30`<00000000000002000000/0oooo00<0P8200000000000000P00000/0?ooo`030820P000
0000000000L0000000<0@4100<30`03oool0=`3oool2000004`0oooo2_ooool000SoooooK@3oool2
00000180oooo100000000`20P800oooo0?ooo`080?ooo`030<30`000000000000080000000<0`<30
0?ooo`3oool0:P3oool00`30`<00000000000008000000030820P03oool0oooo03D0oooo0P00001<
0?ooo`[ooooo0008ooooofd0oooo0P00000B0?ooo`@0000000<0P8200?ooo`3oool02@3oool40000
00030820P03oool0oooo02`0oooo00<0@4100000000000001`0000000`10@400oooo0?ooo`0d0?oo
o`800000C03oool:ooooo`002?oooom]0?ooo`8000004P3ooolD000000030820P03oool0oooo02d0
oooo00<0`<30000000000000200000000`30`<00oooo0?ooo`200?ooo`[ooooo0008ooooofd0oooo
0P00000B0?ooo`030820P0000000000001800000<03oool00`30`<00@41000000008000000030820
P03oool0oooo07l0oooo2_ooool000SoooooK@3oool200000180oooo00<0P8200000000000000P00
000;0?ooo`030820P0000000000000800000<P3oool00`10@400000000000007000000030410@03o
ool0oooo07h0oooo2_ooool000SoooooK@3oool2000001<0oooo100000000`20P800oooo0?ooo`09
0?ooo`@0000000<0`<300?ooo`3oool0<03oool00`30`<00000000000008000000030<30`03oool0
oooo07`0oooo2_ooool000SoooooK@3oool2000001<0oooo00D0@41000000000000000000820P00;
0?ooo`@0000000<0P8200?ooo`3oool0<P3oool00`10@400000000000007000000030410@03oool0
oooo07/0oooo2_ooool000SoooooK@3oool2000001<0oooo00<0P8200000000000000P00000;0?oo
o`050410@0000000000000000020P800=@3oool00`20P800000000000007000000030410@030`<00
oooo07X0oooo2_ooool000SoooooK@3oool2000001@0oooo1000000;0?ooo`050820P00000000000
00000020P800=P3oool00`30`<00000000000008000000030<30`03oool0oooo07P0oooo2_ooool0
00SoooooK@3oool2000001@0oooo00D0@41000000000000000000820P00:0?ooo`050820P0000000
000000000020P800>03oool00`10@400000000000007000000030410@03oool0oooo07L0oooo2_oo
ool000SoooooK@3oool2000001@0oooo00D0`<3000000000000000000410@00:0?ooo`050820P000
0000000000000020P800>@3oool00`20P800000000000008000000030<30`03oool0oooo07D0oooo
2_ooool000SoooooK@3oool2000001D0oooo00@0@41000000000000000002P3oool01@20P8000000
000000000000P82003X0oooo00<0`<300410@0000000200000000`20P800oooo0?ooo`1d0?ooo`[o
oooo0008ooooofd0oooo0P00000E0?ooo`050<30`0000000000000000020P8002@3oool01@20P800
0000000000000000`<3003`0oooo00<0@4100000000000001`0000000`10@400oooo0?ooo`0U0?oo
o`80P820C03oool:ooooo`002?oooom]0?ooo`8000005P3oool01020P80000000000000000090?oo
o`040820P00000000000000003h0oooo00<0`<30000000000000200000000`30`<00oooo0?ooo`0S
0?ooo`800000C03oool:ooooo`002?oooom]0?ooo`8000005`3oool01010@400000000000020P808
0?ooo`040820P000000000000410@3l0oooo00<0`<300410@0000000200000000`20P800oooo0?oo
o`0R0?ooo`800000C03oool:ooooo`002?oooom]0?ooo`800000603oool01010@400000000000030
`<070?ooo`040410@000000000000<30`440oooo00<0P8200000000000001`0000000`10@400`<30
0?ooo`0Q0?ooo`800000C03oool:ooooo`002?oooom]0?ooo`8000006@3oool01010@40000000000
0030`<050?ooo`040<30`000000000000410@4<0oooo00<0`<30000000000000200000000`30`<00
oooo0?ooo`0O0?ooo`800000C03oool:ooooo`002?oooom]0?ooo`8000006P3oool01020P8000000
00000020P8030?ooo`040820P000000000000410@4H0oooo00<0@4100000000000001`0000000`10
@400oooo0?ooo`0N0?ooo`800000C03oool:ooooo`002?oooom]0?ooo`800000703oool00`20P800
@41000000003000000030820P030`<00oooo04L0oooo00<0P8200000000000001`0000000`10@400
`<300?ooo`0M0?ooo`800000C03oool:ooooo`002?oooom]0?ooo`800000K@3oool00`30`<00@410
00000008000000030820P03oool0oooo06T0oooo2_ooool000SoooooK@3oool2000006l0oooo00<0
@4100000000000001`0000000`10@400oooo0?ooo`1X0?ooo`[ooooo0008ooooofd0oooo0P00001`
0?ooo`030<30`0000000000000P0000000<0`<300?ooo`3oool0IP3oool:ooooo`002?oooom]0?oo
o`800000L@3oool00`30`<00@41000000008000000030820P03oool0oooo06D0oooo2_ooool000So
ooooK@3oool2000005d0oooo00<0P8200<30`03oool04`3oool00`20P80000000000000700000003
0410@03oool0oooo06@0oooo2_ooool000SoooooK@3oool2000005`0oooo00<0P82000000010@400
5@3oool00`30`<00000000000008000000030<30`03oool0oooo0680oooo2_ooool000SoooooK@3o
ool2000005`0oooo0`00000G0?ooo`030410@0000000000000L0000000<0@4100?ooo`3oool01@3o
ool00`20P800oooo0?ooo`1I0?ooo`[ooooo0008ooooofd0oooo0P00001K0?ooo`050820P0000000
000000000020P8005`3oool00`20P800000000000007000000030410@030`<00oooo0080oooo00@0
`<300410@0000000@410FP3oool:ooooo`002?oooom]0?ooo`800000F`3oool5000001P0oooo00<0
`<300410@0000000200000000`30`<00oooo0<30`004000000030<30`03oool0oooo05L0oooo2_oo
ool000SoooooK@3oool2000005X0oooo00<0`<300000000000000`0000000`20P800oooo0?ooo`0G
0?ooo`030410@0000000000000L0000000<0@4100000000000000`0000000`10@400oooo0?ooo`1G
0?ooo`[ooooo0008ooooofd0oooo0P00001J0?ooo`030410@0000000000000<0000000<0@4100?oo
o`3oool0603oool00`30`<0000000000000=000000030820P03oool0oooo00P0oooo0P00001<0?oo
o`[ooooo0008ooooofd0oooo0P00001I0?ooo`030<30`0000000000000D0000000<0`<300?ooo`3o
ool0603oool00`30`<00@4100000000=000000030<30`03oool0oooo00L0oooo0P00001<0?ooo`[o
oooo0008ooooofd0oooo0P00001I0?ooo`030820P0000000000000D0000000<0@4100?ooo`3oool0
6P3oool00`20P80000000000000<000000030<30`03oool0oooo00H0oooo0P00001<0?ooo`[ooooo
0008ooooofd0oooo0P00001I0?ooo`L0000000<0P8200000003oool0703oool00`30`<0000000000
000;000000030410@03oool0oooo00H0oooo0P00001<0?ooo`[ooooo0008ooooofd0oooo0P00001H
0?ooo`030820P0000000000000@0000000@0P8200?ooo`000000P8207P3oool=000000030410@03o
ool0oooo00D0oooo0P00001<0?ooo`[ooooo0008ooooofd0oooo0P00001H0?ooo`L000000P3oool0
0`20P80000000?ooo`0L0?ooo`030820P0000000000000`0000000<0eMGE0?ooo`3oool0103oool2
000004`0oooo2_ooool000SoooooK@3oool2000005L0oooo00<0P820000000000000100000001P10
@400oooo0?ooo`30`<0000000820P1`0oooo3`0000000`20P800oooo0?ooo`040?ooo`80P820C03o
ool:ooooo`002?oooom]0?ooo`800000E`3oool00`10@400000000000004000000040<30`03oool0
oooo0?ooo`80@4106`3oool00`30`<0000000000000=0000000302/[:`3oool0oooo0580oooo2_oo
ool000SoooooK@3oool2000005H0oooo00<0`<30000000000000100000000`10@400oooo0?ooo`02
0?ooo`030820P0000000`<3001X0oooo00<0@4100000000000003P0000000`10@400oooo0?ooo`1A
0?ooo`[ooooo0008ooooofd0oooo0P00001F0?ooo`030410@0000000000000@0000000<0`<300?oo
o`3oool00`3oool00`000000@4100?ooo`0I0?ooo`030820P010@400000000l0000000<0@4100<30
`03oool0D03oool:ooooo`002?oooom]0?ooo`800000EP3oool7000000H0oooo00<0P8200000003o
ool0703oool00`20P800@4100000000>000000030<30`03oool0oooo04h0oooo2_ooool000Sooooo
K@3oool2000005D0oooo00<0P820000000000000100000000`20P800oooo0?ooo`050?ooo`030000
0020P800oooo01h0oooo00<0`<300820P0000000300000000`10@400oooo0?ooo`1=0?ooo`[ooooo
0008ooooofd0oooo0P00001E0?ooo`L00000203oool200000280oooo00<0`<300820P00000002@00
00000`20P800oooo0?ooo`1=0?ooo`[ooooo0008ooooofd0oooo0P00001D0?ooo`030820P0000000
000000D00000203oool00`20P80000000820P00T0?ooo`030<30`020P800000000H0000000<0`<30
0?ooo`3oool0C@3oool:ooooo`002?oooom]0?ooo`800000D`3oool00`30`<000000000000060000
00P0oooo00@0@410000000000000`<309P3oool00`30`<00:b/[00000003000000030410@03oool0
oooo04d0oooo2_ooool000SoooooK@3oool200000580oooo00<0P8200000000000001`0000000`10
@400P8200?ooo`030?ooo`030820P010@400000000<0000000<0P8200?ooo`3oool0903oool0103E
eMD0000000000020P802000000030<30`03oool0oooo04`0oooo2_ooool000SoooooK@3oool20000
0580oooo3020P8040?ooo`L0P820:03oool01@20P800oooo0?ooo`30`<00P82004h0oooo2_ooool0
00SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000Sooooo
K@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool2
00000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0
oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_oo
ool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000So
ooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3o
ool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool20000
0>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo
2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool0
00SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000Sooooo
K@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool2
00000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0
oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_oo
ool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000So
ooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3o
ool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool20000
0>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo
2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool0
00SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000Sooooo
K@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool2
00000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0
oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_oo
ool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000So
ooooK@3oool200000>@0oooo2_ooool000SoooooK@3oool200000>@0oooo2_ooool000SoooooK@3o
ool200000>@0oooo2_ooool000SoooooJ`3oool20820P080000000<0P8200?ooo`3oool0h@3oool:
ooooo`002?oooomW0?ooo`80P8202P0000000`20P800`<300?ooo`3M0?ooo`[ooooo0008ooooofH0
oooo4000003M0?ooo`[ooooo0008ooooofH0oooo00<0P8200000000000003@0000090?ooo`030<30
`020P800P82000/0P82000<0`<300?ooo`3oool0``3oool:ooooo`002?oooomV0?ooo`030<30`000
0000000000`0000000<0P8200?ooo`3oool01`3oool00`20P80000000000000<00000<D0oooo2_oo
ool000SoooooI`3oool>000000030<30`03oool0oooo00L0oooo00<0`<3000000000000030000035
0?ooo`[ooooo0008ooooofL0oooo00<0P8200000000000002P0000000`10@400oooo0?ooo`090?oo
o`030<30`0000000000000/0000000<0P8200?ooo`3oool0`P3oool:ooooo`002?oooomW0?ooo`03
0<30`0000000000000X0000000<0`<300?ooo`3oool02P3oool00`30`<0000000<30`0080?ooo`03
0<30`0000000@4100<@0oooo2_ooool000SoooooJ03oool00`10@400000000000009000000h0oooo
00<0`<3000000030`<00203oool00`30`<0000000?ooo`330?ooo`[ooooo0008ooooofP0oooo00<0
P820000000000000200000000`20P800oooo0?ooo`0=0?ooo`030<30`0000000`<3000P0oooo00<0
@4100820P03oool0`P3oool:ooooo`002?oooomY0?ooo`X0000000<0P8200?ooo`3oool03P3oool0
0`30`<0000000<30`03<0?ooo`[ooooo0008ooooofT0oooo00<0@4100000000000001`00000B0?oo
o`030<30`0000000`<300</0oooo2_ooool000SoooooJ@3oool00`20P80000000000000600000003
0410@03oool0oooo0140oooo00<0`<3000000030`<00bP3oool:ooooo`002?oooomZ0?ooo`P00000
00<0P8200?ooo`3oool04P3oool00`30`<0000000<30`0390?ooo`[ooooo0008ooooofX0oooo00<0
@4100000000000001@00000F0?ooo`030<30`0000000`<300<P0oooo2_ooool000SoooooJP3oool0
0`20P800000000000004000000030820P03oool0oooo01D0oooo00<0`<3000000030`<00a`3oool:
ooooo`002?oooom[0?ooo`H0000000<0`<300?ooo`3oool05P3oool00`30`<0000000<30`0360?oo
o`[ooooo0008ooooof/0oooo00<0@4100000000000000P0000000`10@400oooo0?ooo`0H0?ooo`03
0<30`0000000`<300<D0oooo2_ooool000SoooooJ`3oool00`20P800000000000002000000030820
P03oool0oooo00l0oooo00<0P8200410@03oool01`3oool00`30`<0000000<30`0340?ooo`[ooooo
0008ooooof`0oooo1000000C0?ooo`0300000010@400oooo00L0oooo00<0`<3000000030`<00``3o
ool:ooooo`002?oooom/0?ooo`040820P000000000000820P1<0oooo00<0@41000000010@4002020
P8000`10@40000000<30`0320?ooo`[ooooo0008ooooof`0oooo00@0`<30000000000000`<304`3o
ool00`20P80000000000000;000000030<30`03oool0oooo0;l0oooo2_ooool000SoooooK@3oool2
000001D0oooo3P0000000`30`<00oooo0?ooo`2n0?ooo`[ooooo0008ooooofd0oooo0P20P80E0?oo
o`030410@0000000000000/0000000<0P8200?ooo`3oool0_P3oool:ooooo`002?oooom]0?ooo`80
`<30i03oool:ooooo`002?oooooo0?oooe@0oooo2_ooool000Soooooo`3ooomD0?ooo`[ooooo0008
ooooool0ooooE03oool:ooooo`002?oooooo0?oooe@0oooo2_ooool000Soooooo`3ooomD0?ooo`[o
oooo0008ooooool0ooooE03oool:ooooo`002?oooooo0?oooe@0oooo2_ooool000Soooooo`3ooomD
0?ooo`[ooooo0008ooooool0ooooE03oool:ooooo`002?oooooo0?oooe@0oooo2_ooool000Sooooo
o`3ooomD0?ooo`[ooooo0008ooooool0ooooE03oool:ooooo`002?oooooo0?oooe@0oooo2_ooool0
00Soooooo`3ooomD0?ooo`[ooooo0008ooooool0ooooE03oool:ooooo`002?oooooo0?oooe@0oooo
2_ooool000Soooooo`3ooomD0?ooo`[ooooo0008ooooool0ooooE03oool:ooooo`002?oooooo0?oo
oe@0oooo2_ooool000Soooooo`3ooomD0?ooo`[ooooo0008ooooool0ooooE03oool:ooooo`00oooo
oomVooooo`00oooooomVooooo`00oooooomVooooo`00oooooomVooooo`00oooooomVooooo`00oooo
oomVooooo`00oooooomVooooo`00oooooomVooooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{119.125, 118.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 1.16 ",
  "Spherical polar angles ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Theta], \[Phi])\)\)]],
  " describing the direction of a vector ",
  StyleBox["v",
    FontWeight->"Bold"],
  " with respect to fixed axes."
}], "Caption",
  CellTags->"Fig. 1.16"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " James Bond, mass 85 kg, needs to jump off an overpass onto the bed of a \
passing truck 12 m below. He is attached to a bungee cord to break his fall, \
with a nonlinear spring force of ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(-1.1\), " ", 
          FormBox[\(y\^3\),
            "TraditionalForm"]}], TraditionalForm]]],
  " newtons, where ",
  StyleBox["y",
    FontSlant->"Italic"],
  " is the displacement of Bond from the overpass measured in meters. A \
positive displacement corresponds to moving ",
  StyleBox["down",
    FontSlant->"Italic"],
  ".  By eye he quickly calculates that the truck will be beneath him in 2.1 \
seconds. He immediately jumps."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  "Use the shooting method to numerically determine what vertical velocity he \
must give himself, neglecting friction with the air, so that he lands on the \
truck at just the right instant. (A positive velocity corresponds to jumping \
down.) Plot Bond's trajectory. ",
  Cell[BoxData[
      \(TraditionalForm\`y(t)\)]],
  "(Hint: Remember to include gravity, with the right sign!)"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Can you find other, less appealing solutions for Bond's initial velocity \
that involve multiple oscillations at rather high speed?"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontFamily->"Symbol",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "On January 1, 2001, at 12 noon GMT,  a spacecraft is located 500 km above \
the earth's surface, on the night side, along the line directly connecting \
the earth to the sun. The computer controlling  the spacecraft (a HAL9000, of \
course) has been asked to ensure that the ship will be at the future location \
of Jupiter exactly three years from this instant. (To be precise, the \
location is to be 100,000 km on the inboard side of Jupiter on a line toward \
the sun.) Use a shooting method and the information in ",
  ButtonBox["Table 1.2",
    ButtonData:>"Table 1.2",
    ButtonStyle->"Hyperlink"],
  " to determine the HAL9000's solution for the required initial velocity of \
the spacecraft, and plot the trajectory of the craft through the solar \
system. (Hint: to speed up the orbit integration, keep only the orbits of the \
earth, Mars, and Jupiter in the simulation. Use the molecular dynamics code \
developed in ",
  ButtonBox["Sec. 1.4",
    ButtonData:>"Sec. 1.4",
    ButtonStyle->"Hyperlink"],
  " to determine the orbits.) The solution is shown graphically in Fig. ",
  ButtonBox["1.17",
    ButtonData:>"Fig. 1.17",
    ButtonStyle->"Hyperlink"],
  " as a plot of the orbits. (The plot can be viewed from different angles by \
dragging on it with the mouse.)"
}], "Text"],

Cell[BoxData[
  Graphics3D[{
    Line[{{-702990016.000000, -754150016.000000, 
        23898800.000000},{-684785856.000000, -762819648.000000, 
        23491718.000000}}],
    Line[{{-684785856.000000, -762819648.000000, 
        23491718.000000},{-666475008.000000, -771120960.000000, 
        23080532.000000}}],
    Line[{{-666475008.000000, -771120960.000000, 
        23080532.000000},{-648071808.000000, -779056384.000000, 
        22665408.000000}}],
    Line[{{-648071808.000000, -779056384.000000, 
        22665408.000000},{-629589312.000000, -786630144.000000, 
        22246514.000000}}],
    Line[{{-629589312.000000, -786630144.000000, 
        22246514.000000},{-611038720.000000, -793847744.000000, 
        21824018.000000}}],
    Line[{{-611038720.000000, -793847744.000000, 
        21824018.000000},{-592429248.000000, -800715200.000000, 
        21398092.000000}}],
    Line[{{-592429248.000000, -800715200.000000, 
        21398092.000000},{-573768256.000000, -807238976.000000, 
        20968906.000000}}],
    Line[{{-573768256.000000, -807238976.000000, 
        20968906.000000},{-555061120.000000, -813424832.000000, 
        20536628.000000}}],
    Line[{{-555061120.000000, -813424832.000000, 
        20536628.000000},{-536311808.000000, -819278144.000000, 
        20101428.000000}}],
    Line[{{-536311808.000000, -819278144.000000, 
        20101428.000000},{-517522816.000000, -824802880.000000, 
        19663480.000000}}],
    Line[{{-517522816.000000, -824802880.000000, 
        19663480.000000},{-498695840.000000, -830002048.000000, 
        19222952.000000}}],
    Line[{{-498695840.000000, -830002048.000000, 
        19222952.000000},{-479831904.000000, -834876992.000000, 
        18780016.000000}}],
    Line[{{-479831904.000000, -834876992.000000, 
        18780016.000000},{-460931936.000000, -839427648.000000, 
        18334842.000000}}],
    Line[{{-460931936.000000, -839427648.000000, 
        18334842.000000},{-441996928.000000, -843652608.000000, 
        17887604.000000}}],
    Line[{{-441996928.000000, -843652608.000000, 
        17887604.000000},{-423028416.000000, -847548864.000000, 
        17438472.000000}}],
    Line[{{-423028416.000000, -847548864.000000, 
        17438472.000000},{-404028800.000000, -851112320.000000, 
        16987622.000000}}],
    Line[{{-404028800.000000, -851112320.000000, 
        16987622.000000},{-385001536.000000, -854337728.000000, 
        16535224.000000}}],
    Line[{{-385001536.000000, -854337728.000000, 
        16535224.000000},{-365951648.000000, -857219264.000000, 
        16081456.000000}}],
    Line[{{-365951648.000000, -857219264.000000, 
        16081456.000000},{-346885696.000000, -859750464.000000, 
        15626494.000000}}],
    Line[{{-346885696.000000, -859750464.000000, 
        15626494.000000},{-327812096.000000, -861924928.000000, 
        15170514.000000}}],
    Line[{{-327812096.000000, -861924928.000000, 
        15170514.000000},{-308741088.000000, -863736960.000000, 
        14713695.000000}}],
    Line[{{-308741088.000000, -863736960.000000, 
        14713695.000000},{-289684608.000000, -865181504.000000, 
        14256217.000000}}],
    Line[{{-289684608.000000, -865181504.000000, 
        14256217.000000},{-270656160.000000, -866255232.000000, 
        13798257.000000}}],
    Line[{{-270656160.000000, -866255232.000000, 
        13798257.000000},{-251670272.000000, -866956608.000000, 
        13339997.000000}}],
    Line[{{-251670272.000000, -866956608.000000, 
        13339997.000000},{-232742160.000000, -867286208.000000, 
        12881615.000000}}],
    Line[{{-232742160.000000, -867286208.000000, 
        12881615.000000},{-213886928.000000, -867247104.000000, 
        12423290.000000}}],
    Line[{{-213886928.000000, -867247104.000000, 
        12423290.000000},{-195119136.000000, -866844352.000000, 
        11965198.000000}}],
    Line[{{-195119136.000000, -866844352.000000, 
        11965198.000000},{-176452112.000000, -866085184.000000, 
        11507517.000000}}],
    Line[{{-176452112.000000, -866085184.000000, 
        11507517.000000},{-157897536.000000, -864978176.000000, 
        11050419.000000}}],
    Line[{{-157897536.000000, -864978176.000000, 
        11050419.000000},{-139465216.000000, -863533120.000000, 
        10594077.000000}}],
    Line[{{-139465216.000000, -863533120.000000, 
        10594077.000000},{-121162848.000000, -861760320.000000, 
        10138662.000000}}],
    Line[{{-121162848.000000, -861760320.000000, 
        10138662.000000},{-102996160.000000, -859669952.000000, 
        9684341.000000}}],
    Line[{{-102996160.000000, -859669952.000000, 
        9684341.000000},{-84969016.000000, -857271680.000000, 
        9231279.000000}}],
    Line[{{-84969016.000000, -857271680.000000, 
        9231279.000000},{-67083692.000000, -854574336.000000, 
        8779641.000000}}],
    Line[{{-67083692.000000, -854574336.000000, 
        8779641.000000},{-49341212.000000, -851585664.000000, 
        8329588.000000}}],
    Line[{{-49341212.000000, -851585664.000000, 
        8329588.000000},{-31741702.000000, -848311808.000000, 
        7881278.500000}}],
    Line[{{-31741702.000000, -848311808.000000, 
        7881278.500000},{-14284758.000000, -844757632.000000, 
        7434869.500000}}],
    Line[{{-14284758.000000, -844757632.000000, 7434869.500000},{
      3030192.750000, -840926464.000000, 6990514.500000}}],
    Line[{{3030192.750000, -840926464.000000, 6990514.500000},{
      20203530.000000, -836820096.000000, 6548366.500000}}],
    Line[{{20203530.000000, -836820096.000000, 6548366.500000},{
      37235100.000000, -832438976.000000, 6108574.500000}}],
    Line[{{37235100.000000, -832438976.000000, 6108574.500000},{
      54123892.000000, -827782272.000000, 5671286.500000}}],
    Line[{{54123892.000000, -827782272.000000, 5671286.500000},{
      70867752.000000, -822848256.000000, 5236647.500000}}],
    Line[{{70867752.000000, -822848256.000000, 5236647.500000},{
      87463104.000000, -817634432.000000, 4804800.000000}}],
    Line[{{87463104.000000, -817634432.000000, 4804800.000000},{
      103904784.000000, -812138048.000000, 4375884.000000}}],
    Line[{{103904784.000000, -812138048.000000, 4375884.000000},{
      120185904.000000, -806356352.000000, 3950038.250000}}],
    Line[{{120185904.000000, -806356352.000000, 3950038.250000},{
      136297888.000000, -800287360.000000, 3527397.750000}}],
    Line[{{136297888.000000, -800287360.000000, 3527397.750000},{
      152230544.000000, -793929856.000000, 3108095.500000}}],
    Line[{{152230544.000000, -793929856.000000, 3108095.500000},{
      167972432.000000, -787284480.000000, 2692262.250000}}],
    Line[{{167972432.000000, -787284480.000000, 2692262.250000},{
      183511216.000000, -780353536.000000, 2280025.500000}}],
    Line[{{183511216.000000, -780353536.000000, 2280025.500000},{
      198834272.000000, -773141568.000000, 1871510.750000}}],
    Line[{{198834272.000000, -773141568.000000, 1871510.750000},{
      213929216.000000, -765655296.000000, 1466840.625000}}],
    Line[{{213929216.000000, -765655296.000000, 1466840.625000},{
      228784560.000000, -757903488.000000, 1066134.875000}}],
    Line[{{228784560.000000, -757903488.000000, 1066134.875000},{
      243390240.000000, -749896704.000000, 669510.625000}}],
    Line[{{243390240.000000, -749896704.000000, 669510.625000},{
      257737936.000000, -741646656.000000, 277082.468750}}],
    Line[{{257737936.000000, -741646656.000000, 277082.468750},{
      271821408.000000, -733166144.000000, -111038.171875}}],
    Line[{{271821408.000000, -733166144.000000, -111038.171875},{
      285636544.000000, -724467840.000000, -494742.281250}}],
    Line[{{285636544.000000, -724467840.000000, -494742.281250},{
      299181152.000000, -715564416.000000, -873923.625000}}],
    Line[{{299181152.000000, -715564416.000000, -873923.625000},{
      312454944.000000, -706467584.000000, -1248478.375000}}],
    Line[{{312454944.000000, -706467584.000000, -1248478.375000},{
      325459136.000000, -697188224.000000, -1618305.375000}}],
    Line[{{325459136.000000, -697188224.000000, -1618305.375000},{
      338196128.000000, -687735488.000000, -1983305.375000}}],
    Line[{{338196128.000000, -687735488.000000, -1983305.375000},{
      350669088.000000, -678117440.000000, -2343381.250000}}],
    Line[{{350669088.000000, -678117440.000000, -2343381.250000},{
      362881696.000000, -668340096.000000, -2698437.250000}}],
    Line[{{362881696.000000, -668340096.000000, -2698437.250000},{
      374837632.000000, -658408128.000000, -3048379.750000}}],
    Line[{{374837632.000000, -658408128.000000, -3048379.750000},{
      386540288.000000, -648324608.000000, -3393115.500000}}],
    Line[{{386540288.000000, -648324608.000000, -3393115.500000},{
      397992384.000000, -638091008.000000, -3732552.500000}}],
    Line[{{397992384.000000, -638091008.000000, -3732552.500000},{
      409195712.000000, -627707648.000000, -4066600.000000}}],
    Line[{{409195712.000000, -627707648.000000, -4066600.000000},{
      420150688.000000, -617173824.000000, -4395167.000000}}],
    Line[{{420150688.000000, -617173824.000000, -4395167.000000},{
      430856352.000000, -606488192.000000, -4718165.000000}}],
    Line[{{430856352.000000, -606488192.000000, -4718165.000000},{
      441309920.000000, -595648960.000000, -5035505.500000}}],
    Line[{{441309920.000000, -595648960.000000, -5035505.500000},{
      451506880.000000, -584654720.000000, -5347101.500000}}],
    Line[{{451506880.000000, -584654720.000000, -5347101.500000},{
      461440992.000000, -573504576.000000, -5652867.500000}}],
    Line[{{461440992.000000, -573504576.000000, -5652867.500000},{
      471104416.000000, -562198976.000000, -5952721.000000}}],
    Line[{{471104416.000000, -562198976.000000, -5952721.000000},{
      480488192.000000, -550739840.000000, -6246581.000000}}],
    Line[{{480488192.000000, -550739840.000000, -6246581.000000},{
      489582464.000000, -539131072.000000, -6534369.500000}}],
    Line[{{-29120399360.000000, 143576006656.000000, 
        23961400.000000},{-65698717696.000000, 131251068928.000000, 
        24014752.000000}}],
    Line[{{-65698717696.000000, 131251068928.000000, 
        24014752.000000},{-97879826432.000000, 109995425792.000000, 
        24026608.000000}}],
    Line[{{-97879826432.000000, 109995425792.000000, 
        24026608.000000},{-123515478016.000000, 81278337024.000000, 
        23969654.000000}}],
    Line[{{-123515478016.000000, 81278337024.000000, 
        23969654.000000},{-140939837440.000000, 47073218560.000000, 
        23821310.000000}}],
    Line[{{-140939837440.000000, 47073218560.000000, 
        23821310.000000},{-149079638016.000000, 9696660480.000000, 
        23565260.000000}}],
    Line[{{-149079638016.000000, 9696660480.000000, 
        23565260.000000},{-147509133312.000000, -28370964480.000000, 
        23192408.000000}}],
    Line[{{-147509133312.000000, -28370964480.000000, 
        23192408.000000},{-136450433024.000000, -64663236608.000000, 
        22701200.000000}}],
    Line[{{-136450433024.000000, -64663236608.000000, 
        22701200.000000},{-116727963648.000000, -96889389056.000000, 
        22097380.000000}}],
    Line[{{-116727963648.000000, -96889389056.000000, 
        22097380.000000},{-89687097344.000000, -123069005824.000000, 
        21393280.000000}}],
    Line[{{-89687097344.000000, -123069005824.000000, 
        21393280.000000},{-57089638400.000000, -141635420160.000000, 
        20606750.000000}}],
    Line[{{-57089638400.000000, -141635420160.000000, 
        20606750.000000},{-20996118528.000000, -151507681280.000000, 
        19759908.000000}}],
    Line[{{-20996118528.000000, -151507681280.000000, 19759908.000000},{
      16357169152.000000, -152132845568.000000, 18877866.000000}}],
    Line[{{16357169152.000000, -152132845568.000000, 18877866.000000},{
      52681187328.000000, -143502721024.000000, 17987512.000000}}],
    Line[{{52681187328.000000, -143502721024.000000, 17987512.000000},{
      85754429440.000000, -126147026944.000000, 17116196.000000}}],
    Line[{{85754429440.000000, -126147026944.000000, 17116196.000000},{
      113538686976.000000, -101105549312.000000, 16290226.000000}}],
    Line[{{113538686976.000000, -101105549312.000000, 16290226.000000},{
      134288859136.000000, -69879357440.000000, 15533375.000000}}],
    Line[{{134288859136.000000, -69879357440.000000, 15533375.000000},{
      146654642176.000000, -34360299520.000000, 14865484.000000}}],
    Line[{{146654642176.000000, -34360299520.000000, 14865484.000000},{
      149770321920.000000, 3262162688.000000, 14301217.000000}}],
    Line[{{149770321920.000000, 3262162688.000000, 14301217.000000},{
      143326806016.000000, 40617525248.000000, 13848998.000000}}],
    Line[{{143326806016.000000, 40617525248.000000, 13848998.000000},{
      127618007040.000000, 75292884992.000000, 13510209.000000}}],
    Line[{{127618007040.000000, 75292884992.000000, 13510209.000000},{
      103552827392.000000, 104988778496.000000, 13278775.000000}}],
    Line[{{103552827392.000000, 104988778496.000000, 13278775.000000},{
      72623972352.000000, 127683141632.000000, 13141227.000000}}],
    Line[{{72623972352.000000, 127683141632.000000, 13141227.000000},{
      36828160000.000000, 141789642752.000000, 13077360.000000}}],
    Line[{{
      36828160000.000000, 141789642752.000000, 
        13077360.000000},{-1462398080.000000, 146292981760.000000, 
        13061483.000000}}],
    Line[{{-1462398080.000000, 146292981760.000000, 
        13061483.000000},{-39669788672.000000, 140843663360.000000, 
        13064225.000000}}],
    Line[{{-39669788672.000000, 140843663360.000000, 
        13064225.000000},{-75206475776.000000, 125796958208.000000, 
        13054724.000000}}],
    Line[{{-75206475776.000000, 125796958208.000000, 
        13054724.000000},{-105675997184.000000, 102188613632.000000, 
        13002990.000000}}],
    Line[{{-105675997184.000000, 102188613632.000000, 
        13002990.000000},{-129056677888.000000, 71650672640.000000, 
        12882192.000000}}],
    Line[{{-129056677888.000000, 71650672640.000000, 
        12882192.000000},{-143847030784.000000, 36274987008.000000, 
        12670626.000000}}],
    Line[{{-143847030784.000000, 36274987008.000000, 
        12670626.000000},{-149160165376.000000, -1554992512.000000, 
        12353169.000000}}],
    Line[{{-149160165376.000000, -1554992512.000000, 
        12353169.000000},{-144762191872.000000, -39344844800.000000, 
        11922115.000000}}],
    Line[{{-144762191872.000000, -39344844800.000000, 
        11922115.000000},{-131058221056.000000, -74663927808.000000, 
        11377385.000000}}],
    Line[{{-131058221056.000000, -74663927808.000000, 
        11377385.000000},{-109034848256.000000, -105299820544.000000, 
        10726184.000000}}],
    Line[{{-109034848256.000000, -105299820544.000000, 
        10726184.000000},{-80170958848.000000, -129384030208.000000, 
        9982224.000000}}],
    Line[{{-80170958848.000000, -129384030208.000000, 
        9982224.000000},{-46328397824.000000, -145486004224.000000, 
        9164636.000000}}],
    Line[{{-46328397824.000000, -145486004224.000000, 
        9164636.000000},{-9631693824.000000, -152676302848.000000, 
        8296691.500000}}],
    Line[{{-9631693824.000000, -152676302848.000000, 8296691.500000},{
      27654807552.000000, -150560735232.000000, 7404432.500000}}],
    Line[{{27654807552.000000, -150560735232.000000, 7404432.500000},{
      63249612800.000000, -139290099712.000000, 6515249.000000}}],
    Line[{{63249612800.000000, -139290099712.000000, 6515249.000000},{
      94973100032.000000, -119547174912.000000, 5656451.000000}}],
    Line[{{94973100032.000000, -119547174912.000000, 5656451.000000},{
      120861728768.000000, -92512706560.000000, 4853857.000000}}],
    Line[{{120861728768.000000, -92512706560.000000, 4853857.000000},{
      139275714560.000000, -59810394112.000000, 4130412.000000}}],
    Line[{{139275714560.000000, -59810394112.000000, 4130412.000000},{
      148997947392.000000, -23430029312.000000, 3504864.750000}}],
    Line[{{148997947392.000000, -23430029312.000000, 3504864.750000},{
      149319090176.000000, 14372768768.000000, 2990558.250000}}],
    Line[{{149319090176.000000, 14372768768.000000, 2990558.250000},{
      140103122944.000000, 51199750144.000000, 2594403.000000}}],
    Line[{{140103122944.000000, 51199750144.000000, 2594403.000000},{
      121824591872.000000, 84654440448.000000, 2316140.500000}}],
    Line[{{121824591872.000000, 84654440448.000000, 2316140.500000},{
      95568691200.000000, 112501481472.000000, 2148011.000000}}],
    Line[{{95568691200.000000, 112501481472.000000, 2148011.000000},{
      62986174464.000000, 132830740480.000000, 2074938.875000}}],
    Line[{{62986174464.000000, 132830740480.000000, 2074938.875000},{
      26199001088.000000, 144210575360.000000, 2075309.375000}}],
    Line[{{
      26199001088.000000, 144210575360.000000, 
        2075309.375000},{-12341414912.000000, 145813012480.000000, 
        2122337.500000}}],
    Line[{{-12341414912.000000, 145813012480.000000, 
        2122337.500000},{-50033479680.000000, 137493397504.000000, 
        2185938.750000}}],
    Line[{{-50033479680.000000, 137493397504.000000, 
        2185938.750000},{-84325089280.000000, 119811530752.000000, 
        2234924.500000}}],
    Line[{{-84325089280.000000, 119811530752.000000, 
        2234924.500000},{-112911892480.000000, 93989224448.000000, 
        2239304.250000}}],
    Line[{{-112911892480.000000, 93989224448.000000, 
        2239304.250000},{-133911404544.000000, 61808807936.000000, 
        2172475.000000}}],
    Line[{{-133911404544.000000, 61808807936.000000, 
        2172475.000000},{-145994678272.000000, 25465968640.000000, 
        2013111.500000}}],
    Line[{{-145994678272.000000, 25465968640.000000, 
        2013111.500000},{-148464369664.000000, -12604432384.000000, 
        1746592.125000}}],
    Line[{{-148464369664.000000, -12604432384.000000, 
        1746592.125000},{-141277282304.000000, -49909100544.000000, 
        1365847.625000}}],
    Line[{{-141277282304.000000, -49909100544.000000, 
        1365847.625000},{-125016358912.000000, -84066435072.000000, 
        871585.687500}}],
    Line[{{-125016358912.000000, -84066435072.000000, 
        871585.687500},{-100822810624.000000, -112953073664.000000, 
        271944.812500}}],
    Line[{{-100822810624.000000, -112953073664.000000, 
        271944.812500},{-70299672576.000000, -134820438016.000000, \
-418314.718750}}],
    Line[{{-70299672576.000000, -134820438016.000000, \
-418314.718750},{-35398266880.000000, -148379648000.000000, \
-1178946.125000}}],
    Line[{{-35398266880.000000, -148379648000.000000, -1178946.125000},{
      1703095680.000000, -152855560192.000000, -1985553.875000}}],
    Line[{{1703095680.000000, -152855560192.000000, -1985553.875000},{
      38722629632.000000, -148013678592.000000, -2811051.000000}}],
    Line[{{38722629632.000000, -148013678592.000000, -2811051.000000},{
      73396576256.000000, -134162759680.000000, -3627171.250000}}],
    Line[{{73396576256.000000, -134162759680.000000, -3627171.250000},{
      103597006848.000000, -112135782400.000000, -4405976.500000}}],
    Line[{{103597006848.000000, -112135782400.000000, -4405976.500000},{
      127444344832.000000, -83249799168.000000, -5121250.000000}}],
    Line[{{127444344832.000000, -83249799168.000000, -5121250.000000},{
      143412772864.000000, -49244651520.000000, -5749640.000000}}],
    Line[{{143412772864.000000, -49244651520.000000, -5749640.000000},{
      150425632768.000000, -12199372800.000000, -6271681.500000}}],
    Line[{{150425632768.000000, -12199372800.000000, -6271681.500000},{
      147935739904.000000, 25574742016.000000, -6673142.000000}}],
    Line[{{147935739904.000000, 25574742016.000000, -6673142.000000},{
      135983480832.000000, 61664088064.000000, -6946564.500000}}],
    Line[{{135983480832.000000, 61664088064.000000, -6946564.500000},{
      115224182784.000000, 93702324224.000000, -7092341.500000}}],
    Line[{{115224182784.000000, 93702324224.000000, -7092341.500000},{
      86915547136.000000, 119532503040.000000, -7119095.500000}}],
    Line[{{86915547136.000000, 119532503040.000000, -7119095.500000},{
      52858380288.000000, 137369624576.000000, -7043373.000000}}],
    Line[{{52858380288.000000, 137369624576.000000, -7043373.000000},{
      15287738368.000000, 145947656192.000000, -6888683.500000}}],
    Line[{{
      15287738368.000000, 
        145947656192.000000, -6888683.500000},{-23281172480.000000, 
        144632971264.000000, -6683905.000000}}],
    Line[{{-247064002560.000000, -10316099584.000000, 
        5878799872.000000},{-242899517440.000000, -38497058816.000000, 
        5186353664.000000}}],
    Line[{{-242899517440.000000, -38497058816.000000, 
        5186353664.000000},{-235175051264.000000, -66121850880.000000, 
        4418052608.000000}}],
    Line[{{-235175051264.000000, -66121850880.000000, 
        4418052608.000000},{-223931138048.000000, -92764004352.000000, 
        3583827712.000000}}],
    Line[{{-223931138048.000000, -92764004352.000000, 
        3583827712.000000},{-209254121472.000000, -117989564416.000000, 
        2694889984.000000}}],
    Line[{{-209254121472.000000, -117989564416.000000, 
        2694889984.000000},{-191280332800.000000, -141360316416.000000, 
        1763770624.000000}}],
    Line[{{-191280332800.000000, -141360316416.000000, 
        1763770624.000000},{-170201038848.000000, -162438266880.000000, 
        804344064.000000}}],
    Line[{{-170201038848.000000, -162438266880.000000, 
        804344064.000000},{-146267275264.000000, -180791787520.000000, \
-168177936.000000}}],
    Line[{{-146267275264.000000, -180791787520.000000, \
-168177936.000000},{-119794597888.000000, -196003610624.000000, \
-1137299712.000000}}],
    Line[{{-119794597888.000000, -196003610624.000000, \
-1137299712.000000},{-91167014912.000000, -207681142784.000000, \
-2085358720.000000}}],
    Line[{{-91167014912.000000, -207681142784.000000, \
-2085358720.000000},{-60839383040.000000, -215468916736.000000, \
-2993729536.000000}}],
    Line[{{-60839383040.000000, -215468916736.000000, \
-2993729536.000000},{-29337458688.000000, -219063533568.000000, \
-3843132928.000000}}],
    Line[{{-29337458688.000000, -219063533568.000000, -3843132928.000000},{
      2745493504.000000, -218230439936.000000, -4614071808.000000}}],
    Line[{{2745493504.000000, -218230439936.000000, -4614071808.000000},{
      34756538368.000000, -212821835776.000000, -5287401472.000000}}],
    Line[{{34756538368.000000, -212821835776.000000, -5287401472.000000},{
      65996328960.000000, -202794450944.000000, -5845027840.000000}}],
    Line[{{65996328960.000000, -202794450944.000000, -5845027840.000000},{
      95738208256.000000, -188225388544.000000, -6270707712.000000}}],
    Line[{{95738208256.000000, -188225388544.000000, -6270707712.000000},{
      123253153792.000000, -169323823104.000000, -6550908416.000000}}],
    Line[{{123253153792.000000, -169323823104.000000, -6550908416.000000},{
      147839336448.000000, -146436358144.000000, -6675643392.000000}}],
    Line[{{147839336448.000000, -146436358144.000000, -6675643392.000000},{
      168854405120.000000, -120043937792.000000, -6639201792.000000}}],
    Line[{{168854405120.000000, -120043937792.000000, -6639201792.000000},{
      185747423232.000000, -90749337600.000000, -6440670208.000000}}],
    Line[{{185747423232.000000, -90749337600.000000, -6440670208.000000},{
      198087000064.000000, -59255226368.000000, -6084167168.000000}}],
    Line[{{198087000064.000000, -59255226368.000000, -6084167168.000000},{
      205582516224.000000, -26334453760.000000, -5578740224.000000}}],
    Line[{{205582516224.000000, -26334453760.000000, -5578740224.000000},{
      208095903744.000000, 7204598272.000000, -4937929216.000000}}],
    Line[{{208095903744.000000, 7204598272.000000, -4937929216.000000},{
      205642874880.000000, 40554070016.000000, -4179043840.000000}}],
    Line[{{205642874880.000000, 40554070016.000000, -4179043840.000000},{
      198384222208.000000, 72940355584.000000, -3322240768.000000}}],
    Line[{{198384222208.000000, 72940355584.000000, -3322240768.000000},{
      186608975872.000000, 103652605952.000000, -2389514240.000000}}],
    Line[{{186608975872.000000, 103652605952.000000, -2389514240.000000},{
      170711859200.000000, 132063993856.000000, -1403696768.000000}}],
    Line[{{170711859200.000000, 132063993856.000000, -1403696768.000000},{
      151168368640.000000, 157645160448.000000, -387562336.000000}}],
    Line[{{151168368640.000000, 157645160448.000000, -387562336.000000},{
      128509640704.000000, 179970473984.000000, 636918208.000000}}],
    Line[{{128509640704.000000, 179970473984.000000, 636918208.000000},{
      103299383296.000000, 198717833216.000000, 1649143168.000000}}],
    Line[{{103299383296.000000, 198717833216.000000, 1649143168.000000},{
      76113862656.000000, 213663858688.000000, 2630269952.000000}}],
    Line[{{76113862656.000000, 213663858688.000000, 2630269952.000000},{
      47525838848.000000, 224676036608.000000, 3563445248.000000}}],
    Line[{{47525838848.000000, 224676036608.000000, 3563445248.000000},{
      18092175360.000000, 231703134208.000000, 4433909760.000000}}],
    Line[{{
      18092175360.000000, 231703134208.000000, 
        4433909760.000000},{-11655054336.000000, 234765008896.000000, 
        5229001216.000000}}],
    Line[{{-11655054336.000000, 234765008896.000000, 
        5229001216.000000},{-41214500864.000000, 233942614016.000000, 
        5938095104.000000}}],
    Line[{{-41214500864.000000, 233942614016.000000, 
        5938095104.000000},{-70119120896.000000, 229368856576.000000, 
        6552496640.000000}}],
    Line[{{-70119120896.000000, 229368856576.000000, 
        6552496640.000000},{-97937989632.000000, 221220323328.000000, 
        7065313792.000000}}],
    Line[{{-97937989632.000000, 221220323328.000000, 
        7065313792.000000},{-124276776960.000000, 209710366720.000000, 
        7471326720.000000}}],
    Line[{{-124276776960.000000, 209710366720.000000, 
        7471326720.000000},{-148777467904.000000, 195083206656.000000, 
        7766853120.000000}}],
    Line[{{-148777467904.000000, 195083206656.000000, 
        7766853120.000000},{-171117576192.000000, 177609179136.000000, 
        7949633024.000000}}],
    Line[{{-171117576192.000000, 177609179136.000000, 
        7949633024.000000},{-191009079296.000000, 157581082624.000000, 
        8018723840.000000}}],
    Line[{{-191009079296.000000, 157581082624.000000, 
        8018723840.000000},{-208197500928.000000, 135311245312.000000, 
        7974416384.000000}}],
    Line[{{-208197500928.000000, 135311245312.000000, 
        7974416384.000000},{-222461083648.000000, 111129378816.000000, 
        7818170880.000000}}],
    Line[{{-222461083648.000000, 111129378816.000000, 
        7818170880.000000},{-233610248192.000000, 85381046272.000000, 
        7552569856.000000}}],
    Line[{{-233610248192.000000, 85381046272.000000, 
        7552569856.000000},{-241487577088.000000, 58426531840.000000, 
        7181295104.000000}}],
    Line[{{-241487577088.000000, 58426531840.000000, 
        7181295104.000000},{-245968224256.000000, 30640015360.000000, 
        6709118976.000000}}],
    Line[{{-245968224256.000000, 30640015360.000000, 
        6709118976.000000},{-246960816128.000000, 2408901376.000000, 
        6141914112.000000}}],
    Line[{{-246960816128.000000, 2408901376.000000, 
        6141914112.000000},{-244409106432.000000, -25866874880.000000, 
        5486679552.000000}}],
    Line[{{-244409106432.000000, -25866874880.000000, 
        5486679552.000000},{-238294220800.000000, -53775708160.000000, 
        4751574528.000000}}],
    Line[{{-238294220800.000000, -53775708160.000000, 
        4751574528.000000},{-228637491200.000000, -80895565824.000000, 
        3945966592.000000}}],
    Line[{{-228637491200.000000, -80895565824.000000, 
        3945966592.000000},{-215504076800.000000, -106795868160.000000, 
        3080478464.000000}}],
    Line[{{-215504076800.000000, -106795868160.000000, 
        3080478464.000000},{-199007076352.000000, -131040149504.000000, 
        2167033344.000000}}],
    Line[{{-199007076352.000000, -131040149504.000000, 
        2167033344.000000},{-179312148480.000000, -153189990400.000000, 
        1218887936.000000}}],
    Line[{{-179312148480.000000, -153189990400.000000, 
        1218887936.000000},{-156642476032.000000, -172810272768.000000, 
        250642160.000000}}],
    Line[{{-156642476032.000000, -172810272768.000000, 
        250642160.000000},{-131283607552.000000, -189476290560.000000, \
-721790464.000000}}],
    Line[{{-131283607552.000000, -189476290560.000000, \
-721790464.000000},{-103587856384.000000, -202783080448.000000, \
-1681268736.000000}}],
    Line[{{-103587856384.000000, -202783080448.000000, \
-1681268736.000000},{-73977462784.000000, -212356694016.000000, \
-2609583360.000000}}],
    Line[{{-73977462784.000000, -212356694016.000000, \
-2609583360.000000},{-42945925120.000000, -217868140544.000000, \
-3487717120.000000}}],
    Line[{{-42945925120.000000, -217868140544.000000, \
-3487717120.000000},{-11056309248.000000, -219049328640.000000, \
-4296218112.000000}}],
    Line[{{-11056309248.000000, -219049328640.000000, -4296218112.000000},{
      21064384512.000000, -215710629888.000000, -5015708160.000000}}],
    Line[{{21064384512.000000, -215710629888.000000, -5015708160.000000},{
      52735913984.000000, -207758884864.000000, -5627522048.000000}}],
    Line[{{52735913984.000000, -207758884864.000000, -5627522048.000000},{
      83241189376.000000, -195214524416.000000, -6114467328.000000}}],
    Line[{{83241189376.000000, -195214524416.000000, -6114467328.000000},{
      111848611840.000000, -178225381376.000000, -6461664768.000000}}],
    Line[{{111848611840.000000, -178225381376.000000, -6461664768.000000},{
      137839755264.000000, -157075292160.000000, -6657407488.000000}}],
    Line[{{137839755264.000000, -157075292160.000000, -6657407488.000000},{
      160540770304.000000, -132185145344.000000, -6693953024.000000}}],
    Line[{{160540770304.000000, -132185145344.000000, -6693953024.000000},{
      179354894336.000000, -104104722432.000000, -6568153088.000000}}],
    Line[{{179354894336.000000, -104104722432.000000, -6568153088.000000},{
      193792950272.000000, -73494921216.000000, -6281831424.000000}}],
    Line[{{193792950272.000000, -73494921216.000000, -6281831424.000000},{
      203498012672.000000, -41101320192.000000, -5841842176.000000}}],
    Line[{{203498012672.000000, -41101320192.000000, -5841842176.000000},{
      208261906432.000000, -7721298432.000000, -5259781120.000000}}],
    Line[{{208261906432.000000, -7721298432.000000, -5259781120.000000},{
      208031137792.000000, 25831948288.000000, -4551378944.000000}}],
    Line[{{208031137792.000000, 25831948288.000000, -4551378944.000000},{
      202902716416.000000, 58764681216.000000, -3735650816.000000}}],
    Line[{{202902716416.000000, 58764681216.000000, -3735650816.000000},{
      193110474752.000000, 90333896704.000000, -2833913600.000000}}],
    Line[{{193110474752.000000, 90333896704.000000, -2833913600.000000},{
      179004915712.000000, 119872094208.000000, -1868763520.000000}}],
    Line[{{179004915712.000000, 119872094208.000000, -1868763520.000000},{
      161028767744.000000, 146804359168.000000, -863125184.000000}}],
    Line[{{161028767744.000000, 146804359168.000000, -863125184.000000},{
      139691720704.000000, 170657726464.000000, 160570160.000000}}],
    Line[{{267552997376.000000, 704820019200.000000, -8910999552.000000},{
      251663843328.000000, 711365558272.000000, -8582517760.000000}}],
    Line[{{251663843328.000000, 711365558272.000000, -8582517760.000000},{
      235647827968.000000, 717553139712.000000, -8249709056.000000}}],
    Line[{{235647827968.000000, 717553139712.000000, -8249709056.000000},{
      219513307136.000000, 723380535296.000000, -7912752640.000000}}],
    Line[{{219513307136.000000, 723380535296.000000, -7912752640.000000},{
      203268718592.000000, 728845844480.000000, -7571828224.000000}}],
    Line[{{203268718592.000000, 728845844480.000000, -7571828224.000000},{
      186922434560.000000, 733947363328.000000, -7227116544.000000}}],
    Line[{{186922434560.000000, 733947363328.000000, -7227116544.000000},{
      170482892800.000000, 738683453440.000000, -6878800384.000000}}],
    Line[{{170482892800.000000, 738683453440.000000, -6878800384.000000},{
      153958531072.000000, 743052935168.000000, -6527063040.000000}}],
    Line[{{153958531072.000000, 743052935168.000000, -6527063040.000000},{
      137357754368.000000, 747054628864.000000, -6172087296.000000}}],
    Line[{{137357754368.000000, 747054628864.000000, -6172087296.000000},{
      120688984064.000000, 750687551488.000000, -5814059008.000000}}],
    Line[{{120688984064.000000, 750687551488.000000, -5814059008.000000},{
      103960616960.000000, 753951113216.000000, -5453162496.000000}}],
    Line[{{103960616960.000000, 753951113216.000000, -5453162496.000000},{
      87181033472.000000, 756844724224.000000, -5089583616.000000}}],
    Line[{{87181033472.000000, 756844724224.000000, -5089583616.000000},{
      70358605824.000000, 759368122368.000000, -4723508224.000000}}],
    Line[{{70358605824.000000, 759368122368.000000, -4723508224.000000},{
      53501657088.000000, 761521111040.000000, -4355122176.000000}}],
    Line[{{53501657088.000000, 761521111040.000000, -4355122176.000000},{
      36618493952.000000, 763303755776.000000, -3984611840.000000}}],
    Line[{{36618493952.000000, 763303755776.000000, -3984611840.000000},{
      19717382144.000000, 764716384256.000000, -3612163072.000000}}],
    Line[{{19717382144.000000, 764716384256.000000, -3612163072.000000},{
      2806541056.000000, 765759455232.000000, -3237961984.000000}}],
    Line[{{
      2806541056.000000, 
        765759455232.000000, -3237961984.000000},{-14105848832.000000, 
        766433558528.000000, -2862193920.000000}}],
    Line[{{-14105848832.000000, 
        766433558528.000000, -2862193920.000000},{-31011659776.000000, 
        766739480576.000000, -2485044992.000000}}],
    Line[{{-31011659776.000000, 
        766739480576.000000, -2485044992.000000},{-47902814208.000000, 
        766678204416.000000, -2106699264.000000}}],
    Line[{{-47902814208.000000, 
        766678204416.000000, -2106699264.000000},{-64771301376.000000, 
        766251040768.000000, -1727341568.000000}}],
    Line[{{-64771301376.000000, 
        766251040768.000000, -1727341568.000000},{-81609154560.000000, 
        765459169280.000000, -1347155584.000000}}],
    Line[{{-81609154560.000000, 
        765459169280.000000, -1347155584.000000},{-98408497152.000000, 
        764304228352.000000, -966324096.000000}}],
    Line[{{-98408497152.000000, 
        764304228352.000000, -966324096.000000},{-115161489408.000000, 
        762787856384.000000, -585029440.000000}}],
    Line[{{-115161489408.000000, 
        762787856384.000000, -585029440.000000},{-131860389888.000000, 
        760911888384.000000, -203452656.000000}}],
    Line[{{-131860389888.000000, 
        760911888384.000000, -203452656.000000},{-148497530880.000000, 
        758678355968.000000, 178225952.000000}}],
    Line[{{-148497530880.000000, 758678355968.000000, 
        178225952.000000},{-165065293824.000000, 756089487360.000000, 
        559827264.000000}}],
    Line[{{-165065293824.000000, 756089487360.000000, 
        559827264.000000},{-181556166656.000000, 753147576320.000000, 
        941173440.000000}}],
    Line[{{-181556166656.000000, 753147576320.000000, 
        941173440.000000},{-197962743808.000000, 749855047680.000000, 
        1322087680.000000}}],
    Line[{{-197962743808.000000, 749855047680.000000, 
        1322087680.000000},{-214277652480.000000, 746214653952.000000, 
        1702394496.000000}}],
    Line[{{-214277652480.000000, 746214653952.000000, 
        1702394496.000000},{-230493634560.000000, 742229082112.000000, 
        2081920128.000000}}],
    Line[{{-230493634560.000000, 742229082112.000000, 
        2081920128.000000},{-246603546624.000000, 737901346816.000000, 
        2460492032.000000}}],
    Line[{{-246603546624.000000, 737901346816.000000, 
        2460492032.000000},{-262600310784.000000, 733234397184.000000, 
        2837938944.000000}}],
    Line[{{-262600310784.000000, 733234397184.000000, 
        2837938944.000000},{-278476947456.000000, 728231510016.000000, 
        3214091776.000000}}],
    Line[{{-278476947456.000000, 728231510016.000000, 
        3214091776.000000},{-294226591744.000000, 722896093184.000000, 
        3588782848.000000}}],
    Line[{{-294226591744.000000, 722896093184.000000, 
        3588782848.000000},{-309842477056.000000, 717231489024.000000, 
        3961845760.000000}}],
    Line[{{-309842477056.000000, 717231489024.000000, 
        3961845760.000000},{-325317918720.000000, 711241302016.000000, 
        4333116416.000000}}],
    Line[{{-325317918720.000000, 711241302016.000000, 
        4333116416.000000},{-340646363136.000000, 704929398784.000000, 
        4702432768.000000}}],
    Line[{{-340646363136.000000, 704929398784.000000, 
        4702432768.000000},{-355821322240.000000, 698299449344.000000, 
        5069633536.000000}}],
    Line[{{-355821322240.000000, 698299449344.000000, 
        5069633536.000000},{-370836471808.000000, 691355451392.000000, 
        5434560512.000000}}],
    Line[{{-370836471808.000000, 691355451392.000000, 
        5434560512.000000},{-385685585920.000000, 684101599232.000000, 
        5797057536.000000}}],
    Line[{{-385685585920.000000, 684101599232.000000, 
        5797057536.000000},{-400362504192.000000, 676541890560.000000, 
        6156968960.000000}}],
    Line[{{-400362504192.000000, 676541890560.000000, 
        6156968960.000000},{-414861197312.000000, 668680781824.000000, 
        6514143232.000000}}],
    Line[{{-414861197312.000000, 668680781824.000000, 
        6514143232.000000},{-429175799808.000000, 660522598400.000000, 
        6868429312.000000}}],
    Line[{{-429175799808.000000, 660522598400.000000, 
        6868429312.000000},{-443300511744.000000, 652071796736.000000, 
        7219679232.000000}}],
    Line[{{-443300511744.000000, 652071796736.000000, 
        7219679232.000000},{-457229664256.000000, 643333095424.000000, 
        7567746560.000000}}],
    Line[{{-457229664256.000000, 643333095424.000000, 
        7567746560.000000},{-470957654016.000000, 634311016448.000000, 
        7912487424.000000}}],
    Line[{{-470957654016.000000, 634311016448.000000, 
        7912487424.000000},{-484479074304.000000, 625010540544.000000, 
        8253760512.000000}}],
    Line[{{-484479074304.000000, 625010540544.000000, 
        8253760512.000000},{-497788616704.000000, 615436386304.000000, 
        8591425536.000000}}],
    Line[{{-497788616704.000000, 615436386304.000000, 
        8591425536.000000},{-510881071104.000000, 605593534464.000000, 
        8925346816.000000}}],
    Line[{{-510881071104.000000, 605593534464.000000, 
        8925346816.000000},{-523751325696.000000, 595487096832.000000, 
        9255389184.000000}}],
    Line[{{-523751325696.000000, 595487096832.000000, 
        9255389184.000000},{-536394432512.000000, 585122185216.000000, 
        9581419520.000000}}],
    Line[{{-536394432512.000000, 585122185216.000000, 
        9581419520.000000},{-548805574656.000000, 574503976960.000000, 
        9903308800.000000}}],
    Line[{{-548805574656.000000, 574503976960.000000, 
        9903308800.000000},{-560980033536.000000, 563637714944.000000, 
        10220929024.000000}}],
    Line[{{-560980033536.000000, 563637714944.000000, 
        10220929024.000000},{-572913156096.000000, 552528838656.000000, 
        10534154240.000000}}],
    Line[{{-572913156096.000000, 552528838656.000000, 
        10534154240.000000},{-584600453120.000000, 541182689280.000000, 
        10842862592.000000}}],
    Line[{{-584600453120.000000, 541182689280.000000, 
        10842862592.000000},{-596037730304.000000, 529604771840.000000, 
        11146934272.000000}}],
    Line[{{-596037730304.000000, 529604771840.000000, 
        11146934272.000000},{-607220531200.000000, 517800656896.000000, 
        11446250496.000000}}],
    Line[{{-607220531200.000000, 517800656896.000000, 
        11446250496.000000},{-618144923648.000000, 505775882240.000000, 
        11740696576.000000}}],
    Line[{{-618144923648.000000, 505775882240.000000, 
        11740696576.000000},{-628806844416.000000, 493536215040.000000, 
        12030159872.000000}}],
    Line[{{-628806844416.000000, 493536215040.000000, 
        12030159872.000000},{-639202426880.000000, 481087291392.000000, 
        12314529792.000000}}],
    Line[{{-639202426880.000000, 481087291392.000000, 
        12314529792.000000},{-649328001024.000000, 468434944000.000000, 
        12593698816.000000}}],
    Line[{{-649328001024.000000, 468434944000.000000, 
        12593698816.000000},{-659179831296.000000, 455584972800.000000, 
        12867561472.000000}}],
    Line[{{-659179831296.000000, 455584972800.000000, 
        12867561472.000000},{-668754509824.000000, 442543243264.000000, 
        13136015360.000000}}],
    Line[{{-668754509824.000000, 442543243264.000000, 
        13136015360.000000},{-678048628736.000000, 429315686400.000000, 
        13398961152.000000}}],
    Line[{{-678048628736.000000, 429315686400.000000, 
        13398961152.000000},{-687058976768.000000, 415908298752.000000, 
        13656299520.000000}}],
    Line[{{-687058976768.000000, 415908298752.000000, 
        13656299520.000000},{-695782408192.000000, 402327011328.000000, 
        13907937280.000000}}],
    Line[{{-695782408192.000000, 402327011328.000000, 
        13907937280.000000},{-704215908352.000000, 388577951744.000000, 
        14153782272.000000}}],
    Line[{{-704215908352.000000, 388577951744.000000, 
        14153782272.000000},{-712356593664.000000, 374667149312.000000, 
        14393743360.000000}}],
    Line[{{-712356593664.000000, 374667149312.000000, 
        14393743360.000000},{-720201777152.000000, 360600764416.000000, 
        14627733504.000000}}],
    Line[{{-720201777152.000000, 360600764416.000000, 
        14627733504.000000},{-727748706304.000000, 346384859136.000000, 
        14855669760.000000}}],
    Line[{{-727748706304.000000, 346384859136.000000, 
        14855669760.000000},{-734994890752.000000, 332025724928.000000, 
        15077468160.000000}}],
    Line[{{-734994890752.000000, 332025724928.000000, 
        15077468160.000000},{-741937971200.000000, 317529489408.000000, 
        15293049856.000000}}],
    Line[{{-741937971200.000000, 317529489408.000000, 
        15293049856.000000},{-748575719424.000000, 302902378496.000000, 
        15502339072.000000}}],
    Line[{{-748575719424.000000, 302902378496.000000, 
        15502339072.000000},{-754905907200.000000, 288150716416.000000, 
        15705261056.000000}}],
    Line[{{-29120495616.000000, 143576498176.000000, 
        23961400.000000},{-61692342272.000000, 175852371968.000000, 
        613747328.000000}}],
    Line[{{-61692342272.000000, 175852371968.000000, 
        613747328.000000},{-92257746944.000000, 202092314624.000000, 
        1185063296.000000}}],
    Line[{{-92257746944.000000, 202092314624.000000, 
        1185063296.000000},{-121021366272.000000, 224277135360.000000, 
        1733804416.000000}}],
    Line[{{-121021366272.000000, 224277135360.000000, 
        1733804416.000000},{-148211384320.000000, 243494813696.000000, 
        2260286976.000000}}],
    Line[{{-148211384320.000000, 243494813696.000000, 
        2260286976.000000},{-174021410816.000000, 260416765952.000000, 
        2765893120.000000}}],
    Line[{{-174021410816.000000, 260416765952.000000, 
        2765893120.000000},{-198608617472.000000, 275490930688.000000, 
        3252174848.000000}}],
    Line[{{-198608617472.000000, 275490930688.000000, 
        3252174848.000000},{-222100389888.000000, 289033584640.000000, 
        3720598016.000000}}],
    Line[{{-222100389888.000000, 289033584640.000000, 
        3720598016.000000},{-244600946688.000000, 301277708288.000000, 
        4172474368.000000}}],
    Line[{{-244600946688.000000, 301277708288.000000, 
        4172474368.000000},{-266196516864.000000, 312400838656.000000, 
        4608957952.000000}}],
    Line[{{-266196516864.000000, 312400838656.000000, 
        4608957952.000000},{-286959370240.000000, 322541879296.000000, 
        5031058944.000000}}],
    Line[{{-286959370240.000000, 322541879296.000000, 
        5031058944.000000},{-306950701056.000000, 331812012032.000000, 
        5439662080.000000}}],
    Line[{{-306950701056.000000, 331812012032.000000, 
        5439662080.000000},{-326222872576.000000, 340301807616.000000, 
        5835544064.000000}}],
    Line[{{-326222872576.000000, 340301807616.000000, 
        5835544064.000000},{-344821170176.000000, 348086239232.000000, 
        6219390976.000000}}],
    Line[{{-344821170176.000000, 348086239232.000000, 
        6219390976.000000},{-362784948224.000000, 355228319744.000000, 
        6591810048.000000}}],
    Line[{{-362784948224.000000, 355228319744.000000, 
        6591810048.000000},{-380148776960.000000, 361781362688.000000, 
        6953341952.000000}}],
    Line[{{-380148776960.000000, 361781362688.000000, 
        6953341952.000000},{-396943163392.000000, 367791276032.000000, 
        7304469504.000000}}],
    Line[{{-396943163392.000000, 367791276032.000000, 
        7304469504.000000},{-413195173888.000000, 373297676288.000000, 
        7645626880.000000}}],
    Line[{{-413195173888.000000, 373297676288.000000, 
        7645626880.000000},{-428928991232.000000, 378335133696.000000, 
        7977204736.000000}}],
    Line[{{-428928991232.000000, 378335133696.000000, 
        7977204736.000000},{-444166340608.000000, 382934024192.000000, 
        8299556352.000000}}],
    Line[{{-444166340608.000000, 382934024192.000000, 
        8299556352.000000},{-458926686208.000000, 387121283072.000000, 
        8613002240.000000}}],
    Line[{{-458926686208.000000, 387121283072.000000, 
        8613002240.000000},{-473227755520.000000, 390920765440.000000, 
        8917833728.000000}}],
    Line[{{-473227755520.000000, 390920765440.000000, 
        8917833728.000000},{-487085539328.000000, 394353836032.000000, 
        9214317568.000000}}],
    Line[{{-487085539328.000000, 394353836032.000000, 
        9214317568.000000},{-500514619392.000000, 397439696896.000000, 
        9502695424.000000}}],
    Line[{{-500514619392.000000, 397439696896.000000, 
        9502695424.000000},{-513528332288.000000, 400195682304.000000, 
        9783189504.000000}}],
    Line[{{-513528332288.000000, 400195682304.000000, 
        9783189504.000000},{-526138802176.000000, 402637520896.000000, 
        10056005632.000000}}],
    Line[{{-526138802176.000000, 402637520896.000000, 
        10056005632.000000},{-538357202944.000000, 404779433984.000000, 
        10321331200.000000}}],
    Line[{{-538357202944.000000, 404779433984.000000, 
        10321331200.000000},{-550193790976.000000, 406634463232.000000, 
        10579338240.000000}}],
    Line[{{-550193790976.000000, 406634463232.000000, 
        10579338240.000000},{-561658003456.000000, 408214536192.000000, 
        10830185472.000000}}],
    Line[{{-561658003456.000000, 408214536192.000000, 
        10830185472.000000},{-572758491136.000000, 409530597376.000000, 
        11074022400.000000}}],
    Line[{{-572758491136.000000, 409530597376.000000, 
        11074022400.000000},{-583503314944.000000, 410592739328.000000, 
        11310982144.000000}}],
    Line[{{-583503314944.000000, 410592739328.000000, 
        11310982144.000000},{-593899749376.000000, 411410235392.000000, 
        11541189632.000000}}],
    Line[{{-593899749376.000000, 411410235392.000000, 
        11541189632.000000},{-603954806784.000000, 411991703552.000000, 
        11764762624.000000}}],
    Line[{{-603954806784.000000, 411991703552.000000, 
        11764762624.000000},{-613674647552.000000, 412345139200.000000, 
        11981806592.000000}}],
    Line[{{-613674647552.000000, 412345139200.000000, 
        11981806592.000000},{-623065235456.000000, 412477915136.000000, 
        12192419840.000000}}],
    Line[{{-623065235456.000000, 412477915136.000000, 
        12192419840.000000},{-632131813376.000000, 412396945408.000000, 
        12396693504.000000}}],
    Line[{{-632131813376.000000, 412396945408.000000, 
        12396693504.000000},{-640879493120.000000, 412108685312.000000, 
        12594711552.000000}}],
    Line[{{-640879493120.000000, 412108685312.000000, 
        12594711552.000000},{-649312862208.000000, 411619131392.000000, 
        12786550784.000000}}],
    Line[{{-649312862208.000000, 411619131392.000000, 
        12786550784.000000},{-657436180480.000000, 410933886976.000000, 
        12972281856.000000}}],
    Line[{{-657436180480.000000, 410933886976.000000, 
        12972281856.000000},{-665253249024.000000, 410058227712.000000, 
        13151970304.000000}}],
    Line[{{-665253249024.000000, 410058227712.000000, 
        13151970304.000000},{-672767868928.000000, 408997134336.000000, 
        13325673472.000000}}],
    Line[{{-672767868928.000000, 408997134336.000000, 
        13325673472.000000},{-679983120384.000000, 407755194368.000000, 
        13493446656.000000}}],
    Line[{{-679983120384.000000, 407755194368.000000, 
        13493446656.000000},{-686902214656.000000, 406336831488.000000, 
        13655337984.000000}}],
    Line[{{-686902214656.000000, 406336831488.000000, 
        13655337984.000000},{-693527838720.000000, 404746141696.000000, 
        13811391488.000000}}],
    Line[{{-693527838720.000000, 404746141696.000000, 
        13811391488.000000},{-699862482944.000000, 402987024384.000000, 
        13961647104.000000}}],
    Line[{{-699862482944.000000, 402987024384.000000, 
        13961647104.000000},{-705908375552.000000, 401063149568.000000, 
        14106137600.000000}}],
    Line[{{-705908375552.000000, 401063149568.000000, 
        14106137600.000000},{-711667613696.000000, 398977990656.000000, 
        14244893696.000000}}],
    Line[{{-711667613696.000000, 398977990656.000000, 
        14244893696.000000},{-717141966848.000000, 396734824448.000000, 
        14377943040.000000}}],
    Line[{{-717141966848.000000, 396734824448.000000, 
        14377943040.000000},{-722333007872.000000, 394336796672.000000, 
        14505305088.000000}}],
    Line[{{-722333007872.000000, 394336796672.000000, 
        14505305088.000000},{-727242113024.000000, 391786823680.000000, 
        14626998272.000000}}],
    Line[{{-727242113024.000000, 391786823680.000000, 
        14626998272.000000},{-731870461952.000000, 389087756288.000000, 
        14743036928.000000}}],
    Line[{{-731870461952.000000, 389087756288.000000, 
        14743036928.000000},{-736218906624.000000, 386242248704.000000, 
        14853430272.000000}}],
    Line[{{-736218906624.000000, 386242248704.000000, 
        14853430272.000000},{-740288299008.000000, 383252922368.000000, 
        14958183424.000000}}],
    Line[{{-740288299008.000000, 383252922368.000000, 
        14958183424.000000},{-744079163392.000000, 380122136576.000000, 
        15057297408.000000}}],
    Line[{{-744079163392.000000, 380122136576.000000, 
        15057297408.000000},{-747591761920.000000, 376852316160.000000, 
        15150770176.000000}}],
    Line[{{-747591761920.000000, 376852316160.000000, 
        15150770176.000000},{-750826291200.000000, 373445656576.000000, 
        15238595584.000000}}],
    Line[{{-750826291200.000000, 373445656576.000000, 
        15238595584.000000},{-753782685696.000000, 369904386048.000000, 
        15320761344.000000}}],
    Line[{{-753782685696.000000, 369904386048.000000, 
        15320761344.000000},{-756460683264.000000, 366230601728.000000, 
        15397252096.000000}}],
    Line[{{-756460683264.000000, 366230601728.000000, 
        15397252096.000000},{-758859694080.000000, 362426400768.000000, 
        15468046336.000000}}],
    Line[{{-758859694080.000000, 362426400768.000000, 
        15468046336.000000},{-760978997248.000000, 358493749248.000000, 
        15533119488.000000}}],
    Line[{{-760978997248.000000, 358493749248.000000, 
        15533119488.000000},{-762817609728.000000, 354434744320.000000, 
        15592440832.000000}}],
    Line[{{-762817609728.000000, 354434744320.000000, 
        15592440832.000000},{-764374155264.000000, 350251417600.000000, 
        15645970432.000000}}],
    Line[{{-764374155264.000000, 350251417600.000000, 
        15645970432.000000},{-765647192064.000000, 345945833472.000000, 
        15693665280.000000}}],
    Line[{{-765647192064.000000, 345945833472.000000, 
        15693665280.000000},{-766634622976.000000, 341520252928.000000, 
        15735471104.000000}}],
    Line[{{-766634622976.000000, 341520252928.000000, 
        15735471104.000000},{-767334154240.000000, 336977002496.000000, 
        15771325440.000000}}],
    Line[{{-767334154240.000000, 336977002496.000000, 
        15771325440.000000},{-767742836736.000000, 332318736384.000000, 
        15801150464.000000}}],
    Line[{{-767742836736.000000, 332318736384.000000, 
        15801150464.000000},{-767857065984.000000, 327548600320.000000, 
        15824852992.000000}}],
    Line[{{-767857065984.000000, 327548600320.000000, 
        15824852992.000000},{-767672320000.000000, 322670329856.000000, 
        15842314240.000000}}],
    Line[{{-767672320000.000000, 322670329856.000000, 
        15842314240.000000},{-767182569472.000000, 317689004032.000000, 
        15853379584.000000}}],
    Line[{{-767182569472.000000, 317689004032.000000, 
        15853379584.000000},{-766379622400.000000, 312611569664.000000, 
        15857837056.000000}}],
    Line[{{-766379622400.000000, 312611569664.000000, 
        15857837056.000000},{-765251289088.000000, 307448905728.000000, 
        15855367168.000000}}],
    Line[{{-765251289088.000000, 307448905728.000000, 
        15855367168.000000},{-763777253376.000000, 302219919360.000000, 
        15845435392.000000}}],
    Line[{{-763777253376.000000, 302219919360.000000, 
        15845435392.000000},{-761917014016.000000, 296963833856.000000, 
        15826970624.000000}}],
    Line[{{-761917014016.000000, 296963833856.000000, 
        15826970624.000000},{-759558701056.000000, 291791929344.000000, 
        15796987904.000000}}],
    Line[{{-759558701056.000000, 291791929344.000000, 
        15796987904.000000},{-755584925696.000000, 287739445248.000000, 
        15725012992.000000}}]},
    Boxed -> True,
    Lighting -> True,
    SphericalRegion -> False,
    BoxRatios -> {1.000000, 1.000000, 1.000000},
    ViewPoint -> {-2.088495, 2.262513, 2.464927}
  ]
], "Graphics",
  ImageSize->{329.375, 329.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006K0001Vb000`400?l00000o`00003oo`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL
0?ooo`00o`3ooonL0?ooo`00f@3oool00`000000oooo0?ooo`2o0?ooo`00e`3oool400000<00oooo
003F0?ooo`060000003oool0oooo0000003oool00000_`3oool00=D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0;`0oooo003C0?ooo`800000103oool010000000oooo
0?ooo`3oool200000;`0oooo003B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2i0?ooo`00d@3oool00`000000oooo0?ooo`030?ooo`80000000<0
oooo0000003oool0103oool00`000000oooo0?ooo`2h0?ooo`00c`3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;L0oooo003>0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?oo
o`3oool0]P3oool00<`0oooo0P0000050?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0;D0oooo003;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;@0oooo003:0?ooo`030000003o
ool0oooo00<0oooo0P00000>0?ooo`030000003oool0oooo0080oooo0P00002d0?ooo`00b03oool2
000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0;40oooo00370?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0;00oooo00360?ooo`030000003oool0oooo00<0
oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0[`3oool00<@0oooo
0P0000050?ooo`030000003oool0oooo01H0oooo0P0000040?ooo`030000003oool0oooo0:h0oooo
00330?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0:d0oooo00310?ooo`8000001@3oool2000001d0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`2/0?ooo`00`03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool200000:`0oooo002o0?ooo`03
0000003oool0oooo00<0oooo0P00000R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0Z@3oool00;d0oooo0P0000050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2X0?ooo`00_03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02D0oooo0P0000040?ooo`030000003oool0oooo0:L0oooo002j0?ooo`8000001@3oool2
000002X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2V0?ooo`00^@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`2U0?ooo`00^03oool00`000000oooo0?ooo`030?ooo`800000;`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0:@0oooo002f0?ooo`8000001@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo0080oooo0P00002T0?ooo`00]@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`2Q0?ooo`00]03oool00`000000oooo0?ooo`030?ooo`800000=P3oool2000000@0oooo00<00000
0?ooo`3oool0X03oool00;80oooo0P0000050?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`2O0?ooo`00/@3oool00`000000oooo0?ooo`030?ooo`80
0000?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09h0oooo002_0?ooo`800000
1@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
W@3oool00:h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0W03oool00:d0oooo00<000000?ooo`3oool00`3oool2
000004<0oooo00<000000?ooo`3oool00P3oool2000009`0oooo002[0?ooo`8000001@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0V@3oool00:X0
oooo00<000000?ooo`3oool00`3oool2000004P0oooo0P0000040?ooo`030000003oool0oooo09P0
oooo002Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo09L0oooo002W0?ooo`8000001@3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0UP3oool00:H0oooo00<00000
0?ooo`3oool00`3oool200000500oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2E
0?ooo`00Y03oool2000000D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo09@0oooo002S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`020?ooo`800000U03oool00:80oooo00<000000?ooo`3oool0
0`3oool2000005L0oooo0P0000040?ooo`030000003oool0oooo0940oooo002P0?ooo`8000001@3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0T03o
ool009l0oooo00<000000?ooo`3oool00`3oool2000005d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2?0?ooo`00WP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2>0?ooo`00W03oool2000000D0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08d0
oooo002K0?ooo`030000003oool0oooo00<0oooo0P00001T0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0S03oool009T0oooo0P0000050?ooo`030000003oool0oooo06D0oooo0P00
00030?ooo`800000S03oool009P0oooo00<000000?ooo`3oool00`3oool2000006X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`290?ooo`00U`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`280?oo
o`00U@3oool2000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo08L0oooo002D0?ooo`030000003oool0oooo00<0oooo0P00001a0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0QP3oool00980oooo0P0000050?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`250?ooo`00T@3oool0
0`000000oooo0?ooo`030?ooo`800000MP3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo08@0oooo002@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0M`3oool20000
00<0oooo0P0000240?ooo`00SP3oool2000000D0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0840oooo002=0?ooo`030000003oool0oooo00<0oooo
0P00001n0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P03oool008`0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0O`3oool008X0oooo0P0000050?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1n0?ooo`00R@3oool00`000000oooo0?ooo`030?oo
o`800000Q@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07d0oooo00270?ooo`80
00001@3oool00`000000oooo0?ooo`260?ooo`8000000`3oool00`000000oooo0?ooo`1l0?ooo`00
QP3oool00`000000oooo0?ooo`030?ooo`800000R`3oool010000000oooo0?ooo`3oool2000007`0
oooo00250?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07T0oooo00230?ooo`8000001@3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0N03oool00880oooo00<00000
0?ooo`3oool00`3oool200000980oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1g
0?ooo`00P@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1f0?ooo`00O`3oool2000000@0oooo0P00002G0?ooo`80
00000`3oool00`000000oooo0?ooo`1e0?ooo`00OP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04P0oooo1`00001:0?ooo`050000003oool0oooo0?ooo`000000MP3oool007`0oooo
0P0000050?ooo`030000003oool0oooo03L0oooo4P0000070?oooa800000>@3oool01@000000oooo
0?ooo`3oool0000007D0oooo001k0?ooo`030000003oool0oooo00<0oooo0P00000_0?ooo`/00000
:`3oool:00000300oooo00@000000?ooo`3oool0oooo0P00001c0?ooo`00NP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02P0oooo1`0000100?ooo`L000003P3oool<00000100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1`0?ooo`00N03oool2000000@0oooo0P00
000X0?ooo`<00000CP3oool4000000H0oooo1000000<0?ooo`<000003P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo06l0oooo001g0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08@3oool7000005D0oooo1`00000A0?ooo`8000003P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo06h0oooo001f0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool07`3oool3000005d0oooo0`0000030?ooo`<00000403oool2000000d0oooo0P0000030?oo
o`030000003oool0oooo06d0oooo001d0?ooo`800000103oool2000001h0oooo1000001N0?ooo`80
00002@3oool3000000h0oooo0P00000>0?ooo`050000003oool0oooo0?ooo`000000KP3oool007<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`<00000H03oool2000000h0
oooo1000000<0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000001]0?oo
o`00L@3oool2000000@0oooo0P00000K0?ooo`<00000H@3oool2000001@0oooo1P0000070?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool0oooo0P00001[0?ooo`00L03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo0`00001S0?ooo`030000003oool0oooo01X0
oooo0`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1X0?ooo`00K`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo
1000001T0?ooo`800000803oool3000000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1W0?ooo`00K@3oool2000000@0oooo0P00000E0?ooo`<00000I`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo0P0000030?ooo`030000003o
ool0oooo06H0oooo001/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool3
000006P0oooo0P00000k0?ooo`050000003oool0oooo0?ooo`000000I`3oool006X0oooo0P000005
0?ooo`030000003oool0oooo0100oooo0`00001Y0?ooo`800000?P3oool01@000000oooo0?ooo`3o
ool0000006H0oooo001Y0?ooo`030000003oool0oooo00<0oooo0P00000@0?ooo`<00000J`3oool0
0`000000oooo0?ooo`0o0?ooo`050000003oool0oooo0?ooo`000000I@3oool006P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`800000K03oool2000004<0oooo00@00000
0?ooo`3oool0oooo0P00001S0?ooo`00IP3oool2000000@0oooo0P00000?0?ooo`800000K@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H03oool0
06D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`800000KP3oool00`00
0000oooo0?ooo`160?ooo`8000000`3oool00`000000oooo0?ooo`1O0?ooo`00I03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo0P00001_0?ooo`030000003oool0oooo04T0
oooo00D000000?ooo`3oool0oooo0000001P0?ooo`00HP3oool2000000@0oooo0P00000=0?ooo`80
0000K`3oool2000004d0oooo00D000000?ooo`3oool0oooo0000001O0?ooo`00H@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P00001`0?ooo`030000003oool0oooo04h0
oooo00D000000?ooo`3oool0oooo0000001N0?ooo`00G`3oool2000000@0oooo0P00000<0?ooo`80
0000LP3oool00`000000oooo0?ooo`1?0?ooo`050000003oool0oooo0?ooo`000000G@3oool005h0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`800000LP3oool2000005<0
oooo00@000000?ooo`3oool0oooo0P00001K0?ooo`00G@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0F03oool005/0oooo0P0000040?ooo`800000
2`3oool2000007<0oooo00<000000?ooo`3oool0EP3oool2000000<0oooo00<000000?ooo`3oool0
E`3oool005X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`800000M03o
ool00`000000oooo0?ooo`1I0?ooo`050000003oool0oooo0?ooo`000000F03oool005T0oooo00<0
00000?ooo`3oool00P3oool2000000/0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`1K0?ooo`050000003oool0oooo0?ooo`000000E`3oool005L0oooo0P0000040?ooo`030000003o
ool0oooo00T0oooo0P00001e0?ooo`030000003oool0oooo05d0oooo00D000000?ooo`3oool0oooo
0000001F0?ooo`00EP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0P00
001f0?ooo`030000003oool0oooo05l0oooo00D000000?ooo`3oool0oooo0000001E0?ooo`00E03o
ool2000000@0oooo0P00000:0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0H@3o
ool010000000oooo0?ooo`3oool2000005<0oooo001C0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo06<0oooo0P00
00030?ooo`030000003oool0oooo0500oooo001B0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool2000007L0oooo00<000000?ooo`3oool0IP3oool01@000000oooo0?ooo`3o
ool000000540oooo001@0?ooo`800000103oool2000000T0oooo0P00001h0?ooo`030000003oool0
oooo06P0oooo00D000000?ooo`3oool0oooo0000001@0?ooo`00C`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1Y
0?ooo`050000003oool0oooo0?ooo`000000C`3oool004h0oooo00<000000?ooo`3oool00P3oool2
000000X0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1[0?ooo`050000003oool0
oooo0?ooo`000000CP3oool004`0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`1]0?ooo`050000003oool0oooo0?ooo`000000C@3o
ool004/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0K`3oool200000080oooo0P00001;0?ooo`00B@3oool20000
00@0oooo0P00000;0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0LP3oool01@00
0000oooo0?ooo`3oool0000004X0oooo00180?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07@0oooo00D000000?oo
o`3oool0oooo000000190?ooo`00A`3oool00`000000oooo0?ooo`020?ooo`8000002`3oool20000
07X0oooo00<000000?ooo`3oool0MP3oool01@000000oooo0?ooo`3oool0000004P0oooo00150?oo
o`800000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0N03oool01@000000oooo0?ooo`3oool0000004L0oooo00140?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
07T0oooo00D000000?ooo`3oool0oooo000000160?ooo`00@P3oool2000000@0oooo0P00000<0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0N`3oool01@000000oooo0?ooo`3oool0
000004D0oooo00110?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo07`0oooo0P0000020?ooo`800000@`3oool00400
oooo00<000000?ooo`3oool00P3oool2000000d0oooo00<000000?ooo`3oool0N`3oool00`000000
oooo0?ooo`1o0?ooo`050000003oool0oooo0?ooo`000000@P3oool003h0oooo0P0000040?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`210?ooo`05
0000003oool0oooo0?ooo`000000@@3oool003d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0P`3oool01@000000
oooo0?ooo`3oool000000400oooo000l0?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0Q@3oool01@000000oooo0?ooo`3oool00000
03l0oooo000j0?ooo`800000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0Q`3oool01@000000oooo0?ooo`3oool0000003h0oooo000i0?ooo`03
0000003oool0oooo0080oooo0P00000@0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool0R03oool200000080oooo00<000000?ooo`3oool0>`3oool003L0oooo0P0000040?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo00800000>`3oool003H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0S03oool01@000000oooo0?oo
o`3oool0000003X0oooo000e0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0SP3oool01@000000oooo0?ooo`3oool0000003T0oooo
000c0?ooo`800000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool0S`3oool01@000000oooo0?ooo`3oool0000003P0oooo000b0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo0940oooo00D000000?ooo`3oool0oooo0000000g0?ooo`00<@3oool00`000000oooo0?oo
o`020?ooo`800000503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0980oooo0P00
00020?ooo`030000003oool0oooo03@0oooo000_0?ooo`800000103oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0U@3oool010000000oooo0?ooo`00
000e0?ooo`00;P3oool00`000000oooo0?ooo`020?ooo`8000005P3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool00P00000c0?ooo`00;P3oool30000
00030?ooo`000000oooo01H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`2H0?oo
o`050000003oool0oooo0?ooo`000000<P3oool002h0oooo00@000000?ooo`3oool00000603oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo09X0oooo00D000000?ooo`3oool0oooo0000
000a0?ooo`00;P3oool3000000030?ooo`000000000001D0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`2K0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo00<00000
0?ooo`3oool00`3oool200000180oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`2M
0?ooo`050000003oool0oooo0?ooo`000000;`3oool002l0oooo0P0000050?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2N0?ooo`@00000;`3oool0
0340oooo00<000000?ooo`3oool00`3oool2000000h0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`2M0?ooo`80000000@0oooo0000003oool00000;P3oool00380oooo0P0000050?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2L0?oo
o`800000103oool2000002h0oooo000d0?ooo`800000103oool2000008X0oooo00<000000?ooo`3o
ool0VP3oool2000000L0oooo00<000000?ooo`3oool0;03oool003H0oooo00<000000?ooo`3oool0
0`3oool2000008L0oooo00<000000?ooo`3oool0V@3oool2000000L0oooo0P00000_0?ooo`00=`3o
ool2000000D0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`2G0?ooo`8000001`3o
ool200000340oooo000i0?ooo`030000003oool0oooo00<0oooo0P0000230?ooo`030000003oool0
oooo09L0oooo00<000000?ooo`3oool01@3oool2000003<0oooo000j0?ooo`8000001@3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo09D0oooo0P0000060?ooo`800000=@3oool003`0
oooo0P0000040?ooo`800000P03oool00`000000oooo0?ooo`2C0?ooo`8000001P3oool2000003L0
oooo000n0?ooo`030000003oool0oooo00<0oooo0P00001m0?ooo`030000003oool0oooo0980oooo
0P0000060?ooo`800000>@3oool003l0oooo0P0000050?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0T03oool2000000L0oooo00<000000?ooo`3oool0>@3oool00440oooo00<00000
0?ooo`3oool00`3oool2000007T0oooo00<000000?ooo`3oool0S`3oool2000000L0oooo0P00000l
0?ooo`00@P3oool2000000D0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`2=0?oo
o`8000001`3oool2000003h0oooo00140?ooo`800000103oool2000007H0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`050?ooo`800000@03oool004H0oooo00<000000?ooo`3oool0
0`3oool2000007<0oooo00<000000?ooo`3oool0R`3oool2000000H0oooo0P0000120?ooo`00A`3o
ool2000000D0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`290?ooo`8000001P3o
ool2000004@0oooo00190?ooo`030000003oool0oooo00<0oooo0P00001`0?ooo`030000003oool0
oooo0080oooo4@00001d0?ooo`8000001P3oool2000004H0oooo001:0?ooo`8000001@3oool00`00
0000oooo0?ooo`1]0?ooo`D000004@3oool5000006d0oooo0P0000060?ooo`800000B03oool004`0
oooo0P0000040?ooo`800000J@3oool4000001/0oooo1P00001U0?ooo`8000001`3oool00`000000
oooo0?ooo`180?ooo`00CP3oool00`000000oooo0?ooo`030?ooo`800000I@3oool2000000<0oooo
00<000000?ooo`3oool07`3oool300000600oooo0P0000070?ooo`800000B`3oool004l0oooo0P00
00050?ooo`030000003oool0oooo05l0oooo0`0000050?ooo`030000003oool0oooo0280oooo0P00
001M0?ooo`030000003oool0oooo00D0oooo0P00001=0?ooo`00D@3oool00`000000oooo0?ooo`03
0?ooo`800000G@3oool2000000P0oooo00<000000?ooo`3oool0903oool3000005P0oooo0P000006
0?ooo`800000C`3oool00580oooo0P0000050?ooo`030000003oool0oooo05L0oooo0`00000:0?oo
o`030000003oool0oooo02L0oooo0P00001D0?ooo`8000001P3oool200000540oooo001D0?ooo`80
0000103oool2000005D0oooo0P00000<0?ooo`030000003oool0oooo02X0oooo0P00001@0?ooo`80
00001P3oool2000005<0oooo001F0?ooo`030000003oool0oooo00<0oooo0P00001B0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1;0?ooo`800000
1P3oool2000005D0oooo001G0?ooo`8000001@3oool00`000000oooo0?ooo`1=0?ooo`8000003`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04P0oooo0P0000070?ooo`030000003o
ool0oooo05D0oooo001I0?ooo`030000003oool0oooo00<0oooo0P00001<0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`150?ooo`8000001`3oool2
000005P0oooo001J0?ooo`8000001@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0;`3oool2000004@0oooo00<000000?ooo`3oool01@3oool20000
05X0oooo001L0?ooo`800000103oool2000004L0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`030?oooa<000006`3oool200000400oooo0P0000060?ooo`800000G03oool005h0oooo
00<000000?ooo`3oool00`3oool2000004@0oooo00<000000?ooo`3oool04P3oool00`000000oooo
00000005000000h0oooo1`00000H0?ooo`800000?@3oool2000000H0oooo0P00001N0?ooo`00G`3o
ool2000000D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0B0?ooo`D000005`3o
ool4000001L0oooo00<000000?ooo`3oool0>@3oool2000000H0oooo0P00001P0?ooo`00H@3oool0
0`000000oooo0?ooo`030?ooo`800000?`3oool00`000000oooo0?ooo`0A0?ooo`@000007@3oool3
000001H0oooo00<000000?ooo`3oool0=P3oool2000000H0oooo0P00001R0?ooo`00HP3oool20000
00D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0@0?ooo`8000008`3oool20000
01@0oooo0P00000e0?ooo`8000001P3oool2000006@0oooo001T0?ooo`800000103oool2000003/0
oooo00<000000?ooo`3oool03`3oool2000002L0oooo0P00000C0?ooo`030000003oool0oooo0340
oooo0P0000070?ooo`030000003oool0oooo06@0oooo001V0?ooo`030000003oool0oooo00<0oooo
0P00000i0?ooo`030000003oool0oooo00h0oooo0P00000Y0?ooo`8000004`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00D0oooo0P00001W0?ooo`00I`3oool2000000D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0]0?ooo`8000001P3oool2000006T0oooo001Y
0?ooo`030000003oool0oooo00<0oooo0P00000e0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02X0oooo0P000006
0?ooo`800000J`3oool006X0oooo0P0000050?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0:03oool2000000H0oooo0P00001]0?ooo`00K03oool2000000@0oooo0P00000a0?ooo`03
0000003oool0oooo00`0oooo0P00000b0?ooo`030000003oool0oooo00h0oooo0P00000W0?ooo`80
00001P3oool2000006l0oooo001^0?ooo`030000003oool0oooo00<0oooo0P00000^0?ooo`030000
003oool0oooo00`0oooo0P00000c0?ooo`030000003oool0oooo00h0oooo0P00000U0?ooo`800000
1P3oool200000740oooo001_0?ooo`8000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0240oooo0P0000070?ooo`030000003oool0oooo0740oooo001a0?ooo`030000003oool0
oooo00<0oooo0P00000[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3oool2
000007@0oooo001b0?ooo`8000001@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00/0oooo0P00000e0?ooo`8000003`3oool00`000000oooo0?ooo`0N0?ooo`8000001P3oool20000
07H0oooo001d0?ooo`800000103oool2000002P0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0d0?ooo`8000003`3oool00`000000oooo0?ooo`0L0?ooo`8000001P3oool2000007P0
oooo001f0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0J0?ooo`8000001P3oool2000007X0oooo001g0?ooo`800000103oool2000002D0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`8000001P3oool2000007`0oooo001i
0?ooo`030000003oool0oooo00<0oooo0P00000S0?ooo`800000303oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo00`0oooo0P00000H0?ooo`8000001P3oool2000007h0oooo001j0?oo
o`8000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0=03oool2000000h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?oo
o`800000P03oool007`0oooo00<000000?ooo`3oool00`3oool200000240oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0503oool2000000H0oooo00<000000?ooo`3oool0P03oool007d0oooo0P0000050?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool2000003D0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0C0?ooo`8000001P3oool2000008<0oooo001o0?ooo`800000103o
ool2000001l0oooo0P00000;0?ooo`030000003oool0oooo0380oooo0P00000>0?ooo`030000003o
ool0oooo0140oooo0P0000060?ooo`800000Q@3oool00840oooo00<000000?ooo`3oool00`3oool2
000001h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0403oool2000000H0oooo0P0000270?ooo`00PP3oool20000
00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0303oool200000100oooo0P0000060?ooo`800000R@3oool008@0
oooo00<000000?ooo`3oool00`3oool2000001`0oooo00<000000?ooo`3oool02@3oool200000300
oooo0P00000>0?ooo`030000003oool0oooo00d0oooo0P0000060?ooo`800000R`3oool008D0oooo
0P0000050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool2000002l0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo
0P00002=0?ooo`00Q`3oool2000000@0oooo0P00000J0?ooo`8000002`3oool2000002d0oooo00<0
00000?ooo`3oool0303oool2000000d0oooo0P0000060?ooo`030000003oool0oooo08d0oooo0029
0?ooo`030000003oool0oooo00<0oooo0P00000I0?ooo`8000002`3oool2000002X0oooo0P00000>
0?ooo`800000303oool2000000H0oooo0P00002@0?ooo`00RP3oool2000000D0oooo00<000000?oo
o`3oool05`3oool2000000/0oooo0`00000V0?ooo`<000003P3oool2000000/0oooo0P0000060?oo
o`800000TP3oool008`0oooo00<000000?ooo`3oool00`3oool2000001T0oooo0P00000;0?ooo`80
0000903oool3000000h0oooo00<000000?ooo`3oool02@3oool2000000H0oooo0P00002D0?ooo`00
S@3oool2000000D0oooo00<000000?ooo`3oool05`3oool2000000`0oooo0P00000P0?ooo`<00000
3P3oool2000000X0oooo0P0000060?ooo`800000UP3oool008l0oooo0P0000040?ooo`8000006@3o
ool2000000`0oooo0`00000J0?ooo`<00000403oool2000000T0oooo0P0000060?ooo`800000V03o
ool00940oooo00<000000?ooo`3oool00`3oool2000001P0oooo0P00000=0?ooo`@00000503oool4
00000100oooo0P00000:0?ooo`030000003oool0oooo00@0oooo0P00002J0?ooo`00TP3oool20000
00D0oooo00<000000?ooo`3oool05`3oool2000000h0oooo200000060?ooo`T000003`3oool30000
00X0oooo0P0000050?ooo`800000W03oool009@0oooo00<000000?ooo`3oool00`3oool2000001T0
oooo0P00000A0?ooo`h000004@3oool3000000X0oooo0P0000060?ooo`030000003oool0oooo09`0
oooo002E0?ooo`8000001@3oool00`000000oooo0?ooo`0H0?ooo`800000:`3oool3000000/0oooo
0P0000060?ooo`800000W`3oool009L0oooo0P0000040?ooo`8000006P3oool5000002@0oooo0`00
000;0?ooo`8000001P3oool200000:40oooo002I0?ooo`030000003oool0oooo00<0oooo0P00000K
0?ooo`P000006P3oool4000000`0oooo0P0000060?ooo`800000X`3oool009X0oooo0P0000050?oo
o`030000003oool0oooo01`0oooo2P00000<0?ooo`X00000303oool2000000H0oooo0P00002U0?oo
o`00W03oool00`000000oooo0?ooo`030?ooo`8000008P3ooolB000001<0oooo00<000000?ooo`3o
ool0103oool200000:L0oooo002M0?ooo`8000001@3oool00`000000oooo0?ooo`120?ooo`800000
1@3oool200000:T0oooo002O0?ooo`800000103oool200000400oooo0P0000060?ooo`030000003o
ool0oooo0:T0oooo002Q0?ooo`030000003oool0oooo00<0oooo0P00000l0?ooo`8000001P3oool2
00000:`0oooo002R0?ooo`8000001@3oool00`000000oooo0?ooo`0g0?ooo`8000001P3oool20000
0:h0oooo002T0?ooo`030000003oool0oooo00<0oooo0P00000e0?ooo`8000001P3oool200000;00
oooo002U0?ooo`8000001@3oool00`000000oooo0?ooo`0`0?ooo`8000001P3oool200000;80oooo
002W0?ooo`800000103oool2000002l0oooo00<000000?ooo`3oool0103oool200000;@0oooo002Y
0?ooo`030000003oool0oooo00<0oooo0P00000[0?ooo`8000001@3oool200000;H0oooo002Z0?oo
o`8000001@3oool00`000000oooo0?ooo`0V0?ooo`8000001@3oool200000;P0oooo002/0?ooo`03
0000003oool0oooo00<0oooo0P00000T0?ooo`8000001P3oool00`000000oooo0?ooo`2h0?ooo`00
[@3oool2000000D0oooo00<000000?ooo`3oool07`3oool2000000H0oooo0P00002k0?ooo`00[`3o
ool2000000@0oooo0P00000M0?ooo`8000001P3oool200000;d0oooo002a0?ooo`030000003oool0
oooo00<0oooo0P00000I0?ooo`8000001P3oool200000;l0oooo002b0?ooo`8000001@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo0P0000310?ooo`00]03oool00`000000
oooo0?ooo`030?ooo`8000004`3oool2000000D0oooo0P0000330?ooo`00]@3oool2000000D0oooo
00<000000?ooo`3oool03P3oool2000000D0oooo0P0000350?ooo`00]`3oool2000000@0oooo0P00
000<0?ooo`8000001P3oool00`000000oooo0?ooo`350?ooo`00^@3oool00`000000oooo0?ooo`03
0?ooo`800000203oool2000000H0oooo0P0000380?ooo`00^P3oool2000000D0oooo00<000000?oo
o`3oool00`3oool2000000H0oooo0P00003:0?ooo`00_03oool00`000000oooo0?ooo`030?ooo`80
000000<0oooo0000000000001P3oool200000<`0oooo002m0?ooo`8000001@3oool00`000000oooo
0?ooo`040?ooo`800000cP3oool00;l0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P00
003@0?ooo`00`@3oool010000000oooo0?ooo`0000020?ooo`800000dP3oool00<80oooo1@00003D
0?ooo`00a03oool00`000000oooo0?ooo`3D0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3o
oonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00\
\>"]],

Cell["Fig. 1.17 Solution to Exercise (6).", "Caption",
  CellTags->"Fig. 1.17"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " The temperature of a thin rod of unit length satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 
            T/\[DifferentialD]x\^2 = \(T(x)\)\^4\)]],
  " (in suitably scaled units). [The ",
  Cell[BoxData[
      \(TraditionalForm\`T\^4\)]],
  " term represents heat loss due to radiation, and the ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 T/\[DifferentialD]x\^2\)]],
  "term arises from thermal conduction: see Chapter ",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", "c:3"},
    ButtonStyle->"Hyperlink"],
  ".] Find and plot ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " assuming the ends are held at fixed temperature: ",
  Cell[BoxData[
      \(TraditionalForm\`T(0) = \(T(1) = 1\)\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.6 Linear ODEs", "Subtitle",
  CellTags->{"Sec. 1.6", "i:81", "c:33"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["1.6.1 The Principle of Superposition", "Subsubtitle",
  CellTags->"c:34"],

Cell[CellGroupData[{

Cell[TextData[{
  "Linear ODEs of Order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]]
}], "Section",
  CellTags->"c:35"],

Cell[TextData[{
  "A linear ODE is distinguished by the following property: the equation is \
",
  StyleBox["linear",
    FontSlant->"Italic"],
  " in the unknown function; that is, only the first power of this function \
or its derivatives appear. An ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "th",
  "-order",
  " linear ODE has the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                
                FractionBox[\(\[DifferentialD]\^N 
                    x\), \(\[DifferentialD]t\^N\),
                  MultilineFunction->None], "+", " ", 
                RowBox[{\(\(u\_\(N - 1\)\)(t)\), 
                  
                  FractionBox[\(\[DifferentialD]\^\(N - 1\)x\), \(\
\[DifferentialD]t\^\(N - 1\)\),
                    MultilineFunction->None]}], "+"}], "..."}], "+", " ", 
            RowBox[{\(\(u\_1\)(t)\), 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], " ", "+", 
            " ", \(\(\(u\_o\)(t)\) x\)}], "=", \(f(t)\)}], 
        TraditionalForm]]],
  "."
}], "NE6",
  CellTags->"(1.6.1)"],

Cell[TextData[{
  "We have already seen several examples of linear differential equations, \
such as ",
  ButtonBox["Eq. (1.1.1)",
    ButtonData:>"(1.1.1)",
    ButtonStyle->"Hyperlink"],
  " (linear in ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  "),  or ",
  ButtonBox["Eq. (1.1.6)",
    ButtonData:>"(1.1.6)",
    ButtonStyle->"Hyperlink"],
  ", (linear in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "). Another example is the driven damped harmonic oscillator"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
              MultilineFunction->None], "+", 
            RowBox[{"\[Gamma]", " ", 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], "+", 
            " ", \(\(\[Omega]\_o\%2\) x\)}], "=", \(f(t)\)}], 
        TraditionalForm]]],
  ","
}], "NE6",
  CellTags->{"(1.6.2)", "i:91"}],

Cell[TextData[{
  "where",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Gamma]\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Omega]\_o\%2\)\)\)]],
  StyleBox["  ",
    FontFamily->"Symbol"],
  " are time-independent nonnegative constants.  This equation describes \
damped harmonic motion with natural frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "and  damping rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  ", driven by an external force ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(m\)\(\ \)\(f(t)\)\(\ \)\)\)\)]],
  " (where ",
  StyleBox["m",
    FontSlant->"Italic"],
  " is the oscillator's mass)",
  StyleBox[".",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:104"],

Cell["\<\
\tThere are many, many other linear ODEs that have physical \
significance. Linear differential equations play a special role in the \
physical sciences,  appearing in literally every discipline.  As a \
consequence, the properties of these equations and their solutions have \
received considerable attention.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Differential Operators", "Section",
  CellTags->"c:36"],

Cell[TextData[{
  "An operator is simply a rule that transforms one function into another. An \
integral is an operator, and so is a square root. ",
  StyleBox["Differential",
    FontSlant->"Italic"],
  " operators are combinations of derivatives that act on a given function, \
transforming it into another function. For example, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\&^\ f\)\(=\)\(\[ExponentialE]\^\(\
\[DifferentialD]f/\[DifferentialD]t\)\)\(\ \)\)\)]],
  " defines a differential operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " (i.e. a rule) that takes the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  "  to the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[DifferentialD]f/\[DifferentialD]\
t\)\)]],
  "."
}], "Text",
  CellTags->"i:131"],

Cell[TextData[{
  "\t Let us define a ",
  StyleBox["linear differential operator ",
    FontSlant->"Italic"],
  "of ",
  StyleBox["N",
    FontSlant->"Italic"],
  "th",
  "-order",
  " as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(L\&^\), "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                
                FractionBox[\(\[DifferentialD]\^N\), \(\[DifferentialD]t\^N\),
                  
                  MultilineFunction->None], "+", " ", 
                RowBox[{\(\(u\_\(N - 1\)\)(t)\), 
                  
                  FractionBox[\(\[DifferentialD]\^\(N - 
                          1\)\), \(\[DifferentialD]t\^\(N - 1\)\),
                    MultilineFunction->None]}], "+"}], "..."}], "+", " ", 
            RowBox[{\(\(u\_1\)(t)\), 
              FractionBox["\[DifferentialD]", \(\[DifferentialD]t\),
                MultilineFunction->None]}], " ", "+", 
            " ", \(\(u\_o\)(t)\)}]}], TraditionalForm]]],
  "."
}], "NE6",
  CellTags->{"(1.6.3)", "i:130"}],

Cell[TextData[{
  "For the moment, think of this as merely a convenience, so that we can \
write ",
  ButtonBox["Eq. (1.6.1)",
    ButtonData:>"(1.6.1)",
    ButtonStyle->"Hyperlink"],
  " in the compact form ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = f\)]],
  "  . "
}], "Text"],

Cell["Linear operators have the following two properties:", "Text",
  CellTags->"i:83"],

Cell[TextData[{
  "\t (1) for any two functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\)(f + g) = \(L\&^\) f + \(L\&^\) g\)]],
  ".\n\t (2) for any function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " and any constant ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\ \((C\ f)\) = C\ \(L\&^\) f\)]],
  "."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "It is easy to see that  the operator in Eq. ",
  ButtonBox["(1.6.3)",
    ButtonData:>"(1.6.3)",
    ButtonStyle->"Hyperlink"],
  " satisfies these properties, and so  it is a linear operator. It is also \
easy to see that the integral of a function is another linear operator (a \
linear ",
  StyleBox["integral",
    FontSlant->"Italic"],
  " operator).  However, the operator defined by ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\ f = \[ExponentialE]\^\(\[DifferentialD]f/\
\[DifferentialD]t\)\)]],
  "  does not satisfy either property. It is a ",
  StyleBox["nonlinear",
    FontSlant->"Italic"],
  " differential operator. For the most part, we will concentrate on the \
properties of linear operators in this book. Some examples of nonlinear \
operators with relevance to physics can be found in Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Superposition Principle", "Section",
  CellTags->"c:37"],

Cell[TextData[{
  "\tOne important property of linear ODEs is called the ",
  StyleBox["principle of superposition",
    FontSlant->"Italic"],
  ". Consider the general solution of ",
  ButtonBox["Eq. (1.6.1)",
    ButtonData:>"(1.6.1)",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["assuming that the forcing function vanishes:",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x\  = \ \(f(t)\  = \ 0\)\)]],
  ". In this case the equation is termed ",
  StyleBox["homogeneous. ",
    FontSlant->"Italic"],
  " "
}], "Text",
  CellTags->"i:85"],

Cell[TextData[{
  "\tNow, the general solution of the ODE involves ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " undetermined constants, as discussed in ",
  ButtonBox["Sec. 1.1",
    ButtonData:>"Sec. 1.1",
    ButtonStyle->"Hyperlink"],
  ". Let us arbitrarily choose any two different sets of values for these \
constants, and thereby obtain two different possible solutions to the ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_2\)(t)\)\(\ \)\)\)]],
  "(corresponding to different initial or boundary conditions). Then the \
principle of superposition states that the linear combination"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(C\_1\) \(\(x\_1\)(t)\) + \(C\_2\) \(\(x\_1\)(
            t)\)\)]],
  " "
}], "NE6",
  CellTags->"(1.6.4)"],

Cell["\<\
is also a solution of the homogeneous ODE (corresponding to some \
other initial or boundary conditions). This follows directly from the linear \
nature of the differential equation, as we will now show. \
\>", "Text"],

Cell[TextData[{
  "\tBy construction, the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(t)\)]],
  " have the property that  ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x\_1 = \(\(L\&^\) x\_2 = 0\)\)]],
  ". If we now substitute ",
  ButtonBox["Eq. (1.6.4)",
    ButtonData:>"(1.6.3)",
    ButtonStyle->"Hyperlink"],
  " into  ",
  ButtonBox["Eq. (1.6.1)",
    ButtonData:>"(1.6.1)",
    ButtonStyle->"Hyperlink"],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\)(\(C\_1\) x\_1 + \(C\_2\) 
              x\_2) = \(\(L\&^\)(\(C\_1\) x\_1) + \(L\&^\)(\(C\_2\) 
                x\_2) = \(\(C\_1\) \(L\&^\) x\_1 + \(C\_2\) \(L\&^\) x\_2 = 
            0\)\)\)]],
  ","
}], "NE6",
  CellTags->"(1.6.5)"],

Cell[TextData[{
  "verifying our contention that ",
  ButtonBox["Eq. (1.6.4)",
    ButtonData:>"(1.6.3)",
    ButtonStyle->"Hyperlink"],
  " satisfies the homogeneous ODE, and proving the principle of \
superposition."
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {Cell[TextData[StyleBox["The Principle of Superposition",
              FontSlant->"Italic"]], "ColumnHead"], ""},
          {Cell[TextData[Cell[BoxData[
                FormBox[GridBox[{
                      {
                        RowBox[{
                          RowBox[{
                            RowBox[{"If", 
                              FormBox[\(\(x\_1\)(t)\),
                                "TraditionalForm"], "and", 
                              FormBox[\(\(x\_2\)(t)\),
                                "TraditionalForm"], "both", " ", "satisfy", 
                              " ", "the", " ", "homogeneous", " ", "linear", 
                              " ", "ODE", 
                              FormBox[\(\(L\&^\) x = 0\),
                                "TraditionalForm"]}], ",", 
                            RowBox[{
                            "then", " ", "the", " ", "linear", " ", 
                              "combination", " ", 
                              
                              FormBox[\(\(C\_1\) \(\(x\_1\)(
                                      t)\) + \(C\_2\) \(\(x\_2\)(t)\)\),
                                "TraditionalForm"]}]}], "\[IndentingNewLine]",
                           
                          RowBox[{
                          "also", " ", "satisfies", " ", "this", " ", "ODE", 
                            " ", "for", " ", "any", " ", "value", " ", "of", 
                            " ", "the", " ", "constants", 
                            FormBox[\(C\_1\),
                              "TraditionalForm"], "and", 
                            RowBox[{
                              FormBox[\(C\_2\),
                                "TraditionalForm"], "."}]}]}], Cell[
                        "", "Text"]}
                      }], NullForm]]]], "Text"], Cell["", "Text"]}
          }], NullForm]], "Table",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:82"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.6.2 The General Solution to the Homogeneous Equation", "Subsubtitle",
  CellTags->"c:38"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:39"],

Cell[TextData[{
  "\tLet us return now to the discussion surrounding ",
  ButtonBox["Eq. (1.6.3)",
    ButtonData:>"(1.6.3)",
    ButtonStyle->"Hyperlink"],
  " regarding the general solution of the homogeneous equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = 0\)]],
  " .  Rather than choosing only two sets of values for the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " undetermined constants, let us choose ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " different sets of values, so that we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " different functions, ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(t)\)]],
  ",\[Ellipsis],",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_N\)(t)\)]],
  ".  This means that",
  StyleBox[" no one function can be obtained merely as a linear superposition \
of the others",
    FontSlant->"Italic"],
  ". The functions are ",
  StyleBox["linearly independent ",
    FontSlant->"Italic"],
  " of one another.  Then it should be clear that the function obtained by \
superimposing these functions,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`x(
        t) = \(C\_1\ \(\(x\_1\)(t)\) + C\_2\ \(\(x\_2\)(t)\) +  ... \) + 
        C\_N\ \(\(x\_N\)(t)\)\)]]], "NE6",
  CellTags->"(1.6.6)"],

Cell[TextData[{
  "is a form of the general solution of the homogeneous ODE. Recall that the \
general solution has ",
  StyleBox["N",
    FontSlant->"Italic"],
  " undetermined constants that can be used to satisfy any particular initial \
condition. The fact that the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(x\_1\)(t)\), ",", 
          FormBox[\(\(x\_2\)(t)\),
            "TraditionalForm"], ",", "\[Ellipsis]", ",", 
          FormBox[\(\(x\_N\)(t)\),
            "TraditionalForm"], " "}], TraditionalForm]]],
  "are linearly independent means that ",
  ButtonBox["Eq. (1.6.6)",
    ButtonData:>"(1.6.6)",
    ButtonStyle->"Hyperlink"],
  "  and its derivatives, evaluated at the initial time, ",
  StyleBox["span",
    FontSlant->"Italic"],
  " the space of possible initial conditions. By this I mean that any given \
initial condition can be met by appropriate choice of the constants.  (Note \
the use of the term ",
  StyleBox["span",
    FontSlant->"Italic"],
  ", from linear algebra, denoting a set of vectors  that can be made to sum \
to any other vector in a given vector space. As we have already mentioned, \
the connection between linear ODEs and linear algebra will be made clear in \
the next section.)"
}], "Text"],

Cell[TextData[{
  "\tWe have already seen an example of ",
  ButtonBox["Eq. (1.6.6)",
    ButtonData:>"(1.6.6)",
    ButtonStyle->"Hyperlink"],
  ": ",
  ButtonBox["Eq. (1.1.7)",
    ButtonData:>"(1.1.7)",
    ButtonStyle->"Hyperlink"],
  " shows that the solution of the harmonic oscillator equation is a sum of \
the linearly independent solutions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(cos\)\(\ \)\(t\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ t\)]],
  ". Equation ",
  ButtonBox["(1.6.6)",
    ButtonData:>"(1.6.6)",
    ButtonStyle->"Hyperlink"],
  " shows that the general solution of a homogeneous linear ODE can always be \
written in this way, as a sum of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " independent functions each of which satisfy the ODE."
}], "Text"],

Cell[TextData[{
  StyleBox["The general solution of a homogeneous linear ODE  ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = 0\)]],
  " ",
  StyleBox["can be written as a linear combination of N independent solutions \
to the ODE.",
    FontSlant->"Italic"]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:84"],

Cell[TextData[{
  "\tLet's consider possible analytic forms for these ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " independent solutions in the case that the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_n\)(t)\)]],
  " appearing in ",
  ButtonBox["Eq. (1.6.1)",
    ButtonData:>"(1.6.1)",
    ButtonStyle->"Hyperlink"],
  " are time-independent constants:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(L\&^\) x\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                
                FractionBox[\(\[DifferentialD]\^N 
                    x\), \(\[DifferentialD]t\^N\),
                  MultilineFunction->None], "+", " ", 
                RowBox[{\(u\_\(N - 1\)\), 
                  
                  FractionBox[\(\[DifferentialD]\^\(N - 1\)x\), \(\
\[DifferentialD]t\^\(N - 1\)\),
                    MultilineFunction->None]}], "+"}], "..."}], "+", " ", 
            RowBox[{\(u\_1\), 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], " ", "+", " ", \(\(u\_o\) x\)}], 
          "=", \(\(f(t)\)\(.\)\)}]}], TraditionalForm]]]], "NE6",
  CellTags->"(1.6.7)"],

Cell[TextData[{
  "This important special case occurs, for example, in the driven damped \
harmonic oscillator, ",
  ButtonBox["Eq. (1.6.2)",
    ButtonData:>"(1.6.2)",
    ButtonStyle->"Hyperlink"],
  ". We will guess the form ",
  Cell[BoxData[
      \(TraditionalForm\`x(t) = \[ExponentialE]\^\(s\ t\)\)]],
  " for some constant ",
  StyleBox["s",
    FontSlant->"Italic"],
  ". Using the fact that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\^n\), \(\[DifferentialD]t\^n\),
              MultilineFunction->None], \(\[ExponentialE]\^\(s\ t\)\)}], 
          "=", \(s\^n\ \[ExponentialE]\^\(s\ t\)\)}], TraditionalForm]]],
  " ,"
}], "NE6",
  CellTags->"(1.6.8)"],

Cell[TextData[{
  "the ODE ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = 0\)]],
  "becomes a polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\(s\^N + u\_\(N - 1\)\ s\^\(N - 1\) + 
                  u\_\(N - 2\)\ s\^\(N - 2\) +  ... \) + u\_1\ s + 
              u\_o)\)\ \[ExponentialE]\^\(s\ t\) = 0\)]],
  "."
}], "NE6",
  CellTags->"(1.6.9)"],

Cell[TextData[{
  "The bracket must be zero, so we are faced with finding the roots of this \
",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "th-order polynomial in  ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ". Although a general analytic solution cannot be found for ",
  Cell[BoxData[
      \(TraditionalForm\`N > 4\)]],
  ", it is well known that there are always ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " roots (which may be complex), ",
  Cell[BoxData[
      \(TraditionalForm\`{s\_1, s\_2,  ... , s\_N}\)]],
  " . These ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " roots supply us with our ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " independent functions, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_n\)(t) = \[ExponentialE]\^\(s\_n\ t\)\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2,  ... , N, \)]]
}], "NE6",
  CellTags->{"(1.6.10)", "i:89"}],

Cell[TextData[{
  StyleBox["provided that ",
    FontSlant->"Italic"],
  "none of the roots are the same. If two of the roots are the same, the \
roots are said to be ",
  StyleBox["degenerate",
    FontSlant->"Italic"],
  ". In this case only ",
  Cell[BoxData[
      \(TraditionalForm\`N - 1\)]],
  " of the solutions have the form of ",
  ButtonBox["Eq. (1.6.10)",
    ButtonData:>"(1.6.10)",
    ButtonStyle->"Hyperlink"],
  ". The ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "th solution remains to be determined."
}], "Text",
  CellTags->"i:90"],

Cell[TextData[{
  "\tLet's assume that ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  ". Then consider any one of the constants in ",
  ButtonBox["Eq. (1.6.9)",
    ButtonData:>"(1.6.9)",
    ButtonStyle->"Hyperlink"],
  " to be a variable; take the constant ",
  Cell[BoxData[
      \(TraditionalForm\`u\_o\)]],
  ", for example, and replace it with a variable ",
  StyleBox["u",
    FontSlant->"Italic"],
  ". Now the roots all become functions of ",
  StyleBox["u",
    FontSlant->"Italic"],
  ", and in particular so do our two degenerate roots, ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  StyleBox[" = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(s\_1\)(u)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  StyleBox[" = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(s\_2\)(u)\)]],
  " . Furthermore,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_1\)(u\_o)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_2\)(u\_o)\)]],
  ", but in general for ",
  Cell[BoxData[
      \(TraditionalForm\`u \[NotEqual] u\_o\)]],
  ",   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(s\_1\)(u)\),
            "TraditionalForm"], " ", 
          FormBox["\[NotEqual]",
            "TraditionalForm"], " ", 
          FormBox[\(\(s\_2\)(u)\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". Now let us write ",
  Cell[BoxData[
      \(TraditionalForm\`u = u\_o + \[Epsilon]\)]],
  StyleBox[", ",
    FontFamily->"Symbol"],
  " and take the limit of the following superposition as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " vanishes:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`lim\+\(\[Epsilon] \[Rule] 0\)\[ThinSpace]\(1\/\
\[Epsilon]\) \((\[ExponentialE]\^\(\(\(s\_1\)(\[Epsilon] + u\_o)\)\ t\) - \
\[ExponentialE]\^\(\(\(s\_2\)(\[Epsilon] + u\_o)\)\ t\))\)\)]]], "NE6",
  CellTags->"(1.6.11)"],

Cell[TextData[{
  "According to the superposition principle, this sum is also a perfectly \
good solution to the equation.",
  StyleBox[" Mathematica ",
    FontSlant->"Italic"],
  " can easily carry out the limit, obtaining a finite result:"
}], "Text",
  CellTags->"i:117"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s2[u0]\  = \ \(s1[u0] = s1\);\)\), "\n", 
    \(Factor[
      Normal[Series[\[Epsilon]^\(-1\)\ \((E^\((s1[u0 + \[Epsilon]] t)\) - 
                E^\((s2[u0 + \[Epsilon]] t)\))\), {\[Epsilon], 0, 
            0}]]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.79"],

Cell[BoxData[
    RowBox[{\(\[ExponentialE]\^\(s1\ t\)\), " ", "t", " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            SuperscriptBox["s1", "\[Prime]",
              MultilineFunction->None], "[", "u0", "]"}], "-", 
          RowBox[{
            SuperscriptBox["s2", "\[Prime]",
              MultilineFunction->None], "[", "u0", "]"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result, ",
  Cell[BoxData[
      \(TraditionalForm\`t\ \[ExponentialE]\^\(s\_1\ t\)\)]],
  " (neglecting the unimportant multiplicative constant), provides us with \
the new function necessary to complete the set of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " independent solutions. The case of three or more degenerate roots, and \
the case where the multiplicative constant vanishes, can all be handled \
easily using similar methods to those detailed here, and will be left for the \
exercises. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Different Functional Forms for the General Solution",
  FontFamily->"Helvetica",
  FontWeight->"Bold"]], "Section",
  CellTags->"c:40"],

Cell[TextData[{
  "\tOften it may happen that the exponential form of the solutions in ",
  ButtonBox["Eq. (1.6.10)",
    ButtonData:>"(1.6.10)",
    ButtonStyle->"Hyperlink"],
  " is not the most convenient form for a particular application. For \
example, for the undamped harmonic oscillator Eq. ",
  ButtonBox["(1.1.6)",
    ButtonData:>"(1.1.6)",
    ButtonStyle->"Hyperlink"],
  ", the functions obtained via ",
  ButtonBox["Eq. (1.6.10)",
    ButtonData:>"(1.6.10)",
    ButtonStyle->"Hyperlink"],
  " are"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(
          t) = \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\_o\ t\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(
          t) = \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\_o\ t\)\)]]
}], "NE6",
  CellTags->"(1.6.12)"],

Cell[TextData[{
  "For the damped harmonic oscillator  ",
  ButtonBox["Eq. (1.6.2)",
    ButtonData:>"(1.6.2)",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["s",
    FontSlant->"Italic"],
  " satisfies a quadratic equation"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`s\^2 + \[Gamma]\ s + \[Omega]\_o\%2 = 0\)]],
  ","
}], "NE6",
  CellTags->"(1.6.13)"],

Cell["which has solutions", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`s\_1 = \(-\(\[Gamma]\/2\)\) + \[ImaginaryI]\ \@\(\
\[Omega]\_o\%2 - \[Gamma]\^2\/4\), \[IndentingNewLine]s\_2 = \(-\(\[Gamma]\/2\
\)\) - \[ImaginaryI]\ \(\(\@\(\[Omega]\_o\%2 - \[Gamma]\^2\/4\)\)\(.\)\)\)]],
  "\n"
}], "NE6",
  CellTags->"(1.6.14)"],

Cell[TextData[{
  "These solutions are complex (when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  StyleBox[">",
    FontFamily->"Symbol"],
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]/2\)]],
  "), and this can be an inconvenience in certain applications. Fortunately, \
the superposition principle says that we can replace the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(t)\)]],
  " with any linear combination of them. For example, the new functions"
}], "Text",
  CellTags->"i:118"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&_\_1\)(
          t) = \(1\/2\)\ [\(x\_1\)(t) + \(x\_2\)(
              t)], \[IndentingNewLine]\(x\&_\_2\)(
          t) = \(1\/\(2  \[ImaginaryI]\)\)\ [\(x\_1\)(t) - \(x\_2\)(t)], \)]]
}], "NE6",
  CellTags->"(1.6.15)"],

Cell[TextData[{
  "form a useful set of independent solutions for  damped or undamped \
oscillator problems, since standard trigonometric identities can be used show \
that these functions are real. For example, for the undamped harmonic \
oscillator, ",
  ButtonBox["Eqs. (1.6.12)",
    ButtonData:>"(1.6.12)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(1.6.15)",
    ButtonData:>"(1.6.15)",
    ButtonStyle->"Hyperlink"],
  " yield"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(x\&_\_1\)(t) = \(cos\[Omega]\_o\) 
        t, \[IndentingNewLine]\(x\&_\_2\)(t) = \(sin\[Omega]\_o\) 
        t, \)]]], "NE6",
  CellTags->"(1.6.16)"],

Cell[TextData[{
  "which may be recognized as the usual real form for the independent \
solutions. We can then drop the overbars in ",
  ButtonBox["Eq. (1.6.16)",
    ButtonData:>"(1.6.16)",
    ButtonStyle->"Hyperlink"],
  " and treat these functions as our new independent solutions. Similarly, \
the real solutions to the damped harmonic oscillator equation are"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(x\&_\_1\)(
        t) = \[ExponentialE]\^\(\(\ \)\(\(-\[Gamma]\)\ t/2\)\)\ \(cos(\@\(\
\[Omega]\_o\%2 - \[Gamma]\^2\/4\)\ t)\), \[IndentingNewLine]\(x\&_\_2\)(
        t) = \[ExponentialE]\^\(\(\ \)\(\(-\[Gamma]\)\ t/2\)\)\ \(\(sin(\@\(\
\[Omega]\_o\%2 - \[Gamma]\^2\/4\)\ t)\)\(.\)\)\)]]], "NE6",
  CellTags->{"(1.6.17)", "i:92"}],

Cell[TextData[{
  "These solutions are real, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o > \ \[Gamma]/2\)]],
  ". The solutions decay with time, and oscillate at a frequency less than ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " due to the drag force on the oscillator."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.6.3 Linear Differential Operators and Linear \
Algebra",
  FontFamily->"Helvetica"]], "Subsubtitle",
  CellTags->"c:41"],

Cell[TextData[{
  "Consider the following homogeneous linear ",
  "initial-value",
  " problem for the unknown function ",
  StyleBox["x(t)",
    FontSlant->"Italic"],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = 0, 
      x(t\_o) = x\_o, \(x\^\[Prime]\)(t\_o) = v\_o,  ... \)]],
  ","
}], "NE6",
  CellTags->"(1.6.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  "  is some linear differential operator. In this section we will show that \
the function ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") can be thought of as a vector, and the operator  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " can be thought of as a matrix that acts on this vector. We can then apply \
what we know about linear algebra to understand the behavior of solutions to \
linear ODEs. "
}], "Text"],

Cell[TextData[{
  "\tTo directly see the connection of ",
  ButtonBox["Eq. (1.6.18)",
    ButtonData:>"(1.6.18)",
    ButtonStyle->"Hyperlink"],
  " to linear algebra, consider trying to find a numerical solution to this \
ODE using Euler's method. We then discretize time, writing ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", " ", 
          RowBox[{
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], " ", "+", " ", \(t\_o\)}]}], 
        TraditionalForm]]],
  ". The function ",
  StyleBox["x(t)",
    FontSlant->"Italic"],
  " is replaced by a set of values ",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`{x(t\_o), x(t\_1), x(t\_2),  ... }\)]],
  StyleBox[", which can be thought of as a vector ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ":"
}], "Text",
  CellTags->"i:44"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          "=", \({x(t\_o), x(t\_1), x(t\_2),  ... }\)}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t Similarly, the ODE ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = 0\)]],
  " becomes a series of linear equations for the components of ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and therefore the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  "  becomes a matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " that acts on the vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  StyleBox[". ",
    FontWeight->"Bold"],
  "To see how this works in detail, consider the case of a simple first-order \
linear homogeneous ODE:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(L\&^\ x\), "=", 
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None], "+", \(\(\(u\_o\)(t)\) x\)}], "=", 
            "0"}]}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`x(t\_o) = x\_o\)]],
  "."
}], "NE6",
  CellTags->"(1.6.19)"],

Cell[TextData[{
  "Solving this ODE numerically via Euler's method, we replace ",
  ButtonBox["Eq. (1.6.19)",
    ButtonData:>"(1.6.19)",
    ButtonStyle->"Hyperlink"],
  " by"
}], "Text",
  CellTags->"i:126"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(x(t\_o) = x\_o\), ",", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{\(x(t\_1)\), "-", \(x(t\_o)\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \(\(u\_o\)(t\_o)\), \(x(t\_o)\)}]}], "=", "0"}], ",", 
        "\[IndentingNewLine]", 
        FormBox[
          RowBox[{
            RowBox[{
              RowBox[{\(x(t\_2)\), "-", \(x(t\_1)\), "+", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], 
                  " ", \(\(u\_o\)(t\_1)\), \(x(t\_1)\)}]}], "=", "0"}], ",", 
            "..."}],
          "TraditionalForm"], " "}], TraditionalForm]]]], "NE6",
  CellTags->"(1.6.20)"],

Cell["\<\
These linear equations can be replaced by the  matrix \
equation\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"1", "0", "0", "0", "..."},
              {
                RowBox[{\(-1\), "+", 
                  RowBox[{\(\(u\_o\)(t\_o)\), " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}]}], "1", "0", "0", "..."},
              {"0", 
                RowBox[{\(-1\), "+", 
                  RowBox[{\(\(u\_o\)(t\_1)\), " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}]}], "1", "0", "..."},
              {"0", "0", 
                RowBox[{\(-1\), "+", 
                  RowBox[{\(\(u\_o\)(t\_2)\), " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}]}], "1", "..."},
              {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                "\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                "\[DescendingEllipsis]"}
              }], "\[NoBreak]", ")"}], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\[CenterDot]\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x(t\_o)\)},
                {\(x(t\_1)\)},
                {\(x(t\_2)\)},
                {\(x(t\_3)\[IndentingNewLine]
                  \ \ \ \[VerticalEllipsis]\)}
                }], "\[NoBreak]", ")"}], "\[IndentingNewLine]"}], 
        TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\` = \)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(x\_o\)},
              {"0"},
              {"0"},
              {"0"},
              {"\[VerticalEllipsis]"}
              }], "\[NoBreak]", ")"}], TraditionalForm]]]
}], "NE6",
  CellTags->"(1.6.21)"],

Cell[TextData[{
  "The above matrix is a realization of the matrix ",
  StyleBox["L",
    FontWeight->"Bold"],
  " for this simple first-order ODE. All elements above the main diagonal are \
zero because the recursion relation determines the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "th element of ",
  StyleBox["x",
    FontWeight->"Bold"],
  " in terms of earlier steps only.  The ",
  "right-hand",
  " side of ",
  ButtonBox["Eq. (1.6.21)",
    ButtonData:>"(1.6.21)",
    ButtonStyle->"Hyperlink"],
  " is a vector containing information about the initial condition. We will \
call this vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], "=", \({x\_o, 0, 0,  ... }\)}], 
        TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:99"],

Cell[TextData[{
  "\tWe can easily write the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold"],
  " in terms of a special function called a Kronecker delta function, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[Delta]", 
          StyleBox[\(n\ m\),
            FontSlant->"Italic"]], TraditionalForm]]],
  " ",
  StyleBox[". ",
    FontSlant->"Italic"],
  " This function takes two integer arguments, ",
  StyleBox["n",
    FontSlant->"Italic"],
  " and ",
  StyleBox["m",
    FontSlant->"Italic"],
  ", and is defined as"
}], "Text",
  CellTags->"i:100"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[Delta]", 
            StyleBox[\(n\ m\),
              FontSlant->"Italic"]], "=", 
          TagBox[
            StyleBox[
              RowBox[{"{", 
                StyleBox[GridBox[{
                      {"1"},
                      {"0"}
                      }],
                  ShowAutoStyles->True]}],
              ShowAutoStyles->False],
            (#&)]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\(,\)\(n = m\)\(,\)\)},
            {\(\(,\)\(n \[NotEqual] \(\(m\)\(.\)\)\)\)}
            }], TraditionalForm]]]
}], "NE6",
  CellTags->"(1.6.22)"],

Cell[TextData[{
  "The Kronecker delta function can be thought of as the ",
  Cell[BoxData[
      \(TraditionalForm\`\((n, m)\)\)]],
  " element a matrix whose elements are all zero except along the diagonal ",
  Cell[BoxData[
      \(TraditionalForm\`n = m\)]],
  ", where the elements are equal to one. This is the ",
  StyleBox["unit matrix",
    FontSlant->"Italic"],
  " ",
  StyleBox["unit",
    FontWeight->"Bold"],
  ", discussed in Sec. ",
  ButtonBox["9.5.2",
    ButtonData:>{"Chapter9.nb", "c:18"},
    ButtonStyle->"Hyperlink"],
  ". In ",
  StyleBox["Mathematica, ",
    FontSlant->"Italic"],
  "the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            SubscriptBox["\[Delta]", 
              StyleBox[\(n\ m\),
                FontSlant->"Italic"]],
            "TraditionalForm"]}], TraditionalForm]]],
  " is called ",
  StyleBox["KroneckerDelta[n,m]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".",
  StyleBox[" \n",
    FontSlant->"Italic"],
  "\tUsing the Kronecker delta function, the components ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(m\ n\)\)]],
  " of ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " can be expressed as"
}], "Text",
  CellTags->"i:134"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            SubscriptBox["L", 
              StyleBox[\(n\ m\),
                FontSlant->"Italic"]], "=", 
            FormBox[
              RowBox[{
                SubscriptBox["\[Delta]", 
                  StyleBox[\(n\ m\),
                    FontSlant->"Italic"]], "-", " ", 
                FormBox[
                  RowBox[{\(\[Delta]\_\(n - 1, \ m\)\), "[", 
                    RowBox[{"1", "-", 
                      RowBox[{
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["t",
                              FontSlant->"Italic"]}]], 
                        " ", \(\(u\_o\)(t\_m)\)}]}], "]"}],
                  "TraditionalForm"]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  StyleBox["\t\t\t",
    FontWeight->"Bold"]
}], "NE6",
  CellTags->"(1.6.23)"],

Cell[TextData[{
  "The matrix can then be created with a ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L = 
        Table[KroneckerDelta[n, m] - 
            KroneckerDelta[n - 1, m] \((1 - \[CapitalDelta]t\ u[m])\), {n, 0, 
            3}, {m, 0, 3}];\)\), "\n", 
    \(MatrixForm[L]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.80"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0"},
            {\(\(-1\) + \[CapitalDelta]t\ u[0]\), "1", "0", "0"},
            {"0", \(\(-1\) + \[CapitalDelta]t\ u[1]\), "1", "0"},
            {"0", "0", \(\(-1\) + \[CapitalDelta]t\ u[2]\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Here we have only constructed four rows of the matrix, for ease of \
viewing.\
\>", "Text"],

Cell[TextData[{
  "\tOf course, the matrix and vectors of Eq. ",
  ButtonBox["(1.6.21)",
    ButtonData:>"(1.6.21)",
    ButtonStyle->"Hyperlink"],
  " are formally infinite\[Dash]dimensional, but if we content ourselves with \
determining the solution only up to a finite time ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_f\), " ", "=", " ", 
          RowBox[{
            RowBox[{"M", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", " ", \(t\_o\)}]}], 
        TraditionalForm]]],
  ", we can make the matrices and vectors ",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  "-dimensional."
}], "Text"],

Cell[TextData[{
  "\tNote that ",
  ButtonBox["Eq. (1.6.21)",
    ButtonData:>"(1.6.21)",
    ButtonStyle->"Hyperlink"],
  " is only one of many different possible forms for the matrix equation.  \
Recall that there are many different schemes for solving an ODE: the Euler \
method embodied by ",
  ButtonBox["Eq. (1.6.21)",
    ButtonData:>"(1.6.21)",
    ButtonStyle->"Hyperlink"],
  " is one, but the predictor-corrector method, for example, would lead to a \
different matrix ",
  StyleBox["L ",
    FontWeight->"Bold"],
  "(see the exercises). This uncertainty shouldn\[CloseCurlyQuote]t bother \
us, since the solution of the matrix equation always leads to an approximate \
solution to ",
  ButtonBox["Eq. (1.6.19)",
    ButtonData:>"(1.6.19)",
    ButtonStyle->"Hyperlink"],
  " that converges to the right solution as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "\[Rule]", " ", "0"}], 
        TraditionalForm]]],
  StyleBox[", ",
    FontFamily->"Symbol"],
  " independent of the particular method used in obtaining the matrix \
equation. "
}], "Text"],

Cell[TextData[{
  "\tWe can write ",
  ButtonBox["Eq. (1.6.21)",
    ButtonData:>"(1.6.21)",
    ButtonStyle->"Hyperlink"],
  " in a more compact form using vector notation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], "=", 
          SubscriptBox[
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"]}], TraditionalForm]]],
  "."
}], "NE6",
  CellTags->"(1.6.24)"],

Cell[TextData[{
  "This matrix equation is a discretized form of the ODE and initial \
condition,  ",
  ButtonBox["Eq. (1.6.19)",
    ButtonData:>"(1.6.19)",
    ButtonStyle->"Hyperlink"],
  ". It can be shown that",
  " the more general ODE of ",
  ButtonBox["Eq. (1.6.18)",
    ButtonData:>"(1.6.18)",
    ButtonStyle->"Hyperlink"],
  " can also be put in this form",
  ", although this takes more work. (Some examples can be found in the \
exercises.) A solution for ",
  StyleBox["x ",
    FontWeight->"Bold"],
  " then follows simply by inverting the matrix:"
}], "Text",
  CellTags->"i:101"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{
            SuperscriptBox[
              StyleBox["L",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(-1\)], 
            SubscriptBox[
              StyleBox["x",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"]}]}], TraditionalForm]]],
  "."
}], "NE6",
  CellTags->{"(1.6.25)", "i:105"}],

Cell[TextData[{
  "\tRecall that it is not always possible to find the inverse of a matrix. \
However, according to Theorem 1.1, the solution to an initial-value problem \
always exists and is unique, at least for problems that satisfy the \
strictures of the theorem. For linear problems of this type, the matrix \
inverse can be taken, and the unique solution given by Eq. ",
  ButtonBox["(1.6.25)",
    ButtonData:>"(1.6.25)",
    ButtonStyle->"Hyperlink"],
  " can be found."
}], "Text"],

Cell[TextData[{
  "\t   We can perform this matrix inversion numerically in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". But to do so, we must be more specific about the problem we are going to \
solve.  Lets take the case",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\_o = 0\)\)\)]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\  = \ 1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_o\)(t)\  = \ 1\)]],
  ", a constant damping rate. The equation we solve is then ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DifferentialD]x/\[DifferentialD]t\  = \ \(-x\)\
\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 1\)]],
  ". Then the analytic  solution to ",
  ButtonBox["Eq. (1.6.19)",
    ButtonData:>"(1.6.19)",
    ButtonStyle->"Hyperlink"],
  " is a simple exponential decay: ",
  Cell[BoxData[
      \(TraditionalForm\`x(t) = exp(\(-t\))\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tTo do the problem using matrix inversion, we choose a step size , say, \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.05"}], TraditionalForm]]],
  ", and solve the problem only up to a finite time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_f\)]],
  " = 2. This implies that the dimension ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " of the vector ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`2/0.05\  + \ 1\  = \ 41\)]],
  ", (the \"+1\" is necessary because ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " corresponds to the first element of ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  "), and the matrix ",
  StyleBox["L ",
    FontWeight->"Bold"],
  "is 41 by 41.  The following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " statements set up the vector ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  " and the matrix ",
  StyleBox["L",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\[CapitalDelta]t\  = \ 0.05; u[n_]\  = \ 1; \ M = 40;\), "\n", 
    \(\(x0\  = \ Table[0, {n, 0, M}];\)\), "\n", 
    \(\(x0[\([1]\)]\  = \ 1;\)\), "\n", 
    \(\(L = 
        Table[KroneckerDelta[n, m] - 
            KroneckerDelta[n - 1, m] \((1 - \[CapitalDelta]t\ u[m])\), {n, 0, 
            M}, {m, 0, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.81"],

Cell[TextData[{
  "We then solve for ",
  StyleBox["x",
    FontWeight->"Bold"],
  " using ",
  ButtonBox["Eq. (1.6.25)",
    ButtonData:>"(1.6.25)",
    ButtonStyle->"Hyperlink"],
  ", and create a data list ",
  StyleBox["sol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " consisting of times and positions ",
  Cell[BoxData[
      \(TraditionalForm\`{t\_n, x\_n}\)]],
  ": "
}], "Text"],

Cell[BoxData[{
    \(\(x = Inverse[L] . x0;\)\), "\n", 
    \(\(sol\  = \ 
        Table[{n\ \[CapitalDelta]t, x[\([n + 1]\)]}, {n, 0, 
            M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.82"],

Cell[TextData[{
  "This solution can be plotted and compared with ",
  Cell[BoxData[
      \(TraditionalForm\`exp(\(-t\))\)]],
  " (see Cell ",
  ButtonBox["1.83",
    ButtonData:>"Cell 1.83",
    ButtonStyle->"Hyperlink"],
  "), showing good agreement (which could be further improved by taking a \
smaller step size and increasing the dimension ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " of the system)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = 
        ListPlot[sol, PlotStyle \[Rule] PointSize[0.012], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(b = 
        Plot[E^\(-t\), {t, 0, 2}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[a, b, DisplayFunction -> $DisplayFunction, 
        PlotLabel \[Rule] "\<Matrix Inversion compared to E^-t\>", 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.83"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.588604 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matrix) show
105.000 13.000 moveto
(Inversion) show
165.000 13.000 moveto
(compared) show
219.000 13.000 moveto
(to) show
237.000 13.000 moveto
(E) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.012 w
.02381 .60332 Mdot
.04762 .57389 Mdot
.07143 .54593 Mdot
.09524 .51937 Mdot
.11905 .49414 Mdot
.14286 .47017 Mdot
.16667 .44739 Mdot
.19048 .42576 Mdot
.21429 .40521 Mdot
.2381 .38568 Mdot
.2619 .36713 Mdot
.28571 .34951 Mdot
.30952 .33277 Mdot
.33333 .31687 Mdot
.35714 .30176 Mdot
.38095 .28741 Mdot
.40476 .27378 Mdot
.42857 .26082 Mdot
.45238 .24852 Mdot
.47619 .23683 Mdot
.5 .22572 Mdot
.52381 .21517 Mdot
.54762 .20515 Mdot
.57143 .19563 Mdot
.59524 .18658 Mdot
.61905 .17799 Mdot
.64286 .16982 Mdot
.66667 .16207 Mdot
.69048 .1547 Mdot
.71429 .1477 Mdot
.7381 .14105 Mdot
.7619 .13474 Mdot
.78571 .12873 Mdot
.80952 .12303 Mdot
.83333 .11762 Mdot
.85714 .11247 Mdot
.88095 .10758 Mdot
.90476 .10294 Mdot
.92857 .09853 Mdot
.95238 .09434 Mdot
.97619 .09036 Mdot
.5 Mabswid
.02381 .60332 m
.06244 .55745 L
.10458 .51149 L
.14415 .47188 L
.18221 .43676 L
.22272 .40234 L
.26171 .37187 L
.30316 .3421 L
.34309 .31576 L
.3815 .29243 L
.42237 .26959 L
.46172 .24938 L
.49955 .23145 L
.53984 .21387 L
.57861 .1983 L
.61984 .18307 L
.65954 .1696 L
.69774 .15767 L
.73838 .14597 L
.77751 .13562 L
.81909 .12551 L
.85916 .11657 L
.89771 .10865 L
.93871 .1009 L
.97619 .09437 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00GOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03cooooo1Ol0
000Pooooo`00GOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool005gooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo00?oV9RHob4Q8Oo^k^h0
8Oooool005gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03kooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03gooooo
00?oV9RHob4Q8Oo^k^h08?ooool005gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03ogMgMomVIVKooooo01oooooo001Mooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
01kooooo001Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0noooo
o`05o`000?nj^[[ooooooiRHV?l@41008?ooool005gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000m
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`08?ooool00?ooooooJOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?oooooo>_ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo000Nooooo`03o`00
0?oooooooooo0?oooooo>_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo000Goooooooo0000
>Ol0000;ooooo`03o`000?oooooooooo00_ooooo000Nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo000N
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;
ooooo`007_ooool00ol0003oooooooooo`3oooooocSooooo00?o410@o`000?l000000ol0000:oooo
o`007_ooool00ol0003oooooooooo`3ooooooc[ooooo00?o0000ooooooooool02oooool001kooooo
00?o0000ooooooooool0ooooooljooooo`03o`000?oooooooooo00_ooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooolUoooo
o`?o00008?ooool001kooooo00?o0000ooooooooool0oooooolNooooo`?o00001?ooool3o`00023o
oooo000Nooooo`03o`000?oooooooooo0?oooooo7_ooool3o`0000;ooooo1Ol0000Pooooo`007_oo
ool00ol0003oooooooooo`3ooooooaKooooo0ol00005ooooo`Go00009Oooool001kooooo00?o0000
ooooooooool0ooooool?ooooo`?o00001?ooool8o`0002[ooooo000Nooooo`?o0000ooooool7oooo
o`?o00001Oooool:o`0002oooooo000Nooooo`03o`000?oooooooooo0?oooooo1oooool3o`0000;o
oooo1_l0000fooooo`007_ooool00ol0003oooooooooo`3oooooo`?o00001?ooool5o`0003cooooo
000Nooooo`03o`000?oooooooooo0?oooooo0ol000000ooooooo0000o`000002o`00043ooooo000N
ooooo`03o`000?oooooooooo0?Sooooo0ol00004ooooo`Co0000A?ooool001kooooo00?o0000oooo
ooooool0l?ooool3o`0000Gooooo1ol00018ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3`ooooo`?o00000oooool5o`00
04cooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0>Wooooo0ol00004ooooo`Ko0000DOooool0
00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000
ooooooooool0jOooool3o`0000;ooooo1?l0001Eooooo`001?ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000>7ooooo0ol00005ooooo`Go0000FOooool0
00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000
ooooooooool0hOooool3o`0000;ooooo1?l0001Mooooo`001?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Jooooo`?o00001?ooool5
o`00067ooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Gooooo00?o0000ooooooooool0f_ooool7o`0006Kooooo0004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
doooool3o`0000Cooooo0ol0001Zooooo`007_ooool00ol0003oooooooooo`3Cooooo`?o000000Co
ooooo`000?l0003o0000KOooool001kooooo00?o0000ooooooooool0boooool3o`0000Gooooo1?l0
001`ooooo`007_ooool00ol0003oooooooooo`3;ooooo`?o00000oooool3o`0007?ooooo000Noooo
o`03o`000?oooooooooo0<Cooooo0ol00004ooooo`Ko0000M_ooool001kooooo0ol00034ooooo`?o
00000_ooool4o`0007[ooooo000Nooooo`03o`000?oooooooooo0<Cooooo1Ol0001nooooo`007_oo
ool00ol0003oooooooooo`2looooo`?o00000oooool3o`0008;ooooo000Nooooo`03o`000?oooooo
oooo0;cooooo1_l00025ooooo`007_ooool00ol0003oooooooooo`2eooooo`?o00001?ooool3o`00
08Sooooo000Nooooo`03o`000?oooooooooo0;Gooooo0ol00003ooooo`;o0000R_ooool001kooooo
00?o0000ooooooooool0]Oooool6o`0008cooooo000Nooooo`03o`000?oooooooooo0:kooooo0ol0
0004ooooo`?o0000Soooool001kooooo00?o0000ooooooooool0[_ooool3o`000004ooooool0003o
0000o`0009;ooooo000Nooooo`?o0000[_ooool4o`0009Gooooo000Nooooo`03o`000?oooooooooo
0:Kooooo0ol00003ooooo`?o0000V?ooool001kooooo00?o0000ooooooooool0Y_ooool6o`0009_o
oooo000Nooooo`03o`000?oooooooooo0:Kooooo0ol0002Nooooo`007_ooool00ol0003ooooooooo
o`2Oooooo`?o00000_ooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo09oooooo1Ol0002S
ooooo`007_ooool00ol0003oooooooooo`2Oooooo`?o0000YOooool001kooooo00?o0000oooooooo
ool0Uoooool3o`0000?ooooo0_l0002Xooooo`007_ooool00ol0003oooooooooo`2Gooooo`?o0000
00?oooooo`000?l00000Z_ooool001kooooo0ol0002Gooooo`Co0000[?ooool001kooooo00?o0000
ooooooooool0T?ooool3o`0000?ooooo0ol0002^ooooo`007_ooool00ol0003oooooooooo`2@oooo
o`?o000000?oooooo`000?l00000/Oooool001kooooo00?o0000ooooooooool0T?ooool4o`000;?o
oooo000Nooooo`03o`000?oooooooooo093ooooo0_l0002eooooo`007_ooool00ol0003ooooooooo
o`29ooooo`?o000000Coooooo`000?l0003o0000]oooool001kooooo00?o0000ooooooooool0ROoo
ool4o`000;[ooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo08Wooooo0ol0002kooooo`001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0POooool3o`0000;ooooo0ol0002nooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol00005ooooo`?o0000POooool5o`000<7ooooo0004ooooo`05o`000?oooooo
ooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo087ooooo
0ol00033ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
00001_ooool00ol0003oooooooooo`20ooooo`;o0000aOooool000Cooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0N_ooool3o`000003
ooooool0003o00000<Oooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo07[ooooo1?l00039ooooo`001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`1jooooo`?o
0000b_ooool001kooooo00?o0000ooooooooool0N?ooool2o`000<gooooo000Nooooo`03o`000?oo
oooooooo07;ooooo0ol000000ooooooo0000o`00003?ooooo`007_ooool00ol0003oooooooooo`1b
ooooo`Co0000dOooool001kooooo00?o0000ooooooooool0L_ooool3o`000=;ooooo000Nooooo`?o
0000LOooool2o`000=Cooooo000Nooooo`03o`000?oooooooooo06_ooooo0ol00002ooooo`03o`00
0?oooooooooo0=Cooooo000Nooooo`03o`000?oooooooooo06_ooooo1Ol0003Gooooo`007_ooool0
0ol0003oooooooooo`1[ooooo`?o0000fOooool001kooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`3Iooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o0000g?ooool001kooooo
00?o0000ooooooooool0I?ooool3o`000003ooooool0003ooooo0=gooooo000Nooooo`03o`000?oo
oooooooo06Cooooo1?l0003Oooooo`007_ooool00ol0003oooooooooo`1Tooooo`?o0000h?ooool0
01kooooo0ol0001Sooooo`;o0000h_ooool001kooooo00?o0000ooooooooool0G?ooool3o`0000?o
oooo00?o0000ooooooooool0h_ooool001kooooo00?o0000ooooooooool0G?ooool3o`000003oooo
ool0003o00000>Gooooo000Nooooo`03o`000?oooooooooo05cooooo1?l0003Wooooo`007_ooool0
0ol0003oooooooooo`1Mooooo`;o0000j?ooool001kooooo00?o0000ooooooooool0Foooool2o`00
0>[ooooo000Nooooo`03o`000?oooooooooo05Gooooo0ol00002ooooo`03o`000?oooooooooo0>[o
oooo000Nooooo`03o`000?oooooooooo05Gooooo1Ol0003]ooooo`007_ooool00ol0003ooooooooo
o`1Eooooo`?o0000koooool001kooooo0ol0001Eooooo`03o`000?oooooooooo0>oooooo000Noooo
o`03o`000?oooooooooo05?ooooo0_l0003booooo`007_ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo0?;ooooo000Nooooo`03o`000?oooooooooo04kooooo1?l0003eooooo`007_oo
ool00ol0003oooooooooo`1>ooooo`?o0000m_ooool001kooooo00?o0000ooooooooool0COooool4
o`000?Kooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0n?oo
ool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`3iooooo`001?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo04Kooooo1Ol0003looooo`001?ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`?o0000A_ooool3o`000?kooooo0004ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000
ooooooooool0A_ooool3o`000?kooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0ooooool0
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`3oooooo`7ooooo0004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool0ooooool2ooooo`007_ooool00ol0003oooooooooo`0oooooo`Co0000ooooool5
ooooo`007_ooool00ol0003oooooooooo`0oooooo`?o0000ooooool6ooooo`007_ooool00ol0003o
ooooooooo`0oooooo`?o0000ooooool6ooooo`007_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo0?oooooo1oooool001kooooo0ol0000mooooo`03o`000?oooooooooo0?oooooo2?oo
ool001kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`3oooooo`Wooooo000Noooo
o`03o`000?oooooooooo03Oooooo1Ol0003oooooo`cooooo000Nooooo`03o`000?oooooooooo03Oo
oooo0ol0003oooooo`kooooo000Nooooo`03o`000?oooooooooo03Oooooo0ol0003oooooo`kooooo
000Nooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0ooooool>ooooo`007_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo0?oooooo3oooool001kooooo00?o0000oooo
ooooool0=?ooool2o`000?oooooo4_ooool001kooooo00?o0000ooooooooool0<?ooool4o`000?oo
oooo5?ooool001kooooo0ol0000`ooooo`?o0000oooooolEooooo`007_ooool00ol0003ooooooooo
o`0`ooooo`?o0000oooooolEooooo`007_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo0?oooooo5Oooool001kooooo00?o0000ooooooooool0;_ooool2o`000?oooooo6?ooool001ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3ooooooaSooooo000Nooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0oooooolIooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`?o0000oooooolLooooo`007_ooool00ol0003oooooooooo`0Yooooo`?o0000oooooolL
ooooo`007_ooool00ol0003oooooooooo`0Yooooo`?o0000oooooolLooooo`007_ooool3o`0002So
oooo00?o0000ooooooooool0oooooolMooooo`007_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0?oooooo7_ooool001kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`3ooooooaoooooo000Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0oooooolP
ooooo`007_ooool00ol0003oooooooooo`0Qooooo`Co0000oooooolSooooo`007_ooool00ol0003o
ooooooooo`0Qooooo`?o0000oooooolTooooo`007_ooool00ol0003oooooooooo`0Qooooo`?o0000
oooooolTooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0?oo
oooo8oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3ooooo
obCooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Gooooo0ol0000Pooooo`03o`000?oooooooooo0?oooooo9Oooool000Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo0?oooooo9_ooool000Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`0Jooooo`?o0000
00?oooooo`000?ooool0oooooolXooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo01[ooooo1?l0003oooooob[o
oooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Gooooo00?o0000ooooooooool06_ooool3o`000?oooooo:oooool000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo0?oooooo:_ooool001kooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`3oooooob_ooooo000Nooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0ooooool/ooooo`007_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?oooooo
;Oooool001kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3oooooobkooooo000N
ooooo`?o00004_ooool3o`000003ooooool0003ooooo0?oooooo<?ooool001kooooo00?o0000oooo
ooooool04_ooool4o`000?oooooo<_ooool001kooooo00?o0000ooooooooool04_ooool3o`000?oo
oooo<oooool001kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3ooooooc;ooooo
000Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0oooooolcooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0?oooooo=?ooool001kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`3oooooocGooooo000Nooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0oooooolfooooo`007_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo0?oooooo=oooool001kooooo0ol0000;ooooo`?o0000ooooooljooooo`007_ooool0
0ol0003oooooooooo`0;ooooo`?o0000ooooooljooooo`007_ooool00ol0003oooooooooo`0;oooo
o`?o0000ooooooljooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oo
oooo>oooool001kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3ooooooccooooo
000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooollooooo`007_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo?Oooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3oooooockooooo000Nooooo`03o`000?oooooooooo00Co
oooo0ol0003ooooood7ooooo000Nooooo`?o00001?ooool3o`000?oooooo@Oooool001kooooo00?o
0000ooooooooool01?ooool3o`000?oooooo@Oooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3ooooood;ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom2ooooo`007_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo@oooool001kooooo00Go0000ooooooooooooooooo`00003oooooodKooooo000Nooooo`04o`00
0?ooooooooooo`000?ooooooAoooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?oooooo00000?ooooooB?ooool001Oooooo00?o0000ooooooooool00oooool3o`000?ooooooBOoo
ool001Oooooo00?o0000ooooooooool00oooool4o`000?ooooooB?ooool001Oooooo00?o0000oooo
ooooool00oooool3o`000?ooooooBOooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003?ooooo`04oa0@4?l0003o
0000o`0009Gooooo003@ooooo`03o`000?oooooooooo09Gooooo003@ooooo`03o`000?oooooooooo
09Gooooo000gooooo`;o000000So410@oooooooooooo410@o`000?l@413ooooooiRHV0;o000000?o
MgMgoa0@4?l000000oooool01onHV9So0000o`000?m4A4Co^[Zjooooool@41001Ol00004ooooo`Go
00000_ooool2o`0000;ooooo0_l00006ooooo`Go00000oooool01?l@413o0000o`000?ooool2o`00
0006oa0@4?oooooooooooooooolQ8B7o<S8b1?ooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oo
oooo410@1Ol00003ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0oooool5o`0000;ooooo00Ko
k^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool00oooool01OmVIVKo0000o`000?m4A4Coc<c<00;ooooo00Ook^k^oeEEEOl0003o0000oeEE
EOo^k^kooooo00;o00000_ooool02?l0003oooooooooool0003o410@ooooool0003oMgMg0_l00000
1?mEEEGok^k^oooooonHV9P2o`000005ogMgMol@413o0000ooooool@41001Ol00003ooooo`06onk^
k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01oo^k^koEEEEo`000?l0003oV9RHo`000?l@41001_oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h7oooo
o`Ko00004oooool01OnHV9So0000o`000?m4A4Co^[Zj03[ooooo000hooooo`03o`000?oooooooooo
00;ooooo00So0000oooooooooooo0000olc<c?o^k^koQhN7o`0000Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40?ooooo00?o0000ooooooooool01?ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Gooooo00?o
0000ooooooooool00_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0_ooool01_mEEEGoMgMgoooo
ooooooooMgMgoeEEE@;ooooo00Co0000oooooooooooo00000_ooool03ol0003oooooooooool0003o
EEEEonk^k_ooooooMgMgoeEEEOoooooo0000olc<c?o^k^koQhN7o`000004ooooo`03o`000?oooooo
oooo00Cooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06oeEEEOmgMgOoooooonk^k_mE
EEGo00001oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooooooooogMg
MomEEED8ooooo`05o`000?ooooooooooooooool000004oooool01Ol@413o^[Zjonk^k_mgMgOo410@
03[ooooo000hooooo`03o`000?oooooooooo00;ooooo00So0000oooooooooooo410@ohN7Qooooooo
k^k^o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo00CogMgMo`000?l@413oc<c<2Oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool01?l@413o^[ZjoiRHV?lb<S83ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000onk^k_oo
ool00_ooool01ol0003ooooooa0@4?n7QhOoooooonk^k_l000001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooonk^k_l00007ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool@41002_ooool6o`0000?ooooo00?o0000ooooooooool0??ooool003Sooooo
00Ko0000oooooom4A4CoA4A4ooooool00002ooooo`03okZj^_l@413o000000;o00001?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01?o^
k^ko8B4Qoa0@4?o^k^h9ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`06oiRHV?lb<S;oooooooooool@413o^[Zj0_ooool6o`0000?ooooo00?o0000oooooooo
ool01?ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPGooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000onk^k_ooool00_ooool01?l0003o
oooookZj^_l@4103o`0000Cooooo00?o0000ooooooooool01?ooool6o`0000;ooooo00Ko0000oooo
ooooooooooooonk^k_l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo410@01Gooooo00?o0000ooooooooool0??oo
ool003Sooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl00005ooooo`03olc<c?l0003ooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003o<S8bomgMg@07ooooo`03o`000?oooooooooo00?ooooo
00Co8B4QogMgMomgMgOo<S8b2Oooool00ol0003oooooooooo`04ooooo`09o`000?n7QhOoooooojVY
ZOl0003oooooonk^k_l0003ogMgM00;ooooo00[oV9RHoc8b<_oooooooooooeEEEOn7QhOok^k^oooo
oon7QhOo<S8b0oooool00ol0003o<S8bomgMg@04ooooo`06o`000?nj^[[oooooonk^k_mgMgOo0000
1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol0
003oQhN7oooooonYZJWo000000Gooooo00KoIVIVogMgMoooooooooooohN7Qol00002ooooo`06oeEE
EOmgMgOooooooooooomgMgOoEEEE0_ooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B400_oo
ool01_l0003oEEEEonk^k_ooooooMgMgofIVIPCooooo00?oc<c<o`000?ooool00oooool00ol0003o
<S8bomgMg@04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooo^
k^koEEEEo`0000Oooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooooooooMgMgoeEE
E@Sooooo0ol0000Eooooo`03o`000?oooooooooo03cooooo000hooooo`06o`000?n7QhOoZJVYokZj
^_mEEEGo00000oooool01?lb<S;o0000o`000?nHV9P2ooooo`03oa0@4?l0003o000000?o00000ooo
ool2o`000004ojVYZOlQ8B7o0000ob4Q8@?ooooo00?o410@o`000?l000001?ooool2o`0000;ooooo
0_l00008ooooo`03o`000?oooooooooo00?ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
oa0@4002o`0000;ooooo0ol000000oooooook^k^oeEEE@02o`000004odA4A?o^k^koooooooooo`;o
000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000?ooooo00?o
410@o`000?l000001?ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`03ooooo`06onk^k_mVIVKo0000o`000?m4A4Co00000_ooool0
4oo^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVY
ZOoooooo410@o`000?mgMgL00_l000001OmVIVKok^k^oooooooooooo<S8b00;o000000CoV9RHoooo
oooooooooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000o`000?m4A4Co
k^k^0_ooool01_o^k^koEEEEo`000?l@413oc<c<o`0000Gooooo00?o410@o`000?l000000ol00003
ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^2?ooool01Ol0003ooooooa0@4?oooooo410@00Co
oooo00Go<S8bolc<c?ooooooc<c<oc8b<P08ooooo`03oa0@4?l0003o000000?o0000>oooool003So
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000;ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0Poooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00Go0000
ooooooooooooooooo`000004ooooo`05olc<c?l@413oV9RHoa0@4?o<c<`02_ooool00ol0003ooooo
ooooo`0looooo`00=oooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@00[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`Go0000;_ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool6o`0000Gooooo00?o
ZJVYo`000?nYZJT02oooool00ol0003oooooooooo`0looooo`00Foooool00ol@413oooooooooo`11
ooooo`03oa0@4?oooooooooo057ooooo0_l0001cooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.209491, -0.082779, \
0.00845269, 0.00683836}}]
}, Open  ]],

Cell[TextData[{
  "\tNote that the matrix-inverse method of solution, outlined above,  is \
equivalent to the recursive solution of ",
  ButtonBox["Eq.  (1.6.20)",
    ButtonData:>"(1.6.20)",
    ButtonStyle->"Hyperlink"],
  ". In fact,  performing the recursion in ",
  ButtonBox["Eq. (1.6.20)",
    ButtonData:>"(1.6.20)",
    ButtonStyle->"Hyperlink"],
  " can be thought of as just a way of performing the operations of taking \
the matrix inverse and applying the inverse to ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ", so little is gained in any practical sense from using ",
  ButtonBox["Eq. (1.6.25)",
    ButtonData:>"(1.6.25)",
    ButtonStyle->"Hyperlink"],
  " rather than ",
  ButtonBox["Eq. (1.6.20)",
    ButtonData:>"(1.6.20)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe matrix inverse method is really most useful in solving linear ",
  StyleBox["boundary-value ",
    FontSlant->"Italic"],
  "problems, because matrix inversion solves the problem in a single step.  \
This compares favorably with the shooting method for boundary-value problems \
(discussed in Sec. ",
  ButtonBox["1.5.2",
    ButtonData:>"c:31",
    ButtonStyle->"Hyperlink"],
  ") , which is an iterative process that requires several steps and an \
initial guess to find the solution."
}], "Text",
  CellTags->"i:116"],

Cell[TextData[{
  "\tFinally, we note the following: we have seen that a matrix ",
  StyleBox["L ",
    FontWeight->"Bold"],
  "can be connected to any linear differential operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " , and the inverse of the matrix, ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["L",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  ",  is useful in finding a solution to ODEs involving ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " . Therefore, it may  be useful to think about the ",
  StyleBox["inverse of the operator itself",
    FontSlant->"Italic"],
  ", which we might write as  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\&^\^\(-1\)\)\(.\)\)\)]],
  " In fact, we will see in Chapter ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", None},
    ButtonStyle->"Hyperlink"],
  " that the inverse of a linear differential operator can be defined, that \
its discretized form ",
  StyleBox["is",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["L",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  ", and that this operator inverse is connected to the idea of a ",
  StyleBox["Green\[CloseCurlyQuote]s function",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.6.4 Inhomogeneous Linear ODEs", "Subsubtitle",
  CellTags->"c:42"],

Cell[CellGroupData[{

Cell["Homogeneous and Particular Solutions", "Section",
  CellTags->"c:43"],

Cell[TextData[{
  " \tIn the preceding sections, we discussed solutions ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") to the homogeneous linear ODE  for some linear differential operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " .  Let us now consider the case of an ",
  StyleBox["inhomogeneous",
    FontSlant->"Italic"],
  " linear ODE,"
}], "Text",
  CellTags->"i:86"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = f\)]],
  "."
}], "NE6",
  CellTags->"(1.6.26)"],

Cell["\<\
\tWe will examine the general solution of this problem, so that we \
do not have to specify boundary or initial conditions. Using the \
superposition principle, we write the general solution as a linear \
combination of two functions:\
\>", "Text",
  CellTags->"i:119"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(t) = \(x\_h\)(t) + \(x\_p\)(t)\)]],
  ","
}], "NE6",
  CellTags->"(1.6.27)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t)\)]],
  " is the general solution to the homogeneous problem, satisfying"
}], "Text",
  CellTags->"i:87"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(L\&^\) x\_h = 0\)\(,\)\)\)]]], "NE6",
  CellTags->"(1.6.28)"],

Cell[TextData[{
  "and where ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  " is any solution to the inhomogeneous problem, satisfying"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x\_p = f\)]],
  "."
}], "NE6",
  CellTags->"(1.6.29)"],

Cell[TextData[{
  " The function ",
  Cell[BoxData[
      \(TraditionalForm\`x\_h\)]],
  " is called the ",
  StyleBox["homogeneous solution",
    FontSlant->"Italic"],
  ", and the function ",
  Cell[BoxData[
      \(TraditionalForm\`x\_p\)]],
  " is called a ",
  StyleBox["particular solution",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:88"],

Cell[TextData[{
  "\tActing on ",
  ButtonBox["Eq. (1.6.27)",
    ButtonData:>"(1.6.27)",
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ", it is clear that ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  StyleBox["  ",
    FontSlant->"Italic"],
  "satisfies",
  StyleBox[" ",
    FontSlant->"Italic"],
  ButtonBox["Eq. (1.6.26)",
    ButtonData:>"(1.6.26)",
    ButtonStyle->"Hyperlink"],
  ". It is also clear that ",
  ButtonBox["Eq. (1.6.28)",
    ButtonData:>"(1.6.28)",
    ButtonStyle->"Hyperlink"],
  " is the general solution of ",
  ButtonBox["Eq. (1.6.26)",
    ButtonData:>"(1.6.26)",
    ButtonStyle->"Hyperlink"],
  ", since ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t)\)]],
  " contains all of the undetermined constants necessary to satisfy any given \
set of boundary or initial conditions."
}], "Text"],

Cell[TextData[{
  "\tWe have already discussed how to find  the homogeneous solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t)\)]],
  ", in Sec. ",
  ButtonBox["1.6.2",
    ButtonData:>"c:38",
    ButtonStyle->"Hyperlink"],
  " . The problem then comes down to finding a particular solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  "  to the inhomogeneous problem.  This is actually rather nontrivial, and a \
complete and general answer will not be obtained until the end of Chapter ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", None},
    ButtonStyle->"Hyperlink"],
  ". We will take the problem in steps of increasing difficulty."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Method of Undetermined Coefficients", "Section",
  CellTags->{"i:93", "c:44"}],

Cell[TextData[{
  "\t As a first step to finding a particular solution, we will consider the \
case where the ODE has constant coefficients; i.e., the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_n\)(t)\)]],
  " appearing in ",
  ButtonBox["Eq. (1.6.1)",
    ButtonData:>"(1.6.1)",
    ButtonStyle->"Hyperlink"],
  " are time-independent constants, so that the ",
  StyleBox["N",
    FontSlant->"Italic"],
  "th-order ODE takes the form of ",
  ButtonBox["Eq. (1.6.7)",
    ButtonData:>"(1.6.7)",
    ButtonStyle->"Hyperlink"],
  ". Also, we will assume that the forcing function ",
  StyleBox["f(t)",
    FontSlant->"Italic"],
  " is of a very simple analytic form. With these assumptions,  an analytic  \
solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  "  can be found simply by guessing a form for the solution. This is called \
the \"method of undetermined coefficients\" in elementary texts on ODEs."
}], "Text",
  CellTags->"i:94"],

Cell["\<\
\t Take, for example, the simple case of a linearly increasing \
force,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = a + b\ t\)]],
  "."
}], "NE6",
  CellTags->"(1.6.30)"],

Cell["\<\
For the response to this force, let's try the same form back again:\
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t) = A\  + \ B\ t\)]],
  ","
}], "NE6",
  CellTags->"(1.6.31)"],

Cell[TextData[{
  "where ",
  StyleBox["A",
    FontSlant->"Italic"],
  " and ",
  StyleBox["B",
    FontSlant->"Italic"],
  " are undetermined coefficients. Acting on this guess with ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  "  yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x\_p = \(u\_o\)(A + B\ t) + \(u\_1\) B\)]],
  " ,"
}], "NE6",
  CellTags->"(1.6.32)"],

Cell[TextData[{
  "which is of the same form as ",
  StyleBox["f",
    FontSlant->"Italic"],
  ", provided that we now choose values for ",
  StyleBox["A",
    FontSlant->"Italic"],
  " and ",
  StyleBox["B",
    FontSlant->"Italic"],
  " correctly so as to satisfy ",
  ButtonBox["Eq. (1.6.7):",
    ButtonData:>"(1.6.7)",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(u\_o\) A + \(u\_1\) B = a, \ \ \ \(u\_o\) B = 
        b\)]],
  "."
}], "NE6",
  CellTags->"(1.6.33)"],

Cell[TextData[{
  "According to Eq. ",
  ButtonBox["(1.6.31)",
    ButtonData:>"(1.6.31)",
    ButtonStyle->"Hyperlink"],
  ", one way that the system can respond to a linearly increasing force is \
for the amplitude to increase linearly as well: as you push harder on a \
spring, it stretches further.  But this is only one possible solution; the \
spring could also oscillate. In fact, we know that the general solution to \
this problem is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(t) = \(x\_h\)(t) + A\  + \ B\ t\)]],
  "."
}], "NE6",
  CellTags->"(1.6.34)"],

Cell[TextData[{
  "The oscillations are contained in the homogeneous solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t)\)]],
  ", and their amplitude is set by the initial or boundary conditions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Response to Sinusoidal Forcing", "Section",
  CellTags->{"i:103", "c:45"}],

Cell[TextData[{
  "\tThere are many other analytically-tractable forcing functions that we \
could consider. Of course, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " could find such solutions for us, using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  However, there is one more case that we will solve in detail by hand, \
because it  will turn out to be  of great importance to our future work:  the \
case of an oscillating  force of the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = \(f\_o\) cos\[Omega]\ t\)]],
  "."
}], "NE6",
  CellTags->"(1.6.35)"],

Cell["\<\
A particular solution for this type of force can be found using the \
guess\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t) = 
        A\ cos\[Omega]\ t + \ B\ sin\[Omega]\ t\)]],
  ","
}], "NE6",
  CellTags->"(1.6.36)"],

Cell[TextData[{
  "where the constants ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " remain to be determined. In other words, the system responds to the \
oscillatory forcing with an oscillation",
  StyleBox[" of the same frequency",
    FontSlant->"Italic"],
  ".  If we substitute this into ",
  ButtonBox["Eq. (1.6.7) ",
    ButtonData:>"(1.6.7)",
    ButtonStyle->"Hyperlink"],
  " we obtain, after some work,  "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`L\&^\ x\_p = \(cos(\[Omega]\ t)\)\ \(\[Sum]\+\(n = 0\)\
\%\(N\/2\)\((A\ \(\(u\_\(2\ n\)\)(\(-\[Omega]\^2\))\)\^n + 
                B\ \[Omega]\ \(\(u\_\(2\ n + \
1\)\)(\(-\[Omega]\^2\))\)\^n)\)\)\  + \ \ \ \(sin(\[Omega]\ t)\)\ \
\(\[Sum]\+\(n = 0\)\%\(N\/2\)\(\((B\ \(\(u\_\(2\ n\)\)(\(-\[Omega]\^2\))\)\^n \
- A\ \[Omega]\ \(\(u\_\(2\ n + 1\)\)(\(-\[Omega]\^2\))\)\^n)\)\(.\)\)\)\)]]], \
"NE6",
  CellTags->"(1.6.37)"],

Cell[TextData[{
  "This equation can be solved by choosing ",
  StyleBox["A",
    FontSlant->"Italic"],
  " and ",
  StyleBox["B",
    FontSlant->"Italic"],
  " so that the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(sin\[Omega]\)\(\ \)\(t\)\(\ \)\)\)]],
  " vanishes and the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`cos\[Omega]\ t\)]],
  " equals ",
  Cell[BoxData[
      \(TraditionalForm\`f\_o\)]],
  StyleBox[".",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[TextData[{
  "\tA simpler alternative method of solution for this problem employs \
complex notation. We replace ",
  ButtonBox["Eq. (1.6.35)",
    ButtonData:>"(1.6.35)",
    ButtonStyle->"Hyperlink"],
  " by "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`f(t) = 
      Re\ \(f\_o\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\)]]], \
"NE6",
  CellTags->"(1.6.38)"],

Cell["and we now try the form", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(x\_p\)(t) = 
      Re\ C\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\)]]], "NE6",\

  CellTags->"(1.6.39)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C\  = \[LeftBracketingBar]C\[RightBracketingBar]\ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\)]],
  " is a complex number. The magnitude ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(C\)\(|\)\)\)]],
  " is the amplitude of the oscillation, and the argument ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "is the phase of the oscillation with respect to the applied forcing.  \
Using amplitude and phase notation, ",
  ButtonBox["Eq. (1.6.39)",
    ButtonData:>"(1.6.39)",
    ButtonStyle->"Hyperlink"],
  " can be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t) = \(\(\(|\)\(C\)\(|\)\(cos(\[Omega]\ t\  - \[Phi])\)\)\  = \(\(|\
\)\(C\)\(|\)\(\(cos\[Phi]\ cos\[Omega]\ t\)\(+\)\)\(|\)\(C\)\(|\)\(sin\[Phi]\ \
sin\[Omega]\ t\)\)\)\)]],
  "."
}], "NE6",
  CellTags->"(1.6.40)"],

Cell[TextData[{
  "By comparing ",
  ButtonBox["Eq. (1.6.40)",
    ButtonData:>"(1.6.40)",
    ButtonStyle->"Hyperlink"],
  " to ",
  ButtonBox["Eq. (1.6.36)",
    ButtonData:>"(1.6.36)",
    ButtonStyle->"Hyperlink"],
  "  we can make the identifications ",
  Cell[BoxData[
      \(TraditionalForm\`A = \(\(|\)\(C\)\(|\)\(cos\[Phi]\)\)\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B = \(\(|\)\(C\)\(|\)\(sin\[Phi]\)\)\)]],
  " . "
}], "Text"],

Cell[TextData[{
  "\tThe solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  "  can again be found by substituting ",
  ButtonBox["Eq. (1.6.39)",
    ButtonData:>"(1.6.39)",
    ButtonStyle->"Hyperlink"],
  " into ",
  ButtonBox["Eq. (1.6.7)",
    ButtonData:>"(1.6.7)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) 
          x\_p = \(Re\ C\ \(\(L\)\(\ \)\)\&^\ \ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \[Omega]\ t\) = \(\(Re\)\(\ \)\(f\_o\)\(\ \ \)\(\
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\)\(\ \)\)\)\)]],
  ","
}], "NE6",
  CellTags->"(1.6.41)"],

Cell[TextData[{
  "where we have assumed that the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`u\_n\)]],
  " in  ",
  ButtonBox["Eq. (1.6.7)",
    ButtonData:>"(1.6.7)",
    ButtonStyle->"Hyperlink"],
  " are real in order to take the operation ",
  Cell[BoxData[
      \(TraditionalForm\`Re\)]],
  " through ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  "  .  Now, rather than solving only for the real part, we will solve the \
full complex equation. (If the full complex equation is satisfied, the real \
part will also be satisfied.) Also, we will use the fact that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\^n\), \(\[DifferentialD]t\^n\),
              
              MultilineFunction->
                None], \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\
\)}], "=", \(\((\(-\[ImaginaryI]\)\ \[Omega])\)\^n\ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \[Omega]\ t\)\)}], TraditionalForm]]],
  ","
}], "NE6",
  CellTags->"(1.6.42)"],

Cell[TextData[{
  "so that ",
  ButtonBox["Eq. (1.6.41)",
    ButtonData:>"(1.6.41)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`C\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\
\ t\)\) \(\[Sum]\+\(n = 0\)\%N\(\((\(-\[ImaginaryI]\)\ \[Omega])\)\^n\) 
              u\_n\) = \(f\_o\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Omega]\ t\)\)]],
  "."
}], "NE6",
  CellTags->"(1.6.43)"],

Cell[TextData[{
  "Dividing through by the sum and using ",
  ButtonBox["Eq. (1.6.39)",
    ButtonData:>"(1.6.39)",
    ButtonStyle->"Hyperlink"],
  " allows us to write ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  " in the following elegant form:"
}], "Text",
  CellTags->"i:95"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(x\_p\)(t) = 
      Re(\ \(f\_o\/\(\[Sum]\+\(n = 0\)\%N\(\((\(-\[ImaginaryI]\)\ \[Omega])\)\
\^n\) u\_n\)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\))\)]]], \
"NE6",
  CellTags->"(1.6.44)"],

Cell[TextData[{
  "In future chapters we will find that complex notation often simplifies \
algebraic expressions involving trigonometric functions.\n\tLet us use ",
  ButtonBox["Eq. (1.6.44)",
    ButtonData:>"(1.6.44)",
    ButtonStyle->"Hyperlink"],
  " to explore the particular solution for the forced damped oscillator, ",
  ButtonBox["Eq. (1.6.2)",
    ButtonData:>"(1.6.2)",
    ButtonStyle->"Hyperlink"],
  ". For the choice of ",
  Cell[BoxData[
      \(TraditionalForm\`u\_n\)]],
  "'s corresponding to this ODE, ",
  ButtonBox["Eq. (1.6.44)",
    ButtonData:>"(1.6.44)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(x\_p\)(
        t)\)\(=\)\(Re(\ \(f\_o\/\(\(-\[Omega]\^2\) - \[ImaginaryI]\ \[Omega]\ \
\[Gamma]\  + \[Omega]\_o\%2\)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Omega]\ t\))\)\(\ \)\)\)]]], "NE6",
  CellTags->"(1.6.45)"],

Cell[TextData[{
  "This particular solution oscillates at constant amplitude, and with the \
same frequency as the forcing. Since the homogeneous solutions decay with \
time [see ",
  ButtonBox["Eq. (1.6.17)",
    ButtonData:>"(1.6.17)",
    ButtonStyle->"Hyperlink"],
  "], Eq. ",
  ButtonBox["(1.6.45)",
    ButtonData:>"(1.6.45)",
    ButtonStyle->"Hyperlink"],
  " represents the form of the solution at times large compared to \
1/\[Gamma]. At such large times, the oscillator has  'forgotten' its initial \
conditions;  every initial condition approaches ",
  ButtonBox["Eq. (1.6.45)",
    ButtonData:>"(1.6.45)",
    ButtonStyle->"Hyperlink"],
  ".  The convergence of different solutions can be seen directly in Fig. ",
  ButtonBox["1.18",
    ButtonData:>"Fig. 1.14",
    ButtonStyle->"Hyperlink"],
  ", which displays the time evolution of three different initial conditions. \
All three solutions converge to ",
  ButtonBox["Eq. (1.6.45)",
    ButtonData:>"(1.6.45)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0680272 0.309017 0.294302 [
[.15986 .29652 -3 -9 ]
[.15986 .29652 3 0 ]
[.29592 .29652 -3 -9 ]
[.29592 .29652 3 0 ]
[.43197 .29652 -3 -9 ]
[.43197 .29652 3 0 ]
[.56803 .29652 -3 -9 ]
[.56803 .29652 3 0 ]
[.70408 .29652 -6 -9 ]
[.70408 .29652 6 0 ]
[.84014 .29652 -6 -9 ]
[.84014 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .30902 m
.15986 .31527 L
s
[(2)] .15986 .29652 0 1 Mshowa
.29592 .30902 m
.29592 .31527 L
s
[(4)] .29592 .29652 0 1 Mshowa
.43197 .30902 m
.43197 .31527 L
s
[(6)] .43197 .29652 0 1 Mshowa
.56803 .30902 m
.56803 .31527 L
s
[(8)] .56803 .29652 0 1 Mshowa
.70408 .30902 m
.70408 .31527 L
s
[(10)] .70408 .29652 0 1 Mshowa
.84014 .30902 m
.84014 .31527 L
s
[(12)] .84014 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(14)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05782 .30902 m
.05782 .31277 L
s
.09184 .30902 m
.09184 .31277 L
s
.12585 .30902 m
.12585 .31277 L
s
.19388 .30902 m
.19388 .31277 L
s
.22789 .30902 m
.22789 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.32993 .30902 m
.32993 .31277 L
s
.36395 .30902 m
.36395 .31277 L
s
.39796 .30902 m
.39796 .31277 L
s
.46599 .30902 m
.46599 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53401 .30902 m
.53401 .31277 L
s
.60204 .30902 m
.60204 .31277 L
s
.63605 .30902 m
.63605 .31277 L
s
.67007 .30902 m
.67007 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.77211 .30902 m
.77211 .31277 L
s
.80612 .30902 m
.80612 .31277 L
s
.87415 .30902 m
.87415 .31277 L
s
.90816 .30902 m
.90816 .31277 L
s
.94218 .30902 m
.94218 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30902 m
.02499 .30906 L
.02605 .30918 L
.02729 .30939 L
.02846 .30969 L
.03053 .3104 L
.03279 .31143 L
.0379 .31468 L
.04262 .31857 L
.05285 .32856 L
.06244 .33752 L
.06713 .34095 L
.06955 .34235 L
.07218 .34356 L
.07367 .34407 L
.07439 .34428 L
.07505 .34444 L
.07637 .34468 L
.07709 .34477 L
.07778 .34482 L
.07906 .34484 L
.08024 .34477 L
.08153 .34459 L
.08218 .34446 L
.0829 .34428 L
.08435 .34382 L
.08573 .34325 L
.08831 .34184 L
.09109 .33984 L
.09411 .3371 L
.09955 .33079 L
.10458 .32358 L
.12483 .28758 L
.13475 .2712 L
.13909 .26539 L
.14139 .26276 L
.14385 .26032 L
.14625 .25834 L
.14843 .25691 L
.14948 .25635 L
.15062 .25583 L
.15169 .25544 L
.1527 .25516 L
.15382 .25494 L
.15505 .25481 L
.15625 .2548 L
.15754 .25492 L
.15874 .25515 L
.15988 .25548 L
.1609 .25586 L
Mistroke
.16201 .25637 L
.1646 .25791 L
.16693 .25975 L
.17217 .26525 L
.1816 .27922 L
.19177 .2979 L
.2025 .31801 L
.21167 .33249 L
.21687 .33872 L
.21939 .34111 L
.22172 .34292 L
.22412 .34436 L
.22539 .34495 L
.22673 .34544 L
.22789 .34575 L
.22899 .34595 L
.23018 .34606 L
.23147 .34606 L
.23255 .34595 L
.23373 .34574 L
.23497 .34541 L
.23611 .345 L
.23817 .34402 L
.24036 .34265 L
.24574 .33795 L
.25082 .33201 L
.26032 .31818 L
.26917 .30403 L
.27867 .29013 L
.28412 .28373 L
.2891 .27932 L
.29149 .27775 L
.29275 .27708 L
.2941 .27649 L
.29527 .27608 L
.29656 .27574 L
.29773 .27554 L
.29884 .27544 L
.3 .27543 L
.30127 .27553 L
.30191 .27562 L
.3026 .27576 L
.30383 .27609 L
.30507 .27653 L
.30623 .27704 L
.30842 .27826 L
.31099 .28011 L
.31337 .28219 L
.31875 .28811 L
.33981 .32055 L
Mistroke
.34884 .33407 L
.35382 .34016 L
.35855 .34469 L
.36121 .34662 L
.36262 .34744 L
.36411 .34817 L
.3655 .34869 L
.36675 .34905 L
.36801 .34929 L
.3692 .34941 L
.37042 .34942 L
.3717 .34931 L
.37279 .34912 L
.374 .34881 L
.37529 .34836 L
.37668 .34774 L
.37918 .34626 L
.38174 .3443 L
.38447 .34174 L
.38936 .33603 L
.40043 .31911 L
.41012 .3023 L
.42056 .28561 L
.42551 .27919 L
.42822 .27625 L
.43073 .27393 L
.43306 .27216 L
.43518 .27087 L
.43631 .27032 L
.43753 .26983 L
.43883 .26943 L
.44005 .26917 L
.44118 .26903 L
.44225 .26898 L
.44342 .26903 L
.44467 .2692 L
.44598 .26951 L
.44723 .26992 L
.44956 .27099 L
.45174 .27234 L
.45376 .27389 L
.45833 .27837 L
.46894 .29296 L
.47891 .30966 L
.48779 .32434 L
.49753 .33749 L
.49998 .34003 L
.5026 .34233 L
.50487 .34395 L
.50733 .3453 L
Mistroke
.50878 .34589 L
.50941 .34611 L
.51011 .3463 L
.51139 .34657 L
.51209 .34667 L
.51274 .34672 L
.51398 .34674 L
.51511 .34666 L
.51642 .34644 L
.51767 .34612 L
.51883 .34571 L
.51988 .34526 L
.52225 .34395 L
.5265 .34064 L
.53147 .33534 L
.53615 .32917 L
.55452 .29944 L
.55956 .2915 L
.56495 .28395 L
.56962 .27855 L
.57208 .2762 L
.57469 .27413 L
.57601 .27326 L
.57747 .27244 L
.57881 .27182 L
.58004 .27137 L
.5813 .27102 L
.58196 .27088 L
.58266 .27077 L
.58383 .27067 L
.58512 .27068 L
.58636 .2708 L
.5875 .27102 L
.5888 .27138 L
.59004 .27185 L
.59224 .27294 L
.59462 .27451 L
.59994 .27937 L
.60558 .28629 L
.61568 .30192 L
.62583 .31907 L
.63547 .33364 L
.63966 .33876 L
.64412 .34311 L
.64669 .34503 L
.64902 .34637 L
.65014 .34689 L
.65136 .34734 L
.6525 .34766 L
.65356 .34787 L
Mistroke
.65469 .34801 L
.65589 .34804 L
.65703 .34798 L
.65807 .34783 L
.65929 .34756 L
.65998 .34736 L
.66061 .34714 L
.66302 .34605 L
.66532 .34462 L
.66786 .34262 L
.673 .33732 L
.68378 .32197 L
.69389 .30493 L
.70374 .2891 L
.70911 .28187 L
.7141 .27651 L
.71838 .27316 L
.71961 .27243 L
.72077 .27184 L
.72181 .27139 L
.72295 .27099 L
.72412 .27068 L
.72536 .27046 L
.72651 .27037 L
.72759 .27037 L
.72886 .27048 L
.73001 .27068 L
.73065 .27084 L
.73135 .27104 L
.73261 .27151 L
.73494 .27266 L
.73745 .27434 L
.74199 .27843 L
.7474 .28488 L
.75236 .292 L
.76323 .30991 L
.77335 .32648 L
.78248 .33855 L
.78511 .34121 L
.78759 .34333 L
.78981 .34487 L
.79224 .34617 L
.79354 .34669 L
.79475 .34706 L
.79603 .34734 L
.79674 .34744 L
.7974 .34749 L
.79857 .34752 L
.79984 .34743 L
.80105 .34723 L
Mistroke
.80216 .34695 L
.80357 .34647 L
.8049 .34588 L
.80738 .34444 L
.81004 .34242 L
.81293 .33971 L
.82244 .32756 L
.83288 .31061 L
.8439 .2924 L
.84871 .28543 L
.85394 .27905 L
.85647 .27652 L
.85915 .27428 L
.86144 .27274 L
.86276 .27203 L
.86396 .27148 L
.86509 .27106 L
.86632 .27072 L
.86756 .27048 L
.86886 .27036 L
.87001 .27036 L
.87124 .27047 L
.8724 .27067 L
.87346 .27095 L
.87476 .2714 L
.87614 .27202 L
.87862 .27346 L
.88129 .27549 L
.88422 .27825 L
.89437 .29142 L
.90519 .30919 L
.91546 .32609 L
.92468 .33842 L
.9272 .34103 L
.92989 .34337 L
.93224 .34503 L
.93472 .34636 L
.93598 .34686 L
.93664 .34708 L
.93735 .34728 L
.9386 .34754 L
.93977 .34767 L
.94047 .3477 L
.94124 .34769 L
.94196 .34765 L
.94262 .34757 L
.94389 .34733 L
.94452 .34716 L
.94522 .34695 L
.94768 .3459 L
Mistroke
.94906 .34512 L
.95032 .34429 L
.9551 .34019 L
.95962 .33504 L
.96456 .32825 L
.97355 .31379 L
.97619 .30931 L
Mfstroke
.02381 .60332 m
.02499 .60328 L
.02605 .60316 L
.02729 .60294 L
.02846 .60265 L
.03053 .60192 L
.03279 .60084 L
.03527 .5993 L
.0379 .59727 L
.04262 .59257 L
.04749 .58625 L
.05205 .5789 L
.06244 .55658 L
.07305 .52518 L
.08274 .48869 L
.10458 .38504 L
.12517 .28115 L
.1352 .2384 L
.14429 .20811 L
.14886 .19655 L
.15127 .19152 L
.15381 .18703 L
.15603 .18378 L
.15848 .18097 L
.15955 .17998 L
.1607 .17908 L
.16171 .17843 L
.16277 .17789 L
.16409 .17741 L
.16531 .17716 L
.16662 .1771 L
.16737 .17716 L
.16807 .17727 L
.16933 .17762 L
.17048 .1781 L
.17175 .17879 L
.17308 .17972 L
.17541 .18177 L
.17757 .18416 L
.18248 .19113 L
.193 .21159 L
.20294 .23445 L
.21179 .25455 L
.22153 .27348 L
.22621 .28076 L
.23125 .287 L
.23403 .28973 L
.23657 .29176 L
.23912 .29337 L
.24039 .29401 L
Mistroke
.24154 .2945 L
.24261 .29489 L
.24376 .29523 L
.24498 .2955 L
.24612 .29568 L
.2472 .29578 L
.24833 .29582 L
.24931 .2958 L
.25037 .29573 L
.25163 .29558 L
.25277 .29538 L
.2541 .29508 L
.25535 .29474 L
.25999 .29304 L
.26967 .28834 L
.27497 .28586 L
.27757 .28484 L
.27994 .28407 L
.282 .28355 L
.28303 .28335 L
.28416 .28319 L
.2853 .28307 L
.28652 .28301 L
.28767 .28302 L
.28871 .28309 L
.28995 .28323 L
.2911 .28344 L
.29236 .28375 L
.29368 .28417 L
.29592 .2851 L
.29837 .28644 L
.3036 .29047 L
.30856 .2957 L
.31786 .30879 L
.33877 .34584 L
.3484 .36085 L
.35327 .36671 L
.35608 .3694 L
.35865 .37139 L
.36087 .37271 L
.36199 .37323 L
.36322 .37369 L
.36445 .37403 L
.36577 .37426 L
.36701 .37435 L
.36814 .37432 L
.36929 .37418 L
.37034 .37395 L
.3715 .3736 L
.37273 .37311 L
Mistroke
.37479 .37201 L
.37706 .3704 L
.38227 .36523 L
.38721 .35856 L
.39649 .34237 L
.4066 .32159 L
.41737 .29964 L
.42273 .29006 L
.42777 .2824 L
.4323 .27689 L
.43463 .27462 L
.43719 .2726 L
.43836 .27185 L
.4396 .27116 L
.44068 .27067 L
.44185 .27024 L
.44317 .26988 L
.44443 .26967 L
.44565 .26959 L
.44677 .26962 L
.44782 .26973 L
.44881 .26992 L
.44988 .27021 L
.45105 .27061 L
.45341 .27176 L
.45558 .27315 L
.46033 .27729 L
.4654 .28311 L
.47452 .29619 L
.4853 .3131 L
.49523 .32677 L
.50021 .33202 L
.50275 .33415 L
.50548 .33599 L
.50691 .33676 L
.50822 .33733 L
.50953 .33779 L
.51077 .33812 L
.51147 .33825 L
.51222 .33836 L
.51292 .33842 L
.51356 .33844 L
.51431 .33844 L
.51512 .33838 L
.51589 .33829 L
.51659 .33817 L
.51776 .33789 L
.51901 .33748 L
.52127 .33646 L
.52396 .33481 L
Mistroke
.5264 .33291 L
.53172 .32755 L
.53675 .3212 L
.55502 .29321 L
.56002 .28591 L
.56541 .27906 L
.57049 .27391 L
.57275 .27212 L
.57515 .27058 L
.57647 .26989 L
.57767 .26938 L
.57889 .26896 L
.58001 .26866 L
.58132 .26844 L
.58201 .26837 L
.58274 .26834 L
.58396 .26837 L
.58466 .26844 L
.58531 .26854 L
.58656 .26881 L
.58775 .26918 L
.58997 .27015 L
.59237 .27159 L
.59498 .27361 L
.60027 .27905 L
.6059 .28656 L
.616 .30309 L
.62559 .31994 L
.63569 .33573 L
.63985 .34095 L
.64431 .3454 L
.64687 .34736 L
.64919 .34875 L
.65032 .34927 L
.65153 .34973 L
.65268 .35007 L
.65374 .35029 L
.65485 .35043 L
.65605 .35047 L
.65718 .35041 L
.65821 .35027 L
.65942 .35001 L
.66074 .34959 L
.66198 .34908 L
.66313 .34851 L
.66566 .34691 L
.66795 .34508 L
.67308 .33977 L
.68382 .32435 L
.69393 .30713 L
Mistroke
.70371 .29117 L
.70906 .28382 L
.71404 .2783 L
.7183 .27481 L
.72068 .2734 L
.72286 .27247 L
.72409 .2721 L
.72524 .27186 L
.72649 .2717 L
.72712 .27167 L
.72782 .27166 L
.72899 .27174 L
.73025 .27194 L
.73143 .27224 L
.73252 .2726 L
.73501 .27375 L
.73727 .27518 L
.74234 .27961 L
.74704 .28506 L
.75147 .29118 L
.76154 .30725 L
.77219 .32462 L
.78174 .33743 L
.78435 .34015 L
.78716 .3426 L
.78981 .34444 L
.79098 .3451 L
.79223 .34569 L
.79335 .34613 L
.79458 .3465 L
.79571 .34675 L
.79677 .34689 L
.798 .34696 L
.79914 .34692 L
.80039 .34676 L
.80171 .34647 L
.80278 .34614 L
.80393 .34569 L
.80599 .34464 L
.80845 .343 L
.81069 .34116 L
.81553 .33612 L
.82065 .32941 L
.82984 .31496 L
.83986 .29808 L
.84538 .28941 L
.85063 .2822 L
.85551 .27674 L
.85809 .27443 L
.86083 .27246 L
Mistroke
.86214 .2717 L
.86337 .2711 L
.86457 .27062 L
.86568 .27027 L
.86673 .27002 L
.86783 .26985 L
.86895 .26977 L
.87017 .26979 L
.8714 .26992 L
.87256 .27015 L
.8736 .27044 L
.87474 .27085 L
.87728 .27211 L
.87964 .27368 L
.88392 .2775 L
.88847 .28275 L
.90817 .31406 L
.9168 .32799 L
.92168 .33478 L
.92623 .34004 L
.93079 .34405 L
.93334 .34569 L
.93566 .34678 L
.93693 .34721 L
.93811 .3475 L
.9394 .3477 L
.94005 .34775 L
.94076 .34777 L
.94196 .34772 L
.94325 .34755 L
.94447 .34727 L
.94558 .34692 L
.94687 .3464 L
.94824 .34572 L
.9507 .34415 L
.95628 .33911 L
.96161 .33261 L
.96644 .32559 L
.97619 .30953 L
Mfstroke
.02381 .01472 m
.04262 .11387 L
.06244 .23277 L
.07216 .2849 L
.08255 .33068 L
.08852 .35129 L
.09396 .36619 L
.09658 .37207 L
.09942 .37752 L
.1019 .3815 L
.10458 .385 L
.10712 .38761 L
.10945 .38942 L
.11057 .39011 L
.11179 .39072 L
.11295 .39118 L
.11402 .3915 L
.11467 .39166 L
.11538 .39178 L
.11666 .39191 L
.11791 .39192 L
.11905 .39183 L
.1203 .39164 L
.121 .39149 L
.12166 .39132 L
.12442 .39037 L
.12714 .38908 L
.12973 .38761 L
.13457 .3844 L
.14545 .37672 L
.15043 .37375 L
.1551 .3716 L
.15745 .37079 L
.15997 .37015 L
.16134 .3699 L
.16209 .3698 L
.16278 .36972 L
.16401 .36962 L
.16466 .3696 L
.16536 .36959 L
.1666 .36961 L
.16774 .36968 L
.16899 .36982 L
.16962 .36991 L
.17032 .37002 L
.17274 .37054 L
.17501 .37119 L
.17923 .37276 L
.18378 .37484 L
.19391 .37987 L
Mistroke
.19668 .38108 L
.19964 .38218 L
.20107 .38263 L
.20243 .38298 L
.20363 .38324 L
.20495 .38346 L
.20622 .3836 L
.2074 .38366 L
.20865 .38365 L
.20935 .38362 L
.20999 .38356 L
.21113 .38341 L
.21236 .38316 L
.21353 .38285 L
.21461 .38248 L
.21702 .38142 L
.21968 .37983 L
.22245 .37767 L
.22505 .37518 L
.22976 .36952 L
.23491 .36166 L
.24527 .34117 L
.26379 .2959 L
.27391 .27223 L
.28344 .25446 L
.28872 .24738 L
.29169 .2444 L
.29311 .24325 L
.29443 .24234 L
.29564 .24164 L
.29674 .24112 L
.29797 .24067 L
.29928 .24034 L
.30054 .24016 L
.30125 .24013 L
.30191 .24014 L
.30312 .24026 L
.30441 .24053 L
.30554 .24088 L
.30678 .2414 L
.30928 .24285 L
.3116 .24465 L
.31376 .2467 L
.31864 .25257 L
.32385 .26047 L
.34212 .295 L
.35235 .31338 L
.35774 .32128 L
.36068 .32489 L
.36344 .32775 L
Mistroke
.36605 .32997 L
.36843 .33158 L
.3697 .33226 L
.37108 .33286 L
.37183 .33314 L
.37254 .33335 L
.3732 .33352 L
.37392 .33367 L
.37519 .33383 L
.37638 .33387 L
.37754 .33382 L
.3786 .33368 L
.37976 .33344 L
.38103 .33307 L
.38235 .33256 L
.38359 .33198 L
.3886 .32864 L
.39143 .32612 L
.39405 .32344 L
.40396 .31112 L
.41289 .29891 L
.42252 .28725 L
.42755 .28262 L
.42975 .28101 L
.43215 .27958 L
.43326 .27904 L
.43444 .27856 L
.43546 .27821 L
.43656 .27792 L
.43781 .27768 L
.43899 .27755 L
.44014 .27752 L
.4412 .27758 L
.44238 .27773 L
.44366 .278 L
.44487 .27837 L
.44597 .27879 L
.44866 .28016 L
.45121 .28191 L
.45628 .2866 L
.4618 .29334 L
.48318 .32755 L
.48809 .33516 L
.49326 .34222 L
.49805 .34758 L
.50252 .35131 L
.50476 .35267 L
.50591 .35323 L
.50716 .35373 L
.50787 .35396 L
Mistroke
.50852 .35415 L
.50982 .35441 L
.51099 .35454 L
.51224 .35456 L
.51348 .35446 L
.51417 .35436 L
.51481 .35423 L
.51605 .35389 L
.51723 .35346 L
.51985 .35213 L
.52273 .3501 L
.52749 .34548 L
.53258 .33903 L
.54172 .32445 L
.56169 .28943 L
.56716 .28165 L
.57015 .27807 L
.57294 .27523 L
.57552 .27306 L
.57787 .2715 L
.57913 .27083 L
.58049 .27023 L
.58124 .26997 L
.58193 .26976 L
.58259 .26959 L
.58329 .26945 L
.58449 .2693 L
.58558 .26926 L
.58676 .26932 L
.58805 .26951 L
.58917 .26977 L
.59037 .27016 L
.59252 .27112 L
.59527 .27283 L
.59786 .27492 L
.60271 .27995 L
.61261 .29384 L
.62335 .31164 L
.63361 .32774 L
.63863 .33426 L
.64321 .33905 L
.64552 .34097 L
.64804 .34266 L
.64942 .3434 L
.6507 .34397 L
.65193 .3444 L
.65323 .34474 L
.65398 .34487 L
.65466 .34496 L
.65542 .34502 L
Mistroke
.65621 .34503 L
.6569 .34501 L
.65755 .34495 L
.65826 .34486 L
.65901 .34471 L
.66042 .34433 L
.66176 .34384 L
.66425 .34257 L
.66663 .34097 L
.66885 .33913 L
.67393 .33381 L
.68419 .31932 L
.70262 .28959 L
.70773 .28265 L
.71247 .27735 L
.71507 .27501 L
.71743 .27326 L
.72004 .27175 L
.72148 .27114 L
.72284 .27069 L
.72391 .27044 L
.72508 .27025 L
.72631 .27017 L
.72746 .2702 L
.72854 .27031 L
.72952 .27049 L
.73065 .27079 L
.73172 .27115 L
.73412 .27227 L
.73633 .27367 L
.74135 .27806 L
.74597 .28344 L
.75096 .29043 L
.75998 .30512 L
.76981 .32179 L
.77501 .32988 L
.78057 .33734 L
.78336 .34048 L
.786 .34302 L
.78856 .34506 L
.79093 .34654 L
.79318 .34758 L
.79431 .34796 L
.79556 .34827 L
.79681 .34846 L
.79751 .34852 L
.79815 .34854 L
.7994 .34849 L
.80058 .34833 L
.80126 .34819 L
Mistroke
.80191 .34803 L
.80311 .34765 L
.80441 .34711 L
.80581 .34639 L
.80834 .34475 L
.81066 .34285 L
.81601 .3372 L
.82167 .32959 L
.84154 .29677 L
.85021 .28399 L
.85511 .2783 L
.85965 .27433 L
.86196 .27283 L
.86451 .27162 L
.86579 .27119 L
.86646 .27101 L
.86717 .27086 L
.86847 .27068 L
.86967 .27063 L
.87081 .27069 L
.87202 .27085 L
.87316 .2711 L
.8742 .27142 L
.87543 .27189 L
.87675 .27252 L
.87916 .274 L
.88445 .27859 L
.89005 .28525 L
.90008 .30048 L
.91024 .31758 L
.91988 .33228 L
.92408 .33751 L
.92854 .342 L
.93111 .34402 L
.93344 .34545 L
.93456 .34601 L
.93577 .34651 L
.93692 .34688 L
.93797 .34713 L
.93904 .34731 L
.94019 .3474 L
.94127 .3474 L
.94225 .34732 L
.94341 .34713 L
.94466 .34682 L
.94585 .34642 L
.94694 .34595 L
.94912 .34477 L
.95153 .34309 L
.9564 .33852 L
Mistroke
.96132 .33252 L
.96661 .32482 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.875},
  ImageMargins->{{12, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0_l0003oooooodKo
oooo000Hooooo`03oeEEEOmVIVKo000000Kooooo0_l0003oooooodKooooo000Qooooo`;o0000oooo
oom6ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo0_l0003oooooodKooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooo`00003oooooodGooooo000Qooooo`03o`000?oo
oooo00000?ooooooAOooool0027ooooo00?o0000ooooool00000oooooom5ooooo`008Oooool00ol0
003oooooo`00003oooooodGooooo000Qooooo`04o`000?ooooooooooo`000?ooooooA?ooool0027o
oooo00Co0000oooooooooooo0000oooooom4ooooo`008Oooool01?l0003oooooooooool0003ooooo
odCooooo000Qooooo`04o`000?ooooooooooo`000?ooooooA?ooool0027ooooo1?l0003oooooodCo
oooo000Qooooo`05o`000?ooooooooooooooool00000oooooom3ooooo`008Oooool01Ol0003ooooo
oooooooooooo00000?oooooo@oooool0027ooooo00Go0000ooooooooooooooooo`00003ooooood?o
oooo000Qooooo`05o`000?ooooooooooooooool00000oooooom3ooooo`008Oooool01Ol0003ooooo
oooooooooooo00000?oooooo@oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
oom0ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo@?ooool0
027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooood3ooooo000Qooooo`?o
00000_ooool00ol0003oooooooooo`3ooooood3ooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0ooooooloooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo?oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
ooooocoooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolooooo
o`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?oooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocoooooo000Qooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooolnooooo`008Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo?_ooool0027ooooo0ol00004ooooo`03o`000?oooooooooo
0?oooooo?_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooocko
oooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolnooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo?_ooool0027ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0oooooolmooooo`001oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo??ooool000Oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo??ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooccooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0oooooollooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool5
o`000?oooooo6?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Noooo
o`;o00000oooool2o`000?oooooo5oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolEooooo`00
8Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooooaCooooo000Qooooo`?o00001oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolCooooo`008Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3ooooooa?ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo4_ooool0027o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0oooooolBooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3ooooooa7ooooo
000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0?oooooo4Oooool0027ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooooolA
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`3ooooooa3ooooo000Qooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oo
oooo4?ooool0027ooooo0ol00008ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`3oooooo`oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo3ooo
ool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0ooooool>ooooo`008Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3ooooo
o`kooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo3_ooool0027ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
ooooool=ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Looooo`;o0000k_ooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool06?ooool3o`000004ooooool0003o0000o`000>cooooo000Qooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool00oooool2o`000>_ooooo000Qooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Yooooo`008Oooool3o`0000[o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Xooooo`008Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool4o`0000oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>Sooooo
000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`02ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`3Wooooo`008Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`;o00003Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0i_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3Vooooo`008Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00000oooool5o`00
00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00;ooooo0_l000000ol@413oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00Ook^k^oc8b
<_l0003o410@olc<c?oooooo000002?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c002ooooo`?o0000
7_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`Co000000?o410@
ooooooooool01Ol0000Oooooo`Co000000?o410@ooooooooool00_ooool2o`000003oa0@4?oooooo
oooo01Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0
003oooooo`000004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01_ooooo00?oEEEEogMgMoooool02?l0000Oooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401ol0000Nooooo`03o`000?oooooooooo00;ooooo00CoMgMgoiRHV?ooooooV9RH
1Ol0000Looooo`03o`000?oooooooooo00;ooooo00KoV9RHob4Q8Oo^k^koooooodA4A?ooool6o`00
01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`008Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000001Oooool00onHV9So
8B4Qonk^kP05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool01?l0003o
ooooooooooooool6o`0000Sooooo00?o0000ooooooooool06_ooool01Ol0003oooooo`000?oooooo
000000Cooooo0ol0000Nooooo`04o`000?ooooooooooooooo`?o00001?ooool3o`0001cooooo00?o
0000ooooooooool00_ooool00ol@413oooooo`000003o`0000;ooooo0ol0000Jooooo`03o`000?oo
oooooooo00?ooooo00CoV9RHob4Q8Oo^k^kooooo0_l00004ooooo`;o00006Oooool00ol0003ooooo
ooooo`02ooooo`Go00005oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooo000000Oooooo00?oV9RHob4Q8Oo^k^h01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00om4A4CogMgMo`00
0005o`0000Kooooo00?o0000ooooooooool06_ooool00ol0003oV9RHo`000005o`0000?ooooo0_l0
000Mooooo`04oc8b<_nHV9SooooooiRHV0;o00001_ooool2o`0001cooooo00?o0000ooooooooool0
0_ooool3o`000003ooooool0003ooooo00Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo
00?oV9RHob4Q8Ol000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo
00CoA4A4omgMgOoooooo00006?ooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo
0_l00009ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?oooooo00001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Wooooo1?l000000oo<c<coooooooooo`03o`000003
ooooool0003o000001gooooo00Goc<c<o`000?l0003o0000olc<c008ooooo`;o00006oooool00ol0
003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0001Sooooo000Qooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_l00005oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool3o`0000Kooooo00?o0000oooo
ooooool00_l0000Looooo`05oa0@4?nj^[[o0000o`000?l@41002Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4007ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01?ooool3o`0000Wooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`03ooooo`03ogMgMoo<c<co000001Sooooo000Qooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo1?l0
00001Ooooooo0000ooooooo^k^koA4A400?o00001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Oooooo0ol000000onHV9Soooooooooo`05ooooo`04o`000?ooooooooooo`0001co
oooo0ol000000onj^[[o0000ooooo`09ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooo
oooooooo0_l000001?nHV9SooooooiRHV?mgMgL7ooooo`;o00005oooool00ol0003oooooooooo`02
ooooo`05o`000?nj^[[o0000oiRHV?l@41002Oooool2o`0001Kooooo00?o0000ooooooooool00ooo
ool00oo^k^koA4A4o`00000Hooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o00000oooool01_l0003ooooooooo
ooooooooMgMgo`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01Kooooo0_l000001?o<c<coA4A4o`000?l@4106ooooo`04o`000?oooooo0000o`0001_ooooo0ol0
00000ol@413oZJVYooooo`09ooooo`;o00005oooool00omEEEGoIVIVo`000002ooooo`;o000000Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00005?ooool00omEEEGoIVIVo`000004ooooo`05oiRH
V?l0003o0000ob4Q8Oo<c<`02_ooool2o`0001?ooooo00?oEEEEofIVI_l000001_ooool00omgMgOo
0000ooooo`0Gooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`;o00001?ooool2o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool05Oooool3o`0000_ooooo00Co0000ooooool0003o
00006Oooool00ol0003oooooo`00000>ooooo`;o00006oooool2o`0000gooooo0_l0000Kooooo`;o
00003_ooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`Co0000
0_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01?ooooo0ol0000<ooooo`05o`000?oooooo0000oooo
ool000006?ooool2o`00013ooooo00?o0000ooooooooool06?ooool2o`0000oooooo0_l0000Joooo
o`03o`000?oooooooooo00gooooo0_l0000eooooo`008Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00[ooooo0_l0000Eooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04oooool2o`0000kooooo00Co0000ooooool0003o00005oooool3o`00013ooooo0_l0000I
ooooo`03o`000?oooooooooo00oooooo0_l0000Hooooo`;o00004?ooool2o`0002_ooooo00GoV9RH
o`000?l0003oA4A4okZj^P04ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00[ooooo0_l0000Fooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Ooo
ool3o`0000oooooo00Co0000ooooool0003o00005_ooool2o`0001;ooooo0_l0000Gooooo`;o0000
4Oooool2o`0001Oooooo0_l0000Booooo`03o`000?oooooooooo02Wooooo00Go410@okZj^_o^k^ko
MgMgoa0@4004ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooool000005_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013o
oooo0_l0000@ooooo`05o`000?oooooo0000ooooool000005?ooool3o`0001;ooooo0_l0000Foooo
o`;o00004oooool2o`0001Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Kooooo000Joooooooo0000>_l0000<ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`03o`000?oooooooooo00;o00001_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001Oooool01Ol0003oooooo`000?oooooo000000[ooooo00?o0000oooo
ooooool02?ooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0_l00005ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003oooooo`000?oooooo000000Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02o`0000Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`000003oooo
ool0003ooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000:ooooo`03o`00
0?oooooooooo00Oooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo0_l0000Cooooo`03o`00
0?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool03?ooool2o`000003oooo
ool0003ooooo00Gooooo00?o0000ooooooooool02_ooool01Ol0003oooooo`000?oooooo0000013o
oooo0ol00005ooooo`03o`000?oooooooooo00kooooo0_l0000Cooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?oo
ool04oooool2o`0001?ooooo0_l0000Aooooo`03oa0@4?l0003o000000?o00001Oooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo
00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`0>ooooo`;o00004oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool02_ooool2o`0000;ooooo00?o0000oooo
ooooool04_ooool01Ol0003oooooo`000?oooooo000000oooooo0_l0000Hooooo`;o00004Oooool2
o`0001Oooooo0_l0000Booooo`03o`000?oooooooooo01Kooooo0_l0000Aooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00006Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooool0003oooooo`00
000Eooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool02oooool3o`0001Sooooo00?o
0000ooooool000003oooool2o`0001Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Gooooo`;o00004?ooool2o`0001Gooooo00?o0000ooooooooool01_ooool0027ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00cooooo0_l0000Eooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool05?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Wooooo
0ol0000Jooooo`;o00003oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo
0_l0000Jooooo`;o00003oooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000001cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`05o`00
0?ooooooooooooooool000001Oooool2o`0000Kooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`0Fooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`?o000000?oooooo`000?oo
ool06_ooool2o`0000gooooo0_l0000Kooooo`;o00003Oooool2o`0001cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0001Sooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;o00007?ooool2o`0000cooooo0_l0000Mooooo`03o`000?oooooooooo00_o
oooo0_l0000Mooooo`03o`000?oooooooooo00[ooooo0_l0000Pooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool4o`0000;ooooo00Co0000oooooooo
oooo00006_ooool00ol0003oooooo`000002ooooo`;o00001Oooool01?l0003oooooo`000?l0000N
ooooo`?o00002Oooool2o`0001oooooo00?o0000ooooooooool02Oooool2o`0001kooooo0_l0000;
ooooo`03o`000?oooooooooo01oooooo000Qooooo`?o00002Oooool2o`0000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo0ol0000Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000001_ooooo00?o0000ooooool000000_ooool6o`000003ooooool0003o0000023ooooo0ol00007
ooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`;o00008?ooool2o`0000Wooooo00?o0000
ooooooooool08?ooool0027ooooo00?o0000ooooooooool02oooool2o`0000Cooooo0_l00007oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000Koooo
o`03o`000?oooooooooo00;ooooo0_l00008ooooo`05o`000?ooooooooooooooool000007Oooool0
1?l0003oooooo`000?l00006ooooo`03o`000?oooooo0000027ooooo00?o0000ooooool000001?oo
ool2o`000003ooooool0003ooooo027ooooo0_l00006ooooo`;o00008_ooool2o`0000Oooooo00?o
0000ooooooooool08Oooool0027ooooo00?o0000ooooooooool03Oooool5o`0000Oooooo00?o0000
ooooooooool07oooool3o`000003ooooool0003o000000;ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`000003ooooool0
003ooooo02;ooooo2Ol0000Sooooo`?o00000oooool3o`0002Cooooo0_l00004ooooo`;o00009?oo
ool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00Cooooo0_l0
00001?oooooo0000o`000?l00004ooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`Co0000
00?oooooo`000?ooool09?ooool7o`0002Kooooo1_l0000Wooooo`Go00009Oooool0027ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00;ooooo0_l0000Wooooo`Co0000Ooooool0027ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo1?l0002/
ooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0d_ooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0=;ooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3Cooooo`008Oooool3o`0001?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3Dooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02oooool8o`00013ooooo00?o0000ooooooooool09?ooool2
o`0000Gooooo00?o0000ooooooooool0eOooool0027ooooo00?o0000ooooooooool05?ooool01Ol0
003ooooooooooooooooo000000_ooooo0_l00008ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09oooool5o`000=Sooooo000Qooooo`03o`000?oooooooooo01Gooooo00Co0000oooo
oooooooo00002Oooool2o`0000_ooooo0ol00009ooooo`;o0000ooooool8ooooo`008Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool03_ooool2o`00
00Oooooo00?o0000ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0Fooooo`;o
00001oooool2o`0001?ooooo1ol0003oooooo`[ooooo000Qooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooobCooooo000Qooooo`03o`000?oo
oooooooo01Oooooo0ol00003ooooo`;o0000oooooolVooooo`008Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooo000000?o0000oooooolXooooo`008Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo0?oooooo;?ooool0027ooooo0ol0000Fooooo`03o`000?oooooooooo0?oo
oooo;?ooool0027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3oooooobcooooo
000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0ooooool/ooooo`008Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo;?ooool0027ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`3oooooobgooooo000Qooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0ooooool]ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo0?oooooo;Oooool0027ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`3oooooobgooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0ooooool^
ooooo`008Oooool3o`0001Cooooo00?o0000ooooooooool0ooooool^ooooo`008Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo;_ooool0027ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`3oooooobkooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0ooooool^ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0?oooooo;oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3ooooo
oboooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0ooooool_
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3ooooooboooooo0007oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0ooooool_ooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool3o`0001;ooooo00?o0000ooooooooool0ooooool`
ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0ooooool`ooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo0?oooooo<?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`3ooooooc3ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`3ooooooc7ooooo000Qooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0oooooolaooooo`008Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo0?oooooo<Oooool0027ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`3ooooooc7ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
oooooolaooooo`008Oooool3o`00013ooooo00?o0000ooooooooool0oooooolbooooo`008Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo<_ooool0027ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`3ooooooc;ooooo000Qooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0oooooolbooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0?oooooo<oooool0027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`3ooooooc?ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooolc
ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo=?ooool0027o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3oooooocCooooo000Qooooo`?o0000
3_ooool00ol0003oooooooooo`3oooooocCooooo000Qooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0ooooooldooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0?oooooo=Oooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3ooooo
ocGooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0ooooooleooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo=_ooool0027ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`3oooooocKooooo000Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0oooooolfooooo`008Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0?oooooo=oooool0027ooooo0ol0000;ooooo`03o`000?oooooooooo0?oo
oooo=oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooocSooooo
000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooooolhooooo`008Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo>?ooool0027ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`3oooooocWooooo000Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0ooooooliooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0?oooooo>_ooool0027ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`3ooooooc[ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolk
ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo>oooool0027o
oooo0ol00007ooooo`03o`000?oooooooooo0?oooooo>oooool0027ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3ooooooccooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooollooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01?ooool2o`000?oooooo?oooool0027o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocoooooo000Hooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
?oooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo@?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
o`000?oooooo@oooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool0
0ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-1.59627, -1.08578, \
0.0588523, 0.0136036}}],

Cell[TextData[{
  "Fig. 1.18 Three solutions to the driven damped oscillator equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] + x\^\[Prime] + 2  x = 
        cos3\ t\)]],
  "."
}], "Caption",
  CellTags->"Fig. 1.18"],

Cell[TextData[{
  "\t The loss of memory of initial conditions at long times is a general \
feature of linear driven damped systems. Nonlinear driven damped systems, \
such as the van der Pol oscillator [",
  ButtonBox["Eq. (1.2.20)",
    ButtonData:>"(1.2.20)",
    ButtonStyle->"Hyperlink"],
  "] with a driving term added, also display loss of memory of initial \
conditions; but initial conditions do not necessarily collapse onto a single \
trajectory as in Fig. ",
  ButtonBox["1.18",
    ButtonData:>"Fig. 1.14",
    ButtonStyle->"Hyperlink"],
  ". For instance, orbits can collapse onto a strange attractor, and \
subsequently wander chaotically across the surface of this attractor. A \
detailed analysis of the complex chaotic behavior of nonlinear driven damped \
systems is beyond the scope of this introductory text; see ",
  ButtonBox["Ott",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " (1993),  for a discussion of this subject."
}], "Text",
  CellTags->"i:102"]
}, Closed]],

Cell[CellGroupData[{

Cell["Resonance", "Section",
  CellTags->{"i:96", "c:46"}],

Cell[TextData[{
  "The particular solution to the driven damped oscillator equation has an \
amplitude that depends on the frequency \[Omega] at which the system is \
driven.  According to Eq. ",
  ButtonBox["(1.6.45)",
    ButtonData:>"(1.6.45)",
    ButtonStyle->"Hyperlink"],
  ", this complex amplitude is ",
  Cell[BoxData[
      \(TraditionalForm\`C\  = \(\(f\_o/\((\(-\[Omega]\^2\) - \[ImaginaryI]\ \
\[Omega]\ \[Gamma]\  + \[Omega]\_o\%2)\)\)\(\ \)\)\)]],
  ". Plots of the magnitude and phase of ",
  Cell[BoxData[
      \(TraditionalForm\`C/f\_o\)]],
  " are shown in Fig. ",
  ButtonBox["1.19",
    ButtonData:>"Fig. 1.15",
    ButtonStyle->"Hyperlink"],
  " as a function of  \[Omega]."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.176581 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 33.25 6 ]
[.01131 .08829 -18 -4.5 ]
[.01131 .08829 0 4.5 ]
[.01131 .17658 -6 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -18 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -6 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -18 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -6 -4.5 ]
[.01131 .52974 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -22.25 0 ]
[.02381 .64303 22.25 12.875 ]
[.5 .63053 -40.625 0 ]
[.5 .63053 40.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(\\220) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
87.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
92.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .08829 m
.03006 .08829 L
s
[(0.5)] .01131 .08829 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(1)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(1.5)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(2)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(2.5)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(3)] .01131 .52974 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3.5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01766 m
.02756 .01766 L
s
.02381 .03532 m
.02756 .03532 L
s
.02381 .05297 m
.02756 .05297 L
s
.02381 .07063 m
.02756 .07063 L
s
.02381 .10595 m
.02756 .10595 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14126 m
.02756 .14126 L
s
.02381 .15892 m
.02756 .15892 L
s
.02381 .19424 m
.02756 .19424 L
s
.02381 .2119 m
.02756 .2119 L
s
.02381 .22956 m
.02756 .22956 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .28253 m
.02756 .28253 L
s
.02381 .30019 m
.02756 .30019 L
s
.02381 .31785 m
.02756 .31785 L
s
.02381 .3355 m
.02756 .3355 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .38848 m
.02756 .38848 L
s
.02381 .40614 m
.02756 .40614 L
s
.02381 .42379 m
.02756 .42379 L
s
.02381 .45911 m
.02756 .45911 L
s
.02381 .47677 m
.02756 .47677 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .51209 m
.02756 .51209 L
s
.02381 .5474 m
.02756 .5474 L
s
.02381 .56506 m
.02756 .56506 L
s
.02381 .58272 m
.02756 .58272 L
s
.02381 .60038 m
.02756 .60038 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -83.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
81.000 15.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
81.000 9.438 moveto
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.438 moveto
(\\220) show
92.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
98.250 15.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
103.500 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -101.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
93.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(\\220) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
111.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
116.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
122.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
140.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.015 w
.02381 .17658 m
.02499 .17658 L
.02605 .17658 L
.02729 .17659 L
.02846 .17659 L
.03053 .17661 L
.03279 .17663 L
.03527 .17666 L
.0379 .1767 L
.04262 .17679 L
.04749 .17691 L
.05205 .17705 L
.06244 .17746 L
.07305 .17801 L
.08274 .17864 L
.10458 .18047 L
.12357 .18255 L
.14429 .18537 L
.18493 .19264 L
.22406 .20199 L
.26565 .2146 L
.30571 .22919 L
.34426 .24458 L
.36381 .25223 L
.38527 .2598 L
.39512 .26277 L
.40569 .26546 L
.41081 .26654 L
.41566 .26741 L
.42035 .26811 L
.42475 .26863 L
.42715 .26885 L
.42934 .26901 L
.43178 .26915 L
.43306 .26921 L
.43377 .26923 L
.43441 .26925 L
.43563 .26928 L
.43694 .26929 L
.43816 .26929 L
.43931 .26928 L
.43996 .26927 L
.44064 .26925 L
.44188 .26921 L
.4432 .26916 L
.44466 .26908 L
.44706 .26891 L
.44925 .26871 L
.45418 .2681 L
.45875 .26735 L
Mistroke
.46308 .26645 L
.4727 .26387 L
.48293 .26023 L
.50133 .25155 L
.54296 .22463 L
.58308 .19502 L
.62168 .16801 L
.66274 .1431 L
.70228 .12316 L
.7403 .10733 L
.78078 .09346 L
.81974 .08245 L
.86115 .07275 L
.90105 .06494 L
.93943 .05858 L
.97619 .05334 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 0 m
.06244 .01008 L
.10458 .02148 L
.14415 .03298 L
.18221 .04522 L
.22272 .06011 L
.26171 .07701 L
.30316 .09878 L
.34309 .12467 L
.3815 .15517 L
.42237 .19393 L
.46172 .23582 L
.49955 .2769 L
.53984 .31726 L
.57861 .35031 L
.61984 .37874 L
.65954 .40045 L
.69774 .41714 L
.73838 .43147 L
.77751 .4427 L
.81909 .45255 L
.85916 .46048 L
.89771 .46697 L
.93871 .47292 L
.97619 .47765 L
s
0 g
[ .03 .03 ] 0 setdash
.43757 .26487 m
.43757 0 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.0588604 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 27.25 6 ]
[.01131 .13244 -6 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -6 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -6 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -6 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -22.25 0 ]
[.02381 .64303 22.25 12.875 ]
[.5 .63053 -37.625 0 ]
[.5 .63053 37.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
81.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(10)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -83.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
81.000 15.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
81.000 9.438 moveto
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.438 moveto
(\\220) show
92.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
98.250 15.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
103.500 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -98.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(H) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(\\220) show
99.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
105.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
116.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.015 w
.02381 .07328 m
.02499 .07328 L
.02605 .07328 L
.02729 .07329 L
.02846 .07329 L
.03053 .07329 L
.03279 .0733 L
.03527 .07332 L
.0379 .07333 L
.04262 .07337 L
.04749 .07343 L
.05205 .07349 L
.06244 .07367 L
.07305 .07391 L
.08274 .07419 L
.10458 .075 L
.12357 .07594 L
.14429 .07725 L
.16561 .07892 L
.18493 .08077 L
.22406 .0857 L
.24331 .08886 L
.26413 .09299 L
.28368 .0977 L
.30513 .10409 L
.32579 .11182 L
.34462 .12073 L
.36413 .13259 L
.38505 .14967 L
.40413 .17139 L
.41491 .1876 L
.42489 .20625 L
.43387 .22711 L
.44355 .25554 L
.45418 .29675 L
.46416 .34908 L
.4838 .50402 L
.48919 .55168 L
.49215 .57414 L
.4936 .58339 L
.49494 .59058 L
.4962 .59603 L
.49685 .59826 L
.49754 .60022 L
.49824 .60172 L
.49889 .60268 L
.49966 .60326 L
.50037 .60325 L
.50158 .60203 L
.5029 .59899 L
Mistroke
.50414 .59454 L
.5053 .58912 L
.50779 .57369 L
.51049 .55242 L
.51537 .5069 L
.52449 .41964 L
.53424 .34279 L
.54492 .28053 L
.55526 .23672 L
.5649 .20592 L
.57508 .18072 L
.58598 .15962 L
.59618 .14384 L
.60726 .12988 L
.62739 .11046 L
.6472 .09638 L
.66822 .08501 L
.70603 .07039 L
.72541 .06481 L
.74628 .05979 L
.78747 .05209 L
.82715 .04655 L
.86531 .04241 L
.90592 .0389 L
.94502 .03616 L
.97619 .03432 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 .02058 m
.02499 .02058 L
.02605 .02058 L
.02729 .02058 L
.02846 .02058 L
.03053 .02058 L
.03279 .02058 L
.03527 .02059 L
.0379 .02059 L
.04262 .02059 L
.04749 .0206 L
.05205 .0206 L
.06244 .02062 L
.07305 .02064 L
.08274 .02067 L
.10458 .02075 L
.12357 .02085 L
.14429 .02098 L
.16561 .02115 L
.18493 .02133 L
.22406 .02183 L
.24331 .02215 L
.26413 .02257 L
.28368 .02304 L
.30513 .02369 L
.32556 .02446 L
.34462 .02537 L
.36497 .02664 L
.38353 .02818 L
.40261 .03037 L
.4134 .032 L
.42337 .0339 L
.433 .03621 L
.44204 .03899 L
.45195 .04303 L
.45749 .04593 L
.46264 .04919 L
.47221 .05728 L
.47727 .06302 L
.48268 .07067 L
.49374 .09213 L
.50378 .11648 L
.5131 .13712 L
.52297 .15304 L
.52812 .15912 L
.53379 .16446 L
.54376 .1714 L
.54898 .17414 L
.55393 .17633 L
.56321 .17964 L
Mistroke
.57321 .18237 L
.5841 .18465 L
.60381 .18763 L
.61483 .18886 L
.6248 .18979 L
.64409 .19124 L
.66492 .19242 L
.6849 .19331 L
.70597 .19405 L
.744 .19507 L
.78447 .19584 L
.82344 .1964 L
.86485 .19686 L
.90475 .1972 L
.94313 .19747 L
.97619 .19767 L
Mfstroke
0 g
[ .03 .03 ] 0 setdash
.49881 .60332 m
.49881 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{589.5, 173.25},
  ImageMargins->{{3, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;P0000f2000`400?l00000o`00003ooooooooo
ooooon;ooooo003oooooooooooooh_ooool00?oooooooooooooRooooo`00ooooooooooooon;ooooo
003oooooooooooooh_ooool00?oooooooooooooRooooo`00ooooooooooooon;ooooo003ooooooooo
ooooh_ooool00?oooooooooooooRooooo`00ooooooooooooon;ooooo001Rooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0aooooo`Co0000
00?o410@ooooooooool0<?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd0<?ooool5o`000:Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03?ooooo1?l000000ol@413oooooooooo`0b
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0booooo`Go0000@Oooool006;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0;oooool01OnHV9So8B4Qonk^k_ooooooA4A40:Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0dooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool0<Oooool01OnHV9So8B4Qonk^k_ooooooA4A4047ooooo001Rooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0_ooooo`03oiRHV?lQ8B7ok^k^0:Sooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo00?oV9RHob4Q8Oo^k^h0@_ooool0
06;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03;ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo037ooooo00?oV9RH
ob4Q8Oo^k^h0Yoooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0=?oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0<ooo
ool00onHV9So8B4Qonk^kP11ooooo`00H_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03?ooooo00?oMgMgofIVI_ooool0Y_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00eooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Gooooo00?o
MgMgofIVI_ooool0@?ooool006;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0YOooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0oooooo`00H_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool01Ol0003o^[ZjoooooonHV9So410@0:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00Go0000okZj
^_ooooooV9RHoa0@4011ooooo`00H_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000b
ooooo`03oeEEEOmVIVKo000003Cooooo00?oEEEEofIVI_l000003Oooool4o`00037ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c02Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003Cooooo
00?oEEEEofIVI_l00000=_ooool00omEEEGoIVIVo`00000=ooooo`Co0000<oooool01OnHV9So410@
o`000?lQ8B7oc<c<047ooooo003ooooooeSooooo0_l00013ooooo`03o`000?oooooooooo0?oooooo
6?ooool00olQ8B7ogMgMooooo`0;ooooo`;o00006_ooool00?ooooooB_ooool00olQ8B7ogMgMoooo
o`0:ooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool0ooooool?ooooo`07ohN7
Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03oiRHV?mEEEGooooo00?ooooo00SoQhN7o`00
0?mEEEGoIVIVo`000?lb<S;ok^k^o`0000;ooooo00?o0000ooooooooool05oooool00?oooooo@?oo
ool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00oooool00onHV9SoEEEEooooo`02ooooo`09
ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^k_oooooo000000;ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`3oooooo`oooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00?o
oooo00?o0000omgMgOooool00_ooool02?l@413ogMgMogMgMolQ8B7oooooohN7QomVIVKo00000_oo
ool00ol0003oooooooooo`0Gooooo`00oooooom0ooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7
ofIVIP04ooooo`0;o`000?oMgMgoooooooooool@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_oo
ool2o`0004?ooooo00?o0000ooooooooool0ooooool?ooooo`07o`000?oooooogMgMoc8b<_oooooo
k^k^oa0@4003ooooo`;oMgMg0oooool02?l0003oooooomgMgOlb<S;oooooonk^k_l@413ooooo0_l0
000Jooooo`00oooooom0ooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4004ooooo`;oMgMg
0_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@4100@?ooooooo`00013o00002Oooool01?mE
EEGoZJVYooooool00002ooooo`07o`000?ooooooooooooooooo^k^ko410@onk^kP02ooooo`04oeEE
EOnYZJWoooooo`0000;ooooo00?o0000ooooooooool06oooool002Sooooo1_l00004o`00ooko0000
3oooool01?mEEEGoZJVYooooool00002ooooo`03o`000?oooooooooo00;ooooo00Sok^k^oa0@4?o^
k^kooooooeEEEOnYZJWoooooo`0000;ooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ooMgMgo8B4Qonk^
kP03ooooo`03o`000?oooooooooo00;ooooo00OoEEEEoiRHV?ooooooooooomgMgOlQ8B7ok^k^00?o
oooo00?o0000ooooooooool06oooool002kooooo00Co0000oooooooooooooooo1Ol00?l4ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03omgMgOlQ8B7ok^k^
00?ooooo00?o0000ooooooooool00oooool01_mEEEGoV9RHoooooooMgMgo8B4Qonk^kP?ooooo00?o
0000ooooooooool0AOoooom:o`00ocKooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo00kooooo00?oV9RHogMgMoooool00_ooool00ol0003ooooooooo
o`02ooooo`03omgMgOl@413ooooo00;ooooo00?oV9RHogMgMoooool00_ooool00ol0003ooooooooo
o`0Kooooo`00;_ooool00ol0003oooooooooo`06ooooo`Go003oGoooool00ol0003oooooooooo`2R
ooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool00oooool01_oMgMgo410@oooooooo
ooooV9RHogMgM`?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`17oooooaKo003o
_Oooool00omEEEGoV9RHooooo`0Tooooo`00;_ooool00ol0003oooooooooo`0;ooooo`Co003oFooo
ool00ol0003oooooooooo`2^ooooo`03oeEEEOnHV9Sooooo04gooooo00?o0000ooooooooool0GOoo
ool9o`00oi;ooooo2?oo000Jooooo`03okZj^_m4A4Cooooo02Cooooo000^ooooo`;o00004?ooool3
o`00oeSooooo00?o0000ooooooooool0[_ooool00onj^[[oA4A4ooooo`1=ooooo`03o`000?oooooo
oooo06Kooooo1Ol00?lBooooo`03o`000?oooooooooo06oooooo4Ooo0011ooooo`00;_ooool00ol0
003oooooooooo`0Booooo`Co003oE?ooool00ol0003oooooooooo`3nooooo`03o`000?oooooooooo
06_ooooo0ol00?l?ooooo`03o`000?oooooooooo06Cooooo7?oo0011ooooo`00;_ooool00ol0003o
ooooooooo`0Fooooo`?o003oDOooool00ol0003oooooooooo`3nooooo`03o`000?oooooooooo06ko
oooo0_l00?l=ooooo`03o`000?oooooooooo05Wooooo9ooo0011ooooo`00;_ooool00ol0003ooooo
ooooo`0Iooooo`?o003ooooooom@ooooo`;o0000LOooool2o`00o`_ooooo00?o0000ooooooooool0
Coooool/ool004Kooooo000^ooooo`03o`000?oooooooooo01cooooo1?l00?ooooooodcooooo00?o
0000ooooooooool0L_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo04Kooooo;?oo
001?ooooo`00;_ooool2o`00027ooooo0ol00?ooooooodWooooo00?o0000ooooooooool0Loooool2
o`00o`Sooooo00?o0000ooooooooool0@OoooolVool005[ooooo000^ooooo`03o`000?oooooooooo
02?ooooo0ol00?ooooooodKooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo03gooooo7ooo001Uooooo`00;_ooool00ol0003oooooooooo`0Vooooo`?o
003ooooooom3ooooo`03o`000?oooooooooo07Kooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`0joooooaSoo`00Koooool002kooooo00?o0000ooooooooool0:Oooool3o`00oooooooo
@?ooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool0
=_oooolCool007Sooooo000^ooooo`;o0000;Oooool3o`00ol?ooooo1ooo001booooo`03o`000?oo
oooooooo07Sooooo00?o003oooooooooool0=ooooolBool007gooooo000^ooooo`03o`000?oooooo
oooo02oooooo0ol00?lhooooo`03o`000?oooooooooo07kooooo3_oo001`oooooagoo`00HOooool0
0ol00?ooooooooooo`0coooooa7oo`00POooool002kooooo00?o0000ooooooooool0<_ooool2o`00
ocKooooo00?o0000ooooooooool0NOoooolCool0073ooooo9ooo001Gooooo`03o`00oooooooooooo
037ooooo4?oo0024ooooo`00;_ooool00ol0003oooooooooo`0dooooo`;o003o=?ooool00ol0003o
ooooooooo`1coooooaCoo`00MOooooleool004[ooooo00?o003oooooooooool0;Oooool?ool008So
oooo000^ooooo`03o`000?oooooooooo03Kooooo0_l00?lbooooo`03o`000?oooooooooo06kooooo
4_oo001looooocgoo`00@_ooool00ol00?ooooooooooo`0[ooooo`goo`00S?ooool002kooooo0_l0
000iooooo`;o003o<?ooool00ol0003oooooooooo`1Xoooooa?oo`00Poooool00ol0003ooooooooo
o`0EooooobSoo`00?_ooool00ol00?ooooooooooo`0Xooooo`coo`00Soooool002kooooo00?o0000
ooooooooool0>_ooool2o`00obkooooo00?o0000ooooooooool0HooooolBool008Wooooo00?o0000
ooooooooool07ooooolRool003[ooooo00?o003oooooooooool09_ooool<ool0097ooooo000Doooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`03o`000?oooooooooo03cooooo0_l00?l/ooooo`03o`000?oooooooooo05kooooo4_oo
002>ooooo`03o`000?oooooooooo02gooooo5ooo000hooooo`03o`00ool0003ooooo02?ooooo2ooo
002Dooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool0?_ooool2o`00ob[ooooo00?o0000ooooooooool0Fooo
ool?ool009Cooooo00?o0000ooooooooool0=OoooolCool003Cooooo00?o003oo`000?ooool08_oo
ool:ool009Kooooo000Dooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo043ooooo0ol00?lWooooo`03o`000?oooooooooo05Sooooo3Ooo
002Iooooo`03o`000?oooooooooo03[ooooo4_oo000`ooooo`03o`00ool0003ooooo027ooooo2Ooo
002Hooooo`005?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00ooo
ool3o`0004?ooooo0_l00?mmooooo`_oo`00W_ooool2o`0003oooooo4Ooo000^ooooo`03o`000?oo
oooooooo01oooooo2?oo002Jooooo`005?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo04Gooooo0_l00?mhooooo`_oo`00
XOooool00ol0003oooooooooo`11oooooa3oo`00;?ooool00ol0003oooooooooo`0Mooooo`Soo`00
W?ooool001Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Aoooool2o`00ogCooooo2_oo002Tooooo`03o`000?oooooooooo04Gooooo
3_oo000Zooooo`03o`000?oooooooooo01cooooo2?oo002Mooooo`005?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`19ooooo`03o`00
oooooooooooo06kooooo2_oo002Wooooo`03o`000?oooooooooo04Wooooo2ooo000Yooooo`03o`00
0?l00?oooooo01_ooooo2?oo002Nooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`;o0000Boooool2o`00ofcooooo2Ooo002Zooooo`03o`000?oooooooooo04cooooo
2_oo000Wooooo`03o`000?l00?oooooo01[ooooo2?oo002Oooooo`00;_ooool00ol0003ooooooooo
o`1<ooooo`03o`00oooooooooooo06Kooooo2_oo002Qooooo`Go00001_ooool00ol0003ooooooooo
o`1>ooooo`[oo`009Oooool00ol0003o003oooooo`0Iooooo`Ooo`00XOooool002kooooo00?o0000
ooooooooool0COooool00ol00?ooooooooooo`1Sooooo`Woo`00Y?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0D?ooool:ool002?ooooo00?o0000ooooool00?l06?oo
ool7ool00:;ooooo000^ooooo`03o`000?oooooooooo04kooooo0_l00?lJooooo`03o`000?oooooo
oooo04?ooooo2_oo002Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0DOooool:
ool002Gooooo00?o003oooooooooool05Oooool6ool00:?ooooo000^ooooo`03o`000?oooooooooo
053ooooo00?o003oooooooooool05oooool00ol0003oooooooooo`11ooooo`Woo`00Zoooool00onH
V9So8B4Qonk^kP06ooooo`?o0000Doooool9ool002Cooooo00?o003oooooooooool05?ooool6ool0
0:Cooooo000^ooooo`;o0000D_ooool2o`00oaOooooo00?o0000ooooooooool0?oooool9ool00:ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Eooooo`Soo`009?ooool00ol00?oo
ooooooooo`0Booooo`Koo`00YOooool002kooooo00?o0000ooooooooool0Doooool00ol00?oooooo
ooooo`0Dooooo`03o`000?oooooooooo03cooooo2Ooo002booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Eoooool7ool002?ooooo00?o003oooooooooool04Oooool7ool00:Gooooo
000^ooooo`03o`000?oooooooooo05Cooooo00?o003oooooooooool04oooool00ol0003ooooooooo
o`0jooooo`Woo`00/?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
F?ooool7ool002?ooooo00?o003oooooooooool04?ooool6ool00:Kooooo000^ooooo`03o`000?oo
oooooooo05Gooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0hooooo`Woo`00/_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0FOooool7ool002?ooooo
00?o003oooooooooool03_ooool6ool00:Oooooo000^ooooo`03o`000?oooooooooo05Kooooo0_l0
0?lBooooo`03o`000?oooooooooo03Kooooo2?oo0030ooooo`03o`000?oooooooooo05[ooooo1ooo
000Rooooo`03o`00oooooooooooo00kooooo1Ooo002Xooooo`00;_ooool2o`0005Wooooo00?o003o
ooooooooool03oooool00ol0003oooooooooo`0eooooo`Ooo`00`_ooool00ol0003oooooooooo`1K
ooooo`Ooo`006oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00cooooo1_oo002X
ooooo`00;_ooool00ol0003oooooooooo`1Iooooo`03o`00oooooooooooo00kooooo00?o0000oooo
ooooool0<oooool7ool00<Cooooo00?o0000ooooooooool0G?ooool7ool001[ooooo00?o0000oooo
ooooool01Oooool00ol00?ooooooooooo`0;ooooo`Goo`00ZOooool002kooooo00?o0000oooooooo
ool0F_ooool00ol00?ooooooooooo`11ooooo`Ooo`00a_ooool2o`0005kooooo1ooo000Iooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool02Oooool6ool00:Wooooo000^ooooo`03o`00
0?oooooooooo05_ooooo0_l00?m0ooooo`Ooo`00aoooool00ol0003oooooooooo`1Nooooo`Ooo`00
6?ooool00ol0003oooooooooo`07ooooo`;o003o2Oooool5ool00:[ooooo000^ooooo`;o0000G_oo
ool00ol00?ooooooooooo`0kooooo`Ooo`00bOooool00ol0003oooooooooo`1Oooooo`Koo`006?oo
ool00ol0003oooooooooo`09ooooo`;o003o1_ooool6ool00:[ooooo000^ooooo`03o`000?oooooo
oooo05kooooo00?o003oooooooooool0>Oooool6ool00<_ooooo00?o0000ooooooooool0H?ooool6
ool001Oooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`03ooooo`Goo`00Zoooool0
02Gooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo05oooooo00?o003ooooo
ooooool0=_ooool7ool00<cooooo00?o0000ooooooooool0HOooool6ool001Kooooo00?o0000oooo
ooooool03?ooool2o`00o`;ooooo1_oo002[ooooo`009oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo063ooooo00?o003oooooooooool0=?ooool6ool00<kooooo00?o0000oooooooo
ool0HOooool6ool001Kooooo00?o0000ooooooooool03_ooool6o`00o`03ool00?oooooooooo0:[o
oooo000Wooooo`03o`000?oooooooooo00?ooooo5_oo001?ooooo`03o`00oooooooooooo00Kooooo
00?o0000ooooooooool0:?ooool7ool00<oooooo00?o0000ooooooooool0H_ooool6ool001Gooooo
00?o0000ooooooooool03oooool5ool000Co003oZOooool002Oooooo00?o0000ooooooooool00ooo
oolQool004Gooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Wooooo`Koo`00dOoo
ool00ol0003oooooooooo`1Sooooo`Goo`009oooool5ool000Cooooo2ol00?nNooooo`009oooool0
0ol0003oooooooooo`03ooooobKoo`00@Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo
oooo02Kooooo1_oo003Booooo`;o0000I?ooool6ool002Gooooo1_oo000?oooooa3o003oS_ooool0
02Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@oooooaOoo`00?Oooool00ol0
0?ooooooooooo`03ooooo`03o`000?oooooooooo02Cooooo1_oo003Dooooo`03o`000?oooooooooo
06Cooooo1_oo000Tooooo`Goo`008?oooolno`00oe3ooooo000Wooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06ooooolAool003Wooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`0Sooooo`Koo`00eOooool00ol0003oooooooooo`1Tooooo`Koo`009?ooool5ool005ko
oooo3_l00?m2ooooo`009Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo023ooooo
3ooo000gooooo`05o`00ooooooooooooooooool000008oooool7ool00=Kooooo00?o0000oooooooo
ool0IOooool6ool002;ooooo1Ooo002_ooooo`00;_ooool2o`0002Kooooo3Ooo000dooooo`05o`00
ooooooooooooooooool000008_ooool6ool00=Sooooo00?o0000ooooooooool0I_ooool5ool002;o
oooo1Ooo002_ooooo`00;_ooool00ol0003oooooooooo`0Zooooo`coo`00<Oooool01?l00?oooooo
ooooool0000Qooooo`Koo`00fOooool00ol0003oooooooooo`1Vooooo`Koo`008?ooool6ool00:oo
oooo000^ooooo`03o`000?oooooooooo02gooooo3Ooo000^ooooo`03o`00oooooooo0000023ooooo
1Ooo003Kooooo`03o`000?oooooooooo06Oooooo1Ooo000Aooooo`03o`000?oooooooooo00cooooo
1Ooo002`ooooo`00;_ooool00ol0003oooooooooo`0`ooooo`goo`00;?ooool00ol00?oooooooooo
o`0Mooooo`Koo`00g?ooool00ol0003oooooooooo`1Wooooo`Koo`004?ooool00ol0003ooooooooo
o`0<ooooo`Goo`00/?ooool002kooooo0_l0000eooooo`coo`00:_ooool00ol00?ooooooooooo`0K
ooooo`Koo`00gOooool2o`0006Wooooo1Ooo000@ooooo`03o`000?oooooooooo00_ooooo1Ooo002a
ooooo`00;_ooool00ol0003oooooooooo`0hooooo`_oo`00:?ooool00ol00?ooooooooooo`0Ioooo
o`Koo`00g_ooool00ol0003oooooooooo`1Xooooo`Koo`003oooool00ol0003oooooooooo`0;oooo
o`Goo`00/Oooool002kooooo00?o0000ooooooooool0>oooool:ool002Oooooo00?o003ooooooooo
ool05oooool5ool00>3ooooo00?o0000ooooooooool0JOooool5ool000oooooo00?o0000oooooooo
ool02oooool5ool00;7ooooo000^ooooo`03o`000?oooooooooo03kooooo2_oo000Uooooo`03o`00
oooooooooooo01Cooooo1_oo003Qooooo`03o`000?oooooooooo06Wooooo1Ooo000?ooooo`03o`00
0?oooooooooo00[ooooo1Ooo002booooo`00;_ooool00ol0003oooooooooo`11ooooo`Woo`009?oo
ool00ol00?ooooooooooo`0Booooo`Koo`00h_ooool00ol0003oooooooooo`1Zooooo`Goo`003_oo
ool00ol0003oooooooooo`0:ooooo`Goo`00/_ooool002kooooo0_l00014ooooo`[oo`008_ooool0
0ol00?ooooooooooo`0?ooooo`Ooo`00f_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0J_ooool5ool000kooooo00?o0000ooooooooool02_ooool5ool00;;ooooo000^oooo
o`03o`000?oooooooooo04Kooooo2_oo000Jooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool03?ooool7ool00=gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zoooo
o`Goo`003_ooool00ol0003oooooooooo`0:ooooo`Coo`00/oooool002kooooo00?o0000oooooooo
ool0B?ooool;ool001Oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0;ooooo`Oo
o`00foooool5o`0000Kooooo00?o0000ooooooooool0Joooool5ool001Wooooo1Ooo002cooooo`00
;_ooool00ol0003oooooooooo`1;ooooo`[oo`005Oooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo00Sooooo1ooo003Mooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001[ooooo`Go
o`006Oooool5ool00;?ooooo000^ooooo`;o0000Coooool:ool001;ooooo00?o0000ooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`Koo`00goooool01?oMgMgoEEEEooooool00007ooooo`03
o`000?oooooooooo06_ooooo1Ooo000Iooooo`Goo`00/oooool002kooooo00?o0000ooooooooool0
DOooool9ool0013ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`Ooo`00
hOooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo06cooooo1?oo000Iooooo`Coo`00
]?ooool002kooooo00?o0000ooooooooool0Doooool:ool000gooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooool00007ool00>?ooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`1/ooooo`Goo`006?ooool4ool00;Cooooo000Eooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo05Kooooo2_oo
000:ooooo`03o`000?oooooooooo00Oooooo00?oo`00o`00oooo00001_oo003Uooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0K?ooool5ool001Sooooo1?oo002dooooo`005oooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo05Sooooo3?oo0006ooooo`03o`000?oooooooooo00Cooooo1Ooo00000ol00?ooo`00ool00002
ool00?3ooooo00?o0000ooooooooool0K?ooool5ool001Oooooo1Ooo002dooooo`005oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo0ol0001Kooooo`ooo`0000?o0000ool0
0?oo00002_oo00000ol00?ooooooooooo`3aooooo`03o`000?oooooooooo06gooooo1Ooo000;oooo
o`03o`000?oooooooooo00Sooooo1Ooo002dooooo`005oooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0G_oooolHool000;ooooo00?o003ooooooooo
ool0l?ooool00ol0003oooooooooo`1]ooooo`Goo`002oooool00ol0003oooooooooo`08ooooo`Go
o`00]?ooool001Oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool0H_oooolAool000Kooooo00?o003oooooooooool0koooool2o`0006ko
oooo1Ooo000;ooooo`03o`000?oooooooooo00Sooooo1?oo002eooooo`005oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol00?oooooo
ooooo`3^ooooo`03o`000?oooooooooo06kooooo1?oo000;ooooo`03o`000?oooooooooo00Sooooo
1?oo002eooooo`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Noooool00ol00?ooooooooooo`3]ooooo`03o`000?oooooooooo06kooooo1Ooo
000:ooooo`03o`000?oooooooooo00Sooooo1?oo002eooooo`005Oooool00omEEEGoIVIVo`00000=
ooooo`Co00001Oooool2o`0007gooooo00?o003oooooooooool0k?ooool00ol0003oooooooooo`1^
ooooo`Goo`002_ooool00ol0003oooooooooo`07ooooo`Goo`00]Oooool002kooooo00?o0000oooo
ooooool0OOooool00ol00?ooooooooooo`3[ooooo`03o`000?oooooooooo06kooooo1Ooo000:oooo
o`03o`000?oooooooooo00Oooooo1Ooo002eooooo`00;_ooool00ol0003oooooooooo`1nooooo`03
o`00oooooooooooo0>[ooooo00?o0000ooooooooool0Koooool4ool000[ooooo00?o0000oooooooo
ool01oooool5ool00;Gooooo000^ooooo`03o`000?oooooooooo07oooooo00?o003oooooooooool0
jOooool00ol0003oooooooooo`1_ooooo`Goo`002Oooool00ol0003oooooooooo`07ooooo`Coo`00
]_ooool002kooooo0_l00021ooooo`03o`00oooooooooooo0>Sooooo00?o0000ooooooooool0Kooo
ool5ool001?ooooo1?oo002fooooo`00;_ooool00ol0003oooooooooo`21ooooo`03o`00oooooooo
oooo0>Oooooo0_l0001`ooooo`Goo`004_ooool5ool00;Kooooo000^ooooo`03o`000?oooooooooo
08;ooooo00?o003oooooooooool0i_ooool00ol0003oooooooooo`1`ooooo`Coo`004_ooool5ool0
0;Kooooo000^ooooo`03o`000?oooooooooo08?ooooo00?o003oooooooooool0iOooool00ol0003o
ooooooooo`1`ooooo`Coo`004_ooool5ool00;Kooooo000^ooooo`03o`000?oooooooooo08Cooooo
00?o003oooooooooool0i?ooool00ol0003oooooooooo`1`ooooo`Goo`004Oooool4ool00;Oooooo
000^ooooo`;o0000Q_ooool2o`00onCooooo00?o0000ooooooooool0L?ooool5ool0017ooooo1?oo
002gooooo`00;_ooool00ol0003oooooooooo`27ooooo`03o`00oooooooooooo0>7ooooo00?o0000
ooooooooool0L?ooool5ool0017ooooo1?oo002gooooo`00;_ooool00ol0003oooooooooo`28oooo
o`03o`00oooooooooooo0>3ooooo00?o0000ooooooooool0LOooool4ool000Sooooo00?o0000oooo
ooooool01Oooool5ool00;Oooooo000^ooooo`03o`000?oooooooooo08Wooooo00?o003ooooooooo
ool0goooool00ol0003oooooooooo`1aooooo`Coo`002?ooool00ol0003oooooooooo`05ooooo`Go
o`00]oooool002kooooo00?o0000ooooooooool0R_ooool00ol00?ooooooooooo`3Nooooo`;o0000
L_ooool5ool000Oooooo00?o0000ooooooooool01Oooool5ool00;Oooooo000^ooooo`;o0000S?oo
ool00ol00?ooooooooooo`3Mooooo`03o`000?oooooooooo077ooooo1Ooo0007ooooo`03o`000?oo
oooooooo00Gooooo1?oo002hooooo`00;_ooool00ol0003oooooooooo`2<ooooo`03o`00oooooooo
oooo0=cooooo00?o0000ooooooooool0LOooool5ool000Oooooo00?o0000ooooooooool01Oooool4
ool00;Sooooo000Tooooo`Go00001Oooool00ol0003oooooooooo`2=ooooo`03o`00oooooooooooo
0=_ooooo00?o0000ooooooooool0L_ooool4ool000Oooooo00?o0000ooooooooool01Oooool4ool0
0;Sooooo000Tooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`2>oooo
o`03o`00oooooooooooo0=[ooooo00?o0000ooooooooool0L_ooool4ool000Oooooo00?o0000oooo
ooooool01?ooool5ool00;Sooooo000Uooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002?ooooo`;o
003ocoooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0L_ooool4ool0
00Oooooo00?o0000ooooooooool01?ooool5ool00;Sooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?o0000ooooooooool0TOooool00ol00?ooooooooooo`3<ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1booooo`Goo`001_ooool00ol0003oooooooooo`04oooo
o`Goo`00^?ooool002Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`2Booooo`;o
003oc?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0L_ooool5ool0
00gooooo1?oo002iooooo`00:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09Co
oooo0_l00?o:ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0007;ooooo1Ooo000=oooo
o`Coo`00^Oooool002Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo
09Kooooo00?o003oooooooooool0aoooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0Loooool4ool000gooooo1?oo002iooooo`009?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Gooooo0_l0002Hooooo`;o003oaoooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo07?ooooo1?oo000=ooooo`Coo`00^Oooool002kooooo00?o0000ooooooooool0VOooool00ol0
0?ooooooooooo`34ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0Loooool4ool0
00cooooo1Ooo002iooooo`00;_ooool00ol0003oooooooooo`2Jooooo`;o003oaOooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo07?ooooo1?oo000<ooooo`Goo`00^Oooool002ko
oooo00?o0000ooooooooool0W?ooool2o`00olgooooo00?o0000ooooooooool0Loooool4ool000co
oooo1Ooo002iooooo`00;_ooool00ol0003oooooooooo`2Nooooo`03o`00oooooooooooo0<[ooooo
00?o0000ooooooooool0Loooool4ool000Kooooo00?o0000ooooooooool00oooool4ool00;[ooooo
000^ooooo`;o0000X?ooool2o`00ol[ooooo0_l0001dooooo`Goo`001Oooool00ol0003ooooooooo
o`03ooooo`Coo`00^_ooool002kooooo00?o0000ooooooooool0XOooool2o`00olSooooo00?o0000
ooooooooool0Loooool5ool000Gooooo00?o0000ooooooooool00oooool4ool00;[ooooo000^oooo
o`03o`000?oooooooooo0:?ooooo00?o003oooooooooool0aOooool00ol0003oooooooooo`1coooo
o`Goo`001Oooool00ol0003oooooooooo`03ooooo`Coo`00^_ooool002kooooo00?o0000oooooooo
ool0Y?ooool2o`00olGooooo00?o0000ooooooooool0M?ooool4ool000Gooooo00?o0000oooooooo
ool00_ooool5ool00;[ooooo000^ooooo`;o0000Yoooool3o`00ol;ooooo00?o0000ooooooooool0
M?ooool4ool000Gooooo00?o0000ooooooooool00_ooool5ool00;[ooooo000^ooooo`03o`000?oo
oooooooo0:Wooooo0_l00?o0ooooo`03o`000?oooooooooo07Cooooo1?oo0005ooooo`03o`000?oo
oooooooo00;ooooo1Ooo002jooooo`00;_ooool00ol0003oooooooooo`2[ooooo`?o003o_Oooool0
0ol0003oooooooooo`1dooooo`Coo`001Oooool00ol0003oooooooooo`02ooooo`Coo`00^oooool0
02kooooo00?o0000ooooooooool0[_ooool2o`00ok_ooooo00?o0000ooooooooool0M?ooool4ool0
00Gooooo00?o0000ooooooooool00_ooool4ool00;_ooooo000^ooooo`03o`000?oooooooooo0;3o
oooo0ol00?nhooooo`;o0000MOooool5ool000Cooooo00?o0000ooooooooool00_ooool4ool00;_o
oooo000^ooooo`;o0000]?ooool3o`00okGooooo00?o0000ooooooooool0M?ooool5ool000Wooooo
1?oo002kooooo`00;_ooool00ol0003oooooooooo`2fooooo`?o003o/_ooool00ol0003ooooooooo
o`1dooooo`Goo`002Oooool4ool00;_ooooo000Dooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;Wooooo0ol00?n_ooooo`03o`000?oo
oooooooo07Gooooo1?oo0009ooooo`Coo`00^oooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo0ol0
0?n/ooooo`03o`000?oooooooooo07Gooooo1?oo0009ooooo`Coo`00^oooool001Gooooo00?oV9RH
ob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000_oooool3o`00ojWooooo00?o0000
ooooooooool0MOooool4ool000Sooooo1Ooo002kooooo`005_ooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0`_ooool5o`00ojCooooo00?o0000oooo
ooooool0MOooool4ool000Sooooo1Ooo002kooooo`005oooool00omgMgOoIVIVooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`37ooooo`Go003oWoooool00ol0
003oooooooooo`1eooooo`Coo`002?ooool5ool00;_ooooo000Hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3<ooooo`Ko003oVOooool2o`0007Ko
oooo1Ooo0003ooooo`04o`000?ooooooooooooooo`Coo`00_?ooool001Cooooo00Go0000okZj^_oo
ooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0d_ooool5o`00
oiCooooo00?o0000ooooooooool0MOooool5ool000?ooooo00Co0000oooooooooooooooo1?oo002l
ooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`;o0000f?ooool6
o`00ohkooooo00?o0000ooooooooool0MOooool5ool000?ooooo00Co0000oooooooooooooooo1?oo
002looooo`00;_ooool00ol0003oooooooooo`3Mooooo`Go003oROooool00ol0003oooooooooo`1f
ooooo`Coo`000oooool01?l0003oooooooooooooool4ool00;cooooo000^ooooo`03o`000?oooooo
oooo0>;ooooo1Ol00?n4ooooo`03o`000?oooooooooo07Kooooo1?oo0003ooooo`04o`000?oooooo
ooooooooo`Coo`00_?ooool002kooooo00?o0000ooooooooool0ioooool5o`00ogoooooo00?o0000
ooooooooool0M_ooool4ool000?ooooo00Co0000oooooooooooooooo1?oo002looooo`00;_ooool0
0ol0003oooooooooo`3/ooooo`So003oK?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0M_ooool4ool000?ooooo00Co0000oooooooooooooooo1?oo002looooo`00;_oo
ool2o`000?Gooooo1?l00?mXooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`1fooooo`Coo`000oooool01?l0003oooooooooooooool4ool00;cooooo000^ooooo`03o`00
0?oooooooooo0?ooooooHOooool01Ol0003ooooooooooooooooo000000Kooooo0ol0001fooooo`Co
o`000oooool00ol0003oooooooooo`05ool00;cooooo000^ooooo`03o`000?oooooooooo0?oooooo
HOooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0M_ooool5ool000Go
oooo1Ooo002looooo`00;_ooool00ol0003oooooooooo`3oooooof7ooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03o`000?oooooooooo07Kooooo1Ooo0005ooooo`Goo`00_?ooool002kooooo
0_l0003oooooof;ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07Ko
oooo1Ooo0005ooooo`Coo`00_Oooool002kooooo00?o0000ooooooooool0oooooomQooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1gooooo`Coo`001Oooool4ool00;go
oooo000^ooooo`03o`000?oooooooooo0?ooooooHOooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0Moooool4ool000Gooooo1?oo002mooooo`00;_ooool00ol0003ooooo
ooooo`3oooooofcooooo00?o0000ooooooooool0Moooool4ool000Gooooo1?oo002mooooo`00;_oo
ool00ol0003oooooooooo`3oooooofcooooo00?o0000ooooooooool0Moooool4ool000Gooooo1?oo
002mooooo`00;_ooool2o`000?ooooooKOooool2o`0007Sooooo1?oo0002ooooo`03o`000?oooooo
oooo00Coo`00_Oooool002kooooo00?o0000ooooooooool0oooooom/ooooo`03o`000?oooooooooo
07Oooooo1?oo0002ooooo`03o`000?ooooooo`0000Coo`00_Oooool002Cooooo00GoV9RHoa0@4?l0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?ooooooK?ooool00ol0003oooooooooo`1goooo
o`Coo`000_ooool00ol0003oooooool00004ool00;gooooo000Tooooo`05oa0@4?nj^[[oooooogMg
Molb<S801Oooool00ol0003oooooooooo`3oooooofcooooo00?o0000ooooooooool0Moooool5ool0
0003ooooool0003ooooo00Goo`00_Oooool002Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3oooooofcooooo00?o0000ooooooooool0Moooool5ool00003ooooool0003ooooo00Co
o`00__ooool002Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooK?ooool00ol0003ooooo
ooooo`1gooooo`Goo`0000?oooooo`000?ooool01?oo002nooooo`009_ooool00ol@413o0000okZj
^P05ooooo`03o`000?oooooooooo0?ooooooK?ooool00ol0003oooooooooo`1hooooo`Coo`0000?o
ooooo`000?ooool01?oo002nooooo`009oooool00onj^[[o8B4Qooooo`04ooooo`03o`000?oooooo
oooo0?ooooooK?ooool00ol0003oooooooooo`1hooooo`Coo`0000?oooooo`000?oo00001?oo002n
ooooo`009?ooool01Ol@413oV9RHoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooom/
ooooo`;o0000NOooool4ool00003ooooool0003oo`0000Coo`00__ooool002Cooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@05ooooo`;o0000oooooom]ooooo`03o`000?oooooooooo07Sooooo1?oo0002
ooooo`Goo`00__ooool002kooooo00?o0000ooooooooool0oooooom/ooooo`03o`000?oooooooooo
07Sooooo1?oo0002ooooo`Coo`00_oooool002kooooo00?o0000ooooooooool0oooooom/ooooo`03
o`000?oooooooooo07Sooooo1?oo0002ooooo`Coo`00_oooool002kooooo00?o0000ooooooooool0
oooooom/ooooo`03o`000?oooooooooo07Sooooo1?oo0002ooooo`Coo`00_oooool002kooooo00?o
0000ooooooooool0oooooom/ooooo`03o`000?oooooooooo07Sooooo2_oo002oooooo`00;_ooool2
o`000?ooooooKOooool00ol0003oooooooooo`1hooooo`[oo`00_oooool002kooooo00?o0000oooo
ooooool0oooooom/ooooo`03o`000?oooooooooo07Sooooo2_oo002oooooo`00;_ooool00ol0003o
ooooooooo`3oooooofcooooo0_l0001jooooo`Coo`0000Co0000ool00?oo003oo`00`?ooool002ko
oooo00?o0000ooooooooool0oooooom/ooooo`03o`000?oooooooooo07Wooooo1?oo00001?l0003o
o`00ool00?oo0030ooooo`00;_ooool00ol0003oooooooooo`3oooooofcooooo00?o0000oooooooo
ool0NOooool4ool00004o`000?oo003oo`00ool00<3ooooo000^ooooo`;o0000oooooom]ooooo`03
o`000?oooooooooo07Wooooo1?oo00001?l0003oo`00ool00?oo0030ooooo`00;_ooool00ol0003o
ooooooooo`3oooooofcooooo00?o0000ooooooooool0N_ooool3ool00004o`000?oo003oo`00ool0
0<3ooooo000^ooooo`03o`000?oooooooooo0?ooooooK?ooool00ol0003oooooooooo`1jooooo`?o
o`0000Co0000ool00?oo003oo`00`?ooool002kooooo00?o0000ooooooooool0oooooomJooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0N_oo
ool3ool00004o`000?oo003oo`00ool00<3ooooo000^ooooo`;o0000oooooomMooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo07[ooooo
0ooo00001?l0003oo`00ool00?oo0030ooooo`00;_ooool00ol0003oooooooooo`3ooooooecooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0001jooooo`?o
o`0000?o0000ool00?oo0000`Oooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooomLoooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo07_ooooo1Ooo0031ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooomLooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07_ooooo1Ooo
0031ooooo`006?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oooooomLooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Oooooo00?oZJVYoa0@4?ooool03_ooool0
0omgMgOo<S8booooo`03ooooo`?o0000oooooomLooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo@_ooool001Kooooo00?o410@
o`000?nj^[X03?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooHOooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom;ooooo`005oooool00onj^[[o8B4Qoooo
o`0;ooooo`03o`000?oooooooooo0?oooooooooooonjooooo`005?ooool01Ol@413oV9RHoooooonj
^[[o000000cooooo00?o0000ooooooooool0oooooooooooook[ooooo000Dooooo`05ojVYZOl@413o
0000oa0@4?nYZJT03?ooool4o`000?ooooooooooooniooooo`00ooooooooooooon;ooooo0028oooo
o`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool03_ooool00olQ8B7o0000ojVYZ@0Aoooo
o`;o0000oooooollooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool03_ooool00olQ
8B7o0000ojVYZ@0Aooooo`;o0000^Oooool008Oooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko
410@omgMg@0>ooooo`03o`000?nj^[[o410@00?ooooo00?o8B4QomgMgOooool02_ooool01?l0003o
ooooooooool0003ooooooc[ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgMg@0>oooo
o`03o`000?nj^[[o410@00?ooooo00?o8B4QomgMgOooool02_ooool01?l0003oooooooooool0002h
ooooo`00Qoooool01OmEEEGoV9RHooooooooooooV9RH00;o000000?oMgMgoa0@4?l000000oooool0
0on7QhOoIVIVooooo`0=ooooo`03oeEEEOnYZJWo000000?ooooo00?oV9RHoeEEEOooool00oooool0
2?n7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^ko00000_ooool00ol0003oooooooooo`09ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0oooooolJoooo
o`07oeEEEOnHV9Soooooooooool@413o0000ohN7Q`02o`000006ofIVI_o^k^kooooooooooon7QhOo
IVIV3_ooool00omEEEGoZJVYo`000003ooooo`03oiRHV?mEEEGooooo00?ooooo00SoQhN7o`000?mE
EEGoIVIVo`000?lb<S;ok^k^o`0000;ooooo00?o0000ooooooooool02Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool0UOooool002gooooo0_l0
001Hooooo`09o`000?ooooooooooooooool0003oc<c<onk^k_n7QhOo000000Cooooo00?ok^k^o`00
0?ooool03Oooool00oo^k^koA4A4ob4Q8@04ooooo`03o`000?oMgMgooooo00;ooooo00So410@omgM
gOmgMgOo8B4Qoooooon7QhOoIVIVooooo`;o00001Oooool6o`000006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0_oooool2o`0005Sooooo00?o0000oooo
ooooool00_ooool01_l0003oEEEEonk^k_ooooooMgMgofIVIP;ooooo00?ok^k^o`000?ooool03Ooo
ool00oo^k^koA4A4ob4Q8@04ooooo`03o`000?oMgMgooooo00;ooooo00So410@omgMgOmgMgOo8B4Q
oooooon7QhOoIVIVooooo`;o00001Oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool0Uoooool002cooooo00Co0000oooooooooooo00004_oo
ool2o`0004?ooooo00Wo<S8boooooooooooooooooa0@4?n7QhOoooooonk^k_l000001Oooool00ol0
003oooooooooo`0=ooooo`03ofIVI_lQ8B7ok^k^00?ooooo0_mgMgL3ooooo`07o`000?oooooogMgM
oc8b<_ooooook^k^oa0@400?ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`2nooooo`04o`000?ooooooooooo`0001?ooooo0_l00012ooooo`03oc8b<_oooooooooo00;o
oooo00?o0000onk^k_ooool00_ooool01Ol0003ooooooooooooooooo000000oooooo00?oIVIVob4Q
8Oo^k^h00oooool2ogMgM`?ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00oooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo09Oooooo000/ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o8B4QomgMgOooool02_ooool01?l0003oooooooooool00012ooooo`06
oc8b<_oooooooooooooooonj^[[o410@0ol00005ooooo`03o`000?oooooooooo00cooooo00Gok^k^
oa0@4?oMgMgoEEEEonk^kP02ooooo`03onk^k_l@413ok^k^00;ooooo00CoEEEEojVYZOoooooo0000
0_ooool00ol0003oooooooooo`06ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03ob4Q8Ooooooooooo0;gooooo00Co0000oooooooooooo00001Oooool00olQ8B7o
gMgMooooo`0:ooooo`04o`000?ooooooooooo`00047ooooo00?o<S8booooooooool00_ooool00ol0
003ok^k^ooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool01Oo^k^ko410@omgMgOmE
EEGok^k^00;ooooo00?ok^k^oa0@4?o^k^h00_ooool01?mEEEGoZJVYooooool00002ooooo`03o`00
0?oooooooooo00Kooooo1_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0Uoooool001Kooooo00GoV9RHoa0@4?l0003o<S8bolc<c009ooooo`07ohN7
Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`;o00001Oooool00onHV9SoEEEEooooo`04oooo
o`03oa0@4?l0003o000000;o000000Go410@o`000?ooooooooooo`000012ooooo`03o`000?o^k^ko
oooo00Cooooo00?oc<c<o`000?ooool00oooool00oo^k^ko0000ooooo`0<ooooo`07omgMgOlb<S;o
c<c<ooooooo<c<co<S8bonk^kP02ooooo`07oeEEEOnHV9SooooooooooooMgMgo8B4Qonk^kP03oooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo0:Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c009ooooo`08ohN7Qol0003oEEEEofIVI_l0003o
<S8bonk^k_ooool2o`0000Kooooo00?oV9RHoeEEEOooool00oooool00ol@413o0000o`000002o`00
0003oa0@4?oooooo000000;ooooo00?o0000ooooooooool0?oooool00ol0003ok^k^ooooo`02oooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEE0_ooool00oo^k^ko0000ooooo`0<ooooo`07omgMgOlb
<S;oc<c<ooooooo<c<co<S8bonk^kP02ooooo`07oeEEEOnHV9SooooooooooooMgMgo8B4Qonk^kP03
ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo09Oooooo000Eooooo`06ojVYZOlQ8B7ogMgMoooooonHV9So8B4Q2Oooool01ol@413ogMgM
ogMgMolQ8B7oooooohN7QomVIVH02_ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_l00013ooooo`03oeEEEOmgMgOooooo00;ooooo00Co<S8bo`000?l0003oV9RH1?ooool0
0omgMgOoEEEEooooo`0;ooooo`03ofIVI_mEEEGogMgM00?ooooo00Kok^k^ofIVI_ooooooooooomgM
gOl@4103ooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool0Yoooool01_nYZJWo8B4QomgMgOooooooV9RH
ob4Q8@Wooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00[ooooo00?o0000omgMgOooool0
1?ooool00ol0003oooooooooo`03ooooo`;o0000@_ooool00omEEEGoMgMgooooo`02ooooo`06o`00
0?o<c<co410@o`000?mEEEGok^k^0_ooool00omgMgOoEEEEooooo`0;ooooo`03ofIVI_mEEEGogMgM
00?ooooo00Kok^k^ofIVI_ooooooooooomgMgOl@4103ooooo`03oiRHV?mgMgOooooo00;ooooo00?o
0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
Uoooool001Gooooo00?o8B4QojVYZOooool03?ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@
41002_ooool2ogMgM`Kooooo00?o0000ooooooooool0Aoooool00ooMgMgo410@onk^kP09ooooo`03
onk^k_l@413ogMgM01Oooooo00?oEEEEoiRHV?ooool05_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oooooooooooooooooc8b<P2Xooooo`03ob4Q8OnYZJWooooo00cooooo00Oo0000
oooooooMgMgo<S8booooooo^k^ko410@00[ooooo0_mgMgL5ooooo`03o`000?oooooooooo04Oooooo
00?ogMgMoa0@4?o^k^h00_ooool00ol0003oooooooooo`04ooooo`03onk^k_l@413ogMgM01Oooooo
00?oEEEEoiRHV?ooool05_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000oooooooo
ool0Uoooool001Gooooo00?o0000ooooooooool03?ooool01?mEEEGoZJVYooooool00002ooooo`03
o`000?oooooooooo00Sooooo00?ok^k^oa0@4?o^k^h01Oooool00ol0003oooooooooo`18ooooo`03
ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool05oooool00onj^[[oA4A4ooooo`0Fooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`000:Sooooo00?o0000ooooooooool03?ooool01?mE
EEGoZJVYooooool00002ooooo`03o`000?oooooooooo00Sooooo00?ok^k^oa0@4?o^k^h01?ooool0
0ol0003oooooooooo`18ooooo`05ogMgMomVIVKoooooooooool000001_ooool00omVIVKoMgMgoooo
o`0Gooooo`03okZj^_m4A4Cooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEE
EOmVIVKo000009Wooooo000Eooooo`03o`000?oooooooooo00cooooo00?ogMgMob4Q8Oo^k^h00ooo
ool00ol0003oooooooooo`09ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000ooooooooool0oooo
oom4ooooo`03o`000?oooooooooo00cooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003ooooooooo
o`09ooooo`03oeEEEOnHV9Sooooo00?ooooo00?o0000ooooooooool0Boooool00ol@413o0000oooo
o`3Uooooo`005Oooool00olQ8B7oZJVYooooo`02ooooo`03o`000?oooooooooo00Sooooo00?oV9RH
ogMgMoooool00_ooool00ol0003oooooo`000003o`0000Kooooo00?ogMgMoa0@4?ooool00_ooool0
0ol@413o0000o`000003o`000?oooooo@oooool00olQ8B7oZJVYooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?oV9RHogMgMoooool00_ooool5o`0000Oooooo00GogMgMoa0@4?oooooooooooa0@
4005o`000?oooooo<oooool001Gooooo00KoZJVYob4Q8OoMgMgoooooogMgMol0000Booooo`03o`00
0?oooooooooo00Oooooo00?oEEEEoiRHV?ooool00oooool00ol0003oooooooooo`3oooooodCooooo
00KoZJVYob4Q8OoMgMgoooooogMgMol0000Aooooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRH
V?ooool00_ooool00ol0003oooooooooo`3oooooocCooooo000Fooooo`05oiRHV?l@413o0000ob4Q
8Ol000004oooool00ol0003oooooooooo`06ooooo`03okZj^_m4A4Cooooo00?ooooo00?o410@okZj
^_ooool0oooooom5ooooo`05oiRHV?l@413o0000ob4Q8Ol000004_ooool00ol0003oooooooooo`07
ooooo`03okZj^_m4A4Cooooo00;ooooo00?o410@okZj^_ooool0ooooooldooooo`00;oooool00ol0
003oooooooooo`0;ooooo`04okZj^_l@413o0000oa0@4?ooooooG?ooool00ol0003oooooooooo`0;
ooooo`04okZj^_l@413o0000oa0@4?oooooo<oooool002cooooo00Co0000oooooooooooo0000oooo
oomZooooo`04o`000?ooooooooooo`000?ooooooA?ooool002gooooo0_l0003oooooofcooooo0_l0
003oooooodGooooo003oooooooooooooh_ooool00?oooooooooooooRooooo`00ooooooooooooon;o
oooo003oooooooooooooh_ooool00?oooooooooooooRooooo`00ooooooooooooon;ooooo003ooooo
ooooooooh_ooool00?oooooooooooooRooooo`00\
\>"],
  ImageRangeCache->{{{0, 735.875}, {215.562, 0}} -> {-0.0549084, -0.0147182, \
0.00358386, 0.00358386}, {{19.125, 351.312}, {210.375, 5.125}} -> {-0.375513, \
-0.488314, 0.0100001, 0.0269675}, {{384.5, 716.688}, {210.375, 5.125}} -> \
{-3.20702, -1.40064, 0.00972265, 0.0786578}}],

Cell[TextData[{
  "Fig. 1.19 : Magnitude (thick line) and phase (thin line) of the amplitude \
of the particular solution to the driven damped oscillator:\n(a) heavy \
damping, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]/\[Omega]\_o = 0.7\)]],
  "; (b) light damping, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]/\[Omega]\_o = 0.1\)]],
  ". Also shown is the location of the peak amplitude, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \@\(\[Omega]\_o\%2 - \[Gamma]\^2/2\)\)]],
  " (dashed line)."
}], "Caption",
  CellTags->"Fig. 1.19"],

Cell[TextData[{
  "These plots show that a resonance occurs when the driving frequency \
\[Omega] is close to the natural frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ": the amplitude of oscillation has a maximum near ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ", and the phase of the oscillation changes from a value near zero (the \
oscillation is in phase with the driving force) to one near \[Pi] (the \
oscillation has the opposite sign to the driving force). The resonance \
becomes sharper as the damping \[Gamma] becomes weaker. The frequency at \
which the amplitude is maximized can be easily shown to be equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Omega]\_o\%2 - \[Gamma]\^2/2\)\)]],
  "(see the exercises). Note that this is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the same as the frequency  of unforced oscillations in a damped \
oscillator, ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Omega]\_o\%2 - \[Gamma]\^2/4\)\)]],
  " [see Eq. ",
  ButtonBox["(1.6.17)",
    ButtonData:>"(1.6.17)",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell[TextData[{
  "\tWhen the damping equals zero exactly, the undamped oscillator exhibits \
an ",
  StyleBox["exact resonance",
    FontSlant->"Italic"],
  " when driven at \[Omega]=",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ". Here the amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " becomes infinite, and therefore the form of the solution, Eq. ",
  ButtonBox["(1.6.45)",
    ButtonData:>"(1.6.45)",
    ButtonStyle->"Hyperlink"],
  ", is no-longer valid.  "
}], "Text",
  CellTags->"i:97"],

Cell[TextData[{
  "\t One way to find the solution at an exact resonance is to use ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[x];\)\), "\n", 
    \(Expand[
      FullSimplify[
        x[t] /. \(DSolve[\(x''\)[t] + \[Omega]\_o^2\ x[t]\  \[Equal] 
                f\_o\ \ Cos[\[Omega]\_o\ t], x[t], 
              t]\)[\([1]\)]]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.84"],

Cell[BoxData[
    \(C[2]\ Cos[t\ \[Omega]\_o] + 
      C[1]\ Sin[
          t\ \[Omega]\_o] + \(Cos[t\ \[Omega]\_o]\ f\_o\)\/\(2\ \
\[Omega]\_o\%2\) + \(t\ Sin[t\ \[Omega]\_o]\ f\_o\)\/\(2\ \[Omega]\_o\)\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "In addition to the usual cosine and sine terms, there is a new term \
proportional to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", " ", "sin", 
          FormBox[\(\[Omega]\_o\),
            "TraditionalForm"], "t"}], TraditionalForm]]],
  ". This term is an oscillation that grows in amplitude over time. At an \
exact undamped resonance, the force is always in phase with the oscillation, \
adding energy to the motion in every cycle. Since this energy is not \
dissipated by damping, the oscillation increases without bound.  Of course, \
in any real oscillator, some form of damping or nonlinearity will eventually \
come into play, stopping the growth of the oscillation. "
}], "Text"],

Cell[TextData[{
  "\tIn later chapters we will run across examples of other  linear ODEs that \
exhibit exact resonance when driven at a natural frequency of the system . In \
each case, the response grows with time, and therefore must be treated as a \
special case for which ",
  ButtonBox["Eq. (1.6.44)",
    ButtonData:>"(1.6.44)",
    ButtonStyle->"Hyperlink"],
  " does not apply.  The simplest approach is to apply ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or the method of undetermined coefficients for the case of resonance, and \
to use ",
  ButtonBox["Eq. (1.6.44)",
    ButtonData:>"(1.6.44)",
    ButtonStyle->"Hyperlink"],
  " otherwise."
}], "Text"],

Cell[TextData[{
  "\tNevertheless, it is useful to understand mathematically how this  \
resonant behavior arises. Consider an undamped oscillator driven at a \
frequency just off resonance, with forcing ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ \(f\_o\) 
          cos[\((\[Omega]\_o - \ \[Epsilon])\) t]\)]],
  ". Then the particular solution is given by ",
  ButtonBox["Eq. (1.6.45)",
    ButtonData:>{"", "(1.6.45)"},
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{\(\(x\_p\)(t)\), " ", "=", " ", 
              RowBox[{\(f\_o\), 
                RowBox[{\(cos[\((\[Omega]\_o - \ \[Epsilon])\) t]\), "/", 
                  RowBox[{"(", 
                    RowBox[{"2", 
                      FormBox[\(\(\[Omega]\_o\ \[Epsilon]\)\(-\)\),
                        "TraditionalForm"], \(\[Epsilon]\^2\)}], ")"}]}]}]}],
            "TraditionalForm"], " "}], TraditionalForm]]],
  "."
}], "NE6",
  CellTags->"(1.6.46)"],

Cell[TextData[{
  "This oscillation has very large amplitude, approaching infinity as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] \[Rule] \ 0\)]],
  ". However, consider a ",
  "different",
  " particular solution; one that is chosen to be ",
  StyleBox["zero ",
    FontSlant->"Italic"],
  "initially. Such a solution can be obtained by adding in a homogeneous \
solution  to the oscillator equation. One choice for the homogeneous solution \
is simply",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(A\ cos\ \[Omega]\_o\ t\)\)\)]],
  ", with the appropriate choice of the constant ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  "  so that the solution is zero at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\ \)]]
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(x\_p\)(t)\), " ", "=", 
        RowBox[{
          FractionBox[\(f\_o\), 
            RowBox[{"(", 
              RowBox[{"2", 
                FormBox[\(\(\[Omega]\_o\ \[Epsilon]\)\(-\)\),
                  "TraditionalForm"], \(\[Epsilon]\^2\)}], 
              ")"}]], \((cos[\((\[Omega]\_o - \ \[Epsilon])\) t]\  - \ 
              cos\ \[Omega]\_o\ t\ )\)}]}], TraditionalForm]]]], "NE6",
  CellTags->"(1.6.47)"],

Cell[TextData[{
  "The two cosine  functions are at nearly the same frequency, and therefore \
exhibit the phenomenon of beats, as shown in Cell ",
  ButtonBox["1.85",
    ButtonData:>"Cell 1.85",
    ButtonStyle->"Hyperlink"],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 0.1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = 1\)]],
  ":"
}], "Text",
  CellTags->"i:141"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Epsilon]\  = \ 0.1;\)\), "\n", 
    \(\(Plot[
        Cos[\((1 - \[Epsilon])\)\ t] - Cos[t], {t, 0, 200}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.85"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.311025 0.148162 [
[.2619 .29852 -6 -9 ]
[.2619 .29852 6 0 ]
[.5 .29852 -9 -9 ]
[.5 .29852 9 0 ]
[.7381 .29852 -9 -9 ]
[.7381 .29852 9 0 ]
[.97619 .29852 -9 -9 ]
[.97619 .29852 9 0 ]
[.01131 .0147 -12 -4.5 ]
[.01131 .0147 0 4.5 ]
[.01131 .16286 -12 -4.5 ]
[.01131 .16286 0 4.5 ]
[.01131 .45919 -6 -4.5 ]
[.01131 .45919 0 4.5 ]
[.01131 .60735 -6 -4.5 ]
[.01131 .60735 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .31102 m
.2619 .31727 L
s
[(50)] .2619 .29852 0 1 Mshowa
.5 .31102 m
.5 .31727 L
s
[(100)] .5 .29852 0 1 Mshowa
.7381 .31102 m
.7381 .31727 L
s
[(150)] .7381 .29852 0 1 Mshowa
.97619 .31102 m
.97619 .31727 L
s
[(200)] .97619 .29852 0 1 Mshowa
.125 Mabswid
.07143 .31102 m
.07143 .31477 L
s
.11905 .31102 m
.11905 .31477 L
s
.16667 .31102 m
.16667 .31477 L
s
.21429 .31102 m
.21429 .31477 L
s
.30952 .31102 m
.30952 .31477 L
s
.35714 .31102 m
.35714 .31477 L
s
.40476 .31102 m
.40476 .31477 L
s
.45238 .31102 m
.45238 .31477 L
s
.54762 .31102 m
.54762 .31477 L
s
.59524 .31102 m
.59524 .31477 L
s
.64286 .31102 m
.64286 .31477 L
s
.69048 .31102 m
.69048 .31477 L
s
.78571 .31102 m
.78571 .31477 L
s
.83333 .31102 m
.83333 .31477 L
s
.88095 .31102 m
.88095 .31477 L
s
.92857 .31102 m
.92857 .31477 L
s
.25 Mabswid
0 .31102 m
1 .31102 L
s
.02381 .0147 m
.03006 .0147 L
s
[(-2)] .01131 .0147 1 0 Mshowa
.02381 .16286 m
.03006 .16286 L
s
[(-1)] .01131 .16286 1 0 Mshowa
.02381 .45919 m
.03006 .45919 L
s
[(1)] .01131 .45919 1 0 Mshowa
.02381 .60735 m
.03006 .60735 L
s
[(2)] .01131 .60735 1 0 Mshowa
.125 Mabswid
.02381 .04433 m
.02756 .04433 L
s
.02381 .07396 m
.02756 .07396 L
s
.02381 .1036 m
.02756 .1036 L
s
.02381 .13323 m
.02756 .13323 L
s
.02381 .19249 m
.02756 .19249 L
s
.02381 .22213 m
.02756 .22213 L
s
.02381 .25176 m
.02756 .25176 L
s
.02381 .28139 m
.02756 .28139 L
s
.02381 .34066 m
.02756 .34066 L
s
.02381 .37029 m
.02756 .37029 L
s
.02381 .39992 m
.02756 .39992 L
s
.02381 .42955 m
.02756 .42955 L
s
.02381 .48882 m
.02756 .48882 L
s
.02381 .51845 m
.02756 .51845 L
s
.02381 .54808 m
.02756 .54808 L
s
.02381 .57772 m
.02756 .57772 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31102 m
.02499 .31187 L
.02605 .31405 L
.02729 .31795 L
.02846 .32259 L
.03056 .33148 L
.03171 .33557 L
.03279 .33824 L
.03395 .33935 L
.03524 .33795 L
.03633 .33435 L
.0375 .32796 L
.03887 .3174 L
.04017 .30482 L
.04262 .27769 L
.045 .2532 L
.04568 .24763 L
.04633 .24329 L
.04753 .23799 L
.04868 .23688 L
.04973 .23958 L
.05088 .24683 L
.0521 .25925 L
.05333 .27631 L
.05465 .29872 L
.05703 .34521 L
.05966 .39414 L
.06098 .41311 L
.06174 .42121 L
.06244 .42672 L
.06315 .42998 L
.0638 .4309 L
.06451 .42952 L
.06526 .42533 L
.0665 .41219 L
.06721 .40147 L
.06787 .38953 L
.07072 .32037 L
.07376 .23462 L
.07515 .20007 L
.07588 .18454 L
.07665 .17069 L
.07733 .16108 L
.07807 .15349 L
.07938 .14844 L
.08065 .15426 L
.08137 .16221 L
.08202 .17232 L
.08328 .19923 L
.08448 .2325 L
Mistroke
.08914 .39558 L
.09048 .43901 L
.09174 .47274 L
.09288 .49508 L
.0941 .5091 L
.09476 .51188 L
.09548 .51095 L
.09623 .50547 L
.09693 .49626 L
.09819 .47032 L
.0989 .4509 L
.09954 .43053 L
.10194 .33735 L
.10458 .22331 L
.10578 .17597 L
.10707 .13266 L
.10829 .1018 L
.1094 .0839 L
.11059 .07699 L
.1119 .08458 L
.11255 .0944 L
.11326 .10914 L
.11452 .14591 L
.117 .24816 L
.11933 .36251 L
.12142 .45877 L
.12252 .50143 L
.1237 .53748 L
.12501 .56301 L
.12623 .5717 L
.12694 .56964 L
.12762 .56276 L
.1289 .53732 L
.13008 .49997 L
.13119 .45539 L
.13368 .33061 L
.13638 .18782 L
.1377 .12719 L
.13891 .08216 L
.14018 .04898 L
.14085 .03809 L
.14156 .03183 L
.14228 .03113 L
.14295 .03571 L
.14369 .04649 L
.14448 .06443 L
.14571 .10458 L
.14706 .16341 L
.1498 .31146 L
.15236 .45291 L
Mistroke
.15348 .50575 L
.1547 .55249 L
.15544 .57391 L
.15612 .58879 L
.15677 .59824 L
.15746 .60298 L
.15827 .60148 L
.15902 .59326 L
.1597 .58037 L
.16043 .56086 L
.16179 .5108 L
.16323 .44191 L
.1658 .29555 L
.1682 .1612 L
.16952 .0998 L
.17077 .05501 L
.17193 .02755 L
.17319 .01498 L
.17434 .01983 L
.1754 .03792 L
.17666 .07492 L
.17783 .12307 L
.18052 .26596 L
.18333 .42795 L
.1847 .49635 L
.18594 .54645 L
.18711 .58024 L
.18822 .59864 L
.18938 .6029 L
.19064 .58977 L
.19194 .55795 L
.1926 .53554 L
.19332 .50656 L
.19578 .38192 L
.19837 .2357 L
.19979 .16205 L
.20114 .10365 L
.20239 .06318 L
.2031 .04713 L
.20375 .03701 L
.20491 .03076 L
.20614 .04048 L
.2074 .06697 L
.20855 .10453 L
.21115 .22371 L
.21339 .34427 L
.21458 .40591 L
.21586 .46513 L
.21702 .50996 L
.21807 .54113 L
Mistroke
.21913 .56189 L
.22014 .57102 L
.22126 .5688 L
.2223 .5553 L
.22344 .5287 L
.22465 .48871 L
.22947 .26478 L
.23062 .21174 L
.23185 .16192 L
.23298 .12441 L
.23406 .09834 L
.23469 .08757 L
.23538 .0801 L
.23658 .07769 L
.23728 .08245 L
.23802 .09224 L
.23934 .12106 L
.24053 .15777 L
.24164 .19917 L
.24418 .30682 L
.24655 .40446 L
.24771 .44453 L
.24879 .4744 L
.24977 .4944 L
.25081 .50757 L
.25185 .51205 L
.253 .50683 L
.25423 .49021 L
.25535 .46601 L
.25659 .43137 L
.25789 .38826 L
.26009 .30856 L
.26247 .22832 L
.26381 .19263 L
.26504 .16826 L
.26622 .15379 L
.26747 .14843 L
.26859 .15229 L
.26963 .16289 L
.27078 .18144 L
.27201 .20805 L
.27451 .27526 L
.27724 .35071 L
.27849 .37999 L
.27917 .39372 L
.27982 .40486 L
.28107 .42108 L
.28221 .42912 L
.28337 .43065 L
.28461 .42514 L
Mistroke
.28566 .41519 L
.28682 .39961 L
.2918 .3056 L
.29399 .26887 L
.29522 .25361 L
.29634 .24383 L
.29738 .23848 L
.29851 .23679 L
.29958 .23892 L
.30057 .24376 L
.30496 .28624 L
.30735 .31185 L
.30851 .32212 L
.30957 .32954 L
.31074 .33537 L
.31199 .33871 L
.31264 .33931 L
.31335 .33915 L
.31463 .33693 L
.3158 .33323 L
.31704 .32826 L
.31926 .31895 L
.32053 .3147 L
.32123 .31294 L
.32188 .31181 L
.32314 .31103 L
.32433 .3121 L
.325 .31342 L
.32571 .31535 L
.327 .31988 L
.32839 .32574 L
.3299 .33203 L
.33117 .33635 L
.33234 .3388 L
.33346 .33928 L
.33464 .33745 L
.33593 .33243 L
.33714 .32492 L
.33846 .31385 L
.33988 .29947 L
.34246 .2706 L
.34387 .25618 L
.34519 .24544 L
.34631 .23937 L
.34752 .23678 L
.34821 .23735 L
.34887 .23934 L
.3501 .24697 L
.35079 .25355 L
.35143 .26085 L
Mistroke
.35285 .28137 L
.3554 .32858 L
.35686 .35783 L
.35841 .38673 L
.35911 .39813 L
.35985 .40888 L
.36054 .41719 L
.36119 .42341 L
.36243 .4302 L
.36356 .43002 L
.36481 .42239 L
.36552 .41465 L
.36617 .40537 L
.36741 .3825 L
.36878 .35057 L
.37156 .27372 L
.37398 .20858 L
.37535 .17939 L
.3766 .16022 L
.3777 .15064 L
.3789 .1489 L
.38016 .15729 L
.38133 .17432 L
.38261 .20231 L
.38396 .24094 L
.38638 .32495 L
.38921 .42445 L
.39059 .46422 L
.39186 .49141 L
.39303 .50695 L
.39414 .51204 L
.39531 .50666 L
.39659 .48824 L
.3979 .45673 L
.39929 .41121 L
.40179 .30903 L
.40421 .20575 L
.40548 .15803 L
.40617 .13553 L
.40682 .11735 L
.408 .09233 L
.40928 .07835 L
.41038 .07843 L
.41155 .09091 L
.41269 .11494 L
.41392 .15304 L
.41617 .24699 L
.42038 .44881 L
.42158 .4966 L
.42272 .53281 L
Mistroke
.42404 .56067 L
.42525 .57138 L
.42638 .5678 L
.42743 .55265 L
.42858 .52358 L
.42981 .47978 L
.4348 .2274 L
.43617 .15953 L
.43761 .0993 L
.43884 .06112 L
.43955 .04591 L
.4402 .03632 L
.44093 .03112 L
.44163 .03173 L
.44294 .04743 L
.44367 .06419 L
.44434 .08447 L
.44587 .14533 L
.44842 .27837 L
.45122 .43562 L
.45243 .49449 L
.45372 .54641 L
.45495 .58128 L
.45607 .59927 L
.45727 .60255 L
.45858 .58708 L
.45924 .57198 L
.45995 .55076 L
.46122 .50069 L
.46619 .22636 L
.4674 .16111 L
.4687 .10066 L
.46944 .0721 L
.47012 .05056 L
.4708 .03375 L
.47145 .02256 L
.47215 .01596 L
.47289 .01515 L
.47358 .02029 L
.47421 .02981 L
.47496 .04677 L
.47576 .07166 L
.47722 .13195 L
.47976 .26886 L
.48255 .42918 L
.48383 .49306 L
.48453 .52335 L
.48519 .54815 L
.48648 .58394 L
.48766 .60081 L
Mistroke
.48831 .60332 L
.489 .60058 L
.49024 .58198 L
.49093 .56444 L
.49157 .54368 L
.49305 .48279 L
.49546 .35477 L
.49805 .20965 L
.4993 .14726 L
.50048 .09811 L
.50155 .06428 L
.5027 .04039 L
.50389 .0308 L
.50514 .03783 L
.50622 .05736 L
.5074 .09199 L
.50868 .14278 L
.51006 .20875 L
.51254 .34145 L
.51387 .41027 L
.51532 .47621 L
.51598 .50179 L
.51669 .52514 L
.51796 .5558 L
.5186 .56533 L
.51929 .57084 L
.52055 .56806 L
.52178 .54996 L
.5229 .52107 L
.52398 .48395 L
.52513 .43608 L
.5272 .33701 L
.52946 .2279 L
.53065 .17716 L
.53191 .13255 L
.53254 .11459 L
.53324 .09863 L
.53447 .08101 L
.53572 .07747 L
.53688 .08725 L
.53802 .1082 L
.53907 .13616 L
.54141 .2222 L
.54386 .32801 L
.54617 .42002 L
.54745 .46047 L
.54813 .47758 L
.54884 .49212 L
.5501 .50828 L
.55125 .5119 L
Mistroke
.55234 .50552 L
.55351 .4888 L
.55461 .46467 L
.55561 .43677 L
.56039 .26945 L
.56168 .22819 L
.56304 .19191 L
.5642 .16887 L
.56549 .15323 L
.56621 .14921 L
.56687 .14853 L
.56759 .15103 L
.56835 .1572 L
.56963 .17513 L
.57036 .18898 L
.57103 .20387 L
.57358 .27152 L
.57628 .3466 L
.57739 .37347 L
.57858 .39756 L
.57989 .41698 L
.58112 .42769 L
.58176 .43031 L
.58247 .43079 L
.58375 .42553 L
.585 .41351 L
.58616 .39732 L
.58903 .34427 L
.59164 .29392 L
.59283 .2742 L
.59411 .25696 L
.59533 .24532 L
.59645 .23896 L
.59764 .23677 L
.59894 .23952 L
.5996 .24273 L
.6003 .24736 L
.60157 .25825 L
.60396 .28407 L
.60657 .31205 L
.60776 .3225 L
.60903 .33104 L
.61011 .33599 L
.6113 .33887 L
.61245 .33922 L
.6135 .33771 L
.61465 .33446 L
.61587 .32982 L
.61793 .32106 L
.61901 .31695 L
Mistroke
.62016 .31357 L
.6208 .31225 L
.6215 .31134 L
.62274 .3112 L
.624 .31297 L
.62517 .31616 L
.62632 .32038 L
.62737 .32477 L
.62851 .32966 L
.62972 .33432 L
.63103 .33794 L
.63223 .33933 L
.63353 .33818 L
.63427 .33613 L
.63496 .33326 L
.63621 .32583 L
.63735 .31664 L
.63993 .28995 L
.642 .2669 L
.64313 .25557 L
.6442 .24672 L
.64547 .23954 L
.64663 .23683 L
.64771 .23807 L
.64888 .24384 L
.65001 .25378 L
.65126 .26939 L
.65379 .31262 L
.65613 .35919 L
.65831 .39823 L
.65952 .41473 L
.6608 .42643 L
.66153 .42993 L
.66222 .43089 L
.66351 .42637 L
.66475 .41423 L
.66589 .39662 L
.66714 .37101 L
.66845 .3383 L
.67293 .21468 L
.67422 .18564 L
.67544 .1648 L
.67654 .15295 L
.67773 .14843 L
.67903 .15408 L
.67968 .16116 L
.68041 .17218 L
.68168 .19929 L
.68288 .23248 L
.68769 .4007 L
Mistroke
.68903 .44331 L
.68975 .46329 L
.69043 .47927 L
.69163 .50035 L
.69295 .51138 L
.69369 .5116 L
.69438 .50776 L
.69569 .49011 L
.69642 .47452 L
.69709 .4568 L
.69861 .40654 L
.70329 .21041 L
.70464 .15937 L
.70592 .11999 L
.70707 .09452 L
.70832 .07932 L
.70951 .07812 L
.7106 .0886 L
.71185 .11394 L
.71302 .14957 L
.71512 .23545 L
.71739 .34555 L
.7187 .40898 L
.7201 .47051 L
.7214 .5174 L
.72263 .54965 L
.72329 .56135 L
.72401 .56918 L
.72526 .57014 L
.72599 .56318 L
.72676 .54989 L
.72742 .53391 L
.72815 .51169 L
.73061 .40722 L
.73325 .26711 L
.73576 .14174 L
.73685 .09784 L
.73803 .06141 L
.73934 .03704 L
.74057 .03086 L
.74125 .03472 L
.74197 .04442 L
.74327 .07566 L
.74447 .11888 L
.74558 .16953 L
.74813 .3077 L
.75086 .45804 L
.7522 .51941 L
.75345 .56326 L
.75414 .58117 L
Mistroke
.75488 .59459 L
.75562 .60193 L
.75643 .60269 L
.75711 .59746 L
.75784 .58597 L
.75915 .55056 L
.76042 .501 L
.76159 .44384 L
.76426 .29207 L
.7657 .20878 L
.76707 .13766 L
.7684 .08064 L
.76963 .04229 L
.77071 .02177 L
.77186 .01472 L
.77301 .02319 L
.77428 .04997 L
.77551 .09214 L
.77684 .15211 L
.77924 .28504 L
.78178 .43099 L
.78318 .50002 L
.78449 .55155 L
.78572 .58476 L
.78641 .59628 L
.78705 .60206 L
.78817 .60077 L
.78936 .5836 L
.79068 .54698 L
.79141 .51926 L
.79209 .49016 L
.79463 .35685 L
.79763 .18975 L
.79895 .12742 L
.79965 .09943 L
.8004 .07405 L
.80164 .04448 L
.8028 .03165 L
.80345 .03103 L
.80413 .03541 L
.80535 .05576 L
.80599 .07261 L
.80668 .09485 L
.80792 .14446 L
.81073 .28668 L
.81336 .4245 L
.81466 .48179 L
.81585 .52398 L
.81693 .55156 L
.81808 .56818 L
Mistroke
.81923 .57119 L
.8205 .55872 L
.82568 .37223 L
.82842 .23877 L
.82992 .17428 L
.83066 .14731 L
.83133 .12589 L
.83255 .09647 L
.83387 .07947 L
.83452 .07702 L
.83523 .07887 L
.83597 .08578 L
.83667 .0966 L
.83792 .12593 L
.83905 .16204 L
.84161 .2646 L
.84391 .36381 L
.84517 .41286 L
.84636 .45194 L
.84763 .48427 L
.84831 .49665 L
.84904 .50598 L
.85033 .51203 L
.85151 .50581 L
.8527 .48888 L
.85381 .46466 L
.85631 .38737 L
.85869 .30126 L
.86087 .22823 L
.86204 .19668 L
.86331 .17034 L
.8646 .15397 L
.8653 .14959 L
.86595 .14844 L
.86716 .15363 L
.86826 .16611 L
.86954 .18853 L
.87074 .21611 L
.87508 .33607 L
.87727 .38786 L
.87851 .4094 L
.87968 .42311 L
.88094 .43025 L
.88208 .42992 L
.88335 .42243 L
.88398 .41611 L
.88467 .40748 L
.88706 .36731 L
.88929 .32322 L
.89053 .29935 L
Mistroke
.89189 .27636 L
.89308 .25977 L
.89434 .24683 L
.89504 .24189 L
.89581 .23838 L
.89651 .23691 L
.89717 .23698 L
.8984 .24068 L
.8991 .24459 L
.89973 .24915 L
.90452 .29919 L
.90578 .31215 L
.90714 .32388 L
.90842 .33213 L
.90961 .33697 L
.91072 .33912 L
.91194 .33895 L
.91322 .33642 L
.91441 .33245 L
.91649 .32371 L
.91759 .31921 L
.91876 .31518 L
.91943 .3134 L
.92016 .31198 L
.92145 .31103 L
.92277 .31216 L
.924 .31502 L
.9252 .31913 L
.9263 .32363 L
.92878 .33381 L
.93007 .33761 L
.93127 .33928 L
.93259 .33844 L
.93333 .33659 L
.934 .33401 L
.93471 .33036 L
.93536 .32618 L
.93683 .31411 L
.9395 .28582 L
.94174 .26131 L
.94284 .25112 L
.94386 .24369 L
.94503 .23828 L
.94631 .23691 L
.94739 .23987 L
.94854 .24733 L
.94953 .25732 L
.95061 .27148 L
.95255 .30435 L
.95485 .34956 L
Mistroke
.95698 .38965 L
.9582 .40829 L
.95931 .42101 L
.96054 .42927 L
.96186 .43029 L
.96313 .42313 L
.96384 .41556 L
.9645 .40638 L
.96572 .38447 L
.967 .35514 L
.97619 .15017 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo000COol00`00Oomoo`3oOomCOol001=oo`03001oogoo0?mooe=oo`00
27oo1@001Woo00<007ooOol0ogooDgoo0009Ool01000Oomoo`001Woo00<007ooOol0ogooDgoo0006
0004Ool00`00Oomoo`06Ool00`00Oomoo`3oOomCOol000]oo`03001oogoo00Eoo`<0031oo`03001o
ogoo06Aoo`8006Ioo`03001oogoo051oo`0037oo00<007ooOol017oo00<007ooOol0<7oo0P00IGoo
0P00IWoo00<007ooOol0D7oo000<Ool00`00Oomoo`04Ool00`00Oomoo`0`Ool2001UOol2001UOol2
001BOol000Qoo`05001oogooOol00006Ool00`00Oomoo`0`Ool2001UOol2001UOol2001BOol000Uo
o`<000Moo`03001oogoo031oo`8006Eoo`8006Eoo`80059oo`004goo00<007ooOol09Woo00<007oo
Ool01goo0P002Goo00<007ooOol0Cgoo00<007ooOol01goo0P002Goo00<007ooOol0Cgoo00<007oo
Ool01goo0P002Goo0P00Agoo000COol00`00Oomoo`0UOol20009Ool20009Ool00`00Oomoo`1?Ool0
0`00Oomoo`07Ool20009Ool00`00Oomoo`1?Ool00`00Oomoo`07Ool20009Ool20017Ool001=oo`03
001oogoo02Eoo`8000Uoo`8000Uoo`03001oogoo04ioo`8000Uoo`8000Uoo`80051oo`03001oogoo
00Moo`8000Uoo`8004Moo`004goo00<007ooOol09Goo0P002Goo0P002Goo0P00Cgoo0P002Goo0P00
2Goo0P00D7oo00<007ooOol01goo00<007oo000027oo0P00Agoo000COol00`00Oomoo`0UOol20009
Ool20009Ool2001?Ool20009Ool20009Ool2001@Ool00`00Oomoo`07Ool00`00Ool00008Ool20017
Ool001=oo`8002Ioo`8000Qoo`03001oo`0000Uoo`8004moo`8000Uoo`8000Uoo`80051oo`03001o
ogoo00Moo`03001oo`0000Qoo`8004Moo`004goo00<007ooOol09Goo0P0027oo00<007oo00002Goo
0P00Cgoo0P002Goo0P002Goo0P00D7oo00<007ooOol01goo00<007oo000027oo0P00Agoo000COol0
0`00Oomoo`0UOol20008Ool00`00Ool00009Ool2001?Ool20009Ool20009Ool2001?Ool20009Ool0
0`00Ool00008Ool20017Ool001=oo`03001oogoo02Eoo`8000Qoo`03001oo`0000Uoo`8004moo`80
00Uoo`8000Uoo`8004moo`8000Uoo`03001oo`0000Qoo`8004Moo`004goo00<007ooOol09Goo0P00
27oo00<007oo000027oo00<007oo0000Cgoo0P002Goo0P002Goo0P00Cgoo0P002Goo00<007oo0000
27oo0P00Agoo000COol00`00Oomoo`0UOol20008Ool01000Oomoo`001goo00<007oo0000Cgoo00<0
07oo000027oo0P002Goo0P00Cgoo0P002Goo00<007oo000027oo0P00Agoo000COol00`00Oomoo`0U
Ool20008Ool01000Oomoo`001goo00<007oo0000Cgoo00<007oo00001goo00@007ooOol000Qoo`80
04moo`03001oo`0000Qoo`03001oo`0000Qoo`8004Moo`004goo00<007ooOol09Goo0P0027oo00@0
07ooOol000Moo`03001oo`0004moo`03001oo`0000Moo`04001oogoo0008Ool2001?Ool00`00Ool0
0008Ool00`00Ool00008Ool20017Ool001=oo`03001oogoo02Eoo`8000Qoo`04001oogoo0007Ool0
0`00Ool0001?Ool00`00Ool00007Ool01000Oomoo`0027oo0P00Cgoo00<007oo000027oo00<007oo
000027oo00<007oo0000AWoo000COol00`00Oomoo`0UOol20008Ool01000Oomoo`001goo00<007oo
0000Cgoo00<007oo00001goo00@007ooOol000Qoo`8004moo`03001oo`0000Qoo`03001oo`0000Qo
o`03001oo`0004Ioo`004goo0P009Woo0P0027oo00@007ooOol000Moo`03001oo`0004moo`03001o
o`0000Moo`04001oogoo0008Ool2001?Ool00`00Ool00008Ool00`00Ool00008Ool00`00Ool00016
Ool001=oo`03001oogoo01]oo`03001oogoo00Moo`8000Qoo`04001oogoo0007Ool00`00Ool00009
Ool00`00Oomoo`13Ool00`00Ool00007Ool01000Oomoo`0027oo00<007oo000027oo00<007ooOol0
>Goo00<007ooOol01goo00<007oo000027oo00<007oo000027oo00<007oo000027oo00<007ooOol0
>goo000COol00`00Oomoo`0KOol00`00Oomoo`07Ool20008Ool01000Oomoo`001goo00<007oo0000
2Goo00<007ooOol0>Goo00<007ooOol01goo00<007oo00001goo00@007ooOol000Qoo`03001oo`00
00Qoo`03001oogoo03Uoo`03001oogoo00Moo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`00
00Qoo`8003aoo`004goo00<007ooOol06Woo0P002Goo0P0027oo00@007ooOol000Moo`03001oo`00
00Uoo`03001oogoo03Uoo`03001oogoo00Moo`03001oo`0000Moo`04001oogoo0007Ool01000Oomo
o`0027oo00<007ooOol0>Goo00<007ooOol01goo00<007oo000027oo00<007oo000027oo00<007oo
000027oo0P00?7oo000COol00`00Oomoo`0JOol20009Ool20008Ool01000Oomoo`001goo00<007oo
00002Goo00<007ooOol0>Goo00<007ooOol01goo00<007oo00001goo00@007ooOol000Moo`04001o
ogoo0008Ool2000jOol20008Ool00`00Ool00008Ool00`00Ool00008Ool00`00Ool00008Ool2000l
Ool001=oo`03001oogoo01Yoo`8000Uoo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`00
27oo0P00>Goo00<007oo000027oo00<007oo00001goo00@007ooOol000Moo`04001oogoo0008Ool2
000iOol00`00Ool00008Ool00`00Ool00008Ool00`00Ool00007Ool01000Oomoo`0027oo0P00?7oo
000COol00`00Oomoo`0JOol20009Ool00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Qo
o`8003Uoo`03001oo`0000Qoo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00<0
07oo0000>Goo00<007oo000027oo00<007oo000027oo00<007oo00001goo00@007ooOol000Qoo`80
03aoo`004goo00<007ooOol06Woo0P002Goo00<007oo00001goo00@007ooOol000Moo`04001oogoo
0007Ool00`00Ool0000iOol00`00Ool00008Ool00`00Ool00007Ool01000Oomoo`001goo00@007oo
Ool000Moo`03001oo`0003Uoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0000Moo`04001o
ogoo0008Ool2000lOol001=oo`03001oogoo01Yoo`8000Uoo`03001oo`0000Moo`04001oogoo0007
Ool01000Oomoo`001goo00<007oo0000>Goo00<007oo000027oo00<007oo00001goo00@007ooOol0
00Moo`04001oogoo0007Ool00`00Ool0000iOol00`00Ool00008Ool00`00Ool00008Ool00`00Ool0
0007Ool01000Oomoo`0027oo0P00?7oo000COol00`00Oomoo`0JOol20009Ool00`00Ool00007Ool0
1000Oomoo`001goo00@007ooOol000Moo`03001oo`0003Uoo`03001oo`0000Qoo`03001oo`0000Mo
o`04001oogoo0007Ool01000Oomoo`001goo00<007oo0000>Goo00<007oo000027oo00<007oo0000
27oo00<007oo00001goo00@007ooOol000Qoo`8003aoo`004goo0P006goo00<007oo000027oo00<0
07oo00001goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000iOol00`00Ool00008Ool0
0`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0003Uoo`03001oo`0000Qo
o`03001oo`0000Qoo`03001oo`0000Moo`04001oogoo0008Ool2000lOol001=oo`03001oogoo01Yo
o`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`00
03Uoo`03001oo`0000Qoo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo
0000>Goo00<007oo000027oo00<007oo000027oo00<007oo00001goo00@007ooOol000Qoo`8003ao
o`004goo00<007ooOol06Woo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000
Oomoo`001goo00<007oo0000>Goo00<007oo000027oo00<007oo00001goo00@007ooOol000Moo`04
001oogoo0007Ool00`00Ool0000iOol00`00Ool00008Ool00`00Ool00008Ool00`00Ool00007Ool0
1000Oomoo`0027oo0P00?7oo000COol00`00Oomoo`0JOol00`00Ool00007Ool01000Oomoo`001goo
00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000iOol00`00Ool00008Ool00`00Ool00007
Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0003Uoo`03001oo`0000Qoo`03001oo`00
00Moo`04001oogoo0007Ool01000Oomoo`0027oo0P00?7oo000COol00`00Oomoo`0JOol00`00Ool0
0007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000iOol00`00
Ool00008Ool00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0003Uoo`03
001oo`0000Qoo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol003]o
o`004goo00<007ooOol06Woo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000
Oomoo`001goo00<007oo0000>Goo00<007oo000027oo00<007oo00001goo00@007ooOol000Moo`04
001oogoo0007Ool00`00Ool0000iOol00`00Ool00008Ool00`00Ool00007Ool01000Oomoo`001goo
00@007ooOol000Moo`04001oogoo000kOol001=oo`03001oogoo01Yoo`03001oo`0000Moo`04001o
ogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0003Uoo`03001oo`0000Qoo`03
001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo0000>Goo00<007oo00001goo
00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol003]oo`004goo00<0
07ooOol06Woo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo
00<007oo0000>Goo00<007oo000027oo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007
Ool00`00Ool0000iOol00`00Ool00007Ool01000Oomoo`001goo00D007ooOomoo`0000Ioo`04001o
ogoo0007Ool01000Oomoo`00>goo000COol00`00Oomoo`0JOol00`00Ool00007Ool01000Oomoo`00
1goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000iOol00`00Ool00008Ool00`00Ool0
0007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo000hOol00`00Ool00007Ool01000
Oomoo`001goo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`00>goo000COol00`00
Oomoo`0JOol00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool0
0`00Ool0000iOol00`00Ool00008Ool00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Mo
o`04001oogoo000hOol00`00Ool00007Ool01000Oomoo`001goo00D007ooOomoo`0000Ioo`04001o
ogoo0007Ool01000Oomoo`00>goo000COol2000KOol00`00Ool00007Ool01000Oomoo`001goo00@0
07ooOol000Moo`04001oogoo0007Ool00`00Ool0000iOol00`00Ool00007Ool01000Oomoo`001goo
00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`00>7oo00<007oo00001goo00@007ooOol0
00Moo`05001oogooOol00006Ool01000Oomoo`001goo00@007ooOol003]oo`004goo00<007ooOol0
6Woo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo
0000>Goo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@0
07ooOol003Qoo`03001oo`0000Moo`04001oogoo0007Ool01@00Oomoogoo00001Woo00@007ooOol0
00Moo`04001oogoo000kOol001=oo`03001oogoo01Yoo`03001oo`0000Moo`04001oogoo0007Ool0
1000Oomoo`001goo00@007ooOol000Moo`03001oo`0003Uoo`03001oo`0000Moo`04001oogoo0007
Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo000hOol00`00Ool00007Ool01000Oomo
o`001goo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`00>goo000COol00`00Oomo
o`0JOol00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000
Oomoo`00>7oo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo
00@007ooOol003Qoo`03001oo`0000Moo`04001oogoo0007Ool01@00Oomoogoo00001Woo00@007oo
Ool000Moo`04001oogoo000kOol001=oo`03001oogoo01Yoo`03001oo`0000Moo`04001oogoo0007
Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo000hOol00`00Ool00007Ool01000Oomo
o`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`00>7oo00<007oo00001goo00@0
07ooOol000Moo`05001oogooOol00006Ool01000Oomoo`001goo00@007ooOol003]oo`004goo00<0
07ooOol06Woo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo
00@007ooOol003Qoo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol0
00Moo`04001oogoo000hOol00`00Ool00007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`04001oogoo0007Ool01000Oomoo`00>goo000COol00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00
Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`0027oo
00<007ooOol08goo00<007ooOol01Woo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`00
1goo00@007ooOol000Moo`04001oogoo0008Ool00`00Oomoo`0SOol00`00Oomoo`07Ool00`00Ool0
0007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`00
27oo00<007ooOol08goo00<007ooOol02Woo000COol00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00
Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`0027oo
00<007ooOol08goo00<007ooOol01Woo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`00
1goo00@007ooOol000Moo`04001oogoo0008Ool00`00Oomoo`0SOol00`00Oomoo`07Ool00`00Ool0
0007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`00
27oo00<007ooOol08goo00<007ooOol02Woo0009Ool50005Ool00`00Oomoo`0@Ool00`00Oomoo`06
Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007oo
Ool000Moo`8002Eoo`8000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`04
001oogoo0007Ool01000Oomoo`0027oo00<007ooOol08goo0P0027oo00<007oo00001goo00D007oo
Oomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`001goo00@007ooOol000Qoo`8002Aoo`03
001oogoo00Yoo`002goo00<007ooOol01Goo00<007ooOol03goo0P0027oo00@007ooOol000Moo`04
001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool2000TOol00`00
Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo
00@007ooOol000Qoo`8002Aoo`8000Qoo`03001oo`0000Moo`05001oogooOol00006Ool01@00Oomo
ogoo00001Woo00@007ooOol000Moo`04001oogoo0008Ool2000TOol00`00Oomoo`0:Ool000H000Eo
o`03001oogoo00Eoo`03001oogoo00moo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`00
1goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo00008goo00<007oo
00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`04
001oogoo0008Ool2000TOol20008Ool00`00Ool00007Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000Ioo`04001oogoo0007Ool01000Oomoo`0027oo0P0097oo00<007ooOol02Woo000;Ool00`00
Oomoo`05Ool3000?Ool00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo
0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0002=oo`03001oo`0000Moo`04001o
ogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo
00<007oo000097oo0P0027oo00<007oo00001goo00D007ooOomoo`0000Ioo`05001oogooOol00006
Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0002Aoo`03001oogoo00Yoo`002goo00<0
07ooOol01Goo00<007ooOol03goo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool0
1000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000SOol00`00Ool00007
Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007oo
Ool000Moo`03001oo`0002Aoo`8000Qoo`03001oo`0000Moo`05001oogooOol00006Ool01@00Oomo
ogoo00001Woo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000TOol00`00Oomoo`0:Ool0
00]oo`03001oogoo00Eoo`03001oogoo00moo`03001oo`0000Moo`04001oogoo0007Ool01000Oomo
o`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo00008goo00<0
07oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Mo
o`04001oogoo0007Ool00`00Ool0000TOol20008Ool00`00Ool00007Ool01@00Oomoogoo00001Woo
00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`001goo00<007oo000097oo00<007oo
Ool02Woo000;Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Ool00007Ool01000Oomoo`001goo
00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`00
02=oo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`04001o
ogoo0007Ool01000Oomoo`001goo00<007oo000097oo0P0027oo00<007oo00001goo00D007ooOomo
o`0000Ioo`05001oogooOol00006Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0002Ao
o`03001oogoo00Yoo`002Goo0`001goo00<007ooOol03goo00<007oo00001goo00@007ooOol000Mo
o`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0
000SOol00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000
Oomoo`001goo00@007ooOol000Moo`03001oo`0002Aoo`8000Qoo`03001oo`0000Moo`05001oogoo
Ool00006Ool01@00Oomoogoo00001Woo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000T
Ool00`00Oomoo`0:Ool001=oo`03001oogoo00moo`03001oo`0000Moo`04001oogoo0007Ool01000
Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo00008goo
00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00D007ooOomo
o`0000Ioo`04001oogoo0007Ool00`00Ool0000SOol00`00Ool00008Ool00`00Ool00007Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`001goo00<007oo
000097oo00<007ooOol02Woo000COol00`00Oomoo`0?Ool00`00Ool00007Ool01000Oomoo`001goo
00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`00
02=oo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Ioo`03001o
ogoo009oo`03001oogoo00Aoo`04001oogoo0007Ool00`00Ool0000SOol00`00Ool00008Ool00`00
Ool00007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomo
o`001goo00<007oo000097oo00<007ooOol02Woo000COol00`00Oomoo`0?Ool00`00Ool00007Ool0
1000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol0
00Moo`03001oo`0002=oo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007oo
Ool000Ioo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0007Ool00`00Ool0000SOol00`00
Ool00008Ool00`00Ool00007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo
0007Ool01000Oomoo`001goo00<007oo000097oo00<007ooOol02Woo000COol00`00Oomoo`0?Ool0
0`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`00
1goo00@007ooOol000Moo`03001oo`0002=oo`03001oo`0000Moo`04001oogoo0007Ool01000Oomo
o`001goo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0007Ool00`00
Ool0000SOol01000Oomoo`001Woo00@007ooOol000Moo`05001oogooOol00006Ool01@00Oomoogoo
00001Woo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000SOol00`00Oomoo`0;Ool001=o
o`03001oogoo00moo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol0
00Moo`04001oogoo0006Ool01@00Oomoogoo00001goo00<007oo00008goo00@007ooOol000Ioo`04
001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo00Ao
o`04001oogoo0007Ool00`00Ool0000SOol01000Oomoo`001Woo00@007ooOol000Moo`05001oogoo
Ool00006Ool01@00Oomoogoo00001Woo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000S
Ool00`00Oomoo`0;Ool001=oo`80011oo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`00
1goo00@007ooOol000Moo`04001oogoo0006Ool01@00Oomoogoo00001goo00<007oo00008goo00@0
07ooOol000Ioo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Ioo`03001oogoo009o
o`03001oogoo00Aoo`04001oogoo0007Ool00`00Ool0000SOol01000Oomoo`001Woo00@007ooOol0
00Moo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol000Moo`04001oogoo0007
Ool00`00Ool0000SOol00`00Oomoo`0;Ool001=oo`03001oogoo00moo`03001oo`0000Moo`04001o
ogoo0007Ool01000Oomoo`001goo00D007ooOomoo`0000Ioo`04001oogoo0006Ool01@00Oomoogoo
00001goo00<007oo00008goo00@007ooOol000Ioo`04001oogoo0007Ool01000Oomoo`001Woo00D0
07ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0007Ool00`00Ool0000S
Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo0000
1Woo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000SOol00`00Oomoo`0;Ool001=oo`03
001oogoo00moo`03001oo`0000Moo`05001oogooOol00006Ool01000Oomoo`001goo00D007ooOomo
o`0000Ioo`04001oogoo0006Ool01@00Oomoogoo00001goo00<007oo00008goo00@007ooOol000Io
o`04001oogoo0007Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001o
ogoo00Aoo`04001oogoo0007Ool01000Oomoo`008Woo00@007ooOol000Ioo`05001oogooOol00006
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`001goo
00<007oo00008goo00<007ooOol02goo000COol00`00Oomoo`0?Ool00`00Ool00007Ool01@00Oomo
ogoo00001Woo00@007ooOol000Moo`05001oogooOol00005Ool01@00Oomoogoo00001Woo00D007oo
Oomoo`0000Moo`03001oo`0002=oo`04001oogoo0006Ool01@00Oomoogoo00001Woo00@007ooOol0
00Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo
0007Ool01000Oomoo`008Woo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`001goo00<007oo00008goo00<0
07ooOol02goo000COol00`00Oomoo`0?Ool00`00Ool00007Ool01@00Oomoogoo00001Woo00@007oo
Ool000Moo`05001oogooOol00005Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Moo`03001o
o`0002=oo`04001oogoo0006Ool01@00Oomoogoo00001Woo00@007ooOol000Ioo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00007Ool01000Oomo
o`008Woo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000Ioo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol0029oo`03001oogoo00]oo`00
4goo00<007ooOol03goo00<007oo00001goo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01@00
Oomoogoo00001Goo00D007ooOomoo`0000Ioo`05001oogooOol00007Ool00`00Ool0000SOol01000
Oomoo`001Woo00D007ooOomoo`0000Ioo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00@007ooOol0029oo`04001o
ogoo0006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`00
00Ioo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol0029oo`03001oogoo00]oo`004goo
00<007ooOol03goo00<007oo00001goo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01@00Oomo
ogoo00001Goo00D007ooOomoo`0000Ioo`05001oogooOol00007Ool00`00Ool0000SOol01000Oomo
o`001Woo00D007ooOomoo`0000Ioo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00@007ooOol0029oo`04001oogoo
0006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Io
o`04001oogoo0006Ool01@00Oomoogoo00001goo00@007ooOol0029oo`03001oogoo00]oo`004goo
00<007ooOol03goo00<007oo00001goo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01@00Oomo
ogoo00001Goo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`008goo00@007oo
Ool000Ioo`05001oogooOol00006Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol0000ROol01000
Oomoo`001Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol0
0006Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogooOol0000ROol00`00Oomoo`0;
Ool001=oo`03001oogoo00moo`03001oo`0000Moo`05001oogooOol00006Ool01000Oomoo`001goo
00D007ooOomoo`0000Eoo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol002=o
o`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo
00008Woo00@007ooOol000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`05001o
ogooOol0000ROol00`00Oomoo`0;Ool001=oo`03001oogoo00ioo`05001oogooOol00006Ool01@00
Oomoogoo00001Woo00@007ooOol000Moo`05001oogooOol00005Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`0000Ioo`04001oogoo000SOol01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001o
ogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`00029oo`04001oogoo0006Ool01@00Oomoogoo00001Goo
00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00008Woo00<007ooOol02goo000COol2000?Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01@00Oomoogoo00001Goo
00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`008goo00@007ooOol000Ioo`05
001oogooOol00006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol0000ROol01000Oomoo`00
1Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00006Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`00029oo`03001o
ogoo00]oo`004goo00<007ooOol03Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000
Oomoo`001goo00D007ooOomoo`0000Eoo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@0
07ooOol002=oo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool0
1@00Oomoogoo00008Woo00@007ooOol000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo
00=oo`05001oogooOol0000ROol00`00Oomoo`0;Ool001=oo`03001oogoo00ioo`05001oogooOol0
0006Ool01@00Oomoogoo00001Woo00@007ooOol000Moo`05001oogooOol00005Ool01@00Oomoogoo
00001Woo00D007ooOomoo`0000Ioo`04001oogoo000SOol01000Oomoo`001Woo00D007ooOomoo`00
00Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`00029oo`04001oogoo0006Ool01@00Oomo
ogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Ioo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00008Woo00<007ooOol02goo000C
Ool00`00Oomoo`0>Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0006Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001o
ogoo000SOol01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`00029oo`04001oogoo0006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool017oo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool01@00Oomoogoo00008Woo00<007ooOol02goo000COol00`00Oomoo`0>Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Ioo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo000SOol01000Oomoo`001Woo00D007oo
Oomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`00029oo`04001oogoo0006Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Ioo`05001o
ogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00008Woo00<007ooOol0
2goo000COol00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo00001Woo00D007ooOomoo`00
00Ioo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`0000Ioo`04001oogoo0009Ool00`00Oomoo`0=Ool20008Ool01000Oomoo`001Woo00D0
07ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Qoo`03001oogoo00io
o`03001oogoo00Ioo`04001oogoo0006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool017oo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool01@00Oomoogoo000027oo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol02goo000COol0
0`00Oomoo`05Ool20007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`04001oogoo0008Ool2000?Ool20008Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001o
ogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000Moo`8000moo`8000Qoo`04001oogoo0006Ool01@00
Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Ioo`05001oogoo
Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo000027oo00<007ooOol03Woo
00<007ooOol01Woo00<007ooOol02goo000COol00`00Oomoo`05Ool20007Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00007Ool2000?Ool20007Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000Moo`8000moo`8000Qoo`04001oogoo0006Ool01@00Oomoogoo00001Goo00<007ooOol00goo
00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool01@00Oomoogoo00001goo0P0047oo00<007ooOol01Woo00<007ooOol02goo000COol0
0`00Oomoo`05Ool20007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`05001oogooOol00007Ool2000?Ool20007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Moo`8000moo`8000Qoo`04001oogoo0006
Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Ioo`05
001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00<007oo
00003Woo00<007oo00001goo00<007ooOol02goo000COol00`00Oomoo`04Ool00`00Ool00007Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00007Ool2
000?Ool20007Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Moo`03001oo`0000ioo`8000Moo`05001oogooOol00006Ool01@00Oomo
ogoo00001Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00<007oo00003Woo00<0
07oo00001goo00<007ooOol02goo000COol20005Ool00`00Ool00007Ool01@00Oomoogoo00001Woo
00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool00`00Ool0000?Ool20007
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007oo
Oomoo`0000Moo`03001oo`0000ioo`03001oo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo
00001Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00<007oo00003Woo00<007oo
00001goo00<007ooOol02goo000COol00`00Oomoo`04Ool00`00Ool00007Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
1@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001o
o`0000ioo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogoo
Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo000=Ool01000Oomoo`001Woo00D007oo
Oomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00D007oo
Oomoo`0000Moo`03001oo`0000ioo`03001oo`0000Ioo`03001oogoo00aoo`004goo00<007ooOol0
17oo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`00
00Eoo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool01@00Oomoogoo00001Woo00@007ooOol000eoo`04001oogoo0006Ool01@00Oomoogoo
00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04
001oogoo000=Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo
00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Moo`03001oo`0000ioo`03001oo`00
00Ioo`03001oogoo00aoo`004goo00<007ooOol017oo00@007ooOol000Ioo`05001oogooOol00006
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`05
001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00@007oo
Ool000eoo`04001oogoo0006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo
00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol000eoo`04001oogoo0006
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Aoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool01@00Oomoogoo00001goo00<007oo00003Goo00@007ooOol000Ioo`03001oogoo00aoo`004goo
00<007ooOol017oo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Io
o`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01000Oomoo`003Goo00@007oo
Ool000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo0000
1Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomo
o`0000Ioo`05001oogooOol00006Ool01000Oomoo`003Goo00@007ooOol000Ioo`05001oogooOol0
0006Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol0
0007Ool01000Oomoo`0037oo00@007ooOol000Ioo`03001oogoo00aoo`004goo00<007ooOol017oo
00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo009o
o`03001oogoo00=oo`05001oogooOol00006Ool01000Oomoo`003Goo00@007ooOol000Ioo`05001o
ogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001o
ogooOol00006Ool01000Oomoo`003Goo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomo
ogoo00001Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00D0
07ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00007Ool01000Oomo
o`0037oo00@007ooOol000Ioo`03001oogoo00aoo`004goo00<007ooOol00goo00D007ooOomoo`00
00Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo
00=oo`05001oogooOol00006Ool01000Oomoo`003Goo00@007ooOol000Ioo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol00006
Ool01000Oomoo`003Goo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Goo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`00
00Eoo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00007Ool01000Oomoo`0037oo00@0
07ooOol000Ioo`03001oogoo00aoo`004goo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001o
ogooOol00006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo009oo`@00004Ool007ooOol30006
Ool01000Oomoo`003Goo00@007ooOol000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool01@00Oomoogoo00001Goo00<007oo000010000goo0`000goo00<007oo00000P0000=o
o`00Ool00Woo00<007ooOol017oo00D007ooOomoo`0000Ioo`04001oogoo000=Ool01000Oomoo`00
1Woo00D007ooOomoo`0000Ioo`03001oo`0000@000=oo`@0009oo`03001oo`0000<000Aoo`03001o
ogoo00Aoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000aoo`H000Aoo`<000Eoo`<000Aoo`004goo00<007ooOol00goo00D007oo
Oomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo009oo`04
001oogooOol2000017oo001oogoo0P001Goo00@007ooOol000eoo`04001oogoo0006Ool01@00Oomo
ogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Eoo`04001oogooOol2
0003Ool01@00Ool007oo00000Woo0P000goo0P000goo00<007ooOol017oo00D007ooOomoo`0000Io
o`05001oogooOol0000<Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogooOol00005
Ool01P00Oomoogoo001oo`8000=oo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000aoo`06
001oo`00001oo`000goo0P000Woo00D007ooOomoo`0000=oo`03001oogoo005oo`004goo00<007oo
Ool00goo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`03
001oogoo009oo`04001oogooOol2000017oo001oogoo0P001Goo00D007ooOomoo`0000aoo`04001o
ogoo0006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`00
00Eoo`04001oogooOol20003Ool01@00Ool007oo00000Woo0P000goo0P0017oo00<007ooOol00goo
00D007ooOomoo`0000Ioo`05001oogooOol0000<Ool01000Oomoo`001Woo00<007ooOol00Woo00<0
07ooOol00goo00D007ooOomoo`0000Eoo`06001oogooOol007oo0P000goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000aoo`04001oogoo0005Ool20002Ool01@00
Oomoogoo00000goo00<007ooOol00Goo000COol00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<0
07ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool00`00Oomoo`02Ool01000Oomo
ogoo0P0000Aoo`00Oomoo`8000Eoo`05001oogooOol0000<Ool01000Oomoo`001Woo00D007ooOomo
o`0000Eoo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00005Ool01000Oomoogoo0P00
0goo00D007oo001oo`00009oo`8000=oo`8000Aoo`03001oogoo00=oo`05001oogooOol00006Ool0
1@00Oomoogoo000037oo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo00=oo`05001oogoo
Ool00005Ool01P00Oomoogoo001oo`8000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`05001oogooOol0000<Ool00`00Oomoo`020004Ool20002Ool01@00Oomoogoo00000goo00<0
07ooOol00Goo000COol20004Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo009oo`@00004Ool007oo0002Ool20005
Ool01@00Oomoogoo000037oo00@007ooOol000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool01@00Oomoogoo00001Goo00@007ooOomoo`8000=oo`05001oo`00Ool00002Ool2
0003Ool20004Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000]oo`05001o
ogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo10000Woo0P00
0goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000aoo`06001o
ogoo001oo`000goo0P000Woo00D007ooOomoo`0000=oo`03001oogoo005oo`004goo00<007ooOol0
0goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oo`00009oo`8000Eo
o`05001oogooOol0000<Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol017oo00D007ooOomoo`0000Eoo`04001oogooOol20003Ool20002Ool00`00
Oomoo`020003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000]oo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Goo00<007ooOol00goo0P000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D0
07ooOomoo`0000aoo`06001oogoo001oo`000goo0P000Woo00D007ooOomoo`0000=oo`03001oogoo
005oo`004goo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009o
o`03001oo`00009oo`8000Aoo`03001oogoo009oo`03001oogoo00Uoo`05001oogooOol00006Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo0000
1Goo00@007ooOomoo`8000=oo`80009oo`03001oogoo008000=oo`03001oogoo00=oo`03001oogoo
00=oo`05001oogooOol00006Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo
009oo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`09Ool2000017oo001o
o`000goo0P000Woo00D007ooOomoo`0000=oo`03001oogoo005oo`004goo00<007ooOol00goo00D0
07ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo009oo`@00004Ool007ooOol30005Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol017oo00D007ooOomoo`0000Eoo`03001oo`0000<000Aoo`<000=oo`03001oo`0000<0
00Eoo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00002goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007oo00000P001Goo10000Woo00<0
07oo00000`0017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol02Goo
00<007oo00000P001Goo0`001Goo0`0017oo000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo
00D007ooOomoo`0000Ioo`05001oogooOol0000;Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool01@00Oomoogoo00001Goo00<007ooOol037oo000COol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol0000;Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`09Ool01@00Oomoogoo00001Goo00<007ooOol037oo000COol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00Uoo`05001oogooOol00005Ool00`00Oomoo`0<
Ool001=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Qoo`05001o
ogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol037oo000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo
00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00aoo`004goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00aoo`002gooo`00FP0017oo000COol20003Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00=oo`8000=oo`03001oogoo00=oo`03001oogoo
009oo`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oo`0000=oo`03001oogoo009oo`03
001oogoo009oo`03001oo`0000=oo`03001oogoo009oo`03001oogoo00=oo`8000=oo`03001oogoo
00=oo`03001oogoo00=oo`8000=oo`07001oogooOol007oo00000goo00<007oo00000goo00<007oo
Ool00Woo00<007ooOol00goo00<007oo00000Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
00000goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00
Oomoo`03Ool01000Oomoogoo0`0000Eoo`00Oomoo`0000Aoo`03001oogoo00=oo`03001oo`0000ao
o`004goo0P000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo
0P0017oo00<007ooOol00Woo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oo`0000=oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`07
001oogooOol007oo000017oo00<007ooOol00Woo00<007ooOol00goo00<007oo000037oo000COol2
0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`001Goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00D007oo
Oomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool001=oo`8000=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00D007ooOomoo`00009oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo
00000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oogoo00eoo`004goo0P000goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol00goo00@007ooOol000=oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000
Oomoo`000goo00@007ooOol000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`00
1Goo00<007ooOol00Woo00<007ooOol03Goo000COol00`00Ool00002Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool01000Oomoo`000goo00@007ooOol000Eoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0000=oo`04
001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00003Ool01000Oomoo`001Woo00D007ooOomoo`00
00moo`004goo00<007oo00000Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol000=oo`03
001oo`0000Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00Aoo`03001oo`0000=oo`04001oogoo0005Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Ool00004Ool00`00Ool00006Ool01@00Oomoogoo00003goo000COol00`00Oomoo`020006Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Ool00003Ool00`00Ool00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00004Ool2
0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Ool00004Ool00`00Ool00006Ool01@00Oomoogoo00003goo000C
Ool00`00Oomoo`020006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20005Ool20006Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20005Ool2
0007Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol017oo0`0017oo0P001goo00D007ooOomoo`0000moo`004goo0P0000=oo`00Ool01Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol017oo0P001Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo00Eoo`05001oogooOol0000?Ool001=oo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
01=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo01Aoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0DOol01@00Oomoogoo00003goo000COol00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`0DOol01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol057oo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomo
o`0DOol01@00Oomoogoo00003goo000COol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol057oo00D007ooOomoo`0000Eoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Aoo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol057oo00D007ooOomoo`0000moo`00
4goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00D007ooOomo
o`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo01Aoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol057oo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00005Ool00`00Oomoo`02Ool0
0`00Oomoo`0DOol01@00Oomoogoo00003goo000COol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0001Moo`05001oogooOol00005Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol057oo00D007ooOomoo`0000Eoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`05001oogoo
Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`0DOol01@00Oomoogoo00003goo000COol00`00Oomo
o`08Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo009o
o`03001oogoo00Aoo`05001oogooOol00005Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eo
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0DOol01@00Oomoogoo00001Goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`0DOol01@00Oomoogoo00003goo000COol00`00Oomoo`08
Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03
001oogoo00Aoo`05001oogooOol00005Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`05
001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool017oo00D007ooOomoo`0001Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool00goo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`0D
Ool01@00Oomoogoo00003goo000COol00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00005Ool0
1@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`05001oogooOol00006Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0001Ioo`05001o
ogooOol00006Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001o
ogooOol00006Ool01@00Oomoogoo00005Woo00D007ooOomoo`0000moo`004goo00<007ooOol027oo
00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool01@00Oomoogoo00001Woo00@007ooOol001Moo`04001oogoo0006Ool01@00Oomoogoo
00001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo
00005Woo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo
00001Woo00D007ooOomoo`0000Ioo`05001oogooOol0000FOol01@00Oomoogoo00003goo000COol2
0009Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo009o
o`03001oogoo00Aoo`05001oogooOol00006Ool01000Oomoo`005goo00@007ooOol000Ioo`05001o
ogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`05001o
ogooOol0000FOol01@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001o
ogoo00=oo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Ioo`05001oogooOol0000FOol01@00Oomoogoo00003goo000COol00`00
Oomoo`09Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo009o
o`03001oogoo00Aoo`05001oogooOol00006Ool01000Oomoo`005goo00@007ooOol000Ioo`05001o
ogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`04001o
ogoo000GOol01@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo
00=oo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo
00D007ooOomoo`0000Ioo`05001oogooOol0000GOol01000Oomoo`003goo000COol00`00Oomoo`09
Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001o
ogoo00Aoo`05001oogooOol00006Ool01000Oomoo`005goo00@007ooOol000Ioo`05001oogooOol0
0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Eo
o`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00006Ool01000Oomoo`005goo00D007oo
Oomoo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo
00001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol00006
Ool01@00Oomoogoo00005goo00@007ooOol000moo`004goo00<007ooOol02Goo00@007ooOol000Io
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00Aoo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`04001oogoo000GOol01000Oomoo`001goo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo
00=oo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogoo
Ool00006Ool01000Oomoo`005goo00D007ooOomoo`0000Ioo`05001oogooOol00005Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00goo00D0
07ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00005goo00@007ooOol000moo`00
4goo00<007ooOol02Goo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00006Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo000GOol01000Oomoo`001goo00@007oo
Ool000Ioo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`0067oo00@007ooOol000Io
o`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00<0
07ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomo
ogoo00005goo00@007ooOol000moo`004goo00<007ooOol02Goo00@007ooOol000Ioo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`005goo00@0
07ooOol000Moo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol0
01Qoo`03001oo`0000Moo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00
Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogoo
Ool00006Ool01@00Oomoogoo00005goo00@007ooOol000moo`004goo00<007ooOol02Goo00@007oo
Ool000Ioo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol0
01Moo`04001oogoo0007Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00goo00D007oo
Oomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04
001oogoo000HOol00`00Ool00007Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol0
17oo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0001Moo`04001oogoo000?Ool001=oo`03001oogoo00Uoo`04
001oogoo0006Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomo
o`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001o
ogoo000GOol01000Oomoo`001goo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo00=oo`05
001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006
Ool01000Oomoo`0067oo00<007oo00001goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001o
ogoo00Aoo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo
00D007ooOomoo`0000Ioo`04001oogoo000HOol01000Oomoo`003goo000COol00`00Oomoo`09Ool0
1000Oomoo`001Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo00=oo`05001oogoo
Ool00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000
Oomoo`005goo00@007ooOol000Moo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo0000
1Woo00@007ooOol001Qoo`03001oo`0000Moo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Io
o`05001oogooOol00006Ool01000Oomoo`0067oo00@007ooOol000moo`004goo00<007ooOol02Goo
00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo000G
Ool01000Oomoo`001goo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo00=oo`05001oogoo
Ool00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomo
o`0067oo00<007oo00001goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00Aoo`04
001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000Ioo`04001oogoo000HOol01000Oomoo`003goo000COol2000:Ool01000Oomoo`001Woo00D0
07ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol001Moo`04001oogoo0007Ool0
1000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001oogoo
Ool00006Ool01@00Oomoogoo00001Woo00@007ooOol000Moo`04001oogoo000HOol00`00Ool00007
Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00@007ooOol000Ioo`03001o
ogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol0
01Qoo`03001oo`00011oo`004goo00<007ooOol02Goo00@007ooOol000Ioo`05001oogooOol00006
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo
00001Woo00D007ooOomoo`0000Ioo`04001oogoo000GOol01000Oomoo`001goo00@007ooOol000Mo
o`05001oogooOol00005Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol0
0006Ool01000Oomoo`001goo00@007ooOol001Qoo`03001oo`0000Moo`05001oogooOol00005Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00goo
00D007ooOomoo`0000Ioo`05001oogooOol00007Ool00`00Ool0000HOol00`00Ool0000@Ool001=o
o`03001oogoo00Yoo`03001oo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`04001oogoo000GOol01000Oomoo`001goo00@007ooOol000Moo`05001oogooOol00005Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`001goo00@0
07ooOol001Qoo`03001oo`0000Moo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Ioo`05001o
ogooOol00007Ool00`00Ool0000HOol00`00Ool0000@Ool001=oo`03001oogoo00Yoo`03001oo`00
00Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogoo
Ool00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo000HOol00`00Ool0
0007Ool01000Oomoo`001goo00D007ooOomoo`0000Eoo`05001oogooOol00006Ool01@00Oomoogoo
00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool00`00Ool0000IOol00`00Ool00007Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00@007ooOol000Ioo`03001oogoo
009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00001goo00<007oo000067oo
00<007oo000047oo000COol00`00Oomoo`0:Ool00`00Ool00006Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`04001oogoo0007Ool00`00Ool0000IOol00`00Ool00007Ool01000Oomoo`001goo00D007ooOomo
o`0000Eoo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001o
ogoo0008Ool2000IOol00`00Ool00007Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool017oo00@007ooOol000Ioo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool0
1@00Oomoogoo00001goo00<007oo000067oo00<007oo000047oo000COol00`00Oomoo`0:Ool00`00
Ool00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool00`00Ool0000IOol00`00Ool0
0007Ool01000Oomoo`001goo00D007ooOomoo`0000Eoo`05001oogooOol00006Ool01@00Oomoogoo
00001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool2000IOol00`00Ool00007Ool01@00Oomo
ogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00@007ooOol000Ioo`03001oogoo009oo`03
001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00001goo0P006Goo00<007oo000047oo
000COol00`00Oomoo`0:Ool00`00Ool00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0008
Ool2000IOol00`00Ool00007Ool01000Oomoo`001goo00D007ooOomoo`0000Eoo`05001oogooOol0
0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool2000IOol00`00
Ool00007Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00@007ooOol000Io
o`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00001goo0P00
6Goo00<007oo000047oo000COol00`00Oomoo`0:Ool00`00Ool00007Ool01000Oomoo`001Woo00D0
07ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`04001oogoo0008Ool2000IOol00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Ioo`05
001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool2
000IOol00`00Ool00007Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00@0
07ooOol000Ioo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo
00001goo0P006Goo00<007oo000047oo000COol00`00Oomoo`0:Ool20008Ool01000Oomoo`001Woo
00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`00
00Ioo`04001oogoo0008Ool2000IOol20008Ool01000Oomoo`001goo00@007ooOol000Ioo`05001o
ogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool2000I
Ool20008Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00@007ooOol000Io
o`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00001goo0P00
6Goo00<007oo000047oo000COol00`00Oomoo`0:Ool20008Ool01000Oomoo`001Woo00D007ooOomo
o`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001o
ogoo0008Ool2000IOol20008Ool01000Oomoo`001goo00@007ooOol000Ioo`05001oogooOol00006
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool2000IOol20008Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol017oo00@007ooOol000Ioo`03001oogoo
009oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00001goo0P006Goo00<007oo
000047oo000COol00`00Oomoo`0:Ool20008Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05
001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool2
000IOol20008Ool01000Oomoo`001goo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomo
ogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool2000IOol20008Ool01@00Oomoogoo
00001Goo00<007ooOol00Woo00<007ooOol017oo00@007ooOol000Ioo`05001oogooOol00006Ool0
1@00Oomoogoo00001Woo00@007ooOol000Qoo`8001Yoo`03001oogoo00moo`004goo0P002goo0P00
27oo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D007ooOomoo`00
00Ioo`05001oogooOol00006Ool01000Oomoo`0027oo00<007ooOol06Goo00<007ooOol01Woo00@0
07ooOol000Moo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001o
ogooOol00006Ool01000Oomoo`0027oo00<007ooOol06Goo00<007ooOol01Woo00D007ooOomoo`00
00Eoo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`0000Ioo`04001oogoo0008Ool2000JOol00`00Oomoo`0?Ool001=oo`03001oogoo01Ao
o`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006
Ool01@00Oomoogoo00001Woo00@007ooOol002eoo`04001oogoo0007Ool01000Oomoo`001Woo00D0
07ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol002eoo`04
001oogoo0006Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`001Woo00D007ooOomoo`00
00Ioo`05001oogooOol00006Ool01000Oomoo`00=Woo000COol00`00Oomoo`0DOol01000Oomoo`00
1Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol0
00Moo`04001oogoo000]Ool01000Oomoo`001goo00@007ooOol000Ioo`05001oogooOol00006Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo000]Ool01000Oomoo`001Woo00<0
07ooOol00Woo00<007ooOol017oo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo
00001Woo00@007ooOol003Ioo`004goo00<007ooOol057oo00@007ooOol000Ioo`05001oogooOol0
0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`00
;Goo00@007ooOol000Moo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`05001oogooOol00006Ool01000Oomoo`00;Goo00@007ooOol000Ioo`03001oogoo009oo`03001o
ogoo00Aoo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo
000fOol001=oo`03001oogoo01Aoo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000Ioo`05001oogooOol00006Ool01000Oomoo`001goo00@007ooOol002eoo`04001oogoo0007
Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo0000
1Woo00@007ooOol002eoo`04001oogoo0007Ool01@00Oomoogoo00001Woo00@007ooOol000Ioo`05
001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol003Ioo`004goo00<007ooOol057oo
00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol000Moo`04
001oogoo0007Ool01000Oomoo`00;Goo00@007ooOol000Moo`04001oogoo0006Ool01@00Oomoogoo
00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`00;Goo00@007ooOol0
00Moo`05001oogooOol00006Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogooOol0
0006Ool01000Oomoo`00=Woo000COol00`00Oomoo`0DOol01000Oomoo`001Woo00D007ooOomoo`00
00Ioo`05001oogooOol00006Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo000]Ool0
1000Oomoo`001goo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`0000Ioo`04001oogoo000]Ool01000Oomoo`001goo00D007ooOomoo`0000Ioo`04001o
ogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo000fOol000Uoo`D0
00Eoo`03001oogoo01Aoo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Io
o`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol002eoo`04001oogoo0007Ool01000Oomo
o`001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007oo
Ool002eoo`04001oogoo0007Ool01@00Oomoogoo00001Woo00@007ooOol000Ioo`05001oogooOol0
0006Ool01@00Oomoogoo00001Woo00@007ooOol003Ioo`002goo00<007ooOol01Goo00<007ooOol0
57oo00@007ooOol000Ioo`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol000Mo
o`04001oogoo0007Ool01000Oomoo`00;Goo00@007ooOol000Moo`04001oogoo0006Ool01@00Oomo
ogoo00001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`00;Goo00@007oo
Ool000Moo`05001oogooOol00006Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogoo
Ool00006Ool01000Oomoo`00=Woo000;Ool00`00Oomoo`05Ool00`00Oomoo`0DOol01000Oomoo`00
1Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`001goo00@007ooOol000Mo
o`04001oogoo000]Ool01000Oomoo`001goo00@007ooOol000Ioo`05001oogooOol00006Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo000]Ool01000Oomoo`001goo00D007oo
Oomoo`0000Ioo`04001oogoo0006Ool01@00Oomoogoo00001goo00@007ooOol000Ioo`04001oogoo
000fOol000]oo`03001oogoo00Eoo`<001Aoo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol002eoo`04001oogoo
0007Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01@00Oomoogoo
00001Woo00@007ooOol002eoo`04001oogoo0007Ool01@00Oomoogoo00001Woo00@007ooOol000Io
o`05001oogooOol00007Ool01000Oomoo`001Woo00@007ooOol003Ioo`002goo00<007ooOol01Goo
00<007ooOol057oo00<007oo00001goo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000
Oomoo`001goo00@007ooOol000Moo`04001oogoo000]Ool01000Oomoo`001goo00@007ooOol000Io
o`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol000Moo`04001oogoo000]Ool0
1000Oomoo`001goo00@007ooOol000Moo`04001oogoo0006Ool01@00Oomoogoo00001goo00@007oo
Ool000Ioo`04001oogoo000fOol000]oo`03001oogoo00Eoo`03001oogoo01Aoo`03001oo`0000Mo
o`05001oogooOol00006Ool01@00Oomoogoo00001Woo00@007ooOol000Moo`04001oogoo0007Ool0
1000Oomoo`00;Goo00@007ooOol000Moo`04001oogoo0006Ool01@00Oomoogoo00001Woo00D007oo
Oomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`00;Goo00@007ooOol000Moo`04001oogoo0007
Ool01000Oomoo`001Woo00D007ooOomoo`0000Moo`04001oogoo0006Ool01000Oomoo`00=Woo000;
Ool00`00Oomoo`05Ool00`00Oomoo`0DOol00`00Ool00007Ool01@00Oomoogoo00001Woo00D007oo
Oomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol002eoo`04001oogoo0007
Ool01000Oomoo`001goo00@007ooOol000Ioo`05001oogooOol00006Ool01000Oomoo`001goo00@0
07ooOol002eoo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007
Ool00`00Ool00007Ool01000Oomoo`00=Woo0009Ool30007Ool00`00Oomoo`0DOol00`00Ool00007
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Ioo`04001oogoo0007Ool01000Oomoo`001goo
00@007ooOol002eoo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Ioo`05001oogoo
Ool00006Ool01000Oomoo`0027oo00<007oo0000;Goo00@007ooOol000Moo`04001oogoo0007Ool0
1000Oomoo`001goo00@007ooOol000Moo`03001oo`0000Qoo`03001oo`0003Ioo`004goo00<007oo
Ool057oo00<007oo00001goo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool01000Oomoo`00
1goo00@007ooOol000Moo`04001oogoo000]Ool00`00Ool00008Ool01000Oomoo`001goo00@007oo
Ool000Ioo`05001oogooOol00006Ool01000Oomoo`0027oo00<007oo0000;Woo00<007oo00001goo
00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo000027oo00<007oo0000
=Woo000COol00`00Oomoo`0DOol00`00Ool00007Ool01@00Oomoogoo00001Woo00D007ooOomoo`00
00Ioo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol002eoo`03001oo`0000Qoo`04001o
ogoo0007Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool00`00Ool0000^
Ool00`00Ool00007Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0
0008Ool00`00Ool0000fOol001=oo`03001oogoo01Aoo`03001oo`0000Moo`04001oogoo0007Ool0
1000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool0000_Ool20008Ool01000
Oomoo`001goo00@007ooOol000Ioo`05001oogooOol00006Ool01000Oomoo`0027oo0P00;goo00<0
07oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo000027oo
00<007oo0000=Woo000COol00`00Oomoo`0DOol00`00Ool00008Ool00`00Ool00008Ool00`00Ool0
0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0002moo`8000Qoo`04001oogoo0007
Ool01000Oomoo`001Woo00D007ooOomoo`0000Ioo`04001oogoo0008Ool2000_Ool00`00Ool00007
Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool00008Ool00`00Ool0
000fOol001=oo`03001oogoo01Eoo`8000Qoo`03001oo`0000Qoo`03001oo`0000Moo`04001oogoo
0007Ool01000Oomoo`0027oo0P00;goo0P0027oo00@007ooOol000Moo`04001oogoo0006Ool01@00
Oomoogoo00001Woo00@007ooOol000Qoo`8002moo`03001oo`0000Moo`04001oogoo0007Ool01000
Oomoo`001goo00@007ooOol000Moo`03001oo`0000Qoo`03001oo`0003Ioo`004goo0P005Woo0P00
27oo00<007oo000027oo00<007oo00001goo00@007ooOol000Moo`04001oogoo0008Ool2000_Ool2
0008Ool01000Oomoo`001goo00@007ooOol000Ioo`05001oogooOol00006Ool01000Oomoo`0027oo
0P00;goo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<0
07oo000027oo00<007oo0000=Woo000COol00`00Oomoo`0EOol20008Ool00`00Ool00008Ool00`00
Ool00007Ool01000Oomoo`001goo00@007ooOol000Qoo`8002moo`8000Qoo`04001oogoo0007Ool0
1000Oomoo`001Woo00D007ooOomoo`0000Moo`03001oo`0000Qoo`8002moo`03001oo`0000Moo`04
001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0000Qoo`03001oo`0003Io
o`004goo00<007ooOol05Goo0P0027oo00<007oo000027oo00<007oo00001goo00@007ooOol000Mo
o`04001oogoo0008Ool2000_Ool20008Ool01000Oomoo`001goo00@007ooOol000Ioo`05001oogoo
Ool00007Ool00`00Ool00008Ool2000_Ool00`00Ool00007Ool01000Oomoo`001goo00@007ooOol0
00Moo`04001oogoo0007Ool00`00Ool00008Ool00`00Ool0000fOol001=oo`03001oogoo01Eoo`80
00Qoo`03001oo`0000Qoo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`0027oo0P00;goo
0P0027oo00@007ooOol000Moo`04001oogoo0006Ool01@00Oomoogoo00001goo00<007oo000027oo
0P00;goo00<007oo00001goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<0
07oo000027oo00<007oo0000=Woo000COol00`00Oomoo`0EOol20008Ool00`00Ool00008Ool00`00
Ool00007Ool01000Oomoo`001goo00@007ooOol000Qoo`8002moo`8000Qoo`04001oogoo0007Ool0
1000Oomoo`001Woo00D007ooOomoo`0000Moo`03001oo`0000Qoo`8002moo`03001oo`0000Moo`04
001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0000Qoo`8003Moo`004goo
00<007ooOol05Goo0P0027oo00<007oo000027oo00<007oo00001goo00@007ooOol000Moo`04001o
ogoo0008Ool2000_Ool20008Ool00`00Ool00008Ool01000Oomoo`001Woo00D007ooOomoo`0000Mo
o`03001oo`0000Qoo`8002moo`8000Qoo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol0
00Moo`03001oo`0000Qoo`8003Moo`004goo00<007ooOol05Goo0P0027oo00<007oo000027oo00<0
07oo00001goo00@007ooOol000Moo`04001oogoo0008Ool2000_Ool20008Ool00`00Ool00008Ool0
1000Oomoo`001Woo00D007ooOomoo`0000Moo`03001oo`0000Qoo`8002moo`8000Qoo`04001oogoo
0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0000Qoo`8003Moo`004goo00<007oo
Ool05Goo0P0027oo00<007oo000027oo00<007oo00001goo00@007ooOol000Moo`04001oogoo0008
Ool2000_Ool20008Ool00`00Ool00008Ool01000Oomoo`001Woo00D007ooOomoo`0000Moo`03001o
o`0000Qoo`80031oo`03001oogoo00Ioo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol0
00Moo`03001oo`0000Qoo`8003Moo`004goo00<007ooOol05Goo0P0027oo00<007oo000027oo00<0
07oo00001goo00@007ooOol000Moo`04001oogoo0008Ool00`00Oomoo`0_Ool00`00Oomoo`06Ool0
0`00Ool00008Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`0000Uoo`03001oogoo02io
o`03001oogoo00Ioo`04001oogoo0007Ool01000Oomoo`001goo00@007ooOol000Moo`03001oo`00
00Uoo`03001oogoo03Eoo`004goo00<007ooOol07goo00<007oo000027oo00<007oo00001goo00@0
07ooOol000Moo`04001oogoo0013Ool00`00Ool00008Ool01000Oomoo`001goo00<007oo000027oo
00<007oo0000@goo00@007ooOol000Moo`04001oogoo0007Ool01000Oomoo`001goo00<007oo0000
@Goo000COol2000POol00`00Ool00008Ool00`00Ool00007Ool01000Oomoo`001goo00@007ooOol0
04=oo`03001oo`0000Qoo`04001oogoo0007Ool00`00Ool00008Ool00`00Ool00013Ool01000Oomo
o`001goo00@007ooOol000Moo`04001oogoo0007Ool00`00Ool00011Ool001=oo`03001oogoo01mo
o`03001oo`0000Qoo`03001oo`0000Moo`04001oogoo0007Ool01000Oomoo`00@goo00<007oo0000
27oo00@007ooOol000Moo`03001oo`0000Qoo`03001oo`0004=oo`04001oogoo0007Ool01000Oomo
o`001goo00@007ooOol000Moo`03001oo`00045oo`004goo00<007ooOol07goo00<007oo000027oo
00<007oo000027oo00<007oo00001goo00@007ooOol004=oo`03001oo`0000Qoo`04001oogoo0007
Ool00`00Ool00008Ool00`00Ool00013Ool01000Oomoo`001goo00@007ooOol000Moo`04001oogoo
0007Ool00`00Ool00011Ool001=oo`03001oogoo01moo`03001oo`0000Qoo`03001oo`0000Qoo`03
001oo`0000Qoo`03001oo`0004=oo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0000Qoo`03
001oo`0004=oo`03001oo`0000Qoo`03001oo`0000Qoo`04001oogoo0007Ool00`00Ool00011Ool0
01=oo`03001oogoo01moo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`00
04=oo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0004=oo`03001oo`00
00Qoo`03001oo`0000Qoo`04001oogoo0007Ool00`00Ool00011Ool001=oo`03001oogoo01moo`03
001oo`0000Qoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0004=oo`03001oo`0000Qoo`03
001oo`0000Qoo`03001oo`0000Qoo`03001oo`0004=oo`03001oo`0000Qoo`03001oo`0000Qoo`04
001oogoo0007Ool00`00Ool00011Ool001=oo`03001oogoo01moo`03001oo`0000Qoo`03001oo`00
00Qoo`03001oo`0000Qoo`03001oo`0004=oo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`00
00Qoo`03001oo`0004Aoo`8000Qoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`00045oo`00
4goo00<007ooOol07goo00<007oo000027oo00<007oo000027oo00<007oo000027oo00<007oo0000
@goo00<007oo000027oo00<007oo000027oo00<007oo000027oo00<007oo0000A7oo0P0027oo00<0
07oo000027oo00<007oo000027oo00<007oo0000@Goo000COol00`00Oomoo`0OOol00`00Ool00008
Ool00`00Ool00008Ool00`00Ool00008Ool00`00Ool00013Ool00`00Ool00008Ool00`00Ool00008
Ool00`00Ool00008Ool00`00Ool00014Ool20008Ool00`00Ool00008Ool00`00Ool00008Ool00`00
Ool00011Ool001=oo`03001oogoo01moo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0000Qo
o`8004Aoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0004Aoo`8000Qo
o`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`00045oo`004goo00<007ooOol07goo00<007oo
000027oo00<007oo000027oo00<007oo000027oo0P00A7oo00<007oo000027oo00<007oo000027oo
00<007oo000027oo00<007oo0000A7oo0P0027oo00<007oo000027oo00<007oo000027oo00<007oo
0000@Goo000COol2000POol00`00Ool00008Ool00`00Ool00008Ool00`00Ool00008Ool20015Ool2
0008Ool00`00Ool00008Ool00`00Ool00008Ool00`00Ool00014Ool20008Ool00`00Ool00008Ool0
0`00Ool00008Ool00`00Ool00011Ool001=oo`03001oogoo021oo`8000Qoo`03001oo`0000Qoo`03
001oo`0000Qoo`8004Eoo`8000Qoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`0004Aoo`80
00Qoo`03001oo`0000Qoo`03001oo`0000Qoo`03001oo`00045oo`004goo00<007ooOol087oo0P00
27oo00<007oo000027oo00<007oo000027oo0P00AGoo0P0027oo00<007oo000027oo00<007oo0000
27oo00<007oo0000A7oo0P0027oo00<007oo000027oo00<007oo000027oo00<007oo0000@Goo000C
Ool00`00Oomoo`0POol20008Ool00`00Ool00008Ool00`00Ool00008Ool20015Ool20008Ool00`00
Ool00008Ool00`00Ool00008Ool00`00Ool00014Ool20008Ool00`00Ool00008Ool00`00Ool00008
Ool00`00Ool00011Ool001=oo`03001oogoo021oo`8000Qoo`03001oo`0000Qoo`03001oo`0000Qo
o`8004Eoo`8000Qoo`03001oo`0000Qoo`03001oo`0000Qoo`8004Eoo`8000Qoo`03001oo`0000Qo
o`03001oo`0000Uoo`80045oo`004goo00<007ooOol087oo0P0027oo00<007oo000027oo00<007oo
000027oo0P00AGoo0P0027oo00<007oo000027oo00<007oo000027oo0P00AGoo0P0027oo00<007oo
000027oo00<007oo00002Goo0P00@Goo000COol00`00Oomoo`0POol20008Ool00`00Ool00008Ool0
0`00Ool00009Ool00`00Oomoo`13Ool20008Ool00`00Ool00008Ool00`00Ool00008Ool20015Ool2
0008Ool00`00Ool00008Ool00`00Ool00009Ool00`00Oomoo`10Ool001=oo`03001oogoo021oo`03
001oogoo00Moo`03001oo`0000Qoo`03001oo`0000Uoo`03001oogoo04=oo`8000Qoo`03001oo`00
00Qoo`03001oo`0000Uoo`03001oogoo04=oo`8000Qoo`03001oo`0000Uoo`8000Uoo`03001oogoo
041oo`004goo00<007ooOol087oo00<007ooOol01goo00<007oo000027oo00<007oo0000Cgoo00<0
07ooOol01goo00<007oo000027oo00<007oo0000FGoo00<007oo00002Goo0P002Goo00<007ooOol0
@7oo000COol00`00Oomoo`0ZOol00`00Ool00008Ool2001JOol00`00Ool00008Ool00`00Ool0001J
Ool20009Ool2001<Ool001=oo`8002]oo`03001oo`0000Qoo`8005Yoo`03001oo`0000Qoo`03001o
o`0005Yoo`8000Uoo`8004aoo`004goo00<007ooOol0:Woo00<007oo000027oo0P00FWoo00<007oo
000027oo00<007oo0000FWoo0P002Goo0P00C7oo000COol00`00Oomoo`0ZOol00`00Ool00008Ool2
001JOol00`00Ool00008Ool00`00Ool0001JOol20009Ool2001<Ool001=oo`03001oogoo02Yoo`03
001oo`0000Qoo`8005Yoo`03001oo`0000Qoo`03001oo`0005Yoo`8000Uoo`8004aoo`004goo00<0
07ooOol0:Woo0P002Goo0P00FWoo00<007oo000027oo00<007oo0000FWoo0P002Goo0P00C7oo000C
Ool00`00Oomoo`0ZOol2000:Ool00`00Oomoo`1IOol20008Ool2001KOol20009Ool2001<Ool001=o
o`03001oogoo02]oo`03001oogoo00Qoo`03001oogoo05Uoo`03001oogoo00Qoo`03001oogoo05Uo
o`8000Uoo`03001oogoo04]oo`004goo00<007ooOol0:goo00<007ooOol027oo00<007ooOol0FGoo
00<007ooOol027oo00<007ooOol0FGoo0P002Goo00<007ooOol0Bgoo0008Ool50006Ool00`00Oomo
o`0[Ool00`00Oomoo`08Ool00`00Oomoo`1IOol00`00Oomoo`08Ool00`00Oomoo`1IOol00`00Oomo
o`08Ool00`00Oomoo`1;Ool000Uoo`04001oogoo0006Ool00`00Oomoo`2MOol00`00Oomoo`2bOol0
00Yoo`03001oogoo00Ioo`<00?mooe=oo`002goo00<007ooOol01Goo00<007ooOol0ogooDgoo000<
Ool00`00Oomoo`04Ool00`00Oomoo`3oOomCOol000aoo`03001oogoo00Aoo`03001oogoo0?mooe=o
o`0027oo00D007ooOomoo`0000Ioo`03001oogoo0?mooe=oo`002Goo0`00ogooGGoo003oOomYOol0
0?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-11, -2, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "Oscillations grow for a time, then decay due to the interference between \
the two cosine functions. The smaller the frequency difference between the \
two cosine oscillations, the longer the beats become. (Try changing the \
frequency difference ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Epsilon]\)\(\ \)\)\)]],
  "in ",
  ButtonBox["Cell 1.85",
    ButtonData:>"Cell 1.85",
    ButtonStyle->"Hyperlink"],
  ".) Finally, in the limit as the difference ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\  \[Rule] \ \ 0\)]],
  ", the length of time between beats goes to infinity, and the initial \
linear growth in amplitude of the oscillation continues indefinitely; the \
oscillation grows without bound.  To see this from Eq. ",
  ButtonBox["(1.6.47)",
    ButtonData:>"(1.6.47)",
    ButtonStyle->"Hyperlink"],
  " mathematically, we can take a limit (see ",
  ButtonBox["Cell 1.86",
    ButtonData:>"Cell 1.86",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[\(f\_o\/\(2 \( \[Omega]\_o\) \[Epsilon]\  - \ \[Epsilon]\^2\)\) \
\((Cos[\((\[Omega]\_o - \[Epsilon])\) t] - 
            Cos[\[Omega]\_o\ t])\), \[Epsilon] \[Rule] 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 1.86"],

Cell[BoxData[
    \(\(t\ Sin[t\ \[Omega]\_o]\ f\_o\)\/\(2\ \[Omega]\_o\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This limit reproduces the linear amplitude growth observed in the general \
solution of the undamped oscillator found previously using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe examples we have seen so far in this section have all involved \
simple forcing functions. In the next chapter we will learn how to deal with \
general ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", and in the process develop an understanding of Fourier series and \
integrals. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 1.6", "Subsubtitle",
  CellTags->{"Ex. 1.6", "c:47"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " In the introduction to Sec. ",
  ButtonBox["1.6.1",
    ButtonData:>"c:34",
    ButtonStyle->"Hyperlink"],
  ", we presented an operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) 
          f = \[ExponentialE]\^\(\[DifferentialD]f/\[DifferentialD]t\)\)]],
  ",  as an example of a nonlinear operator. On the other hand, consider the \
operator defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) 
          f = \(\[ExponentialE]\^\(\[DifferentialD]\(\(/\)\(\[DifferentialD]t\
\)\)\)\) f\)]],
  ". Here, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[ExponentialE]\^\(\[DifferentialD]\(\(/\)\(\[DifferentialD]\
t\)\)\)\), "=", 
          RowBox[{
            RowBox[{
              RowBox[{"1", "+", 
                FormBox[\(\[DifferentialD]\/\[DifferentialD]t\),
                  "TraditionalForm"], 
                "+", \(\(1\/\(2!\)\) \
\((\[DifferentialD]\/\[DifferentialD]t)\)\^2\), 
                "+", \(\(1\/\(3!\)\) \
\((\[DifferentialD]\/\[DifferentialD]t)\)\^3\), " ", "+"}], "..."}], " ", 
            "."}]}], TraditionalForm]]],
  "  Is this operator linear or nonlinear? Find and plot the action of both \
operators on ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = sin\ t\)]],
  ", on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2  \[Pi]\)]],
  " . (Hint: The infinite series can be summed analytically.)"
}], "Text",
  CellTags->"i:132"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Find, by hand, a complete set of independent solutions to the following \
linear homogeneous ODEs. (You may check your results using ",
  StyleBox["Mathematica, ",
    FontSlant->"Italic"],
  "of course.):"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[DoublePrime]\)\^\[DoublePrime] + 
          2 \( x\^\[Prime]\)\^\[DoublePrime] + 3  x\^\[DoublePrime] + 
          2  x\^\[Prime] + 2  x = 0\)]],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[DoublePrime]\)\^\[DoublePrime] + 
          6 \( x\^\[Prime]\)\^\[DoublePrime] + 38  x\^\[DoublePrime] + 
          112  x\^\[Prime] + 104  x = 0\)]],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[Prime]\)\^\[DoublePrime] - 
          3  x\^\[DoublePrime] + 3  x\^\[Prime] - x = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] = 
        2 \((y - x)\) - x\^\[Prime], \ \ y\^\[DoublePrime] = 
        2 \((x - y)\) - y\^\[Prime]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Use the matrix inversion technique to solve the following ODE \
numerically:"
}], "Text"],

Cell[TextData[{
  "\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(L\&^\ v\), "=", 
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]v\), \(\[DifferentialD]t\),
                MultilineFunction->None], "+", \(t\ \(v(t)\)\)}], "=", 
            "0"}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v(0) = 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Use the Euler method form, ",
  ButtonBox["Eq. (1.6.23)",
    ButtonData:>"(1.6.23)",
    ButtonStyle->"Hyperlink"],
  ", for the finite-differenced version of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " on the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t\  = \ 0.05\)]],
  ".  Plot the solution on this time interval, and compare it with the exact \
solution found with ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " A finite-difference method for second-order ODEs was discussed in ",
  ButtonBox["Sec. 1.4",
    ButtonData:>"Sec. 1.4",
    ButtonStyle->"Hyperlink"],
  "; see Eqs. ",
  ButtonBox["(1.4.27)",
    ButtonData:>"(1.4.27)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(1.4.28)",
    ButtonData:>"(1.4.28)",
    ButtonStyle->"Hyperlink"],
  ". Using this method, finite-difference ",
  StyleBox[ButtonBox["Airy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Airy.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox["'s equation",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:106"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
              MultilineFunction->None],
            FontSize->15], "=", \(\(-t\)\ \(x(t)\)\)}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  StyleBox[" ",
    FontSlant->"Italic"],
  "with initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x(\(-1\)) = 1, \(x\^\[Prime]\)(\(-1\)) = 0\)]],
  ". Write the ODE and initial conditions as a matrix equation of the form ",
  ButtonBox["(1.6.24)",
    ButtonData:>"(1.6.24)",
    ButtonStyle->"Hyperlink"],
  ". Solve the ODE by matrix inversion, taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", "=", " ", "0.1"}], ","}], 
        TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < t < 5\)]],
  ", and plot the result along with the analytic result found from ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " For the following general first-order linear ODE, find the matrix ",
  StyleBox["L ",
    FontWeight->"Bold"],
  "that corresponds to the second-order predictor-corrector method, and write \
out the first four rows of ",
  StyleBox["L",
    FontWeight->"Bold"],
  ": "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  + \ \(\(u\_o\)(
              t)\)\ x\  = \ 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Use this matrix to solve the initial-value problem where ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_o\)(
          t)\  = \ \(\(t/\((1 + t\^2)\)\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 1\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 5\)]],
  " taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.1"}], TraditionalForm]]],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " and on the same plot, compare it with the exact solution found using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " Add the following forcing functions to the right-hand side of the \
problems listed in Exercise (2), and solve for a particular solution by hand \
using the method of undetermined coefficients. (You can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to help with the algebra, and to check your answers.):"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ sin(t)\)]],
  " to Exercise (2)(a) and (b)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{\(f(t)\), " ", "=", " ", 
            FormBox[\(t\^3\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  " to Exercise (2)(c)"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] = 2 \((y - x)\) - x\^\[Prime]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[DoublePrime] = 2 \((x - y)\) + cos\ 2  t\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)(a)",
    FontWeight->"Bold"],
  " Find the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  " between two parallel conducting plates located at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ". The potential on the left plate is ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)]],
  ", and that on the right plate is ",
  Cell[BoxData[
      \(TraditionalForm\`V\_2\)]],
  ". There is a charge density between the plates of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \(\[Rho]\_o\) cos\ k\ x\)]],
  ". The potential satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]/\[DifferentialD]x\^2 = \
\(-\[Rho]\)/\[Epsilon]\_o\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Discuss the behavior of the answer from part a)  for the case of constant \
charge density, ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Consider an ",
  StyleBox["LRC",
    FontSlant->"Italic"],
  " circuit driven by an oscillating voltage ",
  Cell[BoxData[
      \(TraditionalForm\`V(t)\  = \ V\_o\ cos\[Omega]t\)]],
  ".  The charge on the capacitor satisfies Eq. ",
  ButtonBox["(1.3.2)",
    ButtonData:>"(1.3.2)",
    ButtonStyle->"Hyperlink"],
  ". The homogeneous solution was found in ",
  ButtonBox["Sec. 1.3",
    ButtonData:>"Ex. 1.3",
    ButtonStyle->"Hyperlink"],
  ", Exercise (3)."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find a particular solution using the method of complex exponentials, ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t) = 
        Re(C\ \[ExponentialE]\^\(\(-i\)\ \[Omega]\ t\))\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " For ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\  = \ 1\)]],
  " Volt, ",
  Cell[BoxData[
      \(TraditionalForm\`R\  = \ 2\)]],
  " ohms, ",
  Cell[BoxData[
      \(TraditionalForm\`C\  = \ 100\)]],
  " pico-farads and ",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ 2\ \[Times]\ 10\^\(-3\)\)]],
  " Henry, find the resonant frequency of the circuit. Plot the amplitude",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(|\)\(C\)\(|\)\)\)\)]],
  " and phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "of the particular solution vs. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " over a range of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "from zero to twice the resonant frequency."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " A damped linear oscillator has mass ",
  StyleBox["m",
    FontSlant->"Italic"],
  " and has a Hooke's law force constant ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "and a linear damping",
  StyleBox[" ",
    FontSlant->"Italic"],
  "force of the form",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`F\_d\  = \ \(-m\)\ \[Gamma]\ \(v(t)\)\)]],
  ". The oscillator is driven by an external periodic force of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(F\_ext\)(t)\  = \ 
        F\_o\ \(\(sin\[Omega]t\)\(.\)\(\ \)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find a particular solution in complex exponential form, ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t) = 
        Re(C\ \[ExponentialE]\^\(\(-i\)\ \[Omega]\ t\))\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The rate of work done by the external force on the mass is ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]W\_ext/\[DifferentialD]t = \
\(\(F\_ext\)(t)\) \(v(t)\)\)]],
  " . Using the particular solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(v\_p\)(t)\)\(\ \)\)\)]],
  "from part (a), find a (time-independent) expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[LeftAngleBracket]\[DifferentialD]W\_ext/\
\[DifferentialD]t\[RightAngleBracket]\)\(,\)\)\)]],
  " the average rate of work done on the mass, averaged over an oscillation \
period ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/\[Omega]\)]],
  ".  .\n",
  StyleBox["Hint: Be careful! When evaluating the work the real solution for \
",
    FontColor->RGBColor[0, 0, 0.00389105]],
  Cell[BoxData[
      \(TraditionalForm\`\(v\_p\)(t)\)]],
  StyleBox[" must be used. Use ",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[" to help do the required time integration over a period of the \
oscillatio",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox["n.",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.00389105]],
  StyleBox[")",
    FontColor->RGBColor[0, 0, 0.00389105]]
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " According to part (b) work is being done on the mass by the external \
force, but according to part (a) its amplitude of oscillation is not \
increasing.  Where is the energy going?"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Work is done by the damping force ",
  Cell[BoxData[
      \(TraditionalForm\`F\_d\)]],
  " on the mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " at the rate",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[DifferentialD]W\_d/\[DifferentialD]t = \
\(\(F\_d\)(t)\) \(v(t)\)\)\)\)]],
  ". The work is negative, indicating that energy flows from the mass into \
the damper. What happens to this energy? Using the particular solution from \
part (a) for ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(t), show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"<", \(\[DifferentialD]W\_d/\[DifferentialD]t\), ">", " ", 
            RowBox[{"+", " ", 
              
              FormBox[\(\(\(<\)\(\[DifferentialD]W\_ext/\[DifferentialD]t\)\(>\
\)\)\  = 0\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Find the length of time between beats in the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"cos", "[", 
            RowBox[{
              RowBox[{"(", 
                FormBox[\(\[Omega]\_o - \[Epsilon]\),
                  "TraditionalForm"], ")"}], " ", "t"}], "]"}], " ", "-", " ",
           
          RowBox[{"cos", 
            FormBox[\(\[Omega]\_o\),
              "TraditionalForm"], "t"}]}], TraditionalForm]]],
  "  (i.e. the time between maxima in the envelope of the oscillation.) Show \
that this time goes to infinity as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] \[Rule] \ \(\(0\)\(\ \)\(.\)\)\)]],
  " (Hint: Write this combination as the real part of complex exponential \
functions, and go on from there.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " Show that the response of a damped oscillator to a  harmonic driving \
force at frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ", Eq. ",
  ButtonBox["(1.6.45)",
    ButtonData:>"(1.6.45)",
    ButtonStyle->"Hyperlink"],
  ",  has a maximum amplitude of oscillation when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \@\(\[Omega]\_o\%2 - \[Gamma]\^2/2\)\)]],
  ". "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->{"refs", "c:48"}],

Cell[TextData[{
  "W. E. Boyce and R. C. DiPrima, ",
  StyleBox["Elementary Differential Equations",
    FontSlant->"Italic"],
  " (John Wiley and Sons, New York, 1969)."
}], "Text"],

Cell[TextData[{
  "G.W. Marcy and R. P. Butler, ",
  StyleBox["Detection of extrasolar giant planets",
    FontSlant->"Italic"],
  ", Ann. Rev. Astron. and Astroph. ",
  StyleBox["36",
    FontWeight->"Bold"],
  ", 57 (1998)."
}], "Text"],

Cell[TextData[{
  "W. H. Press, S. A. Teukolsky , W. T. Vetterling, and B. P. Flannery, ",
  StyleBox["Numerical Recipes",
    FontSlant->"Italic"],
  " (Cambridge University Press,  Cambridge, 1986)."
}], "Text"],

Cell[TextData[{
  "E. Ott, ",
  StyleBox["Chaos in Dynamical Systems",
    FontSlant->"Italic"],
  " (Cambridge University Press, Cambridge, 1993)."
}], "Text"],

Cell[TextData[{
  " A. J. Lichtenberg and M. A. Lieberman, ",
  StyleBox["Regular and Chaotic Dynamics, ",
    FontSlant->"Italic"],
  "2nd ed",
  StyleBox[".",
    FontSlant->"Italic"],
  " (Springer-Verlag, New York, 1992).",
  StyleBox[" ",
    FontSlant->"Italic"]
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 1, Section 1.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 148, "IndexEntries" -> {{"i:1", \
"Differential equations"}, {"i:102", "Strange attractors"}, {"i:104", \
"Damping rate"}, {"i:104", "Forcing"}, {"i:107", "Poincar\[EAcute], Jules \
Henri"}, {"i:107", "Poincar\[EAcute] plot"}, {"i:110", "Damping rate"}, \
{"i:111", 
  StyleBox[ "AccuracyGoal", FontWeight -> "Bold"]}, {"i:111", 
  StyleBox[ 
  "PrecisionGoal", FontWeight -> 
    "Bold"]}, {"i:113", "Fixed points"}, {"i:114", "Fixed points"}, {"i:117", \
"Superposition principle"}, {"i:118", "Superposition principle"}, {"i:119", \
"Superposition principle"}, {"i:12", "Boundary value problems"}, {"i:120", \
"Boundary conditions"}, {"i:121", "Boundary conditions"}, {"i:122", "Boundary \
conditions"}, {"i:123", "Boundary conditions"}, {"i:127", "Einstein, \
Albert"}, {"i:128", "Einstein, Albert"}, {"i:129", "Strange attractors"}, \
{"i:131", "Differential operators"}, {"i:133", {
  StyleBox[ "AiryAi[x]", FontWeight -> "Bold"], " and ", 
  StyleBox[ "AiryBi[x]", FontWeight -> "Bold"]}}, {"i:134", 
  StyleBox[ 
  "KroneckerDelta", FontWeight -> 
    "Bold"]}, {"i:136", "\[Element] (element of)"}, {"i:137", "cyclotron \
radius"}, {"i:139", "Step size"}, {"i:14", "Initial value problems"}, \
{"i:140", "Timestep"}, {"i:141", "Beats"}, {"i:143", "Implicit methods"}, \
{"i:147", "$DisplayFunction"}, {"i:15", "Direction field"}, {"i:18", 
  StyleBox[ 
  "PlotVectorField", FontWeight -> 
    "Bold"]}, {"i:2", "Liebniz, Gottfried"}, {"i:2", "Newton, Sir Isaac"}, \
{"i:20", "Phase space"}, {"i:22", "Hamiltonian"}, {"i:22", "Hamilton, Sir \
William"}, {"i:22", "Momentum"}, {"i:23", "Energy"}, {"i:27", "Lyapunov, \
Aleksandr"}, {"i:27", "Lyapunov exponent"}, {"i:28", "Lyapunov exponent"}, \
{"i:30", 
  StyleBox[ 
  "DSolve", FontWeight -> 
    "Bold"]}, {"i:32", "Airy, George B."}, {"i:34", "Eccentricity"}, {"i:34", \
"Perihelion"}, {"i:4", "Velocity"}, {"i:40", 
  StyleBox[ "NDSolve", FontWeight -> "Bold"]}, {"i:41", 
  StyleBox[ 
  "InterpolatingFunction", FontWeight -> 
    "Bold"]}, {"i:42", "Numerical solution of ordinary differential \
equations"}, {"i:43", "Shooting method"}, {"i:47", "Euler, Leonhard"}, \
{"i:5", "Ordinary differential equations"}, {"i:51", 
  StyleBox[ 
  "Module", FontWeight -> 
    "Bold"]}, {"i:54", "Molecular dynamics"}, {"i:58", "Lyapunov exponent"}, \
{"i:59", "Lyapunov exponent"}, {"i:6", "Poisson, Simeon Denis"}, {"i:60", \
"Strange attractors"}, {"i:62", "Lyapunov exponent"}, {"i:65", "Leapfrog \
method"}, {"i:7", "Partial differential equations"}, {"i:72", "Penning \
trap"}, {"i:75", "Molecular dynamics"}, {"i:76", "Molecular dynamics"}, \
{"i:77", "Molecular dynamics"}, {"i:78", "Energy"}, {"i:79", "Boundary value \
problems"}, {"i:8", {"Laplacian operator ( ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], ")"}}, {"i:81", "Linear ODEs"}, {"i:82", \
"Superposition principle"}, {"i:9", "Hooke, Robert"}, {"i:94", "Forcing"}, \
{"i:10", "Differential equations", "general solution"}, {"i:10", "Ordinary \
differential equations", "harmonic oscillator equation"}, {"i:101", "Linear \
ODEs", "discretized form as a matrix equation"}, {"i:102", "Ordinary \
differential equations", "Van der Pol oscillator"}, {"i:105", "Numerical \
solution of ordinary differential equations", "matrix method, for linear \
ODEs"}, {"i:106", "Ordinary differential equations", "Airy equation"}, \
{"i:108", "Hamiltonian", "pendulum"}, {"i:11", "Ordinary differential \
equations", "order"}, {"i:111", 
  StyleBox[ 
  "NDSolve", FontWeight -> "Bold"], {"improving the solution accuracy (", 
  StyleBox[ "AccuracyGoal", FontWeight -> "Bold"], ", ", 
  StyleBox[ 
  "PrecisionGoal", FontWeight -> 
    "Bold"], ")"}}, {"i:115", "Equilibrium", {"chemical, for disociation of \
", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SubscriptBox[ "H", "2"], 
        TraditionalForm]]]}}, {"i:116", "Boundary value problems", {"matrix \
inverse method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Green's functions)"}}, {"i:124", "Recursion relation", {"used \
to solve ODEs (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Euler's method, numerical solution of ODEs)"}}, {"i:13", \
"Differential equations", "general solution"}, {"i:130", "Differential \
operators", "linear"}, {"i:135", "Frequency", "cyclotron"}, {"i:138", \
"Recursion relation", "definition"}, {"i:14", "Differential equations", \
"graphical solution"}, {"i:142", "Variables", "internal"}, {"i:144", \
"Planets", "extrasolar"}, {"i:145", "planets", "orbits"}, {"i:146", "Planet", \
"orbits"}, {"i:16", "Ordinary differential equations", "existence and \
uniqueness of solutions for IVP's"}, {"i:17", "Boundary value problems", \
"existence and uniqueness of solution"}, {"i:17", "Ordinary differential \
equations", "existence and uniqueness of solutions for BVP's"}, {"i:20", \
"Ordinary differential equations", "phase space"}, {"i:24", "Ordinary \
differential equations", "integrable"}, {"i:25", "Ordinary differential \
equations", "damped harmonic oscillator"}, {"i:27", "Numerical solution of \
ordinary differential equations", "error"}, {"i:29", "Ordinary differential \
equations", "harmonic oscillator equation"}, {"i:31", "Ordinary differential \
equations", "Airy equation"}, {"i:35", "Field lines", "from a point dipole"}, \
{"i:36", "Field lines", "differential equation"}, {"i:37", "Ordinary \
differential equations", "pendulum"}, {"i:39", "Angular momentum", \
"specific"}, {"i:40", "Numerical solution of ordinary differential \
equations", 
  StyleBox[ 
  "NDSolve", FontWeight -> 
    "Bold"]}, {"i:42", "Ordinary differential equations", {"numerical \
solution (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ordinary differential equations)"}}, \
{"i:43", "Ordinary differential equations", {"numerical solution (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ordinary differential equations)"}}, \
{"i:44", "Ordinary differential equations", {"numerical solution (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ordinary differential equations)"}}, \
{"i:45", "Numerical solution of ordinary differential equations", "error"}, \
{"i:48", "Numerical solution of ordinary differential equations", "order of a \
numerical method"}, {"i:49", "Numerical solution of ordinary differential \
equations", "predictor-corrector method"}, {"i:50", "Ordinary differential \
equations", "driven pendulum"}, {"i:53", "Numerical solution of ordinary \
differential equations", "Runga-Kutta method"}, {"i:57", "Field lines", "for \
TE modes in a cubic cavity"}, {"i:61", "Ordinary differential equations", \
"Lorenz system"}, {"i:64", "Numerical solution of ordinary differential \
equations", "centered-difference method"}, {"i:65", "Numerical solution of \
ordinary differential equations", "leapfrog method"}, {"i:66", "Numerical \
solution of ordinary differential equations", "Adams-Bashforth method"}, \
{"i:67", "Momentum", "total linear"}, {"i:68", "Angular momentum", "total"}, \
{"i:69", "Velocity", "center of mass"}, {"i:70", "Velocity", "as rate of \
change of position"}, {"i:71", "equilibrium ", "configuration of a \
molecule"}, {"i:72", "Molecular dynamics", "for charged particles in a \
Penning trap"}, {"i:73", "Molecular dynamics", "of an elastic rod"}, {"i:74", \
"Molecular dynamics", "to determine molecular configuration"}, {"i:78", \
"Hamiltonian", "for system of interacting paticles"}, {"i:82", "Linear ODEs", \
"superposition principle"}, {"i:84", "Linear ODEs", "general solution"}, \
{"i:87", "Linear ODEs", "homogeneous solution"}, {"i:88", "Linear ODEs", \
"particular solution"}, {"i:89", "Linear ODEs", "with constant coefficients, \
independent homogeneous solutions"}, {"i:90", "Linear ODEs", "degenerate \
homogeneous solutions"}, {"i:91", "Ordinary differential equations", "damped \
harmonic oscillator"}, {"i:92", "Linear ODEs", "damped hamonic oscillator, \
homogeneous solution"}, {"i:93", "Linear ODEs", "particular solution"}, \
{"i:94", "Linear ODEs", "method of undetermined coefficients"}, {"i:95", \
"Linear ODEs", "particular solution"}, {"i:96", "Linear ODEs", "resonance"}, \
{"i:97", "Linear ODEs", "exact resonance"}, {"i:1", "Equations", \
{"differential (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Differential equations)"}, ""}, {"i:10", {"Harmonic oscillator \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Ordinary differential equations, Linear ODEs)"}, "", ""}, \
{"i:100", "Delta function", "Kronecker", ""}, {"i:103", "Forcing", \
"sinusoidal", ""}, {"i:109", "Damping rate", "", ""}, {"i:112", {"Chaotic \
systems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Ordinary differential equations, Lyapunov exponent)"}, "", \
""}, {"i:12", "Differential equations", {"boundary conditions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Boundary value problems, Boundary conditions)"}, ""}, \
{"i:12", {"Initial value problems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Differential equations)"}, "", ""}, {"i:124", {"Euler's method \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:125", {"Euler's \
method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:126", {"Euler's \
method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:132", \
"Differential operators", "nonlinear", ""}, {"i:133", "Airy functions", "", \
""}, {"i:16", {"Initial value problems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Differential equations)"}, "existence and uniqueness of \
solution", ""}, {"i:21", "Ordinary differential equations", {"Hamiltonian \
systems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Hamiltonian)"}, ""}, {"i:26", "Ordinary differential \
equations", {"chaotic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Chaotic systems)"}, ""}, {"i:26", {"Chaotic systems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Ordinary differential equations, Lyapunov exponent)"}, "", \
""}, {"i:3", "Differential equations", "initial conditions", ""}, {"i:33", \
"Ordinary differential equations", {"chaotic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Chaotic systems)"}, ""}, {"i:33", {"Chaotic systems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Ordinary differential equations, Lyapunov exponent)"}, "", \
""}, {"i:36", "Ordinary differential equations", {"for field lines (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Field lines)"}, ""}, {"i:38", "Ordinary differential \
equations", "Van der Pol oscillator", ""}, {"i:4", "Function(s)", "unknown", \
""}, {"i:43", "Boundary value problems", {"shooting method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Shooting method)"}, ""}, {"i:43", "Numerical solution of \
ordinary differential equations", {"shooting method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Shooting method)"}, ""}, {"i:46", "Numerical solution of \
ordinary differential equations", {"Euler's method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Euler's method)"}, ""}, {"i:46", {"Euler's method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:49", {"Predictor \
corrector method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:5", "Differential \
equations", {"ordinary (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Ordinary differential equations)"}, ""}, {"i:52", {"Euler's \
method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "for systems of ODEs", ""}, \
{"i:54", "Numerical solution of ordinary differential equations", {"molecular \
dynamics method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Molecular dynamics)"}, ""}, {"i:55", "Ordinary differential \
equations", "Van der Pol oscillator", ""}, {"i:56", "Perihelion", "precession \
of Mercury's", ""}, {"i:6", "Differential equations", {"ordinary (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Ordinary differential equations)"}, ""}, {"i:6", "Differential \
equations", {"partial (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Partial differential equations)"}, ""}, {"i:6", "Partial \
differential equations", {"Poisson's equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Poisson's equation)"}, ""}, {"i:63", "Field lines", "chaotic \
magnetic field", ""}, {"i:66", {"Adams-Bashforth method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:71", "Potential", \
"Lennard-Jones", ""}, {"i:79", "Differential equations", {"boundary \
conditions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Boundary value problems and boundary conditions)"}, ""}, \
{"i:80", "Eigenvalue problem", "", ""}, {"i:81", "Ordinary differential \
equations", {"linear (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Linear ODEs)"}, ""}, {"i:83", "Linear ODEs", {"linear \
operators (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Differential operators)"}, ""}, {"i:85", "Linear ODEs", \
"homogeneous ODEs", ""}, {"i:86", "Linear ODEs", "inhomogeneous ODEs", ""}, \
{"i:91", "Linear ODEs", "damped harmonic oscillator equation", ""}, {"i:91", \
{"Harmonic oscillator (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Ordinary differential equations, Linear ODEs)"}, "damped", \
""}, {"i:99", "Differential operators", "matrix form by finite-differencing", \
""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(1.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(1.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(1.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(1.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(1.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE6"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(1.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE6"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE6", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "chapter 2"->{
    Cell[1727, 52, 117, 1, 111, "Title",
      CellTags->{"chapter 2", "i:5", "c:1"}]},
  "i:5"->{
    Cell[1727, 52, 117, 1, 111, "Title",
      CellTags->{"chapter 2", "i:5", "c:1"}]},
  "c:1"->{
    Cell[1727, 52, 117, 1, 111, "Title",
      CellTags->{"chapter 2", "i:5", "c:1"}]},
  "Sec. 1.1"->{
    Cell[1888, 59, 69, 1, 39, "Subtitle",
      CellTags->{"Sec. 1.1", "c:2"}]},
  "c:2"->{
    Cell[1888, 59, 69, 1, 39, "Subtitle",
      CellTags->{"Sec. 1.1", "c:2"}]},
  "c:3"->{
    Cell[2002, 66, 59, 1, 41, "Subsubtitle",
      CellTags->"c:3"]},
  "i:1"->{
    Cell[2086, 71, 122, 4, 42, "Section",
      CellTags->{"i:1", "c:4"}]},
  "c:4"->{
    Cell[2086, 71, 122, 4, 42, "Section",
      CellTags->{"i:1", "c:4"}]},
  "i:2"->{
    Cell[2211, 77, 887, 24, 78, "Text",
      CellTags->"i:2"]},
  "i:4"->{
    Cell[3101, 103, 1465, 50, 78, "Text",
      CellTags->"i:4"]},
  "(1.1.1)"->{
    Cell[4569, 155, 173, 3, 27, "NumberedEquation",
      CellTags->"(1.1.1)"]},
  "(1.1.2)"->{
    Cell[5928, 203, 206, 6, 39, "NumberedEquation",
      CellTags->"(1.1.2)"]},
  "(1.1.3)"->{
    Cell[6875, 239, 552, 16, 38, "NumberedEquation",
      CellTags->"(1.1.3)"]},
  "i:3"->{
    Cell[7430, 257, 2087, 64, 112, "Text",
      CellTags->"i:3"]},
  "i:13"->{
    Cell[9799, 331, 1356, 47, 61, "Text",
      CellTags->"i:13"]},
  "i:9"->{
    Cell[11158, 380, 994, 35, 44, "Text",
      CellTags->"i:9"]},
  "(1.1.4)"->{
    Cell[12155, 417, 902, 37, 29, "NumberedEquation",
      CellTags->"(1.1.4)"]},
  "(1.1.5)"->{
    Cell[13444, 470, 448, 15, 29, "NumberedEquation",
      CellTags->{"(1.1.5)", "i:70"}]},
  "i:70"->{
    Cell[13444, 470, 448, 15, 29, "NumberedEquation",
      CellTags->{"(1.1.5)", "i:70"}]},
  "(1.1.6)"->{
    Cell[14472, 510, 318, 10, 42, "NumberedEquation",
      CellTags->"(1.1.6)"]},
  "i:10"->{
    Cell[14793, 522, 988, 36, 44, "Text",
      CellTags->"i:10"]},
  "(1.1.7)"->{
    Cell[15784, 560, 204, 7, 29, "NumberedEquation",
      CellTags->"(1.1.7)"]},
  "(1.1.8)"->{
    Cell[16389, 582, 649, 26, 29, "NumberedEquation",
      CellTags->"(1.1.8)"]},
  "(1.1.9)"->{
    Cell[17874, 641, 231, 7, 39, "NumberedEquation",
      CellTags->"(1.1.9)"]},
  "Cell 1.1"->{
    Cell[18488, 665, 292, 7, 86, "Input",
      CellTags->"Cell 1.1"]},
  "Cell 1.2"->{
    Cell[19017, 685, 83, 3, 67, "Input",
      CellTags->"Cell 1.2"]},
  "Cell 1.3"->{
    Cell[19176, 696, 88, 3, 67, "Input",
      CellTags->"Cell 1.3"]},
  "c:5"->{
    Cell[19352, 708, 70, 1, 31, "Section",
      CellTags->"c:5"]},
  "i:11"->{
    Cell[19425, 711, 1897, 68, 61, "Text",
      CellTags->"i:11"]},
  "i:7"->{
    Cell[23269, 849, 77, 1, 31, "Section",
      CellTags->{"i:7", "c:6"}]},
  "c:6"->{
    Cell[23269, 849, 77, 1, 31, "Section",
      CellTags->{"i:7", "c:6"}]},
  "i:6"->{
    Cell[23349, 852, 1440, 50, 112, "Text",
      CellTags->"i:6"]},
  "(1.1.10)"->{
    Cell[24792, 904, 213, 4, 42, "NumberedEquation",
      CellTags->"(1.1.10)"]},
  "i:8"->{
    Cell[25008, 910, 789, 27, 47, "Text",
      CellTags->"i:8"]},
  "(1.1.11)"->{
    Cell[25800, 939, 542, 14, 45, "NumberedEquation",
      CellTags->"(1.1.11)"]},
  "i:123"->{
    Cell[26523, 962, 517, 12, 78, "Text",
      CellTags->"i:123"]},
  "c:7"->{
    Cell[27762, 998, 79, 1, 31, "Section",
      CellTags->"c:7"]},
  "i:12"->{
    Cell[27844, 1001, 847, 28, 78, "Text",
      CellTags->"i:12"]},
  "i:121"->{
    Cell[29615, 1059, 596, 14, 98, "Text",
      CellTags->"i:121"]},
  "Ex. 1.1"->{
    Cell[30260, 1079, 124, 2, 30, "Subsubtitle",
      CellTags->{"Ex. 1.1", "c:8"}]},
  "c:8"->{
    Cell[30260, 1079, 124, 2, 30, "Subsubtitle",
      CellTags->{"Ex. 1.1", "c:8"}]},
  "Sec. 1.2"->{
    Cell[35414, 1257, 109, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.2", "i:14", "c:9"}]},
  "i:14"->{
    Cell[35414, 1257, 109, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.2", "i:14", "c:9"}]},
  "c:9"->{
    Cell[35414, 1257, 109, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.2", "i:14", "c:9"}]},
  "c:10"->{
    Cell[35567, 1264, 114, 4, 41, "Subsubtitle",
      CellTags->"c:10"]},
  "(1.2.1)"->{
    Cell[36010, 1280, 5963, 137, 223, "NE2",
      CellTags->{"(1.2.1)", "i:16"}]},
  "i:16"->{
    Cell[36010, 1280, 5963, 137, 223, "NE2",
      CellTags->{"(1.2.1)", "i:16"}]},
  "(1.2.2)"->{
    Cell[42463, 1434, 249, 8, 38, "NE2",
      CellTags->"(1.2.2)"]},
  "Fig. 1.1"->{
    Cell[87274, 2027, 331, 17, 16, "Caption",
      CellTags->"Fig. 1.1"]},
  "(1.2.3)"->{
    Cell[87664, 2048, 259, 7, 38, "NE2",
      CellTags->"(1.2.3)"]},
  "i:15"->{
    Cell[87926, 2057, 897, 27, 78, "Text",
      CellTags->"i:15"]},
  "Fig. 1.2"->{
    Cell[220415, 5144, 269, 12, 16, "Caption",
      CellTags->"Fig. 1.2"]},
  "(1.2.4)"->{
    Cell[221274, 5174, 160, 6, 29, "NE2",
      CellTags->"(1.2.4)"]},
  "i:18"->{
    Cell[222249, 5210, 277, 11, 27, "Text",
      CellTags->"i:18"]},
  "Cell 1.4"->{
    Cell[222771, 5234, 91, 3, 67, "Input",
      CellTags->"Cell 1.4"]},
  "Cell 1.5"->{
    Cell[222865, 5239, 295, 6, 105, "Input",
      CellTags->"Cell 1.5"]},
  "(1.2.5)"->{
    Cell[223852, 5270, 144, 5, 31, "NE2",
      CellTags->"(1.2.5)"]},
  "(1.2.6)"->{
    Cell[225537, 5327, 115, 5, 29, "NE2",
      CellTags->"(1.2.6)"]},
  "(1.2.7)"->{
    Cell[225994, 5349, 113, 5, 29, "NE2",
      CellTags->"(1.2.7)"]},
  "Fig. 1.3"->{
    Cell[343716, 8102, 293, 9, 16, "Caption",
      CellTags->"Fig. 1.3"]},
  "c:11"->{
    Cell[344046, 8116, 120, 4, 30, "Subsubtitle",
      CellTags->"c:11"]},
  "i:20"->{
    Cell[344191, 8124, 60, 1, 42, "Section",
      CellTags->{"i:20", "c:12"}]},
  "c:12"->{
    Cell[344191, 8124, 60, 1, 42, "Section",
      CellTags->{"i:20", "c:12"}]},
  "(1.2.8)"->{
    Cell[344707, 8138, 427, 12, 42, "NE2",
      CellTags->"(1.2.8)"]},
  "i:25"->{
    Cell[345137, 8152, 973, 33, 78, "Text",
      CellTags->"i:25"]},
  "(1.2.9)"->{
    Cell[346113, 8187, 148, 5, 32, "NE2",
      CellTags->"(1.2.9)"]},
  "i:109"->{
    Cell[346264, 8194, 248, 9, 27, "Text",
      CellTags->"i:109"]},
  "(1.2.10)"->{
    Cell[347321, 8232, 305, 5, 38, "NE2",
      CellTags->"(1.2.10)"]},
  "Fig. 1.4"->{
    Cell[445887, 9495, 286, 10, 16, "Caption",
      CellTags->"Fig. 1.4"]},
  "i:114"->{
    Cell[447254, 9540, 721, 20, 78, "Text",
      CellTags->"i:114"]},
  "Cell 1.6"->{
    Cell[448000, 9564, 341, 7, 124, "Input",
      CellTags->"Cell 1.6"]},
  "c:13"->{
    Cell[539213, 11956, 71, 1, 31, "Section",
      CellTags->"c:13"]},
  "Fig. 1.5"->{
    Cell[615595, 12913, 306, 14, 16, "Caption",
      CellTags->"Fig. 1.5"]},
  "(1.2.11)"->{
    Cell[616799, 12952, 621, 17, 69, "NE2",
      CellTags->"(1.2.11)"]},
  "(1.2.12)"->{
    Cell[618710, 13013, 935, 26, 44, "NE2",
      CellTags->"(1.2.12)"]},
  "(1.2.13)"->{
    Cell[621952, 13116, 1062, 29, 34, "NE2",
      CellTags->"(1.2.13)"]},
  "Fig. 1.6"->{
    Cell[2143416, 34201, 407, 16, 16, "Caption",
      CellTags->"Fig. 1.6"]},
  "(1.2.14)"->{
    Cell[2144757, 34254, 793, 22, 41, "NE2",
      CellTags->"(1.2.14)"]},
  "i:113"->{
    Cell[2145612, 34280, 600, 12, 78, "Text",
      CellTags->"i:113"]},
  "Fig. 1.7"->{
    Cell[2286486, 37533, 345, 15, 16, "Caption",
      CellTags->"Fig. 1.7"]},
  "c:14"->{
    Cell[2286868, 37553, 58, 1, 31, "Section",
      CellTags->"c:14"]},
  "i:21"->{
    Cell[2286929, 37556, 295, 7, 44, "Text",
      CellTags->"i:21"]},
  "(1.2.15)"->{
    Cell[2287227, 37565, 715, 20, 86, "NE2",
      CellTags->"(1.2.15)"]},
  "i:22"->{
    Cell[2287945, 37587, 703, 26, 44, "Text",
      CellTags->"i:22"]},
  "(1.2.16)"->{
    Cell[2288651, 37615, 947, 25, 46, "NE2",
      CellTags->"(1.2.16)"]},
  "i:23"->{
    Cell[2289601, 37642, 343, 11, 44, "Text",
      CellTags->"i:23"]},
  "(1.2.17)"->{
    Cell[2289947, 37655, 316, 11, 47, "NE2",
      CellTags->"(1.2.17)"]},
  "(1.2.18)"->{
    Cell[2292025, 37719, 874, 20, 41, "NE2",
      CellTags->"(1.2.18)"]},
  "i:24"->{
    Cell[2293535, 37765, 904, 26, 95, "Text",
      CellTags->"i:24"]},
  "i:112"->{
    Cell[2294442, 37793, 1218, 33, 129, "Text",
      CellTags->"i:112"]},
  "Ex. 1.2"->{
    Cell[2295709, 37832, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 1.2", "c:15"}]},
  "c:15"->{
    Cell[2295709, 37832, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 1.2", "c:15"}]},
  "(1.2.19)"->{
    Cell[2299156, 37958, 365, 11, 38, "NE2",
      CellTags->"(1.2.19)"]},
  "i:37"->{
    Cell[2299524, 37971, 1017, 33, 55, "Text",
      CellTags->"i:37"]},
  "Fig. 1.8"->{
    Cell[2392533, 39147, 68, 1, 16, "Caption",
      CellTags->"Fig. 1.8"]},
  "i:108"->{
    Cell[2394337, 39212, 378, 12, 44, "Text",
      CellTags->"i:108"]},
  "i:38"->{
    Cell[2395690, 39257, 237, 6, 44, "Text",
      CellTags->"i:38"]},
  "(1.2.20)"->{
    Cell[2395930, 39265, 166, 6, 33, "NE2",
      CellTags->"(1.2.20)"]},
  "(1.2.21)"->{
    Cell[2397778, 39330, 286, 9, 42, "NE2",
      CellTags->"(1.2.21)"]},
  "i:39"->{
    Cell[2398067, 39341, 460, 16, 46, "Text",
      CellTags->"i:39"]},
  "(1.2.22)"->{
    Cell[2398530, 39359, 126, 5, 32, "NE2",
      CellTags->"(1.2.22)"]},
  "(1.2.23)"->{
    Cell[2399000, 39378, 301, 11, 43, "NE2",
      CellTags->"(1.2.23)"]},
  "(1.2.24)"->{
    Cell[2405504, 39592, 1253, 39, 38, "NE2",
      CellTags->{"(1.2.24)", "i:36"}]},
  "i:36"->{
    Cell[2405504, 39592, 1253, 39, 38, "NE2",
      CellTags->{"(1.2.24)", "i:36"}]},
  "Sec. 1.3"->{
    Cell[2410381, 39767, 414, 15, 74, "Subtitle",
      CellTags->{"Sec. 1.3", "c:16"}]},
  "c:16"->{
    Cell[2410381, 39767, 414, 15, 74, "Subtitle",
      CellTags->{"Sec. 1.3", "c:16"}]},
  "c:17"->{
    Cell[2410839, 39788, 162, 7, 41, "Subsubtitle",
      CellTags->"c:17"]},
  "i:29"->{
    Cell[2411373, 39809, 155, 4, 27, "Text",
      CellTags->"i:29"]},
  "(1.3.1)"->{
    Cell[2411531, 39815, 171, 6, 42, "NE3",
      CellTags->"(1.3.1)"]},
  "i:30"->{
    Cell[2411911, 39832, 248, 9, 27, "Text",
      CellTags->"i:30"]},
  "Cell 1.7"->{
    Cell[2415096, 39944, 147, 4, 67, "Input",
      CellTags->"Cell 1.7"]},
  "Cell 1.8"->{
    Cell[2416829, 40014, 271, 6, 86, "Input",
      CellTags->"Cell 1.8"]},
  "Cell 1.9"->{
    Cell[2418079, 40057, 421, 9, 105, "Input",
      CellTags->"Cell 1.9"]},
  "Cell 1.10"->{
    Cell[2419626, 40100, 113, 3, 67, "Input",
      CellTags->"Cell 1.10"]},
  "i:31"->{
    Cell[2419823, 40109, 856, 27, 64, "Text",
      CellTags->"i:31"]},
  "(1.3.2)"->{
    Cell[2420682, 40138, 140, 5, 30, "NE3",
      CellTags->"(1.3.2)"]},
  "Cell 1.11"->{
    Cell[2420907, 40149, 132, 3, 67, "Input",
      CellTags->"Cell 1.11"]},
  "i:133"->{
    Cell[2421141, 40158, 1143, 38, 95, "Text",
      CellTags->"i:133"]},
  "Cell 1.12"->{
    Cell[2422309, 40200, 452, 10, 143, "Input",
      CellTags->"Cell 1.12"]},
  "Cell 1.13"->{
    Cell[2484569, 41548, 136, 3, 67, "Input",
      CellTags->"Cell 1.13"]},
  "i:32"->{
    Cell[2485545, 41577, 1114, 23, 129, "Text",
      CellTags->"i:32"]},
  "i:33"->{
    Cell[2486925, 41609, 692, 20, 86, "Text",
      CellTags->"i:33"]},
  "Table 1.1"->{
    Cell[2487620, 41631, 3740, 109, 88, "Text",
      CellTags->"Table 1.1"]},
  "Ex. 1.3"->{
    Cell[2491397, 41745, 79, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 1.3", "c:18"}]},
  "c:18"->{
    Cell[2491397, 41745, 79, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 1.3", "c:18"}]},
  "i:128"->{
    Cell[2492405, 41781, 1144, 36, 110, "Text",
      CellTags->"i:128"]},
  "(1.3.3)"->{
    Cell[2495927, 41902, 161, 6, 30, "NE3",
      CellTags->"(1.3.3)"]},
  "i:110"->{
    Cell[2497213, 41959, 595, 21, 45, "Text",
      CellTags->"i:110"]},
  "i:115"->{
    Cell[2501285, 42108, 840, 26, 63, "Text",
      CellTags->"i:115"]},
  "(1.3.4)"->{
    Cell[2503985, 42206, 1131, 35, 29, "NE3",
      CellTags->"(1.3.4)"]},
  "i:135"->{
    Cell[2505942, 42273, 795, 30, 61, "Text",
      CellTags->"i:135"]},
  "i:137"->{
    Cell[2507791, 42350, 851, 33, 61, "Text",
      CellTags->"i:137"]},
  "i:146"->{
    Cell[2508645, 42385, 530, 21, 44, "Text",
      CellTags->"i:146"]},
  "(1.3.5)"->{
    Cell[2509178, 42408, 274, 7, 42, "NE3",
      CellTags->"(1.3.5)"]},
  "i:34"->{
    Cell[2510584, 42460, 1193, 41, 97, "Text",
      CellTags->"i:34"]},
  "i:35"->{
    Cell[2511780, 42503, 875, 27, 67, "Text",
      CellTags->"i:35"]},
  "(1.3.6)"->{
    Cell[2512658, 42532, 2416, 65, 68, "NE3",
      CellTags->"(1.3.6)"]},
  "(1.3.7)"->{
    Cell[2517515, 42682, 2347, 65, 68, "NE3",
      CellTags->"(1.3.7)"]},
  "(1.3.8)"->{
    Cell[2521101, 42790, 170, 6, 33, "NE3",
      CellTags->"(1.3.8)"]},
  "Sec. 1.4"->{
    Cell[2521595, 42815, 110, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.4", "i:42", "c:19"}]},
  "i:42"->{
    Cell[2521595, 42815, 110, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.4", "i:42", "c:19"}]},
  "c:19"->{
    Cell[2521595, 42815, 110, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.4", "i:42", "c:19"}]},
  "c:20"->{
    Cell[2521749, 42822, 163, 7, 41, "Subsubtitle",
      CellTags->"c:20"]},
  "i:40"->{
    Cell[2522393, 42852, 684, 29, 27, "Text",
      CellTags->"i:40"]},
  "Cell 1.14"->{
    Cell[2523940, 42921, 176, 4, 67, "Input",
      CellTags->"Cell 1.14"]},
  "i:41"->{
    Cell[2524406, 42937, 1742, 61, 112, "Text",
      CellTags->"i:41"]},
  "Cell 1.15"->{
    Cell[2526809, 43024, 98, 3, 67, "Input",
      CellTags->"Cell 1.15"]},
  "Cell 1.16"->{
    Cell[2527272, 43046, 104, 3, 67, "Input",
      CellTags->"Cell 1.16"]},
  "i:45"->{
    Cell[2548407, 43522, 813, 20, 95, "Text",
      CellTags->"i:45"]},
  "Cell 1.17"->{
    Cell[2549245, 43546, 221, 5, 105, "Input",
      CellTags->"Cell 1.17"]},
  "Cell 1.18"->{
    Cell[2627560, 45363, 224, 6, 86, "Input",
      CellTags->"Cell 1.18"]},
  "Cell 1.19"->{
    Cell[2628096, 45383, 98, 3, 67, "Input",
      CellTags->"Cell 1.19"]},
  "Cell 1.20"->{
    Cell[2628390, 45397, 117, 3, 67, "Input",
      CellTags->"Cell 1.20"]},
  "i:111"->{
    Cell[2684370, 46517, 2262, 75, 146, "Text",
      CellTags->"i:111"]},
  "Cell 1.21"->{
    Cell[2686635, 46594, 329, 7, 105, "Input",
      CellTags->"Cell 1.21"]},
  "Cell 1.22"->{
    Cell[2687141, 46613, 123, 3, 67, "Input",
      CellTags->"Cell 1.22"]},
  "i:26"->{
    Cell[2750068, 47935, 130, 2, 30, "Subsubtitle",
      CellTags->{"i:26", "c:21"}]},
  "c:21"->{
    Cell[2750068, 47935, 130, 2, 30, "Subsubtitle",
      CellTags->{"i:26", "c:21"}]},
  "c:22"->{
    Cell[2750223, 47941, 76, 1, 42, "Section",
      CellTags->"c:22"]},
  "(1.4.1)"->{
    Cell[2750691, 47957, 246, 8, 30, "NE4",
      CellTags->{"(1.4.1)", "i:50"}]},
  "i:50"->{
    Cell[2750691, 47957, 246, 8, 30, "NE4",
      CellTags->{"(1.4.1)", "i:50"}]},
  "Fig. 1.9"->{
    Cell[2797489, 49639, 206, 5, 29, "Caption",
      CellTags->"Fig. 1.9"]},
  "i:27"->{
    Cell[2798179, 49663, 1424, 46, 95, "Text",
      CellTags->"i:27"]},
  "Fig. 1.10"->{
    Cell[2841976, 50674, 102, 1, 16, "Caption",
      CellTags->"Fig. 1.10"]},
  "i:28"->{
    Cell[2844811, 50752, 70, 1, 31, "Section",
      CellTags->{"i:28", "c:23"}]},
  "c:23"->{
    Cell[2844811, 50752, 70, 1, 31, "Section",
      CellTags->{"i:28", "c:23"}]},
  "(1.4.2)"->{
    Cell[2848581, 50905, 3482, 84, 42, "NE4",
      CellTags->"(1.4.2)"]},
  "Cell 1.23"->{
    Cell[2854859, 51087, 372, 8, 124, "Input",
      CellTags->"Cell 1.23"]},
  "Cell 1.24"->{
    Cell[2855707, 51114, 212, 5, 67, "Input",
      CellTags->"Cell 1.24"]},
  "Cell 1.25"->{
    Cell[2856245, 51132, 495, 9, 124, "Input",
      CellTags->"Cell 1.25"]},
  "Cell 1.26"->{
    Cell[2857522, 51170, 387, 8, 86, "Input",
      CellTags->"Cell 1.26"]},
  "i:46"->{
    Cell[2904063, 52501, 73, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:24"}]},
  "c:24"->{
    Cell[2904063, 52501, 73, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:24"}]},
  "i:47"->{
    Cell[2904139, 52504, 669, 17, 78, "Text",
      CellTags->"i:47"]},
  "(1.4.3)"->{
    Cell[2905014, 52533, 316, 11, 38, "NE4",
      CellTags->"(1.4.3)"]},
  "i:140"->{
    Cell[2905440, 52551, 350, 13, 44, "Text",
      CellTags->"i:140"]},
  "(1.4.4)"->{
    Cell[2905793, 52566, 399, 14, 29, "NE4",
      CellTags->"(1.4.4)"]},
  "i:139"->{
    Cell[2906195, 52582, 992, 35, 61, "Text",
      CellTags->"i:139"]},
  "(1.4.5)"->{
    Cell[2907400, 52627, 632, 19, 39, "NE4",
      CellTags->"(1.4.5)"]},
  "(1.4.6)"->{
    Cell[2908752, 52679, 797, 23, 37, "NE4",
      CellTags->"(1.4.6)"]},
  "i:138"->{
    Cell[2910960, 52753, 551, 21, 44, "Text",
      CellTags->"i:138"]},
  "(1.4.7)"->{
    Cell[2911514, 52776, 623, 17, 33, "NE4",
      CellTags->"(1.4.7)"]},
  "i:124"->{
    Cell[2912140, 52795, 923, 28, 78, "Text",
      CellTags->"i:124"]},
  "Cell 1.27"->{
    Cell[2915707, 52910, 271, 7, 105, "Input",
      CellTags->"Cell 1.27"]},
  "Cell 1.28"->{
    Cell[2920602, 53072, 86, 3, 67, "Input",
      CellTags->"Cell 1.28"]},
  "Cell 1.29"->{
    Cell[2922273, 53127, 88, 3, 67, "Input",
      CellTags->"Cell 1.29"]},
  "Cell 1.30"->{
    Cell[2922364, 53132, 305, 7, 105, "Input",
      CellTags->"Cell 1.30"]},
  "i:136"->{
    Cell[2922672, 53141, 2651, 79, 103, "Text",
      CellTags->"i:136"]},
  "Cell 1.31"->{
    Cell[2925348, 53224, 86, 3, 67, "Input",
      CellTags->"Cell 1.31"]},
  "(1.4.8)"->{
    Cell[2931738, 53438, 179, 8, 29, "NE4",
      CellTags->"(1.4.8)"]},
  "(1.4.9)"->{
    Cell[2932146, 53459, 125, 2, 30, "NE4",
      CellTags->"(1.4.9)"]},
  "Cell 1.32"->{
    Cell[2937215, 53612, 555, 16, 69, "Input",
      CellTags->"Cell 1.32"]},
  "Cell 1.33"->{
    Cell[2939197, 53673, 454, 10, 143, "Input",
      CellTags->"Cell 1.33"]},
  "Cell 1.34"->{
    Cell[2939931, 53695, 184, 5, 105, "Input",
      CellTags->"Cell 1.34"]},
  "Cell 1.35"->{
    Cell[2941738, 53756, 149, 4, 67, "Input",
      CellTags->"Cell 1.35"]},
  "Cell 1.36"->{
    Cell[2943067, 53794, 392, 9, 124, "Input",
      CellTags->"Cell 1.36"]},
  "i:147"->{
    Cell[2964664, 54312, 1199, 39, 103, "Text",
      CellTags->"i:147"]},
  "Cell 1.37"->{
    Cell[2966161, 54365, 127, 3, 67, "Input",
      CellTags->"Cell 1.37"]},
  "Cell 1.38"->{
    Cell[2966781, 54389, 201, 4, 86, "Input",
      CellTags->"Cell 1.38"]},
  "i:51"->{
    Cell[2994357, 54986, 594, 17, 78, "Text",
      CellTags->"i:51"]},
  "i:142"->{
    Cell[2995452, 55027, 216, 5, 44, "Text",
      CellTags->"i:142"]},
  "Cell 1.39"->{
    Cell[2996967, 55076, 773, 14, 200, "Input",
      CellTags->"Cell 1.39"]},
  "Cell 1.40"->{
    Cell[2999743, 55160, 550, 13, 162, "Input",
      CellTags->"Cell 1.40"]},
  "i:48"->{
    Cell[3041771, 56141, 1058, 33, 98, "Text",
      CellTags->"i:48"]},
  "i:49"->{
    Cell[3042866, 56179, 147, 2, 30, "Subsubtitle",
      CellTags->{"i:49", "c:25"}]},
  "c:25"->{
    Cell[3042866, 56179, 147, 2, 30, "Subsubtitle",
      CellTags->{"i:49", "c:25"}]},
  "(1.4.10)"->{
    Cell[3044253, 56222, 724, 19, 40, "NE4",
      CellTags->"(1.4.10)"]},
  "i:125"->{
    Cell[3123511, 57218, 420, 14, 29, "Caption",
      CellTags->{"i:125", "Fig. 1.11"}]},
  "Fig. 1.11"->{
    Cell[3123511, 57218, 420, 14, 29, "Caption",
      CellTags->{"i:125", "Fig. 1.11"}]},
  "(1.4.11)"->{
    Cell[3126318, 57314, 475, 12, 40, "NE4",
      CellTags->"(1.4.11)"]},
  "i:143"->{
    Cell[3126796, 57328, 1766, 65, 81, "Text",
      CellTags->"i:143"]},
  "(1.4.12)"->{
    Cell[3132835, 57551, 380, 9, 60, "NE4",
      CellTags->"(1.4.12)"]},
  "Cell 1.41"->{
    Cell[3133467, 57573, 687, 14, 200, "Input",
      CellTags->"Cell 1.41"]},
  "Cell 1.42"->{
    Cell[3135799, 57640, 167, 4, 86, "Input",
      CellTags->"Cell 1.42"]},
  "Cell 1.43"->{
    Cell[3136150, 57656, 698, 17, 200, "Input",
      CellTags->"Cell 1.43"]},
  "i:53"->{
    Cell[3175403, 58589, 464, 12, 61, "Text",
      CellTags->"i:53"]},
  "i:52"->{
    Cell[3176345, 58615, 140, 2, 30, "Subsubtitle",
      CellTags->{"i:52", "c:26"}]},
  "c:26"->{
    Cell[3176345, 58615, 140, 2, 30, "Subsubtitle",
      CellTags->{"i:52", "c:26"}]},
  "(1.4.13)"->{
    Cell[3176544, 58621, 733, 21, 42, "NE4",
      CellTags->"(1.4.13)"]},
  "(1.4.14)"->{
    Cell[3177789, 58659, 541, 18, 38, "NE4",
      CellTags->"(1.4.14)"]},
  "(1.4.15)"->{
    Cell[3178934, 58700, 961, 32, 38, "NE4",
      CellTags->"(1.4.15)"]},
  "(1.4.16)"->{
    Cell[3180515, 58758, 426, 15, 29, "NE4",
      CellTags->"(1.4.16)"]},
  "(1.4.17)"->{
    Cell[3181202, 58784, 1008, 30, 29, "NE4",
      CellTags->"(1.4.17)"]},
  "(1.4.18)"->{
    Cell[3182866, 58839, 600, 14, 42, "NE4",
      CellTags->"(1.4.18)"]},
  "(1.4.19)"->{
    Cell[3183496, 58857, 324, 10, 27, "NE4",
      CellTags->"(1.4.19)"]},
  "(1.4.20)"->{
    Cell[3183859, 58871, 459, 16, 29, "NE4",
      CellTags->"(1.4.20)"]},
  "Cell 1.44"->{
    Cell[3184832, 58910, 101, 3, 67, "Input",
      CellTags->"Cell 1.44"]},
  "Cell 1.45"->{
    Cell[3184936, 58915, 666, 13, 181, "Input",
      CellTags->"Cell 1.45"]},
  "Cell 1.46"->{
    Cell[3187477, 58995, 171, 5, 67, "Input",
      CellTags->"Cell 1.46"]},
  "Cell 1.47"->{
    Cell[3188959, 59053, 106, 3, 67, "Input",
      CellTags->"Cell 1.47"]},
  "Cell 1.48"->{
    Cell[3189090, 59060, 125, 3, 67, "Input",
      CellTags->"Cell 1.48"]},
  "i:54"->{
    Cell[3221863, 59754, 175, 3, 30, "Subsubtitle",
      CellTags->{"i:54", "c:27"}]},
  "c:27"->{
    Cell[3221863, 59754, 175, 3, 30, "Subsubtitle",
      CellTags->{"i:54", "c:27"}]},
  "(1.4.21)"->{
    Cell[3224212, 59825, 1074, 31, 59, "NE4",
      CellTags->"(1.4.21)"]},
  "(1.4.22)"->{
    Cell[3225921, 59885, 1003, 29, 40, "NE4",
      CellTags->"(1.4.22)"]},
  "Cell 1.49"->{
    Cell[3227094, 59924, 101, 3, 67, "Input",
      CellTags->"Cell 1.49"]},
  "Cell 1.50"->{
    Cell[3227198, 59929, 1300, 25, 295, "Input",
      CellTags->"Cell 1.50"]},
  "(1.4.23)"->{
    Cell[3235204, 60190, 2079, 54, 54, "NE4",
      CellTags->"(1.4.23)"]},
  "(1.4.24)"->{
    Cell[3239403, 60322, 825, 27, 33, "NE4",
      CellTags->"(1.4.24)"]},
  "Cell 1.51"->{
    Cell[3240577, 60363, 181, 4, 67, "Input",
      CellTags->"Cell 1.51"]},
  "Cell 1.52"->{
    Cell[3242027, 60416, 142, 4, 67, "Input",
      CellTags->"Cell 1.52"]},
  "Cell 1.53"->{
    Cell[3242424, 60433, 97, 3, 67, "Input",
      CellTags->"Cell 1.53"]},
  "Cell 1.54"->{
    Cell[3242723, 60451, 96, 3, 67, "Input",
      CellTags->"Cell 1.54"]},
  "Cell 1.55"->{
    Cell[3246665, 60554, 346, 8, 105, "Input",
      CellTags->"Cell 1.55"]},
  "Cell 1.56"->{
    Cell[4245749, 80826, 556, 12, 162, "Input",
      CellTags->"Cell 1.56"]},
  "Table 1.2"->{
    Cell[4290230, 81968, 471, 16, 73, "Text",
      CellTags->"Table 1.2"]},
  "Cell 1.57"->{
    Cell[4293484, 82041, 1445, 27, 428, "Input",
      CellTags->"Cell 1.57"]},
  "Cell 1.58"->{
    Cell[4294932, 82070, 186, 4, 86, "Input",
      CellTags->"Cell 1.58"]},
  "i:145"->{
    Cell[4295121, 82076, 341, 7, 61, "Text",
      CellTags->"i:145"]},
  "Cell 1.59"->{
    Cell[4296481, 82112, 205, 6, 67, "Input",
      CellTags->"Cell 1.59"]},
  "Cell 1.60"->{
    Cell[4296913, 82127, 261, 6, 86, "Input",
      CellTags->"Cell 1.60"]},
  "Cell 1.61"->{
    Cell[4297344, 82143, 230, 5, 86, "Input",
      CellTags->"Cell 1.61"]},
  "Cell 1.62"->{
    Cell[4297702, 82155, 127, 3, 67, "Input",
      CellTags->"Cell 1.62"]},
  "Cell 1.63"->{
    Cell[4298069, 82168, 175, 4, 67, "Input",
      CellTags->"Cell 1.63"]},
  "Cell 1.64"->{
    Cell[4298247, 82174, 268, 6, 86, "Input",
      CellTags->"Cell 1.64"]},
  "Cell 1.65"->{
    Cell[4298540, 82184, 247, 5, 86, "Input",
      CellTags->"Cell 1.65"]},
  "Ex. 1.4"->{
    Cell[5539738, 188523, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 1.4", "c:28"}]},
  "c:28"->{
    Cell[5539738, 188523, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 1.4", "c:28"}]},
  "i:55"->{
    Cell[5542430, 188615, 1132, 36, 81, "Text",
      CellTags->"i:55"]},
  "i:127"->{
    Cell[5545417, 188705, 728, 21, 65, "Text",
      CellTags->"i:127"]},
  "i:56"->{
    Cell[5548253, 188801, 698, 17, 78, "Text",
      CellTags->"i:56"]},
  "i:57"->{
    Cell[5548954, 188820, 269, 7, 44, "Text",
      CellTags->"i:57"]},
  "Fig. 1.12"->{
    Cell[5881683, 193291, 176, 4, 16, "Caption",
      CellTags->"Fig. 1.12"]},
  "i:58"->{
    Cell[5881862, 193297, 977, 39, 64, "Text",
      CellTags->"i:58"]},
  "i:59"->{
    Cell[5882842, 193338, 1735, 64, 98, "Text",
      CellTags->"i:59"]},
  "i:60"->{
    Cell[5884580, 193404, 1337, 36, 146, "Text",
      CellTags->"i:60"]},
  "(1.4.25)"->{
    Cell[5885920, 193442, 829, 26, 100, "NE4",
      CellTags->"(1.4.25)"]},
  "i:62"->{
    Cell[5889736, 193572, 960, 36, 47, "Text",
      CellTags->"i:62"]},
  "Fig. 1.13"->{
    Cell[6826744, 211989, 105, 1, 16, "Caption",
      CellTags->{"Fig. 1.13", "i:129"}]},
  "i:129"->{
    Cell[6826744, 211989, 105, 1, 16, "Caption",
      CellTags->{"Fig. 1.13", "i:129"}]},
  "Fig. 1.14"->{
    Cell[7024398, 222675, 438, 17, 16, "Caption",
      CellTags->"Fig. 1.14"]},
  "i:63"->{
    Cell[7024839, 222694, 3351, 96, 117, "Text",
      CellTags->"i:63"]},
  "i:107"->{
    Cell[7028193, 222792, 2276, 71, 112, "Text",
      CellTags->"i:107"]},
  "Fig. 1.15"->{
    Cell[7096809, 224697, 550, 19, 16, "Caption",
      CellTags->"Fig. 1.15"]},
  "ex 13"->{
    Cell[7102249, 224919, 418, 15, 30, "Text",
      CellTags->"ex 13"]},
  "i:64"->{
    Cell[7103364, 224972, 1349, 44, 91, "Text",
      CellTags->"i:64"]},
  "(1.4.26)"->{
    Cell[7104716, 225018, 565, 17, 42, "NE4",
      CellTags->"(1.4.26)"]},
  "(1.4.27)"->{
    Cell[7105844, 225056, 616, 20, 32, "NE4",
      CellTags->"(1.4.27)"]},
  "(1.4.28)"->{
    Cell[7107038, 225101, 658, 20, 42, "NE4",
      CellTags->"(1.4.28)"]},
  "i:65"->{
    Cell[7108998, 225180, 1191, 33, 74, "Text",
      CellTags->"i:65"]},
  "i:66"->{
    Cell[7114249, 225353, 679, 20, 61, "Text",
      CellTags->"i:66"]},
  "(1.4.29)"->{
    Cell[7117245, 225464, 456, 14, 29, "NE4",
      CellTags->"(1.4.29)"]},
  "(1.4.30)"->{
    Cell[7120448, 225570, 749, 21, 43, "NE4",
      CellTags->{"(1.4.30)", "i:78"}]},
  "i:78"->{
    Cell[7120448, 225570, 749, 21, 43, "NE4",
      CellTags->{"(1.4.30)", "i:78"}]},
  "(1.4.31)"->{
    Cell[7121639, 225608, 429, 13, 33, "NE4",
      CellTags->{"(1.4.31)", "i:67"}]},
  "i:67"->{
    Cell[7121639, 225608, 429, 13, 33, "NE4",
      CellTags->{"(1.4.31)", "i:67"}]},
  "(1.4.32)"->{
    Cell[7122708, 225647, 647, 20, 33, "NE4",
      CellTags->{"(1.4.32)", "i:68"}]},
  "i:68"->{
    Cell[7122708, 225647, 647, 20, 33, "NE4",
      CellTags->{"(1.4.32)", "i:68"}]},
  "i:69"->{
    Cell[7124119, 225697, 867, 29, 48, "Text",
      CellTags->"i:69"]},
  "i:75"->{
    Cell[7124989, 225728, 1042, 35, 80, "Text",
      CellTags->"i:75"]},
  "(1.4.33)"->{
    Cell[7126034, 225765, 1049, 34, 33, "NE4",
      CellTags->"(1.4.33)"]},
  "i:76"->{
    Cell[7128951, 225872, 916, 19, 115, "Text",
      CellTags->"i:76"]},
  "i:77"->{
    Cell[7129870, 225893, 1538, 46, 115, "Text",
      CellTags->"i:77"]},
  "i:74"->{
    Cell[7131601, 225948, 1483, 40, 57, "Text",
      CellTags->"i:74"]},
  "i:71"->{
    Cell[7133087, 225990, 1141, 31, 127, "Text",
      CellTags->"i:71"]},
  "i:72"->{
    Cell[7139870, 226211, 651, 17, 78, "Text",
      CellTags->"i:72"]},
  "i:73"->{
    Cell[7142671, 226307, 1114, 30, 95, "Text",
      CellTags->"i:73"]},
  "Cell 1.66"->{
    Cell[7143788, 226339, 188, 4, 86, "Input",
      CellTags->"Cell 1.66"]},
  "Cell 1.67"->{
    Cell[7144197, 226355, 160, 5, 67, "Input",
      CellTags->"Cell 1.67"]},
  "Cell 1.68"->{
    Cell[7144587, 226370, 310, 7, 105, "Input",
      CellTags->"Cell 1.68"]},
  "Cell 1.69"->{
    Cell[7145391, 226398, 237, 6, 124, "Input",
      CellTags->"Cell 1.69"]},
  "i:144"->{
    Cell[7146806, 226444, 922, 25, 96, "Text",
      CellTags->"i:144"]},
  "Sec. 1.5"->{
    Cell[7147777, 226475, 300, 11, 40, "Subtitle",
      CellTags->{"Sec. 1.5", "i:79", "c:29"}]},
  "i:79"->{
    Cell[7147777, 226475, 300, 11, 40, "Subtitle",
      CellTags->{"Sec. 1.5", "i:79", "c:29"}]},
  "c:29"->{
    Cell[7147777, 226475, 300, 11, 40, "Subtitle",
      CellTags->{"Sec. 1.5", "i:79", "c:29"}]},
  "c:30"->{
    Cell[7148121, 226492, 108, 2, 41, "Subsubtitle",
      CellTags->"c:30"]},
  "(1.5.1)"->{
    Cell[7149575, 226543, 251, 8, 43, "NE5",
      CellTags->"(1.5.1)"]},
  "i:120"->{
    Cell[7149829, 226553, 986, 36, 65, "Text",
      CellTags->"i:120"]},
  "(1.5.2)"->{
    Cell[7150818, 226591, 115, 2, 27, "NE5",
      CellTags->"(1.5.2)"]},
  "(1.5.3)"->{
    Cell[7151172, 226603, 140, 5, 43, "NE5",
      CellTags->"(1.5.3)"]},
  "(1.5.4)"->{
    Cell[7152208, 226646, 163, 6, 43, "NE5",
      CellTags->"(1.5.4)"]},
  "i:17"->{
    Cell[7152709, 226662, 199, 6, 47, "Text",
      CellTags->"i:17"]},
  "(1.5.5)"->{
    Cell[7153101, 226676, 280, 9, 42, "NE5",
      CellTags->"(1.5.5)"]},
  "(1.5.6)"->{
    Cell[7153835, 226701, 141, 5, 29, "NE5",
      CellTags->"(1.5.6)"]},
  "(1.5.7)"->{
    Cell[7154681, 226729, 146, 3, 27, "NE5",
      CellTags->"(1.5.7)"]},
  "(1.5.8)"->{
    Cell[7155390, 226756, 122, 5, 29, "NE5",
      CellTags->"(1.5.8)"]},
  "(1.5.9)"->{
    Cell[7156335, 226792, 123, 2, 27, "NE5",
      CellTags->"(1.5.9)"]},
  "(1.5.10)"->{
    Cell[7157756, 226843, 127, 5, 29, "NE5",
      CellTags->"(1.5.10)"]},
  "i:80"->{
    Cell[7158134, 226861, 458, 15, 64, "Text",
      CellTags->"i:80"]},
  "i:43"->{
    Cell[7159073, 226893, 135, 4, 30, "Subsubtitle",
      CellTags->{"i:43", "c:31"}]},
  "c:31"->{
    Cell[7159073, 226893, 135, 4, 30, "Subsubtitle",
      CellTags->{"i:43", "c:31"}]},
  "(1.5.11)"->{
    Cell[7159938, 226919, 411, 10, 43, "NE5",
      CellTags->"(1.5.11)"]},
  "i:122"->{
    Cell[7160352, 226931, 65, 1, 27, "Text",
      CellTags->"i:122"]},
  "(1.5.12)"->{
    Cell[7160420, 226934, 133, 5, 29, "NE5",
      CellTags->"(1.5.12)"]},
  "Cell 1.70"->{
    Cell[7162946, 227014, 230, 6, 86, "Input",
      CellTags->"Cell 1.70"]},
  "Cell 1.71"->{
    Cell[7164264, 227054, 167, 4, 86, "Input",
      CellTags->"Cell 1.71"]},
  "Cell 1.72"->{
    Cell[7165144, 227081, 130, 4, 86, "Input",
      CellTags->"Cell 1.72"]},
  "Cell 1.73"->{
    Cell[7165660, 227104, 87, 3, 67, "Input",
      CellTags->"Cell 1.73"]},
  "Cell 1.74"->{
    Cell[7166301, 227132, 121, 3, 67, "Input",
      CellTags->"Cell 1.74"]},
  "Cell 1.75"->{
    Cell[7187546, 227612, 124, 3, 67, "Input",
      CellTags->"Cell 1.75"]},
  "Cell 1.76"->{
    Cell[7187892, 227628, 88, 3, 67, "Input",
      CellTags->"Cell 1.76"]},
  "Cell 1.77"->{
    Cell[7189155, 227681, 124, 3, 67, "Input",
      CellTags->"Cell 1.77"]},
  "Cell 1.78"->{
    Cell[7189772, 227705, 173, 4, 86, "Input",
      CellTags->"Cell 1.78"]},
  "Ex. 1.5"->{
    Cell[7211245, 228176, 125, 2, 30, "Subsubtitle",
      CellTags->{"Ex. 1.5", "c:32"}]},
  "c:32"->{
    Cell[7211245, 228176, 125, 2, 30, "Subsubtitle",
      CellTags->{"Ex. 1.5", "c:32"}]},
  "(1.5.13)"->{
    Cell[7214269, 228265, 421, 12, 27, "NE5",
      CellTags->"(1.5.13)"]},
  "(1.5.14)"->{
    Cell[7215337, 228302, 150, 5, 41, "NE5",
      CellTags->"(1.5.14)"]},
  "Fig. 1.16"->{
    Cell[7258722, 229021, 287, 10, 16, "Caption",
      CellTags->"Fig. 1.16"]},
  "Fig. 1.17"->{
    Cell[7347190, 230481, 79, 1, 16, "Caption",
      CellTags->"Fig. 1.17"]},
  "Sec. 1.6"->{
    Cell[7348153, 230514, 77, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.6", "i:81", "c:33"}]},
  "i:81"->{
    Cell[7348153, 230514, 77, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.6", "i:81", "c:33"}]},
  "c:33"->{
    Cell[7348153, 230514, 77, 1, 40, "Subtitle",
      CellTags->{"Sec. 1.6", "i:81", "c:33"}]},
  "c:34"->{
    Cell[7348274, 230521, 79, 1, 41, "Subsubtitle",
      CellTags->"c:34"]},
  "c:35"->{
    Cell[7348378, 230526, 124, 5, 42, "Section",
      CellTags->"c:35"]},
  "(1.6.1)"->{
    Cell[7348871, 230547, 837, 23, 42, "NE6",
      CellTags->"(1.6.1)"]},
  "(1.6.2)"->{
    Cell[7350209, 230591, 506, 14, 42, "NE6",
      CellTags->{"(1.6.2)", "i:91"}]},
  "i:91"->{
    Cell[7350209, 230591, 506, 14, 42, "NE6",
      CellTags->{"(1.6.2)", "i:91"}]},
  "i:104"->{
    Cell[7350718, 230607, 813, 28, 47, "Text",
      CellTags->"i:104"]},
  "c:36"->{
    Cell[7351905, 230648, 68, 1, 31, "Section",
      CellTags->"c:36"]},
  "i:131"->{
    Cell[7351976, 230651, 823, 22, 85, "Text",
      CellTags->"i:131"]},
  "(1.6.3)"->{
    Cell[7353006, 230687, 850, 22, 42, "NE6",
      CellTags->{"(1.6.3)", "i:130"}]},
  "i:130"->{
    Cell[7353006, 230687, 850, 22, 42, "NE6",
      CellTags->{"(1.6.3)", "i:130"}]},
  "i:83"->{
    Cell[7354155, 230723, 87, 1, 27, "Text",
      CellTags->"i:83"]},
  "c:37"->{
    Cell[7355803, 230779, 66, 1, 31, "Section",
      CellTags->"c:37"]},
  "i:85"->{
    Cell[7355872, 230782, 584, 19, 65, "Text",
      CellTags->"i:85"]},
  "(1.6.4)"->{
    Cell[7357218, 230825, 166, 6, 29, "NE6",
      CellTags->"(1.6.4)"]},
  "(1.6.5)"->{
    Cell[7358157, 230860, 300, 8, 33, "NE6",
      CellTags->"(1.6.5)"]},
  "i:82"->{
    Cell[7358693, 230879, 2004, 40, 94, "Table",
      CellTags->"i:82"]},
  "c:38"->{
    Cell[7360746, 230925, 97, 1, 30, "Subsubtitle",
      CellTags->"c:38"]},
  "c:39"->{
    Cell[7360868, 230930, 51, 1, 42, "Section",
      CellTags->"c:39"]},
  "(1.6.6)"->{
    Cell[7362094, 230970, 193, 4, 27, "NE6",
      CellTags->"(1.6.6)"]},
  "i:84"->{
    Cell[7364379, 231035, 379, 12, 68, "Text",
      CellTags->"i:84"]},
  "(1.6.7)"->{
    Cell[7365156, 231063, 837, 20, 42, "NE6",
      CellTags->"(1.6.7)"]},
  "(1.6.8)"->{
    Cell[7366413, 231100, 346, 10, 40, "NE6",
      CellTags->"(1.6.8)"]},
  "(1.6.9)"->{
    Cell[7366951, 231122, 264, 7, 33, "NE6",
      CellTags->"(1.6.9)"]},
  "(1.6.10)"->{
    Cell[7367948, 231157, 225, 7, 31, "NE6",
      CellTags->{"(1.6.10)", "i:89"}]},
  "i:89"->{
    Cell[7367948, 231157, 225, 7, 31, "NE6",
      CellTags->{"(1.6.10)", "i:89"}]},
  "i:90"->{
    Cell[7368176, 231166, 560, 19, 44, "Text",
      CellTags->"i:90"]},
  "(1.6.11)"->{
    Cell[7370498, 231251, 270, 4, 38, "NE6",
      CellTags->"(1.6.11)"]},
  "i:117"->{
    Cell[7370771, 231257, 275, 7, 44, "Text",
      CellTags->"i:117"]},
  "Cell 1.79"->{
    Cell[7371071, 231268, 299, 7, 86, "Input",
      CellTags->"Cell 1.79"]},
  "c:40"->{
    Cell[7372352, 231306, 159, 3, 31, "Section",
      CellTags->"c:40"]},
  "(1.6.12)"->{
    Cell[7373042, 231328, 307, 9, 32, "NE6",
      CellTags->"(1.6.12)"]},
  "(1.6.13)"->{
    Cell[7373595, 231350, 149, 6, 32, "NE6",
      CellTags->"(1.6.13)"]},
  "(1.6.14)"->{
    Cell[7373785, 231360, 306, 7, 129, "NE6",
      CellTags->"(1.6.14)"]},
  "i:118"->{
    Cell[7374094, 231369, 595, 17, 61, "Text",
      CellTags->"i:118"]},
  "(1.6.15)"->{
    Cell[7374692, 231388, 290, 8, 69, "NE6",
      CellTags->"(1.6.15)"]},
  "(1.6.16)"->{
    Cell[7375447, 231413, 203, 4, 46, "NE6",
      CellTags->"(1.6.16)"]},
  "(1.6.17)"->{
    Cell[7376033, 231429, 384, 6, 124, "NE6",
      CellTags->{"(1.6.17)", "i:92"}]},
  "i:92"->{
    Cell[7376033, 231429, 384, 6, 124, "NE6",
      CellTags->{"(1.6.17)", "i:92"}]},
  "c:41"->{
    Cell[7376797, 231451, 146, 3, 30, "Subsubtitle",
      CellTags->"c:41"]},
  "(1.6.18)"->{
    Cell[7377135, 231465, 177, 6, 33, "NE6",
      CellTags->"(1.6.18)"]},
  "i:44"->{
    Cell[7377876, 231492, 1151, 37, 61, "Text",
      CellTags->"i:44"]},
  "(1.6.19)"->{
    Cell[7380165, 231574, 423, 14, 38, "NE6",
      CellTags->"(1.6.19)"]},
  "i:126"->{
    Cell[7380591, 231590, 209, 7, 27, "Text",
      CellTags->"i:126"]},
  "(1.6.20)"->{
    Cell[7380803, 231599, 939, 24, 65, "NE6",
      CellTags->"(1.6.20)"]},
  "(1.6.21)"->{
    Cell[7381836, 231630, 2053, 56, 138, "NE6",
      CellTags->"(1.6.21)"]},
  "i:99"->{
    Cell[7383892, 231688, 880, 29, 78, "Text",
      CellTags->"i:99"]},
  "i:100"->{
    Cell[7384775, 231719, 656, 24, 44, "Text",
      CellTags->"i:100"]},
  "(1.6.22)"->{
    Cell[7385434, 231745, 693, 24, 45, "NE6",
      CellTags->"(1.6.22)"]},
  "i:134"->{
    Cell[7386130, 231771, 1334, 47, 86, "Text",
      CellTags->"i:134"]},
  "(1.6.23)"->{
    Cell[7387467, 231820, 954, 27, 30, "NE6",
      CellTags->"(1.6.23)"]},
  "Cell 1.80"->{
    Cell[7388606, 231859, 265, 7, 105, "Input",
      CellTags->"Cell 1.80"]},
  "(1.6.24)"->{
    Cell[7391595, 231954, 485, 17, 29, "NE6",
      CellTags->"(1.6.24)"]},
  "i:101"->{
    Cell[7392083, 231973, 597, 18, 61, "Text",
      CellTags->"i:101"]},
  "(1.6.25)"->{
    Cell[7392683, 231993, 525, 18, 32, "NE6",
      CellTags->{"(1.6.25)", "i:105"}]},
  "i:105"->{
    Cell[7392683, 231993, 525, 18, 32, "NE6",
      CellTags->{"(1.6.25)", "i:105"}]},
  "Cell 1.81"->{
    Cell[7396163, 232111, 396, 9, 143, "Input",
      CellTags->"Cell 1.81"]},
  "Cell 1.82"->{
    Cell[7396965, 232140, 215, 6, 86, "Input",
      CellTags->"Cell 1.82"]},
  "Cell 1.83"->{
    Cell[7397638, 232165, 482, 11, 124, "Input",
      CellTags->"Cell 1.83"]},
  "i:116"->{
    Cell[7428122, 232852, 544, 13, 78, "Text",
      CellTags->"i:116"]},
  "c:42"->{
    Cell[7430108, 232914, 74, 1, 30, "Subsubtitle",
      CellTags->"c:42"]},
  "c:43"->{
    Cell[7430207, 232919, 75, 1, 42, "Section",
      CellTags->"c:43"]},
  "i:86"->{
    Cell[7430285, 232922, 441, 15, 48, "Text",
      CellTags->"i:86"]},
  "(1.6.26)"->{
    Cell[7430729, 232939, 117, 5, 33, "NE6",
      CellTags->"(1.6.26)"]},
  "i:119"->{
    Cell[7430849, 232946, 279, 6, 44, "Text",
      CellTags->"i:119"]},
  "(1.6.27)"->{
    Cell[7431131, 232954, 135, 5, 30, "NE6",
      CellTags->"(1.6.27)"]},
  "i:87"->{
    Cell[7431269, 232961, 185, 6, 27, "Text",
      CellTags->"i:87"]},
  "(1.6.28)"->{
    Cell[7431457, 232969, 118, 2, 32, "NE6",
      CellTags->"(1.6.28)"]},
  "(1.6.29)"->{
    Cell[7431744, 232980, 120, 5, 34, "NE6",
      CellTags->"(1.6.29)"]},
  "i:88"->{
    Cell[7431867, 232987, 362, 15, 28, "Text",
      CellTags->"i:88"]},
  "i:93"->{
    Cell[7433847, 233060, 84, 1, 31, "Section",
      CellTags->{"i:93", "c:44"}]},
  "c:44"->{
    Cell[7433847, 233060, 84, 1, 31, "Section",
      CellTags->{"i:93", "c:44"}]},
  "i:94"->{
    Cell[7433934, 233063, 979, 26, 96, "Text",
      CellTags->"i:94"]},
  "(1.6.30)"->{
    Cell[7435014, 233096, 118, 5, 29, "NE6",
      CellTags->"(1.6.30)"]},
  "(1.6.31)"->{
    Cell[7435231, 233108, 129, 5, 30, "NE6",
      CellTags->"(1.6.31)"]},
  "(1.6.32)"->{
    Cell[7435628, 233128, 151, 5, 34, "NE6",
      CellTags->"(1.6.32)"]},
  "(1.6.33)"->{
    Cell[7436150, 233151, 161, 6, 29, "NE6",
      CellTags->"(1.6.33)"]},
  "(1.6.34)"->{
    Cell[7436772, 233171, 136, 5, 29, "NE6",
      CellTags->"(1.6.34)"]},
  "i:103"->{
    Cell[7437170, 233188, 80, 1, 31, "Section",
      CellTags->{"i:103", "c:45"}]},
  "c:45"->{
    Cell[7437170, 233188, 80, 1, 31, "Section",
      CellTags->{"i:103", "c:45"}]},
  "(1.6.35)"->{
    Cell[7437763, 233205, 133, 5, 29, "NE6",
      CellTags->"(1.6.35)"]},
  "(1.6.36)"->{
    Cell[7438001, 233217, 165, 6, 30, "NE6",
      CellTags->"(1.6.36)"]},
  "(1.6.37)"->{
    Cell[7438668, 233243, 472, 8, 86, "NE6",
      CellTags->"(1.6.37)"]},
  "(1.6.38)"->{
    Cell[7439875, 233283, 169, 4, 31, "NE6",
      CellTags->"(1.6.38)"]},
  "(1.6.39)"->{
    Cell[7440089, 233291, 170, 4, 33, "NE6",
      CellTags->"(1.6.39)"]},
  "(1.6.40)"->{
    Cell[7440934, 233318, 292, 8, 30, "NE6",
      CellTags->"(1.6.40)"]},
  "(1.6.41)"->{
    Cell[7442075, 233363, 316, 8, 34, "NE6",
      CellTags->"(1.6.41)"]},
  "(1.6.42)"->{
    Cell[7443002, 233392, 458, 13, 40, "NE6",
      CellTags->"(1.6.42)"]},
  "(1.6.43)"->{
    Cell[7443607, 233415, 316, 8, 33, "NE6",
      CellTags->"(1.6.43)"]},
  "i:95"->{
    Cell[7443926, 233425, 298, 10, 28, "Text",
      CellTags->"i:95"]},
  "(1.6.44)"->{
    Cell[7444227, 233437, 252, 5, 49, "NE6",
      CellTags->"(1.6.44)"]},
  "(1.6.45)"->{
    Cell[7445123, 233464, 279, 5, 44, "NE6",
      CellTags->"(1.6.45)"]},
  "Fig. 1.18"->{
    Cell[7494210, 235082, 238, 7, 18, "Caption",
      CellTags->"Fig. 1.18"]},
  "i:102"->{
    Cell[7494451, 235091, 991, 22, 112, "Text",
      CellTags->"i:102"]},
  "i:96"->{
    Cell[7495479, 235118, 58, 1, 31, "Section",
      CellTags->{"i:96", "c:46"}]},
  "c:46"->{
    Cell[7495479, 235118, 58, 1, 31, "Section",
      CellTags->{"i:96", "c:46"}]},
  "Fig. 1.19"->{
    Cell[7560889, 236901, 564, 14, 63, "Caption",
      CellTags->"Fig. 1.19"]},
  "i:97"->{
    Cell[7562591, 236946, 531, 17, 44, "Text",
      CellTags->"i:97"]},
  "Cell 1.84"->{
    Cell[7563326, 236975, 291, 8, 124, "Input",
      CellTags->"Cell 1.84"]},
  "(1.6.46)"->{
    Cell[7565838, 237046, 555, 15, 33, "NE6",
      CellTags->"(1.6.46)"]},
  "(1.6.47)"->{
    Cell[7567208, 237088, 476, 11, 42, "NE6",
      CellTags->"(1.6.47)"]},
  "i:141"->{
    Cell[7567687, 237101, 422, 14, 44, "Text",
      CellTags->"i:141"]},
  "Cell 1.85"->{
    Cell[7568134, 237119, 194, 5, 86, "Input",
      CellTags->"Cell 1.85"]},
  "Cell 1.86"->{
    Cell[7669264, 239142, 253, 5, 96, "Input",
      CellTags->"Cell 1.86"]},
  "Ex. 1.6"->{
    Cell[7670248, 239176, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 1.6", "c:47"}]},
  "c:47"->{
    Cell[7670248, 239176, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 1.6", "c:47"}]},
  "i:132"->{
    Cell[7670329, 239179, 1532, 44, 97, "Text",
      CellTags->"i:132"]},
  "i:106"->{
    Cell[7674322, 239321, 746, 26, 44, "Text",
      CellTags->"i:106"]},
  "refs"->{
    Cell[7686387, 239744, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:48"}]},
  "c:48"->{
    Cell[7686387, 239744, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:48"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"chapter 2", 7735367, 241191},
  {"i:5", 7735466, 241194},
  {"c:1", 7735565, 241197},
  {"Sec. 1.1", 7735669, 241200},
  {"c:2", 7735761, 241203},
  {"c:3", 7735853, 241206},
  {"i:1", 7735934, 241209},
  {"c:4", 7736021, 241212},
  {"i:2", 7736108, 241215},
  {"i:4", 7736184, 241218},
  {"(1.1.1)", 7736266, 241221},
  {"(1.1.2)", 7736362, 241224},
  {"(1.1.3)", 7736458, 241227},
  {"i:3", 7736551, 241230},
  {"i:13", 7736631, 241233},
  {"i:9", 7736710, 241236},
  {"(1.1.4)", 7736792, 241239},
  {"(1.1.5)", 7736890, 241242},
  {"i:70", 7736995, 241245},
  {"(1.1.6)", 7737103, 241248},
  {"i:10", 7737198, 241251},
  {"(1.1.7)", 7737281, 241254},
  {"(1.1.8)", 7737378, 241257},
  {"(1.1.9)", 7737476, 241260},
  {"Cell 1.1", 7737574, 241263},
  {"Cell 1.2", 7737662, 241266},
  {"Cell 1.3", 7737749, 241269},
  {"c:5", 7737831, 241272},
  {"i:11", 7737911, 241275},
  {"i:7", 7737991, 241278},
  {"c:6", 7738079, 241281},
  {"i:6", 7738167, 241284},
  {"(1.1.10)", 7738252, 241287},
  {"i:8", 7738346, 241290},
  {"(1.1.11)", 7738429, 241293},
  {"i:123", 7738526, 241296},
  {"c:7", 7738606, 241299},
  {"i:12", 7738686, 241302},
  {"i:121", 7738768, 241305},
  {"Ex. 1.1", 7738853, 241308},
  {"c:8", 7738951, 241311},
  {"Sec. 1.2", 7739054, 241314},
  {"i:14", 7739159, 241317},
  {"c:9", 7739263, 241320},
  {"c:10", 7739368, 241323},
  {"(1.2.1)", 7739458, 241326},
  {"i:16", 7739554, 241329},
  {"(1.2.2)", 7739653, 241332},
  {"Fig. 1.1", 7739739, 241335},
  {"(1.2.3)", 7739830, 241338},
  {"i:15", 7739912, 241341},
  {"Fig. 1.2", 7739997, 241344},
  {"(1.2.4)", 7740089, 241347},
  {"i:18", 7740172, 241350},
  {"Cell 1.4", 7740258, 241353},
  {"Cell 1.5", 7740347, 241356},
  {"(1.2.5)", 7740437, 241359},
  {"(1.2.6)", 7740523, 241362},
  {"(1.2.7)", 7740609, 241365},
  {"Fig. 1.3", 7740696, 241368},
  {"c:11", 7740784, 241371},
  {"i:20", 7740872, 241374},
  {"c:12", 7740965, 241377},
  {"(1.2.8)", 7741061, 241380},
  {"i:25", 7741145, 241383},
  {"(1.2.9)", 7741230, 241386},
  {"i:109", 7741314, 241389},
  {"(1.2.10)", 7741400, 241392},
  {"Fig. 1.4", 7741488, 241395},
  {"i:114", 7741578, 241398},
  {"Cell 1.6", 7741665, 241401},
  {"c:13", 7741752, 241404},
  {"Fig. 1.5", 7741840, 241407},
  {"(1.2.11)", 7741934, 241410},
  {"(1.2.12)", 7742024, 241413},
  {"(1.2.13)", 7742114, 241416},
  {"Fig. 1.6", 7742205, 241419},
  {"(1.2.14)", 7742300, 241422},
  {"i:113", 7742388, 241425},
  {"Fig. 1.7", 7742477, 241428},
  {"c:14", 7742568, 241431},
  {"i:21", 7742653, 241434},
  {"(1.2.15)", 7742740, 241437},
  {"i:22", 7742827, 241440},
  {"(1.2.16)", 7742915, 241443},
  {"i:23", 7743002, 241446},
  {"(1.2.17)", 7743090, 241449},
  {"(1.2.18)", 7743181, 241452},
  {"i:24", 7743268, 241455},
  {"i:112", 7743353, 241458},
  {"Ex. 1.2", 7743443, 241461},
  {"c:15", 7743545, 241464},
  {"(1.2.19)", 7743651, 241467},
  {"i:37", 7743738, 241470},
  {"Fig. 1.8", 7743827, 241473},
  {"i:108", 7743917, 241476},
  {"i:38", 7744002, 241479},
  {"(1.2.20)", 7744089, 241482},
  {"(1.2.21)", 7744179, 241485},
  {"i:39", 7744265, 241488},
  {"(1.2.22)", 7744353, 241491},
  {"(1.2.23)", 7744443, 241494},
  {"(1.2.24)", 7744534, 241497},
  {"i:36", 7744632, 241500},
  {"Sec. 1.3", 7744734, 241503},
  {"c:16", 7744836, 241506},
  {"c:17", 7744938, 241509},
  {"i:29", 7745028, 241512},
  {"(1.3.1)", 7745114, 241515},
  {"i:30", 7745199, 241518},
  {"Cell 1.7", 7745286, 241521},
  {"Cell 1.8", 7745378, 241524},
  {"Cell 1.9", 7745470, 241527},
  {"Cell 1.10", 7745564, 241530},
  {"i:31", 7745653, 241533},
  {"(1.3.2)", 7745740, 241536},
  {"Cell 1.11", 7745830, 241539},
  {"i:133", 7745920, 241542},
  {"Cell 1.12", 7746011, 241545},
  {"Cell 1.13", 7746107, 241548},
  {"i:32", 7746196, 241551},
  {"i:33", 7746282, 241554},
  {"Table 1.1", 7746371, 241557},
  {"Ex. 1.3", 7746465, 241560},
  {"c:18", 7746567, 241563},
  {"i:128", 7746670, 241566},
  {"(1.3.3)", 7746760, 241569},
  {"i:110", 7746846, 241572},
  {"i:115", 7746932, 241575},
  {"(1.3.4)", 7747020, 241578},
  {"i:135", 7747108, 241581},
  {"i:137", 7747194, 241584},
  {"i:146", 7747280, 241587},
  {"(1.3.5)", 7747368, 241590},
  {"i:34", 7747453, 241593},
  {"i:35", 7747538, 241596},
  {"(1.3.6)", 7747625, 241599},
  {"(1.3.7)", 7747715, 241602},
  {"(1.3.8)", 7747805, 241605},
  {"Sec. 1.4", 7747894, 241608},
  {"i:42", 7748003, 241611},
  {"c:19", 7748112, 241614},
  {"c:20", 7748221, 241617},
  {"i:40", 7748311, 241620},
  {"Cell 1.14", 7748400, 241623},
  {"i:41", 7748489, 241626},
  {"Cell 1.15", 7748580, 241629},
  {"Cell 1.16", 7748673, 241632},
  {"i:45", 7748762, 241635},
  {"Cell 1.17", 7748851, 241638},
  {"Cell 1.18", 7748946, 241641},
  {"Cell 1.19", 7749040, 241644},
  {"Cell 1.20", 7749133, 241647},
  {"i:111", 7749223, 241650},
  {"Cell 1.21", 7749315, 241653},
  {"Cell 1.22", 7749410, 241656},
  {"i:26", 7749499, 241659},
  {"c:21", 7749599, 241662},
  {"c:22", 7749699, 241665},
  {"(1.4.1)", 7749787, 241668},
  {"i:50", 7749882, 241671},
  {"Fig. 1.9", 7749981, 241674},
  {"i:27", 7750071, 241677},
  {"Fig. 1.10", 7750161, 241680},
  {"i:28", 7750252, 241683},
  {"c:23", 7750347, 241686},
  {"(1.4.2)", 7750445, 241689},
  {"Cell 1.23", 7750537, 241692},
  {"Cell 1.24", 7750632, 241695},
  {"Cell 1.25", 7750726, 241698},
  {"Cell 1.26", 7750821, 241701},
  {"i:46", 7750910, 241704},
  {"c:24", 7751009, 241707},
  {"i:47", 7751108, 241710},
  {"(1.4.3)", 7751195, 241713},
  {"i:140", 7751282, 241716},
  {"(1.4.4)", 7751370, 241719},
  {"i:139", 7751457, 241722},
  {"(1.4.5)", 7751545, 241725},
  {"(1.4.6)", 7751634, 241728},
  {"i:138", 7751721, 241731},
  {"(1.4.7)", 7751809, 241734},
  {"i:124", 7751896, 241737},
  {"Cell 1.27", 7751986, 241740},
  {"Cell 1.28", 7752081, 241743},
  {"Cell 1.29", 7752174, 241746},
  {"Cell 1.30", 7752267, 241749},
  {"i:136", 7752358, 241752},
  {"Cell 1.31", 7752450, 241755},
  {"(1.4.8)", 7752541, 241758},
  {"(1.4.9)", 7752629, 241761},
  {"Cell 1.32", 7752719, 241764},
  {"Cell 1.33", 7752814, 241767},
  {"Cell 1.34", 7752910, 241770},
  {"Cell 1.35", 7753005, 241773},
  {"Cell 1.36", 7753099, 241776},
  {"i:147", 7753190, 241779},
  {"Cell 1.37", 7753282, 241782},
  {"Cell 1.38", 7753376, 241785},
  {"i:51", 7753465, 241788},
  {"i:142", 7753550, 241791},
  {"Cell 1.39", 7753639, 241794},
  {"Cell 1.40", 7753735, 241797},
  {"i:48", 7753826, 241800},
  {"i:49", 7753911, 241803},
  {"c:25", 7754011, 241806},
  {"(1.4.10)", 7754115, 241809},
  {"i:125", 7754203, 241812},
  {"Fig. 1.11", 7754311, 241815},
  {"(1.4.11)", 7754418, 241818},
  {"i:143", 7754506, 241821},
  {"(1.4.12)", 7754596, 241824},
  {"Cell 1.41", 7754687, 241827},
  {"Cell 1.42", 7754783, 241830},
  {"Cell 1.43", 7754877, 241833},
  {"i:53", 7754968, 241836},
  {"i:52", 7755052, 241839},
  {"c:26", 7755152, 241842},
  {"(1.4.13)", 7755256, 241845},
  {"(1.4.14)", 7755347, 241848},
  {"(1.4.15)", 7755438, 241851},
  {"(1.4.16)", 7755529, 241854},
  {"(1.4.17)", 7755620, 241857},
  {"(1.4.18)", 7755712, 241860},
  {"(1.4.19)", 7755803, 241863},
  {"(1.4.20)", 7755894, 241866},
  {"Cell 1.44", 7755986, 241869},
  {"Cell 1.45", 7756080, 241872},
  {"Cell 1.46", 7756176, 241875},
  {"Cell 1.47", 7756270, 241878},
  {"Cell 1.48", 7756364, 241881},
  {"i:54", 7756453, 241884},
  {"c:27", 7756553, 241887},
  {"(1.4.21)", 7756657, 241890},
  {"(1.4.22)", 7756749, 241893},
  {"Cell 1.49", 7756842, 241896},
  {"Cell 1.50", 7756936, 241899},
  {"(1.4.23)", 7757032, 241902},
  {"(1.4.24)", 7757124, 241905},
  {"Cell 1.51", 7757216, 241908},
  {"Cell 1.52", 7757310, 241911},
  {"Cell 1.53", 7757404, 241914},
  {"Cell 1.54", 7757497, 241917},
  {"Cell 1.55", 7757590, 241920},
  {"Cell 1.56", 7757685, 241923},
  {"Table 1.2", 7757781, 241926},
  {"Cell 1.57", 7757875, 241929},
  {"Cell 1.58", 7757972, 241932},
  {"i:145", 7758062, 241935},
  {"Cell 1.59", 7758151, 241938},
  {"Cell 1.60", 7758245, 241941},
  {"Cell 1.61", 7758339, 241944},
  {"Cell 1.62", 7758433, 241947},
  {"Cell 1.63", 7758527, 241950},
  {"Cell 1.64", 7758621, 241953},
  {"Cell 1.65", 7758715, 241956},
  {"Ex. 1.4", 7758807, 241959},
  {"c:28", 7758910, 241962},
  {"i:55", 7759013, 241965},
  {"i:127", 7759100, 241968},
  {"i:56", 7759186, 241971},
  {"i:57", 7759271, 241974},
  {"Fig. 1.12", 7759360, 241977},
  {"i:58", 7759452, 241980},
  {"i:59", 7759537, 241983},
  {"i:60", 7759623, 241986},
  {"(1.4.25)", 7759714, 241989},
  {"i:62", 7759803, 241992},
  {"Fig. 1.13", 7759893, 241995},
  {"i:129", 7759997, 241998},
  {"Fig. 1.14", 7760105, 242001},
  {"i:63", 7760198, 242004},
  {"i:107", 7760286, 242007},
  {"Fig. 1.15", 7760379, 242010},
  {"ex 13", 7760473, 242013},
  {"i:64", 7760559, 242016},
  {"(1.4.26)", 7760649, 242019},
  {"(1.4.27)", 7760741, 242022},
  {"(1.4.28)", 7760833, 242025},
  {"i:65", 7760921, 242028},
  {"i:66", 7761007, 242031},
  {"(1.4.29)", 7761096, 242034},
  {"(1.4.30)", 7761188, 242037},
  {"i:78", 7761286, 242040},
  {"(1.4.31)", 7761388, 242043},
  {"i:67", 7761486, 242046},
  {"(1.4.32)", 7761588, 242049},
  {"i:68", 7761686, 242052},
  {"i:69", 7761784, 242055},
  {"i:75", 7761869, 242058},
  {"(1.4.33)", 7761959, 242061},
  {"i:76", 7762048, 242064},
  {"i:77", 7762134, 242067},
  {"i:74", 7762221, 242070},
  {"i:71", 7762307, 242073},
  {"i:72", 7762394, 242076},
  {"i:73", 7762479, 242079},
  {"Cell 1.66", 7762570, 242082},
  {"Cell 1.67", 7762665, 242085},
  {"Cell 1.68", 7762760, 242088},
  {"Cell 1.69", 7762856, 242091},
  {"i:144", 7762948, 242094},
  {"Sec. 1.5", 7763038, 242097},
  {"i:79", 7763149, 242100},
  {"c:29", 7763260, 242103},
  {"c:30", 7763371, 242106},
  {"(1.5.1)", 7763465, 242109},
  {"i:120", 7763552, 242112},
  {"(1.5.2)", 7763641, 242115},
  {"(1.5.3)", 7763730, 242118},
  {"(1.5.4)", 7763819, 242121},
  {"i:17", 7763905, 242124},
  {"(1.5.5)", 7763992, 242127},
  {"(1.5.6)", 7764081, 242130},
  {"(1.5.7)", 7764170, 242133},
  {"(1.5.8)", 7764259, 242136},
  {"(1.5.9)", 7764348, 242139},
  {"(1.5.10)", 7764438, 242142},
  {"i:80", 7764525, 242145},
  {"i:43", 7764610, 242148},
  {"c:31", 7764711, 242151},
  {"(1.5.11)", 7764816, 242154},
  {"i:122", 7764905, 242157},
  {"(1.5.12)", 7764993, 242160},
  {"Cell 1.70", 7765085, 242163},
  {"Cell 1.71", 7765180, 242166},
  {"Cell 1.72", 7765275, 242169},
  {"Cell 1.73", 7765370, 242172},
  {"Cell 1.74", 7765464, 242175},
  {"Cell 1.75", 7765559, 242178},
  {"Cell 1.76", 7765654, 242181},
  {"Cell 1.77", 7765748, 242184},
  {"Cell 1.78", 7765843, 242187},
  {"Ex. 1.5", 7765936, 242190},
  {"c:32", 7766040, 242193},
  {"(1.5.13)", 7766148, 242196},
  {"(1.5.14)", 7766240, 242199},
  {"Fig. 1.16", 7766332, 242202},
  {"Fig. 1.17", 7766430, 242205},
  {"Sec. 1.6", 7766525, 242208},
  {"i:81", 7766634, 242211},
  {"c:33", 7766743, 242214},
  {"c:34", 7766852, 242217},
  {"c:35", 7766942, 242220},
  {"(1.6.1)", 7767032, 242223},
  {"(1.6.2)", 7767122, 242226},
  {"i:91", 7767219, 242229},
  {"i:104", 7767317, 242232},
  {"c:36", 7767403, 242235},
  {"i:131", 7767490, 242238},
  {"(1.6.3)", 7767579, 242241},
  {"i:130", 7767678, 242244},
  {"i:83", 7767776, 242247},
  {"c:37", 7767859, 242250},
  {"i:85", 7767945, 242253},
  {"(1.6.4)", 7768033, 242256},
  {"(1.6.5)", 7768122, 242259},
  {"i:82", 7768208, 242262},
  {"c:38", 7768295, 242265},
  {"c:39", 7768385, 242268},
  {"(1.6.6)", 7768474, 242271},
  {"i:84", 7768560, 242274},
  {"(1.6.7)", 7768648, 242277},
  {"(1.6.8)", 7768738, 242280},
  {"(1.6.9)", 7768828, 242283},
  {"(1.6.10)", 7768918, 242286},
  {"i:89", 7769015, 242289},
  {"i:90", 7769112, 242292},
  {"(1.6.11)", 7769201, 242295},
  {"i:117", 7769289, 242298},
  {"Cell 1.79", 7769379, 242301},
  {"c:40", 7769469, 242304},
  {"(1.6.12)", 7769560, 242307},
  {"(1.6.13)", 7769651, 242310},
  {"(1.6.14)", 7769742, 242313},
  {"i:118", 7769831, 242316},
  {"(1.6.15)", 7769921, 242319},
  {"(1.6.16)", 7770012, 242322},
  {"(1.6.17)", 7770103, 242325},
  {"i:92", 7770201, 242328},
  {"c:41", 7770299, 242331},
  {"(1.6.18)", 7770394, 242334},
  {"i:44", 7770481, 242337},
  {"(1.6.19)", 7770571, 242340},
  {"i:126", 7770660, 242343},
  {"(1.6.20)", 7770749, 242346},
  {"(1.6.21)", 7770841, 242349},
  {"i:99", 7770931, 242352},
  {"i:100", 7771017, 242355},
  {"(1.6.22)", 7771107, 242358},
  {"i:134", 7771196, 242361},
  {"(1.6.23)", 7771287, 242364},
  {"Cell 1.80", 7771380, 242367},
  {"(1.6.24)", 7771475, 242370},
  {"i:101", 7771564, 242373},
  {"(1.6.25)", 7771654, 242376},
  {"i:105", 7771754, 242379},
  {"Cell 1.81", 7771858, 242382},
  {"Cell 1.82", 7771954, 242385},
  {"Cell 1.83", 7772049, 242388},
  {"i:116", 7772142, 242391},
  {"c:42", 7772228, 242394},
  {"c:43", 7772318, 242397},
  {"i:86", 7772404, 242400},
  {"(1.6.26)", 7772493, 242403},
  {"i:119", 7772581, 242406},
  {"(1.6.27)", 7772670, 242409},
  {"i:87", 7772757, 242412},
  {"(1.6.28)", 7772845, 242415},
  {"(1.6.29)", 7772936, 242418},
  {"i:88", 7773023, 242421},
  {"i:93", 7773108, 242424},
  {"c:44", 7773204, 242427},
  {"i:94", 7773300, 242430},
  {"(1.6.30)", 7773389, 242433},
  {"(1.6.31)", 7773480, 242436},
  {"(1.6.32)", 7773571, 242439},
  {"(1.6.33)", 7773662, 242442},
  {"(1.6.34)", 7773753, 242445},
  {"i:103", 7773841, 242448},
  {"c:45", 7773938, 242451},
  {"(1.6.35)", 7774039, 242454},
  {"(1.6.36)", 7774130, 242457},
  {"(1.6.37)", 7774221, 242460},
  {"(1.6.38)", 7774312, 242463},
  {"(1.6.39)", 7774403, 242466},
  {"(1.6.40)", 7774494, 242469},
  {"(1.6.41)", 7774585, 242472},
  {"(1.6.42)", 7774676, 242475},
  {"(1.6.43)", 7774768, 242478},
  {"i:95", 7774855, 242481},
  {"(1.6.44)", 7774944, 242484},
  {"(1.6.45)", 7775035, 242487},
  {"Fig. 1.18", 7775127, 242490},
  {"i:102", 7775220, 242493},
  {"i:96", 7775307, 242496},
  {"c:46", 7775403, 242499},
  {"Fig. 1.19", 7775504, 242502},
  {"i:97", 7775597, 242505},
  {"Cell 1.84", 7775687, 242508},
  {"(1.6.46)", 7775782, 242511},
  {"(1.6.47)", 7775874, 242514},
  {"i:141", 7775963, 242517},
  {"Cell 1.85", 7776054, 242520},
  {"Cell 1.86", 7776149, 242523},
  {"Ex. 1.6", 7776242, 242526},
  {"c:47", 7776345, 242529},
  {"i:132", 7776449, 242532},
  {"i:106", 7776537, 242535},
  {"refs", 7776623, 242538},
  {"c:48", 7776720, 242541}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 117, 1, 111, "Title",
  CellTags->{"chapter 2", "i:5", "c:1"}],
Cell[1847, 55, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1888, 59, 69, 1, 39, "Subtitle",
  CellTags->{"Sec. 1.1", "c:2"}],
Cell[1960, 62, 17, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2002, 66, 59, 1, 41, "Subsubtitle",
  CellTags->"c:3"],

Cell[CellGroupData[{
Cell[2086, 71, 122, 4, 42, "Section",
  CellTags->{"i:1", "c:4"}],
Cell[2211, 77, 887, 24, 78, "Text",
  CellTags->"i:2"],
Cell[3101, 103, 1465, 50, 78, "Text",
  CellTags->"i:4"],
Cell[4569, 155, 173, 3, 27, "NumberedEquation",
  CellTags->"(1.1.1)"],
Cell[4745, 160, 211, 7, 27, "Text"],
Cell[4959, 169, 966, 32, 61, "Text"],
Cell[5928, 203, 206, 6, 39, "NumberedEquation",
  CellTags->"(1.1.2)"],
Cell[6137, 211, 735, 26, 27, "Text"],
Cell[6875, 239, 552, 16, 38, "NumberedEquation",
  CellTags->"(1.1.3)"],
Cell[7430, 257, 2087, 64, 112, "Text",
  CellTags->"i:3"],
Cell[9520, 323, 276, 6, 64, "Text"],
Cell[9799, 331, 1356, 47, 61, "Text",
  CellTags->"i:13"],
Cell[11158, 380, 994, 35, 44, "Text",
  CellTags->"i:9"],
Cell[12155, 417, 902, 37, 29, "NumberedEquation",
  CellTags->"(1.1.4)"],
Cell[13060, 456, 381, 12, 27, "Text"],
Cell[13444, 470, 448, 15, 29, "NumberedEquation",
  CellTags->{"(1.1.5)", "i:70"}],
Cell[13895, 487, 574, 21, 27, "Text"],
Cell[14472, 510, 318, 10, 42, "NumberedEquation",
  CellTags->"(1.1.6)"],
Cell[14793, 522, 988, 36, 44, "Text",
  CellTags->"i:10"],
Cell[15784, 560, 204, 7, 29, "NumberedEquation",
  CellTags->"(1.1.7)"],
Cell[15991, 569, 395, 11, 48, "Text"],
Cell[16389, 582, 649, 26, 29, "NumberedEquation",
  CellTags->"(1.1.8)"],
Cell[17041, 610, 830, 29, 45, "Text"],
Cell[17874, 641, 231, 7, 39, "NumberedEquation",
  CellTags->"(1.1.9)"],
Cell[18108, 650, 355, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[18488, 665, 292, 7, 86, "Input",
  CellTags->"Cell 1.1"],
Cell[18783, 674, 38, 1, 46, "Output"]
}, Open  ]],
Cell[18836, 678, 156, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[19017, 685, 83, 3, 67, "Input",
  CellTags->"Cell 1.2"],
Cell[19103, 690, 36, 1, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19176, 696, 88, 3, 67, "Input",
  CellTags->"Cell 1.3"],
Cell[19267, 701, 36, 1, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[19352, 708, 70, 1, 31, "Section",
  CellTags->"c:5"],
Cell[19425, 711, 1897, 68, 61, "Text",
  CellTags->"i:11"],
Cell[21325, 781, 1683, 55, 78, "Text"],
Cell[23011, 838, 221, 6, 64, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[23269, 849, 77, 1, 31, "Section",
  CellTags->{"i:7", "c:6"}],
Cell[23349, 852, 1440, 50, 112, "Text",
  CellTags->"i:6"],
Cell[24792, 904, 213, 4, 42, "NumberedEquation",
  CellTags->"(1.1.10)"],
Cell[25008, 910, 789, 27, 47, "Text",
  CellTags->"i:8"],
Cell[25800, 939, 542, 14, 45, "NumberedEquation",
  CellTags->"(1.1.11)"],
Cell[26345, 955, 175, 5, 30, "Text"],
Cell[26523, 962, 517, 12, 78, "Text",
  CellTags->"i:123"],
Cell[27043, 976, 415, 9, 61, "Text"],
Cell[27461, 987, 264, 6, 64, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[27762, 998, 79, 1, 31, "Section",
  CellTags->"c:7"],
Cell[27844, 1001, 847, 28, 78, "Text",
  CellTags->"i:12"],
Cell[28694, 1031, 817, 21, 78, "Text"],
Cell[29514, 1054, 98, 3, 27, "Text"],
Cell[29615, 1059, 596, 14, 98, "Text",
  CellTags->"i:121"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[30260, 1079, 124, 2, 30, "Subsubtitle",
  CellTags->{"Ex. 1.1", "c:8"}],
Cell[30387, 1083, 463, 20, 27, "Text"],
Cell[30853, 1105, 257, 6, 44, "Text"],
Cell[31113, 1113, 428, 15, 40, "Text"],
Cell[31544, 1130, 457, 16, 38, "Text"],
Cell[32004, 1148, 1077, 31, 40, "Text"],
Cell[33084, 1181, 312, 7, 44, "Text"],
Cell[33399, 1190, 399, 13, 36, "Text"],
Cell[33801, 1205, 809, 24, 40, "Text"],
Cell[34613, 1231, 752, 20, 40, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[35414, 1257, 109, 1, 40, "Subtitle",
  CellTags->{"Sec. 1.2", "i:14", "c:9"}],
Cell[35526, 1260, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[35567, 1264, 114, 4, 41, "Subsubtitle",
  CellTags->"c:10"],
Cell[35684, 1270, 323, 8, 61, "Text"],
Cell[36010, 1280, 5963, 137, 223, "NE2",
  CellTags->{"(1.2.1)", "i:16"}],
Cell[41976, 1419, 484, 13, 61, "Text"],
Cell[42463, 1434, 249, 8, 38, "NE2",
  CellTags->"(1.2.2)"],
Cell[42715, 1444, 183, 4, 44, "Text"],
Cell[42901, 1450, 1254, 37, 95, "Text"],
Cell[44158, 1489, 43113, 536, 168, 42993, 532, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[87274, 2027, 331, 17, 16, "Caption",
  CellTags->"Fig. 1.1"],
Cell[87608, 2046, 53, 0, 27, "Text"],
Cell[87664, 2048, 259, 7, 38, "NE2",
  CellTags->"(1.2.3)"],
Cell[87926, 2057, 897, 27, 78, "Text",
  CellTags->"i:15"],
Cell[88826, 2086, 131586, 3056, 428, 38279, 1900, "GraphicsData", \
"PostScript", "Picture"],
Cell[220415, 5144, 269, 12, 16, "Caption",
  CellTags->"Fig. 1.2"],
Cell[220687, 5158, 584, 14, 61, "Text"],
Cell[221274, 5174, 160, 6, 29, "NE2",
  CellTags->"(1.2.4)"],
Cell[221437, 5182, 328, 10, 44, "Text"],
Cell[221768, 5194, 478, 14, 44, "Text"],
Cell[222249, 5210, 277, 11, 27, "Text",
  CellTags->"i:18"],
Cell[222529, 5223, 239, 9, 27, "Text"],
Cell[222771, 5234, 91, 3, 67, "Input",
  CellTags->"Cell 1.4"],
Cell[222865, 5239, 295, 6, 105, "Input",
  CellTags->"Cell 1.5"],
Cell[223163, 5247, 400, 9, 61, "Text"],
Cell[223566, 5258, 283, 10, 27, "Text"],
Cell[223852, 5270, 144, 5, 31, "NE2",
  CellTags->"(1.2.5)"],
Cell[223999, 5277, 1314, 40, 112, "Text"],
Cell[225316, 5319, 218, 6, 44, "Text"],
Cell[225537, 5327, 115, 5, 29, "NE2",
  CellTags->"(1.2.6)"],
Cell[225655, 5334, 336, 13, 27, "Text"],
Cell[225994, 5349, 113, 5, 29, "NE2",
  CellTags->"(1.2.7)"],
Cell[226110, 5356, 1031, 32, 95, "Text"],
Cell[227144, 5390, 116569, 2710, 370, 34926, 1697, "GraphicsData", \
"PostScript", "Picture"],
Cell[343716, 8102, 293, 9, 16, "Caption",
  CellTags->"Fig. 1.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[344046, 8116, 120, 4, 30, "Subsubtitle",
  CellTags->"c:11"],

Cell[CellGroupData[{
Cell[344191, 8124, 60, 1, 42, "Section",
  CellTags->{"i:20", "c:12"}],
Cell[344254, 8127, 450, 9, 78, "Text"],
Cell[344707, 8138, 427, 12, 42, "NE2",
  CellTags->"(1.2.8)"],
Cell[345137, 8152, 973, 33, 78, "Text",
  CellTags->"i:25"],
Cell[346113, 8187, 148, 5, 32, "NE2",
  CellTags->"(1.2.9)"],
Cell[346264, 8194, 248, 9, 27, "Text",
  CellTags->"i:109"],
Cell[346515, 8205, 803, 25, 61, "Text"],
Cell[347321, 8232, 305, 5, 38, "NE2",
  CellTags->"(1.2.10)"],
Cell[347629, 8239, 791, 25, 78, "Text"],
Cell[348423, 8266, 855, 29, 78, "Text"],
Cell[349281, 8297, 96603, 1196, 119, 96481, 1192, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[445887, 9495, 286, 10, 16, "Caption",
  CellTags->"Fig. 1.4"],
Cell[446176, 9507, 1075, 31, 95, "Text"],
Cell[447254, 9540, 721, 20, 78, "Text",
  CellTags->"i:114"],

Cell[CellGroupData[{
Cell[448000, 9564, 341, 7, 124, "Input",
  CellTags->"Cell 1.6"],
Cell[448344, 9573, 90820, 2377, 349, 35427, 1689, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[539213, 11956, 71, 1, 31, "Section",
  CellTags->"c:13"],
Cell[539287, 11959, 520, 11, 78, "Text"],
Cell[539810, 11972, 75782, 939, 370, 75660, 935, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[615595, 12913, 306, 14, 16, "Caption",
  CellTags->"Fig. 1.5"],
Cell[615904, 12929, 892, 21, 91, "Text"],
Cell[616799, 12952, 621, 17, 69, "NE2",
  CellTags->"(1.2.11)"],
Cell[617423, 12971, 1284, 40, 88, "Text"],
Cell[618710, 13013, 935, 26, 44, "NE2",
  CellTags->"(1.2.12)"],
Cell[619648, 13041, 2301, 73, 99, "Text"],
Cell[621952, 13116, 1062, 29, 34, "NE2",
  CellTags->"(1.2.13)"],
Cell[623017, 13147, 659, 20, 44, "Text"],
Cell[623679, 13169, 1519734, 21030, 154, 1473229, 20451, "GraphicsData", \
"PostScript", "Picture"],
Cell[2143416, 34201, 407, 16, 16, "Caption",
  CellTags->"Fig. 1.6"],
Cell[2143826, 34219, 928, 33, 56, "Text"],
Cell[2144757, 34254, 793, 22, 41, "NE2",
  CellTags->"(1.2.14)"],
Cell[2145553, 34278, 56, 0, 27, "Text"],
Cell[2145612, 34280, 600, 12, 78, "Text",
  CellTags->"i:113"],
Cell[2146215, 34294, 140268, 3237, 370, 39779, 1992, "GraphicsData", \
"PostScript", "Picture"],
Cell[2286486, 37533, 345, 15, 16, "Caption",
  CellTags->"Fig. 1.7"]
}, Closed]],

Cell[CellGroupData[{
Cell[2286868, 37553, 58, 1, 31, "Section",
  CellTags->"c:14"],
Cell[2286929, 37556, 295, 7, 44, "Text",
  CellTags->"i:21"],
Cell[2287227, 37565, 715, 20, 86, "NE2",
  CellTags->"(1.2.15)"],
Cell[2287945, 37587, 703, 26, 44, "Text",
  CellTags->"i:22"],
Cell[2288651, 37615, 947, 25, 46, "NE2",
  CellTags->"(1.2.16)"],
Cell[2289601, 37642, 343, 11, 44, "Text",
  CellTags->"i:23"],
Cell[2289947, 37655, 316, 11, 47, "NE2",
  CellTags->"(1.2.17)"],
Cell[2290266, 37668, 565, 17, 61, "Text"],
Cell[2290834, 37687, 1130, 28, 40, "Text"],
Cell[2291967, 37717, 55, 0, 27, "Text"],
Cell[2292025, 37719, 874, 20, 41, "NE2",
  CellTags->"(1.2.18)"],
Cell[2292902, 37741, 630, 22, 61, "Text"],
Cell[2293535, 37765, 904, 26, 95, "Text",
  CellTags->"i:24"],
Cell[2294442, 37793, 1218, 33, 129, "Text",
  CellTags->"i:112"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2295709, 37832, 78, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 1.2", "c:15"}],
Cell[2295790, 37835, 1134, 37, 59, "Text"],
Cell[2296927, 37874, 318, 9, 44, "Text"],
Cell[2297248, 37885, 383, 15, 37, "Text"],
Cell[2297634, 37902, 383, 15, 37, "Text"],
Cell[2298020, 37919, 758, 25, 44, "Text"],
Cell[2298781, 37946, 372, 10, 44, "Text"],
Cell[2299156, 37958, 365, 11, 38, "NE2",
  CellTags->"(1.2.19)"],
Cell[2299524, 37971, 1017, 33, 55, "Text",
  CellTags->"i:37"],
Cell[2300544, 38006, 91986, 1139, 142, 91864, 1135, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[2392533, 39147, 68, 1, 16, "Caption",
  CellTags->"Fig. 1.8"],
Cell[2392604, 39150, 987, 33, 48, "Text"],
Cell[2393594, 39185, 251, 6, 44, "Text"],
Cell[2393848, 39193, 486, 17, 45, "Text"],
Cell[2394337, 39212, 378, 12, 44, "Text",
  CellTags->"i:108"],
Cell[2394718, 39226, 969, 29, 75, "Text"],
Cell[2395690, 39257, 237, 6, 44, "Text",
  CellTags->"i:38"],
Cell[2395930, 39265, 166, 6, 33, "NE2",
  CellTags->"(1.2.20)"],
Cell[2396099, 39273, 513, 11, 61, "Text"],
Cell[2396615, 39286, 493, 17, 45, "Text"],
Cell[2397111, 39305, 219, 7, 28, "Text"],
Cell[2397333, 39314, 442, 14, 44, "Text"],
Cell[2397778, 39330, 286, 9, 42, "NE2",
  CellTags->"(1.2.21)"],
Cell[2398067, 39341, 460, 16, 46, "Text",
  CellTags->"i:39"],
Cell[2398530, 39359, 126, 5, 32, "NE2",
  CellTags->"(1.2.22)"],
Cell[2398659, 39366, 338, 10, 45, "Text"],
Cell[2399000, 39378, 301, 11, 43, "NE2",
  CellTags->"(1.2.23)"],
Cell[2399304, 39391, 398, 14, 46, "Text"],
Cell[2399705, 39407, 169, 5, 28, "Text"],
Cell[2399877, 39414, 183, 6, 27, "Text"],
Cell[2400063, 39422, 211, 6, 27, "Text"],
Cell[2400277, 39430, 1101, 29, 98, "Text"],
Cell[2401381, 39461, 436, 14, 45, "Text"],
Cell[2401820, 39477, 2074, 63, 95, "Text"],
Cell[2403897, 39542, 1604, 48, 44, "Text"],
Cell[2405504, 39592, 1253, 39, 38, "NE2",
  CellTags->{"(1.2.24)", "i:36"}],
Cell[2406760, 39633, 971, 35, 27, "Text"],
Cell[2407734, 39670, 854, 30, 44, "Text"],
Cell[2408591, 39702, 120, 5, 30, "Text"],
Cell[2408714, 39709, 319, 11, 30, "Text"],
Cell[2409036, 39722, 1296, 39, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2410381, 39767, 414, 15, 74, "Subtitle",
  CellTags->{"Sec. 1.3", "c:16"}],
Cell[2410798, 39784, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2410839, 39788, 162, 7, 41, "Subsubtitle",
  CellTags->"c:17"],
Cell[2411004, 39797, 366, 10, 44, "Text"],
Cell[2411373, 39809, 155, 4, 27, "Text",
  CellTags->"i:29"],
Cell[2411531, 39815, 171, 6, 42, "NE3",
  CellTags->"(1.3.1)"],
Cell[2411705, 39823, 203, 7, 27, "Text"],
Cell[2411911, 39832, 248, 9, 27, "Text",
  CellTags->"i:30"],
Cell[2412162, 39843, 2909, 97, 63, "Text"],

Cell[CellGroupData[{
Cell[2415096, 39944, 147, 4, 67, "Input",
  CellTags->"Cell 1.7"],
Cell[2415246, 39950, 115, 2, 46, "Output"]
}, Open  ]],
Cell[2415376, 39955, 391, 11, 44, "Text"],
Cell[2415770, 39968, 281, 9, 44, "Text"],
Cell[2416054, 39979, 340, 13, 27, "Text"],
Cell[2416397, 39994, 407, 16, 44, "Text"],

Cell[CellGroupData[{
Cell[2416829, 40014, 271, 6, 86, "Input",
  CellTags->"Cell 1.8"],
Cell[2417103, 40022, 130, 3, 68, "Output"]
}, Open  ]],
Cell[2417248, 40028, 180, 6, 27, "Text"],
Cell[2417431, 40036, 623, 17, 78, "Text"],

Cell[CellGroupData[{
Cell[2418079, 40057, 421, 9, 105, "Input",
  CellTags->"Cell 1.9"],
Cell[2418503, 40068, 718, 12, 104, "Output"]
}, Open  ]],
Cell[2419236, 40083, 365, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[2419626, 40100, 113, 3, 67, "Input",
  CellTags->"Cell 1.10"],
Cell[2419742, 40105, 66, 1, 64, "Output"]
}, Open  ]],
Cell[2419823, 40109, 856, 27, 64, "Text",
  CellTags->"i:31"],
Cell[2420682, 40138, 140, 5, 30, "NE3",
  CellTags->"(1.3.2)"],
Cell[2420825, 40145, 57, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2420907, 40149, 132, 3, 67, "Input",
  CellTags->"Cell 1.11"],
Cell[2421042, 40154, 84, 1, 46, "Output"]
}, Open  ]],
Cell[2421141, 40158, 1143, 38, 95, "Text",
  CellTags->"i:133"],

Cell[CellGroupData[{
Cell[2422309, 40200, 452, 10, 143, "Input",
  CellTags->"Cell 1.12"],
Cell[2422764, 40212, 61567, 1325, 277, 11862, 708, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2484346, 41540, 198, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[2484569, 41548, 136, 3, 67, "Input",
  CellTags->"Cell 1.13"],
Cell[2484708, 41553, 290, 8, 68, "Output"]
}, Open  ]],
Cell[2485013, 41564, 529, 11, 78, "Text"],
Cell[2485545, 41577, 1114, 23, 129, "Text",
  CellTags->"i:32"],
Cell[2486662, 41602, 260, 5, 44, "Text"],
Cell[2486925, 41609, 692, 20, 86, "Text",
  CellTags->"i:33"],
Cell[2487620, 41631, 3740, 109, 88, "Text",
  CellTags->"Table 1.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[2491397, 41745, 79, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 1.3", "c:18"}],
Cell[2491479, 41748, 923, 31, 78, "Text"],
Cell[2492405, 41781, 1144, 36, 110, "Text",
  CellTags->"i:128"],
Cell[2493552, 41819, 353, 11, 87, "Text"],
Cell[2493908, 41832, 167, 5, 27, "Text"],
Cell[2494078, 41839, 272, 8, 47, "Text"],
Cell[2494353, 41849, 1244, 36, 123, "Text"],
Cell[2495600, 41887, 324, 13, 27, "Text"],
Cell[2495927, 41902, 161, 6, 30, "NE3",
  CellTags->"(1.3.3)"],
Cell[2496091, 41910, 229, 10, 27, "Text"],
Cell[2496323, 41922, 887, 35, 64, "Text"],
Cell[2497213, 41959, 595, 21, 45, "Text",
  CellTags->"i:110"],
Cell[2497811, 41982, 113, 4, 27, "Text"],
Cell[2497927, 41988, 664, 24, 47, "Text"],
Cell[2498594, 42014, 195, 5, 44, "Text"],
Cell[2498792, 42021, 2165, 72, 100, "Text"],
Cell[2500960, 42095, 191, 5, 44, "Text"],
Cell[2501154, 42102, 128, 4, 27, "Text"],
Cell[2501285, 42108, 840, 26, 63, "Text",
  CellTags->"i:115"],
Cell[2502128, 42136, 989, 34, 29, "Text"],
Cell[2503120, 42172, 862, 32, 44, "Text"],
Cell[2503985, 42206, 1131, 35, 29, "NE3",
  CellTags->"(1.3.4)"],
Cell[2505119, 42243, 820, 28, 45, "Text"],
Cell[2505942, 42273, 795, 30, 61, "Text",
  CellTags->"i:135"],
Cell[2506740, 42305, 1048, 43, 48, "Text"],
Cell[2507791, 42350, 851, 33, 61, "Text",
  CellTags->"i:137"],
Cell[2508645, 42385, 530, 21, 44, "Text",
  CellTags->"i:146"],
Cell[2509178, 42408, 274, 7, 42, "NE3",
  CellTags->"(1.3.5)"],
Cell[2509455, 42417, 222, 9, 27, "Text"],
Cell[2509680, 42428, 305, 10, 44, "Text"],
Cell[2509988, 42440, 593, 18, 36, "Text"],
Cell[2510584, 42460, 1193, 41, 97, "Text",
  CellTags->"i:34"],
Cell[2511780, 42503, 875, 27, 67, "Text",
  CellTags->"i:35"],
Cell[2512658, 42532, 2416, 65, 68, "NE3",
  CellTags->"(1.3.6)"],
Cell[2515077, 42599, 1522, 49, 127, "Text"],
Cell[2516602, 42650, 910, 30, 44, "Text"],
Cell[2517515, 42682, 2347, 65, 68, "NE3",
  CellTags->"(1.3.7)"],
Cell[2519865, 42749, 542, 17, 54, "Text"],
Cell[2520410, 42768, 357, 9, 40, "Text"],
Cell[2520770, 42779, 328, 9, 44, "Text"],
Cell[2521101, 42790, 170, 6, 33, "NE3",
  CellTags->"(1.3.8)"],
Cell[2521274, 42798, 272, 11, 27, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2521595, 42815, 110, 1, 40, "Subtitle",
  CellTags->{"Sec. 1.4", "i:42", "c:19"}],
Cell[2521708, 42818, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2521749, 42822, 163, 7, 41, "Subsubtitle",
  CellTags->"c:20"],
Cell[2521915, 42831, 475, 19, 44, "Text"],
Cell[2522393, 42852, 684, 29, 27, "Text",
  CellTags->"i:40"],
Cell[2523080, 42883, 156, 6, 27, "Text"],
Cell[2523239, 42891, 127, 5, 27, "Text"],
Cell[2523369, 42898, 115, 3, 27, "Text"],
Cell[2523487, 42903, 189, 6, 27, "Text"],
Cell[2523679, 42911, 236, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[2523940, 42921, 176, 4, 67, "Input",
  CellTags->"Cell 1.14"],
Cell[2524119, 42927, 272, 7, 46, "Output"]
}, Open  ]],
Cell[2524406, 42937, 1742, 61, 112, "Text",
  CellTags->"i:41"],
Cell[2526151, 43000, 633, 20, 61, "Text"],

Cell[CellGroupData[{
Cell[2526809, 43024, 98, 3, 67, "Input",
  CellTags->"Cell 1.15"],
Cell[2526910, 43029, 156, 4, 46, "Output"]
}, Open  ]],
Cell[2527081, 43036, 166, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[2527272, 43046, 104, 3, 67, "Input",
  CellTags->"Cell 1.16"],
Cell[2527379, 43051, 21013, 468, 233, 3614, 249, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2548407, 43522, 813, 20, 95, "Text",
  CellTags->"i:45"],

Cell[CellGroupData[{
Cell[2549245, 43546, 221, 5, 105, "Input",
  CellTags->"Cell 1.17"],
Cell[2549469, 43553, 77140, 1773, 233, 15127, 1003, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2626624, 45329, 95, 3, 27, "Text"],
Cell[2626722, 45334, 813, 25, 79, "Text"],

Cell[CellGroupData[{
Cell[2627560, 45363, 224, 6, 86, "Input",
  CellTags->"Cell 1.18"],
Cell[2627787, 45371, 272, 7, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2628096, 45383, 98, 3, 67, "Input",
  CellTags->"Cell 1.19"],
Cell[2628197, 45388, 156, 4, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2628390, 45397, 117, 3, 67, "Input",
  CellTags->"Cell 1.20"],
Cell[2628510, 45402, 55845, 1112, 233, 7638, 512, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2684370, 46517, 2262, 75, 146, "Text",
  CellTags->"i:111"],
Cell[2686635, 46594, 329, 7, 105, "Input",
  CellTags->"Cell 1.21"],
Cell[2686967, 46603, 149, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[2687141, 46613, 123, 3, 67, "Input",
  CellTags->"Cell 1.22"],
Cell[2687267, 46618, 61872, 1282, 233, 9767, 634, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2749154, 47903, 877, 27, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2750068, 47935, 130, 2, 30, "Subsubtitle",
  CellTags->{"i:26", "c:21"}],

Cell[CellGroupData[{
Cell[2750223, 47941, 76, 1, 42, "Section",
  CellTags->"c:22"],
Cell[2750302, 47944, 386, 11, 44, "Text"],
Cell[2750691, 47957, 246, 8, 30, "NE4",
  CellTags->{"(1.4.1)", "i:50"}],
Cell[2750940, 47967, 432, 10, 61, "Text"],
Cell[2751375, 47979, 1252, 39, 96, "Text"],
Cell[2752630, 48020, 44856, 1617, 233, 20855, 1316, "GraphicsData", \
"PostScript", "Picture"],
Cell[2797489, 49639, 206, 5, 29, "Caption",
  CellTags->"Fig. 1.9"],
Cell[2797698, 49646, 478, 15, 44, "Text"],
Cell[2798179, 49663, 1424, 46, 95, "Text",
  CellTags->"i:27"],
Cell[2799606, 49711, 42367, 961, 233, 8674, 541, "GraphicsData", \
"PostScript", "Picture"],
Cell[2841976, 50674, 102, 1, 16, "Caption",
  CellTags->"Fig. 1.10"],
Cell[2842081, 50677, 1158, 33, 102, "Text"],
Cell[2843242, 50712, 265, 6, 64, "Text"],
Cell[2843510, 50720, 412, 7, 78, "Text"],
Cell[2843925, 50729, 384, 6, 78, "Text"],
Cell[2844312, 50737, 462, 10, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2844811, 50752, 70, 1, 31, "Section",
  CellTags->{"i:28", "c:23"}],
Cell[2844884, 50755, 716, 26, 61, "Text"],
Cell[2845603, 50783, 2860, 114, 61, "Text"],
Cell[2848466, 50899, 112, 4, 27, "Text"],
Cell[2848581, 50905, 3482, 84, 42, "NE4",
  CellTags->"(1.4.2)"],
Cell[2852066, 50991, 964, 29, 78, "Text"],
Cell[2853033, 51022, 766, 25, 61, "Text"],
Cell[2853802, 51049, 467, 15, 62, "Text"],
Cell[2854272, 51066, 584, 19, 27, "Text"],
Cell[2854859, 51087, 372, 8, 124, "Input",
  CellTags->"Cell 1.23"],
Cell[2855234, 51097, 470, 15, 44, "Text"],
Cell[2855707, 51114, 212, 5, 67, "Input",
  CellTags->"Cell 1.24"],
Cell[2855922, 51121, 320, 9, 44, "Text"],
Cell[2856245, 51132, 495, 9, 124, "Input",
  CellTags->"Cell 1.25"],
Cell[2856743, 51143, 754, 23, 27, "Text"],

Cell[CellGroupData[{
Cell[2857522, 51170, 387, 8, 86, "Input",
  CellTags->"Cell 1.26"],
Cell[2857912, 51180, 42844, 1219, 233, 13842, 857, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2900771, 52402, 812, 18, 101, "Text"],
Cell[2901586, 52422, 2428, 73, 133, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2904063, 52501, 73, 1, 30, "Subsubtitle",
  CellTags->{"i:46", "c:24"}],
Cell[2904139, 52504, 669, 17, 78, "Text",
  CellTags->"i:47"],
Cell[2904811, 52523, 200, 8, 27, "Text"],
Cell[2905014, 52533, 316, 11, 38, "NE4",
  CellTags->"(1.4.3)"],
Cell[2905333, 52546, 104, 3, 27, "Text"],
Cell[2905440, 52551, 350, 13, 44, "Text",
  CellTags->"i:140"],
Cell[2905793, 52566, 399, 14, 29, "NE4",
  CellTags->"(1.4.4)"],
Cell[2906195, 52582, 992, 35, 61, "Text",
  CellTags->"i:139"],
Cell[2907190, 52619, 207, 6, 27, "Text"],
Cell[2907400, 52627, 632, 19, 39, "NE4",
  CellTags->"(1.4.5)"],
Cell[2908035, 52648, 292, 13, 27, "Text"],
Cell[2908330, 52663, 419, 14, 44, "Text"],
Cell[2908752, 52679, 797, 23, 37, "NE4",
  CellTags->"(1.4.6)"],
Cell[2909552, 52704, 1405, 47, 65, "Text"],
Cell[2910960, 52753, 551, 21, 44, "Text",
  CellTags->"i:138"],
Cell[2911514, 52776, 623, 17, 33, "NE4",
  CellTags->"(1.4.7)"],
Cell[2912140, 52795, 923, 28, 78, "Text",
  CellTags->"i:124"],
Cell[2913066, 52825, 2638, 83, 80, "Text"],
Cell[2915707, 52910, 271, 7, 105, "Input",
  CellTags->"Cell 1.27"],
Cell[2915981, 52919, 1974, 63, 95, "Text"],
Cell[2917958, 52984, 2619, 84, 61, "Text"],

Cell[CellGroupData[{
Cell[2920602, 53072, 86, 3, 67, "Input",
  CellTags->"Cell 1.28"],
Cell[2920691, 53077, 124, 2, 31, "Message"],
Cell[2920818, 53081, 124, 2, 31, "Message"],
Cell[2920945, 53085, 124, 2, 31, "Message"],
Cell[2921072, 53089, 175, 3, 50, "Message"]
}, Open  ]],
Cell[2921262, 53095, 1008, 30, 61, "Text"],
Cell[2922273, 53127, 88, 3, 67, "Input",
  CellTags->"Cell 1.29"],
Cell[2922364, 53132, 305, 7, 105, "Input",
  CellTags->"Cell 1.30"],
Cell[2922672, 53141, 2651, 79, 103, "Text",
  CellTags->"i:136"],

Cell[CellGroupData[{
Cell[2925348, 53224, 86, 3, 67, "Input",
  CellTags->"Cell 1.31"],
Cell[2925437, 53229, 41, 1, 46, "Output"]
}, Open  ]],
Cell[2925493, 53233, 4134, 133, 61, "Text"],
Cell[2929630, 53368, 1898, 59, 112, "Text"],
Cell[2931531, 53429, 204, 7, 27, "Text"],
Cell[2931738, 53438, 179, 8, 29, "NE4",
  CellTags->"(1.4.8)"],
Cell[2931920, 53448, 223, 9, 27, "Text"],
Cell[2932146, 53459, 125, 2, 30, "NE4",
  CellTags->"(1.4.9)"],
Cell[2932274, 53463, 4938, 147, 112, "Text"],
Cell[2937215, 53612, 555, 16, 69, "Input",
  CellTags->"Cell 1.32"],
Cell[2937773, 53630, 1362, 39, 95, "Text"],
Cell[2939138, 53671, 56, 0, 27, "Text"],
Cell[2939197, 53673, 454, 10, 143, "Input",
  CellTags->"Cell 1.33"],
Cell[2939654, 53685, 274, 8, 44, "Text"],
Cell[2939931, 53695, 184, 5, 105, "Input",
  CellTags->"Cell 1.34"],
Cell[2940118, 53702, 1595, 50, 27, "Text"],

Cell[CellGroupData[{
Cell[2941738, 53756, 149, 4, 67, "Input",
  CellTags->"Cell 1.35"],
Cell[2941890, 53762, 707, 11, 122, "Output"]
}, Open  ]],
Cell[2942612, 53776, 430, 14, 44, "Text"],

Cell[CellGroupData[{
Cell[2943067, 53794, 392, 9, 124, "Input",
  CellTags->"Cell 1.36"],
Cell[2943462, 53805, 21187, 504, 233, 4178, 290, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2964664, 54312, 1199, 39, 103, "Text",
  CellTags->"i:147"],
Cell[2965866, 54353, 270, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[2966161, 54365, 127, 3, 67, "Input",
  CellTags->"Cell 1.37"],
Cell[2966291, 54370, 155, 4, 46, "Output"]
}, Open  ]],
Cell[2966461, 54377, 295, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[2966781, 54389, 201, 4, 86, "Input",
  CellTags->"Cell 1.38"],
Cell[2966985, 54395, 25792, 531, 233, 3623, 253, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2992792, 54929, 1562, 55, 95, "Text"],
Cell[2994357, 54986, 594, 17, 78, "Text",
  CellTags->"i:51"],
Cell[2994954, 55005, 495, 20, 47, "Text"],
Cell[2995452, 55027, 216, 5, 44, "Text",
  CellTags->"i:142"],
Cell[2995671, 55034, 1293, 40, 61, "Text"],
Cell[2996967, 55076, 773, 14, 200, "Input",
  CellTags->"Cell 1.39"],
Cell[2997743, 55092, 487, 15, 61, "Text"],
Cell[2998233, 55109, 1485, 47, 103, "Text"],

Cell[CellGroupData[{
Cell[2999743, 55160, 550, 13, 162, "Input",
  CellTags->"Cell 1.40"],
Cell[3000296, 55175, 37899, 844, 233, 7942, 470, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3038210, 56022, 996, 33, 61, "Text"],
Cell[3039209, 56057, 1708, 55, 67, "Text"],
Cell[3040920, 56114, 848, 25, 78, "Text"],
Cell[3041771, 56141, 1058, 33, 98, "Text",
  CellTags->"i:48"]
}, Closed]],

Cell[CellGroupData[{
Cell[3042866, 56179, 147, 2, 30, "Subsubtitle",
  CellTags->{"i:49", "c:25"}],
Cell[3043016, 56183, 1234, 37, 112, "Text"],
Cell[3044253, 56222, 724, 19, 40, "NE4",
  CellTags->"(1.4.10)"],
Cell[3044980, 56243, 78528, 973, 158, 78410, 969, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[3123511, 57218, 420, 14, 29, "Caption",
  CellTags->{"i:125", "Fig. 1.11"}],
Cell[3123934, 57234, 2108, 66, 141, "Text"],
Cell[3126045, 57302, 270, 10, 27, "Text"],
Cell[3126318, 57314, 475, 12, 40, "NE4",
  CellTags->"(1.4.11)"],
Cell[3126796, 57328, 1766, 65, 81, "Text",
  CellTags->"i:143"],
Cell[3128565, 57395, 2526, 99, 104, "Text"],
Cell[3131094, 57496, 1738, 53, 81, "Text"],
Cell[3132835, 57551, 380, 9, 60, "NE4",
  CellTags->"(1.4.12)"],
Cell[3133218, 57562, 246, 9, 27, "Text"],
Cell[3133467, 57573, 687, 14, 200, "Input",
  CellTags->"Cell 1.41"],
Cell[3134157, 57589, 962, 30, 95, "Text"],
Cell[3135122, 57621, 239, 5, 44, "Text"],
Cell[3135364, 57628, 432, 10, 61, "Text"],
Cell[3135799, 57640, 167, 4, 86, "Input",
  CellTags->"Cell 1.42"],
Cell[3135969, 57646, 156, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[3136150, 57656, 698, 17, 200, "Input",
  CellTags->"Cell 1.43"],
Cell[3136851, 57675, 37506, 877, 233, 8841, 519, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3174372, 58555, 1028, 32, 81, "Text"],
Cell[3175403, 58589, 464, 12, 61, "Text",
  CellTags->"i:53"],
Cell[3175870, 58603, 438, 7, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3176345, 58615, 140, 2, 30, "Subsubtitle",
  CellTags->{"i:52", "c:26"}],
Cell[3176488, 58619, 53, 0, 27, "Text"],
Cell[3176544, 58621, 733, 21, 42, "NE4",
  CellTags->"(1.4.13)"],
Cell[3177280, 58644, 506, 13, 61, "Text"],
Cell[3177789, 58659, 541, 18, 38, "NE4",
  CellTags->"(1.4.14)"],
Cell[3178333, 58679, 598, 19, 44, "Text"],
Cell[3178934, 58700, 961, 32, 38, "NE4",
  CellTags->"(1.4.15)"],
Cell[3179898, 58734, 614, 22, 27, "Text"],
Cell[3180515, 58758, 426, 15, 29, "NE4",
  CellTags->"(1.4.16)"],
Cell[3180944, 58775, 255, 7, 44, "Text"],
Cell[3181202, 58784, 1008, 30, 29, "NE4",
  CellTags->"(1.4.17)"],
Cell[3182213, 58816, 650, 21, 61, "Text"],
Cell[3182866, 58839, 600, 14, 42, "NE4",
  CellTags->"(1.4.18)"],
Cell[3183469, 58855, 24, 0, 27, "Text"],
Cell[3183496, 58857, 324, 10, 27, "NE4",
  CellTags->"(1.4.19)"],
Cell[3183823, 58869, 33, 0, 27, "Text"],
Cell[3183859, 58871, 459, 16, 29, "NE4",
  CellTags->"(1.4.20)"],
Cell[3184321, 58889, 508, 19, 44, "Text"],
Cell[3184832, 58910, 101, 3, 67, "Input",
  CellTags->"Cell 1.44"],
Cell[3184936, 58915, 666, 13, 181, "Input",
  CellTags->"Cell 1.45"],
Cell[3185605, 58930, 940, 28, 95, "Text"],
Cell[3186548, 58960, 926, 33, 44, "Text"],
Cell[3187477, 58995, 171, 5, 67, "Input",
  CellTags->"Cell 1.46"],
Cell[3187651, 59002, 435, 14, 44, "Text"],
Cell[3188089, 59018, 867, 33, 44, "Text"],
Cell[3188959, 59053, 106, 3, 67, "Input",
  CellTags->"Cell 1.47"],

Cell[CellGroupData[{
Cell[3189090, 59060, 125, 3, 67, "Input",
  CellTags->"Cell 1.48"],
Cell[3189218, 59065, 32063, 669, 233, 4830, 329, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3221296, 59737, 199, 4, 44, "Text"],
Cell[3221498, 59743, 328, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3221863, 59754, 175, 3, 30, "Subsubtitle",
  CellTags->{"i:54", "c:27"}],
Cell[3222041, 59759, 497, 10, 78, "Text"],
Cell[3222541, 59771, 580, 12, 78, "Text"],
Cell[3223124, 59785, 1085, 38, 44, "Text"],
Cell[3224212, 59825, 1074, 31, 59, "NE4",
  CellTags->"(1.4.21)"],
Cell[3225289, 59858, 629, 25, 45, "Text"],
Cell[3225921, 59885, 1003, 29, 40, "NE4",
  CellTags->"(1.4.22)"],
Cell[3226927, 59916, 164, 6, 27, "Text"],
Cell[3227094, 59924, 101, 3, 67, "Input",
  CellTags->"Cell 1.49"],
Cell[3227198, 59929, 1300, 25, 295, "Input",
  CellTags->"Cell 1.50"],
Cell[3228501, 59956, 2932, 102, 180, "Text"],
Cell[3231436, 60060, 392, 14, 44, "Text"],
Cell[3231831, 60076, 692, 22, 61, "Text"],
Cell[3232526, 60100, 2040, 62, 27, "Text"],
Cell[3234569, 60164, 374, 13, 27, "Text"],
Cell[3234946, 60179, 255, 9, 27, "Text"],
Cell[3235204, 60190, 2079, 54, 54, "NE4",
  CellTags->"(1.4.23)"],
Cell[3237286, 60246, 667, 23, 61, "Text"],
Cell[3237956, 60271, 606, 22, 44, "Text"],
Cell[3238565, 60295, 186, 4, 44, "Text"],
Cell[3238754, 60301, 646, 19, 45, "Text"],
Cell[3239403, 60322, 825, 27, 33, "NE4",
  CellTags->"(1.4.24)"],
Cell[3240231, 60351, 343, 10, 31, "Text"],
Cell[3240577, 60363, 181, 4, 67, "Input",
  CellTags->"Cell 1.51"],
Cell[3240761, 60369, 272, 9, 44, "Text"],
Cell[3241036, 60380, 966, 32, 61, "Text"],

Cell[CellGroupData[{
Cell[3242027, 60416, 142, 4, 67, "Input",
  CellTags->"Cell 1.52"],
Cell[3242172, 60422, 73, 1, 46, "Output"]
}, Open  ]],
Cell[3242260, 60426, 139, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[3242424, 60433, 97, 3, 67, "Input",
  CellTags->"Cell 1.53"],
Cell[3242524, 60438, 40, 1, 46, "Output"]
}, Open  ]],
Cell[3242579, 60442, 119, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[3242723, 60451, 96, 3, 67, "Input",
  CellTags->"Cell 1.54"],
Cell[3242822, 60456, 2711, 63, 255, "Output"]
}, Open  ]],
Cell[3245548, 60522, 1092, 28, 112, "Text"],

Cell[CellGroupData[{
Cell[3246665, 60554, 346, 8, 105, "Input",
  CellTags->"Cell 1.55"],

Cell[CellGroupData[{
Cell[3247036, 60566, 24216, 490, 370, 3157, 226, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3271255, 61058, 24285, 491, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3295543, 61551, 24353, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3319899, 62045, 24333, 491, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3344235, 62538, 24333, 491, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3368571, 63031, 24373, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3392947, 63525, 24373, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3417323, 64019, 24341, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3441667, 64513, 24346, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3466016, 65007, 24373, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3490392, 65501, 24390, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3514785, 65995, 24284, 491, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3539072, 66488, 24285, 491, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3563360, 66981, 24285, 491, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3587648, 67474, 24373, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3612024, 67968, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3636401, 68462, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3660778, 68956, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3685155, 69450, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3709532, 69944, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3733909, 70438, 24372, 492, 70, 3155, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3758284, 70932, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3782661, 71426, 24285, 491, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3806949, 71919, 24284, 491, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3831236, 72412, 24285, 491, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3855524, 72905, 24390, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3879917, 73399, 24373, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3904293, 73893, 24373, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3928669, 74387, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3953046, 74881, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3977423, 75375, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4001800, 75869, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4026177, 76363, 24372, 492, 70, 3155, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4050552, 76857, 24362, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4074917, 77351, 24272, 491, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4099192, 77844, 24273, 491, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4123468, 78337, 24272, 491, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4147743, 78830, 24365, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4172111, 79324, 24373, 492, 70, 3156, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4196487, 79818, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[4220864, 80312, 24374, 492, 70, 3157, 226, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[4245265, 80808, 459, 14, 61, "Text"],

Cell[CellGroupData[{
Cell[4245749, 80826, 556, 12, 162, "Input",
  CellTags->"Cell 1.56"],
Cell[4246308, 80840, 42272, 1084, 370, 9521, 676, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4288595, 81927, 474, 12, 61, "Text"],
Cell[4289072, 81941, 396, 7, 78, "Text"],
Cell[4289471, 81950, 309, 5, 61, "Text"],
Cell[4289783, 81957, 444, 9, 61, "Text"],
Cell[4290230, 81968, 471, 16, 73, "Text",
  CellTags->"Table 1.2"],
Cell[4290704, 81986, 2598, 47, 186, "Text"],
Cell[4293305, 82035, 176, 4, 44, "Text"],
Cell[4293484, 82041, 1445, 27, 428, "Input",
  CellTags->"Cell 1.57"],
Cell[4294932, 82070, 186, 4, 86, "Input",
  CellTags->"Cell 1.58"],
Cell[4295121, 82076, 341, 7, 61, "Text",
  CellTags->"i:145"],
Cell[4295465, 82085, 690, 12, 112, "Text"],
Cell[4296158, 82099, 190, 4, 44, "Text"],
Cell[4296351, 82105, 105, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[4296481, 82112, 205, 6, 67, "Input",
  CellTags->"Cell 1.59"],
Cell[4296689, 82120, 144, 2, 77, "Output"]
}, Open  ]],
Cell[4296848, 82125, 62, 0, 27, "Text"],
Cell[4296913, 82127, 261, 6, 86, "Input",
  CellTags->"Cell 1.60"],
Cell[4297177, 82135, 164, 6, 27, "Text"],
Cell[4297344, 82143, 230, 5, 86, "Input",
  CellTags->"Cell 1.61"],
Cell[4297577, 82150, 122, 3, 27, "Text"],
Cell[4297702, 82155, 127, 3, 67, "Input",
  CellTags->"Cell 1.62"],
Cell[4297832, 82160, 234, 6, 27, "Text"],
Cell[4298069, 82168, 175, 4, 67, "Input",
  CellTags->"Cell 1.63"],
Cell[4298247, 82174, 268, 6, 86, "Input",
  CellTags->"Cell 1.64"],

Cell[CellGroupData[{
Cell[4298540, 82184, 247, 5, 86, "Input",
  CellTags->"Cell 1.65"],
Cell[4298790, 82191, 1240558, 106318, 288, 1184702, 105624, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5539363, 188512, 338, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5539738, 188523, 78, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 1.4", "c:28"}],
Cell[5539819, 188526, 854, 23, 98, "Text"],
Cell[5540676, 188551, 521, 15, 41, "Text"],
Cell[5541200, 188568, 995, 35, 48, "Text"],
Cell[5542198, 188605, 229, 8, 27, "Text"],
Cell[5542430, 188615, 1132, 36, 81, "Text",
  CellTags->"i:55"],
Cell[5543565, 188653, 1849, 50, 123, "Text"],
Cell[5545417, 188705, 728, 21, 65, "Text",
  CellTags->"i:127"],
Cell[5546148, 188728, 349, 12, 42, "Text"],
Cell[5546500, 188742, 425, 15, 44, "Text"],
Cell[5546928, 188759, 1322, 40, 68, "Text"],
Cell[5548253, 188801, 698, 17, 78, "Text",
  CellTags->"i:56"],
Cell[5548954, 188820, 269, 7, 44, "Text",
  CellTags->"i:57"],
Cell[5549226, 188829, 838, 21, 76, "Text"],
Cell[5550067, 188852, 1730, 59, 61, "Text"],
Cell[5551800, 188913, 329880, 4376, 370, 299917, 4004, "BoxData", \
"Graphics3D", "Picture"],
Cell[5881683, 193291, 176, 4, 16, "Caption",
  CellTags->"Fig. 1.12"],
Cell[5881862, 193297, 977, 39, 64, "Text",
  CellTags->"i:58"],
Cell[5882842, 193338, 1735, 64, 98, "Text",
  CellTags->"i:59"],
Cell[5884580, 193404, 1337, 36, 146, "Text",
  CellTags->"i:60"],
Cell[5885920, 193442, 829, 26, 100, "NE4",
  CellTags->"(1.4.25)"],
Cell[5886752, 193470, 292, 11, 27, "Text"],
Cell[5887047, 193483, 2080, 67, 129, "Text"],
Cell[5889130, 193552, 603, 18, 61, "Text"],
Cell[5889736, 193572, 960, 36, 47, "Text",
  CellTags->"i:62"],
Cell[5890699, 193610, 246, 7, 44, "Text"],
Cell[5890948, 193619, 935793, 18368, 337, 857090, 17393, "BoxData", \
"Graphics3D", "Picture"],
Cell[6826744, 211989, 105, 1, 16, "Caption",
  CellTags->{"Fig. 1.13", "i:129"}],
Cell[6826852, 211992, 197, 5, 44, "Text"],
Cell[6827052, 211999, 2170, 66, 32, "Text"],
Cell[6829225, 212067, 1052, 29, 72, "Text"],
Cell[6830280, 212098, 585, 14, 38, "Text"],
Cell[6830868, 212114, 131, 6, 27, "Text"],
Cell[6831002, 212122, 1190, 43, 63, "Text"],
Cell[6832195, 212167, 741, 20, 78, "Text"],
Cell[6832939, 212189, 191456, 10484, 370, 156259, 10045, "GraphicsData", \
"PostScript", "Picture"],
Cell[7024398, 222675, 438, 17, 16, "Caption",
  CellTags->"Fig. 1.14"],
Cell[7024839, 222694, 3351, 96, 117, "Text",
  CellTags->"i:63"],
Cell[7028193, 222792, 2276, 71, 112, "Text",
  CellTags->"i:107"],
Cell[7030472, 222865, 1245, 42, 61, "Text"],
Cell[7031720, 222909, 65086, 1786, 370, 22769, 1259, "GraphicsData", \
"PostScript", "Picture"],
Cell[7096809, 224697, 550, 19, 16, "Caption",
  CellTags->"Fig. 1.15"],
Cell[7097362, 224718, 99, 4, 27, "Text"],
Cell[7097464, 224724, 193, 5, 27, "Text"],
Cell[7097660, 224731, 95, 4, 27, "Text"],
Cell[7097758, 224737, 179, 7, 27, "Text"],
Cell[7097940, 224746, 329, 10, 50, "Text"],
Cell[7098272, 224758, 453, 18, 36, "Text"],
Cell[7098728, 224778, 750, 22, 40, "Text"],
Cell[7099481, 224802, 585, 19, 28, "Text"],
Cell[7100069, 224823, 378, 10, 64, "Text"],
Cell[7100450, 224835, 292, 13, 31, "Text"],
Cell[7100745, 224850, 320, 13, 28, "Text"],
Cell[7101068, 224865, 633, 32, 27, "Text"],
Cell[7101704, 224899, 542, 18, 30, "Text"],
Cell[7102249, 224919, 418, 15, 30, "Text",
  CellTags->"ex 13"],
Cell[7102670, 224936, 272, 6, 44, "Text"],
Cell[7102945, 224944, 102, 5, 27, "Text"],
Cell[7103050, 224951, 103, 5, 27, "Text"],
Cell[7103156, 224958, 101, 5, 27, "Text"],
Cell[7103260, 224965, 101, 5, 27, "Text"],
Cell[7103364, 224972, 1349, 44, 91, "Text",
  CellTags->"i:64"],
Cell[7104716, 225018, 565, 17, 42, "NE4",
  CellTags->"(1.4.26)"],
Cell[7105284, 225037, 557, 17, 44, "Text"],
Cell[7105844, 225056, 616, 20, 32, "NE4",
  CellTags->"(1.4.27)"],
Cell[7106463, 225078, 572, 21, 44, "Text"],
Cell[7107038, 225101, 658, 20, 42, "NE4",
  CellTags->"(1.4.28)"],
Cell[7107699, 225123, 98, 3, 27, "Text"],
Cell[7107800, 225128, 127, 5, 27, "Text"],
Cell[7107930, 225135, 770, 30, 44, "Text"],
Cell[7108703, 225167, 292, 11, 27, "Text"],
Cell[7108998, 225180, 1191, 33, 74, "Text",
  CellTags->"i:65"],
Cell[7110192, 225215, 196, 6, 27, "Text"],
Cell[7110391, 225223, 861, 28, 53, "Text"],
Cell[7111255, 225253, 689, 19, 68, "Text"],
Cell[7111947, 225274, 1066, 36, 88, "Text"],
Cell[7113016, 225312, 904, 24, 58, "Text"],
Cell[7113923, 225338, 127, 5, 27, "Text"],
Cell[7114053, 225345, 193, 6, 27, "Text"],
Cell[7114249, 225353, 679, 20, 61, "Text",
  CellTags->"i:66"],
Cell[7114931, 225375, 747, 23, 31, "Text"],
Cell[7115681, 225400, 251, 9, 27, "Text"],
Cell[7115935, 225411, 346, 12, 30, "Text"],
Cell[7116284, 225425, 616, 22, 45, "Text"],
Cell[7116903, 225449, 164, 6, 28, "Text"],
Cell[7117070, 225457, 172, 5, 27, "Text"],
Cell[7117245, 225464, 456, 14, 29, "NE4",
  CellTags->"(1.4.29)"],
Cell[7117704, 225480, 1306, 35, 97, "Text"],
Cell[7119013, 225517, 290, 10, 27, "Text"],
Cell[7119306, 225529, 775, 25, 61, "Text"],
Cell[7120084, 225556, 361, 12, 44, "Text"],
Cell[7120448, 225570, 749, 21, 43, "NE4",
  CellTags->{"(1.4.30)", "i:78"}],
Cell[7121200, 225593, 436, 13, 62, "Text"],
Cell[7121639, 225608, 429, 13, 33, "NE4",
  CellTags->{"(1.4.31)", "i:67"}],
Cell[7122071, 225623, 634, 22, 62, "Text"],
Cell[7122708, 225647, 647, 20, 33, "NE4",
  CellTags->{"(1.4.32)", "i:68"}],
Cell[7123358, 225669, 423, 12, 44, "Text"],
Cell[7123784, 225683, 332, 12, 44, "Text"],
Cell[7124119, 225697, 867, 29, 48, "Text",
  CellTags->"i:69"],
Cell[7124989, 225728, 1042, 35, 80, "Text",
  CellTags->"i:75"],
Cell[7126034, 225765, 1049, 34, 33, "NE4",
  CellTags->"(1.4.33)"],
Cell[7127086, 225801, 454, 16, 44, "Text"],
Cell[7127543, 225819, 767, 23, 78, "Text"],
Cell[7128313, 225844, 226, 10, 27, "Text"],
Cell[7128542, 225856, 406, 14, 45, "Text"],
Cell[7128951, 225872, 916, 19, 115, "Text",
  CellTags->"i:76"],
Cell[7129870, 225893, 1538, 46, 115, "Text",
  CellTags->"i:77"],
Cell[7131411, 225941, 187, 5, 27, "Text"],
Cell[7131601, 225948, 1483, 40, 57, "Text",
  CellTags->"i:74"],
Cell[7133087, 225990, 1141, 31, 127, "Text",
  CellTags->"i:71"],
Cell[7134231, 226023, 279, 10, 27, "Text"],
Cell[7134513, 226035, 125, 5, 27, "Text"],
Cell[7134641, 226042, 349, 10, 44, "Text"],
Cell[7134993, 226054, 210, 7, 27, "Text"],
Cell[7135206, 226063, 169, 4, 44, "Text"],
Cell[7135378, 226069, 441, 13, 61, "Text"],
Cell[7135822, 226084, 2907, 81, 116, "Text"],
Cell[7138732, 226167, 1135, 42, 61, "Text"],
Cell[7139870, 226211, 651, 17, 78, "Text",
  CellTags->"i:72"],
Cell[7140524, 226230, 2144, 75, 137, "Text"],
Cell[7142671, 226307, 1114, 30, 95, "Text",
  CellTags->"i:73"],
Cell[7143788, 226339, 188, 4, 86, "Input",
  CellTags->"Cell 1.66"],
Cell[7143979, 226345, 215, 8, 27, "Text"],
Cell[7144197, 226355, 160, 5, 67, "Input",
  CellTags->"Cell 1.67"],
Cell[7144360, 226362, 224, 6, 44, "Text"],
Cell[7144587, 226370, 310, 7, 105, "Input",
  CellTags->"Cell 1.68"],
Cell[7144900, 226379, 488, 17, 27, "Text"],
Cell[7145391, 226398, 237, 6, 124, "Input",
  CellTags->"Cell 1.69"],
Cell[7145631, 226406, 1172, 36, 62, "Text"],
Cell[7146806, 226444, 922, 25, 96, "Text",
  CellTags->"i:144"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7147777, 226475, 300, 11, 40, "Subtitle",
  CellTags->{"Sec. 1.5", "i:79", "c:29"}],
Cell[7148080, 226488, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[7148121, 226492, 108, 2, 41, "Subsubtitle",
  CellTags->"c:30"],
Cell[7148232, 226496, 401, 14, 44, "Text"],
Cell[7148636, 226512, 464, 15, 44, "Text"],
Cell[7149103, 226529, 469, 12, 61, "Text"],
Cell[7149575, 226543, 251, 8, 43, "NE5",
  CellTags->"(1.5.1)"],
Cell[7149829, 226553, 986, 36, 65, "Text",
  CellTags->"i:120"],
Cell[7150818, 226591, 115, 2, 27, "NE5",
  CellTags->"(1.5.2)"],
Cell[7150936, 226595, 233, 6, 44, "Text"],
Cell[7151172, 226603, 140, 5, 43, "NE5",
  CellTags->"(1.5.3)"],
Cell[7151315, 226610, 890, 34, 61, "Text"],
Cell[7152208, 226646, 163, 6, 43, "NE5",
  CellTags->"(1.5.4)"],
Cell[7152374, 226654, 332, 6, 61, "Text"],
Cell[7152709, 226662, 199, 6, 47, "Text",
  CellTags->"i:17"],
Cell[7152911, 226670, 187, 4, 44, "Text"],
Cell[7153101, 226676, 280, 9, 42, "NE5",
  CellTags->"(1.5.5)"],
Cell[7153384, 226687, 448, 12, 61, "Text"],
Cell[7153835, 226701, 141, 5, 29, "NE5",
  CellTags->"(1.5.6)"],
Cell[7153979, 226708, 699, 19, 61, "Text"],
Cell[7154681, 226729, 146, 3, 27, "NE5",
  CellTags->"(1.5.7)"],
Cell[7154830, 226734, 343, 14, 44, "Text"],
Cell[7155176, 226750, 211, 4, 44, "Text"],
Cell[7155390, 226756, 122, 5, 29, "NE5",
  CellTags->"(1.5.8)"],
Cell[7155515, 226763, 817, 27, 78, "Text"],
Cell[7156335, 226792, 123, 2, 27, "NE5",
  CellTags->"(1.5.9)"],
Cell[7156461, 226796, 517, 16, 61, "Text"],
Cell[7156981, 226814, 772, 27, 61, "Text"],
Cell[7157756, 226843, 127, 5, 29, "NE5",
  CellTags->"(1.5.10)"],
Cell[7157886, 226850, 245, 9, 27, "Text"],
Cell[7158134, 226861, 458, 15, 64, "Text",
  CellTags->"i:80"],
Cell[7158595, 226878, 441, 10, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7159073, 226893, 135, 4, 30, "Subsubtitle",
  CellTags->{"i:43", "c:31"}],
Cell[7159211, 226899, 608, 13, 95, "Text"],
Cell[7159822, 226914, 113, 3, 27, "Text"],
Cell[7159938, 226919, 411, 10, 43, "NE5",
  CellTags->"(1.5.11)"],
Cell[7160352, 226931, 65, 1, 27, "Text",
  CellTags->"i:122"],
Cell[7160420, 226934, 133, 5, 29, "NE5",
  CellTags->"(1.5.12)"],
Cell[7160556, 226941, 451, 15, 44, "Text"],
Cell[7161010, 226958, 934, 23, 113, "Text"],
Cell[7161947, 226983, 409, 7, 78, "Text"],
Cell[7162359, 226992, 211, 4, 44, "Text"],
Cell[7162573, 226998, 370, 14, 45, "Text"],
Cell[7162946, 227014, 230, 6, 86, "Input",
  CellTags->"Cell 1.70"],
Cell[7163179, 227022, 713, 21, 78, "Text"],
Cell[7163895, 227045, 366, 7, 61, "Text"],
Cell[7164264, 227054, 167, 4, 86, "Input",
  CellTags->"Cell 1.71"],
Cell[7164434, 227060, 707, 19, 64, "Text"],
Cell[7165144, 227081, 130, 4, 86, "Input",
  CellTags->"Cell 1.72"],
Cell[7165277, 227087, 358, 13, 27, "Text"],

Cell[CellGroupData[{
Cell[7165660, 227104, 87, 3, 67, "Input",
  CellTags->"Cell 1.73"],
Cell[7165750, 227109, 224, 6, 46, "Output"]
}, Open  ]],
Cell[7165989, 227118, 287, 10, 27, "Text"],

Cell[CellGroupData[{
Cell[7166301, 227132, 121, 3, 67, "Input",
  CellTags->"Cell 1.74"],
Cell[7166425, 227137, 20460, 450, 233, 3326, 235, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7186900, 227590, 409, 9, 61, "Text"],
Cell[7187312, 227601, 231, 9, 27, "Text"],
Cell[7187546, 227612, 124, 3, 67, "Input",
  CellTags->"Cell 1.75"],
Cell[7187673, 227617, 194, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[7187892, 227628, 88, 3, 67, "Input",
  CellTags->"Cell 1.76"],
Cell[7187983, 227633, 53, 1, 46, "Output"]
}, Open  ]],
Cell[7188051, 227637, 91, 3, 27, "Text"],
Cell[7188145, 227642, 985, 35, 61, "Text"],

Cell[CellGroupData[{
Cell[7189155, 227681, 124, 3, 67, "Input",
  CellTags->"Cell 1.77"],
Cell[7189282, 227686, 66, 1, 46, "Output"]
}, Open  ]],
Cell[7189363, 227690, 384, 11, 44, "Text"],

Cell[CellGroupData[{
Cell[7189772, 227705, 173, 4, 86, "Input",
  CellTags->"Cell 1.78"],
Cell[7189948, 227711, 20391, 439, 233, 3188, 223, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7210354, 228153, 460, 7, 78, "Text"],
Cell[7210817, 228162, 75, 0, 27, "Text"],
Cell[7210895, 228164, 313, 7, 64, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7211245, 228176, 125, 2, 30, "Subsubtitle",
  CellTags->{"Ex. 1.5", "c:32"}],
Cell[7211373, 228180, 2122, 61, 188, "Text"],
Cell[7213498, 228243, 768, 20, 95, "Text"],
Cell[7214269, 228265, 421, 12, 27, "NE5",
  CellTags->"(1.5.13)"],
Cell[7214693, 228279, 641, 21, 61, "Text"],
Cell[7215337, 228302, 150, 5, 41, "NE5",
  CellTags->"(1.5.14)"],
Cell[7215490, 228309, 950, 39, 77, "Text"],
Cell[7216443, 228350, 383, 13, 44, "Text"],
Cell[7216829, 228365, 493, 14, 44, "Text"],
Cell[7217325, 228381, 689, 23, 61, "Text"],
Cell[7218017, 228406, 1087, 36, 78, "Text"],
Cell[7219107, 228444, 3589, 113, 148, "Text"],
Cell[7222699, 228559, 484, 16, 47, "Text"],
Cell[7223186, 228577, 35533, 442, 158, 35411, 438, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[7258722, 229021, 287, 10, 16, "Caption",
  CellTags->"Fig. 1.16"],
Cell[7259012, 229033, 749, 20, 81, "Text"],
Cell[7259764, 229055, 463, 11, 61, "Text"],
Cell[7260230, 229068, 215, 6, 44, "Text"],
Cell[7260448, 229076, 1426, 30, 163, "Text"],
Cell[7261877, 229108, 85310, 1371, 422, 55210, 996, "BoxData", "Graphics3D", \
"Graphics"],
Cell[7347190, 230481, 79, 1, 16, "Caption",
  CellTags->"Fig. 1.17"],
Cell[7347272, 230484, 832, 24, 69, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7348153, 230514, 77, 1, 40, "Subtitle",
  CellTags->{"Sec. 1.6", "i:81", "c:33"}],
Cell[7348233, 230517, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[7348274, 230521, 79, 1, 41, "Subsubtitle",
  CellTags->"c:34"],

Cell[CellGroupData[{
Cell[7348378, 230526, 124, 5, 42, "Section",
  CellTags->"c:35"],
Cell[7348505, 230533, 363, 12, 44, "Text"],
Cell[7348871, 230547, 837, 23, 42, "NE6",
  CellTags->"(1.6.1)"],
Cell[7349711, 230572, 495, 17, 44, "Text"],
Cell[7350209, 230591, 506, 14, 42, "NE6",
  CellTags->{"(1.6.2)", "i:91"}],
Cell[7350718, 230607, 813, 28, 47, "Text",
  CellTags->"i:104"],
Cell[7351534, 230637, 334, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7351905, 230648, 68, 1, 31, "Section",
  CellTags->"c:36"],
Cell[7351976, 230651, 823, 22, 85, "Text",
  CellTags->"i:131"],
Cell[7352802, 230675, 201, 10, 27, "Text"],
Cell[7353006, 230687, 850, 22, 42, "NE6",
  CellTags->{"(1.6.3)", "i:130"}],
Cell[7353859, 230711, 293, 10, 31, "Text"],
Cell[7354155, 230723, 87, 1, 27, "Text",
  CellTags->"i:83"],
Cell[7354245, 230726, 574, 22, 76, "Text"],
Cell[7354822, 230750, 944, 24, 99, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7355803, 230779, 66, 1, 31, "Section",
  CellTags->"c:37"],
Cell[7355872, 230782, 584, 19, 65, "Text",
  CellTags->"i:85"],
Cell[7356459, 230803, 756, 20, 78, "Text"],
Cell[7357218, 230825, 166, 6, 29, "NE6",
  CellTags->"(1.6.4)"],
Cell[7357387, 230833, 228, 4, 44, "Text"],
Cell[7357618, 230839, 536, 19, 48, "Text"],
Cell[7358157, 230860, 300, 8, 33, "NE6",
  CellTags->"(1.6.5)"],
Cell[7358460, 230870, 230, 7, 27, "Text"],
Cell[7358693, 230879, 2004, 40, 94, "Table",
  CellTags->"i:82"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7360746, 230925, 97, 1, 30, "Subsubtitle",
  CellTags->"c:38"],

Cell[CellGroupData[{
Cell[7360868, 230930, 51, 1, 42, "Section",
  CellTags->"c:39"],
Cell[7360922, 230933, 1169, 35, 99, "Text"],
Cell[7362094, 230970, 193, 4, 27, "NE6",
  CellTags->"(1.6.6)"],
Cell[7362290, 230976, 1261, 30, 129, "Text"],
Cell[7363554, 231008, 822, 25, 78, "Text"],
Cell[7364379, 231035, 379, 12, 68, "Text",
  CellTags->"i:84"],
Cell[7364761, 231049, 392, 12, 44, "Text"],
Cell[7365156, 231063, 837, 20, 42, "NE6",
  CellTags->"(1.6.7)"],
Cell[7365996, 231085, 414, 13, 46, "Text"],
Cell[7366413, 231100, 346, 10, 40, "NE6",
  CellTags->"(1.6.8)"],
Cell[7366762, 231112, 186, 8, 31, "Text"],
Cell[7366951, 231122, 264, 7, 33, "NE6",
  CellTags->"(1.6.9)"],
Cell[7367218, 231131, 727, 24, 61, "Text"],
Cell[7367948, 231157, 225, 7, 31, "NE6",
  CellTags->{"(1.6.10)", "i:89"}],
Cell[7368176, 231166, 560, 19, 44, "Text",
  CellTags->"i:90"],
Cell[7368739, 231187, 1756, 62, 78, "Text"],
Cell[7370498, 231251, 270, 4, 38, "NE6",
  CellTags->"(1.6.11)"],
Cell[7370771, 231257, 275, 7, 44, "Text",
  CellTags->"i:117"],

Cell[CellGroupData[{
Cell[7371071, 231268, 299, 7, 86, "Input",
  CellTags->"Cell 1.79"],
Cell[7371373, 231277, 382, 9, 50, "Output"]
}, Open  ]],
Cell[7371770, 231289, 545, 12, 80, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7372352, 231306, 159, 3, 31, "Section",
  CellTags->"c:40"],
Cell[7372514, 231311, 525, 15, 61, "Text"],
Cell[7373042, 231328, 307, 9, 32, "NE6",
  CellTags->"(1.6.12)"],
Cell[7373352, 231339, 240, 9, 27, "Text"],
Cell[7373595, 231350, 149, 6, 32, "NE6",
  CellTags->"(1.6.13)"],
Cell[7373747, 231358, 35, 0, 27, "Text"],
Cell[7373785, 231360, 306, 7, 129, "NE6",
  CellTags->"(1.6.14)"],
Cell[7374094, 231369, 595, 17, 61, "Text",
  CellTags->"i:118"],
Cell[7374692, 231388, 290, 8, 69, "NE6",
  CellTags->"(1.6.15)"],
Cell[7374985, 231398, 459, 13, 61, "Text"],
Cell[7375447, 231413, 203, 4, 46, "NE6",
  CellTags->"(1.6.16)"],
Cell[7375653, 231419, 377, 8, 61, "Text"],
Cell[7376033, 231429, 384, 6, 124, "NE6",
  CellTags->{"(1.6.17)", "i:92"}],
Cell[7376420, 231437, 328, 8, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7376797, 231451, 146, 3, 30, "Subsubtitle",
  CellTags->"c:41"],
Cell[7376946, 231456, 186, 7, 27, "Text"],
Cell[7377135, 231465, 177, 6, 33, "NE6",
  CellTags->"(1.6.18)"],
Cell[7377315, 231473, 558, 17, 69, "Text"],
Cell[7377876, 231492, 1151, 37, 61, "Text",
  CellTags->"i:44"],
Cell[7379030, 231531, 256, 10, 27, "Text"],
Cell[7379289, 231543, 873, 29, 69, "Text"],
Cell[7380165, 231574, 423, 14, 38, "NE6",
  CellTags->"(1.6.19)"],
Cell[7380591, 231590, 209, 7, 27, "Text",
  CellTags->"i:126"],
Cell[7380803, 231599, 939, 24, 65, "NE6",
  CellTags->"(1.6.20)"],
Cell[7381745, 231625, 88, 3, 27, "Text"],
Cell[7381836, 231630, 2053, 56, 138, "NE6",
  CellTags->"(1.6.21)"],
Cell[7383892, 231688, 880, 29, 78, "Text",
  CellTags->"i:99"],
Cell[7384775, 231719, 656, 24, 44, "Text",
  CellTags->"i:100"],
Cell[7385434, 231745, 693, 24, 45, "NE6",
  CellTags->"(1.6.22)"],
Cell[7386130, 231771, 1334, 47, 86, "Text",
  CellTags->"i:134"],
Cell[7387467, 231820, 954, 27, 30, "NE6",
  CellTags->"(1.6.23)"],
Cell[7388424, 231849, 157, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[7388606, 231859, 265, 7, 105, "Input",
  CellTags->"Cell 1.80"],
Cell[7388874, 231868, 411, 9, 104, "Output"]
}, Open  ]],
Cell[7389300, 231880, 101, 3, 27, "Text"],
Cell[7389404, 231885, 793, 23, 63, "Text"],
Cell[7390200, 231910, 1203, 34, 95, "Text"],
Cell[7391406, 231946, 186, 6, 27, "Text"],
Cell[7391595, 231954, 485, 17, 29, "NE6",
  CellTags->"(1.6.24)"],
Cell[7392083, 231973, 597, 18, 61, "Text",
  CellTags->"i:101"],
Cell[7392683, 231993, 525, 18, 32, "NE6",
  CellTags->{"(1.6.25)", "i:105"}],
Cell[7393211, 232013, 491, 10, 78, "Text"],
Cell[7393705, 232025, 936, 29, 78, "Text"],
Cell[7394644, 232056, 1516, 53, 80, "Text"],
Cell[7396163, 232111, 396, 9, 143, "Input",
  CellTags->"Cell 1.81"],
Cell[7396562, 232122, 400, 16, 27, "Text"],
Cell[7396965, 232140, 215, 6, 86, "Input",
  CellTags->"Cell 1.82"],
Cell[7397183, 232148, 430, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[7397638, 232165, 482, 11, 124, "Input",
  CellTags->"Cell 1.83"],
Cell[7398123, 232178, 29057, 642, 233, 6131, 354, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7427195, 232823, 924, 27, 78, "Text"],
Cell[7428122, 232852, 544, 13, 78, "Text",
  CellTags->"i:116"],
Cell[7428669, 232867, 1402, 42, 108, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7430108, 232914, 74, 1, 30, "Subsubtitle",
  CellTags->"c:42"],

Cell[CellGroupData[{
Cell[7430207, 232919, 75, 1, 42, "Section",
  CellTags->"c:43"],
Cell[7430285, 232922, 441, 15, 48, "Text",
  CellTags->"i:86"],
Cell[7430729, 232939, 117, 5, 33, "NE6",
  CellTags->"(1.6.26)"],
Cell[7430849, 232946, 279, 6, 44, "Text",
  CellTags->"i:119"],
Cell[7431131, 232954, 135, 5, 30, "NE6",
  CellTags->"(1.6.27)"],
Cell[7431269, 232961, 185, 6, 27, "Text",
  CellTags->"i:87"],
Cell[7431457, 232969, 118, 2, 32, "NE6",
  CellTags->"(1.6.28)"],
Cell[7431578, 232973, 163, 5, 28, "Text"],
Cell[7431744, 232980, 120, 5, 34, "NE6",
  CellTags->"(1.6.29)"],
Cell[7431867, 232987, 362, 15, 28, "Text",
  CellTags->"i:88"],
Cell[7432232, 233004, 888, 32, 65, "Text"],
Cell[7433123, 233038, 687, 17, 79, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7433847, 233060, 84, 1, 31, "Section",
  CellTags->{"i:93", "c:44"}],
Cell[7433934, 233063, 979, 26, 96, "Text",
  CellTags->"i:94"],
Cell[7434916, 233091, 95, 3, 27, "Text"],
Cell[7435014, 233096, 118, 5, 29, "NE6",
  CellTags->"(1.6.30)"],
Cell[7435135, 233103, 93, 3, 27, "Text"],
Cell[7435231, 233108, 129, 5, 30, "NE6",
  CellTags->"(1.6.31)"],
Cell[7435363, 233115, 262, 11, 31, "Text"],
Cell[7435628, 233128, 151, 5, 34, "NE6",
  CellTags->"(1.6.32)"],
Cell[7435782, 233135, 365, 14, 27, "Text"],
Cell[7436150, 233151, 161, 6, 29, "NE6",
  CellTags->"(1.6.33)"],
Cell[7436314, 233159, 455, 10, 61, "Text"],
Cell[7436772, 233171, 136, 5, 29, "NE6",
  CellTags->"(1.6.34)"],
Cell[7436911, 233178, 222, 5, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7437170, 233188, 80, 1, 31, "Section",
  CellTags->{"i:103", "c:45"}],
Cell[7437253, 233191, 507, 12, 78, "Text"],
Cell[7437763, 233205, 133, 5, 29, "NE6",
  CellTags->"(1.6.35)"],
Cell[7437899, 233212, 99, 3, 27, "Text"],
Cell[7438001, 233217, 165, 6, 30, "NE6",
  CellTags->"(1.6.36)"],
Cell[7438169, 233225, 496, 16, 44, "Text"],
Cell[7438668, 233243, 472, 8, 86, "NE6",
  CellTags->"(1.6.37)"],
Cell[7439143, 233253, 498, 19, 44, "Text"],
Cell[7439644, 233274, 228, 7, 44, "Text"],
Cell[7439875, 233283, 169, 4, 31, "NE6",
  CellTags->"(1.6.38)"],
Cell[7440047, 233289, 39, 0, 27, "Text"],
Cell[7440089, 233291, 170, 4, 33, "NE6",
  CellTags->"(1.6.39)"],
Cell[7440262, 233297, 669, 19, 64, "Text"],
Cell[7440934, 233318, 292, 8, 30, "NE6",
  CellTags->"(1.6.40)"],
Cell[7441229, 233328, 497, 18, 27, "Text"],
Cell[7441729, 233348, 343, 13, 28, "Text"],
Cell[7442075, 233363, 316, 8, 34, "NE6",
  CellTags->"(1.6.41)"],
Cell[7442394, 233373, 605, 17, 65, "Text"],
Cell[7443002, 233392, 458, 13, 40, "NE6",
  CellTags->"(1.6.42)"],
Cell[7443463, 233407, 141, 6, 27, "Text"],
Cell[7443607, 233415, 316, 8, 33, "NE6",
  CellTags->"(1.6.43)"],
Cell[7443926, 233425, 298, 10, 28, "Text",
  CellTags->"i:95"],
Cell[7444227, 233437, 252, 5, 49, "NE6",
  CellTags->"(1.6.44)"],
Cell[7444482, 233444, 638, 18, 86, "Text"],
Cell[7445123, 233464, 279, 5, 44, "NE6",
  CellTags->"(1.6.45)"],
Cell[7445405, 233471, 1027, 27, 95, "Text"],
Cell[7446435, 233500, 47772, 1580, 233, 19306, 1224, "GraphicsData", \
"PostScript", "Picture"],
Cell[7494210, 235082, 238, 7, 18, "Caption",
  CellTags->"Fig. 1.18"],
Cell[7494451, 235091, 991, 22, 112, "Text",
  CellTags->"i:102"]
}, Closed]],

Cell[CellGroupData[{
Cell[7495479, 235118, 58, 1, 31, "Section",
  CellTags->{"i:96", "c:46"}],
Cell[7495540, 235121, 710, 19, 65, "Text"],
Cell[7496253, 235142, 64633, 1757, 227, 23989, 1251, "GraphicsData", \
"PostScript", "Picture"],
Cell[7560889, 236901, 564, 14, 63, "Caption",
  CellTags->"Fig. 1.19"],
Cell[7561456, 236917, 1132, 27, 130, "Text"],
Cell[7562591, 236946, 531, 17, 44, "Text",
  CellTags->"i:97"],
Cell[7563125, 236965, 176, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[7563326, 236975, 291, 8, 124, "Input",
  CellTags->"Cell 1.84"],
Cell[7563620, 236985, 219, 5, 69, "Output"]
}, Open  ]],
Cell[7563854, 236993, 719, 14, 95, "Text"],
Cell[7564576, 237009, 702, 18, 78, "Text"],
Cell[7565281, 237029, 554, 15, 61, "Text"],
Cell[7565838, 237046, 555, 15, 33, "NE6",
  CellTags->"(1.6.46)"],
Cell[7566396, 237063, 809, 23, 78, "Text"],
Cell[7567208, 237088, 476, 11, 42, "NE6",
  CellTags->"(1.6.47)"],
Cell[7567687, 237101, 422, 14, 44, "Text",
  CellTags->"i:141"],

Cell[CellGroupData[{
Cell[7568134, 237119, 194, 5, 86, "Input",
  CellTags->"Cell 1.85"],
Cell[7568331, 237126, 99895, 1984, 233, 14042, 920, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7668241, 239113, 998, 25, 95, "Text"],

Cell[CellGroupData[{
Cell[7669264, 239142, 253, 5, 96, "Input",
  CellTags->"Cell 1.86"],
Cell[7669520, 239149, 86, 1, 68, "Output"]
}, Open  ]],
Cell[7669621, 239153, 247, 7, 44, "Text"],
Cell[7669871, 239162, 328, 8, 61, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7670248, 239176, 78, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 1.6", "c:47"}],
Cell[7670329, 239179, 1532, 44, 97, "Text",
  CellTags->"i:132"],
Cell[7671864, 239225, 281, 8, 44, "Text"],
Cell[7672148, 239235, 278, 9, 28, "Text"],
Cell[7672429, 239246, 283, 9, 28, "Text"],
Cell[7672715, 239257, 221, 8, 28, "Text"],
Cell[7672939, 239267, 249, 9, 28, "Text"],
Cell[7673191, 239278, 152, 5, 27, "Text"],
Cell[7673346, 239285, 396, 14, 36, "Text"],
Cell[7673745, 239301, 574, 18, 65, "Text"],
Cell[7674322, 239321, 746, 26, 44, "Text",
  CellTags->"i:106"],
Cell[7675071, 239349, 304, 10, 45, "Text"],
Cell[7675378, 239361, 949, 31, 62, "Text"],
Cell[7676330, 239394, 343, 11, 44, "Text"],
Cell[7676676, 239407, 173, 6, 27, "Text"],
Cell[7676852, 239415, 773, 27, 48, "Text"],
Cell[7677628, 239444, 396, 9, 61, "Text"],
Cell[7678027, 239455, 173, 7, 27, "Text"],
Cell[7678203, 239464, 279, 10, 30, "Text"],
Cell[7678485, 239476, 277, 10, 28, "Text"],
Cell[7678765, 239488, 821, 26, 65, "Text"],
Cell[7679589, 239516, 227, 8, 27, "Text"],
Cell[7679819, 239526, 537, 18, 44, "Text"],
Cell[7680359, 239546, 262, 7, 30, "Text"],
Cell[7680624, 239555, 906, 32, 64, "Text"],
Cell[7681533, 239589, 646, 21, 44, "Text"],
Cell[7682182, 239612, 249, 7, 30, "Text"],
Cell[7682434, 239621, 1368, 37, 105, "Text"],
Cell[7683805, 239660, 257, 6, 44, "Text"],
Cell[7684065, 239668, 948, 29, 61, "Text"],
Cell[7685016, 239699, 847, 22, 61, "Text"],
Cell[7685866, 239723, 472, 15, 53, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7686387, 239744, 60, 1, 40, "Subtitle",
  CellTags->{"refs", "c:48"}],
Cell[7686450, 239747, 182, 5, 27, "Text"],
Cell[7686635, 239754, 238, 8, 27, "Text"],
Cell[7686876, 239764, 213, 5, 44, "Text"],
Cell[7687092, 239771, 160, 5, 27, "Text"],
Cell[7687255, 239778, 280, 10, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

